// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = eval('(function() { try { return Module || {} } catch(e) { return {} } })()');
// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function(filename) { return Module['read'](filename, true) };
  Module['load'] = function(f) {
    globalEval(read(f));
  };
  Module['arguments'] = process['argv'].slice(2);
  module.exports = Module;
}
else if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function() { throw 'no read() available (jsc?)' };
  }
  Module['readBinary'] = function(f) {
    return read(f, 'binary');
  };
  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  this['Module'] = Module;
}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  if (ENVIRONMENT_IS_WEB) {
    Module['print'] = function(x) {
      console.log(x);
    };
    Module['printErr'] = function(x) {
      console.log(x);
    };
    this['Module'] = Module;
  } else if (ENVIRONMENT_IS_WORKER) {
    // We can do very little here...
    var TRY_USE_DUMP = false;
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];
// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (type == 'i64' || type == 'double' || vararg) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    var index = 0;
    type.flatIndexes = type.fields.map(function(field) {
      index++;
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        if (field[1] === '0') {
          // this is [0 x something]. When inside another structure like here, it must be at the end,
          // and it adds no size
          // XXX this happens in java-nbody for example... assert(index === type.fields.length, 'zero-length in the middle!');
          size = 0;
          alignSize = type.alignSize || QUANTUM_SIZE;
        } else {
          size = Types.types[field].flatSize;
          alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
        }
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2 + 2*i;
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;
      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }
      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          Math.floor((codePoint - 0x10000) / 0x400) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+7)>>3)<<3); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+7)>>3)<<3); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = ((((DYNAMICTOP)+7)>>3)<<3); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>(0))))+((+(((high)>>>(0))))*(+(4294967296)))) : ((+(((low)>>>(0))))+((+(((high)|(0))))*(+(4294967296))))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = Module['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value, or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 67108864;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited
var runtimeInitialized = false;
function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}
function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;
function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;
function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;
function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;
function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math['imul']) Math['imul'] = function(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledInit = false, calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
function loadMemoryInitializer(filename) {
  function applyData(data) {
    HEAPU8.set(data, STATIC_BASE);
  }
  // always do this asynchronously, to keep shell and web as similar as possible
  addOnPreRun(function() {
    if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
      applyData(Module['readBinary'](filename));
    } else {
      Browser.asyncLoad(filename, function(data) {
        applyData(data);
      }, function(data) {
        throw 'could not load memory initializer ' + filename;
      });
    }
  });
}
// === Body ===
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 741496;
var _stdout;
var _stdin;
var _stderr;
/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } },{ func: function() { __GLOBAL__I_a72() } },{ func: function() { __GLOBAL__I_a419() } },{ func: function() { __GLOBAL__I_a2219() } });
var ___fsmu8;
var ___dso_handle;
var __ZTVN10__cxxabiv120__si_class_type_infoE;
var __ZTVN10__cxxabiv117__class_type_infoE;
var _stdout = _stdout=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stdin = _stdin=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stderr = _stderr=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
__ZTVN10__cxxabiv120__si_class_type_infoE=allocate([0,0,0,0,200,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
__ZTVN10__cxxabiv117__class_type_infoE=allocate([0,0,0,0,216,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,88,0,0,0,10,0,0,0,208,0,0,0,14,0,0,0,108,0,0,0,54,0,0,0,102,1,0,0,56,145,0,0,46,0,0,0,60,0,0,0,22,0,0,0,204,1,0,0,34,0,0,0,116,2,0,0,150,1,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,248,0,5,0,184,9,5,0,1,1,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,0,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,13,0,0,0,15,0,0,0,17,0,0,0,19,0,0,0,23,0,0,0,27,0,0,0,31,0,0,0,35,0,0,0,43,0,0,0,51,0,0,0,59,0,0,0,67,0,0,0,83,0,0,0,99,0,0,0,115,0,0,0,131,0,0,0,163,0,0,0,195,0,0,0,227,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,13,0,0,0,17,0,0,0,25,0,0,0,33,0,0,0,49,0,0,0,65,0,0,0,97,0,0,0,129,0,0,0,193,0,0,0,1,1,0,0,129,1,0,0,1,2,0,0,1,3,0,0,1,4,0,0,1,6,0,0,1,8,0,0,1,12,0,0,1,16,0,0,1,24,0,0,1,32,0,0,1,48,0,0,1,64,0,0,1,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,240,40,1,0,0,0,0,0,208,40,1,0,1,0,0,0,232,111,0,0,2,0,0,0,120,110,0,0,3,0,0,0,216,108,0,0,4,0,0,0,48,107,0,0,5,0,0,0,240,105,0,0,6,0,0,0,40,104,0,0,7,0,0,0,248,40,1,0,8,0,0,0,216,40,1,0,9,0,0,0,232,40,1,0,10,0,0,0,136,43,0,0,11,0,0,0,24,95,0,0,12,0,0,0,240,93,0,0,13,0,0,0,0,93,0,0,14,0,0,0,176,91,0,0,15,0,0,0,192,90,0,0,16,0,0,0,160,89,0,0,17,0,0,0,248,88,0,0,18,0,0,0,24,87,0,0,19,0,0,0,136,84,0,0,20,0,0,0,248,82,0,0,21,0,0,0,8,81,0,0,22,0,0,0,80,80,0,0,23,0,0,0,248,79,0,0,24,0,0,0,152,79,0,0,25,0,0,0,0,79,0,0,26,0,0,0,72,78,0,0,27,0,0,0,208,77,0,0,28,0,0,0,224,76,0,0,29,0,0,0,40,75,0,0,30,0,0,0,80,74,0,0,31,0,0,0,144,73,0,0,32,0,0,0,184,72,0,0,33,0,0,0,16,72,0,0,34,0,0,0,72,71,0,0,35,0,0,0,120,70,0,0,36,0,0,0,104,69,0,0,37,0,0,0,144,68,0,0,38,0,0,0,200,67,0,0,39,0,0,0,224,65,0,0,40,0,0,0,232,64,0,0,41,0,0,0,176,63,0,0,42,0,0,0,184,62,0,0,43,0,0,0,48,62,0,0,44,0,0,0,144,61,0,0,45,0,0,0,8,61,0,0,46,0,0,0,56,60,0,0,47,0,0,0,104,59,0,0,48,0,0,0,192,58,0,0,49,0,0,0,160,56,0,0,50,0,0,0,176,55,0,0,51,0,0,0,40,54,0,0,52,0,0,0,112,53,0,0,53,0,0,0,200,52,0,0,54,0,0,0,32,52,0,0,55,0,0,0,2,0,0,0,152,2,0,0,114,0,0,0,216,180,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,111,114,109,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,56,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,55,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,2,0,0,0,1,1,0,0,4,1,0,0,4,2,0,0,4,3,0,0,4,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,3,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,248,0,5,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,9,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,128,163,0,0,208,157,8,0,104,195,0,0,216,157,8,0,48,144,0,0,144,157,8,0,152,115,0,0,96,157,8,0,168,97,0,0,128,157,8,0,24,85,0,0,64,157,8,0,136,75,0,0,184,157,8,0,72,66,0,0,80,157,8,0,0,57,0,0,72,157,8,0,120,47,0,0,0,158,8,0,56,212,0,0,16,158,8,0,176,201,0,0,8,158,8,0,48,192,0,0,200,157,8,0,208,185,0,0,24,158,8,0,136,181,0,0,224,157,8,0,248,175,0,0,192,157,8,0,40,170,0,0,136,157,8,0,192,165,0,0,240,157,8,0,152,161,0,0,232,157,8,0,160,157,0,0,248,157,8,0,168,153,0,0,176,157,8,0,160,148,0,0,88,157,8,0,8,142,0,0,104,157,8,0,168,136,0,0,120,157,8,0,80,132,0,0,168,157,8,0,40,130,0,0,112,157,8,0,248,126,0,0,160,157,8,0,72,124,0,0,152,157,8,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,104,176,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,136,175,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,184,174,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,192,173,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,96,173,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,232,172,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,128,172,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,64,172,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,240,171,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,144,171,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,112,170,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,208,169,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,120,169,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,144,168,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,248,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,192,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,136,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,80,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,32,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,216,166,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,240,165,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,112,165,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,224,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,64,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,16,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,104,176,0,0,122,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,136,175,0,0,97,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,184,174,0,0,47,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,192,173,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,96,173,0,0,17,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,232,172,0,0,18,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,128,172,0,0,20,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,64,172,0,0,19,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,240,171,0,0,120,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,144,171,0,0,115,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,112,170,0,0,113,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,208,169,0,0,119,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,120,169,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,144,168,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,248,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,192,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,136,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,80,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,32,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,216,166,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,240,165,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,112,165,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,224,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,64,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,16,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,25,0,0,0,240,163,0,0,32,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,26,0,0,0,184,163,0,0,108,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,27,0,0,0,40,178,0,0,29,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,28,0,0,0,160,178,0,0,27,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,29,0,0,0,24,163,0,0,102,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,30,0,0,0,8,162,0,0,27,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,31,0,0,0,80,161,0,0,32,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,32,0,0,0,8,161,0,0,31,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,33,0,0,0,208,211,0,0,114,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,34,0,0,0,200,159,0,0,111,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,35,0,0,0,128,159,0,0,112,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,36,0,0,0,56,159,0,0,107,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,37,0,0,0,0,159,0,0,104,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,38,0,0,0,200,158,0,0,109,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,39,0,0,0,128,158,0,0,110,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,40,0,0,0,0,158,0,0,121,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,41,0,0,0,64,157,0,0,116,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,42,0,0,0,224,156,0,0,117,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,43,0,0,0,48,156,0,0,33,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,44,0,0,0,240,155,0,0,99,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,45,0,0,0,136,42,0,0,34,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,46,0,0,0,160,155,0,0,105,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,47,0,0,0,136,155,0,0,101,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,48,0,0,0,64,155,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,49,0,0,0,8,155,0,0,14,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,50,0,0,0,8,154,0,0,13,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,51,0,0,0,96,153,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,52,0,0,0,248,152,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,53,0,0,0,72,152,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,54,0,0,0,8,204,0,0,36,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,55,0,0,0,208,151,0,0,26,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,37,0,0,0,20,1,0,0,39,0,0,0,19,1,0,0,38,0,0,0,17,1,0,0,40,0,0,0,18,1,0,0,13,0,0,0,13,0,0,0,9,0,0,0,9,0,0,0,45,0,0,0,21,1,0,0,46,0,0,0,127,0,0,0,16,0,0,0,47,1,0,0,16,0,0,0,48,1,0,0,17,0,0,0,50,1,0,0,35,0,0,0,23,1,0,0,36,0,0,0,22,1,0,0,34,0,0,0,25,1,0,0,33,0,0,0,24,1,0,0,18,0,0,0,52,1,0,0,32,0,0,0,32,0,0,0,27,0,0,0,27,0,0,0,8,0,0,0,8,0,0,0,13,0,0,0,15,1,0,0,107,0,0,0,14,1,0,0,109,0,0,0,13,1,0,0,106,0,0,0,12,1,0,0,111,0,0,0,11,1,0,0,192,0,0,0,96,0,0,0,19,0,0,0,19,0,0,0,96,0,0,0,0,1,0,0,97,0,0,0,1,1,0,0,98,0,0,0,2,1,0,0,99,0,0,0,3,1,0,0,100,0,0,0,4,1,0,0,101,0,0,0,5,1,0,0,102,0,0,0,6,1,0,0,103,0,0,0,7,1,0,0,104,0,0,0,8,1,0,0,105,0,0,0,9,1,0,0,48,0,0,0,48,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,50,0,0,0,51,0,0,0,51,0,0,0,52,0,0,0,52,0,0,0,53,0,0,0,53,0,0,0,54,0,0,0,54,0,0,0,55,0,0,0,55,0,0,0,56,0,0,0,56,0,0,0,57,0,0,0,57,0,0,0,112,0,0,0,26,1,0,0,113,0,0,0,27,1,0,0,114,0,0,0,28,1,0,0,115,0,0,0,29,1,0,0,116,0,0,0,30,1,0,0,117,0,0,0,31,1,0,0,118,0,0,0,32,1,0,0,119,0,0,0,33,1,0,0,120,0,0,0,34,1,0,0,121,0,0,0,35,1,0,0,122,0,0,0,36,1,0,0,123,0,0,0,37,1,0,0,65,0,0,0,97,0,0,0,66,0,0,0,98,0,0,0,67,0,0,0,99,0,0,0,68,0,0,0,100,0,0,0,69,0,0,0,101,0,0,0,70,0,0,0,102,0,0,0,71,0,0,0,103,0,0,0,72,0,0,0,104,0,0,0,73,0,0,0,105,0,0,0,74,0,0,0,106,0,0,0,75,0,0,0,107,0,0,0,76,0,0,0,108,0,0,0,77,0,0,0,109,0,0,0,78,0,0,0,110,0,0,0,79,0,0,0,111,0,0,0,80,0,0,0,112,0,0,0,81,0,0,0,113,0,0,0,82,0,0,0,114,0,0,0,83,0,0,0,115,0,0,0,84,0,0,0,116,0,0,0,85,0,0,0,117,0,0,0,86,0,0,0,118,0,0,0,87,0,0,0,119,0,0,0,88,0,0,0,120,0,0,0,89,0,0,0,121,0,0,0,90,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,176,167,0,0,224,163,0,0,168,187,0,0,72,188,0,0,192,151,0,0,40,145,0,0,48,139,0,0,120,134,0,0,224,130,0,0,104,128,0,0,152,126,0,0,184,112,0,0,128,186,0,0,128,185,0,0,16,185,0,0,192,184,0,0,0,0,0,0,0,0,36,64,0,0,0,0,0,0,89,64,0,0,0,0,0,136,195,64,0,0,0,0,132,215,151,65,0,128,224,55,121,195,65,67,23,110,5,181,181,184,147,70,245,249,63,233,3,79,56,77,50,29,48,249,72,119,130,90,60,191,115,127,221,79,21,117,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,137,80,78,71,13,10,26,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,5,0,184,9,5,0,120,18,5,0,56,27,5,0,248,35,5,0,184,44,5,0,120,53,5,0,56,62,5,0,14,0,0,0,68,1,0,0,2,0,0,0,2,0,0,0,30,0,0,0,0,0,0,0,8,210,0,0,34,0,0,0,240,105,0,0,20,1,0,0,40,104,0,0,19,1,0,0,216,108,0,0,17,1,0,0,48,107,0,0,18,1,0,0,96,199,0,0,13,0,0,0,184,197,0,0,15,1,0,0,136,205,0,0,9,0,0,0,80,196,0,0,21,1,0,0,96,195,0,0,127,0,0,0,152,194,0,0,23,1,0,0,8,194,0,0,22,1,0,0,136,193,0,0,47,1,0,0,8,192,0,0,48,1,0,0,104,191,0,0,50,1,0,0,8,190,0,0,52,1,0,0,200,200,0,0,32,0,0,0,248,188,0,0,27,0,0,0,112,188,0,0,14,1,0,0,248,187,0,0,13,1,0,0,120,187,0,0,14,1,0,0,56,187,0,0,13,1,0,0,248,186,0,0,26,1,0,0,160,185,0,0,27,1,0,0,32,185,0,0,28,1,0,0,216,184,0,0,29,1,0,0,144,184,0,0,30,1,0,0,80,184,0,0,31,1,0,0,232,183,0,0,32,1,0,0,144,183,0,0,33,1,0,0,80,183,0,0,34,1,0,0,8,183,0,0,35,1,0,0,192,182,0,0,36,1,0,0,104,181,0,0,37,1,0,0,208,180,0,0,48,0,0,0,80,180,0,0,49,0,0,0,224,179,0,0,50,0,0,0,112,179,0,0,51,0,0,0,192,178,0,0,52,0,0,0,112,178,0,0,53,0,0,0,208,177,0,0,54,0,0,0,120,177,0,0,55,0,0,0,32,177,0,0,56,0,0,0,216,175,0,0,57,0,0,0,80,175,0,0,24,1,0,0,64,174,0,0,25,1,0,0,184,173,0,0,0,1,0,0,88,173,0,0,1,1,0,0,176,172,0,0,2,1,0,0,168,172,0,0,3,1,0,0,104,172,0,0,4,1,0,0,32,172,0,0,5,1,0,0,192,171,0,0,6,1,0,0,120,171,0,0,7,1,0,0,0,170,0,0,8,1,0,0,160,169,0,0,9,1,0,0,176,46,0,0,46,0,0,0,72,168,0,0,45,1,0,0,232,167,0,0,44,1,0,0,40,89,0,0,8,0,0,0,112,167,0,0,12,1,0,0,48,167,0,0,11,1,0,0,232,166,0,0,60,1,0,0,176,166,0,0,46,1,0,0,48,203,0,0,96,0,0,0,248,164,0,0,96,0,0,0,128,164,0,0,19,0,0,0,40,164,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,240,40,1,0,40,122,0,0,0,0,0,0,1,0,0,0,0,0,0,0,208,40,1,0,16,90,0,0,1,0,0,0,1,0,0,0,0,0,0,0,232,111,0,0,120,69,0,0,2,0,0,0,1,0,0,0,0,0,0,0,120,110,0,0,240,50,0,0,3,0,0,0,1,0,0,0,0,0,0,0,216,108,0,0,56,207,0,0,4,0,0,0,1,0,0,0,0,0,0,0,48,107,0,0,128,187,0,0,5,0,0,0,1,0,0,0,0,0,0,0,240,105,0,0,24,178,0,0,6,0,0,0,1,0,0,0,0,0,0,0,40,104,0,0,96,167,0,0,7,0,0,0,1,0,0,0,0,0,0,0,248,40,1,0,8,159,0,0,8,0,0,0,1,0,0,0,0,0,0,0,216,40,1,0,80,151,0,0,9,0,0,0,1,0,0,0,0,0,0,0,232,40,1,0,112,138,0,0,10,0,0,0,1,0,0,0,0,0,0,0,136,43,0,0,184,130,0,0,11,0,0,0,1,0,0,0,0,0,0,0,24,95,0,0,240,124,0,0,12,0,0,0,1,0,0,0,0,0,0,0,240,93,0,0,240,121,0,0,13,0,0,0,1,0,0,0,0,0,0,0,0,93,0,0,232,118,0,0,14,0,0,0,1,0,0,0,0,0,0,0,176,91,0,0,152,113,0,0,15,0,0,0,1,0,0,0,0,0,0,0,192,90,0,0,128,110,0,0,16,0,0,0,1,0,0,0,0,0,0,0,160,89,0,0,80,107,0,0,17,0,0,0,1,0,0,0,0,0,0,0,248,88,0,0,120,104,0,0,18,0,0,0,1,0,0,0,0,0,0,0,24,87,0,0,72,101,0,0,19,0,0,0,1,0,0,0,0,0,0,0,136,84,0,0,64,96,0,0,20,0,0,0,1,0,0,0,0,0,0,0,248,82,0,0,56,94,0,0,21,0,0,0,1,0,0,0,0,0,0,0,8,81,0,0,216,91,0,0,22,0,0,0,1,0,0,0,0,0,0,0,80,80,0,0,184,89,0,0,23,0,0,0,1,0,0,0,0,0,0,0,248,79,0,0,152,87,0,0,24,0,0,0,1,0,0,0,1,0,0,0,152,79,0,0,16,83,0,0,25,0,0,0,1,0,0,0,2,0,0,0,0,79,0,0,136,80,0,0,26,0,0,0,1,0,0,0,1,0,0,0,72,78,0,0,184,79,0,0,27,0,0,0,1,0,0,0,1,0,0,0,208,77,0,0,112,78,0,0,28,0,0,0,1,0,0,0,2,0,0,0,224,76,0,0,96,77,0,0,29,0,0,0,1,0,0,0,2,0,0,0,40,75,0,0,48,175,0,0,30,0,0,0,1,0,0,0,2,0,0,0,80,74,0,0,240,72,0,0,31,0,0,0,1,0,0,0,2,0,0,0,144,73,0,0,112,71,0,0,32,0,0,0,1,0,0,0,1,0,0,0,184,72,0,0,208,211,0,0,33,0,0,0,1,0,0,0,2,0,0,0,16,72,0,0,0,68,0,0,34,0,0,0,1,0,0,0,2,0,0,0,72,71,0,0,40,65,0,0,35,0,0,0,1,0,0,0,2,0,0,0,120,70,0,0,224,62,0,0,36,0,0,0,1,0,0,0,2,0,0,0,104,69,0,0,176,61,0,0,37,0,0,0,1,0,0,0,2,0,0,0,144,68,0,0,104,60,0,0,38,0,0,0,1,0,0,0,2,0,0,0,200,67,0,0,8,59,0,0,39,0,0,0,1,0,0,0,2,0,0,0,224,65,0,0,216,55,0,0,40,0,0,0,1,0,0,0,2,0,0,0,232,64,0,0,152,53,0,0,41,0,0,0,1,0,0,0,2,0,0,0,176,63,0,0,64,52,0,0,42,0,0,0,1,0,0,0,2,0,0,0,184,62,0,0,200,50,0,0,43,0,0,0,1,0,0,0,2,0,0,0,48,62,0,0,104,49,0,0,44,0,0,0,1,0,0,0,2,0,0,0,144,61,0,0,88,46,0,0,45,0,0,0,1,0,0,0,2,0,0,0,8,61,0,0,248,44,0,0,46,0,0,0,1,0,0,0,2,0,0,0,56,60,0,0,208,43,0,0,47,0,0,0,1,0,0,0,2,0,0,0,104,59,0,0,216,42,0,0,48,0,0,0,1,0,0,0,2,0,0,0,192,58,0,0,136,214,0,0,49,0,0,0,1,0,0,0,2,0,0,0,160,56,0,0,88,211,0,0,50,0,0,0,1,0,0,0,2,0,0,0,176,55,0,0,248,209,0,0,51,0,0,0,1,0,0,0,2,0,0,0,40,54,0,0,112,208,0,0,52,0,0,0,1,0,0,0,2,0,0,0,112,53,0,0,128,206,0,0,53,0,0,0,1,0,0,0,2,0,0,0,200,52,0,0,8,204,0,0,54,0,0,0,1,0,0,0,1,0,0,0,32,52,0,0,48,200,0,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,155,8,0,200,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,238,0,0,0,4,0,0,0,72,166,0,0,0,0,0,0,90,0,0,0,32,0,0,0,244,1,0,0,44,1,0,0,6,0,0,0,6,0,0,0,60,0,0,0,26,1,0,0,0,0,0,0,20,1,0,0,20,0,0,0,2,0,0,0,4,0,0,0,18,0,0,0,2,0,0,0,114,0,0,0,12,0,0,0,2,0,0,0,38,0,0,0,16,0,0,0,48,0,0,0,216,0,0,0,98,1,0,0,178,0,0,0,100,0,0,0,24,0,0,0,2,0,0,0,152,48,0,0,2,0,0,0,56,48,0,0,0,0,0,0,36,48,0,0,8,0,0,0,35,48,0,0,8,0,0,0,34,48,0,0,8,0,0,0,33,48,0,0,8,0,0,0,51,48,0,0,4,0,0,0,56,48,0,0,0,0,0,0,28,0,0,0,48,0,0,0,12,0,0,0,150,0,0,0,58,0,0,0,204,0,0,0,4,0,0,0,24,0,0,0,6,0,0,0,12,0,0,0,26,0,0,0,36,0,0,0,112,0,0,0,226,0,0,0,104,0,0,0,2,0,0,0,0,0,0,0,136,165,0,0,0,0,0,0,0,0,0,0,160,199,0,0,192,52,0,0,248,184,0,0,0,0,0,0,0,0,0,0,100,16,183,29,200,32,110,59,172,48,217,38,144,65,220,118,244,81,107,107,88,97,178,77,60,113,5,80,32,131,184,237,68,147,15,240,232,163,214,214,140,179,97,203,176,194,100,155,212,210,211,134,120,226,10,160,28,242,189,189,0,0,0,0,255,0,0,0,85,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,144,115,0,0,2,0,0,0,160,97,0,0,3,0,0,0,16,85,0,0,5,0,0,0,128,75,0,0,4,0,0,0,248,0,5,0,184,9,5,0,120,18,5,0,56,27,5,0,248,35,5,0,184,44,5,0,120,53,5,0,56,62,5,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,92,0,0,0,168,1,0,0,206,1,0,0,2,0,0,0,8,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,16,66,8,32,0,0,74,41,0,0,0,0,0,0,168,175,212,87,0,0,128,248,226,232,35,0,0,0,136,170,168,138,0,0,192,164,100,82,116,0,0,132,16,0,0,0,0,0,136,8,33,132,32,8,0,130,32,132,16,34,2,0,0,144,234,42,1,0,0,0,16,242,9,1,0,0,0,0,0,0,32,2,0,0,0,240,1,0,0,0,0,0,0,0,32,0,0,16,34,68,136,16,1,0,192,197,88,99,116,0,0,128,24,66,8,113,0,0,192,69,200,68,248,0,0,192,69,200,96,116,0,0,0,49,149,62,66,0,0,224,135,240,96,116,0,0,128,137,240,98,116,0,0,224,67,132,8,17,0,0,192,197,232,98,116,0,0,192,197,232,33,50,0,0,0,0,2,0,1,0,0,0,0,2,0,17,0,0,0,64,54,24,4,0,0,0,128,15,62,0,0,0,0,4,131,77,0,0,0,192,69,136,8,32,0,0,192,135,214,122,240,0,0,128,16,165,92,140,0,0,224,197,248,98,124,0,0,192,197,16,66,116,0,0,224,164,24,99,58,0,0,224,135,240,66,248,0,0,224,135,240,66,8,0,0,192,197,144,99,244,0,0,32,198,248,99,140,0,0,192,17,66,8,113,0,0,128,67,8,33,124,0,0,32,166,50,74,138,0,0,32,132,16,66,248,0,0,32,198,189,107,141,0,0,96,206,90,107,206,0,0,192,197,24,99,116,0,0,224,197,248,66,8,0,0,192,197,24,99,246,0,0,224,197,248,98,140,0,0,192,197,224,96,116,0,0,224,19,66,8,33,0,0,32,198,24,99,116,0,0,32,198,168,20,33,0,0,32,214,90,149,82,0,0,32,70,69,84,140,0,0,32,198,232,8,33,0,0,224,67,68,68,248,0,0,78,8,33,132,16,14,0,33,8,65,8,66,16,0,14,33,132,16,66,14,0,128,168,8,0,0,0,0,0,0,0,0,0,31,0,128,32,0,0,0,0,0,0,0,7,125,244,0,0,33,132,23,99,124,0,0,0,0,31,66,240,0,0,16,66,31,99,244,0,0,0,0,23,127,240,0,0,92,136,39,132,16,0,0,0,0,23,99,244,208,1,33,132,23,99,140,0,0,128,0,67,8,33,0,0,0,1,134,16,66,232,0,66,8,169,140,146,0,0,134,16,66,8,33,0,0,0,128,85,107,173,0,0,0,128,23,99,140,0,0,0,0,23,99,116,0,0,0,128,23,99,124,33,0,0,0,31,99,244,16,2,0,128,54,67,8,0,0,0,0,31,28,124,0,0,64,8,39,132,224,0,0,0,128,24,99,244,0,0,0,128,24,149,34,0,0,0,128,88,171,82,0,0,0,128,168,136,138,0,0,0,128,24,99,244,208,1,0,128,143,136,248,0,0,136,16,34,8,33,8,0,132,16,66,8,33,4,0,130,16,130,8,33,2,0,0,0,96,50,0,0,0,0,0,0,0,0,0,0,63,132,16,66,8,225,3,0,0,0,0,0,0,0,0,0,0,0,64,4,0,152,16,71,8,33,68,0,0,0,0,0,80,10,0,0,0,0,0,168,0,0,132,124,66,8,33,4,0,132,124,242,9,33,4,0,68,1,0,0,0,0,0,0,72,69,84,2,0,0,138,0,31,62,124,0,0,0,0,68,4,65,0,0,192,166,148,83,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,32,0,0,0,0,0,8,17,0,0,0,0,0,74,81,0,0,0,0,0,148,42,0,0,0,0,0,0,0,192,24,0,0,0,0,0,0,62,0,0,0,0,0,0,62,0,0,0,0,0,64,21,0,0,0,0,128,175,149,2,0,0,138,0,31,28,124,0,0,0,0,130,32,34,0,0,0,0,155,114,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,10,196,24,29,33,0,0,0,0,0,0,0,0,0,128,0,66,8,33,0,0,0,32,174,20,71,0,0,152,16,79,68,248,0,0,0,4,47,165,15,0,0,32,70,71,62,33,0,0,132,16,2,8,33,4,0,152,16,23,163,35,100,0,64,1,0,0,0,0,0,192,135,86,90,240,0,0,4,49,197,0,0,0,0,0,0,34,147,36,0,0,0,0,224,33,132,0,0,0,0,0,0,0,0,0,192,135,84,74,240,0,0,224,3,0,0,0,0,0,128,56,2,0,0,0,0,0,16,242,9,249,0,0,6,17,225,0,0,0,0,6,25,100,0,0,0,0,136,0,0,0,0,0,0,0,0,41,165,116,34,0,192,223,107,41,165,148,2,0,0,64,0,0,0,0,0,0,0,0,96,136,0,196,16,226,0,0,0,0,68,41,2,0,0,0,0,0,128,36,137,76,0,0,48,166,68,168,22,1,0,48,166,68,137,148,1,0,81,46,85,168,22,1,0,128,0,130,96,116,0,0,130,0,226,92,140,0,0,68,0,226,92,140,0,0,68,1,226,92,140,0,0,84,1,226,92,140,0,0,64,1,226,92,140,0,0,196,17,226,92,140,0,0,128,59,231,83,202,0,0,192,197,16,66,116,68,0,130,128,31,94,248,0,0,68,128,31,94,248,0,0,68,129,31,94,248,0,0,64,129,31,94,248,0,0,130,0,71,8,113,0,0,68,0,71,8,113,0,0,68,1,71,8,113,0,0,64,1,71,8,113,0,0,192,73,241,132,116,0,0,84,129,89,107,206,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,84,1,23,99,116,0,0,64,1,23,99,116,0,0,0,68,69,84,4,0,0,0,48,169,173,108,0,0,130,128,24,99,116,0,0,68,128,24,99,116,0,0,68,129,24,99,116,0,0,64,129,24,99,116,0,0,136,196,24,29,33,0,0,64,8,39,165,19,2,0,192,73,233,164,116,1,0,130,0,7,125,244,0,0,68,0,7,125,244,0,0,68,1,7,125,244,0,0,84,1,7,125,244,0,0,64,1,7,125,244,0,0,196,17,7,125,244,0,0,0,0,139,124,178,0,0,0,0,31,66,240,68,0,130,0,23,127,240,0,0,68,0,23,127,240,0,0,68,1,23,127,240,0,0,64,1,23,127,240,0,0,130,0,67,8,33,0,0,68,0,67,8,33,0,0,68,1,67,8,33,0,0,64,1,67,8,33,0,0,192,34,232,99,116,0,0,84,129,23,99,140,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,170,0,23,99,116,0,0,64,1,23,99,116,0,0,0,16,240,1,1,0,0,0,48,169,173,108,0,0,130,128,24,99,244,0,0,68,128,24,99,244,0,0,68,129,24,99,244,0,0,64,129,24,99,244,0,0,68,128,24,99,244,208,1,32,132,23,99,124,33,0,64,129,24,99,244,208,1,168,159,0,0,72,159,0,0,32,159,0,0,216,158,0,0,144,158,0,0,88,158,0,0,88,157,0,0,240,156,0,0,30,0,0,0,74,0,0,0,94,0,0,0,230,0,0,0,206,0,0,0,96,0,0,0,6,0,0,0,240,198,0,0].concat([10,0,0,0,8,0,0,0,82,0,0,0,18,0,0,0,236,0,0,0,102,0,0,0,62,2,0,0,192,0,0,0,50,0,0,0,160,180,0,0,0,0,0,0,0,0,0,0,232,39,0,0,16,40,0,0,52,58,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,169,170,63,49,54,58,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,142,227,63,49,54,58,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,205,204,204,63,49,54,58,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,137,136,136,63,67,111,110,102,105,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,113,117,97,114,101,32,112,105,120,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,111,114,101,32,112,114,111,118,105,100,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,117,115,116,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,110,112,117,116,95,100,101,98,117,103,95,101,110,97,98,108,101,0,0,0,0,0,0,74,117,108,0,0,0,0,0,81,73,88,0,0,0,0,0,77,117,116,101,32,65,117,100,105,111,0,0,0,0,0,0,115,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,109,111,118,105,101,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,69,110,97,98,108,101,32,104,111,116,107,101,121,115,0,0,105,110,112,117,116,95,100,117,116,121,95,99,121,99,108,101,0,0,0,0,0,0,0,0,74,117,110,0,0,0,0,0,37,100,0,0,0,0,0,0,80,79,75,69,77,79,78,32,89,69,76,76,79,87,0,0,68,105,115,107,32,73,109,97,103,101,32,65,112,112,101,110,100,0,0,0,0,0,0,0,115,99,97,108,101,95,121,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,117,110,109,117,116,101,32,97,117,100,105,111,46,10,0,0,0,105,110,112,117,116,95,116,117,114,98,111,95,112,101,114,105,111,100,0,0,0,0,0,0,114,0,0,0,0,0,0,0,65,112,114,0,0,0,0,0,80,79,75,69,77,79,78,32,82,69,68,0,0,0,0,0,68,105,115,107,32,73,110,100,101,120,0,0,0,0,0,0,115,99,97,108,101,95,120,0,65,117,100,105,111,32,117,110,109,117,116,101,100,46,0,0,83,108,111,119,32,109,111,116,105,111,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,82,79,84,65,84,73,79,78,58,32,37,117,10,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,115,105,122,101,0,0,0,0,0,0,0,77,97,114,0,0,0,0,0,80,79,75,69,77,79,78,32,71,82,69,69,78,0,0,0,69,115,116,105,109,97,116,101,100,32,77,111,110,105,116,111,114,32,70,80,83,0,0,0,115,99,97,108,101,0,0,0,65,117,100,105,111,32,109,117,116,101,100,46,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,112,97,116,104,0,0,0,0,0,0,0,70,101,98,0,0,0,0,0,80,79,75,69,77,79,78,32,66,76,85,69,0,0,0,0,67,114,111,112,32,79,118,101,114,115,99,97,110,32,40,114,101,108,111,97,100,41,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,88,77,76,58,32,73,110,118,97,108,105,100,32,112,114,111,112,101,114,116,121,32,102,111,114,32,102,105,108,116,101,114,46,10,0,0,86,111,108,117,109,101,58,32,37,46,49,102,32,100,66,0,78,101,116,112,108,97,121,32,102,108,105,112,32,112,108,97,121,101,114,115,0,0,0,0,115,116,100,105,110,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,61,61,61,10,0,74,97,110,0,0,0,0,0,80,79,75,69,66,79,77,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,89,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,76,73,78,69,65,82,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,100,106,117,115,116,105,110,103,32,97,115,112,101,99,116,32,114,97,116,105,111,32,116,111,32,37,46,50,102,10,0,0,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,112,111,114,116,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,45,37,109,37,100,45,37,72,37,77,37,83,46,0,0,68,101,99,101,109,98,101,114,0,0,0,0,0,0,0,0,80,73,78,79,67,67,72,73,79,0,0,0,0,0,0,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,88,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,78,69,65,82,69,83,84,46,10,0,0,0,0,0,0,65,117,100,105,111,32,109,117,116,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,112,101,114,105,111,100,0,0,78,111,118,101,109,98,101,114,0,0,0,0,0,0,0,0,80,73,67,82,79,83,83,32,50,0,0,0,0,0,0,0,86,83,121,110,99,32,83,119,97,112,32,73,110,116,101,114,118,97,108,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,76,85,84,32,102,105,108,116,101,114,32,116,121,112,101,46,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,108,111,99,97,108,101,32,102,111,114,32,115,116,97,110,100,97,114,100,32,105,110,112,117,116,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,98,32,109,111,117,115,101,32,115,116,97,116,101,58,32,37,115,46,10,0,0,0,0,0,0,0,114,98,0,0,0,0,0,0,103,108,67,111,112,121,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,105,110,32,118,101,99,52,32,99,111,108,111,114,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,72,87,32,114,101,110,100,101,114,32,70,66,79,32,35,37,117,44,32,101,114,114,111,114,58,32,48,120,37,117,46,10,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,108,111,97,100,0,0,0,0,0,77,66,67,51,32,82,79,77,43,84,73,77,69,82,43,66,65,84,84,69,82,89,32,108,111,97,100,101,100,46,0,0,115,116,121,108,101,0,0,0,79,99,116,111,98,101,114,0,80,69,78,71,85,73,78,75,85,78,87,65,82,83,86,83,0,0,0,0,0,0,0,0,66,108,97,99,107,32,70,114,97,109,101,32,73,110,115,101,114,116,105,111,110,0,0,0,111,118,101,114,108,97,121,37,117,95,110,97,109,101,0,0,110,101,97,114,101,115,116,0,60,33,45,45,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,117,109,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,0,0,0,0,68,83,80,32,99,111,110,102,105,103,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,115,97,118,101,0,0,0,0,0,83,101,112,116,101,109,98,101,114,0,0,0,0,0,0,0,80,69,78,71,85,73,78,32,87,65,82,83,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,32,70,114,97,109,101,115,0,0,0,0,108,105,110,101,97,114,0,0,82,101,116,114,111,65,114,99,104,58,32,85,110,112,97,117,115,101,100,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,105,110,100,101,120,0,0,0,0,65,117,103,117,115,116,0,0,80,65,67,45,73,78,45,84,73,77,69,0,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,102,105,108,101,110,97,109,101,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,97,117,115,101,100,46,10,0,0,0,0,0,84,97,107,101,32,115,99,114,101,101,110,115,104,111,116,0,98,108,111,99,107,95,115,114,97,109,95,111,118,101,114,119,114,105,116,101,0,0,0,0,83,116,97,114,116,32,98,117,116,116,111,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,77,111,118,105,101,32,102,111,114,109,97,116,32,115,101,101,109,115,32,116,111,32,104,97,118,101,32,97,32,100,105,102,102,101,114,101,110,116,32,115,101,114,105,97,108,105,122,101,114,32,118,101,114,115,105,111,110,46,32,87,105,108,108,32,109,111,115,116,32,108,105,107,101,108,121,32,102,97,105,108,46,10,0,0,74,117,108,121,0,0,0,0,79,84,72,69,76,76,79,0,86,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,73,68,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,82,101,97,99,104,101,100,32,101,110,100,32,111,102,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,0,0,0,99,104,101,97,116,95,115,101,116,116,105,110,103,115,95,112,97,116,104,0,0,0,0,0,74,117,110,101,0,0,0,0,78,69,87,32,67,72,69,83,83,77,65,83,84,69,82,0,82,111,116,97,116,105,111,110,0,0,0,0,0,0,0,0,102,105,108,116,101,114,0,0,109,101,110,117,95,116,111,103,103,108,101,0,0,0,0,0,82,101,119,105,110,100,105,110,103,46,0,0,0,0,0,0,67,104,101,97,116,32,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,77,69,83,83,65,71,69,58,32,37,115,10,0,0,0,0,0,99,104,101,97,116,95,100,97,116,97,98,97,115,101,95,112,97,116,104,0,0,0,0,0,77,97,121,0,0,0,0,0,78,69,84,84,79,85,32,75,79,70,32,57,53,0,0,0,84,111,103,103,108,101,32,70,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,103,114,97,98,95,109,111,117,115,101,95,116,111,103,103,108,101,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,46,0,0,0,0,97,117,116,111,115,97,118,101,95,105,110,116,101,114,118,97,108,0,0,0,0,0,0,0,65,112,114,105,108,0,0,0,77,89,83,84,73,67,32,81,85,69,83,84,0,0,0,0,67,117,115,116,111,109,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,84,111,111,32,109,97,110,121,32,116,101,120,116,117,114,101,32,105,109,97,103,101,115,46,32,73,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,100,105,115,107,95,110,101,120,116,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,32,114,101,119,105,110,100,46,0,0,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,45,0,0,0,112,97,117,115,101,95,110,111,110,97,99,116,105,118,101,0,77,97,114,99,104,0,0,0,77,79,71,85,82,65,78,89,65,0,0,0,0,0,0,0,65,115,112,101,99,116,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,65,77,32,97,100,100,114,101,115,115,32,115,112,101,99,105,102,105,99,101,100,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,100,105,115,107,95,101,106,101,99,116,95,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,10,0,0,0,0,0,0,0,91,71,97,109,98,97,116,116,101,93,58,32,88,82,71,66,56,56,56,56,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,37,115,32,124,124,32,70,80,83,58,32,37,54,46,49,102,32,124,124,32,70,114,97,109,101,115,58,32,37,100,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,117,100,105,111,32,114,97,116,101,32,99,111,110,116,114,111,108,32,119,97,115,32,100,101,115,105,114,101,100,44,32,98,117,116,32,100,114,105,118,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,101,101,100,101,100,32,102,101,97,116,117,114,101,115,46,10,0,0,0,0,0,0,0,102,97,115,116,102,111,114,119,97,114,100,95,114,97,116,105,111,0,0,0,0,0,0,0,102,105,108,101,95,112,97,116,104,46,99,0,0,0,0,0,70,101,98,114,117,97,114,121,0,0,0,0,0,0,0,0,77,73,76,76,73,47,67,69,78,84,73,47,80,69,68,69,0,0,0,0,0,0,0,0,73,110,116,101,103,101,114,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,105,110,112,117,116,32,115,108,111,116,32,102,111,114,32,105,109,112,111,114,116,46,10,0,0,0,0,111,118,101,114,108,97,121,95,110,101,120,116,0,0,0,0,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,43,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,115,108,111,119,109,111,116,105,111,110,95,114,97,116,105,111,0,0,0,0,0,0,0,0,74,97,110,117,97,114,121,0,77,69,84,82,79,73,68,50,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,79,112,116,105,111,110,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,118,111,108,117,109,101,95,100,111,119,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,77,77,48,49,32,82,79,77,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,103,108,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,79,69,83,95,112,97,99,107,101,100,95,100,101,112,116,104,95,115,116,101,110,99,105,108,0,0,0,0,0,0,0,0,114,101,119,105,110,100,95,103,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,71,76,83,76,0,0,0,0,77,69,71,65,77,65,78,51,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,83,99,97,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,110,102,105,103,32,107,101,121,58,32,37,115,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,111,114,32,73,68,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,118,111,108,117,109,101,95,117,112,0,0,0,0,0,0,0,61,34,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,80,114,101,118,105,111,117,115,32,115,104,97,100,101,114,0,114,101,119,105,110,100,95,98,117,102,102,101,114,95,115,105,122,101,0,0,0,0,0,0,68,0,0,0,101,0,0,0,99,0,0,0,0,0,0,0,77,69,71,65,77,65,78,0,83,104,97,100,101,114,32,35,37,117,32,70,105,108,116,101,114,0,0,0,0,0,0,0,101,113,117,97,108,0,0,0,101,110,97,98,108,101,95,104,111,116,107,101,121,0,0,0,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,97,118,101,32,115,116,97,116,101,115,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,114,101,119,105,110,100,95,101,110,97,98,108,101,0,0,0,78,0,0,0,111,0,0,0,118,0,0,0,0,0,0,0,77,69,71,65,32,77,65,78,32,50,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,0,0,0,0,0,0,109,97,115,107,0,0,0,0,115,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,0,0,78,101,120,116,32,115,104,97,100,101,114,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,115,99,97,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,115,116,97,116,101,32,102,114,111,109,32,109,111,118,105,101,46,10,0,0,0,79,0,0,0,99,0,0,0,116,0,0,0,0,0,0,0,77,65,82,73,79,76,65,78,68,50,0,0,0,0,0,0,83,104,97,100,101,114,32,80,97,115,115,101,115,0,0,0,105,110,112,117,116,95,115,108,111,116,0,0,0,0,0,0,110,101,116,112,108,97,121,95,102,108,105,112,95,112,108,97,121,101,114,115,0,0,0,0,37,115,46,98,115,118,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,111,112,97,99,105,116,121,0,0,0,83,0,0,0,101,0,0,0,112,0,0,0,0,0,0,0,98,97,115,105,99,95,115,116,114,105,110,103,0,0,0,0,77,65,82,73,79,39,83,32,80,73,67,82,79,83,83,0,76,111,97,100,32,83,104,97,100,101,114,32,80,114,101,115,101,116,0,0,0,0,0,0,119,114,97,109,0,0,0,0,97,117,100,105,111,95,109,117,116,101,0,0,0,0,0,0,37,115,37,117,46,98,115,118,0,0,0,0,0,0,0,0,82,101,115,101,116,32,103,97,109,101,0,0,0,0,0,0,46,114,101,116,114,111,97,114,99,104,45,99,111,114,101,45,111,112,116,105,111,110,115,46,99,102,103,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,0,0,0,65,0,0,0,117,0,0,0,103,0,0,0,0,0,0,0,77,65,82,73,79,32,38,32,89,79,83,72,73,0,0,0,68,101,102,97,117,108,116,32,70,105,108,116,101,114,0,0,115,101,109,97,110,116,105,99,0,0,0,0,0,0,0,0,100,115,112,95,99,111,110,102,105,103,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,0,111,118,101,114,108,97,121,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,74,0,0,0,117,0,0,0,108,0,0,0,0,0,0,0,77,65,78,83,69,76,76,0,65,112,112,108,121,32,83,104,97,100,101,114,32,67,104,97,110,103,101,115,0,0,0,0,105,100,0,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,70,114,97,109,101,97,100,118,97,110,99,101,0,0,0,0,114,103,117,105,95,98,114,111,119,115,101,114,95,100,105,114,101,99,116,111,114,121,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,101,110,100,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,74,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,77,65,71,78,69,84,73,67,32,83,79,67,67,69,82,0,37,115,32,40,37,100,44,32,37,100,32,58,32,37,52,117,120,37,52,117,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,111,111,32,109,97,110,121,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,115,32,46,46,46,10,0,0,0,0,0,99,104,101,97,116,95,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,108,121,32,115,104,97,100,101,114,46,10,0,0,0,0,91,71,97,109,98,97,116,116,101,93,58,32,67,97,110,110,111,116,32,100,117,112,101,32,102,114,97,109,101,115,33,10,0,0,0,0,0,0,0,0,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,110,32,101,120,105,115,116,105,110,103,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,77,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,76,79,76,79,50,0,0,0,83,101,116,32,66,111,116,116,111,109,45,82,105,103,104,116,32,67,111,114,110,101,114,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,80,121,116,104,111,110,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,109,105,110,117,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,0,80,97,117,115,101,32,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,100,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,0,0,0,0,65,0,0,0,112,0,0,0,114,0,0,0,0,0,0,0,75,73,82,66,89,50,0,0,83,101,116,32,85,112,112,101,114,45,76,101,102,116,32,67,111,114,110,101,114,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,108,97,110,103,117,97,103,101,32,105,115,32,110,111,116,32,80,121,116,104,111,110,46,10,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,112,108,117,115,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,58,32,34,37,115,34,46,0,0,0,0,0,0,0,80,108,97,105,110,32,82,79,77,32,119,105,116,104,32,97,100,100,105,116,105,111,110,97,108,32,82,65,77,32,97,110,100,32,66,97,116,116,101,114,121,32,108,111,97,100,101,100,46,0,0,0,0,0,0,0,103,108,84,101,120,73,109,97,103,101,51,68,79,69,83,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,116,97,116,101,32,116,114,97,99,107,101,114,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,77,97,120,32,116,101,120,116,117,114,101,32,115,105,122,101,58,32,37,100,32,112,120,44,32,114,101,110,100,101,114,98,117,102,102,101,114,32,115,105,122,101,58,32,37,117,32,112,120,46,10,0,0,0,0,99,111,114,101,95,111,112,116,105,111,110,115,95,112,97,116,104,0,0,0,0,0,0,0,78,47,65,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,66,105,116,32,100,101,112,116,104,32,111,102,32,84,71,65,32,105,109,97,103,101,32,105,115,32,119,114,111,110,103,46,32,79,110,108,121,32,51,50,45,98,105,116,32,97,110,100,32,50,52,45,98,105,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,0,0,0,0,75,73,82,66,89,39,83,32,80,73,78,66,65,76,76,0,37,115,32,40,37,52,117,120,37,52,117,44,32,37,117,32,120,32,37,117,32,115,99,97,108,101,41,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,111,118,101,114,108,97,121,0,0,0,0,0,0,0,99,108,97,115,115,0,0,0,115,104,97,100,101,114,95,112,114,101,118,0,0,0,0,0,32,10,9,12,11,13,0,0,82,101,116,114,111,65,114,99,104,58,32,9,9,37,115,10,0,0,0,0,0,0,0,0,46,99,103,112,0,0,0,0,77,111,118,105,101,32,114,101,99,111,114,100,32,116,111,103,103,108,101,0,0,0,0,0,108,105,98,114,101,116,114,111,95,112,97,116,104,0,0,0,70,0,0,0,101,0,0,0,98,0,0,0,0,0,0,0,75,73,82,66,89,32,68,82,69,65,77,32,76,65,78,68,0,0,0,0,0,0,0,0,83,101,116,32,115,99,97,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,97,108,114,101,97,100,121,32,105,109,112,111,114,116,101,100,46,10,0,0,115,104,97,100,101,114,95,110,101,120,116,0,0,0,0,0,46,99,103,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,117,115,101,115,32,116,104,114,101,97,100,101,100,32,97,117,100,105,111,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,0,105,110,112,117,116,95,106,111,121,112,97,100,95,100,114,105,118,101,114,0,0,0,0,0,74,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,75,73,82,66,89,32,66,76,79,67,75,66,65,76,76,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,67,71,80,32,102,97,105,108,101,100,46,10,0,0,63,63,63,0,0,0,0,0,114,101,115,101,116,0,0,0,46,115,104,97,100,101,114,0,83,101,108,101,99,116,32,98,117,116,116,111,110,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,82,67,51,50,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,82,79,77,32,102,105,108,101,32,97,110,100,32,115,97,118,101,100,32,82,79,77,32,99,104,101,99,107,115,117,109,32,105,110,32,114,101,112,108,97,121,32,102,105,108,101,32,104,101,97,100,101,114,59,32,114,101,112,108,97,121,32,104,105,103,104,108,121,32,108,105,107,101,108,121,32,116,111,32,100,101,115,121,110,99,32,111,110,32,112,108,97,121,98,97,99,107,46,10,0,68,0,0,0,101,0,0,0,99,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,75,73,82,65,75,73,82,65,32,75,73,68,83,0,0,0,78,47,65,32,40,115,116,111,99,107,41,0,0,0,0,0,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,0,102,114,97,109,101,95,97,100,118,97,110,99,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,111,116,32,105,110,118,97,108,105,100,32,100,105,115,107,32,105,110,100,101,120,32,102,114,111,109,32,108,105,98,114,101,116,114,111,46,10,0,0,0,0,0,97,117,100,105,111,95,100,115,112,95,112,108,117,103,105,110,0,0,0,0,0,0,0,0,78,0,0,0,111,0,0,0,118,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,75,73,78,71,79,70,84,72,69,90,79,79,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,0,114,101,112,101,97,116,0,0,112,97,117,115,101,95,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,66,83,82,77,58,32,37,115,10,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,45,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,86,65,82,73,65,66,76,69,83,46,10,0,0,0,0,0,0,97,117,100,105,111,95,100,114,105,118,101,114,0,0,0,0,79,0,0,0,99,0,0,0,116,0,0,0,111,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,75,73,76,76,69,82,73,78,83,84,73,78,67,84,57,53,0,0,0,0,0,0,0,0,37,115,32,40,37,115,41,0,99,108,97,109,112,95,116,111,95,101,100,103,101,0,0,0,109,111,118,105,101,95,114,101,99,111,114,100,95,116,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,83,82,77,58,32,37,115,10,0,0,0,0,118,105,100,101,111,95,103,108,95,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,83,0,0,0,101,0,0,0,112,0,0,0,116,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,75,73,68,32,73,67,65,82,85,83,0,0,0,0,0,0,60,85,115,101,32,116,104,105,115,32,100,105,114,101,99,116,111,114,121,62,0,0,0,0,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,0,114,101,119,105,110,100,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,83,117,102,97,109,105,32,116,117,114,98,111,32,65,47,66,32,82,65,77,46,10,0,0,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,43,0,0,0,0,0,0,0,0,118,105,100,101,111,95,100,114,105,118,101,114,0,0,0,0,37,48,50,120,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,101,110,100,105,110,103,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,0,65,0,0,0,117,0,0,0,103,0,0,0,117,0,0,0,115,0,0,0,116,0,0,0,0,0,0,0,0,0,0,0,75,69,78,32,71,82,73,70,70,69,89,32,74,82,0,0,37,115,124,122,105,112,0,0,97,98,115,111,108,117,116,101,0,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,100,101,99,114,101,97,115,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,83,82,77,58,32,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,114,101,115,97,109,112,108,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,97,117,100,105,111,95,118,111,108,117,109,101,0,0,0,0,74,0,0,0,117,0,0,0,108,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,75,65,69,82,85,78,79,84,65,77,69,78,73,0,0,0,99,102,103,0,0,0,0,0,118,105,101,119,112,111,114,116,0,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,105,110,99,114,101,97,115,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,32,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,32,98,117,102,102,101,114,46,10,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,95,100,101,108,116,97,0,0,0,0,0,0,0,0,74,0,0,0,117,0,0,0,110,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,74,65,77,69,83,32,32,66,79,78,68,32,32,48,48,55,0,0,0,0,0,0,0,0,99,103,124,103,108,115,108,0,115,111,117,114,99,101,0,0,101,120,105,116,95,101,109,117,108,97,116,111,114,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,66,83,88,32,40,80,41,82,65,77,46,10,0,0,80,108,97,105,110,32,82,79,77,32,119,105,116,104,32,97,100,100,105,116,105,111,110,97,108,32,82,65,77,32,108,111,97,100,101,100,46,0,0,0,80,76,84,69,0,0,0,0,103,108,71,101,116,66,117,102,102,101,114,80,111,105,110,116,101,114,118,79,69,83,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,76,85,84,115,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,32,72,87,32,114,101,110,100,101,114,32,40,37,117,32,120,32,37,117,41,46,10,0,0,0,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,84,71,65,32,112,105,120,101,108,115,46,10,0,0,0,0,115,104,97,100,101,114,0,0,72,79,83,72,73,78,79,75,65,45,66,73,0,0,0,0,99,103,112,124,103,108,115,108,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,111,118,101,114,108,97,121,32,99,97,108,108,101,100,58,32,34,37,115,34,46,10,0,0,0,0,115,99,97,108,101,95,37,115,37,117,0,0,0,0,0,0,116,111,103,103,108,101,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,67,104,101,97,116,58,32,35,37,117,32,91,37,115,93,58,32,37,115,0,0,0,0,0,60,47,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,80,111,115,115,105,98,108,101,32,118,97,108,117,101,115,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,71,97,109,101,98,111,121,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,116,111,103,103,108,101,0,0,0,0,0,0,0,97,117,100,105,111,95,115,121,110,99,0,0,0,0,0,0,65,0,0,0,112,0,0,0,114,0,0,0,105,0,0,0,108,0,0,0,0,0,0,0,71,97,109,101,32,97,110,100,32,87,97,116,99,104,32,50,0,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,95,37,115,37,117,0,115,97,118,101,95,115,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,84,67,58,32,37,115,10,0,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,0,0,0,0,0,97,117,100,105,111,95,108,97,116,101,110,99,121,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,99,0,0,0,104,0,0,0,0,0,0,0,71,79,76,70,0,0,0,0,37,99,32,37,45,42,46,42,115,32,37,45,42,115,0,0,108,111,97,100,95,115,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,37,115,10,0,0,0,0,0,83,97,118,101,32,115,116,97,116,101,0,0,0,0,0,0,97,117,100,105,111,95,100,101,118,105,99,101,0,0,0,0,70,0,0,0,101,0,0,0,98,0,0,0,114,0,0,0,117,0,0,0,97,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,118,105,101,32,102,105,108,101,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,66,83,86,49,32,102,105,108,101,46,10,0,0,0,0,0,0,71,66,87,65,82,83,84,0,104,111,108,100,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,114,101,103,117,108,97,114,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,97,117,100,105,111,95,98,108,111,99,107,95,102,114,97,109,101,115,0,0,0,0,0,0,74,0,0,0,97,0,0,0,110,0,0,0,117,0,0,0,97,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,71,66,87,65,82,83,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,37,117,0,0,0,0,0,116,111,103,103,108,101,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,102,97,105,108,101,100,0,0,76,111,97,100,32,115,116,97,116,101,0,0,0,0,0,0,97,117,100,105,111,95,111,117,116,95,114,97,116,101,0,0,71,65,77,69,66,79,89,32,71,65,76,76,69,82,89,50,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,114,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0])
.concat([115,117,99,99,101,101,100,101,100,0,0,0,0,0,0,0,97,117,100,105,111,95,101,110,97,98,108,101,0,0,0,0,80,77,0,0,0,0,0,0,71,65,77,69,66,79,89,32,71,65,76,76,69,82,89,0,85,110,107,110,111,119,110,0,112,121,116,104,111,110,0,0,114,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,117,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,32,37,115,46,10,0,70,97,115,116,32,102,111,114,119,97,114,100,32,104,111,108,100,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,37,117,95,106,111,121,112,97,100,95,105,110,100,101,120,0,0,0,0,0,44,0,0,0,0,0,0,0,65,77,0,0,0,0,0,0,71,65,77,69,38,87,65,84,67,72,0,0,0,0,0,0,83,117,112,101,114,83,99,111,112,101,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,95,112,114,101,118,105,111,117,115,0,0,0,0,0,114,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,46,97,117,116,111,0,0,0,71,66,32,67,111,108,111,114,105,122,97,116,105,111,110,59,32,100,105,115,97,98,108,101,100,124,101,110,97,98,108,101,100,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,110,101,116,112,108,97,121,95,99,108,105,101,110,116,95,115,119,97,112,95,105,110,112,117,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,100,105,114,101,99,116,111,114,121,58,32,34,37,115,34,10,0,0,0,0,71,65,76,65,71,65,38,71,65,76,65,88,73,65,78,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,0,74,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,99,97,112,116,117,114,101,95,112,114,101,118,105,111,117,115,0,0,0,0,0,0,0,0,114,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,45,118,0,0,0,0,0,0,70,97,115,116,32,102,111,114,119,97,114,100,32,116,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,105,110,112,117,116,95,97,120,105,115,95,116,104,114,101,115,104,111,108,100,0,0,0,0,80,0,0,0,77,0,0,0,0,0,0,0,0,0,0,0,71,38,87,32,71,65,76,76,69,82,89,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,74,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,95,99,111,117,110,116,0,0,0,0,0,0,0,0,108,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,45,99,0,0,0,0,0,0,77,66,67,50,32,82,79,77,43,66,65,84,84,69,82,89,32,108,111,97,100,101,100,46,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,105,108,101,32,67,82,67,32,100,105,102,102,101,114,115,32,102,114,111,109,32,90,73,80,32,67,82,67,46,32,70,105,108,101,58,32,48,120,37,120,44,32,90,73,80,58,32,48,120,37,120,46,10,0,0,0,0,0,0,73,69,78,68,0,0,0,0,103,108,85,110,109,97,112,66,117,102,102,101,114,79,69,83,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,83,76,32,115,116,111,99,107,32,112,114,111,103,114,97,109,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,37,117,32,116,101,120,116,117,114,101,115,46,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,101,100,32,84,71,65,58,32,40,37,117,120,37,117,32,64,32,37,117,32,98,112,112,41,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,0,0,0,65,0,0,0,77,0,0,0,0,0,0,0,0,0,0,0,70,79,79,84,66,65,76,76,32,73,78,84,39,76,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,0,0,0,77,111,117,115,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,111,108,118,101,32,110,101,120,116,32,116,97,114,103,101,116,115,46,10,0,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,0,0,0,0,0,0,108,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,110,121,32,99,104,101,97,116,115,32,105,110,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,93,93,62,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,67,117,114,114,101,110,116,32,118,97,108,117,101,58,32,37,115,10,0,0,45,83,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,100,105,114,0,0,0,0,0,0,0,0,70,49,82,65,67,69,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,66,79,32,116,101,120,116,117,114,101,115,32,101,120,99,101,101,100,101,100,32,109,97,120,105,109,117,109,32,115,105,122,101,32,111,102,32,71,80,85,32,40,37,117,120,37,117,41,46,32,82,101,115,105,122,105,110,103,32,116,111,32,102,105,116,46,10,0,0,0,0,0,0,0,0,77,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,99,97,112,116,117,114,101,0,108,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,45,115,0,0,0,0,0,0,118,105,100,101,111,95,103,112,117,95,115,99,114,101,101,110,115,104,111,116,0,0,0,0,98,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,68,89,78,65,66,76,65,83,84,69,82,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,66,79,32,112,97,115,115,32,35,37,100,32,105,115,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,46,10,0,0,0,0,0,74,111,121,112,97,100,32,119,47,32,65,110,97,108,111,103,0,0,0,0,0,0,0,0,37,115,95,101,113,117,97,108,0,0,0,0,0,0,0,0,108,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,45,45,109,101,110,117,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,85,78,83,85,80,80,79,82,84,69,68,32,40,35,37,117,41,46,10,0,0,118,105,100,101,111,95,103,112,117,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,89,32,98,117,116,116,111,110,32,40,108,101,102,116,41,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,109,111,118,105,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,68,82,46,77,65,82,73,79,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,32,101,120,116,101,110,115,105,111,110,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,0,0,74,111,121,112,97,100,0,0,37,115,95,109,97,115,107,0,116,117,114,98,111,0,0,0,82,101,116,114,111,65,114,99,104,58,32,78,111,32,82,79,77,44,32,115,116,97,114,116,105,110,103,32,100,117,109,109,121,32,99,111,114,101,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,46,10,0,0,0,0,0,118,105,100,101,111,95,112,111,115,116,95,102,105,108,116,101,114,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,68,79,78,75,69,89,75,79,78,71,76,65,78,68,57,53,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,104,97,100,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,0,0,0,0,0,0,0,0,78,111,110,101,0,0,0,0,37,115,95,105,110,112,117,116,95,115,108,111,116,0,0,0,114,51,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,82,79,77,58,32,37,115,46,10,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,95,69,83,67,65,80,69,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,37,115,10,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,99,111,108,111,114,0,0,0,0,0,46,98,114,97,109,0,0,0,68,79,78,75,69,89,75,79,78,71,76,65,78,68,32,51,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,118,101,114,115,105,111,110,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,117,112,32,102,114,97,109,101,32,98,117,102,102,101,114,32,111,98,106,101,99,116,115,46,32,77,117,108,116,105,45,112,97,115,115,32,115,104,97,100,105,110,103,32,119,105,108,108,32,110,111,116,32,119,111,114,107,46,10,0,0,37,115,95,119,114,97,109,0,108,51,0,0,0,0,0,0,114,101,116,114,111,97,114,99,104,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,83,69,84,95,76,73,66,82,69,84,82,79,95,80,65,84,72,46,10,0,0,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,104,101,105,103,104,116,0,0,46,97,114,97,109,0,0,0,68,79,78,75,69,89,75,79,78,71,76,65,78,68,32,50,0,0,0,0,0,0,0,0,35,118,101,114,115,105,111,110,32,37,117,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,0,0,0,78,47,65,32,40,112,111,114,116,32,35,37,117,41,0,0,37,115,95,115,101,109,97,110,116,105,99,0,0,0,0,0,114,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,70,82,65,77,69,95,84,73,77,69,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,119,105,100,116,104,0,0,0,115,101,116,116,105,110,103,115,46,99,0,0,0,0,0,0,46,112,114,97,109,0,0,0,68,79,78,75,69,89,75,79,78,71,76,65,78,68,0,0,35,118,101,114,115,105,111,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,35,37,100,0,0,0,0,0,49,0,0,0,0,0,0,0,108,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,109,111,118,105,110,103,32,116,101,109,112,111,97,114,121,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,103,98,95,99,111,108,111,114,105,122,97,116,105,111,110,0,110,111,0,0,0,0,0,0,100,114,105,118,101,114,46,99,0,0,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,121,0,0,0,0,0,0,0,46,114,116,99,0,0,0,0,46,46,0,0,0,0,0,0,68,79,78,75,69,89,32,75,79,78,71,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,98,105,110,100,32,65,80,73,32,37,115,32,116,111,32,99,111,110,116,101,120,116,32,37,115,46,10,0,0,0,0,0,0,37,46,50,102,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,65,77,32,119,105,108,108,32,110,111,116,32,98,101,32,115,97,118,101,100,46,10,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,0,121,101,115,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,120,0,0,0,0,0,0,0,68,77,71,32,70,79,79,84,66,65,76,76,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,105,110,107,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,0,0,0,0,0,79,112,101,110,71,76,32,69,83,0,0,0,0,0,0,0,46,46,47,99,111,109,109,111,110,47,114,101,115,97,109,112,108,101,47,115,114,99,47,99,104,97,105,110,114,101,115,97,109,112,108,101,114,46,99,112,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,107,105,112,112,105,110,103,32,83,82,65,77,32,108,111,97,100,46,10,0,77,66,67,50,32,82,79,77,32,108,111,97,100,101,100,46,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,97,110,121,32,82,79,77,83,32,116,104,97,116,32,109,97,116,99,104,101,100,32,118,97,108,105,100,32,101,120,116,101,110,115,105,111,110,115,32,102,111,114,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,73,68,65,84,0,0,0,0,103,108,77,97,112,66,117,102,102,101,114,79,69,83,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,99,111,110,116,101,120,116,32,105,115,32,117,115,101,100,44,32,98,117,116,32,115,104,97,100,101,114,32,105,115,32,110,111,116,32,109,111,100,101,114,110,46,32,67,97,110,110,111,116,32,117,115,101,32,105,116,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,68,105,109,101,110,115,105,111,110,115,58,32,37,117,120,37,117,10,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,83,85,80,80,79,82,84,95,78,79,95,71,65,77,69,58,32,37,115,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,109,117,108,116,105,112,97,115,115,32,115,104,97,100,101,114,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,68,73,83,75,32,65,80,80,69,78,68,32,37,115,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,71,65,32,105,109,97,103,101,32,105,115,32,110,111,116,32,117,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,46,46,46,32,67,97,110,110,111,116,32,114,101,99,111,118,101,114,32,115,97,118,101,32,102,105,108,101,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,88,77,76,32,115,104,97,100,101,114,58,32,37,115,10,0,0,0,0,0,0,68,69,70,69,78,68,69,82,47,74,79,85,83,84,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,105,110,103,32,71,76,83,76,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,46,10,51,50,45,98,105,116,32,112,97,116,104,32,119,105,108,108,32,114,101,113,117,105,114,101,32,99,111,110,118,101,114,115,105,111,110,46,10,0,0,0,60,82,79,77,32,100,105,114,62,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,103,114,97,98,32,99,104,101,97,116,115,46,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,0,0,60,33,91,67,68,65,84,65,91,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,75,101,121,58,32,37,115,10,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,10,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,117,110,107,110,111,119,110,32,99,111,110,116,101,120,116,46,10,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,120,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,99,99,101,101,100,101,100,32,105,110,32,115,97,118,105,110,103,32,82,65,77,32,100,97,116,97,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,89,0,0,0,0,0,0,0,66,84,50,82,65,71,78,65,82,79,75,87,79,82,76,68,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,32,102,111,117,110,100,32,102,111,114,32,71,76,69,83,46,10,0,0,0,0,60,100,101,102,97,117,108,116,62,0,0,0,0,0,0,0,105,109,112,111,114,116,115,0,61,61,61,32,66,117,105,108,100,32,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,32,99,111,110,116,101,120,116,44,32,98,117,116,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,79,112,101,110,71,76,69,83,50,46,32,67,97,110,110,111,116,32,117,115,101,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,99,97,108,101,0,0,0,0,0,0,0,0,102,105,110,100,95,97,117,100,105,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,37,89,45,37,109,45,37,100,45,37,72,45,37,77,45,37,83,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,108,111,99,97,108,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,0,0,0,66,79,89,32,65,78,68,32,66,76,79,66,32,71,66,50,0,0,0,0,0,0,0,0,35,100,101,102,105,110,101,32,70,82,65,71,77,69,78,84,10,0,0,0,0,0,0,0,66,71,82,65,56,56,56,56,0,0,0,0,0,0,0,0,37,46,51,102,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,95,99,108,97,115,115,0,0,0,0,0,114,105,103,104,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,116,97,108,32,101,114,114,111,114,32,114,101,99,101,105,118,101,100,32,105,110,58,32,34,37,115,34,10,0,0,0,0,0,103,97,109,98,97,116,116,101,0,0,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,69,83,50,32,99,111,110,116,101,120,116,46,10,0,0,0,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,101,110,97,98,108,101,0,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,97,117,100,105,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,37,115,47,82,101,116,114,111,65,114,99,104,45,114,101,99,111,118,101,114,121,45,0,0,66,79,89,32,65,78,68,32,66,76,79,66,32,71,66,49,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,112,108,97,121,98,97,99,107,46,10,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,104,97,100,101,114,44,32,102,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,0,0,0,108,101,102,116,0,0,0,0,90,73,80,124,122,105,112,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,110,111,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,105,122,101,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,97,117,100,105,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,37,0,0,0,73,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,112,0,0,0,0,0,0,0,66,79,77,66,69,82,77,65,78,32,71,66,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,0,0,37,46,51,102,32,72,122,32,40,37,46,49,102,37,37,32,100,101,118,44,32,37,117,32,115,97,109,112,108,101,115,41,0,0,0,0,0,0,0,0,37,115,95,119,114,97,112,95,109,111,100,101,0,0,0,0,100,111,119,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,58,32,37,115,32,37,115,0,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,72,87,95,82,69,78,68,69,82,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,86,65,82,73,65,66,76,69,32,37,115,58,10,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,112,97,116,104,0,102,105,110,100,95,118,105,100,101,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,79,77,32,105,115,32,117,115,101,100,44,32,98,117,116,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,104,105,115,46,10,0,0,37,73,58,37,77,58,37,83,32,37,112,0,0,0,0,0,66,65,83,69,66,65,76,76,0,0,0,0,0,0,0,0,35,100,101,102,105,110,101,32,86,69,82,84,69,88,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,118,97,108,105,100,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,32,67,111,110,116,105,110,117,105,110,103,32,119,105,116,104,111,117,116,32,115,104,97,100,101,114,115,46,10,0,0,0,0,0,0,0,37,46,49,102,120,0,0,0,37,115,95,108,105,110,101,97,114,0,0,0,0,0,0,0,117,112,0,0,0,0,0,0,83,101,116,116,105,110,103,32,114,101,102,114,101,115,104,32,114,97,116,101,32,116,111,58,32,37,46,51,102,32,72,122,46,0,0,0,0,0,0,0,118,48,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,68,73,83,75,95,67,79,78,84,82,79,76,95,73,78,84,69,82,70,65,67,69,46,10,0,118,105,100,101,111,95,97,108,108,111,119,95,114,111,116,97,116,101,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,118,105,100,101,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,32,105,110,32,34,37,115,34,10,0,0,0,0,0,0,0,0,37,0,0,0,97,0,0,0,32,0,0,0,37,0,0,0,98,0,0,0,32,0,0,0,37,0,0,0,100,0,0,0,32,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,89,0,0,0,0,0,0,0,0,0,0,0,66,65,76,76,79,79,78,32,75,73,68,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,118,101,114,116,101,120,32,115,104,97,100,101,114,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,10,0,0,0,0,116,101,120,116,117,114,101,115,0,0,0,0,0,0,0,0,115,116,97,114,116,0,0,0,84,117,114,98,111,32,101,110,97,98,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,75,69,89,66,79,65,82,68,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,101,110,97,98,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,118,105,100,101,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,116,99,104,32,37,115,58,32,69,114,114,111,114,32,35,37,117,10,0,0,0,0,0,37,97,32,37,98,32,37,100,32,37,72,58,37,77,58,37,83,32,37,89,0,0,0,0,66,65,46,84,79,83,72,73,78,68,69,78,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,71,76,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,78,111,116,32,108,111,97,100,105,110,103,32,97,110,121,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,115,101,108,101,99,116,0,0,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,0,0,0,0,0,0,0,103,98,124,103,98,99,124,100,109,103,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,82,101,116,114,111,80,97,100,44,32,80,108,97,121,101,114,32,37,117,44,32,66,117,116,116,111,110,32,34,37,115,34,32,61,62,32,34,37,115,34,10,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,0,0,0,0,102,105,110,100,95,105,110,112,117,116,95,100,114,105,118,101,114,40,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,112,97,116,99,104,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,40,37,115,41,46,10,0,0,0,0,0,0,82,0,0,0,0,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,0,0,0,0,0,0,0,0,65,84,79,77,73,67,32,80,85,78,75,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,71,76,83,76,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,110,32,115,112,101,99,105,102,105,101,100,32,71,76,32,101,114,114,111,114,46,10,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,37,117,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,100,105,115,107,32,37,117,32,111,102,32,37,117,46,0,0,0,0,82,51,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,73,78,80,85,84,95,68,69,83,67,82,73,80,84,79,82,83,58,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,68,105,100,110,39,116,32,114,101,97,100,32,119,104,111,108,101,32,102,105,108,101,46,10,0,0,0,0,118,105,100,101,111,95,114,101,102,114,101,115,104,95,114,97,116,101,0,0,0,0,0,0,9,37,115,10,0,0,0,0,115,116,100,58,58,98,97,100,95,97,108,108,111,99,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,112,97,116,99,104,101,100,32,82,79,77,32,46,46,46,10,0,0,0,0,0,65,83,84,69,82,79,73,68,83,47,77,73,83,67,77,68,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,79,117,116,32,111,102,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,119,114,97,112,95,109,111,100,101,37,117,0,0,0,0,0,82,101,109,111,118,101,100,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,77,66,67,49,32,82,79,77,43,82,65,77,43,66,65,84,84,69,82,89,32,108,111,97,100,101,100,46,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,79,70,70,83,69,84,58,32,37,117,44,32,67,83,73,90,69,58,32,37,117,44,32,83,73,90,69,58,32,37,117,46,10,0,0,0,0,73,72,68,82,0,0,0,0,103,108,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,83,116,111,99,107,32,71,76,83,76,32,115,104,97,100,101,114,115,32,119,105,108,108,32,98,101,32,117,115,101,100,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,65,116,116,101,109,112,116,101,100,32,116,111,32,114,101,45,105,110,105,116,105,97,108,105,122,101,32,100,114,105,118,101,114,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,67,97,110,110,111,116,32,102,105,110,100,32,115,104,97,100,101,114,32,99,111,114,101,32,102,111,114,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,0,0,0,67,79,82,69,32,83,69,76,69,67,84,73,79,78,32,37,115,0,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,95,97,117,116,111,0,99,103,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,65,118,97,105,108,97,98,108,101,32,105,110,112,117,116,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,37,115,32,102,105,108,101,32,105,110,32,34,37,115,34,44,32,97,116,116,101,109,112,116,105,110,103,32,116,111,32,112,97,116,99,104,32,46,46,46,10,0,0,0,0,0,0,37,0,0,0,109,0,0,0,47,0,0,0,37,0,0,0,100,0,0,0,47,0,0,0,37,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,65,76,76,69,89,32,87,65,89,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,111,112,101,114,97,116,105,111,110,46,10,0,0,0,0,79,70,70,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,111,118,101,114,108,97,121,115,32,118,97,114,105,97,98,108,101,32,110,111,116,32,100,101,102,105,110,101,100,32,105,110,32,99,111,110,102,105,103,46,10,0,0,102,105,108,116,101,114,95,108,105,110,101,97,114,37,117,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,115,97,116,117,114,97,116,101,95,112,99,116,0,0,0,115,104,97,50,53,54,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,105,109,97,103,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,60,47,37,115,62,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,68,101,115,99,114,105,112,116,105,111,110,58,32,37,115,10,0,0,0,0,83,101,116,116,105,110,103,32,100,105,115,107,32,37,117,32,111,102,32,37,117,32,105,110,32,116,114,97,121,46,0,0,76,51,32,98,117,116,116,111,110,32,40,108,101,102,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,0,97,115,112,101,99,116,95,114,97,116,105,111,95,105,110,100,101,120,0,0,0,0,0,0,83,112,114,105,116,101,37,50,48,50,51,61,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,105,110,112,117,116,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,32,118,97,108,105,100,32,82,79,77,32,112,97,116,99,104,46,10,0,0,0,0,0,104,101,97,100,101,114,66,121,116,101,48,120,49,52,55,32,60,32,115,105,122,101,111,102,40,116,121,112,101,76,117,116,41,0,0,0,0,0,0,0,114,117,98,121,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,79,78,0,0,0,0,0,0])
.concat([115,104,97,100,101,114,37,117,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,65,110,97,108,111,103,32,104,105,116,98,111,120,32,116,121,112,101,32,109,117,115,116,32,98,101,32,34,114,97,100,105,97,108,34,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,37,115,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,32,46,46,46,10,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,0,83,112,114,105,116,101,37,50,48,50,50,61,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,32,97,117,100,105,111,32,105,110,112,117,116,32,114,97,116,101,32,116,111,58,32,37,46,50,102,32,72,122,46,10,0,0,0,73,80,83,0,0,0,0,0,115,114,99,47,109,101,109,47,99,97,114,116,114,105,100,103,101,46,99,112,112,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,101,110,117,109,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,88,77,76,32,115,104,97,100,101,114,32,46,46,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,72,105,116,98,111,120,32,116,121,112,101,32,40,37,115,41,32,105,115,32,105,110,118,97,108,105,100,46,32,85,115,101,32,34,114,97,100,105,97,108,34,32,111,114,32,34,114,101,99,116,34,46,10,0,0,0,99,108,111,115,101,0,0,0,82,50,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,118,105,100,101,111,95,99,114,111,112,95,111,118,101,114,115,99,97,110,0,0,0,0,0,66,32,98,117,116,116,111,110,32,40,100,111,119,110,41,0,83,112,114,105,116,101,37,50,48,50,49,61,0,0,0,0,37,117,58,37,117,32,40,49,58,49,32,80,65,82,41,0,82,101,116,114,111,65,114,99,104,58,32,71,97,109,101,32,70,80,83,32,62,32,77,111,110,105,116,111,114,32,70,80,83,46,32,67,97,110,110,111,116,32,114,101,108,121,32,111,110,32,86,83,121,110,99,46,10,0,0,0,0,0,0,0,66,80,83,0,0,0,0,0,102,0,0,0,97,0,0,0,108,0,0,0,115,0,0,0,101,0,0,0,0,0,0,0,114,111,109,98,97,110,107,115,58,32,37,117,10,0,0,0,84,101,120,116,117,114,101,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,76,111,97,100,101,100,32,37,117,32,112,114,111,103,114,97,109,40,115,41,46,10,0,0,0,78,101,97,114,101,115,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,110,111,114,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,105,110,32,88,77,76,32,102,105,108,101,46,10,0,0,0,0,0,0,114,101,99,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,97,100,106,117,115,116,101,100,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,116,111,32,37,117,32,77,105,66,10,0,0,0,0,0,101,106,101,99,116,0,0,0,118,105,100,101,111,95,115,99,97,108,101,95,105,110,116,101,103,101,114,0,0,0,0,0,83,112,114,105,116,101,37,50,48,50,48,61,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,84,105,109,105,110,103,115,32,100,101,118,105,97,116,101,32,116,111,111,32,109,117,99,104,46,32,87,105,108,108,32,110,111,116,32,97,100,106,117,115,116,46,32,40,68,105,115,112,108,97,121,32,61,32,37,46,50,102,32,72,122,44,32,71,97,109,101,32,61,32,37,46,50,102,32,72,122,41,10,0,0,0,0,0,0,85,80,83,0,0,0,0,0,102,97,108,115,101,0,0,0,114,97,109,98,97,110,107,115,58,32,37,117,10,0,0,0,103,108,71,101,116,80,111,105,110,116,101,114,118,0,0,0,37,115,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,105,110,105,116,32,102,97,105,108,101,100,46,10,0,76,105,110,101,97,114,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,114,97,100,105,97,108,0,0,70,97,105,108,101,100,32,116,111,32,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,76,50,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,67,65,78,95,68,85,80,69,58,32,116,114,117,101,10,0,0,118,105,100,101,111,95,102,111,114,99,101,95,97,115,112,101,99,116,0,0,0,0,0,0,83,112,114,105,116,101,37,50,48,49,51,61,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,117,100,105,111,32,98,97,99,107,101,110,100,32,102,97,105,108,101,100,32,116,111,32,119,114,105,116,101,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,115,111,117,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,109,111,117,110,116,32,111,102,32,116,105,109,101,32,115,112,101,110,116,32,99,108,111,115,101,32,116,111,32,117,110,100,101,114,114,117,110,58,32,37,46,50,102,32,37,37,46,32,67,108,111,115,101,32,116,111,32,98,108,111,99,107,105,110,103,58,32,37,46,50,102,32,37,37,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,115,99,111,112,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,101,118,101,114,97,108,32,112,97,116,99,104,101,115,32,97,114,101,32,101,120,112,108,105,99,105,116,108,121,32,100,101,102,105,110,101,100,44,32,105,103,110,111,114,105,110,103,32,97,108,108,32,46,46,46,10,0,0,0,76,0,0,0,0,0,0,0,116,0,0,0,114,0,0,0,117,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,77,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,99,103,98,58,32,37,100,10,0,0,0,0,0,0,0,0,103,108,71,101,116,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,80,114,101,118,37,117,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,10,0,0,37,115,0,0,0,0,0,0,115,99,114,105,112,116,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,110,101,120,116,95,116,97,114,103,101,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,115,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,67,108,111,115,101,100,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,109,111,117,115,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,115,99,111,110,110,101,99,116,105,110,103,32,100,101,118,105,99,101,32,102,114,111,109,32,112,111,114,116,32,37,117,46,10,0,0,88,32,40,117,112,41,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,99,111,110,102,105,103,32,102,105,108,101,46,32,85,115,105,110,103,32,115,121,115,116,101,109,32,100,101,102,97,117,108,116,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,99,111,110,102,105,103,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,118,105,100,101,111,95,115,109,111,111,116,104,0,0,0,0,83,112,114,105,116,101,37,50,48,49,50,61,0,0,0,0,46,99,102,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,97,117,100,105,111,32,98,117,102,102,101,114,32,115,97,116,117,114,97,116,105,111,110,58,32,37,46,50,102,32,37,37,44,32,115,116,97,110,100,97,114,100,32,100,101,118,105,97,116,105,111,110,32,40,112,101,114,99,101,110,116,97,103,101,32,112,111,105,110,116,115,41,58,32,37,46,50,102,32,37,37,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,82,67,51,50,58,32,48,120,37,120,44,32,83,72,65,50,53,54,58,32,37,115,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,87,114,111,110,103,32,100,97,116,97,45,102,111,114,109,97,116,44,32,99,111,114,114,117,112,116,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,82,79,77,46,0,0,103,108,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,0,0,0,80,114,101,118,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,114,115,105,111,110,58,32,37,115,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,111,114,116,32,118,97,108,117,101,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,46,120,109,108,0,0,0,0,46,105,112,115,0,0,0,0,69,106,101,99,116,101,100,0,46,98,112,115,0,0,0,0,82,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,46,117,112,115,0,0,0,0,65,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,102,97,109,105,32,84,117,114,98,111,32,83,82,65,77,32,112,97,116,104,115,32,119,105,108,108,32,98,101,32,105,110,102,101,114,114,101,100,32,102,114,111,109,32,116,104,101,105,114,32,114,101,115,112,101,99,116,105,118,101,32,112,97,116,104,115,32,116,111,32,97,118,111,105,100,32,99,111,110,102,108,105,99,116,115,46,10,0,0,0,118,105,100,101,111,95,116,104,114,101,97,100,101,100,0,0,83,112,114,105,116,101,37,50,48,49,49,61,0,0,0,0,46,112,115,114,109,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,115,104,97,100,101,114,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,103,97,109,101,46,10,0,0,0,0,0,0,9,45,68,47,45,45,100,101,116,97,99,104,58,32,68,101,116,97,99,104,32,82,101,116,114,111,65,114,99,104,32,102,114,111,109,32,116,104,101,32,114,117,110,110,105,110,103,32,99,111,110,115,111,108,101,46,32,78,111,116,32,114,101,108,101,118,97,110,116,32,102,111,114,32,97,108,108,32,112,108,97,116,102,111,114,109,115,46,10,0,0,0,0,0,0,0,72,117,67,49,32,82,79,77,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,103,108,71,101,116,79,98,106,101,99,116,76,97,98,101,108,0,0,0,0,0,0,0,0,80,97,115,115,37,117,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,110,100,111,114,58,32,37,115,44,32,82,101,110,100,101,114,101,114,58,32,37,115,46,10,0,0,0,0,0,102,114,111,110,116,101,110,100,47,109,101,110,117,47,46,46,47,46,46,47,103,102,120,47,46,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,105,109,112,111,114,116,0,0,82,101,116,114,111,65,114,99,104,58,32,91,67,111,110,102,105,103,93,58,32,81,117,101,114,121,105,110,103,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,97,110,97,108,111,103,95,114,105,103,104,116,0,0,0,0,9,45,88,47,45,45,120,109,108,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,116,111,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,46,0,0,0,0,9,45,45,110,111,45,112,97,116,99,104,58,32,68,105,115,97,98,108,101,115,32,97,108,108,32,102,111,114,109,115,32,111,102,32,114,111,109,32,112,97,116,99,104,105,110,103,46,0,0,0,0,0,0,0,0,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,0,0,118,48,46,53,46,48,0,0,9,45,45,105,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,73,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,9,45,45,98,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,66,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,9,45,85,47,45,45,117,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,85,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,0,115,116,100,58,58,98,97,100,95,99,97,115,116,0,0,0,9,45,118,47,45,45,118,101,114,98,111,115,101,58,32,86,101,114,98,111,115,101,32,108,111,103,103,105,110,103,46,0,9,9,68,111,32,110,111,116,101,32,116,104,97,116,32,110,111,108,111,97,100,45,115,97,118,101,32,105,109,112,108,105,101,115,32,116,104,97,116,32,115,97,118,101,32,102,105,108,101,115,32,119,105,108,108,32,98,101,32,100,101,108,101,116,101,100,32,97,110,100,32,111,118,101,114,119,114,105,116,116,101,110,46,0,0,0,0,0,118,105,100,101,111,95,115,119,97,112,95,105,110,116,101,114,118,97,108,0,0,0,0,0,32,10,9,12,13,11,0,0,83,112,114,105,116,101,37,50,48,49,48,61,0,0,0,0,9,9,123,110,111,44,125,108,111,97,100,45,123,110,111,44,125,115,97,118,101,32,100,101,115,99,114,105,98,101,115,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,108,111,97,100,101,100,44,32,97,110,100,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,115,97,118,101,100,46,0,0,115,104,97,100,101,114,124,99,103,124,99,103,112,124,103,108,115,108,124,103,108,115,108,112,0,0,0,0,0,0,0,0,9,45,77,47,45,45,115,114,97,109,45,109,111,100,101,58,32,84,97,107,101,115,32,97,110,32,97,114,103,117,109,101,110,116,32,116,101,108,108,105,110,103,32,104,111,119,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,104,97,110,100,108,101,100,32,105,110,32,116,104,101,32,115,101,115,115,105,111,110,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,0,0,9,45,82,47,45,45,98,115,118,114,101,99,111,114,100,58,32,83,116,97,114,116,32,114,101,99,111,114,100,105,110,103,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,32,102,114,111,109,32,116,104,101,32,98,101,103,105,110,110,105,110,103,46,0,0,0,72,117,67,51,32,82,79,77,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,103,108,79,98,106,101,99,116,76,97,98,101,108,0,0,0,80,97,115,115,80,114,101,118,37,117,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,101,116,101,99,116,105,110,103,32,115,99,114,101,101,110,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,46,10,0,0,48,46,57,46,57,46,51,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,101,120,116,117,114,101,32,105,109,97,103,101,32,102,97,105,108,101,100,32,116,111,32,108,111,97,100,46,10,0,0,0,0,0,97,110,97,108,111,103,95,108,101,102,116,0,0,0,0,0,9,45,80,47,45,45,98,115,118,112,108,97,121,58,32,80,108,97,121,98,97,99,107,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,46,0,0,0,0,0,0,0,9,45,52,47,45,45,109,117,108,116,105,116,97,112,58,32,67,111,110,110,101,99,116,32,97,32,83,78,69,83,32,109,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,65,112,112,101,110,100,101,100,32,100,105,115,107,58,32,37,115,0,0,0,0,0,0,0,9,45,74,47,45,45,106,117,115,116,105,102,105,101,114,115,58,32,68,97,105,115,121,32,99,104,97,105,110,32,116,119,111,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,115,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,76,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,0,9,45,106,47,45,45,106,117,115,116,105,102,105,101,114,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,9,45,112,47,45,45,115,99,111,112,101,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,83,117,112,101,114,83,99,111,112,101,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,9,45,109,47,45,45,109,111,117,115,101,58,32,67,111,110,110,101,99,116,32,97,32,109,111,117,115,101,32,105,110,116,111,32,112,111,114,116,32,111,102,32,116,104,101,32,100,101,118,105,99,101,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,0,0,0,9,45,65,47,45,45,100,117,97,108,97,110,97,108,111,103,58,32,67,111,110,110,101,99,116,32,97,32,68,117,97,108,65,110,97,108,111,103,32,99,111,110,116,114,111,108,108,101,114,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,118,105,100,101,111,95,98,108,97,99,107,95,102,114,97,109,101,95,105,110,115,101,114,116,105,111,110,0,0,0,0,0,34,0,0,0,0,0,0,0,66,97,99,107,103,114,111,117,110,100,51,61,0,0,0,0,9,45,78,47,45,45,110,111,100,101,118,105,99,101,58,32,68,105,115,99,111,110,110,101,99,116,115,32,99,111,110,116,114,111,108,108,101,114,32,100,101,118,105,99,101,32,99,111,110,110,101,99,116,101,100,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,48,82,71,66,49,53,53,53,32,112,105,120,101,108,32,102,111,114,109,97,116,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,97,110,100,32,119,105,108,108,32,98,101,32,115,108,111,119,101,114,46,32,70,111,114,32,49,53,47,49,54,45,98,105,116,44,32,82,71,66,53,54,53,32,102,111,114,109,97,116,32,105,115,32,112,114,101,102,101,114,114,101,100,46,10,0,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,9,45,45,115,117,102,97,109,105,66,58,32,80,97,116,104,32,116,111,32,66,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,108,111,97,100,105,110,103,32,115,107,105,112,112,101,100,46,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,119,105,108,108,32,108,111,97,100,32,105,116,32,111,110,32,105,116,115,32,111,119,110,46,10,0,0,0,0,0,0,0,0,9,45,45,115,117,102,97,109,105,65,58,32,80,97,116,104,32,116,111,32,65,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,32,76,111,97,100,32,83,117,102,97,109,105,32,98,97,115,101,32,99,97,114,116,32,97,115,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,66,97,110,100,97,105,32,84,65,77,65,53,32,82,79,77,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,103,108,80,111,112,68,101,98,117,103,71,114,111,117,112,0,79,114,105,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,10,0,0,0,0,0,0,0,0,37,115,32,45,32,37,115,32,37,115,0,0,0,0,0,0,46,46,46,0,0,0,0,0,116,101,120,116,117,114,101,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,79,118,101,114,108,97,121,32,100,101,115,99,32,105,115,32,105,110,118,97,108,105,100,46,32,82,101,113,117,105,114,101,115,32,97,116,32,108,101,97,115,116,32,54,32,116,111,107,101,110,115,46,10,0,0,0,9,45,66,47,45,45,98,115,120,115,108,111,116,58,32,80,97,116,104,32,116,111,32,66,83,88,32,115,108,111,116,116,101,100,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,9,45,98,47,45,45,98,115,120,58,32,80,97,116,104,32,116,111,32,66,83,88,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,82,101,115,101,116,46,0,0,9,45,103,47,45,45,103,97,109,101,98,111,121,58,32,80,97,116,104,32,116,111,32,71,97,109,101,98,111,121,32,82,79,77,46,32,76,111,97,100,32,83,117,112,101,114,71,97,109,101,66,111,121,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,77,66,67,49,32,82,79,77,43,82,65,77,32,108,111,97,100,101,100,46,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,90,73,80,32,101,120,116,114,97,99,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,108,105,110,101,58,32,37,100,46,10,0,0,0,0,0,0,0,0,9,9,77,117,108,116,105,112,108,101,32,99,111,110,102,105,103,115,32,97,114,101,32,100,101,108,105,109,105,116,101,100,32,98,121,32,39,44,39,46,0,0,0,0,0,0,0,0,103,108,71,101,116,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,71,76,83,76,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,46,46,46,10,0,0,0,9,45,45,97,112,112,101,110,100,99,111,110,102,105,103,58,32,69,120,116,114,97,32,99,111,110,102,105,103,32,102,105,108,101,115,32,97,114,101,32,108,111,97,100,101,100,32,105,110,44,32,97,110,100,32,116,97,107,101,32,112,114,105,111,114,105,116,121,32,111,118,101,114,32,99,111,110,102,105,103,32,115,101,108,101,99,116,101,100,32,105,110,32,45,99,32,40,111,114,32,100,101,102,97,117,108,116,41,46,0,0,0,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,0,103,108,0,0,0,0,0,0,37,115,10,37,115,10,37,115,10,0,0,0,0,0,0,0,9,45,99,47,45,45,99,111,110,102,105,103,58,32,80,97,116,104,32,102,111,114,32,99,111,110,102,105,103,32,102,105,108,101,46,10,9,9,66,121,32,100,101,102,97,117,108,116,32,108,111,111,107,115,32,102,111,114,32,99,111,110,102,105,103,32,105,110,32,36,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,36,72,79,77,69,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,97,110,100,32,36,72,79,77,69,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,46,0,0,0,0,0,9,45,83,47,45,45,115,97,118,101,115,116,97,116,101,58,32,80,97,116,104,32,116,111,32,117,115,101,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,115,46,32,73,102,32,110,111,116,32,115,101,108,101,99,116,101,100,44,32,42,46,115,116,97,116,101,32,119,105,108,108,32,98,101,32,97,115,115,117,109,101,100,46,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,46,10,0,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,95,102,114,97,109,101,115,0,0,82,101,116,114,111,65,114,99,104,58,32,83,73,78,67,32,112,97,114,97,109,115,32,40,37,117,32,112,104,97,115,101,32,98,105,116,115,44,32,37,117,32,116,97,112,115,41,46,10,0,0,0,0,0,0,0,33,33,33,32,35,105,110,99,108,117,100,101,32,100,101,112,116,104,32,101,120,99,101,101,100,101,100,32,102,111,114,32,99,111,110,102,105,103,46,32,77,105,103,104,116,32,98,101,32,97,32,99,121,99,108,101,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,80,78,71,93,58,32,85,115,105,110,103,32,82,80,78,71,32,108,111,97,100,101,114,46,10,0,0,66,97,99,107,103,114,111,117,110,100,50,61,0,0,0,0,9,45,102,47,45,45,102,117,108,108,115,99,114,101,101,110,58,32,83,116,97,114,116,32,82,101,116,114,111,65,114,99,104,32,105,110,32,102,117,108,108,115,99,114,101,101,110,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,99,111,110,102,105,103,32,115,101,116,116,105,110,103,115,46,0,0,105,111,115,95,98,97,115,101,58,58,99,108,101,97,114,0,9,45,115,47,45,45,115,97,118,101,58,32,80,97,116,104,32,102,111,114,32,115,97,118,101,32,102,105,108,101,32,40,42,46,115,114,109,41,46,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,101,101,100,32,116,111,32,100,101,102,105,110,101,32,97,116,32,108,101,97,115,116,32,49,32,115,104,97,100,101,114,46,10,0,9,45,45,102,101,97,116,117,114,101,115,58,32,80,114,105,110,116,115,32,97,118,97,105,108,97,98,108,101,32,102,101,97,116,117,114,101,115,32,99,111,109,112,105,108,101,100,32,105,110,116,111,32,82,101,116,114,111,65,114,99,104,46,0,80,111,99,107,101,116,32,67,97,109,101,114,97,32,82,79,77,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,0,0,0,0,0,0,0,103,108,80,117,115,104,68,101,98,117,103,71,114,111,117,112,0,0,0,0,0,0,0,0,70,114,97,109,101,68,105,114,101,99,116,105,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,99,114,101,97,116,105,110,103,32,70,66,79,32,116,101,120,116,117,114,101,32,35,37,100,58,32,37,117,120,37,117,10,0,0,0,71,65,77,69,32,40,37,115,41,32,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,71,85,73,93,58,32,79,112,101,110,105,110,103,32,104,105,115,116,111,114,121,58,32,37,115,46,10,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,88,77,76,32,115,104,97,100,101,114,32,97,116,116,114,105,98,117,116,101,115,32,100,111,32,110,111,116,32,99,111,109,112,108,121,32,119,105,116,104,32,115,112,101,99,105,102,105,99,97,116,105,111,110,115,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,111,118,101,114,108,97,121,32,100,101,115,99,46,10,0,0,99,97,114,116,114,105,100,103,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,9,9,73,102,32,110,111,32,97,114,103,117,109,101,110,116,115,32,97,114,101,32,112,97,115,115,101,100,32,116,111,32,82,101,116,114,111,65,114,99,104,44,32,105,116,32,105,115,32,101,113,117,105,118,97,108,101,110,116,32,116,111,32,117,115,105,110,103,32,45,45,109,101,110,117,32,97,115,32,111,110,108,121,32,97,114,103,117,109,101,110,116,46,0,0,0,47,62,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,114,101,32,111,112,116,105,111,110,58,10,0,0,0,0,0,0,0,0,9,45,45,109,101,110,117,58,32,68,111,32,110,111,116,32,114,101,113,117,105,114,101,32,82,79,77,32,111,114,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,116,111,32,98,101,32,108,111,97,100,101,100,44,32,115,116,97,114,116,115,32,100,105,114,101,99,116,108,121,32,105,110,32,109,101,110,117,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,115,101,116,116,105,110,103,32,103,97,109,101,46,10,0,0,0,0,0,9,45,104,47,45,45,104,101,108,112,58,32,83,104,111,119,32,116,104,105,115,32,104,101,108,112,32,109,101,115,115,97,103,101,46,0,0,0,0,0,88,32,98,117,116,116,111,110,32,40,116,111,112,41,0,0,85,115,97,103,101,58,32,114,101,116,114,111,97,114,99,104,32,91,114,111,109,32,102,105,108,101,93,32,91,111,112,116,105,111,110,115,46,46,46,93,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,114,111,110,116,101,110,100,32,102,111,114,32,108,105,98,114,101,116,114,111,32,45,45,32,118,48,46,57,46,57,46,51,32,45,45,0,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,0,77,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,83,99,114,105,112,116,32,115,117,112,112,111,114,116,32,105,110,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,68,105,115,107,32,83,119,97,112,32,78,101,120,116,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,0,105,110,99,108,117,100,101,32,0,0,0,0,0,0,0,0,66,97,99,107,103,114,111,117,110,100,49,61,0,0,0,0,80,121,116,104,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,109,111,110,105,116,111,114,32,72,122,58,32,37,46,54,102,32,72,122,46,32,40,37,46,51,102,32,37,37,32,102,114,97,109,101,32,116,105,109,101,32,100,101,118,105,97,116,105,111,110,44,32,98,97,115,101,100,32,111,110,32,37,117,32,108,97,115,116,32,115,97,109,112,108,101,115,41,46,10,0,0,0,0,0,0,68,105,115,107,32,69,106,101,99,116,32,84,111,103,103,108,101,0,0,0,0,0,0,0,37,112,0,0,0,0,0,0,80,101,101,114,45,116,111,45,112,101,101,114,32,110,101,116,112,108,97,121,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,46,10,0,0,78,101,120,116,32,79,118,101,114,108,97,121,0,0,0,0,78,101,116,112,108,97,121,0,77,66,67,53,43,82,85,77,76,69,43,82,65,77,43,66,65,84,84,69,82,89,32,82,79,77,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,0,0,0,0,0,0,103,108,71,101,116,68,101,98,117,103,77,101,115,115,97,103,101,76,111,103,0,0,0,0,70,114,97,109,101,67,111,117,110,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,105,110,105,116,32,70,66,79,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,86,111,108,117,109,101,32,68,111,119,110,0,0,0,0,0,78,111,32,67,111,114,101,0,46,114,101,116,114,111,97,114,99,104,45,103,97,109,101,45,104,105,115,116,111,114,121,46,116,120,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,100,101,114,110,32,71,76,83,76,32,119,97,115,32,99,104,111,115,101,110,32,97,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,119,97,115,32,110,111,116,32,112,114,111,118,105,100,101,100,46,32,84,104,105,115,32,105,115,32,97,110,32,101,114,114,111,114,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,107,101,121,58,32,37,115,46,10,0,0,0,84,84,70,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,119,105,116,104,32,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,85,112,0,0,0,0,0,0,0,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,69,110,97,98,108,101,32,72,111,116,107,101,121,0,0,0,79,110,45,116,104,101,45,102,108,121,32,114,101,99,111,114,100,105,110,103,32,111,102,32,103,97,109,101,112,108,97,121,32,119,105,116,104,32,108,105,98,97,118,99,111,100,101,99,0,0,0,0,0,0,0,0,83,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,70,70,109,112,101,103,0,0,78,101,116,112,108,97,121,32,70,108,105,112,32,80,108,97,121,101,114,115,0,0,0,0,68,121,110,97,109,105,99,32,114,117,110,45,116,105,109,101,32,108,111,97,100,105,110,103,32,111,102,32,108,105,98,114,101,116,114,111,32,108,105,98,114,97,114,121,0,0,0,0,68,121,110,97,109,105,99,0,68,83,80,32,67,111,110,102,105,103,0,0,0,0,0,0,79,112,101,110,71,76,32,114,101,110,100,101,114,45,116,111,45,116,101,120,116,117,114,101,32,40,109,117,108,116,105,45,112,97,115,115,32,115,104,97,100,101,114,115,41,0,0,0,83,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,118,105,100,101,111,95,118,115,121,110,99,0,0,0,0,0,66,97,99,107,103,114,111,117,110,100,48,61,0,0,0,0,70,66,79,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,111,101,115,32,110,111,116,32,104,97,118,101,32,101,110,111,117,103,104,32,115,97,109,112,108,101,115,32,102,111,114,32,109,111,110,105,116,111,114,32,114,101,102,114,101,115,104,32,114,97,116,101,32,101,115,116,105,109,97,116,105,111,110,46,32,82,101,113,117,105,114,101,115,32,116,111,32,114,117,110,32,102,111,114,32,97,116,32,108,101,97,115,116,32,37,117,32,102,114,97,109,101,115,46,10,0,0,0,67,104,101,97,116,32,84,111,103,103,108,101,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,56,0,0,0,83,68,76,95,105,109,97,103,101,32,105,109,97,103,101,32,108,111,97,100,105,110,103,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,67,104,101,97,116,32,73,110,100,101,120,32,77,105,110,117,115,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,55,0,0,0,83,68,76,95,105,109,97,103,101,0,0,0,0,0,0,0,77,66,67,53,43,82,85,77,76,69,43,82,65,77,32,82,79,77,32,110,111,116,32,115,117,112,111,114,116,101,100,46,0,0,0,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,97,108,108,98,97,99,107,0,0,84,101,120,116,117,114,101,83,105,122,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,69,71,76,32,105,109,97,103,101,46,10,0,67,104,101,97,116,32,73,110,100,101,120,32,80,108,117,115,0,0,0,0,0,0,0,0,83,89,83,84,69,77,32,68,73,82,32,37,115,0,0,0,102,114,97,103,109,101,110,116,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,0,0,0,0,0,0,0,0,43,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,54,0,0,0,108,105,98,120,109,108,50,32,88,77,76,32,112,97,114,115,105,110,103,0,0,0,0,0,80,114,101,118,105,111,117,115,32,83,104,97,100,101,114,0,105,110,112,117,116,95,112,108,97,121,101,114,53,0,0,0,108,105,98,120,109,108,50,0,83,97,118,101,32,115,116,97,116,101,47,109,111,118,105,101,32,115,108,111,116,58,32,37,117,0,0,0,0,0,0,0,78,101,120,116,32,83,104,97,100,101,114,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,52,0,0,0,67,103,32,112,105,120,101,108,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,0,82,101,115,101,116,0,0,0,65,32,98,117,116,116,111,110,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,51,0,0,0,67,103,0,0,0,0,0,0,70,114,97,109,101,32,65,100,118,97,110,99,101,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,50,0,0,0,69,120,116,101,114,110,97,108,32,102,105,108,116,101,114,32,97,110,100,32,112,108,117,103,105,110,32,115,117,112,112,111,114,116,0,0,0,0,0,0,80,97,117,115,101,32,84,111,103,103,108,101,0,0,0,0,80,108,97,105,110,32,82,79,77,32,108,111,97,100,101,100,46,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,49,0,0,0,69,120,116,101,114,110,97,108,0,0,0,0,0,0,0,0,77,111,118,105,101,32,82,101,99,111,114,100,32,84,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,111,117,110,100,32,105,110,118,97,108,105,100,32,104,97,116,32,105,110])
.concat([32,99,111,110,102,105,103,33,10,0,0,0,0,0,0,0,79,112,101,110,65,76,0,0,118,105,100,101,111,95,100,105,115,97,98,108,101,95,99,111,109,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,91,71,97,109,98,97,116,116,101,93,58,32,117,110,97,98,108,101,32,116,111,32,114,101,97,100,32,112,97,108,101,116,116,101,32,99,111,108,111,114,32,105,110,32,37,115,44,32,108,105,110,101,32,37,100,32,40,99,111,108,111,114,32,108,101,102,116,32,97,115,32,100,101,102,97,117,108,116,41,46,10,0,0,0,0,0,0,0,80,78,71,32,101,110,99,111,100,101,47,100,101,99,111,100,101,32,97,110,100,32,46,122,105,112,32,101,120,116,114,97,99,116,105,111,110,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,110,105,116,111,114,32,70,80,83,32,101,115,116,105,109,97,116,105,111,110,32,105,115,32,100,105,115,97,98,108,101,100,32,102,111,114,32,116,104,114,101,97,100,101,100,32,118,105,100,101,111,46,10,0,0,0,0,0,0,83,116,97,116,101,32,83,108,111,116,32,77,105,110,117,115,0,0,0,0,0,0,0,0,122,108,105,98,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,82,79,77,32,116,121,112,101,46,10,0,83,116,97,116,101,32,83,108,111,116,32,80,108,117,115,0,105,110,112,117,116,95,100,114,105,118,101,114,0,0,0,0,88,65,117,100,105,111,50,0,77,66,67,53,43,82,85,77,76,69,32,82,79,77,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,73,110,115,101,114,116,0,0,0,0,79,117,116,112,117,116,83,105,122,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,34,37,115,34,32,102,111,114,32,114,101,99,111,114,100,105,110,103,46,10,0,0,0,0,0,111,110,0,0,0,0,0,0,81,117,105,116,32,75,101,121,0,0,0,0,0,0,0,0,79,86,69,82,76,65,89,32,68,73,82,32,37,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,109,101,110,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,104,97,100,101,114,32,115,111,117,114,99,101,32,102,105,108,101,32,119,97,115,32,112,114,111,118,105,100,101,100,44,32,98,117,116,32,102,97,105,108,101,100,32,116,111,32,114,101,97,100,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,100,101,115,99,115,32,102,111,114,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,99,111,100,101,0,0,0,0,68,105,114,101,99,116,83,111,117,110,100,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,84,111,103,103,108,101,0,0,0,0,0,0,0,80,117,108,115,101,65,117,100,105,111,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,0,0,0,37,115,95,37,115,95,97,120,105,115,0,0,0,0,0,0,82,111,97,114,65,117,100,105,111,0,0,0,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,84,101,120,116,117,114,101,50,68,79,69,83,0,0,0,0,37,115,95,37,115,95,98,116,110,0,0,0,0,0,0,0,82,83,111,117,110,100,0,0,70,97,115,116,32,70,111,114,119,97,114,100,32,72,111,108,100,0,0,0,0,0,0,0,105,110,112,117,116,0,0,0,74,97,99,107,0,0,0,0,89,32,40,108,101,102,116,41,0,0,0,0,0,0,0,0,70,97,115,116,32,70,111,114,119,97,114,100,0,0,0,0,37,115,95,37,115,0,0,0,79,83,83,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,45,0,0,0,0,0,0,0,0,110,117,108,0,0,0,0,0,97,117,100,105,111,32,100,114,105,118,101,114,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,43,0,0,0,0,0,0,0,0,118,105,100,101,111,95,109,111,110,105,116,111,114,95,105,110,100,101,120,0,0,0,0,0,40,105,110,99,108,117,100,101,100,41,0,0,0,0,0,0,112,97,117,115,101,0,0,0,115,108,101,99,116,101,100,83,99,104,101,109,101,61,0,0,65,76,83,65,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,45,0,0,0,0,0,0,0,0,98,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0,103,108,115,108,0,0,0,0,88,86,105,100,101,111,32,111,117,116,112,117,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,101,120,116,114,97,99,116,32,82,79,77,32,102,114,111,109,32,122,105,112,112,101,100,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,67,0,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,43,0,0,0,0,0,0,0,0,101,109,115,99,114,105,112,116,101,110,0,0,0,0,0,0,88,86,105,100,101,111,0,0,77,66,67,53,32,82,79,77,43,82,65,77,43,66,65,84,84,69,82,89,32,108,111,97,100,101,100,46,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,111,110,116,114,111,108,0,0,0,73,110,112,117,116,83,105,122,101,0,0,0,0,0,0,0,111,102,102,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,45,0,83,65,86,69,70,73,76,69,32,68,73,82,32,37,115,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,102,97,105,108,101,100,46,10,0,0,0,0,71,76,32,114,97,115,116,101,114,0,0,0,0,0,0,0,115,114,99,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,100,101,115,99,115,46,10,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,115,99,114,111,108,108,95,108,111,99,107,0,0,0,0,0,79,112,101,110,86,71,32,111,117,116,112,117,116,32,115,117,112,112,111,114,116,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,43,0,112,114,105,110,116,95,115,99,114,101,101,110,0,0,0,0,79,112,101,110,86,71,0,0,83,97,118,101,100,32,115,116,97,116,101,32,116,111,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,45,0,100,105,118,105,100,101,0,0,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,43,0,82,105,103,104,116,32,68,45,112,97,100,0,0,0,0,0,109,117,108,116,105,112,108,121,0,0,0,0,0,0,0,0,69,71,76,0,0,0,0,0,84,117,114,98,111,32,69,110,97,98,108,101,0,0,0,0,75,77,83,47,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,66,32,40,98,111,116,116,111,109,41,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,51,32,66,117,116,116,111,110,0,0,0,0,0,0,71,66,67,32,45,32,89,101,108,108,111,119,0,0,0,0,110,117,109,108,111,99,107,0,75,77,83,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,51,32,66,117,116,116,111,110,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,114,101,97,116,105,110,103,32,70,66,79,32,37,100,32,64,32,37,117,120,37,117,10,0,0,0,0,0,71,66,67,32,45,32,82,101,100,0,0,0,0,0,0,0,99,97,112,115,108,111,99,107,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,79,86,69,82,83,67,65,78,58,32,37,117,10,0,0,0,0,79,112,101,110,71,76,32,100,114,105,118,101,114,0,0,0,82,101,116,114,111,80,97,100,32,82,50,32,66,117,116,116,111,110,0,0,0,0,0,0,118,105,100,101,111,95,119,105,110,100,111,119,101,100,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,32,37,115,10,0,0,0,71,66,67,32,45,32,80,97,115,116,101,108,32,77,105,120,0,0,0,0,0,0,0,0,91,71,97,109,98,97,116,116,101,93,58,32,101,114,114,111,114,32,105,110,32,37,115,44,32,108,105,110,101,32,37,100,32,40,99,111,108,111,114,32,108,101,102,116,32,97,115,32,100,101,102,97,117,108,116,41,46,10,0,0,0,0,0,0,79,112,101,110,71,76,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,105,110,105,116,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,50,32,66,117,116,116,111,110,0,0,0,0,0,0,71,66,67,32,45,32,79,114,97,110,103,101,0,0,0,0,107,101,121,112,97,100,57,0,84,104,114,101,97,100,105,110,103,32,115,117,112,112,111,114,116,0,0,0,0,0,0,0,122,105,112,0,0,0,0,0,66,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,32,66,117,116,116,111,110,0,0,0,0,0,0,0,71,66,67,32,45,32,73,110,118,101,114,116,101,100,0,0,118,101,99,116,111,114,0,0,107,101,121,112,97,100,56,0,84,104,114,101,97,100,115,0,77,66,67,53,32,82,79,77,43,82,65,77,32,108,111,97,100,101,100,46,0,0,0,0,103,108,73,115,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,0,0,76,85,84,84,101,120,67,111,111,114,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,32,86,83,121,110,99,32,61,62,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,32,66,117,116,116,111,110,0,0,0,0,0,0,0,83,65,86,69,83,84,65,84,69,32,68,73,82,32,37,115,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,37,115,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,104,97,118,101,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,105,110,32,97,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,71,66,67,32,45,32,71,114,101,101,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,110,117,109,98,101,114,32,111,102,32,100,101,115,99,115,32,102,114,111,109,32,99,111,110,102,105,103,32,107,101,121,58,32,37,115,46,10,0,0,0,0,99,104,101,97,116,0,0,0,107,101,121,112,97,100,55,0,83,68,76,32,100,114,105,118,101,114,115,0,0,0,0,0,82,101,116,114,111,80,97,100,32,88,32,66,117,116,116,111,110,0,0,0,0,0,0,0,71,66,67,32,45,32,68,97,114,107,32,71,114,101,101,110,0,0,0,0,0,0,0,0,107,101,121,112,97,100,54,0,83,68,76,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,0,82,101,116,114,111,80,97,100,32,65,32,66,117,116,116,111,110,0,0,0,0,0,0,0,71,66,67,32,45,32,68,97,114,107,32,66,114,111,119,110,0,0,0,0,0,0,0,0,107,101,121,112,97,100,53,0,9,37,115,58,10,9,9,37,115,58,32,37,115,10,0,0,37,102,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,71,66,67,32,45,32,68,97,114,107,32,66,108,117,101,0,107,101,121,112,97,100,52,0,70,101,97,116,117,114,101,115,58,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,71,66,67,32,45,32,66,114,111,119,110,0,0,0,0,0,107,101,121,112,97,100,51,0,107,101,121,112,97,100,50,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,88,82,71,66,56,56,56,56,46,10,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,71,66,67,32,45,32,71,114,97,121,115,99,97,108,101,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,45,45,109,101,110,117,32,119,97,115,32,117,115,101,100,44,32,98,117,116,32,82,79,77,32,102,105,108,101,32,119,97,115,32,112,97,115,115,101,100,32,97,115,32,119,101,108,108,46,10,0,107,101,121,112,97,100,49,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,71,66,67,32,45,32,66,108,117,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,114,103,117,109,101,110,116,115,46,10,0,0,107,101,121,112,97,100,48,0,82,101,116,114,111,80,97,100,32,83,116,97,114,116,32,66,117,116,116,111,110,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,10,0,0,0,0,0,0,101,110,97,98,108,101,100,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,32,105,110,32,45,45,115,114,97,109,45,109,111,100,101,46,10,0,0,112,97,103,101,100,111,119,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,112,104,105,99,115,32,100,114,105,118,101,114,32,100,105,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,97,110,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,112,105,99,107,32,97,32,115,117,105,116,97,98,108,101,32,100,114,105,118,101,114,46,10,0,0,0,82,101,116,114,111,80,97,100,32,83,101,108,101,99,116,32,66,117,116,116,111,110,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,114,101,115,111,108,118,101,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,33,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,100,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,81,117,105,116,32,82,101,116,114,111,65,114,99,104,0,0,108,111,97,100,45,115,97,118,101,0,0,0,0,0,0,0,112,97,103,101,117,112,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,116,111,32,34,37,115,34,46,10,0,65,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,89,32,66,117,116,116,111,110,0,0,0,0,0,0,0,92,47,0,0,0,0,0,0,82,101,115,116,97,114,116,32,82,101,116,114,111,65,114,99,104,0,0,0,0,0,0,0,37,46,48,76,102,0,0,0,108,111,97,100,45,110,111,115,97,118,101,0,0,0,0,0,110,117,109,57,0,0,0,0,77,66,67,53,32,82,79,77,32,108,111,97,100,101,100,46,0,0,0,0,0,0,0,0,103,108,71,101,110,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,0,0,0,67,111,108,111,114,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,51,50,45,98,105,116,32,70,66,79,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,49,54,45,98,105,116,46,10,0,0,0,0,82,101,116,114,111,80,97,100,32,66,32,66,117,116,116,111,110,0,0,0,0,0,0,0,83,72,65,68,69,82,32,68,73,82,32,37,115,0,0,0,82,101,116,114,111,65,114,99,104,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,115,117,99,99,101,101,100,101,100,46,10,0,0,0,118,101,114,116,101,120,0,0,82,101,115,116,97,114,116,32,71,97,109,101,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,115,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,99,104,101,97,116,32,102,111,114,32,103,97,109,101,58,32,34,37,115,34,10,0,0,110,111,108,111,97,100,45,115,97,118,101,0,0,0,0,0,110,117,109,56,0,0,0,0,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,0,82,101,115,117,109,101,32,71,97,109,101,0,0,0,0,0,110,111,108,111,97,100,45,110,111,115,97,118,101,0,0,0,76,111,97,100,101,100,32,115,116,97,116,101,32,102,114,111,109,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,110,117,109,55,0,0,0,0,84,97,107,101,32,83,99,114,101,101,110,115,104,111,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,115,99,111,110,110,101,99,116,32,100,101,118,105,99,101,32,102,114,111,109,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,110,117,109,54,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,0,0,0,0,0,0,0,76,101,102,116,32,68,45,112,97,100,0,0,0,0,0,0,76,111,97,100,32,83,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,109,111,117,115,101,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,110,117,109,53,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,58,32,37,115,46,10,0,0,0,83,97,118,101,32,83,116,97,116,101,0,0,0,0,0,0,112,97,114,115,101,95,105,110,112,117,116,40,41,0,0,0,110,117,109,52,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,82,71,66,53,54,53,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,46,10,0,0,0,0,0,68,105,115,107,32,79,112,116,105,111,110,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,0,110,117,109,51,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,114,111,109,58,32,37,115,46,10,0,0,0,0,83,101,116,116,105,110,103,115,0,0,0,0,0,0,0,0,104,115,58,102,118,83,58,109,58,112,52,106,74,65,58,103,58,98,58,99,58,66,58,89,58,90,58,85,58,68,78,58,88,58,80,58,82,58,77,58,0,0,0,0,0,0,0,0,110,117,109,50,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,121,0,0,0,0,0,0,35,105,110,99,108,117,100,101,32,34,37,115,34,10,0,0,80,97,116,104,32,79,112,116,105,111,110,115,0,0,0,0,100,101,102,97,117,108,116,46,112,97,108,0,0,0,0,0,102,101,97,116,117,114,101,115,0,0,0,0,0,0,0,0,110,117,109,49,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,111,112,101,110,32,118,105,100,101,111,32,100,114,105,118,101,114,32,46,46,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,47,101,116,99,0,0,0,0,110,117,108,108,0,0,0,0,47,112,114,111,99,47,37,117,47,37,115,0,0,0,0,0,73,110,112,117,116,32,79,112,116,105,111,110,115,0,0,0,100,101,116,97,99,104,0,0,110,117,109,48,0,0,0,0,115,105,110,99,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,114,101,99,111,118,101,114,32,46,46,46,10,0,0,37,115,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,0,65,117,100,105,111,32,79,112,116,105,111,110,115,0,0,0,109,111,110,101,121,95,103,101,116,32,101,114,114,111,114,0,105,110,108,101,110,32,60,61,32,112,101,114,105,111,100,83,105,122,101,0,0,0,0,0,120,109,108,0,0,0,0,0,102,49,50,0,0,0,0,0,77,66,67,52,32,82,79,77,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,103,108,68,101,108,101,116,101,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,86,101,114,116,101,120,67,111,111,114,100,0,0,0,0,0,46,116,103,97,0,0,0,0,65,82,77,95,97,114,103,98,56,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,111,107,105,110,103,32,102,111,114,32,99,111,110,102,105,103,32,105,110,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,66,82,79,87,83,69,82,32,68,73,82,32,37,115,0,0,98,105,116,109,97,112,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,76,101,103,97,99,121,32,115,104,97,100,101,114,115,32,97,114,101,32,100,101,112,114,101,99,97,116,101,100,46,10,0,0,0,0,0,0,0,86,105,100,101,111,32,79,112,116,105,111,110,115,0,0,0,111,118,101,114,108,97,121,37,117,95,102,117,108,108,95,115,99,114,101,101,110,0,0,0,110,97,109,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,110,111,45,112,97,116,99,104,0,0,0,0,0,0,0,0,102,49,49,0,0,0,0,0,37,115,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,67,111,114,101,32,79,112,116,105,111,110,115,0,0,0,0,105,112,115,0,0,0,0,0,102,49,48,0,0,0,0,0,37,115,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,90,69,76,68,65,0,0,0,76,111,97,100,32,71,97,109,101,0,0,0,0,0,0,0,98,112,115,0,0,0,0,0,102,57,0,0,0,0,0,0,72,79,77,69,0,0,0,0,89,79,83,83,89,32,78,79,32,84,65,77,65,71,79,0,76,111,97,100,32,71,97,109,101,32,40,72,105,115,116,111,114,121,41,0,0,0,0,0,117,112,115,0,0,0,0,0,102,56,0,0,0,0,0,0,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,0,48,0,0,0,0,0,0,0,89,79,83,83,89,32,78,79,32,80,65,78,69,80,79,78,0,0,0,0,0,0,0,0,114,103,117,105,46,99,103,112,0,0,0,0,0,0,0,0,115,114,97,109,45,109,111,100,101,0,0,0,0,0,0,0,102,55,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,48,82,71,66,49,53,53,53,46,10,0,89,79,83,83,89,32,78,79,32,67,79,79,75,73,69,0,114,103,117,105,46,103,108,115,108,112,0,0,0,0,0,0,98,115,118,114,101,99,111,114,100,0,0,0,0,0,0,0,102,54,0,0,0,0,0,0,89,79,83,72,73,39,83,32,67,79,79,75,73,69,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,46,46,46,10,0,98,115,118,112,108,97,121,0,102,53,0,0,0,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,120,0,0,0,0,0,0,83,97,116,0,0,0,0,0,89,65,75,85,77,65,78,0,82,51,0,0,0,0,0,0,46,112,97,108,0,0,0,0,115,117,102,97,109,105,66,0,102,52,0,0,0,0,0,0,105,110,105,116,95,118,105,100,101,111,95,105,110,112,117,116,40,41,0,0,0,0,0,0,112,97,116,104,47,97,46,111,117,116,0,0,0,0,0,0,70,114,105,0,0,0,0,0,76,51,0,0,0,0,0,0,115,117,102,97,109,105,65,0,102,51,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,83,82,65,77,46,10,0,0,0,0,0,0,84,104,117,0,0,0,0,0,105,111,115,116,114,101,97,109,0,0,0,0,0,0,0,0,87,79,82,76,68,32,67,85,80,0,0,0,0,0,0,0,82,50,0,0,0,0,0,0,37,76,102,0,0,0,0,0,109,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,102,50,0,0,0,0,0,0,77,66,67,51,32,82,79,77,43,82,65,77,43,66,65,84,84,69,82,89,32,108,111,97,100,101,100,46,0,0,0,0,3,3,11,0,0,0,0,0,103,108,66,105,110,100,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,84,101,120,67,111,111,114,100,0,0,0,0,0,0,0,0,79,69,83,95,114,103,98,56,95,114,103,98,97,56,0,0,79,86,69,82,76,65,89,32,37,115,0,0,0,0,0,0,73,78,70,79,32,45,32,76,111,97,100,105,110,103,32,37,115,32,46,46,46,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,114,101,112,111,114,116,115,32,97,32,71,76,69,83,50,32,115,116,121,108,101,32,115,104,97,100,101,114,46,10,0,0,87,101,100,0,0,0,0,0,87,65,86,69,82,65,67,69,0,0,0,0,0,0,0,0,76,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,114,101,99,116,32,34,37,115,34,32,105,110,116,111,32,97,116,32,108,101,97,115,116,32,102,111,117,114,32,116,111,107,101,110,115,46,10,0,0,0,115,99,97,108,101,95,121,37,117,0,0,0,0,0,0,0,98,115,120,115,108,111,116,0,102,49,0,0,0,0,0,0,84,117,101,0,0,0,0,0,87,65,82,73,79,76,65,78,68,50,0,0,0,0,0,0,115,99,97,108,101,95,120,37,117,0,0,0,0,0,0,0,98,115,120,0,0,0,0,0,37,115,37,117,0,0,0,0,107,112,95,109,105,110,117,115,0,0,0,0,0,0,0,0,77,111,110,0,0,0,0,0,87,65,82,73,79,32,66,76,65,83,84,0,0,0,0,0,115,99,97,108,101,37,117,0,115,97,118,101,115,116,97,116,101,0,0,0,0,0,0,0,107,112,95,112,108,117,115,0,68,111,119,110,32,68,45,112,97,100,0,0,0,0,0,0,83,117,110,0,0,0,0,0,86,69,71,65,83,32,83,84,65,75,69,83,0,0,0,0,83,101,108,101,99,116,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,116,116,114,105,98,117,116,101,46,10,0,0,0,0,0,0,0,0,115,104,97,100,101,114,115,0,100,117,97,108,97,110,97,108,111,103,0,0,0,0,0,0,115,117,98,116,114,97,99,116,0,0,0,0,0,0,0,0,79,117,116,32,88,32,61,32,37,100,32,61,62,32,73,110,32,88,32,61,32,37,100,10,0,0,0,0,0,0,0,0,83,97,116,117,114,100,97,121,0,0,0,0,0,0,0,0,84,79,89,32,83,84,79,82,89,0,0,0,0,0,0,0,83,116,97,114,116,0,0,0,115,99,97,108,101,95,116,121,112,101,95,121,37,117,0,0,106,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,97,100,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,89,83,84,69,77,95,68,73,82,69,67,84,79,82,89,58,32,34,37,115,34,46,10,0,0,0,0,0,105,110,112,117,116,95,100,101,118,105,99,101,95,112,37,117,0,0,0,0,0,0,0,0,70,114,105,100,97,121,0,0,84,79,80,82,65,78,75,84,69,78,78,73,83,0,0,0,115,99,97,108,101,95,116,121,112,101,95,120,37,117,0,0,106,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,101,115,99,97,112,101,0,0,105,110,112,117,116,95,100,112,97,100,95,101,109,117,108,97,116,105,111,110,95,112,37,117,0,0,0,0,0,0,0,0,84,104,117,114,115,100,97,121,0,0,0,0,0,0,0,0,84,79,80,82,65,78,75,73,78,71,84,69,78,78,73,83,0,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,37,117,0,0,0,0,115,99,111,112,101,0,0,0,99,117,115,116,111,109,95,98,103,109,95,101,110,97,98,108,101,0,0,0,0,0,0,0,118,105,100,101,111,95,121,115,99,97,108,101,0,0,0,0,87,101,100,110,101,115,100,97,121,0,0,0,0,0,0,0,84,72,69,32,67,72,69,83,83,77,65,83,84,69,82,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,112,97,114,115,101,32,115,104,97,100,101,114,32,115,111,117,114,99,101,32,40,37,115,41,46,10,0,0,0,0,0,0,0,0,110,111,100,101,118,105,99,101,0,0,0,0,0,0,0,0,47,112,97,108,101,116,116,101,115,47,0,0,0,0,0,0,97,108,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,112,105,120,101,108,32,99,111,110,118,101,114,116,101,114,46,10,0,0,0,115,99,114,101,101,110,95,111,114,105,101,110,116,97,116,105,111,110,0,0,0,0,0,0,109,111,117,115,101,0,0,0,84,117,101,115,100,97,121,0,84,69,84,82,73,83,50,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,73,110,118,97,108,105,100,32,119,114,97,112,112,105,110,103,32,116,121,112,101,32,37,115,46,32,86,97,108,105,100,32,111,110,101,115,32,97,114,101,58,32,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,32,40,100,101,102,97,117,108,116,41,44,32,99,108,97,109,112,95,116,111,95,101,100,103,101,44,32,114,101,112,101,97,116,32,97,110,100,32,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,100,101,102,97,117,108,116,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,32,82,101,119,105,110,100,105,110,103,32,119,105,108,108,32,98,101,32,100,105,115,97,98,108,101,100,46,10,0,0,99,116,114,108,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,66,108,111,99,107,105,110,103,32,83,82,65,77,32,111,118,101,114,119,114,105,116,101,46,10,0,0,0,0,77,111,110,100,97,121,0,0,84,69,84,82,73,83,32,80,76,85,83,0,0,0,0,0,82,105,103,104,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,112,97,116,104,32,116,111,32,116,101,120,116,117,114,101,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,97,112,112,101,110,100,99,111,110,102,105,103,0,0,0,0,115,104,105,102,116,0,0,0,77,66,67,51,32,82,79,77,43,82,65,77,32,108,111,97,100,101,100,46,0,0,0,0,2,3,7,0,0,0,0,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,51,68,79,69,83,0,0,0,0,0,0,0,77,86,80,77,97,116,114,105,120,0,0,0,0,0,0,0,100,111,101,115,110,39,116,32,101,120,105,115,116,0,0,0,115,116,97,116,101,95,115,108,111,116,0,0,0,0,0,0,37,115,46,122,105,112,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,117,110,105,102,111,114,109,32,97,110,100,32,97,116,116,114,105,98,32,112,114,101,102,105,120,58,32,37,115,10,0,0,0,83,117,110,100,97,121,0,0,84,69,84,82,73,83,32,70,76,65,83,72,0,0,0,0,76,101,102,116,0,0,0,0,44,32,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,97,100,100,114,101,115,115,32,97,115,115,105,103,110,101,100,32,116,111,32,115,101,109,97,110,116,105,99,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,32,116,111,32,34,37,115,34,46,32,67,104,101,99,107,32,112,101,114,109,105,115,115,105,111,110,115,46,10,0,0,0,0,63,62,10,0,0,0,0,0,99,111,110,102,105,103,0,0,114,115,104,105,102,116,0,0,115,111,117,110,100,95,109,111,100,101,0,0,0,0,0,0,84,69,84,82,73,83,32,66,76,65,83,84,0,0,0,0,68,111,119,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,46,10,0,103,97,109,101,98,111,121,0,82,101,116,114,111,65,114,99,104,58,32,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,104,111,109,101,0,0,0,0,99,117,114,114,101,110,116,95,114,101,115,111,108,117,116,105,111,110,95,105,100,0,0,0,58,32,0,0,0,0,0,0,83,0,0,0,97,0,0,0,116,0,0,0,0,0,0,0,84,69,84,82,73,83,32,65,84,84,65,67,75,0,0,0,85,112,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,46,10,0,0,118,101,114,98,111,115,101,0,101,110,100,0,0,0,0,0,77,66,67,49,32,82,79,77,32,108,111,97,100,101,100,46,0,0,0,0,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,91,82,80,78,71,93,58,32,69,114,114,111,114,32,105,110,32,108,105,110,101,32,37,100,46,10,0,0,0,0,0,0,70,0,0,0,114,0,0,0,105,0,0,0,0,0,0,0,84,69,84,82,73,83,0,0,68,80,97,100,32,69,109,117,108,97,116,105,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,101,120,116,101,114,110,97,108,32,115,111,117,114,99,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,100,101,108,0,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,79,69,83,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,103,108,115,108,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,37,115,10,0,0,84,0,0,0,104,0,0,0,117,0,0,0,0,0,0,0,84,69,78,78,73,83,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,105,110,105,116,32,102,111,110,116,32,114,101,110,100,101,114,101,114,46,10,0,0,0,0,0,0,0,68,101,118,105,99,101,32,84,121,112,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,115,97,118,101,0,0,0,0,105,110,115,101,114,116,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,80,69,82,70,79,82,77,65,78,67,69,95,76,69,86,69,76,58,32,37,117,46,10,0,0,0,0,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,70,66,79,32,116,97,114,103,101,116,115,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,70,66,79,46,10,0,0,87,0,0,0,101,0,0,0,100,0,0,0,0,0,0,0,83,85,80,69,82,77,65,82,73,79,76,65,78,68,51,0,68,101,118,105,99,101,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,104,101,108,112,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,0,0,0,84,0,0,0,117,0,0,0,101,0,0,0,0,0,0,0,83,85,80,69,82,68,79,78,75,69,89,75,79,78,71,0,80,108,97,121,101,114,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,109,101,110,117,0,0,0,0,107,112,95,101,110,116,101,114,0,0,0,0,0,0,0,0,105,110,102,111,95,109,115,103,95,101,110,97,98,108,101,0,118,105,100,101,111,95,120,115,99,97,108,101,0,0,0,0,99,103,112,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,118,101,114,108,97,121,32,105,110,116,101,114,102,97,99,101,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,118,105,100,101,111,32,100,114,105,118,101,114,46,10,0,82,101,116,114,111,65,114,99,104,58,32,83,105,110,99,32,114,101,115,97,109,112,108,101,114,32,91,67,93,10,0,0,77,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,83,85,80,69,82,32,82,67,32,80,82,79,45,65,77,0,46,112,110,103,0,0,0,0,79,118,101,114,108,97,121,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,121,32,97,116,116,114,58,32,37,117,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,114,119,101,98,97,117,100,105,111,0,0,0,0,0,0,0,83,101,112,32,49,51,32,50,48,49,51,0,0,0,0,0,91,71,97,109,98,97,116,116,101,93,58,32,110,111,32,115,121,115,116,101,109,32,100,105,114,101,99,116,111,114,121,32,100,101,102,105,110,101,100,44,32,117,110,97,98,108,101,32,116,111,32,108,111,111,107,32,102,111,114,32,99,117,115,116,111,109,32,112,97,108,101,116,116,101,115,46,10,0,0,0,101,110,116,101,114,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,102,117,108,108,115,99,114,101,101,110,10,0,0,116,114,105,112,108,101,95,98,117,102,102,101,114,105,110,103,95,101,110,97,98,108,101,0,101,120,101,0,0,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,105,111,115,116,114,101,97,109,95,99,97,116,101,103,111,114,121,32,101,114,114,111,114,0,0,0,0,0,83,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,83,85,80,69,82,32,77,65,82,73,79,76,65,78,68,0,79,118,101,114,108,97,121,32,79,112,97,99,105,116,121,0,82,101,116,114,111,65,114,99])
.concat([104,58,32,71,111,116,32,115,105,122,101,95,120,32,97,116,116,114,58,32,37,117,10,0,66,117,105,108,116,58,32,37,115,10,0,0,0,0,0,0,82,71,85,73,32,109,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,34,115,104,97,100,101,114,115,34,32,112,97,114,97,109,46,10,0,0,0,0,0,0,79,117,116,32,89,32,61,32,37,100,32,61,62,32,73,110,32,89,32,61,32,37,100,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,115,112,97,99,101,0,0,0,103,97,109,109,97,95,99,111,114,114,101,99,116,105,111,110,0,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,83,85,80,69,82,32,66,79,77,66,76,73,83,83,32,32,0,0,0,0,0,0,0,0,79,118,101,114,108,97,121,32,80,114,101,115,101,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,32,97,116,116,114,58,32,37,117,10,0,0,0,52,46,50,46,49,32,67,111,109,112,97,116,105,98,108,101,32,67,108,97,110,103,32,51,46,50,32,40,116,97,103,115,47,82,69,76,69,65,83,69,95,51,50,47,102,105,110,97,108,41,0,0,0,0,0,0,77,66,67,51,32,82,79,77,32,108,111,97,100,101,100,46,0,0,0,0,0,0,0,0,5,5,4,0,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,101,120,105,115,116,115,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,77,69,78,85,32,37,115,0,37,117,120,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,99,111,110,102,105,103,32,102,105,108,101,58,32,37,115,46,10,0,0,0,116,105,108,100,101,0,0,0,112,114,101,102,105,120,0,0,70,0,0,0,114,0,0,0,105,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,83,84,82,69,69,84,32,70,73,71,72,84,69,82,32,50,0,0,0,0,0,0,0,0,83,121,115,116,101,109,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,114,101,99,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,37,117,59,0,0,0,0,0,60,63,120,109,108,0,0,0,100,97,116,97,98,97,115,101,0,0,0,0,0,0,0,0,119,98,0,0,0,0,0,0,67,108,97,110,103,47,76,76,86,77,32,40,37,115,41,32,37,117,45,98,105,116,10,0,71,114,97,98,32,109,111,117,115,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,99,111,109,112,97,116,47,99,111,109,112,97,116,46,99,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,99,111,110,102,105,103,46,32,65,115,115,117,109,105,110,103,32,115,121,115,116,101,109,32,100,105,114,101,99,116,111,114,121,32,105,115,32,115,97,109,101,32,102,111,108,100,101,114,32,97,115,32,103,97,109,101,58,32,34,37,115,34,46,10,0,0,0,0,0,84,0,0,0,104,0,0,0,117,0,0,0,114,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,83,84,65,82,32,87,65,82,83,45,78,79,65,0,0,0,79,118,101,114,108,97,121,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,10,67,111,109,112,105,108,101,114,58,32,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,73,110,105,116,105,110,103,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,119,105,116,104,32,115,105,122,101,58,32,37,117,32,77,66,10,0,0,0,0,0,0,98,109,112,0,0,0,0,0,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,116,97,98,0,0,0,0,0,87,0,0,0,101,0,0,0,100,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,83,84,65,82,32,87,65,82,83,0,0,0,0,0,0,0,83,97,118,101,102,105,108,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,97,32,100,105,102,102,101,114,101,110,116,32,118,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,116,104,97,110,32,116,104,105,115,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,68,105,115,107,32,110,101,120,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,85,115,105,110,103,32,82,88,77,76,32,97,115,32,100,114,111,112,32,105,110,32,102,111,114,32,108,105,98,120,109,108,50,46,32,66,101,104,97,118,105,111,114,32,109,105,103,104,116,32,98,101,32,118,101,114,121,32,98,117,103,103,121,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,85,112,32,68,45,112,97,100,0,0,0,0,0,0,0,0,37,117,0,0,0,0,0,0,84,0,0,0,117,0,0,0,101,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,83,84,65,82,32,83,84,65,67,75,69,82,0,0,0,0,83,97,118,101,115,116,97,116,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,102,114,97,109,101,32,99,111,117,110,116,32,109,111,100,32,97,116,116,114,58,32,37,117,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,65,80,73,58,32,37,117,10,0,0,0,0,46,115,116,97,116,101,0,0,77,0,0,0,111,0,0,0,110,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,83,80,65,67,69,32,73,78,86,65,68,69,82,83,0,0,83,104,97,100,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,65,80,73,58,32,37,117,10,0,68,105,115,107,32,101,106,101,99,116,32,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,72,85,84,68,79,87,78,46,10,0,0,0,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,83,0,0,0,117,0,0,0,110,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,83,79,76,65,82,83,84,82,73,75,69,82,0,0,0,0,66,114,111,119,115,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,108,97,115,116,32,115,116,97,116,101,32,115,108,111,116,58,32,35,37,117,10,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,0,83,79,67,67,69,82,0,0,68,101,98,117,103,32,73,110,102,111,32,77,101,115,115,97,103,101,115,0,0,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,0,59,32,0,0,0,0,0,0,65,117,116,111,45,108,111,97,100,105,110,103,32,115,97,118,101,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,32,37,115,46,0,0,0,0,79,118,101,114,108,97,121,32,110,101,120,116,0,0,0,0,114,119,101,98,105,110,112,117,116,0,0,0,0,0,0,0,46,115,114,109,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,101,110,100,32,61,61,61,10,0,0,0,0,0,68,101,99,0,0,0,0,0,37,120,0,0,0,0,0,0,83,69,73,75,69,78,32,68,69,78,83,69,84,83,85,0,67,111,110,102,105,103,32,83,97,118,101,32,79,110,32,69,120,105,116,0,0,0,0,0,111,117,116,115,99,97,108,101,95,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,97,117,116,111,32,115,97,118,101,115,116,97,116,101,32,105,110,58,32,37,115,10,0,91,71,97,109,98,97,116,116,101,93,58,32,71,111,116,32,105,110,116,101,114,110,97,108,32,103,97,109,101,32,110,97,109,101,58,32,37,115,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,37,117,120,37,117,10,0,0,0,0,0,0,0,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,46,37,115,0,0,0,0,0,78,111,118,0,0,0,0,0,82,79,67,75,77,65,78,87,79,82,76,68,51,0,0,0,82,101,119,105,110,100,32,71,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,111,117,116,115,99,97,108,101,95,120,0,0,0,0,0,0,86,111,108,117,109,101,32,45,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,0,99,111,110,102,105,103,95,115,97,118,101,95,111,110,95,101,120,105,116,0,0,0,0,0,79,99,116,0,0,0,0,0,82,79,67,75,77,65,78,32,87,79,82,76,68,50,0,0,82,101,119,105,110,100,0,0,111,117,116,115,99,97,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,10,0,0,0,0,77,66,67,51,32,82,79,77,43,84,73,77,69,82,43,82,65,77,43,66,65,84,84,69,82,89,32,108,111,97,100,101,100,46,0,0,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,81,117,101,114,121,105,110,103,32,71,76,32,101,120,116,101,110,115,105,111,110,58,32,37,115,32,61,62,32,37,115,10,0,0,0,0,0,106,111,121,112,97,100,95,97,117,116,111,99,111,110,102,105,103,95,100,105,114,0,0,0,83,72,65,68,69,82,32,37,115,0,0,0,0,0,0,0,71,76,69,83,50,0,0,0,83,101,112,0,0,0,0,0,82,79,67,75,77,65,78,32,87,79,82,76,68,0,0,0,78,111,32,111,112,116,105,111,110,115,32,97,118,97,105,108,97,98,108,101,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,115,105,122,101,95,121,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,115,97,118,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,46,10,0,0,0,45,45,62,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,43,0,0,0,0,0,0,0,0,105,110,112,117,116,95,97,117,116,111,100,101,116,101,99,116,95,101,110,97,98,108,101,0,65,117,103,0,0,0,0,0,82,65,68,65,82,77,73,83,83,73,79,78,0,0,0,0,82,97,116,101,32,67,111,110,116,114,111,108,32,68,101,108,116,97,0,0,0,0,0,0,115,105,122,101,95,120,0,0,105,110,105,116,95,109,111,118,105,101,40,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,101,114,102,111,114,109,32,105,110,105,116,105,97,108,32,115,101,114,105,97,108,105,122,97,116,105,111,110,32,102,111,114,32,114,101,119,105,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,32,71,80,85,32,114,101,110,100,101,114,105,110,103,32,105,115,32,117,115,101,100,32,97,110,100,32,114,101,97,100,95,118,105,101,119,112,111,114,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,103,97,109,98,97,116,116,101,58,58,67,97,114,116,114,105,100,103,101,116,121,112,101,32,103,97,109,98,97,116,116,101,58,58,99,97,114,116,114,105,100,103,101,84,121,112,101,40,99,111,110,115,116,32,117,110,115,105,103,110,101,100,32,105,110,116,41,0,0,0,0,0,118,105,114,116,117,97,108,32,115,116,100,58,58,115,105,122,101,95,116,32,67,104,97,105,110,82,101,115,97,109,112,108,101,114,58,58,114,101,115,97,109,112,108,101,40,115,104,111,114,116,32,42,99,111,110,115,116,44,32,99,111,110,115,116,32,115,104,111,114,116,32,42,99,111,110,115,116,44,32,115,116,100,58,58,115,105,122,101,95,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,0,0,0,0,0,0,37,0,0,0,89,0,0,0,45,0,0,0,37,0,0,0,109,0,0,0,45,0,0,0,37,0,0,0,100,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,0,0,0,0,37,0,0,0,73,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,112,0,0,0,0,0,0,0,37,0,0,0,109,0,0,0,47,0,0,0,37,0,0,0,100,0,0,0,47,0,0,0,37,0,0,0,121,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,37,72,58,37,77,58,37,83,37,72,58,37,77,0,0,0,37,73,58,37,77,58,37,83,32,37,112,0,0,0,0,0,37,89,45,37,109,45,37,100,37,109,47,37,100,47,37,121,37,72,58,37,77,58,37,83,37,0,0,0,0,0,0,0,37,112,0,0,0,0,0,0,0,254,0,128,0,32,0,0,0,254,0,128,0,32,0,0,0,160,0,0,0,128,0,0,0,254,0,128,0,32,0,0,0,254,0,128,0,32,0,0,0,0,0,0,0,0,0,0,0,192,0,128,0,32,0,0,0,192,0,128,0,32,0,0,0,160,0,0,0,128,0,0,0,254,0,0,0,192,0,0,0,192,0,128,0,32,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,2,2,0,0,0,0,0,0,0,0,3,3,3,3,3,0,0,0,0,0,4,4,4,4,4,4,0,101,110,118,52,118,111,108,0,101,110,118,52,99,116,114,0,108,102,115,114,114,101,103,0,108,102,115,114,99,116,114,0,99,51,109,97,115,116,114,0,110,114,51,52,0,0,0,0,110,114,51,51,0,0,0,0,119,97,118,115,109,112,108,0,119,97,118,101,112,111,115,0,108,119,97,118,114,100,116,0,104,0,0,0,0,0,0,0,119,97,118,101,99,116,114,0,108,101,110,51,118,97,108,0,108,101,110,51,99,116,114,0,119,97,118,101,114,97,109,0,99,50,109,97,115,116,114,0,110,114,50,52,0,0,0,0,110,114,50,51,0,0,0,0,108,101,110,50,118,97,108,0,108,101,110,50,99,116,114,0,101,110,118,50,118,111,108,0,102,0,0,0,0,0,0,0,101,110,118,50,99,116,114,0,100,117,116,50,112,111,115,0,100,117,116,50,99,116,114,0,99,49,109,97,115,116,114,0,110,114,49,52,0,0,0,0,110,114,49,51,0,0,0,0,110,114,49,48,0,0,0,0,108,101,110,49,118,97,108,0,108,101,110,49,99,116,114,0,101,110,118,49,118,111,108,0,101,0,0,0,0,0,0,0,101,110,118,49,99,116,114,0,100,117,116,49,112,111,115,0,100,117,116,49,99,116,114,0,115,119,112,110,101,103,0,0,115,119,112,115,104,100,119,0,115,119,112,99,110,116,114,0,115,112,117,99,110,116,114,0,108,99,100,115,105,114,113,0,119,101,109,97,115,116,114,0,119,115,99,120,0,0,0,0,100,0,0,0,0,0,0,0,119,105,110,100,114,97,119,0,111,108,100,119,121,0,0,0,109,48,108,121,99,0,0,0,108,121,99,0,0,0,0,0,99,115,112,114,105,116,101,0,110,115,112,114,105,116,101,0,112,112,117,115,116,97,116,0,98,103,110,97,116,114,98,0,98,103,97,116,114,98,0,0,112,112,117,114,49,0,0,0,99,0,0,0,0,0,0,0,112,112,117,114,48,0,0,0,101,110,100,120,0,0,0,0,120,112,111,115,0,0,0,0,119,105,110,121,112,111,115,0,98,103,110,116,119,0,0,0,98,103,116,119,0,0,0,0,110,109,48,105,114,113,0,0,109,48,116,105,109,101,0,0,101,100,77,48,116,105,109,0,118,99,121,99,108,101,115,0,98,0,0,0,0,0,0,0,115,112,98,121,116,101,49,0,115,112,98,121,116,101,48,0,115,112,97,116,116,114,0,0,115,112,115,122,98,117,102,0,115,112,111,115,98,117,102,0,111,98,106,112,0,0,0,0,98,103,112,0,0,0,0,0,104,100,109,97,0,0,0,0,114,97,109,98,109,111,100,0,115,114,97,109,111,110,0,0,97,0,0,0,0,0,0,0,105,109,101,0,0,0,0,0,111,100,109,97,112,111,115,0,114,97,109,98,97,110,107,0,100,109,97,100,115,116,0,0,100,109,97,115,114,99,0,0,114,111,109,98,97,110,107,0,117,110,104,97,108,116,116,0,109,105,110,105,110,116,116,0,108,111,100,109,97,117,112,0,115,101,114,105,97,108,116,0,115,112,0,0,0,0,0,0,116,109,97,116,105,109,101,0,108,116,105,109,97,117,112,0,108,100,105,118,117,112,0,0,104,114,97,109,0,0,0,0,115,114,97,109,0,0,0,0,118,114,97,109,0,0,0,0,104,97,108,116,0,0,0,0,114,116,99,108,108,100,0,0,114,116,99,115,0,0,0,0,114,116,99,109,0,0,0,0,115,107,105,112,0,0,0,0,114,116,99,104,0,0,0,0,114,116,99,100,108,0,0,0,114,116,99,100,104,0,0,0,114,116,99,105,110,100,120,0,114,116,99,104,97,108,116,0,114,116,99,98,97,115,101,0,99,52,109,97,115,116,114,0,110,114,52,52,0,0,0,0,108,101,110,52,118,97,108,0,108,101,110,52,99,116,114,0,108,0,0,0,0,0,0,0,112,99,0,0,0,0,0,0,99,99,0,0,0,0,0,0,6,5,4,3,2,1,0,0,0,5,4,3,2,1,0,1,0,3,2,1,0,3,2,1,0,5,4,3,2,1,0,1,64,72,72,80,0,0,0,0,0,0,242,171,97,194,217,186,136,110,221,99,40,39,251,159,53,66,214,212,80,72,87,94,35,62,61,202,113,33,55,192,198,179,251,249,8,0,141,41,163,32,219,135,98,5,93,212,14,8,254,175,32,2,215,255,7,106,85,236,131,64,11,119,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,1,0,0,0,0,0,207,0,126,255,211,0,0,248,255,255,255,255,255,255,255,225,128,191,243,255,191,255,63,0,255,191,127,255,159,255,191,255,255,0,0,191,119,243,241,255,255,255,255,255,255,255,255,255,113,114,213,145,88,187,42,250,207,60,84,117,72,207,143,217,0,128,0,0,0,0,255,252,255,255,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,43,11,100,47,175,21,96,109,97,78,172,69,15,218,146,243,131,56,228,78,167,108,56,88,190,234,229,129,180,203,191,123,89,173,80,19,94,246,179,193,220,223,158,104,215,89,38,243,98,84,248,54,183,120,106,34,167,221,136,21,202,150,57,211,230,85,110,234,144,118,184,255,80,205,181,27,31,165,77,46,180,9,71,138,196,90,140,78,231,41,80,136,168,102,133,75,170,56,231,107,69,62,48,55,186,197,49,242,113,180,207,41,188,127,126,208,199,195,189,207,89,234,57,1,46,0,105,0,187,216,196,4,205,172,161,199,125,133,21,240,173,25,17,106,186,199,118,248,92,160,103,10,123,117,86,59,101,92,77,163,0,5,215,201,27,202,17,109,56,231,19,42,177,16,114,77,167,71,19,137,124,98,95,144,100,46,211,239,171,1,21,133,232,42,110,74,31,190,73,177,230,15,147,226,182,135,93,53,216,212,74,69,202,179,51,116,24,193,22,251,143,164,142,112,205,180,74,220,230,52,50,65,249,132,106,153,236,146,241,139,93,165,9,207,58,147,188,224,21,25,228,182,154,4,59,193,150,183,86,133,106,170,30,42,128,238,231,70,118,139,13,186,36,64,66,5,14,4,32,166,94,193,151,126,68,5,1,169,207,0,124,255,68,0,0,248,255,255,255,255,255,255,255,225,128,191,243,255,191,255,63,0,255,191,127,255,159,255,191,255,255,0,0,191,119,243,241,255,255,255,255,255,255,255,255,255,0,255,0,255,0,255,0,255,0,255,0,255,0,255,0,255,0,128,0,0,0,0,0,252,0,0,0,0,255,126,255,254,255,255,255,255,255,255,62,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,255,193,0,254,255,255,255,248,255,0,0,0,143,0,0,255,255,255,255,255,255,255,255,206,237,102,102,204,13,0,11,3,115,0,131,0,12,0,13,0,8,17,31,136,137,0,14,220,204,110,230,221,221,217,153,187,187,103,99,110,14,236,204,221,220,153,159,187,185,51,62,69,236,66,250,8,183,7,93,1,245,192,255,8,252,0,229,11,248,194,202,244,249,13,127,68,109,25,254,70,151,51,94,8,255,209,255,198,139,36,116,18,252,0,159,148,183,6,213,64,122,32,158,4,95,65,47,61,119,54,117,129,138,112,58,152,209,113,2,77,1,193,255,13,0,211,5,249,0,11,0,8,1,239,222,6,74,205,189,8,1,239,222,6,74,205,189,8,1,239,222,6,74,205,189,8,1,239,222,6,74,205,189,0,144,247,127,192,177,188,251,0,144,247,127,192,177,188,251,0,144,247,127,192,177,188,251,0,144,247,127,192,177,188,251,36,19,253,58,16,16,173,69,36,19,253,58,16,16,173,69,36,19,253,58,16,16,173,69,36,19,253,58,16,16,173,69,0,0,8,0,4,0,8,0,8,0,77,0,10,0,128,0,16,0,2,0,24,0,4,0,32,0,16,0,40,0,5,0,44,0,8,0,56,0,33,0,58,0,64,0,96,0,2,0,102,0,3,0,104,0,64,0,114,0,128,0,116,0,64,0,118,0,128,0,124,0,128,0,126,0,32,0,128,0,12,0,136,0,8,0,140,0,2,0,142,0,4,0,146,0,1,0,152,0,2,0,162,0,8,0,168,0,2,0,172,0,21,0,176,0,2,0,178,0,128,0,182,0,128,0,184,0,6,0,186,0,1,0,188,0,8,0,196,0,4,0,200,0,2,0,204,0,1,0,208,0,133,0,216,0,129,0,220,0,1,0,222,0,1,0,224,0,1,0,230,0,8,0,232,0,68,0,236,0,68,0,240,0,64,0,244,0,32,0,250,0,4,0,252,0,18,0,254,0,1,0,3,1,127,0,7,1,253,0,19,1,251,0,25,1,191,0,27,1,239,0,29,1,251,0,33,1,251,0,51,1,247,0,53,1,111,0,55,1,189,0,63,1,246,0,69,1,247,0,73,1,223,0,77,1,250,0,79,1,254,0,81,1,253,0,97,1,253,0,101,1,191,0,113,1,253,0,115,1,239,0,119,1,254,0,121,1,127,0,133,1,247,0,137,1,239,0,153,1,247,0,171,1,239,0,177,1,127,0,179,1,239,0,181,1,191,0,193,1,251,0,201,1,251,0,203,1,239,0,207,1,191,0,213,1,127,0,225,1,221,0,231,1,247,0,245,1,254,0,24,2,1,0,32,2,8,0,38,2,8,0,44,2,32,0,48,2,80,0,56,2,1,0,70,2,2,0,86,2,16,0,88,2,64,0,96,2,112,0,100,2,4,0,104,2,40,0,120,2,2,0,132,2,16,0,152,2,32,0,154,2,16,0,160,2,68,0,174,2,32,0,178,2,32,0,192,2,40,0,202,2,100,0,208,2,32,0,224,2,128,0,232,2,2,0,234,2,2,0,238,2,8,0,240,2,12,0,242,2,2,0,5,3,223,0,7,3,254,0,9,3,253,0,15,3,191,0,17,3,251,0,37,3,223,0,41,3,253,0,53,3,253,0,59,3,247,0,69,3,251,0,71,3,253,0,75,3,239,0,83,3,249,0,91,3,191,0,93,3,191,0,97,3,245,0,105,3,191,0,117,3,253,0,129,3,239,0,131,3,223,0,141,3,247,0,145,3,247,0,155,3,254,0,169,3,223,0,179,3,251,0,193,3,254,0,205,3,251,0,219,3,251,0,221,3,127,0,225,3,127,0,237,3,253,0,243,3,253,0,253,3,251,0,6,4,32,0,14,4,4,0,18,4,5,0,28,4,8,0,32,4,16,0,34,4,64,0,40,4,64,0,42,4,8,0,48,4,50,0,52,4,2,0,56,4,128,0,58,4,1,0,74,4,2,0,82,4,80,0,88,4,1,0,112,4,20,0,120,4,160,0,122,4,1,0,142,4,1,0,144,4,4,0,146,4,16,0,150,4,80,0,152,4,2,0,158,4,12,0,162,4,64,0,166,4,1,0,168,4,192,0,176,4,2,0,190,4,32,0,194,4,1,0,200,4,1,0,204,4,1,0,208,4,1,0,210,4,32,0,222,4,1,0,224,4,12,0,226,4,24,0,234,4,8,0,238,4,1,0,242,4,144,0,248,4,32,0,250,4,129,0,252,4,64,0,5,5,247,0,9,5,254,0,17,5,205,0,23,5,243,0,37,5,247,0,43,5,247,0,45,5,127,0,47,5,191,0,49,5,239,0,51,5,191,0,69,5,251,0,93,5,247,0,131,5,254,0,147,5,254,0,171,5,239,0,177,5,223,0,189,5,111,0,203,5,191,0,205,5,251,0,207,5,251,0,211,5,251,0,251,5,213,0,253,5,247,0,0,6,130,0,6,6,4,0,24,6,40,0,48,6,64,0,56,6,8,0,64,6,32,0,84,6,64,0,88,6,34,0,92,6,132,0,100,6,6,0,110,6,16,0,114,6,1,0,120,6,4,0,128,6,16,0,134,6,128,0,138,6,66,0,144,6,18,0,168,6,17,0,176,6,64,0,206,6,8,0,216,6,16,0,220,6,129,0,226,6,6,0,240,6,4,0,19,7,249,0,21,7,191,0,27,7,223,0,29,7,253,0,37,7,253,0,69,7,239,0,73,7,250,0,83,7,191,0,91,7,191,0,95,7,253,0,99,7,223,0,113,7,223,0,143,7,247,0,153,7,253,0,165,7,239,0,211,7,127,0,221,7,191,0,227,7,253,0,229,7,246,0,235,7,253,0,251,7,191,0,3,8,191,0,15,8,237,0,17,8,191,0,19,8,247,0,27,8,127,0,39,8,250,0,41,8,127,0,47,8,239,0,51,8,239,0,63,8,239,0,65,8,223,0,67,8,254,0,77,8,251,0,119,8,191,0,127,8,251,0,141,8,254,0,143,8,127,0,159,8,239,0,165,8,191,0,169,8,239,0,171,8,253,0,177,8,239,0,181,8,239,0,191,8,223,0,199,8,223,0,207,8,251,0,221,8,254,0,223,8,247,0,227,8,90,0,231,8,191,0,235,8,251,0,237,8,249,0,239,8,251,0,247,8,159,0,255,8,223,0,20,9,148,0,22,9,17,0,24,9,33,0,28,9,1,0,34,9,64,0,38,9,8,0,44,9,4,0,52,9,16,0,56,9,2,0,58,9,8,0,106,9,2,0,134,9,16,0,136,9,32,0,162,9,3,0,170,9,2,0,178,9,8,0,184,9,8,0,190,9,16,0,194,9,2,0,202,9,64,0,212,9,64,0,226,9,1,0,232,9,16,0,236,9,64,0,1,10,239,0,7,10,111,0,23,10,215,0,39,10,254,0,45,10,251,0,47,10,191,0,51,10,239,0,55,10,254,0,95,10,250,0,103,10,251,0,141,10,223,0,143,10,253,0,145,10,239,0,151,10,253,0,159,10,252,0,167,10,239,0,173,10,239,0,177,10,191,0,191,10,127,0,217,10,223,0,247,10,254,0,255,10,190,0,20,11,16,0,36,11,8,0,44,11,2,0,68,11,8,0,70,11,1,0,78,11,128,0,82,11,16,0,84,11,128,0,106,11,4,0,114,11,8,0,136,11,32,0,182,11,32,0,194,11,4,0,206,11,16,0,216,11,8,0,236,11,64,0,15,12,254,0,17,12,191,0,23,12,183,0,25,12,127,0,35,12,251,0,39,12,254,0,45,12,223,0,47,12,187,0,55,12,239,0,63,12,189,0,73,12,253,0,79,12,247,0,95,12,191,0,97,12,223,0,103,12,55,0,107,12,223,0,115,12,247,0,125,12,127,0,135,12,220,0,137,12,223,0,139,12,253,0,145,12,239,0,163,12,251,0,165,12,251,0,183,12,246,0,191,12,63,0,197,12,251,0,199,12,127,0,209,12,127,0,213,12,127,0,215,12,239,0,217,12,127,0,229,12,191,0,245,12,127,0,251,12,127,0,255,12,254,0,2,13,1,0,10,13,17,0,12,13,128,0,14,13,8,0,18,13,64,0,22,13,11,0,30,13,8,0,34,13,1,0,38,13,4,0,40,13,4,0,42,13,1,0,46,13,2,0,50,13,16,0,68,13,17,0,78,13,4,0,82,13,128,0,90,13,64,0,94,13,4,0,114,13,1,0,118,13,2,0,122,13,4,0,124,13,128,0,130,13,128,0,132,13,4,0,144,13,4,0,160,13,1,0,164,13,2,0,176,13,4,0,180,13,4,0,182,13,16,0,188,13,8,0,194,13,8,0,208,13,40,0,210,13,16,0,214,13,16,0,226,13,8,0,23,14,254,0,25,14,223,0,43,14,239,0,47,14,253,0,55,14,243,0,57,14,223,0,63,14,223,0,79,14,254,0,83,14,251,0,91,14,239,0,93,14,247,0,95,14,253,0,113,14,251,0,119,14,253,0,123,14,251,0,127,14,253,0,133,14,127,0,139,14,253,0,155,14,123,0,167,14,254,0,187,14,251,0,215,14,119,0,225,14,223,0,227,14,247,0,239,14,254,0,251,14,254,0,255,14,247,0,2,15,16,0,6,15,32,0,10,15,2,0,28,15,16,0,50,15,8,0,84,15,16,0,132,15,16,0,146,15,64,0,166,15,8,0,170,15,2,0,182,15,64,0,206,15,10,0,210,15,16,0,212,15,16,0,224,15,4,0,240,15,4,0,0,16,128,0,4,16,8,0,8,16,9,0,16,16,2,0,18,16,32,0,32,16,5,0,36,16,1,0,38,16,16,0,42,16,2,0,50,16,64,0,52,16,8,0,54,16,3,0,56,16,1,0,62,16,64,0,64,16,64,0,66,16,18,0,70,16,2,0,80,16,34,0,86,16,128,0,88,16,16,0,94,16,64,0,102,16,4,0,104,16,2,0,108,16,96,0,112,16,128,0,118,16,64,0,120,16,102,0,124,16,2,0,128,16,64,0,136,16,1,0,138,16,128,0,142,16,16,0,144,16,49,0,146,16,32,0,152,16,17,0,154,16,128,0,160,16,5,0,164,16,1,0,166,16,129,0,168,16,1,0,170,16,1,0,176,16,64,0,180,16,64,0,182,16,32,0,184,16,3,0,188,16,136,0,190,16,2,0,192,16,48,0,196,16,66,0,198,16,16,0,200,16,1,0,212,16,64,0,216,16,128,0,222,16,16,0,224,16,16,0,226,16,16,0,228,16,1,0,232,16,38,0,238,16,16,0,240,16,128,0,246,16,64,0,248,16,1,0,250,16,32,0,252,16,4,0,254,16,128,0,1,17,253,0,19,17,127,0,21,17,239,0,23,17,251,0,33,17,127,0,57,17,247,0,65,17,253,0,83,17,253,0,89,17,245,0,95,17,127,0,109,17,247,0,113,17,126,0,121,17,223,0,123,17,251,0,127,17,223,0,137,17,127,0,149,17,223,0,157,17,223,0,159,17,215,0,167,17,249,0,171,17,175,0,173,17,191,0,185,17,223,0,187,17,191,0,197,17,249,0,207,17,127,0,213,17,127,0,223,17,239,0,225,17,254,0,231,17,223,0,233,17,247,0,237,17,251,0,8,18,1,0,24,18,22,0,48,18,4,0,66,18,12,0,70,18,128,0,96,18,1,0,118,18,16,0,120,18,16,0,128,18,4,0,132,18,68,0,134,18,1,0,138,18,2,0,144,18,128,0,160,18,2,0,168,18,80,0,176,18,8,0,178,18,64,0,180,18,16,0,182,18,2,0,184,18,4,0,192,18,4,0,204,18,32,0,208,18,66,0,216,18,16,0,218,18,16,0,228,18,8,0,240,18,64,0,242,18,64,0,248,18,66,0,252,18,128,0,254,18,64,0,1,19,253,0,7,19,127,0,9,19,63,0,37,19,223,0,47,19,251,0,77,19,127,0,81,19,219,0,83,19,231,0,87,19,239,0,99,19,247,0,109,19,247,0,111,19,247,0,137,19,127,0,139,19,254,0,141,19,127,0,155,19,235,0,161,19,239,0,187,19,239,0,199,19,127,0,213,19,247,0,235,19,253,0,245,19,223,0,247,19,254,0,0,20,17,0,8,20,144,0,14,20,32,0,20,20,16,0,22,20,1,0,24,20,16,0,32,20,32,0,40,20,12,0,44,20,17,0,48,20,1,0,52,20,32,0,56,20,16,0,58,20,2,0,62,20,16,0,64,20,161,0,74,20,32,0,76,20,128,0,80,20,18,0,82,20,128,0,88,20,128,0,90,20,65,0,92,20,2,0,96,20,18,0,102,20,130,0,104,20,24,0,112,20,8,0,114,20,36,0,124,20,32,0,126,20,129,0,132,20,16,0,136,20,4,0,144,20,4,0,146,20,8,0,152,20,96,0,156,20,2,0,160,20,128,0,162,20,81,0,168,20,4,0,172,20,2,0,176,20,1,0,184,20,16,0,186,20,128,0,190,20,20,0,192,20,2,0,196,20,128,0,200,20,140,0,202,20,12,0,210,20,128,0,216,20,8,0,220,20,128,0,232,20,144,0,234,20,9,0,240,20,4,0,244,20,4,0,248,20,68,0,250,20,2,0,252,20,64,0,254,20,8,0,5,21,254,0,13,21,247,0,19,21,223,0,27,21,239,0,31,21,223,0,39,21,127,0,43,21,187,0,45,21,254,0,47,21,253,0,49,21,223,0,57,21,191,0,59,21,254,0,65,21,223,0,71,21,191,0,75,21,127,0,107,21,127,0,125,21,191,0,133,21,254,0,135,21,239,0,145,21,223,0,147,21,239,0,151,21,251,0,153,21,247,0,155,21,191,0,163,21,213,0,165,21,191,0,179,21,235,0,181,21,254,0,195,21,247,0,197,21,239,0,201,21,253,0,209,21,254,0,215,21,254,0,217,21,239,0,221,21,251,0,225,21,123,0,227,21,191,0,233,21,253,0,245,21,127,0,251,21,239,0,0,22,32,0,10,22,16,0,30,22,4,0,32,22,2,0,48,22,4,0,54,22,64,0,64,22,44,0,70,22,32,0,84,22,32,0,86,22,24,0,88,22,74,0,90,22,32,0,92,22,128,0,100,22,8,0,104,22,2,0,112,22,72,0,122,22,32,0,128,22,16,0,130,22,8,0,132,22,64,0,140,22,1,0,152,22,33,0,158,22,64,0,160,22,3,0,162,22,64,0,164,22,1,0,166,22,1,0,182,22,16,0,184,22,128,0,186,22,2,0,188,22,1,0,208,22,4,0,210,22,2,0,216,22,129,0,232,22,3,0,238,22,128,0,248,22,164,0,3,23,254,0,43,23,239,0,45,23,191,0,59,23,223,0,69,23,61,0,73,23,251,0,75,23,223,0,83,23,223,0,89,23,253,0,99,23,239,0,101,23,191,0,117,23,191,0,125,23,223,0,129,23,254,0,137,23,239,0,139,23,254,0,145,23,239,0,147,23,223,0,149,23,239,0,155,23,254,0,167,23,251,0,173,23,254,0,179,23,251,0,181,23,250,0,185,23,251,0,195,23,251,0,219,23,251,0,235,23,191,0,243,23,251,0,3,24,189,0,19,24,191,0,27,24,126,0,39,24,253,0,51,24,254,0,55,24,219,0,57,24,247,0,69,24,223,0,75,24,253,0,83,24,223,0,103,24,253,0,111,24,247,0,121,24,223,0,125,24,239,0,137,24,251,0,143,24,159,0,147,24,223,0,151,24,253,0,155,24,127,0,169,24,253,0,175,24,251,0,181,24,191,0,183,24,47,0,189,24,254,0,191,24,251,0,205,24,191,0,211,24,245,0,213,24,127,0,215,24,253,0,225,24,253,0,227,24,239,0,229,24,127,0,235,24,254,0,239,24,223,0,243,24,239,0,247,24,239,0,251,24,123,0,253,24,223,0,255,24,223,0,10,25,64,0,16,25,32,0,22,25,4,0,32,25,1,0,36,25,2,0,38,25,2,0,54,25,64,0,70,25,4,0,90,25,16,0,92,25,64,0,104,25,32,0,124,25,8,0,136,25,8,0,148,25,32,0,150,25,32,0,154,25,18,0,186,25,8,0,196,25,1,0,204,25,4,0,212,25,4,0,218,25,128,0,220,25,64,0,226,25,2,0,238,25,128,0,244,25,2,0,246,25,144,0,252,25,2,0,254,25,26,0,17,26,223,0,31,26,238,0,37,26,251,0,39,26,247,0,45,26,245,0,47,26,250,0,59,26,239,0,63,26,251,0,75,26,223,0,111,26,251,0,119,26,247,0,129,26,231,0,143,26,231,0,147,26,223,0,159,26,223,0,173,26,239,0,199,26,247,0,213,26,254,0,223,26,251,0,227,26,191,0,237,26,247,0,241,26,254,0,249,26,253,0,26,27,2,0,38,27,16,0,108,27,2,0,132,27,4,0,136,27,64,0,160,27,8,0,174,27,8,0,188,27,2,0,244,27,4,0,7,28,223,0,11,28,127,0,15,28,223,0,19,28,191,0,27,28,251,0,31,28,239,0,39,28,189,0,47,28,119,0,61,28,239,0,63,28,247,0,65,28,247,0,67,28,254,0,69,28,223,0,71,28,254,0,79,28,239,0,83,28,243,0,93,28,223,0,95,28,187,0,97,28,251,0,103,28,254,0,105,28,253,0,107,28,254,0,115,28,251,0,123,28,254,0,125,28,239,0,131,28,239,0,135,28,63,0,139,28,239,0,143,28,217,0,151,28,239,0,155,28,239,0,159,28,247,0,163,28,253,0,167,28,191,0,169,28,247,0,171,28,251,0,173,28,253,0,177,28,127,0,179,28,187,0,185,28,253,0,187,28,251,0,199,28,246,0,207,28,191,0,211,28,235,0,225,28,191,0,241,28,253,0,245,28,127,0])
.concat([247,28,239,0,253,28,223,0,255,28,253,0,2,29,4,0,6,29,64,0,8,29,146,0,16,29,4,0,26,29,2,0,28,29,8,0,36,29,8,0,48,29,1,0,52,29,4,0,58,29,34,0,62,29,4,0,86,29,16,0,90,29,2,0,126,29,64,0,142,29,1,0,144,29,32,0,154,29,16,0,160,29,4,0,164,29,2,0,172,29,33,0,190,29,32,0,194,29,32,0,214,29,64,0,216,29,8,0,242,29,1,0,254,29,128,0,1,30,239,0,5,30,239,0,29,30,223,0,39,30,221,0,47,30,127,0,51,30,245,0,55,30,251,0,63,30,247,0,75,30,223,0,95,30,127,0,113,30,235,0,127,30,191,0,143,30,223,0,151,30,191,0,155,30,239,0,159,30,247,0,167,30,253,0,179,30,251,0,183,30,127,0,197,30,127,0,223,30,127,0,233,30,247,0,243,30,253,0,2,31,16,0,4,31,5,0,32,31,4,0,36,31,16,0,58,31,128,0,68,31,4,0,70,31,4,0,78,31,64,0,80,31,1,0,84,31,3,0,96,31,3,0,114,31,1,0,118,31,4,0,122,31,2,0,134,31,128,0,140,31,2,0,162,31,64,0,182,31,128,0,198,31,16,0,204,31,32,0,210,31,32,0,216,31,4,0,220,31,16,0,222,31,4,0,131,0,127,0,139,0,16,0,192,0,127,0,225,0,127,0,226,0,127,0,234,0,16,0,10,1,64,0,121,1,1,0,175,1,1,0,1,2,251,0,84,2,247,0,100,2,127,0,209,2,191,0,210,2,251,0,1,3,247,0,19,3,247,0,21,3,127,0,37,3,127,0,57,3,4,0,84,3,127,0,117,3,253,0,145,3,251,0,172,3,64,0,197,3,251,0,251,3,32,0,18,4,247,0,34,4,247,0,177,4,251,0,181,4,127,0,198,4,127,0,208,4,251,0,210,4,223,0,4,5,127,0,28,5,1,0,35,5,253,0,50,5,247,0,53,5,247,0,6,6,127,0,144,6,247,0,151,6,251,0,152,6,2,0,181,6,127,0,228,6,127,0,241,6,223,0,249,6,4,0,48,7,253,0,131,7,251,0,181,7,127,0,182,7,247,0,14,8,247,0,28,8,247,0,73,8,191,0,89,8,247,0,94,8,127,0,95,8,127,0,105,8,127,0,109,8,127,0,110,8,127,0,121,8,191,0,124,8,251,0,137,8,187,0,154,8,247,0,157,8,215,0,158,8,159,0,169,8,127,0,170,8,251,0,172,8,127,0,175,8,247,0,187,8,223,0,216,8,251,0,219,8,127,0,220,8,191,0,232,8,247,0,251,8,125,0,252,8,127,0,253,8,253,0,10,9,251,0,28,9,247,0,30,9,223,0,41,9,247,0,43,9,247,0,44,9,247,0,45,9,251,0,75,9,247,0,77,9,127,0,91,9,123,0,105,9,247,0,124,9,127,0,126,9,247,0,220,9,95,0,235,9,253,0,238,9,223,0,239,9,127,0,251,9,191,0,254,9,247,0,10,10,247,0,14,10,191,0,15,10,127,0,26,10,191,0,28,10,63,0,42,10,253,0,46,10,247,0,60,10,223,0,62,10,247,0,75,10,251,0,79,10,223,0,92,10,247,0,110,10,247,0,126,10,183,0,127,10,247,0,129,10,1,0,141,10,223,0,159,10,127,0,171,10,253,0,172,10,251,0,190,10,191,0,201,10,251,0,207,10,247,0,220,10,245,0,221,10,191,0,234,10,123,0,235,10,127,0,248,10,251,0,251,10,223,0,13,11,127,0,46,11,253,0,57,11,247,0,72,11,191,0,93,11,127,0,107,11,127,0,109,11,251,0,118,11,16,0,139,11,127,0,140,11,245,0,141,11,223,0,159,11,191,0,185,11,223,0,191,11,127,0,206,11,247,0,223,11,127,0,233,11,127,0,238,11,247,0,249,11,127,0,254,11,183,0,9,12,253,0,12,12,253,0,13,12,253,0,15,12,251,0,24,12,219,0,26,12,247,0,27,12,191,0,30,12,247,0,41,12,127,0,45,12,253,0,63,12,119,0,91,12,247,0,94,12,191,0,107,12,127,0,120,12,127,0,121,12,247,0,125,12,247,0,143,12,119,0,154,12,247,0,187,12,219,0,188,12,249,0,206,12,127,0,216,12,223,0,248,12,127,0,254,12,251,0,255,12,127,0,9,13,219,0,28,13,223,0,31,13,247,0,41,13,127,0,46,13,123,0,57,13,119,0,58,13,251,0,59,13,127,0,60,13,223,0,62,13,251,0,89,13,127,0,94,13,223,0,110,13,253,0,120,13,247,0,121,13,251,0,122,13,127,0,139,13,251,0,143,13,191,0,155,13,247,0,186,13,191,0,191,13,215,0,201,13,127,0,202,13,247,0,216,13,251,0,217,13,251,0,218,13,253,0,219,13,247,0,221,13,247,0,222,13,247,0,251,13,251,0,253,13,127,0,8,14,251,0,9,14,251,0,24,14,251,0,41,14,183,0,43,14,251,0,61,14,247,0,67,14,32,0,72,14,247,0,77,14,247,0,95,14,247,0,105,14,127,0,107,14,251,0,126,14,123,0,137,14,127,0,139,14,251,0,141,14,247,0,153,14,191,0,155,14,247,0,157,14,247,0,159,14,247,0,171,14,223,0,175,14,247,0,185,14,223,0,189,14,127,0,190,14,251,0,203,14,223,0,206,14,247,0,207,14,127,0,223,14,223,0,235,14,253,0,248,14,215,0,252,14,119,0,253,14,223,0,255,14,127,0,8,15,247,0,13,15,223,0,30,15,127,0,44,15,223,0,45,15,247,0,46,15,251,0,47,15,127,0,56,15,251,0,59,15,223,0,67,15,16,0,75,15,87,0,76,15,127,0,95,15,215,0,120,15,191,0,143,15,187,0,159,15,247,0,171,15,253,0,175,15,247,0,184,15,251,0,190,15,127,0,217,15,179,0,221,15,251,0,223,15,127,0,242,15,247,0,252,15,247,0,176,16,247,0,224,16,253,0,43,17,64,0,80,17,223,0,132,17,191,0,136,17,1,0,193,17,127,0,228,17,127,0,241,17,127,0,17,18,247,0,20,18,253,0,21,18,247,0,68,18,251,0,91,18,32,0,108,18,4,0,114,18,253,0,193,18,223,0,219,18,16,0,240,18,127,0,100,19,247,0,242,19,251,0,19,20,223,0,48,20,247,0,54,20,247,0,80,20,127,0,112,20,247,0,114,20,127,0,180,20,223,0,182,20,251,0,22,21,247,0,27,21,1,0,101,21,127,0,151,21,191,0,166,21,127,0,176,21,127,0,197,21,191,0,213,21,251,0,242,21,253,0,252,21,4,0,26,22,16,0,137,22,32,0,167,22,251,0,10,23,2,0,50,23,253,0,68,23,127,0,89,23,1,0,97,23,247,0,116,23,247,0,149,23,253,0,155,23,16,0,196,23,247,0,8,24,223,0,11,24,223,0,15,24,119,0,29,24,127,0,31,24,247,0,44,24,127,0,63,24,127,0,74,24,127,0,77,24,127,0,78,24,247,0,89,24,127,0,95,24,127,0,100,24,1,0,104,24,63,0,110,24,159,0,111,24,247,0,122,24,251,0,143,24,191,0,157,24,127,0,158,24,251,0,170,24,223,0,190,24,127,0,207,24,127,0,219,24,119,0,220,24,223,0,232,24,119,0,233,24,127,0,251,24,247,0,254,24,247,0,30,25,127,0,31,25,127,0,41,25,191,0,45,25,223,0,76,25,251,0,78,25,223,0,91,25,127,0,104,25,191,0,106,25,247,0,127,25,247,0,139,25,127,0,142,25,127,0,155,25,251,0,168,25,223,0,170,25,183,0,171,25,119,0,173,25,253,0,184,25,191,0,190,25,253,0,191,25,223,0,220,25,127,0,223,25,125,0,234,25,223,0,236,25,223,0,239,25,127,0,251,25,251,0,252,25,247,0,253,25,191,0,255,25,254,0,8,26,223,0,11,26,247,0,13,26,127,0,15,26,127,0,26,26,191,0,29,26,191,0,31,26,127,0,41,26,253,0,42,26,253,0,47,26,247,0,62,26,127,0,73,26,253,0,74,26,187,0,76,26,247,0,79,26,127,0,104,26,247,0,109,26,191,0,120,26,191,0,125,26,127,0,126,26,247,0,155,26,247,0,156,26,191,0,157,26,247,0,159,26,127,0,170,26,127,0,191,26,191,0,202,26,191,0,207,26,247,0,218,26,247,0,234,26,253,0,255,26,253,0,11,27,247,0,25,27,127,0,29,27,247,0,30,27,247,0,41,27,223,0,59,27,251,0,60,27,247,0,77,27,251,0,79,27,247,0,109,27,127,0,110,27,247,0,120,27,247,0,155,27,127,0,158,27,223,0,159,27,127,0,171,27,191,0,175,27,253,0,184,27,251,0,186,27,247,0,191,27,247,0,205,27,223,0,218,27,223,0,222,27,119,0,248,27,191,0,252,27,253,0,253,27,251,0,254,27,247,0,12,28,247,0,14,28,127,0,26,28,127,0,28,28,251,0,46,28,251,0,62,28,253,0,77,28,127,0,79,28,247,0,95,28,127,0,106,28,253,0,110,28,251,0,137,28,251,0,139,28,253,0,142,28,253,0,154,28,251,0,156,28,127,0,168,28,191,0,169,28,191,0,174,28,191,0,185,28,247,0,186,28,127,0,189,28,223,0,207,28,247,0,12,29,251,0,15,29,127,0,24,29,191,0,31,29,247,0,40,29,223,0,41,29,247,0,47,29,247,0,72,29,215,0,74,29,247,0,89,29,247,0,99,29,64,0,106,29,247,0,108,29,191,0,110,29,247,0,125,29,191,0,142,29,183,0,155,29,251,0,158,29,253,0,173,29,127,0,175,29,127,0,200,29,247,0,202,29,191,0,207,29,251,0,219,29,247,0,222,29,191,0,233,29,191,0,15,30,253,0,27,30,253,0,43,30,223,0,45,30,127,0,57,30,251,0,58,30,4,0,61,30,223,0,72,30,95,0,77,30,127,0,94,30,127,0,107,30,127,0,111,30,63,0,123,30,251,0,126,30,247,0,137,30,127,0,140,30,123,0,143,30,247,0,153,30,247,0,156,30,247,0,159,30,251,0,168,30,253,0,172,30,127,0,173,30,247,0,191,30,247,0,207,30,127,0,220,30,223,0,221,30,253,0,222,30,119,0,223,30,247,0,238,30,245,0,239,30,247,0,251,30,243,0,8,31,127,0,9,31,247,0,12,31,127,0,25,31,251,0,30,31,253,0,42,31,2,0,56,31,247,0,75,31,223,0,79,31,191,0,92,31,253,0,93,31,223,0,95,31,127,0,120,31,251,0,122,31,1,0,133,31,1,0,136,31,127,0,137,31,223,0,139,31,247,0,158,31,253,0,159,31,127,0,168,31,251,0,172,31,223,0,174,31,247,0,175,31,223,0,187,31,191,0,190,31,251,0,203,31,127,0,206,31,127,0,217,31,247,0,222,31,251,0,223,31,127,0,235,31,127,0,248,31,127,0,251,31,223,0,252,31,127,0,253,31,127,0,254,31,247,0,8,32,28,0,11,32,3,0,64,40,255,0,65,40,127,0,66,40,255,0,67,40,127,0,68,40,255,0,69,40,127,0,70,40,255,0,71,40,127,0,72,40,255,0,73,40,127,0,74,40,255,0,75,40,127,0,76,40,255,0,77,40,127,0,78,40,255,0,79,40,127,0,80,40,255,0,81,40,127,0,82,40,255,0,83,40,127,0,84,40,255,0,85,40,127,0,86,40,255,0,87,40,127,0,88,40,255,0,89,40,127,0,90,40,255,0,91,40,127,0,92,40,255,0,93,40,127,0,94,40,255,0,95,40,127,0,96,40,255,0,97,40,127,0,98,40,255,0,99,40,127,0,100,40,255,0,101,40,127,0,102,40,255,0,103,40,127,0,104,40,255,0,105,40,127,0,106,40,255,0,107,40,127,0,108,40,255,0,109,40,127,0,110,40,255,0,111,40,127,0,112,40,255,0,113,40,127,0,114,40,255,0,115,40,127,0,116,40,255,0,117,40,127,0,118,40,255,0,119,40,127,0,120,40,255,0,121,40,127,0,122,40,255,0,123,40,127,0,124,40,255,0,125,40,127,0,126,40,255,0,127,40,127,0,0,41,128,0,1,41,128,0,2,41,64,0,3,41,136,0,4,41,136,0,5,41,104,0,6,41,222,0,7,41,222,0,8,41,112,0,9,41,222,0,10,41,222,0,11,41,120,0,12,41,32,0,13,41,32,0,14,41,56,0,15,41,32,0,16,41,32,0,17,41,144,0,18,41,32,0,19,41,32,0,20,41,160,0,21,41,224,0,22,41,224,0,23,41,192,0,24,41,152,0,25,41,152,0,26,41,72,0,27,41,128,0,28,41,128,0,29,41,80,0,30,41,30,0,31,41,30,0,32,41,88,0,33,41,32,0,34,41,32,0,35,41,224,0,36,41,136,0,37,41,136,0,38,41,16,0,39,41,32,0,40,41,32,0,41,41,16,0,42,41,32,0,43,41,32,0,44,41,24,0,45,41,224,0,46,41,224,0,48,41,24,0,49,41,24,0,50,41,32,0,51,41,168,0,52,41,168,0,53,41,32,0,54,41,24,0,55,41,24,0,57,41,32,0,58,41,32,0,59,41,216,0,60,41,200,0,61,41,200,0,62,41,224,0,65,41,64,0,66,41,40,0,67,41,40,0,68,41,40,0,69,41,24,0,70,41,24,0,71,41,96,0,72,41,32,0,73,41,32,0,74,41,224,0,77,41,8,0,78,41,224,0,79,41,224,0,80,41,48,0,81,41,208,0,82,41,208,0,83,41,208,0,84,41,32,0,85,41,32,0,86,41,232,0,87,41,255,0,88,41,255,0,89,41,191,0,0,42,255,0,1,42,127,0,2,42,223,0,3,42,1,0,4,42,18,0,5,42,1,0,8,42,255,0,9,42,127,0,10,42,223,0,11,42,1,0,12,42,18,0,13,42,1,0,16,42,255,0,17,42,127,0,18,42,181,0,19,42,66,0,20,42,200,0,21,42,61,0,24,42,31,0,25,42,35,0,26,42,95,0,27,42,3,0,28,42,242,0,30,42,9,0,32,42,31,0,33,42,35,0,34,42,95,0,35,42,3,0,36,42,242,0,38,42,9,0,40,42,255,0,41,42,79,0,42,42,210,0,43,42,126,0,44,42,76,0,45,42,58,0,46,42,224,0,47,42,28,0,48,42,255,0,49,42,127,0,50,42,255,0,51,42,127,0,52,42,140,0,53,42,126,0,55,42,124,0,56,42,255,0,57,42,127,0,58,42,255,0,59,42,127,0,60,42,140,0,61,42,126,0,63,42,124,0,64,42,237,0,65,42,3,0,66,42,255,0,67,42,127,0,68,42,95,0,69,42,37,0,72,42,255,0,73,42,127,0,74,42,255,0,75,42,127,0,76,42,140,0,77,42,126,0,79,42,124,0,80,42,255,0,81,42,127,0,82,42,255,0,83,42,127,0,84,42,140,0,85,42,126,0,87,42,124,0,88,42,106,0,89,42,3,0,90,42,31,0,91,42,2,0,92,42,255,0,93,42,3,0,94,42,255,0,95,42,127,0,96,42,255,0,97,42,127,0,98,42,31,0,99,42,66,0,100,42,242,0,101,42,28,0,104,42,255,0,105,42,127,0,106,42,31,0,107,42,66,0,108,42,242,0,109,42,28,0,112,42,255,0,113,42,127,0,114,42,239,0,115,42,3,0,116,42,214,0,117,42,1,0,120,42,255,0,121,42,127,0,122,42,31,0,123,42,66,0,124,42,242,0,125,42,28,0,128,42,255,0,129,42,127,0,130,42,31,0,131,42,66,0,132,42,242,0,133,42,28,0,136,42,255,0,137,42,127,0,138,42,234,0,139,42,3,0,140,42,31,0,141,42,1,0,144,42,255,0,145,42,127,0,146,42,31,0,147,42,66,0,148,42,242,0,149,42,28,0,152,42,255,0,153,42,127,0,154,42,31,0,155,42,66,0,156,42,242,0,157,42,28,0,160,42,255,0,161,42,127,0,162,42,127,0,163,42,2,0,164,42,31,0,168,42,255,0,169,42,127,0,170,42,140,0,171,42,126,0,173,42,124,0,176,42,255,0,177,42,127,0,178,42,140,0,179,42,126,0,181,42,124,0,184,42,255,0,185,42,127,0,186,42,255,0,187,42,3,0,188,42,31,0,192,42,159,0,193,42,41,0,194,42,26,0,196,42,12,0,200,42,159,0,201,42,41,0,202,42,26,0,204,42,12,0,208,42,116,0,209,42,126,0,210,42,255,0,211,42,3,0,212,42,128,0,213,42,1,0,216,42,255,0,217,42,127,0,218,42,223,0,219,42,1,0,220,42,18,0,221,42,1,0,224,42,255,0,225,42,127,0,226,42,223,0,227,42,1,0,228,42,18,0,229,42,1,0,232,42,255,0,233,42,103,0,234,42,172,0,235,42,119,0,236,42,19,0,237,42,26,0,238,42,107,0,239,42,45,0,242,42,255,0,243,42,127,0,244,42,31,0,245,42,66,0,246,42,242,0,247,42,28,0,250,42,255,0,251,42,127,0,252,42,31,0,253,42,66,0,254,42,242,0,255,42,28,0,0,43,214,0,1,43,126,0,2,43,255,0,3,43,75,0,4,43,117,0,5,43,33,0,8,43,255,0,9,43,127,0,10,43,31,0,11,43,66,0,12,43,242,0,13,43,28,0,16,43,255,0,17,43,127,0,18,43,31,0,19,43,66,0,20,43,242,0,21,43,28,0,24,43,255,0,25,43,127,0,26,43,140,0,27,43,126,0,29,43,124,0,32,43,31,0,33,43,35,0,34,43,95,0,35,43,3,0,36,43,242,0,38,43,9,0,40,43,31,0,41,43,35,0,42,43,95,0,43,43,3,0,44,43,242,0,46,43,9,0,48,43,255,0,49,43,127,0,50,43,49,0,51,43,110,0,52,43,74,0,53,43,69,0,56,43,255,0,57,43,127,0,58,43,31,0,59,43,66,0,60,43,242,0,61,43,28,0,64,43,255,0,65,43,127,0,66,43,31,0,67,43,66,0,68,43,242,0,69,43,28,0,72,43,255,0,73,43,127,0,74,43,49,0,75,43,110,0,76,43,74,0,77,43,69,0,80,43,255,0,81,43,127,0,82,43,31,0,83,43,66,0,84,43,242,0,85,43,28,0,88,43,255,0,89,43,127,0,90,43,31,0,91,43,66,0,92,43,242,0,93,43,28,0,96,43,255,0,97,43,127,0,98,43,239,0,99,43,27,0,101,43,2,0,104,43,255,0,105,43,127,0,106,43,140,0,107,43,126,0,109,43,124,0,112,43,255,0,113,43,127,0,114,43,140,0,115,43,126,0,117,43,124,0,120,43,255,0,121,43,127,0,122,43,191,0,123,43,50,0,124,43,208,0,128,43,255,0,129,43,127,0,130,43,239,0,131,43,27,0,133,43,2,0,136,43,255,0,137,43,127,0,138,43,239,0,139,43,27,0,141,43,2,0,144,43,255,0,145,43,127,0,146,43,31,0,147,43,66,0,148,43,242,0,149,43,28,0,152,43,255,0,153,43,127,0,154,43,224,0,155,43,3,0,156,43,6,0,157,43,2,0,158,43,32,0,159,43,1,0,160,43,255,0,161,43,127,0,162,43,224,0,163,43,3,0,164,43,6,0,165,43,2,0,166,43,32,0,167,43,1,0,168,43,255,0,169,43,127,0,170,43,31,0,171,43,66,0,172,43,242,0,173,43,28,0,176,43,255,0,177,43,127,0,178,43,239,0,179,43,27,0,181,43,2,0,184,43,255,0,185,43,127,0,186,43,239,0,187,43,27,0,189,43,2,0,192,43,255,0,193,43,127,0,194,43,191,0,195,43,50,0,196,43,208,0,200,43,255,0,201,43,127,0,202,43,31,0,203,43,66,0,204,43,242,0,205,43,28,0,208,43,255,0,209,43,127,0,210,43,31,0,211,43,66,0,212,43,242,0,213,43,28,0,219,43,66,0,220,43,127,0,221,43,3,0,222,43,255,0,223,43,127,0,224,43,255,0,225,43,3,0,226,43,31,0,228,43,12,0,232,43,255,0,233,43,3,0,234,43,31,0,236,43,12,0,240,43,255,0,241,43,127,0,242,43,140,0,243,43,126,0,245,43,124,0,248,43,255,0,249,43,127,0,250,43,191,0,251,43,50,0,252,43,208,0,0,44,255,0,1,44,127,0,2,44,191,0,3,44,50,0,4,44,208,0,8,44,255,0,9,44,127,0,10,44,181,0,11,44,66,0,12,44,200,0,13,44,61,0,16,44,255,0,17,44,127,0,18,44,148,0,19,44,82,0,20,44,74,0,21,44,41,0,24,44,255,0,25,44,127,0,26,44,148,0,27,44,82,0,28,44,74,0,29,44,41,0,32,44,255,0,33,44,127,0,34,44,148,0,35,44,82,0,36,44,74,0,37,44,41,0,40,44,255,0,41,44,127,0,42,44,239,0,43,44,27,0,45,44,2,0,48,44,255,0,49,44,127,0,50,44,239,0,51,44,27,0,53,44,2,0,56,44,255,0,57,44,83,0,58,44,95,0,59,44,74,0,60,44,82,0,61,44,126,0,64,44,255,0,65,44,127,0,66,44,31,0,67,44,66,0,68,44,242,0,69,44,28,0,72,44,255,0,73,44,127,0,74,44,31,0,75,44,66,0,76,44,242,0,77,44,28,0,80,44,255,0,81,44,127,0,82,44,140,0,83,44,126,0,85,44,124,0,88,44,255,0,89,44,127,0,90,44,191,0,91,44,50,0,92,44,208,0,96,44,255,0,97,44,127,0,98,44,191,0,99,44,50,0,100,44,208,0,104,44,159,0,105,44,99,0,106,44,121,0,107,44,66,0,108,44,176,0,109,44,21,0,110,44,203,0,111,44,4,0,112,44,255,0,113,44,127,0,114,44,140,0,115,44,126,0,117,44,124,0,120,44,255,0,121,44,127,0,122,44,140,0,123,44,126,0,125,44,124,0,128,44,255,0,129,44,127,0,130,44,255,0,131,44,3,0,132,44,47,0,133,44,1,0,136,44,255,0,137,44,127,0,138,44,63,0,139,44,3,0,140,44,147,0,141,44,1,0,144,44,255,0,145,44,127,0,146,44,63,0,147,44,3,0,148,44,147,0,149,44,1,0,152,44,255,0,153,44,127,0,154,44,63,0,155,44,3,0,156,44,147,0,157,44,1,0,160,44,255,0,161,44,127,0,162,44,31,0,163,44,66,0,164,44,242,0,165,44,28,0,168,44,255,0,169,44,127,0,170,44,31,0,171,44,66,0,172,44,242,0,173,44,28,0,176,44,255,0,177,44,127,0,178,44,239,0,179,44,27,0,180,44,128,0,181,44,97,0,184,44,32,0,185,44,33,0,186,44,34,0,187,44,128,0,188,44,129,0,189,44,130,0,190,44,16,0,191,44,17,0,192,44,32,0,193,44,33,0,194,44,34,0,195,44,128,0,196,44,129,0,197,44,130,0,198,44,16,0,199,44,17,0,201,44,255,0,202,44,127,0,203,44,255,0,204,44,3,0,205,44,31,0,208,44,255,0,209,44,127,0,210,44,191,0,211,44,50,0,212,44,208,0,216,44,255,0,217,44,127,0,218,44,191,0,219,44,50,0,220,44,208,0,224,44,255,0,225,44,127,0,226,44,191,0,227,44,50,0,228,44,208,0,232,44,255,0,233,44,127,0,234,44,191,0,235,44,50,0,236,44,208,0,240,44,255,0,241,44,127,0,242,44,191,0,243,44,50,0,244,44,208,0,248,44,255,0,249,44,127,0,250,44,191,0,251,44,50,0,252,44,208,0,127,48,64,0,233,48,2,0,244,48,191,0,7,49,247,0,128,49,63,0,187,49,16,0,244,49,223,0,18,50,127,0,37,50,127,0,106,50,1,0,176,50,127,0,181,50,247,0,240,50,253,0,246,50,127,0,0,51,127,0,17,51,247,0,49,51,223,0,84,51,247,0,151,51,191,0,188,51,4,0,55,52,223,0,209,52,127,0,225,52,223,0,16,53,191,0,71,53,127,0,115,53,247,0,134,53,223,0,165,53,191,0,176,53,247,0,215,53,247,0,1,54,223,0,7,54,189,0,52,54,247,0,144,54,247,0,154,54,4,0,200,54,16,0,210,54,247,0,227,54,191,0,5,55,253,0,28,55,64,0,29,55,1,0,31,55,4,0,46,55,64,0,49,55,223,0,104,55,1,0,128,55,191,0,167,55,127,0,205,55,1,0,246,55,247,0,8,56,127,0,12,56,191,0,52,56,2,0,58,56,191,0,77,56,191,0,90,56,127,0,93,56,127,0,107,56,191,0,123,56,251,0,124,56,253,0,137,56,191,0,138,56,127,0,168,56,247,0,170,56,127,0,174,56,191,0,188,56,127,0,236,56,223,0,251,56,247,0,252,56,253,0,11,57,191,0,43,57,127,0,45,57,191,0,61,57,251,0,88,57,253,0,95,57,247,0,111,57,127,0,121,57,223,0,127,57,127,0,137,57,243,0,143,57,127,0,152,57,191,0,158,57,247,0,159,57,251,0,172,57,247,0,173,57,223,0,174,57,247,0,175,57,247,0,186,57,247,0,187,57,247,0,190,57,251,0,191,57,127,0,200,57,251,0,204,57,247,0,217,57,127,0,222,57,127,0,223,57,127,0,234,57,247,0,253,57,191,0,254,57,247,0,9,58,127,0,24,58,191,0,27,58,191,0,29,58,247,0,43,58,191,0,44,58,247,0,47,58,127,0,62,58,223,0,78,58,127,0,79,58,127,0,93,58,127,0,109,58,223,0,110,58,223,0,139,58,247,0,153,58,191,0,157,58,127,0,158,58,247,0,171,58,247,0,172,58,223,0,174,58,247,0,205,58,215,0,206,58,247,0,216,58,127,0,233,58,253,0,235,58,63,0,251,58,247,0,28,59,245,0,43,59,247,0,44,59,159,0,45,59,191,0,60,59,219,0,61,59,247,0,62,59,127,0,63,59,251,0,72,59,251,0,75,59,127,0,76,59,247,0,90,59,127,0,106,59,127,0,107,59,191,0,123,59,251,0,125,59,127,0,127,59,191,0,141,59,251,0,143,59,95,0,152,59,127,0,154,59,127,0,158,59,253,0,171,59,253,0,172,59,223,0,175,59,247,0,178,59,2,0,187,59,127,0,206,59,253,0,219,59,191,0,24,60,127,0,31,60,127,0,43,60,247,0,57,60,253,0,74,60,119,0,76,60,127,0,89,60,191,0,95,60,251,0,104,60,127,0,105,60,223,0,106,60,187,0,111,60,127,0,121,60,247,0,139,60,223,0,154,60,95,0,169,60,127,0,175,60,191,0,184,60,191,0,185,60,127,0,186,60,127,0,187,60,127,0,188,60,191,0,191,60,221,0,200,60,223,0,207,60,127,0,221,60,247,0,222,60,119,0,232,60,247,0,235,60,223,0,239,60,251,0,240,60,1,0,249,60,127,0,251,60,247,0,25,61,247,0,42,61,251,0,47,61,127,0,59,61,221,0,63,61,251,0,72,61,191,0,91,61,247,0,111,61,191,0,125,61,251,0,138,61,127,0,140,61,251,0,150,61,64,0,159,61,127,0,170,61,247,0,173,61,247,0,175,61,119,0,184,61,127,0,188,61,191,0,189,61,223,0,201,61,247,0,239,61,223,0,250,61,223,0,253,61,253,0,254,61,251,0,24,62,251,0,31,62,247,0,45,62,223,0,47,62,251,0,61,62,127,0,63,62,251,0,72,62,245,0,73,62,253,0,92,62,251,0,95,62,95,0,109,62,191,0,111,62,127,0,124,62,253,0,126,62,127,0,136,62,253,0,158,62,253,0,174,62,127,0,188,62,223,0,205,62,119,0,237,62,247,0,251,62,127,0,8,63,247,0,15,63,253,0,29,63,191,0,30,63,159,0,41,63,251,0,46,63,127,0,57,63,223,0,63,63,223,0,72,63,223,0,78,63,251,0,105,63,253,0,124,63,253,0,126,63,63,0,137,63,247,0,155,63,247,0,158,63,247,0,174,63,127,0,178,63,223,0,188,63,247,0,217,63,189,0,219,63,215,0,222,63,127,0,238,63,127,0,239,63,127,0,254,63,123,0,69,64,127,0,140,64,32,0,167,64,253,0,179,64,215,0,209,64,127,0,224,64,119,0,254,64,64,0,3,65,127,0,48,65,191,0,61,65,16,0,82,65,247,0,89,65,1,0,125,65,2,0,165,65,223,0,167,65,127,0,24,66,64,0,31,66,2,0,34,66,247,0,134,66,247,0,227,66,159,0,3,67,251,0,78,67,4,0,186,67,1,0,8,68,1,0,19,68,247,0,46,68,32,0,59,68,1,0,199,68,127,0,224,68,127,0,231,68,247,0,35,69,247,0,52,69,127,0,70,69,127,0,121,69,16,0,138,69,1,0,148,69,251,0,154,69,2,0,180,69,247,0,182,69,253,0,197,69,127,0,213,69,127,0,240,69,247,0,19,70,251,0,56,70,1,0,120,70,1,0,148,70,191,0,160,70,247,0,206,70,1,0,214,70,191,0,244,70,247,0,245,70,223,0,16,71,127,0,39,71,127,0,43,71,4,0,48,71,191,0,54,71,127,0,98,71,247,0,108,71,4,0,123,71,4,0,213,71,251,0,228,71,191,0,240,71,223,0,9,72,127,0,13,72,127,0,30,72,223,0,40,72,127,0,46,72,253,0,56,72,253,0,61,72,127,0,63,72,251,0,75,72,253,0,77,72,127,0,94,72,253,0,111,72,191,0,120,72,223,0,136,72,251,0,137,72,247,0,141,72,127,0,169,72,127,0,172,72,223,0,174,72,127,0,180,72,1,0,188,72,247,0,189,72,187,0,190,72,247,0,200,72,251,0,203,72,223,0,204,72,127,0,237,72,251,0,238,72,127,0,240,72,16,0,11,73,183,0,41,73,127,0,46,73,191,0,48,73,1,0,61,73,223,0,72,73,251,0,74,73,127,0,78,73,251,0,110,73,95,0,111,73,223,0,121,73,247,0,142,73,223,0,154,73,251,0,157,73,247,0,159,73,247,0,169,73,191,0,170,73,127,0,189,73,247,0,190,73,253,0,201,73,191,0,222,73,127,0,235,73,253,0,238,73,127,0,27,74,247,0,29,74,119,0,30,74,127,0,31,74,191,0,43,74,223,0,48,74,64,0,63,74,243,0,79,74,251,0,88,74,247,0,105,74,247,0,107,74,247,0,110,74,247,0,126,74,253,0,143,74,127,0,153,74,127,0,154,74,247,0,157,74,127,0,158,74,251,0,174,74,253,0,185,74,127,0,188,74,127,0,189,74,247,0,203,74,191,0,206,74,247,0,207,74,223,0,220,74,247,0,222,74,251,0,238,74,191,0,255,74,127,0,27,75,251,0,30,75,243,0,40,75,247,0,58,75,247,0,59,75,93,0,61,75,251,0,63,75,63,0,77,75,191,0,78,75,247,0,95,75,127,0,110,75,251,0,138,75,223,0,143,75,127,0,144,75,16,0,155,75,221,0,159,75,127,0,169,75,127,0,172,75,191,0,185,75,253,0,200,75,251,0,202,75,251,0,203,75,219,0,205,75,119,0,219,75,253,0,220,75,247,0,223,75,127,0,233,75,127,0,249,75,247,0,250,75,251,0,251,75,191,0,253,75,119,0,254,75,249,0,10,76,127,0,15,76,191,0,24,76,253,0,25,76,191,0,27,76,247,0,28,76,127,0,30,76,127,0,31,76,127,0,56,76,247,0,61,76,247,0,72,76,223,0,74,76,247,0,77,76,223,0,93,76,247,0,104,76,127,0,107,76,127,0,111,76,127,0,127,76,127,0,129,76,64,0,136,76,251,0,153,76,247,0,156,76,127,0,157,76,127,0,174,76,127,0,175,76,127,0,186,76,191,0,187,76,127,0,188,76,251,0,191,76,247,0,202,76,191,0,203,76,191,0,207,76,191,0,218,76,243,0,219,76,191,0,232,76,253,0,235,76,251,0,237,76,223,0,8,77,191,0,10,77,119,0,25,77,251,0,28,77,251,0,31,77,191,0,47,77,125,0,57,77,191,0,58,77,223,0,59,77,119,0,90,77,191,0,91,77,119,0,94,77,247,0,122,77,183,0,123,77,247,0,124,77,127,0,127,77,127,0,141,77,223,0,143,77,247,0,159,77,127,0,189,77,127,0,204,77,191,0,207,77,127,0,216,77,253,0,219,77,127,0,229,77,4,0,250,77,191,0,11,78,223,0,12,78,127,0,25,78,253,0,27,78,247,0,31,78,251,0,79,78,127,0,105,78,127,0,111,78,253,0,123,78,251,0,127,78,191,0,137,78,247,0,152,78,251,0,158,78,127,0,168,78,247,0,169,78,253,0,187,78,215,0,200,78,191,0,224,78,64,0,236,78,247,0,251,78,251,0,252,78,127,0,255,78,253,0,12,79,127,0,13,79,251,0,29,79,251,0,40,79,191,0,61,79,191,0,77,79,223,0,79,79,251,0,92,79,247,0,94,79,247,0,111,79,253,0,120,79,247,0,123,79,247,0,125,79,127,0,133,79,16,0,153,79,253,0,157,79,127,0,159,79,127,0,171,79,251,0,172,79,127,0,173,79,125,0,175,79,253,0,189,79,247,0,200,79,125,0,217,79,159,0,222,79,127,0,233,79,127,0,237,79,253,0,238,79,253,0,249,79,247,0,252,79,191,0,255,79,127,0,8,80,1,0,99,80,191,0,134,80,191,0,154,80,4,0,177,80,247,0,220,80,4,0,49,81,127,0,78,81,32,0,90,81,16,0,123,81,1,0,143,81,1,0,162,81,191,0,209,81,127,0,1,82,251,0,18,82,247,0,25,82,4,0,50,82,247,0,66,82,127,0,27,83,1,0,71,83,127,0,103,83,127,0,114,83,247,0,132,83,253,0,180,83,251,0,208,83,247,0,16,84,251,0,66,84,253,0,85,84,127,0,86,84,191,0,98,84,127,0,144,84,191,0,36,85,251,0,66,85,247,0,98,85,223,0,117,85,247,0,129,85,223,0,130,85,191,0,215,85,127,0,246,85,247,0,18,86,223,0,19,86,127,0,39,86,251,0,68,86,127,0,250,86,2,0,37,87,247,0,52,87,253,0,57,87,2,0,233,87,32,0,10,88,251,0,13,88,127,0,25,88,127,0,30,88,253,0,47,88,247,0,77,88,191,0,79,88,251,0,89,88,247,0,109,88,191,0,124,88,223,0,126,88,247,0,137,88,253,0,152,88,191,0,156,88,247,0,170,88,191,0,203,88,223,0,238,88,247,0,255,88,127,0,14,89,251,0,24,89,191,0,41,89,127,0,42,89,191,0,43,89,253,0,58,89,191,0,62,89,127,0,73,89,127,0,91,89,127,0,121,89,127,0,125,89,127,0,136,89,127,0,137,89,191,0,139,89,127,0,152,89,191,0,159,89,253,0,168,89,223,0,174,89,253,0,184,89,127,0,202,89,251,0,206,89,127,0,207,89,251,0,221,89,191,0,234,89,251,0,235,89,127,0,248,89,247,0,249,89,253,0,250,89,247,0,15,90,223,0,26,90,247,0,29,90,127,0,31,90,191,0,46,90,247,0,63,90,127,0,89,90,223,0,90,90,183,0,95,90,127,0,109,90,247,0,124,90,223,0,143,90,127,0,152,90,123,0,170,90,127,0,175,90,127,0,188,90,127,0,189,90,253,0,205,90,223,0,217,90,191,0,223,90,127,0,232,90,127,0,234,90,247,0,237,90,247,0,254,90,247,0,255,90,95,0,9,91,251,0,10,91,251,0,14,91,191,0,15,91,123,0,40,91,253,0,43,91,251,0,46,91,191,0,47,91,251,0,61,91,247,0,63,91,247,0,73,91,127,0,78,91,247,0,94,91,247,0,107,91,127,0,108,91,191,0,111,91,127,0,121,91,127,0,126,91,95,0,142,91,223,0,153,91,243,0,159,91,215,0,168,91,191,0,170,91,191,0,172,91,247,0,173,91,119,0,186,91,127,0,190,91,247,0,202,91,191,0,207,91,95,0,210,91,64,0,219,91,247,0,234,91,247,0,235,91,247,0,251,91,187,0,253,91,247,0,14,92,127,0,15,92,223,0,26,92,247,0,40,92,127,0,43,92,247,0,61,92,223,0,62,92,251,0,74,92,223,0,76,92,223,0,77,92,253,0,92,92,127,0,109,92,127,0,127,92,127,0,133,92,1,0,138,92,253,0,139,92,127,0,155,92,191,0,159,92,127,0,174,92,127,0,175,92,127,0,185,92,251,0,206,92,253,0,211,92,4,0,214,92,1,0,223,92,253,0,235,92,127,0,249,92,191,0,11,93,191,0,29,93,253,0,30,93,127,0,43,93,253,0,44,93,253,0,45,93,127,0,47,93,191,0,58,93,127,0,59,93,247,0,75,93,251,0,77,93,251,0,79,93,247,0,90,93,253,0,91,93,223,0,92,93,127,0,94,93,191,0,105,93,251,0,107,93,183,0,109,93,191,0,112,93,2,0,120,93,247,0,127,93,251,0,138,93,223,0,143,93,253,0,153,93,191,0,158,93,223,0,172,93,251,0,203,93,127,0,205,93,191,0,219,93,215,0,222,93,127,0,233,93,127,0,234,93,251,0,255,93,127,0,25,94,247,0,31,94,251,0,40,94,191,0,45,94,223,0,61,94,127,0,73,94,127,0,78,94,251,0,92,94,191,0,104,94,253,0,108,94,223,0,109,94,223,0,121,94,223,0,125,94,127,0,153,94,127,0,175,94,191,0,188,94,223,0,200,94,191,0,204,94,247,0,210,94,191,0,249,94,247,0,254,94,223,0,8,95,247,0,15,95,247,0,24,95,253,0,25,95,127,0,27,95,253,0,63,95,127,0,76,95,253,0,78,95,247,0,92,95,127,0,93,95,247,0,94,95,127,0,105,95,251,0,108,95,253,0,111,95,223,0,146,95,247,0,173,95,127,0,174,95,247,0,205,95,247,0,207,95,191,0,220,95,247,0,222,95,127,0,223,95,127,0,235,95,127,0,237,95,223,0,248,95,223,0,12,96,32,0,65,96,191,0,69,96,127,0,98,96,247,0,119,96,191,0,160,96,223,0,193,96,127,0,199,96,253,0,203,96,64,0,232,96,1,0,24,97,2,0,60,97,1,0,67,97,247,0,74,97,64,0,91,97,16,0,111,97,1,0,124,97,1,0,144,97,223,0,150,97,247,0,166,97,127,0,214,97,247,0,248,97,4,0,250,97,16,0,1,98,127,0,167,98,191,0,212,98,127,0,34,99,247,0,97,99,251,0,99,99,127,0,116,99,247,0,146,99,127,0,159,99,1,0,160,99,247,0,161,99,127,0,217,99,32,0,232,99,1,0,6,100,127,0,36,100,127,0,55,100,127,0,59,100,1,0,177,100,251,0,20,101,247,0,54,101,253,0,70,101,127,0,120,101,1,0,130,101,127,0,163,101,251,0,185,101,1,0,201,101,1,0,224,101,247,0,18,102,223,0,50,102,247,0,54,102,127,0,81,102,247,0,102,102,247,0,117,102,127,0,132,102,127,0,135,102,127,0,233,102,64,0,6,103,253,0,19,103,223,0,88,103,17,0,115,103,247,0,118,103,191,0,240,103,127,0,43,104,251,0,44,104,251,0,62,104,245,0,63,104,127,0,73,104,247,0,92,104,245,0,108,104,127,0,109,104,247,0,110,104,127,0,126,104,223,0,137,104,127,0,142,104,191,0,143,104,127,0,155,104,247,0,156,104,247,0,158,104,127,0,203,104,191,0,233,104,127,0,234,104,223,0,235,104,127,0,239,104,247,0,11,105,247,0,24,105,191,0,29,105,247,0,41,105,127,0,56,105,127,0,58,105,63,0,62,105,63,0,73,105,247,0,76,105,127,0,77,105,223,0,78,105,119,0,90,105,253,0,123,105,127,0,126,105,127,0,137,105,127,0,138,105,127,0,142,105,247,0,143,105,247,0,155,105,223,0,158,105,95,0,159,105,223,0,173,105,127,0,201,105,247,0,217,105,247,0,220,105,247,0,249,105,191,0,250,105,247,0,252,105,127,0,9,106,247,0,27,106,127,0,42,106,247,0,45,106,253,0,60,106,253,0,61,106,127,0,63,106,127,0,90,106,191,0,108,106,251,0,111,106,253,0,122,106,247,0,123,106,123,0,137,106,127,0,159,106,127,0,171,106,223,0,184,106,247,0,190,106,253,0,200,106,253,0,203,106,127,0,207,106,215,0,220,106,253,0,234,106,191,0,235,106,247,0,248,106,251,0,253,106,191,0,26,107,127,0,31,107,127,0,45,107,253,0,46,107,215,0,62,107,223,0,75,107,247,0,77,107,251,0,79,107,191,0,94,107,123,0,95,107,127,0,108,107,251,0,111,107,223,0,136,107,221,0,138,107,251,0,139,107,119,0,168,107,127,0,170,107,247,0,202,107,251,0,203,107,247,0,219,107,223,0,220,107,191,0,221,107,119,0,223,107,253,0,232,107,127,0,233,107,247,0,237,107,127,0,248,107,253,0,249,107,245,0,250,107,247,0,253,107,245,0,254,107,247,0,255,107,191,0,9,108,251,0,15,108,127,0,41,108,215,0,47,108,127,0,58,108,223,0,62,108,247,0,78,108,191,0,94,108,127,0,95,108,223,0,121,108,223,0,122,108,127,0,126,108,191,0,139,108,127,0,141,108,223,0,153,108,253,0,154,108,191,0,158,108,127,0,169,108,127,0,170,108,247,0,172,108,251,0,173,108,127,0,175,108,247,0,201,108,251,0,220,108,253,0,236,108,223,0,239,108,191,0,251,108,127,0,29,109,253,0,31,109,223,0,43,109,217,0,59,109,127,0,60,109,183,0,77,109,191,0,88,109,127,0,92,109,127,0,109,109,253,0,126,109,127,0,137,109,191,0,155,109,127,0,159,109,247,0,185,109,127,0,191,109,251,0,233,109,127,0,234,109,247,0,236,109,191,0,251,109,127,0,9,110,127,0,15,110,127,0,16,110,1,0,18,110,223,0,30,110,251,0,40,110,247,0,46,110,251,0,78,110,127,0,114,110,127,0,121,110,127,0,126,110,159,0,136,110,127,0,142,110,247,0,158,110,191,0,172,110,253,0,173,110,247,0,175,110,127,0,185,110,251,0,190,110,127,0,201,110,127,0,232,110,247,0,233,110,119,0,235,110,247,0,236,110,127,0,4,111,4,0,12,111,127,0,14,111,127,0,24,111,223,0,31,111,127,0,43,111,251,0,46,111,253,0,60,111,247,0,63,111,127,0,77,111,251,0,89,111,119,0,94,111,127,0,107,111,251,0,110,111,159,0,159,111,127,0,173,111,183,0,191,111,247,0,200,111,223,0,205,111,63,0,206,111,187,0,220,111,127,0,221,111,223,0,239,111,247,0,251,111,251,0,253,111,119,0,30,112,16,0,71,112,127,0,118,112,247,0,124,112,16,0,213,112,253,0,244,112,223,0,12,113,4,0,26,113,1,0,78,113,6,0,111,113,1,0,163,113,223,0,176,113,253,0,222,113,16,0,6,114,191,0,12,114,64,0,35,114,251,0,108,114,4,0,114,114,247,0,165,114,191,0,192,114,247,0,222,114,1,0,248,114,4,0,2,115,223,0,19,115,127,0,50,115,247,0,114,115,247,0,235,115,64,0,16,116,223,0,35,116,247,0,50,116,247,0,51,116,247,0,74,116,1,0,139,116,1,0,144,116,247,0,154,116,1,0,38,117,251,0,54,117,127,0,64,117,127,0,87,117,127,0,127,117,4,0,132,117,127,0,184,117,1,0,194,117,247,0,198,117,127,0,213,117,183,0,248,117,1,0,7,118,223,0,79,118,2,0,148,118,127,0,151,118,253,0,204,118,16,0,208,118,247,0,224,118,247,0,2,119,247,0,33,119,127,0,82,119,251,0,182,119,251,0,184,119,1,0,194,119,247,0,210,119,247,0,211,119,127,0,227,119,253,0,11,120,127,0,15,120,63,0,24,120,247,0,52,120,1,0,76,120,127,0,79,120,95,0,91,120,127,0,120,120,127,0,136,120,127,0,137,120,251,0,138,120,251,0,139,120,247,0,185,120,127,0,203,120,223,0,205,120,127,0,218,120,247,0,234,120,247,0,251,120,251,0,11,121,127,0,12,121,247,0,13,121,223,0,14,121,251,0,15,121,253,0,26,121,127,0,29,121,191,0,59,121,247,0,63,121,127,0,73,121,253,0,79,121,251,0,92,121,127,0,96,121,1,0,104,121,191,0,105,121,253,0,120,121,127,0,125,121,247,0,141,121,254,0,142,121,191,0,169,121,127,0,173,121,247,0,187,121,253,0,200,121,247,0,201,121,127,0,219,121,127,0,222,121,127,0,233,121,251,0,248,121,183,0,251,121,191,0,255,121,191,0,12,122,243,0,15,122,221,0,24,122,127,0,56,122,127,0,57,122,127,0,73,122,191,0,75,122,119,0,76,122,127,0,81,122,64,0,109,122,253,0,111,122,127,0,142,122,127,0,175,122,223,0,187,122,127,0,206,122,191,0,220,122,223,0,223,122,183,0,238,122,247,0,239,122,251,0,248,122,247,0,251,122,127,0,254,122,251,0,15,123,223,0,25,123,253,0,31,123,253,0,41,123,245,0,45,123,127,0,47,123,247,0,56,123,127,0,60,123,251,0,61,123,253,0,74,123,247,0,75,123,247,0,90,123,127,0,94,123,127,0,95,123,191,0,109,123,191,0,111,123,51,0,122,123,247,0,123,123,251,0,127,123,127,0,142,123,127,0,149,123,4,0,153,123,247,0,169,123,127,0,184,123,127,0,185,123,253,0,206,123,127,0,207,123,127,0])
.concat([216,123,215,0,218,123,127,0,220,123,127,0,222,123,247,0,233,123,251,0,248,123,159,0,250,123,191,0,251,123,223,0,254,123,247,0,255,123,119,0,8,124,127,0,10,124,223,0,26,124,127,0,28,124,247,0,46,124,127,0,47,124,127,0,62,124,247,0,72,124,247,0,89,124,127,0,92,124,247,0,123,124,247,0,127,124,251,0,185,124,223,0,191,124,127,0,217,124,127,0,218,124,127,0,221,124,127,0,253,124,223,0,8,125,253,0,29,125,247,0,45,125,215,0,47,125,127,0,59,125,191,0,74,125,223,0,77,125,247,0,78,125,127,0,90,125,127,0,91,125,223,0,95,125,223,0,106,125,191,0,108,125,251,0,110,125,249,0,120,125,247,0,125,125,223,0,126,125,127,0,141,125,247,0,142,125,247,0,143,125,95,0,152,125,119,0,154,125,247,0,157,125,223,0,158,125,251,0,184,125,247,0,185,125,247,0,187,125,223,0,188,125,223,0,191,125,223,0,204,125,191,0,217,125,247,0,234,125,223,0,236,125,253,0,238,125,221,0,249,125,247,0,253,125,127,0,2,126,253,0,11,126,253,0,24,126,247,0,27,126,251,0,29,126,127,0,72,126,251,0,74,126,1,0,108,126,223,0,111,126,247,0,142,126,253,0,221,126,127,0,234,126,32,0,235,126,191,0,239,126,239,0,253,126,119,0,254,126,127,0,255,126,223,0,40,127,247,0,44,127,247,0,46,127,123,0,47,127,247,0,54,127,16,0,61,127,253,0,73,127,127,0,88,127,123,0,94,127,223,0,104,127,247,0,108,127,247,0,123,127,249,0,126,127,223,0,141,127,223,0,146,127,247,0,152,127,247,0,156,127,127,0,169,127,185,0,171,127,123,0,188,127,127,0,191,127,247,0,201,127,127,0,203,127,127,0,205,127,191,0,206,127,127,0,207,127,251,0,219,127,247,0,223,127,127,0,232,127,223,0,236,127,251,0,242,127,247,0,240,240,252,252,252,252,243,243,60,60,60,60,60,60,60,60,240,240,240,240,0,0,243,243,0,0,0,0,0,0,207,207,0,0,15,15,63,63,15,15,0,0,0,0,192,192,15,15,0,0,0,0,0,0,240,240,0,0,0,0,0,0,243,243,0,0,0,0,0,0,192,192,3,3,3,3,3,3,255,255,192,192,192,192,192,192,195,195,0,0,0,0,0,0,252,252,243,243,240,240,240,240,240,240,60,60,252,252,252,252,60,60,243,243,243,243,243,243,243,243,243,243,195,195,195,195,195,195,207,207,207,207,207,207,207,207,60,60,63,63,60,60,15,15,60,60,252,252,0,0,252,252,252,252,240,240,240,240,240,240,243,243,243,243,243,243,240,240,195,195,195,195,195,195,255,255,207,207,207,207,207,207,195,195,15,15,15,15,15,15,252,252,60,66,185,165,185,165,66,60,104,72,1,0,88,72,1,0,72,72,1,0,56,72,1,0,40,72,1,0,24,72,1,0,24,72,1,0,24,72,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,129,225,126,0,0,0,0,160,0,0,0,144,0,0,0,160,0,0,0,144,0,0,0,0,0,0,0,0,0,0,0,80,95,0,0,32,81,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,52,1,0,60,1,0,0,254,0,0,0,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,52,1,0,152,1,0,0,86,1,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,52,1,0,154,0,0,0,26,2,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,1,0,202,0,0,0,36,0,0,0,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,53,1,0,202,0,0,0,76,0,0,0,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,53,1,0,202,0,0,0,26,0,0,0,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,53,1,0,90,1,0,0,178,0,0,0,92,0,0,0,2,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,53,1,0,234,1,0,0,126,1,0,0,92,0,0,0,4,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,53,1,0,106,1,0,0,128,1,0,0,92,0,0,0,12,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,53,1,0,18,2,0,0,50,1,0,0,92,0,0,0,10,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,54,1,0,14,2,0,0,196,0,0,0,92,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,54,1,0,82,1,0,0,244,0,0,0,92,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,54,1,0,70,0,0,0,246,0,0,0,92,0,0,0,214,0,0,0,4,0,0,0,38,0,0,0,8,0,0,0,22,0,0,0,18,0,0,0,8,0,0,0,248,255,255,255,120,54,1,0,36,0,0,0,16,0,0,0,122,0,0,0,22,0,0,0,4,0,0,0,48,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,54,1,0,134,1,0,0,176,0,0,0,92,0,0,0,34,0,0,0,6,0,0,0,66,0,0,0,32,0,0,0,20,0,0,0,2,0,0,0,10,0,0,0,248,255,255,255,160,54,1,0,126,0,0,0,188,0,0,0,206,0,0,0,222,0,0,0,46,0,0,0,72,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,54,1,0,166,0,0,0,132,1,0,0,92,0,0,0,80,0,0,0,64,0,0,0,98,0,0,0,84,0,0,0,178,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,54,1,0,214,0,0,0,144,0,0,0,92,0,0,0,70,0,0,0,158,0,0,0,108,0,0,0,188,1,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,54,1,0,6,2,0,0,4,0,0,0,92,0,0,0,70,0,0,0,56,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,55,1,0,88,0,0,0,10,0,0,0,92,0,0,0,38,0,0,0,18,0,0,0,184,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,55,1,0,214,1,0,0,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,55,1,0,46,0,0,0,48,1,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,55,1,0,102,0,0,0,96,1,0,0,92,0,0,0,46,0,0,0,12,0,0,0,14,0,0,0,10,0,0,0,12,0,0,0,4,0,0,0,2,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,55,1,0,0,1,0,0,24,0,0,0,92,0,0,0,38,0,0,0,42,0,0,0,42,0,0,0,40,0,0,0,40,0,0,0,8,0,0,0,10,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,55,1,0,72,0,0,0,32,0,0,0,92,0,0,0,56,0,0,0,54,0,0,0,48,0,0,0,50,0,0,0,36,0,0,0,44,0,0,0,46,0,0,0,62,0,0,0,60,0,0,0,58,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,55,1,0,136,1,0,0,8,0,0,0,92,0,0,0,82,0,0,0,76,0,0,0,70,0,0,0,72,0,0,0,64,0,0,0,74,0,0,0,68,0,0,0,34,0,0,0,80,0,0,0,78,0,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,55,1,0,160,0,0,0,194,0,0,0,92,0,0,0,18,0,0,0,56,0,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,55,1,0,44,0,0,0,104,1,0,0,92,0,0,0,10,0,0,0,68,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,55,1,0,232,1,0,0,30,1,0,0,92,0,0,0,14,0,0,0,4,0,0,0,24,0,0,0,26,0,0,0,168,0,0,0,4,0,0,0,228,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,1,0,208,1,0,0,130,0,0,0,92,0,0,0,2,0,0,0,8,0,0,0,16,0,0,0,190,0,0,0,180,0,0,0,14,0,0,0,176,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,56,1,0,208,1,0,0,32,1,0,0,92,0,0,0,16,0,0,0,6,0,0,0,2,0,0,0,232,0,0,0,198,0,0,0,12,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,56,1,0,208,1,0,0,70,1,0,0,92,0,0,0,10,0,0,0,12,0,0,0,22,0,0,0,52,0,0,0,140,0,0,0,6,0,0,0,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,56,1,0,208,1,0,0,58,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,56,1,0,116,0,0,0,18,1,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,56,1,0,208,1,0,0,170,0,0,0,92,0,0,0,4,0,0,0,8,0,0,0,14,0,0,0,26,0,0,0,40,0,0,0,94,0,0,0,62,0,0,0,16,0,0,0,16,0,0,0,24,0,0,0,48,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,56,1,0,24,2,0,0,62,0,0,0,92,0,0,0,4,0,0,0,46,0,0,0,52,0,0,0,106,0,0,0,26,0,0,0,16,0,0,0,78,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,56,1,0,146,0,0,0,226,1,0,0,142,0,0,0,70,0,0,0,100,0,0,0,102,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,164,1,0,0,222,0,0,0,56,0,0,0,248,255,255,255,0,0,0,0,90,0,0,0,128,0,0,0,192,255,255,255,192,255,255,255,0,0,0,0,178,1,0,0,168,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,56,1,0,208,1,0,0,180,0,0,0,92,0,0,0,10,0,0,0,12,0,0,0,22,0,0,0,52,0,0,0,140,0,0,0,6,0,0,0,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,56,1,0,208,1,0,0,246,1,0,0,92,0,0,0,10,0,0,0,12,0,0,0,22,0,0,0,52,0,0,0,140,0,0,0,6,0,0,0,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,0,0,0,210,1,0,0,248,1,0,0,112,0,0,0,44,0,0,0,6,0,0,0,84,0,0,0,160,0,0,0,62,0,0,0,220,0,0,0,20,0,0,0,72,0,0,0,60,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,1,0,22,1,0,0,238,1,0,0,198,0,0,0,68,0,0,0,20,0,0,0,48,0,0,0,74,0,0,0,184,0,0,0,98,0,0,0,44,0,0,0,40,0,0,0,20,0,0,0,120,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,57,1,0,154,1,0,0,138,1,0,0,248,1,0,0,112,0,0,0,52,0,0,0,32,0,0,0,84,0,0,0,160,0,0,0,62,0,0,0,12,0,0,0,20,0,0,0,82,0,0,0,60,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,108,1,0,0,148,255,255,255,148,255,255,255,0,0,0,0,228,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,56,57,1,0,80,0,0,0,194,1,0,0,252,255,255,255,252,255,255,255,56,57,1,0,56,1,0,0,20,1,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,80,57,1,0,216,1,0,0,242,1,0,0,252,255,255,255,252,255,255,255,80,57,1,0,242,0,0,0,162,1,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,104,57,1,0,184,0,0,0,28,2,0,0,248,255,255,255,248,255,255,255,104,57,1,0,212,1,0,0,236,1,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,128,57,1,0,236,0,0,0,176,1,0,0,248,255,255,255,248,255,255,255,128,57,1,0,218,1,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,1,0,0,136,0,0,0,126,1,0,0,24,0,0,0,26,0,0,0,54,0,0,0,32,0,0,0,160,0,0,0,62,0,0,0,172,0,0,0,20,0,0,0,50,0,0,0,60,0,0,0,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,57,1,0,170,1,0,0,116,1,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,57,1,0,10,2,0,0,118,1,0,0,176,0,0,0,68,0,0,0,20,0,0,0,48,0,0,0,96,0,0,0,184,0,0,0,98,0,0,0,44,0,0,0,40,0,0,0,20,0,0,0,120,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,57,1,0,72,1,0,0,184,1,0,0,52,1,0,0,112,0,0,0,52,0,0,0,32,0,0,0,164,0,0,0,160,0,0,0,62,0,0,0,12,0,0,0,20,0,0,0,82,0,0,0,60,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,1,0,228,1,0,0,54,1,0,0,92,0,0,0,124,0,0,0,210,0,0,0,152,1,0,0,132,2,0,0,48,0,0,0,16,1,0,0,86,0,0,0,218,0,0,0,82,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,58,1,0,234,0,0,0,112,0,0,0,92,0,0,0,196,0,0,0,204,0,0,0,8,2,0,0,64,2,0,0,82,2,0,0,246,0,0,0,200,0,0,0,180,1,0,0,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,58,1,0,230,1,0,0,252,0,0,0,92,0,0,0,24,0,0,0,106,0,0,0,158,1,0,0,138,1,0,0,94,2,0,0,18,2,0,0,174,0,0,0,190,1,0,0,158,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,58,1,0,162,0,0,0,94,1,0,0,92,0,0,0,186,0,0,0,192,0,0,0,14,1,0,0,50,2,0,0,248,0,0,0,200,0,0,0,144,0,0,0,34,2,0,0,22,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,58,1,0,148,1,0,0,22,0,0,0,200,1,0,0,68,0,0,0,20,0,0,0,48,0,0,0,74,0,0,0,184,0,0,0,98,0,0,0,138,0,0,0,154,0,0,0,36,0,0,0,120,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,58,1,0,20,0,0,0,220,1,0,0,6,2,0,0,112,0,0,0,52,0,0,0,32,0,0,0,84,0,0,0,160,0,0,0,62,0,0,0,28,0,0,0,234,0,0,0,6,0,0,0,60,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,0,0,0,142,1,0,0,4,2,0,0,74,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,56,0,0,0,120,1,0,0,56,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,1,0,0,16,2,0,0,206,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,0,0,0,40,1,0,0,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,82,0,0,0,98,0,0,0,102,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,1,0,0,200,1,0,0,126,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,1,0,0,192,1,0,0,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,0,0,0,168,0,0,0,222,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,230,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,0,0,0,18,0,0,0,198,1,0,0,102,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,0,0,0,188,1,0,0,40,0,0,0,102,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,58,1,0,12,2,0,0,156,1,0,0,134,0,0,0,64,1,0,0,36,0,0,0,28,0,0,0,14,0,0,0,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,1,0,0,224,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,18,0,0,0,66,0,0,0,246,1,0,0,114,1,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,40,0,0,0,56,0,0,0,22,0,0,0,218,0,0,0,188,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,146,0,0,0,54,0,0,0,210,0,0,0,240,1,0,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,162,0,0,0,128,0,0,0,170,1,0,0,150,1,0,0,8,1,0,0,0,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,120,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,83,116,57,116,121,112,101,95,105,110,102,111,0,0,0,0,83,116,57,101,120,99,101,112,116,105,111,110,0,0,0,0,83,116,57,98,97,100,95,97,108,108,111,99,0,0,0,0,83,116,56,98,97,100,95,99,97,115,116,0,0,0,0,0,83,116,49,51,114,117,110,116,105,109,101,95,101,114,114,111,114,0,0,0,0,0,0,0,83,116,49,50,111,117,116,95,111,102,95,114,97,110,103,101,0,0,0,0,0,0,0,0,83,116,49,50,108,101,110,103,116,104,95,101,114,114,111,114,0,0,0,0,0,0,0,0,83,116,49,49,108,111,103,105,99,95,101,114,114,111,114,0,78,83,116,51,95,95,49,57,116,105,109,101,95,98,97,115,101,69,0,0,0,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,98,97,115,105,99,95,105,111,115,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,57,98,97,115,105,99,95,105,111,115,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,112,117,116,73,119,69,69,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,112,117,116,73,99,69,69,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,103,101,116,73,119,69,69,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,103,101,116,73,99,69,69,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,110,117,109,112,117,110,99,116,73,119,69,69,0,0,0,0,78,83,116,51,95,95,49,56,110,117,109,112,117,110,99,116,73,99,69,69,0,0,0,0,78,83,116,51,95,95,49,56,109,101,115,115,97,103,101,115,73,119,69,69,0,0,0,0,78,83,116,51,95,95,49,56,109,101,115,115,97,103,101,115,73,99,69,69,0,0,0,0,78,83,116,51,95,95,49,56,105,111,115,95,98,97,115,101,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,56,105,111,115,95,98,97,115,101,55,102,97,105,108,117,114,101,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,108,108,97,116,101,73,119,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,108,108,97,116,101,73,99,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,119,99,49,48,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,99,99,49,48,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,68,115,99,49,48,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,68,105,99,49,48,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,54,108,111,99,97,108,101,53,102,97,99,101,116,69,0,0,0,78,83,116,51,95,95,49,54,108,111,99,97,108,101,53,95,95,105,109,112,69,0,0,0,78,83,116,51,95,95,49,53,99,116,121,112,101,73,119,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,53,99,116,121,112,101,73,99,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,50,48,95,95,116,105,109,101,95,103,101,116,95,99,95,115,116,111,114,97,103,101,73,119,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,50,48,95,95,116,105,109,101,95,103,101,116,95,99,95,115,116,111,114,97,103,101,73,99,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,57,95,95,105,111,115,116,114,101,97,109,95,99,97,116,101,103,111,114,121,69,0,0,0,78,83,116,51,95,95,49,49,55,95,95,119,105,100,101,110,95,102,114,111,109,95,117,116,102,56,73,76,106,51,50,69,69,69,0,0,0,0,0,0,78,83,116,51,95,95,49,49,54,95,95,110,97,114,114,111,119,95,116,111,95,117,116,102,56,73,76,106,51,50,69,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,53,98,97,115,105,99,95,115,116,114,101,97,109,98,117,102,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,53,98,97,115,105,99,95,115,116,114,101,97,109,98,117,102,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,101,114,114,111,114,95,99,97,116,101,103,111,114,121,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,95,95,115,104,97,114,101,100,95,99,111,117,110,116,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,95,95,110,117,109,95,112,117,116,95,98,97,115,101,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,95,95,110,117,109,95,103,101,116,95,98,97,115,101,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,51,109,101,115,115,97,103,101,115,95,98,97,115,101,69,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,111,115,116,114,101,97,109,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,111,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,105,115,116,114,101,97,109,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,105,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,78,83,116,51,95,95,49,49,50,115,121,115,116,101,109,95,101,114,114,111,114,69,0,0,78,83,116,51,95,95,49,49,50,99,111,100,101,99,118,116,95,98,97,115,101,69,0,0,78,83,116,51,95,95,49,49,50,95,95,100,111,95,109,101,115,115,97,103,101,69,0,0,78,83,116,51,95,95,49,49,49,95,95,115,116,100,111,117,116,98,117,102,73,119,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,115,116,100,111,117,116,98,117,102,73,99,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,112,117,116,73,119,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,112,117,116,73,99,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,103,101,116,73,119,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,103,101,116,73,99,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,119,76,98,49,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,119,76,98,48,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,99,76,98,49,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,99,76,98,48,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,95,98,97,115,101,69,0,0,0,0,78,83,116,51,95,95,49,49,48,99,116,121,112,101,95,98,97,115,101,69,0,0,0,0,78,83,116,51,95,95,49,49,48,95,95,116,105,109,101,95,112,117,116,69,0,0,0,0,78,83,116,51,95,95,49,49,48,95,95,115,116,100,105,110,98,117,102,73,119,69,69,0,78,83,116,51,95,95,49,49,48,95,95,115,116,100,105,110,98,117,102,73,99,69,69,0,78,49,48,95,95,99,120,120,97,98,105,118,49,50,49,95,95,118,109,105,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,50,48,95,95,115,105,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,55,95,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,54,95,95,115,104,105,109,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,0,0,0,0,0,0,0,0,0,41,1,0,0,0,0,0,16,41,1,0,0,0,0,0,32,41,1,0,200,52,1,0,0,0,0,0,0,0,0,0,48,41,1,0,200,52,1,0,0,0,0,0,0,0,0,0,64,41,1,0,200,52,1,0,0,0,0,0,0,0,0,0,88,41,1,0,32,53,1,0,0,0,0,0,0,0,0,0,112,41,1,0,32,53,1,0,0,0,0,0,0,0,0,0,136,41,1,0,200,52,1,0,0,0,0,0,0,0,0,0,152,41,1,0,232,39,1,0,176,41,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,224,57,1,0,0,0,0,0,232,39,1,0,248,41,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,232,57,1,0,0,0,0,0,232,39,1,0,64,42,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,240,57,1,0,0,0,0,0,232,39,1,0,136,42,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,248,57,1,0,0,0,0,0,0,0,0,0,208,42,1,0,40,55,1,0,0,0,0,0,0,0,0,0,0,43,1,0,40,55,1,0,0,0,0,0,232,39,1,0,48,43,1,0,0,0,0,0,1,0,0,0,32,57,1,0,0,0,0,0,232,39,1,0,72,43,1,0,0,0,0,0,1,0,0,0,32,57,1,0,0,0,0,0,232,39,1,0,96,43,1,0,0,0,0,0,1,0,0,0,40,57,1,0,0,0,0,0,232,39,1,0,120,43,1,0,0,0,0,0,1,0,0,0,40,57,1,0,0,0,0,0,232,39,1,0,144,43,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,144,58,1,0,0,8,0,0,232,39,1,0,216,43,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,144,58,1,0,0,8,0,0,232,39,1,0,32,44,1,0,0,0,0,0,3,0,0,0,96,56,1,0,2,0,0,0,48,53,1,0,2,0,0,0,192,56,1,0,0,8,0,0,232,39,1,0,104,44,1,0,0,0,0,0,3,0,0,0,96,56,1,0,2,0,0,0,48,53,1,0,2,0,0,0,200,56,1,0,0,8,0,0,0,0,0,0,176,44,1,0,96,56,1,0,0,0,0,0,0,0,0,0,200,44,1,0,96,56,1,0,0,0,0,0,232,39,1,0,224,44,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,48,57,1,0,2,0,0,0,232,39,1,0,248,44,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,48,57,1,0,2,0,0,0,0,0,0,0,16,45,1,0,0,0,0,0,40,45,1,0,152,57,1,0,0,0,0,0,232,39,1,0,72,45,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,216,53,1,0,0,0,0,0,232,39,1,0,144,45,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,240,53,1,0,0,0,0,0,232,39,1,0,216,45,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,8,54,1,0,0,0,0,0,232,39,1,0,32,46,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,32,54,1,0,0,0,0,0,0,0,0,0,104,46,1,0,96,56,1,0,0,0,0,0,0,0,0,0,128,46,1,0,96,56,1,0,0,0,0,0,232,39,1,0,152,46,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,168,57,1,0,2,0,0,0,232,39,1,0,192,46,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,168,57,1,0,2,0,0,0,232,39,1,0,232,46,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,168,57,1,0,2,0,0,0,232,39,1,0,16,47,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,168,57,1,0,2,0,0,0,0,0,0,0,56,47,1,0,24,57,1,0,0,0,0,0,0,0,0,0,80,47,1,0,96,56,1,0,0,0,0,0,232,39,1,0,104,47,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,136,58,1,0,2,0,0,0,232,39,1,0,128,47,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,136,58,1,0,2,0,0,0,0,0,0,0,152,47,1,0,0,0,0,0,192,47,1,0,0,0,0,0,232,47,1,0,176,57,1,0,0,0,0,0,0,0,0,0,8,48,1,0,64,56,1,0,0,0,0,0,0,0,0,0,48,48,1,0,64,56,1,0,0,0,0,0,0,0,0,0,88,48,1,0,0,0,0,0,144,48,1,0,0,0,0,0,200,48,1,0,0,0,0,0,232,48,1,0,0,0,0,0,8,49,1,0,0,0,0,0,40,49,1,0,0,0,0,0,72,49,1,0,232,39,1,0,96,49,1,0,0,0,0,0,1,0,0,0,184,53,1,0,3,244,255,255,232,39,1,0,144,49,1,0,0,0,0,0,1,0,0,0,200,53,1,0,3,244,255,255,232,39,1,0,192,49,1,0,0,0,0,0,1,0,0,0,184,53,1,0,3,244,255,255,232,39,1,0,240,49,1,0,0,0,0,0,1,0,0,0,200,53,1,0,3,244,255,255,0,0,0,0,32,50,1,0,240,52,1,0,0,0,0,0,0,0,0,0,56,50,1,0,0,0,0,0,80,50,1,0,16,57,1,0,0,0,0,0,0,0,0,0,104,50,1,0,0,57,1,0,0,0,0,0,0,0,0,0,136,50,1,0,8,57,1,0,0,0,0,0,0,0,0,0,168,50,1,0,0,0,0,0,200,50,1,0,0,0,0,0,232,50,1,0,0,0,0,0,8,51,1,0,232,39,1,0,40,51,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,128,58,1,0,2,0,0,0,232,39,1,0,72,51,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,128,58,1,0,2,0,0,0,232,39,1,0,104,51,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,128,58,1,0,2,0,0,0,232,39,1,0,136,51,1,0,0,0,0,0,2,0,0,0,96,56,1,0,2,0,0,0,128,58,1,0,2,0,0,0,0,0,0,0,168,51,1,0,0,0,0,0,192,51,1,0,0,0,0,0,216,51,1,0,0,0,0,0,240,51,1,0,0,57,1,0,0,0,0,0,0,0,0,0,8,52,1,0,8,57,1,0,0,0,0,0,0,0,0,0,32,52,1,0,216,58,1,0,0,0,0,0,0,0,0,0,72,52,1,0,216,58,1,0,0,0,0,0,0,0,0,0,112,52,1,0,232,58,1,0,0,0,0,0,0,0,0,0,152,52,1,0,192,52,1,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,236,0,0,0,176,1,0,0,192,255,255,255,192,255,255,255,0,0,0,0,218,1,0,0,104,0,0,0,108,0,0,0,0,0,0,0,0,0,0,0,236,0,0,0,176,1,0,0,148,255,255,255,148,255,255,255,0,0,0,0,218,1,0,0,104,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,48,49,50,51,52,53,54,55,56,57,97,98,99,100,101,102,65,66,67,68,69,70,120,88,43,45,112,80,105,73,110,78,0,0,0,0,0,0,0,0,255,127,230,63,152,1,0,0,255,127,16,126,231,72,0,0,255,127,159,50,31,0,0,0,255,127,224,127,32,61,0,0,255,127,159,50,31,0,0,0,255,127,230,63,0,2,0,0,255,127,159,50,31,0,0,0,255,127,16,126,231,72,0,0,255,127,230,63,0,2,0,0,255,127,176,86,207,33,0,0,255,127,172,126,192,64,0,0,255,127,159,50,31,0,0,0,255,127,159,50,31,0,0,0,224,127,0,124,0,48,0,0,255,127,230,63,0,2,0,0,255,127,172,126,192,64,0,0,255,127,230,63,0,2,0,0,255,127,159,50,31,0,0,0,255,127,16,126,231,72,0,0,255,127,224,3,0,26,32,1,255,127,159,50,31,0,0,0,255,127,16,126,231,72,0,0,255,127,230,63,0,2,0,0,255,127,159,50,31,0,0,0,255,127,172,126,192,64,0,0,255,127,159,50,31,0,0,0,255,127,230,63,0,2,0,0,255,127,230,63,0,2,0,0,255,127,16,126,231,72,0,0,255,127,159,50,31,0,0,0,255,127,59,70,81,41,0,0,255,127,16,126,231,72,0,0,255,127,172,126,192,64,0,0,255,127,59,70,81,41,0,0,8,127,64,127,224,72,0,36,255,127,255,46,0,124,31,0,255,127,159,50,31,0,0,0,255,127,16,126,231,72,0,0,255,127,239,127,31,2,0,124,249,127,189,51,6,78,107,45,255,127,192,125,0,73,0,0,255,127,159,50,31,0,0,0,127,82,224,127,128,1,0,0,138,125,0,104,0,48,0,0,31,0,255,127,239,127,31,2,96,43,0,126,224,127,255,127,255,127,255,127,159,50,31,0,255,127,16,126,231,72,0,0,224,55,255,127,73,125,0,0,255,127,255,127,159,50,31,0,255,127,172,126,192,64,0,0,243,127,223,74,78,50,231,0,8,127,64,127,224,72,0,36,255,127,16,126,231,72,0,0,255,127,176,86,207,33,0,0,255,127,192,125,0,73,0,0,255,127,255,46,0,124,31,0,255,127,224,127,0,124,0,0,255,127,224,127,0,124,0,0,255,127,255,46,0,124,31,0,255,127,96,126,0,124,0,0,255,127,96,126,0,124,0,0,255,127,255,46,0,124,31,0,255,127,224,43,0,125,0,0,255,127,224,43,0,125,0,0,255,127,255,46,0,124,31,0,255,127,230,63,152,1,0,0,255,127,16,126,231,72,0,0,255,127,16,126,231,72,0,0,152,127,112,102,165,65,193,44,255,127,172,126,192,64,0,0,255,127,172,126,192,64,0,0,255,127,172,126,192,64,0,0,255,127,230,63,0,2,0,0,255,127,230,63,0,2,0,0,255,127,172,126,192,64,0,0,255,127,159,50,31,0,0,0,255,127,159,50,31,0,0,0,255,127,230,63,0,2,0,0,255,127,16,126,231,72,0,0,255,127,16,126,231,72,0,0,255,127,59,70,81,41,0,0,255,127,16,126,231,72,0,0,255,127,16,126,231,72,0,0,255,127,59,70,81,41,0,0,8,127,64,127,224,72,0,36,8,127,64,127,224,72,0,36,223,90,242,127,104,85,0,0,0,0,255,127,16,126,231,72,0,0,255,127,16,126,231,72,127,82,224,127,128,1,0,0,138,125,0,104,0,48,0,0,138,125,0,104,0,48,0,0,255,127,96,126,0,124,0,0,255,127,16,126,231,72,0,0,255,127,16,126,231,72,0,0,255,127,224,43,0,125,0,0,255,127,16,126,231,72,0,0,255,127,16,126,231,72,0,0,255,127,224,63,192,89,0,0,255,127,16,126,231,72,0,0,255,127,16,126,231,72,0,0,255,127,176,86,207,33,0,0,255,127,192,125,0,73,0,0,255,127,192,125,0,73,0,0,255,127,59,70,81,41,0,0,255,127,59,70,81,41,0,0,8,127,64,127,224,72,0,36,255,127,159,50,31,0,0,0,255,127,159,50,31,0,0,0,255,127,16,126,231,72,0,0,255,127,230,63,152,1,0,0,255,127,16,126,231,72,0,0,255,127,230,63,152,1,0,0,255,127,16,126,231,72,0,0,255,127,230,63,0,2,0,0,255,127,16,126,231,72,0,0,255,127,59,70,81,41,0,0,255,127,16,126,231,72,0,0,255,127,59,70,81,41,0,0,255,127,159,50,31,0,0,0,255,127,16,126,231,72,0,0,255,127,159,50,31,0,0,0,255,127,176,86,207,33,0,0,255,127,192,125,0,73,0,0,255,127,176,86,207,33,0,0,244,127,82,126,95,74,0,0,244,127,82,126,95,74,0,0,244,127,82,126,95,74,0,0,255,127,148,82,74,41,0,0,255,127,148,82,74,41,0,0,255,127,148,82,74,41,0,0,0,0,16,2,96,127,255,127,0,0,16,2,96,127,255,127,0,0,16,2,96,127,255,127,255,127,172,126,192,64,0,0,255,127,172,126,192,64,0,0,255,127,172,126,192,64,0,0,127,82,224,127,128,1,0,0,127,82,224,127,128,1,0,0,127,82,224,127,128,1,0,0,255,127,224,127,0,124,0,0,255,127,224,127,0,124,0,0,255,127,224,127,0,124,0,0,255,127,96,126,0,124,0,0])
.concat([255,127,96,126,0,124,0,0,255,127,96,126,0,124,0,0,255,127,224,43,0,125,0,0,255,127,224,43,0,125,0,0,255,127,224,43,0,125,0,0,112,117,0,0,208,63,1,0,144,114,0,0,240,61,1,0,232,112,0,0,216,61,1,0,104,111,0,0,64,60,1,0,0,110,0,0,0,64,1,0,64,108,0,0,232,60,1,0,168,106,0,0,144,61,1,0,16,105,0,0,248,59,1,0,200,103,0,0,248,59,1,0,232,101,0,0,192,61,1,0,160,99,0,0,64,60,1,0,120,96,0,0,240,61,1,0,160,95,0,0,104,62,1,0,176,94,0,0,136,60,1,0,112,93,0,0,136,60,1,0,80,92,0,0,136,60,1,0,64,91,0,0,24,61,1,0,88,90,0,0,224,62,1,0,56,89,0,0,216,61,1,0,200,87,0,0,184,63,1,0,24,86,0,0,0,61,1,0,112,83,0,0,152,62,1,0,248,81,0,0,160,63,1,0,208,80,0,0,184,63,1,0,48,80,0,0,152,62,1,0,216,79,0,0,152,62,1,0,120,79,0,0,48,61,1,0,248,78,0,0,48,61,1,0,48,78,0,0,240,61,1,0,160,77,0,0,152,62,1,0,104,76,0,0,208,60,1,0,0,75,0,0,248,62,1,0,40,74,0,0,40,63,1,0,104,73,0,0,144,61,1,0,128,72,0,0,8,62,1,0,224,71,0,0,112,60,1,0,8,71,0,0,216,61,1,0,72,70,0,0,184,63,1,0,32,69,0,0,208,60,1,0,56,68,0,0,208,60,1,0,120,67,0,0,80,62,1,0,136,65,0,0,208,60,1,0,144,64,0,0,64,60,1,0,80,63,0,0,88,60,1,0,144,62,0,0,184,63,1,0,0,62,0,0,128,62,1,0,96,61,0,0,184,63,1,0,216,60,0,0,184,60,1,0,16,60,0,0,64,60,1,0,64,59,0,0,64,60,1,0,24,58,0,0,64,60,1,0,64,56,0,0,224,59,1,0,80,55,0,0,144,61,1,0,192,53,0,0,176,62,1,0,16,53,0,0,88,60,1,0,152,52,0,0,64,60,1,0,248,51,0,0,216,61,1,0,112,51,0,0,88,60,1,0,80,50,0,0,128,59,1,0,160,49,0,0,216,61,1,0,192,48,0,0,216,61,1,0,200,46,0,0,184,63,1,0,0,46,0,0,200,62,1,0,64,45,0,0,32,62,1,0,136,44,0,0,64,63,1,0,40,44,0,0,248,62,1,0,152,43,0,0,16,63,1,0,16,43,0,0,232,63,1,0,128,42,0,0,72,61,1,0,184,214,0,0,88,63,1,0,200,213,0,0,64,60,1,0,192,211,0,0,64,60,1,0,32,211,0,0,64,60,1,0,72,210,0,0,88,60,1,0,152,209,0,0,0,61,1,0,224,208,0,0,160,63,1,0,24,208,0,0,160,63,1,0,112,207,0,0,184,63,1,0,184,205,0,0,248,59,1,0,208,204,0,0,248,59,1,0,96,203,0,0,64,60,1,0,16,201,0,0,0,64,1,0,224,199,0,0,56,62,1,0,104,198,0,0,64,60,1,0,112,197,0,0,24,61,1,0,0,197,0,0,48,61,1,0,208,195,0,0,0,61,1,0,8,195,0,0,232,63,1,0,64,194,0,0,120,61,1,0,160,193,0,0,0,64,1,0,200,192,0,0,72,61,1,0,160,191,0,0,144,61,1,0,112,190,0,0,72,61,1,0,152,189,0,0,216,61,1,0,48,189,0,0,0,61,1,0,200,188,0,0,0,61,1,0,56,188,0,0,240,61,1,0,152,187,0,0,88,60,1,0,80,187,0,0,144,61,1,0,8,187,0,0,200,59,1,0,112,186,0,0,160,60,1,0,112,185,0,0,240,61,1,0,168,103,0,0,136,63,1,0,184,184,0,0,184,63,1,0,88,184,0,0,96,61,1,0,32,184,0,0,96,61,1,0,176,183,0,0,120,61,1,0,96,183,0,0,128,62,1,0,48,183,0,0,16,60,1,0,120,173,0,0,176,59,1,0,152,172,0,0,184,63,1,0,88,172,0,0,112,60,1,0,8,172,0,0,168,61,1,0,168,171,0,0,144,61,1,0,0,173,0,0,136,63,1,0,8,171,0,0,24,64,1,0,232,169,0,0,160,63,1,0,144,169,0,0,232,63,1,0,216,168,0,0,112,63,1,0,56,168,0,0,40,60,1,0,216,167,0,0,152,59,1,0,0,0,0,64,0,16,0,80,0,4,0,68,0,20,0,84,0,1,0,65,0,17,0,81,0,5,0,69,0,21,0,85,64,0,64,64,64,16,64,80,64,4,64,68,64,20,64,84,64,1,64,65,64,17,64,81,64,5,64,69,64,21,64,85,16,0,16,64,16,16,16,80,16,4,16,68,16,20,16,84,16,1,16,65,16,17,16,81,16,5,16,69,16,21,16,85,80,0,80,64,80,16,80,80,80,4,80,68,80,20,80,84,80,1,80,65,80,17,80,81,80,5,80,69,80,21,80,85,4,0,4,64,4,16,4,80,4,4,4,68,4,20,4,84,4,1,4,65,4,17,4,81,4,5,4,69,4,21,4,85,68,0,68,64,68,16,68,80,68,4,68,68,68,20,68,84,68,1,68,65,68,17,68,81,68,5,68,69,68,21,68,85,20,0,20,64,20,16,20,80,20,4,20,68,20,20,20,84,20,1,20,65,20,17,20,81,20,5,20,69,20,21,20,85,84,0,84,64,84,16,84,80,84,4,84,68,84,20,84,84,84,1,84,65,84,17,84,81,84,5,84,69,84,21,84,85,1,0,1,64,1,16,1,80,1,4,1,68,1,20,1,84,1,1,1,65,1,17,1,81,1,5,1,69,1,21,1,85,65,0,65,64,65,16,65,80,65,4,65,68,65,20,65,84,65,1,65,65,65,17,65,81,65,5,65,69,65,21,65,85,17,0,17,64,17,16,17,80,17,4,17,68,17,20,17,84,17,1,17,65,17,17,17,81,17,5,17,69,17,21,17,85,81,0,81,64,81,16,81,80,81,4,81,68,81,20,81,84,81,1,81,65,81,17,81,81,81,5,81,69,81,21,81,85,5,0,5,64,5,16,5,80,5,4,5,68,5,20,5,84,5,1,5,65,5,17,5,81,5,5,5,69,5,21,5,85,69,0,69,64,69,16,69,80,69,4,69,68,69,20,69,84,69,1,69,65,69,17,69,81,69,5,69,69,69,21,69,85,21,0,21,64,21,16,21,80,21,4,21,68,21,20,21,84,21,1,21,65,21,17,21,81,21,5,21,69,21,21,21,85,85,0,85,64,85,16,85,80,85,4,85,68,85,20,85,84,85,1,85,65,85,17,85,81,85,5,85,69,85,21,85,85,0,0,1,0,4,0,5,0,16,0,17,0,20,0,21,0,64,0,65,0,68,0,69,0,80,0,81,0,84,0,85,0,0,1,1,1,4,1,5,1,16,1,17,1,20,1,21,1,64,1,65,1,68,1,69,1,80,1,81,1,84,1,85,1,0,4,1,4,4,4,5,4,16,4,17,4,20,4,21,4,64,4,65,4,68,4,69,4,80,4,81,4,84,4,85,4,0,5,1,5,4,5,5,5,16,5,17,5,20,5,21,5,64,5,65,5,68,5,69,5,80,5,81,5,84,5,85,5,0,16,1,16,4,16,5,16,16,16,17,16,20,16,21,16,64,16,65,16,68,16,69,16,80,16,81,16,84,16,85,16,0,17,1,17,4,17,5,17,16,17,17,17,20,17,21,17,64,17,65,17,68,17,69,17,80,17,81,17,84,17,85,17,0,20,1,20,4,20,5,20,16,20,17,20,20,20,21,20,64,20,65,20,68,20,69,20,80,20,81,20,84,20,85,20,0,21,1,21,4,21,5,21,16,21,17,21,20,21,21,21,64,21,65,21,68,21,69,21,80,21,81,21,84,21,85,21,0,64,1,64,4,64,5,64,16,64,17,64,20,64,21,64,64,64,65,64,68,64,69,64,80,64,81,64,84,64,85,64,0,65,1,65,4,65,5,65,16,65,17,65,20,65,21,65,64,65,65,65,68,65,69,65,80,65,81,65,84,65,85,65,0,68,1,68,4,68,5,68,16,68,17,68,20,68,21,68,64,68,65,68,68,68,69,68,80,68,81,68,84,68,85,68,0,69,1,69,4,69,5,69,16,69,17,69,20,69,21,69,64,69,65,69,68,69,69,69,80,69,81,69,84,69,85,69,0,80,1,80,4,80,5,80,16,80,17,80,20,80,21,80,64,80,65,80,68,80,69,80,80,80,81,80,84,80,85,80,0,81,1,81,4,81,5,81,16,81,17,81,20,81,21,81,64,81,65,81,68,81,69,81,80,81,81,81,84,81,85,81,0,84,1,84,4,84,5,84,16,84,17,84,20,84,21,84,64,84,65,84,68,84,69,84,80,84,81,84,84,84,85,84,0,85,1,85,4,85,5,85,16,85,17,85,20,85,21,85,64,85,65,85,68,85,69,85,80,85,81,85,84,85,85,85,112,1,0,0,76,0,0,0,0,0,0,0,0,0,0,0,126,0,0,0,108,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,90,0,0,0,133,0,0,0,0,0,0,0,12,1,0,0,110,0,0,0,132,0,0,0,0,0,0,0,78,1,0,0,34,0,0,0,131,0,0,0,0,0,0,0,174,1,0,0,44,0,0,0,130,0,0,0,0,0,0,0,156,0,0,0,92,0,0,0,129,0,0,0,0,0,0,0,76,1,0,0,96,0,0,0,128,0,0,0,0,0,0,0,50,0,0,0,114,0,0,0,149,0,0,0,0,0,0,0,64,0,0,0,40,0,0,0,148,0,0,0,0,0,0,0,98,1,0,0,22,0,0,0,147,0,0,0,0,0,0,0,152,0,0,0,64,0,0,0,146,0,0,0,0,0,0,0,38,1,0,0,80,0,0,0,145,0,0,0,0,0,0,0,36,1,0,0,8,0,0,0,144,0,0,0,0,0,0,0,224,1,0,0,6,0,0,0,141,0,0,0,0,0,0,0,86,0,0,0,84,0,0,0,140,0,0,0,0,0,0,0,26,1,0,0,14,0,0,0,139,0,0,0,0,0,0,0,254,1,0,0,50,0,0,0,138,0,0,0,0,0,0,0,108,0,0,0,20,0,0,0,137,0,0,0,0,0,0,0,160,1,0,0,118,0,0,0,136,0,0,0,0,0,0,0,124,1,0,0,28,0,0,0,0,0,0,0,0,0,0,0,252,1,0,0,32,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,10,4,6,8,0,0,0,0,0,0,0,0,0,0,0,0,152,47,138,66,145,68,55,113,207,251,192,181,165,219,181,233,91,194,86,57,241,17,241,89,164,130,63,146,213,94,28,171,152,170,7,216,1,91,131,18,190,133,49,36,195,125,12,85,116,93,190,114,254,177,222,128,167,6,220,155,116,241,155,193,193,105,155,228,134,71,190,239,198,157,193,15,204,161,12,36,111,44,233,45,170,132,116,74,220,169,176,92,218,136,249,118,82,81,62,152,109,198,49,168,200,39,3,176,199,127,89,191,243,11,224,198,71,145,167,213,81,99,202,6,103,41,41,20,133,10,183,39,56,33,27,46,252,109,44,77,19,13,56,83,84,115,10,101,187,10,106,118,46,201,194,129,133,44,114,146,161,232,191,162,75,102,26,168,112,139,75,194,163,81,108,199,25,232,146,209,36,6,153,214,133,53,14,244,112,160,106,16,22,193,164,25,8,108,55,30,76,119,72,39,181,188,176,52,179,12,28,57,74,170,216,78,79,202,156,91,243,111,46,104,238,130,143,116,111,99,165,120,20,120,200,132,8,2,199,140,250,255,190,144,235,108,80,164,247,163,249,190,242,120,113,198,103,230,9,106,133,174,103,187,114,243,110,60,58,245,79,165,127,82,14,81,140,104,5,155,171,217,131,31,25,205,224,91])
, "i8", ALLOC_NONE, Runtime.GLOBAL_BASE)
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
  function _emscripten_set_canvas_size(width, height) {
      Browser.setCanvasSize(width, height);
    }
  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
      Module['noExitRuntime'] = true;
      Browser.mainLoop.runner = function() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        if (Module['preMainLoop']) {
          Module['preMainLoop']();
        }
        Runtime.dynCall('v', func);
        if (Module['postMainLoop']) {
          Module['postMainLoop']();
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        }
      } else {
        Browser.mainLoop.scheduler = function() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        }
      }
      Browser.mainLoop.scheduler();
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:35,EIDRM:36,ECHRNG:37,EL2NSYNC:38,EL3HLT:39,EL3RST:40,ELNRNG:41,EUNATCH:42,ENOCSI:43,EL2HLT:44,EDEADLK:45,ENOLCK:46,EBADE:50,EBADR:51,EXFULL:52,ENOANO:53,EBADRQC:54,EBADSLT:55,EDEADLOCK:56,EBFONT:57,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:74,EDOTDOT:76,EBADMSG:77,ENOTUNIQ:80,EBADFD:81,EREMCHG:82,ELIBACC:83,ELIBBAD:84,ELIBSCN:85,ELIBMAX:86,ELIBEXEC:87,ENOSYS:88,ENOTEMPTY:90,ENAMETOOLONG:91,ELOOP:92,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:106,EPROTOTYPE:107,ENOTSOCK:108,ENOPROTOOPT:109,ESHUTDOWN:110,ECONNREFUSED:111,EADDRINUSE:112,ECONNABORTED:113,ENETUNREACH:114,ENETDOWN:115,ETIMEDOUT:116,EHOSTDOWN:117,EHOSTUNREACH:118,EINPROGRESS:119,EALREADY:120,EDESTADDRREQ:121,EMSGSIZE:122,EPROTONOSUPPORT:123,ESOCKTNOSUPPORT:124,EADDRNOTAVAIL:125,ENETRESET:126,EISCONN:127,ENOTCONN:128,ETOOMANYREFS:129,EUSERS:131,EDQUOT:132,ESTALE:133,ENOTSUP:134,ENOMEDIUM:135,EILSEQ:138,EOVERFLOW:139,ECANCELED:140,ENOTRECOVERABLE:141,EOWNERDEAD:142,ESTRPIPE:143};
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"No message of desired type",36:"Identifier removed",37:"Channel number out of range",38:"Level 2 not synchronized",39:"Level 3 halted",40:"Level 3 reset",41:"Link number out of range",42:"Protocol driver not attached",43:"No CSI structure available",44:"Level 2 halted",45:"Deadlock condition",46:"No record locks available",50:"Invalid exchange",51:"Invalid request descriptor",52:"Exchange full",53:"No anode",54:"Invalid request code",55:"Invalid slot",56:"File locking deadlock error",57:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",74:"Multihop attempted",76:"Cross mount point (not really error)",77:"Trying to read unreadable message",80:"Given log. name not unique",81:"f.d. invalid for this operation",82:"Remote address changed",83:"Can   access a needed shared lib",84:"Accessing a corrupted shared lib",85:".lib section in a.out corrupted",86:"Attempting to link in too many libs",87:"Attempting to exec a shared library",88:"Function not implemented",90:"Directory not empty",91:"File or path name too long",92:"Too many symbolic links",95:"Operation not supported on transport endpoint",96:"Protocol family not supported",104:"Connection reset by peer",105:"No buffer space available",106:"Address family not supported by protocol family",107:"Protocol wrong type for socket",108:"Socket operation on non-socket",109:"Protocol not available",110:"Can't send after socket shutdown",111:"Connection refused",112:"Address already in use",113:"Connection aborted",114:"Network is unreachable",115:"Network interface is not configured",116:"Connection timed out",117:"Host is down",118:"Host is unreachable",119:"Connection already in progress",120:"Socket already connected",121:"Destination address required",122:"Message too long",123:"Unknown protocol",124:"Socket type not supported",125:"Address not available",126:"Connection reset by network",127:"Socket is already connected",128:"Socket is not connected",129:"Too many references",131:"Too many users",132:"Quota exceeded",133:"Stale file handle",134:"Not supported",135:"No medium (in tape drive)",138:"Illegal byte sequence",139:"Value too large for defined data type",140:"Operation canceled",141:"State not recoverable",142:"Previous owner died",143:"Streams pipe error"};
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value
      return value;
    }
  var VFS=undefined;
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path, ext) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var f = PATH.splitPath(path)[2];
        if (ext && f.substr(-1 * ext.length) === ext) {
          f = f.substr(0, f.length - ext.length);
        }
        return f;
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.filter(function(p, index) {
          if (typeof p !== 'string') {
            throw new TypeError('Arguments to path.join must be strings');
          }
          return p;
        }).join('/'));
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            continue;
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  var MEMFS={CONTENT_OWNING:1,CONTENT_FLEXIBLE:2,CONTENT_FIXED:3,ensureFlexible:function (node) {
        if (node.contentMode !== MEMFS.CONTENT_FLEXIBLE) {
          var contents = node.contents;
          node.contents = Array.prototype.slice.call(contents);
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        }
      },mount:function (mount) {
        return MEMFS.create_node(null, '/', 0040000 | 0777, 0);
      },create_node:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            lookup: MEMFS.node_ops.lookup,
            mknod: MEMFS.node_ops.mknod,
            mknod: MEMFS.node_ops.mknod,
            rename: MEMFS.node_ops.rename,
            unlink: MEMFS.node_ops.unlink,
            rmdir: MEMFS.node_ops.rmdir,
            readdir: MEMFS.node_ops.readdir,
            symlink: MEMFS.node_ops.symlink
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek
          };
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek,
            read: MEMFS.stream_ops.read,
            write: MEMFS.stream_ops.write,
            allocate: MEMFS.stream_ops.allocate,
            mmap: MEMFS.stream_ops.mmap
          };
          node.contents = [];
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            readlink: MEMFS.node_ops.readlink
          };
          node.stream_ops = {};
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = FS.chrdev_stream_ops;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.contents.length;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.ensureFlexible(node);
            var contents = node.contents;
            if (attr.size < contents.length) contents.length = attr.size;
            else while (attr.size > contents.length) contents.push(0);
          }
        },lookup:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.create_node(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.create_node(parent, newname, 0777 | 0120000, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          var node = stream.node;
          node.timestamp = Date.now();
          var contents = node.contents;
          if (length && contents.length === 0 && position === 0 && buffer.subarray) {
            // just replace it with the new data
            assert(buffer.length);
            if (canOwn && buffer.buffer === HEAP8.buffer && offset === 0) {
              node.contents = buffer; // this is a subarray of the heap, and we can own it
              node.contentMode = MEMFS.CONTENT_OWNING;
            } else {
              node.contents = new Uint8Array(buffer.subarray(offset, offset+length));
              node.contentMode = MEMFS.CONTENT_FIXED;
            }
            return length;
          }
          MEMFS.ensureFlexible(node);
          var contents = node.contents;
          while (contents.length < position) contents.push(0);
          for (var i = 0; i < length; i++) {
            contents[position + i] = buffer[offset + i];
          }
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.contents.length;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.ensureFlexible(stream.node);
          var contents = stream.node.contents;
          var limit = offset + length;
          while (limit > contents.length) contents.push(0);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 0x02) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < contents.length) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);var FS={root:null,nodes:[null],devices:[null],streams:[null],nextInode:1,name_table:null,currentPath:"/",initialized:false,ignorePermissions:true,ErrnoError:function ErrnoError(errno) {
          this.errno = errno;
          for (var key in ERRNO_CODES) {
            if (ERRNO_CODES[key] === errno) {
              this.code = key;
              break;
            }
          }
          this.message = ERRNO_MESSAGES[errno];
        },handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + new Error().stack;
        return ___setErrNo(e.errno);
      },hashName:function (parentid, name) {
        var hash = 0;
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.name_table.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.name_table[hash];
        FS.name_table[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.name_table[hash] === node) {
          FS.name_table[hash] = node.name_next;
        } else {
          var current = FS.name_table[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.name_table[hash]; node; node = node.name_next) {
          if (node.parent.id === parent.id && node.name === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        var node = {
          id: FS.nextInode++,
          name: name,
          mode: mode,
          node_ops: {},
          stream_ops: {},
          rdev: rdev,
          parent: null,
          mount: null
        };
        if (!parent) {
          parent = node;  // root node sets parent to itself
        }
        node.parent = parent;
        node.mount = parent.mount;
        // compatibility
        var readMode = 292 | 73;
        var writeMode = 146;
        // NOTE we must use Object.defineProperties instead of individual calls to
        // Object.defineProperty in order to make closure compiler happy
        Object.defineProperties(node, {
          read: {
            get: function() { return (node.mode & readMode) === readMode; },
            set: function(val) { val ? node.mode |= readMode : node.mode &= ~readMode; }
          },
          write: {
            get: function() { return (node.mode & writeMode) === writeMode; },
            set: function(val) { val ? node.mode |= writeMode : node.mode &= ~writeMode; }
          },
          isFolder: {
            get: function() { return FS.isDir(node.mode); },
          },
          isDevice: {
            get: function() { return FS.isChrdev(node.mode); },
          },
        });
        FS.hashAddNode(node);
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return node.mounted;
      },isFile:function (mode) {
        return (mode & 0170000) === 0100000;
      },isDir:function (mode) {
        return (mode & 0170000) === 0040000;
      },isLink:function (mode) {
        return (mode & 0170000) === 0120000;
      },isChrdev:function (mode) {
        return (mode & 0170000) === 0020000;
      },isBlkdev:function (mode) {
        return (mode & 0170000) === 0060000;
      },isFIFO:function (mode) {
        return (mode & 0170000) === 0010000;
      },isSocket:function (mode) {
        return (mode & 0140000) === 0140000;
      },cwd:function () {
        return FS.currentPath;
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.currentPath, path);
        opts = opts || { recurse_count: 0 };
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
        // start at the root
        var current = FS.root;
        var current_path = '/';
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join(current_path, parts[i]);
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            current = current.mount.root;
          }
          // follow symlinks
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            return path ? PATH.join(node.mount.mountpoint, path) : node.mount.mountpoint;
          }
          path = path ? PATH.join(node.name, path) : node.name;
          node = node.parent;
        }
      },flagModes:{"r":0,"rs":8192,"r+":2,"w":1537,"wx":3585,"xw":3585,"w+":1538,"wx+":3586,"xw+":3586,"a":521,"ax":2569,"xa":2569,"a+":522,"ax+":2570,"xa+":2570},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 3;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 1024)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        return FS.nodePermissions(dir, 'x');
      },mayMknod:function (mode) {
        switch (mode & 0170000) {
          case 0100000:
          case 0020000:
          case 0060000:
          case 0010000:
          case 0140000:
            return 0;
          default:
            return ERRNO_CODES.EINVAL;
        }
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.currentPath) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 3) !== 0 ||  // opening for write
              (flags & 1024)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 1;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        // compatibility
        Object.defineProperties(stream, {
          object: {
            get: function() { return stream.node; },
            set: function(val) { stream.node = val; }
          },
          isRead: {
            get: function() { return (stream.flags & 3) !== 1; }
          },
          isWrite: {
            get: function() { return (stream.flags & 3) !== 0; }
          },
          isAppend: {
            get: function() { return (stream.flags & 8); }
          }
        });
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join(parent, part);
          try {
            FS.mkdir(current, 0777);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(path, mode | 146);
          var stream = FS.open(path, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(path, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
              if (!hasByteServing) chunkSize = datalength;
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp', 0777);
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev', 0777);
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', 0666, FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', 0666, FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', 0666, FS.makedev(6, 0));
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm', 0777);
        FS.mkdir('/dev/shm/tmp', 0777);
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=stdin.fd;
        assert(stdin.fd === 1, 'invalid handle for stdin (' + stdin.fd + ')');
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=stdout.fd;
        assert(stdout.fd === 2, 'invalid handle for stdout (' + stdout.fd + ')');
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=stderr.fd;
        assert(stderr.fd === 3, 'invalid handle for stderr (' + stderr.fd + ')');
      },staticInit:function () {
        FS.name_table = new Array(4096);
        FS.root = FS.createNode(null, '/', 0040000 | 0777, 0);
        FS.mount(MEMFS, {}, '/');
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },mount:function (type, opts, mountpoint) {
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          root: null
        };
        var lookup;
        if (mountpoint) {
          lookup = FS.lookupPath(mountpoint, { follow: false });
        }
        // create a root node for the fs
        var root = type.mount(mount);
        root.mount = mount;
        mount.root = root;
        // assign the mount info to the mountpoint's node
        if (lookup) {
          lookup.node.mount = mount;
          lookup.node.mounted = true;
          // compatibility update FS.root if we mount to /
          if (mountpoint === '/') {
            FS.root = mount.root;
          }
        }
        return root;
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode &= 4095;
        mode |= 0100000;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode &= 511 | 0001000;
        mode |= 0040000;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        mode |= 0020000;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
      },readlink:function (path) {
        var lookup = FS.lookupPath(path, { follow: false });
        var link = lookup.node;
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        path = PATH.normalize(path);
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 0666 : mode;
        if ((flags & 512)) {
          mode = (mode & 4095) | 0100000;
        } else {
          mode = 0;
        }
        var node;
        try {
          var lookup = FS.lookupPath(path, {
            follow: !(flags & 0200000)
          });
          node = lookup.node;
          path = lookup.path;
        } catch (e) {
          // ignore
        }
        // perhaps we need to create the node
        if ((flags & 512)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 2048)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~1024;
        }
        // check permissions
        var err = FS.mayOpen(node, flags);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // do truncation if necessary
        if ((flags & 1024)) {
          FS.truncate(node, 0);
        }
        // register the stream with the filesystem
        var stream = FS.createStream({
          path: path,
          node: node,
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        if (stream.flags & 8) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.errnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      }};function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module.print('exit(' + status + ') called');
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }
  var SOCKFS={mount:function (mount) {
        return FS.createNode(null, '/', 0040000 | 0777, 0);
      },nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 0140000, 0);
        node.sock = sock;
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              var url = 'ws://' + addr + ':' + port;
              // the node ws library API is slightly different than the browser's
              var opts = ENVIRONMENT_IS_NODE ? {} : ['binary'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
          var handleOpen = function () {
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
          var handleMessage = function(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
          };
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('error', function() {
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onmessage = function(event) {
              handleMessage(event.data);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (0 /* XXX missing C define POLLRDNORM */ | 1) : 0;
          }
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (0 /* XXX missing C define POLLRDNORM */ | 1);
          }
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 2;
          }
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 1:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODS.EOPNOTSUPP);
          }
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
              // push to queue for accept to pick up
              sock.pending.push(newsock);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
            }
          });
          sock.server.on('closed', function() {
            sock.server = null;
          });
          sock.server.on('error', function() {
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  Module["_strlen"] = _strlen;
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (flagAlwaysSigned) {
                if (currArg < 0) {
                  prefix = '-' + prefix;
                } else {
                  prefix = '+' + prefix;
                }
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (flagAlwaysSigned && currArg >= 0) {
                  argText = '+' + argText;
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }
  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i32=_memset;
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    } 
  Module["_saveSetjmp"] = _saveSetjmp;
  Module["_testSetjmp"] = _testSetjmp;var _setjmp=undefined;
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _remove(path) {
      // int remove(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/remove.html
      var ret = _unlink(path);
      if (ret == -1) ret = _rmdir(path);
      return ret;
    }
  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }
  var ___timespec_struct_layout={__size__:8,tv_sec:0,tv_nsec:4};function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_sec))>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_nsec))>>2)];
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_sec))>>2)]=0
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_nsec))>>2)]=0
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }
  function _strrchr(ptr, chr) {
      var ptr2 = ptr + _strlen(ptr);
      do {
        if (HEAP8[(ptr2)] == chr) return ptr2;
        ptr2--;
      } while (ptr2 >= ptr);
      return 0;
    }
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  var _llvm_pow_f32=Math.pow;
  function _round(x) {
      return (x < 0) ? -Math.round(-x) : Math.round(x);
    }var _roundf=_round;
  function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }
  function _isspace(chr) {
      return (chr == 32) || (chr >= 9 && chr <= 13);
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm["setTempRet0"]((tempDouble=ret,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)),ret>>>0)|0);
      }
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }
  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function _llvm_lifetime_start() {}
  function _llvm_lifetime_end() {}
  var _llvm_memset_p0i8_i64=_memset;
  var ___dirent_struct_layout={__size__:1040,d_ino:0,d_name:4,d_off:1028,d_reclen:1032,d_type:1036};function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStream(stream);
      stream.eof = false;
      return 0;
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStream(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }
  function _rewind(stream) {
      // void rewind(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rewind.html
      _fseek(stream, 0, 0);  // SEEK_SET.
      var streamObj = FS.getStream(stream);
      if (streamObj) streamObj.error = false;
    }
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStream(stream);
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)|0)]=streamObj.ungotten.pop()
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(stream, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return Math.floor(bytesRead / size);
    }
  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      stream = FS.getStream(stream);
      return Number(stream && stream.eof);
    }
  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }function _fgets(s, n, stream) {
      // char *fgets(char *restrict s, int n, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgets.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return 0;
      if (streamObj.error || streamObj.eof) return 0;
      var byte_;
      for (var i = 0; i < n - 1 && byte_ != 10; i++) {
        byte_ = _fgetc(stream);
        if (byte_ == -1) {
          if (streamObj.error || (streamObj.eof && i == 0)) return 0;
          else if (streamObj.eof) break;
        }
        HEAP8[(((s)+(i))|0)]=byte_
      }
      HEAP8[(((s)+(i))|0)]=0
      return s;
    }
  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }
  Module["_tolower"] = _tolower; 
  Module["_strncasecmp"] = _strncasecmp; 
  Module["_strcasecmp"] = _strcasecmp;
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'root';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/emscripten';
        ENV['LANG'] = 'en_US.UTF-8';
        ENV['_'] = './this.program';
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        for (var j = 0; j < line.length; j++) {
          HEAP8[(((poolPtr)+(j))|0)]=line.charCodeAt(j);
        }
        HEAP8[(((poolPtr)+(j))|0)]=0;
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  var ___tm_struct_layout={__size__:44,tm_sec:0,tm_min:4,tm_hour:8,tm_mday:12,tm_mon:16,tm_year:20,tm_wday:24,tm_yday:28,tm_isdst:32,tm_gmtoff:36,tm_zone:40};
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
      var date = {
        tm_sec: HEAP32[(((tm)+(___tm_struct_layout.tm_sec))>>2)],
        tm_min: HEAP32[(((tm)+(___tm_struct_layout.tm_min))>>2)],
        tm_hour: HEAP32[(((tm)+(___tm_struct_layout.tm_hour))>>2)],
        tm_mday: HEAP32[(((tm)+(___tm_struct_layout.tm_mday))>>2)],
        tm_mon: HEAP32[(((tm)+(___tm_struct_layout.tm_mon))>>2)],
        tm_year: HEAP32[(((tm)+(___tm_struct_layout.tm_year))>>2)],
        tm_wday: HEAP32[(((tm)+(___tm_struct_layout.tm_wday))>>2)],
        tm_yday: HEAP32[(((tm)+(___tm_struct_layout.tm_yday))>>2)],
        tm_isdst: HEAP32[(((tm)+(___tm_struct_layout.tm_isdst))>>2)]
      };
      var pattern = Pointer_stringify(format);
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S',                 // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
      var leadingSomething = function(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
      var leadingNulls = function(value, digits) {
        return leadingSomething(value, digits, '0');
      };
      var compareByDay = function(date1, date2) {
        var sgn = function(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
      var getFirstWeekStartDate = function(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
      var getWeekBasedYear = function(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls(Math.floor(year/100),2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ),
          // or by no characters if no timezone is determinable. 
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich). 
          // If tm_isdst is zero, the standard time offset is used. 
          // If tm_isdst is greater than zero, the daylight savings time offset is used. 
          // If tm_isdst is negative, no characters are returned. 
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%Z': function(date) {
          // Replaced by the timezone name or abbreviation, or by no bytes if no timezone information exists. [ tm_isdst]
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }
  var ___tm_current=allocate(4*26, "i8", ALLOC_STATIC);
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);
  var __tzname=allocate(8, "i32*", ALLOC_STATIC);
  var __daylight=allocate(1, "i32*", ALLOC_STATIC);
  var __timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
      HEAP32[((__timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((__daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset())
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((__tzname)>>2)]=winterNamePtr
      HEAP32[(((__tzname)+(4))>>2)]=summerNamePtr
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var offsets = ___tm_struct_layout;
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getDay()
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=start.getTimezoneOffset() * 60
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=dst
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezone
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }
  function _strtok_r(s, delim, lasts) {
      var skip_leading_delim = 1;
      var spanp;
      var c, sc;
      var tok;
      if (s == 0 && (s = getValue(lasts, 'i8*')) == 0) {
        return 0;
      }
      cont: while (1) {
        c = getValue(s++, 'i8');
        for (spanp = delim; (sc = getValue(spanp++, 'i8')) != 0;) {
          if (c == sc) {
            if (skip_leading_delim) {
              continue cont;
            } else {
              setValue(lasts, s, 'i8*');
              setValue(s - 1, 0, 'i8');
              return s - 1;
            }
          }
        }
        break;
      }
      if (c == 0) {
        setValue(lasts, 0, 'i8*');
        return 0;
      }
      tok = s - 1;
      for (;;) {
        c = getValue(s++, 'i8');
        spanp = delim;
        do {
          if ((sc = getValue(spanp++, 'i8')) == c) {
            if (c == 0) {
              s = 0;
            } else {
              setValue(s - 1, 0, 'i8');
            }
            setValue(lasts, s, 'i8*');
            return tok;
          }
        } while (sc != 0);
      }
      abort('strtok_r error!');
    }
  function _qsort(base, num, size, cmp) {
      if (num == 0 || size == 0) return;
      // forward calls to the JavaScript sort method
      // first, sort the items logically
      var keys = [];
      for (var i = 0; i < num; i++) keys.push(i);
      keys.sort(function(a, b) {
        return Module['dynCall_iii'](cmp, base+a*size, base+b*size);
      });
      // apply the sort
      var temp = _malloc(num*size);
      _memcpy(temp, base, num*size);
      for (var i = 0; i < num; i++) {
        if (keys[i] == i) continue; // already in place
        _memcpy(base+i*size, temp+keys[i]*size, size);
      }
      _free(temp);
    }
  function _opendir(dirname) {
      // DIR *opendir(const char *dirname);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/opendir.html
      // NOTE: Calculating absolute path redundantly since we need to associate it
      //       with the opened stream.
      var path = Pointer_stringify(dirname);
      if (!path) {
        ___setErrNo(ERRNO_CODES.ENOENT);
        return 0;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return 0;
      }
      if (!FS.isDir(node.mode)) {
        ___setErrNo(ERRNO_CODES.ENOTDIR);
        return 0;
      }
      var err = _open(dirname, 0, allocate([0, 0, 0, 0], 'i32', ALLOC_STACK));
      // open returns 0 on failure, not -1
      return err === -1 ? 0 : err;
    }
  function _readdir_r(dirp, entry, result) {
      // int readdir_r(DIR *dirp, struct dirent *entry, struct dirent **result);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        return ___setErrNo(ERRNO_CODES.EBADF);
      }
      var entries;
      try {
        entries = FS.readdir(stream.path);
      } catch (e) {
        return FS.handleFSError(e);
      }
      if (stream.position < 0 || stream.position >= entries.length) {
        HEAP32[((result)>>2)]=0
        return 0;
      }
      var id;
      var type;
      var name = entries[stream.position];
      var offset = stream.position + 1;
      if (!name.indexOf('.')) {
        id = 1;
        type = 4;
      } else {
        var child = FS.lookupNode(stream.node, name);
        id = child.id;
        type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
               FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
               FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
               8;                             // DT_REG, regular file.
      }
      HEAP32[(((entry)+(___dirent_struct_layout.d_ino))>>2)]=id
      HEAP32[(((entry)+(___dirent_struct_layout.d_off))>>2)]=offset
      HEAP32[(((entry)+(___dirent_struct_layout.d_reclen))>>2)]=name.length + 1
      for (var i = 0; i < name.length; i++) {
        HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=name.charCodeAt(i)
      }
      HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=0
      HEAP8[(((entry)+(___dirent_struct_layout.d_type))|0)]=type
      HEAP32[((result)>>2)]=entry
      stream.position++;
      return 0;
    }function _readdir(dirp) {
      // struct dirent *readdir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // TODO Is it supposed to be safe to execute multiple readdirs?
      if (!_readdir.entry) _readdir.entry = _malloc(___dirent_struct_layout.__size__);
      if (!_readdir.result) _readdir.result = _malloc(4);
      var err = _readdir_r(dirp, _readdir.entry, _readdir.result);
      if (err) {
        ___setErrNo(err);
        return 0;
      }
      return HEAP32[((_readdir.result)>>2)];
    }
  function _closedir(dirp) {
      // int closedir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/closedir.html
      return _close(dirp);
    }
  var ___stat_struct_layout={__size__:68,st_dev:0,st_ino:4,st_mode:8,st_nlink:12,st_uid:16,st_gid:20,st_rdev:24,st_size:28,st_atime:32,st_spare1:36,st_mtime:40,st_spare2:44,st_ctime:48,st_spare3:52,st_blksize:56,st_blocks:60,st_spare4:64};function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[(((buf)+(___stat_struct_layout.st_dev))>>2)]=stat.dev;
        HEAP32[(((buf)+(___stat_struct_layout.st_ino))>>2)]=stat.ino
        HEAP32[(((buf)+(___stat_struct_layout.st_mode))>>2)]=stat.mode
        HEAP32[(((buf)+(___stat_struct_layout.st_nlink))>>2)]=stat.nlink
        HEAP32[(((buf)+(___stat_struct_layout.st_uid))>>2)]=stat.uid
        HEAP32[(((buf)+(___stat_struct_layout.st_gid))>>2)]=stat.gid
        HEAP32[(((buf)+(___stat_struct_layout.st_rdev))>>2)]=stat.rdev
        HEAP32[(((buf)+(___stat_struct_layout.st_size))>>2)]=stat.size
        HEAP32[(((buf)+(___stat_struct_layout.st_atime))>>2)]=Math.floor(stat.atime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_mtime))>>2)]=Math.floor(stat.mtime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_ctime))>>2)]=Math.floor(stat.ctime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_blksize))>>2)]=4096
        HEAP32[(((buf)+(___stat_struct_layout.st_blocks))>>2)]=stat.blocks
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _realpath(file_name, resolved_name) {
      // char *realpath(const char *restrict file_name, char *restrict resolved_name);
      // http://pubs.opengroup.org/onlinepubs/009604499/functions/realpath.html
      var absolute = FS.analyzePath(Pointer_stringify(file_name));
      if (absolute.error) {
        ___setErrNo(absolute.error);
        return 0;
      } else {
        var size = Math.min(4095, absolute.path.length);  // PATH_MAX - 1.
        for (var i = 0; i < size; i++) {
          HEAP8[(((resolved_name)+(i))|0)]=absolute.path.charCodeAt(i)
        }
        HEAP8[(((resolved_name)+(size))|0)]=0
        return resolved_name;
      }
    }
  function _getgid() {
      // gid_t getgid(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/getgid.html
      // We have just one process/group/user, all with ID 0.
      return 0;
    }var _getpid=_getgid;
  function _readlink(path, buf, bufsize) {
      // ssize_t readlink(const char *restrict path, char *restrict buf, size_t bufsize);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/readlink.html
      path = Pointer_stringify(path);
      var str;
      try {
        str = FS.readlink(path);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      str = str.slice(0, Math.max(0, bufsize - 1));
      writeStringToMemory(str, buf, true);
      return str.length;
    }
  var _sqrt=Math.sqrt;
  var _fabs=Math.abs;
  function ___errno_location() {
      return ___errno_state;
    }var ___errno=___errno_location;
  function __parseInt64(str, endptr, base, min, max, unsign) {
      var isNegative = false;
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      if (HEAP8[(str)] == 45) {
        str++;
        isNegative = true;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var ok = false;
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            ok = true; // we saw an initial zero, perhaps the entire thing is just "0"
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      start = str;
      // Get digits.
      var chr;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          str++;
          ok = true;
        }
      }
      if (!ok) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return ((asm["setTempRet0"](0),0)|0);
      }
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      try {
        var numberString = isNegative ? '-'+Pointer_stringify(start, str - start) : Pointer_stringify(start, str - start);
        i64Math.fromString(numberString, finalBase, min, max, unsign);
      } catch(e) {
        ___setErrNo(ERRNO_CODES.ERANGE); // not quite correct
      }
      return ((asm["setTempRet0"](((HEAP32[(((tempDoublePtr)+(4))>>2)])|0)),((HEAP32[((tempDoublePtr)>>2)])|0))|0);
    }function _strtoull(str, endptr, base) {
      return __parseInt64(str, endptr, base, 0, '18446744073709551615', true);  // ULONG_MAX.
    }
  var _getc=_fgetc;
  function _isgraph(chr) {
      return 0x20 < chr && chr < 0x7F;
    }
  function _llvm_bswap_i32(x) {
      return ((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24);
    }
  function _isalpha(chr) {
      return (chr >= 97 && chr <= 122) ||
             (chr >= 65 && chr <= 90);
    }
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', {
              alpha: false
            });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var x, y;
          if (event.type == 'touchstart' ||
              event.type == 'touchend' ||
              event.type == 'touchmove') {
            var t = event.touches.item(0);
            if (t) {
              x = t.pageX - (window.scrollX + rect.left);
              y = t.pageY - (window.scrollY + rect.top);
            } else {
              return;
            }
          } else {
            x = event.pageX - (window.scrollX + rect.left);
            y = event.pageY - (window.scrollY + rect.top);
          }
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};var RI={temp:null,contexts:[],eventHandler:function (event) {
           var i;
           switch (event.type) {
              case 'mousemove':
                 var x = event['movementX'] || event['mozMovementX'] || event['webkitMovementX'];
                 var y = event['movementY'] || event['mozMovementY'] || event['webkitMovementY'];
                 for (i = 0; i < RI.contexts.length; i++) {
                    var oldX = HEAP32[(((RI.contexts[i].state)+(32))>>2)];
                    var oldY = HEAP32[(((RI.contexts[i].state)+(36))>>2)];
                    x += oldX;
                    y += oldY;
                    HEAP32[(((RI.contexts[i].state)+(32))>>2)]=x;
                    HEAP32[(((RI.contexts[i].state)+(36))>>2)]=y;
                 }
                 break;
              case 'mouseup':
              case 'mousedown':
                 var value;
                 var offset;
                 if (event.button === 0) offset = 40;
                 else if (event.button === 2) offset = 41;
                 else break;
                 if (event.type === 'mouseup') value = 0;
                 else value = 1;
                 for (i = 0; i < RI.contexts.length; i++) {
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 break;
              case 'keyup':
              case 'keydown':
                 var key = event.keyCode;
                 var offset = key >> 3;
                 var bit = 1 << (key & 7);
                 if (offset >= 32) throw 'key code error! bad code: ' + key;
                 for (i = 0; i < RI.contexts.length; i++) {
                    var value = HEAP8[(((RI.contexts[i].state)+(offset))|0)];
                    if (event.type === 'keyup') value &= ~bit;
                    else value |= bit;
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 event.preventDefault();
                 break;
              case 'blur':
              case 'visibilitychange':
                 for (i = 0; i < RI.contexts.length; i++) {
                    _memset(RI.contexts[i].state, 0, 42);
                 }
                 break;
           }
        }};function _RWebInputDestroy(context) {
        if (context === RI.contexts.length) {
           RI.contexts.pop();
           if (RI.contexts.length === 0) {
              document.removeEventListener('keyup', RI.eventHandler, false);
              document.removeEventListener('keydown', RI.eventHandler, false);
              document.removeEventListener('mousemove', RI.eventHandler, false);
              document.removeEventListener('mouseup', RI.eventHandler, false);
              document.removeEventListener('mousedown', RI.eventHandler, false);
              document.removeEventListener('blur', RI.eventHandler, false);
              document.removeEventListener('onvisbilitychange', RI.eventHandler, false);
           }
        }
     }
  function _RWebInputPoll(context) {
        context -= 1;
        var state = RI.contexts[context].state;
        _memcpy(RI.temp, state, 42);
        // reset mouse movements
        HEAP32[(((RI.contexts[context].state)+(32))>>2)]=0;
        HEAP32[(((RI.contexts[context].state)+(36))>>2)]=0;
        return RI.temp;
     }
  function _RWebInputInit(latency) {
        if (RI.contexts.length === 0) {
           document.addEventListener('keyup', RI.eventHandler, false);
           document.addEventListener('keydown', RI.eventHandler, false);
           document.addEventListener('mousemove', RI.eventHandler, false);
           document.addEventListener('mouseup', RI.eventHandler, false);
           document.addEventListener('mousedown', RI.eventHandler, false);
           document.addEventListener('blur', RI.eventHandler, false);
           document.addEventListener('onvisbilitychange', RI.eventHandler, false);
        }
        if (RI.temp === null) RI.temp = _malloc(42);
        var s = _malloc(42);
        _memset(s, 0, 42);
        RI.contexts.push({
           state: s
        });
        return RI.contexts.length;
     }
  function _strstr(ptr1, ptr2) {
      var check = 0, start;
      do {
        if (!check) {
          start = ptr1;
          check = ptr2;
        }
        var curr1 = HEAP8[((ptr1++)|0)];
        var curr2 = HEAP8[((check++)|0)];
        if (curr2 == 0) return start;
        if (curr2 != curr1) {
          // rewind to one character after start, to find ez in eeez
          ptr1 = start + 1;
          check = 0;
        }
      } while (curr1);
      return 0;
    }
  Module["_memmove"] = _memmove;var _llvm_memmove_p0i8_p0i8_i32=_memmove;
  Module["_memcmp"] = _memcmp;
  var RA={BUFFER_SIZE:256,context:null,buffers:[],numBuffers:0,bufIndex:0,bufOffset:0,startTime:0,nonblock:false,currentTimeWorkaround:false,setStartTime:function () {
           if (RA.context.currentTime) {
              RA.startTime = window['performance']['now']() - RA.context.currentTime * 1000;
              var time1 = RA.context.currentTime;
              _usleep(50);
              if (time1 === RA.context.currentTime) {
                 RA.currentTimeWorkaround = true;
                 if (RA.startTime === 0) throw 'startTime is 0';
              }
              Module["resumeMainLoop"]();
           } else window['setTimeout'](RA.setStartTime, 0);
        },getCurrentPerfTime:function () {
           if (!RA.currentTimeWorkaround) return RA.context.currentTime;
           else if (RA.startTime) return (window['performance']['now']() - RA.startTime) / 1000;
           else throw 'getCurrentPerfTime() called before start time set';
        },process:function (queueBuffers) {
           var currentTime = RA.getCurrentPerfTime();
           for (var i = 0; i < RA.bufIndex; i++) {
              if (RA.buffers[i].endTime < currentTime) {
                 var buf = RA.buffers.splice(i, 1);
                 RA.buffers[RA.numBuffers - 1] = buf[0];
                 i--;
                 RA.bufIndex--;
              }
           }
        },fillBuffer:function (buf, samples) {
           var count = 0;
           var leftBuffer = RA.buffers[RA.bufIndex].getChannelData(0);
           var rightBuffer = RA.buffers[RA.bufIndex].getChannelData(1);
           while (samples && RA.bufOffset !== RA.BUFFER_SIZE) {
              leftBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8))>>2)];
              rightBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8 + 4))>>2)];
              RA.bufOffset++;
              count++;
              samples--;
           }
           return count;
        },queueAudio:function () {
           var index = RA.bufIndex;
           var startTime;
           if (RA.bufIndex) startTime = RA.buffers[RA.bufIndex - 1].endTime;
           else startTime = RA.context.currentTime;
           RA.buffers[index].endTime = startTime + RA.buffers[index].duration;
           var bufferSource = RA.context.createBufferSource();
           bufferSource.buffer = RA.buffers[index];
           bufferSource.connect(RA.context.destination);
           bufferSource.start(startTime);
           RA.bufIndex++;
           RA.bufOffset = 0;
        },block:function () {
           do {
              RA.process();
           } while (RA.bufIndex === RA.numBuffers - 1);
        }};function _RWebAudioBufferSize() {
        return RA.numBuffers * RA.BUFFER_SIZE + RA.BUFFER_SIZE;
     }
  function _RWebAudioWriteAvail() {
        RA.process();
        return ((RA.numBuffers - RA.bufIndex) * RA.BUFFER_SIZE - RA.bufOffset) * 8;
     }
  function _RWebAudioFree() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return;
     }
  function _RWebAudioSetNonblockState(state) {
        RA.nonblock = state;
     }
  function _RWebAudioStart() {
        return true;
     }
  function _RWebAudioStop() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return true;
     }
  function _RWebAudioWrite(buf, size) {
        RA.process();
        var samples = size / 8;
        var count = 0;
        while (samples) {
           var fill = RA.fillBuffer(buf, samples);
           samples -= fill;
           count += fill;
           buf += fill * 8;
           if (RA.bufOffset === RA.BUFFER_SIZE) {
              if (RA.bufIndex === RA.numBuffers - 1) {
                 if (RA.nonblock) break;
                 else RA.block();
              }
              RA.queueAudio();
           }
        }
        return count * 8;
     }
  function _RWebAudioInit(latency) {
        var ac = window['AudioContext'] || window['webkitAudioContext'];
        if (!ac) return 0;
        RA.context = new ac();
        RA.numBuffers = ((latency * RA.context.sampleRate) / (1000 * RA.BUFFER_SIZE))|0;
        if (RA.numBuffers < 2) RA.numBuffers = 2;
        for (var i = 0; i < RA.numBuffers; i++) RA.buffers[i] = RA.context.createBuffer(2, RA.BUFFER_SIZE, RA.context.sampleRate);
        RA.nonblock = false;
        RA.startTime = 0;
        // chrome hack to get currentTime running
        RA.context.createGain();
        window['setTimeout'](RA.setStartTime, 0);
        Module["pauseMainLoop"]();
        return 1;
     }
  function _RWebAudioSampleRate() {
        return RA.context.sampleRate;
     }
  var _fabsf=Math.abs;
  var _sin=Math.sin;
  var _ceil=Math.ceil;
  function _emscripten_get_now() {
      if (!_emscripten_get_now.actual) {
        if (ENVIRONMENT_IS_NODE) {
            _emscripten_get_now.actual = function() {
              var t = process['hrtime']();
              return t[0] * 1e3 + t[1] / 1e6;
            }
        } else if (typeof dateNow !== 'undefined') {
          _emscripten_get_now.actual = dateNow;
        } else if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
          _emscripten_get_now.actual = function() { return window['performance']['now'](); };
        } else {
          _emscripten_get_now.actual = Date.now;
        }
      }
      return _emscripten_get_now.actual();
    }
  function _llvm_uadd_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm["setTempRet0"](x+y > 4294967295),(x+y)>>>0)|0);
    }
  var GL={counter:1,buffers:[],programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],currArrayBuffer:0,currElementArrayBuffer:0,byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],uniformTable:{},packAlignment:4,unpackAlignment:4,init:function () {
        Browser.moduleContextCreatedCallbacks.push(GL.initExtensions);
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:16,miniTempBuffer:null,miniTempBufferViews:[0],MAX_TEMP_BUFFER_SIZE:2097152,tempBufferIndexLookup:null,tempVertexBuffers:null,tempIndexBuffers:null,tempQuadIndexBuffer:null,generateTempBuffers:function (quads) {
        GL.tempBufferIndexLookup = new Uint8Array(GL.MAX_TEMP_BUFFER_SIZE+1);
        GL.tempVertexBuffers = [];
        GL.tempIndexBuffers = [];
        var last = -1, curr = -1;
        var size = 1;
        for (var i = 0; i <= GL.MAX_TEMP_BUFFER_SIZE; i++) {
          if (i > size) {
            size <<= 1;
          }
          if (size != last) {
            curr++;
            GL.tempVertexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, GL.tempVertexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, null);
            GL.tempIndexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempIndexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
            last = size;
          }
          GL.tempBufferIndexLookup[i] = curr;
        }
        if (quads) {
          // GL_QUAD indexes can be precalculated
          GL.tempQuadIndexBuffer = Module.ctx.createBuffer();
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempQuadIndexBuffer);
          var numIndexes = GL.MAX_TEMP_BUFFER_SIZE >> 1;
          var quadIndexes = new Uint16Array(numIndexes);
          var i = 0, v = 0;
          while (1) {
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+1;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+3;
            if (i >= numIndexes) break;
            v += 4;
          }
          Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, quadIndexes, Module.ctx.STATIC_DRAW);
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
        }
      },findToken:function (source, token) {
        function isIdentChar(ch) {
          if (ch >= 48 && ch <= 57) // 0-9
            return true;
          if (ch >= 65 && ch <= 90) // A-Z
            return true;
          if (ch >= 97 && ch <= 122) // a-z
            return true;
          return false;
        }
        var i = -1;
        do {
          i = source.indexOf(token, i + 1);
          if (i < 0) {
            break;
          }
          if (i > 0 && isIdentChar(source[i - 1])) {
            continue;
          }
          i += token.length;
          if (i < source.length - 1 && isIdentChar(source[i + 1])) {
            continue;
          }
          return true;
        } while (true);
        return false;
      },getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        // Let's see if we need to enable the standard derivatives extension
        type = Module.ctx.getShaderParameter(GL.shaders[shader], 0x8B4F /* GL_SHADER_TYPE */);
        if (type == 0x8B30 /* GL_FRAGMENT_SHADER */) {
          if (GL.findToken(source, "dFdx") ||
              GL.findToken(source, "dFdy") ||
              GL.findToken(source, "fwidth")) {
            source = "#extension GL_OES_standard_derivatives : enable\n" + source;
            var extension = Module.ctx.getExtension("OES_standard_derivatives");
          }
        }
        return source;
      },computeImageSize:function (width, height, sizePerPixel, alignment) {
        function roundedToNextMultipleOf(x, y) {
          return Math.floor((x + y - 1) / y) * y
        }
        var plainRowSize = width * sizePerPixel;
        var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
        return (height <= 0) ? 0 :
                 ((height - 1) * alignedRowSize + plainRowSize);
      },getTexPixelData:function (type, format, width, height, pixels, internalFormat) {
        var sizePerPixel;
        switch (type) {
          case 0x1401 /* GL_UNSIGNED_BYTE */:
            switch (format) {
              case 0x1906 /* GL_ALPHA */:
              case 0x1909 /* GL_LUMINANCE */:
                sizePerPixel = 1;
                break;
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4;
                break;
              case 0x190A /* GL_LUMINANCE_ALPHA */:
                sizePerPixel = 2;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            break;
          case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
          case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
          case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
            sizePerPixel = 2;
            break;
          case 0x1406 /* GL_FLOAT */:
            assert(GL.floatExt, 'Must have OES_texture_float to use float textures');
            switch (format) {
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3*4;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4*4;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            internalFormat = Module.ctx.RGBA;
            break;
          default:
            throw 'Invalid type (' + type + ')';
        }
        var bytes = GL.computeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
        if (type == 0x1401 /* GL_UNSIGNED_BYTE */) {
          pixels = HEAPU8.subarray((pixels),(pixels+bytes));
        } else if (type == 0x1406 /* GL_FLOAT */) {
          pixels = HEAPF32.subarray((pixels)>>2,(pixels+bytes)>>2);
        } else {
          pixels = HEAPU16.subarray((pixels)>>1,(pixels+bytes)>>1);
        }
        return {
          pixels: pixels,
          internalFormat: internalFormat
        }
      },initExtensions:function () {
        if (GL.initExtensions.done) return;
        GL.initExtensions.done = true;
        if (!Module.useWebGL) return; // an app might link both gl and 2d backends
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }
        GL.maxVertexAttribs = Module.ctx.getParameter(Module.ctx.MAX_VERTEX_ATTRIBS);
        GL.compressionExt = Module.ctx.getExtension('WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('MOZ_WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('WEBKIT_WEBGL_compressed_texture_s3tc');
        GL.anisotropicExt = Module.ctx.getExtension('EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('MOZ_EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('WEBKIT_EXT_texture_filter_anisotropic');
        GL.floatExt = Module.ctx.getExtension('OES_texture_float');
        GL.elementIndexUintExt = Module.ctx.getExtension('OES_element_index_uint');
        GL.standardDerivativesExt = Module.ctx.getExtension('OES_standard_derivatives');
      }};function _glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        Module.ctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }
  function _glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        Module.ctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }
  function _glViewport(x0, x1, x2, x3) { Module.ctx.viewport(x0, x1, x2, x3) }
  function _glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.textures);
        var texture = Module.ctx.createTexture();
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }
  function _glBindTexture(target, texture) {
      Module.ctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }
  function _glTexParameteri(x0, x1, x2) { Module.ctx.texParameteri(x0, x1, x2) }
  function _glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      Module.ctx.pixelStorei(pname, param);
    }
  function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, internalFormat);
        pixels = data.pixels;
        internalFormat = data.internalFormat;
      } else {
        pixels = null;
      }
      Module.ctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels);
    }
  function _glBindFramebuffer(target, framebuffer) {
      Module.ctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
    }
  function _glReadPixels(x, y, width, height, format, type, pixels) {
      assert(type == 0x1401 /* GL_UNSIGNED_BYTE */);
      var sizePerPixel;
      switch (format) {
        case 0x1907 /* GL_RGB */:
          sizePerPixel = 3;
          break;
        case 0x1908 /* GL_RGBA */:
          sizePerPixel = 4;
          break;
        default: throw 'unsupported glReadPixels format';
      }
      var totalSize = width*height*sizePerPixel;
      Module.ctx.readPixels(x, y, width, height, format, type, HEAPU8.subarray(pixels, pixels + totalSize));
    }
  function _glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        Module.ctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }
  function _glGetIntegerv(name_, p) {
      switch(name_) { // Handle a few trivial GLES values
        case 0x8DFA: // GL_SHADER_COMPILER
          HEAP32[((p)>>2)]=1;
          return;
        case 0x8DF9: // GL_NUM_SHADER_BINARY_FORMATS
          HEAP32[((p)>>2)]=0;
          return;
        case 0x86A2: // GL_NUM_COMPRESSED_TEXTURE_FORMATS
          // WebGL doesn't have GL_NUM_COMPRESSED_TEXTURE_FORMATS (it's obsolete since GL_COMPRESSED_TEXTURE_FORMATS returns a JS array that can be queried for length),
          // so implement it ourselves to allow C++ GLES2 code get the length.
          var formats = Module.ctx.getParameter(0x86A3 /*GL_COMPRESSED_TEXTURE_FORMATS*/);
          HEAP32[((p)>>2)]=formats.length;
          return;
      }
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAP8[(p)]=result ? 1 : 0;
          break;
        case "string":
          throw 'Native code calling glGetIntegerv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP32[((p)>>2)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetIntegerv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var id = GL.getNewId(GL.framebuffers);
        var framebuffer = Module.ctx.createFramebuffer();
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }
  function _glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.renderbuffers);
        var renderbuffer = Module.ctx.createRenderbuffer();
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }
  function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      Module.ctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }
  function _glBindRenderbuffer(target, renderbuffer) {
      Module.ctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }
  function _glRenderbufferStorage(x0, x1, x2, x3) { Module.ctx.renderbufferStorage(x0, x1, x2, x3) }
  function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      Module.ctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }
  function _glCheckFramebufferStatus(x0) { return Module.ctx.checkFramebufferStatus(x0) }
  function _glGetString(name_) {
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x1F02 /* GL_VERSION */:
          return allocate(intArrayFromString(Module.ctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
        case 0x1F03 /* GL_EXTENSIONS */:
          return allocate(intArrayFromString(Module.ctx.getSupportedExtensions().join(' ')), 'i8', ALLOC_NORMAL);
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          return allocate(intArrayFromString('OpenGL ES GLSL 1.00 (WebGL)'), 'i8', ALLOC_NORMAL);
        default:
          throw 'Failure: Invalid glGetString value: ' + name_;
      }
    }
  function _glDisable(x0) { Module.ctx.disable(x0) }
  function _glBlendFunc(x0, x1) { Module.ctx.blendFunc(x0, x1) }
  function _glClearColor(x0, x1, x2, x3) { Module.ctx.clearColor(x0, x1, x2, x3) }
  function _glClear(x0) { Module.ctx.clear(x0) }
  function _glDrawArrays(mode, first, count) {
      Module.ctx.drawArrays(mode, first, count);
    }
  function _glEnable(x0) { Module.ctx.enable(x0) }
  function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, -1);
        pixels = data.pixels;
      } else {
        pixels = null;
      }
      Module.ctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels);
    }
  function _glGetError() { return Module.ctx.getError() }
  var _cosf=Math.cos;
  var _sinf=Math.sin;
  function _glGetFloatv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAPF32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAPF32[((p)>>2)]=result ? 1.0 : 0.0;
          break;
        case "string":
            HEAPF32[((p)>>2)]=0;
        case "object":
          if (result === null) {
            throw 'Native code calling glGetFloatv(' + name_ + ') and it returns null';
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAPF32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetFloatv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGetBooleanv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP8[(p)]=result != 0;
          break;
        case "boolean":
          HEAP8[(p)]=result != 0;
          break;
        case "string":
          throw 'Native code calling glGetBooleanv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP8[(p)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP8[(((p)+(i))|0)]=result[i] != 0;
            }
          } else if (result instanceof WebGLBuffer ||
                     result instanceof WebGLProgram ||
                     result instanceof WebGLFramebuffer ||
                     result instanceof WebGLRenderbuffer ||
                     result instanceof WebGLTexture) {
            HEAP8[(p)]=1; // non-zero ID is always 1!
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
            throw 'Unknown object returned from WebGL getParameter';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data);
    }
  function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, data);
    }
  function _glGetTexParameterfv(target, pname, params) {
      HEAPF32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glGetTexParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      Module.ctx.texParameterf(target, pname, param);
    }
  function _glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      Module.ctx.texParameteri(target, pname, param);
    }
  function _glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return Module.ctx.isTexture(texture);
    }
  function _glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.buffers);
        var buffer = Module.ctx.createBuffer();
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }
  function _glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
        Module.ctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }
  function _glGetBufferParameteriv(target, value, data) {
      HEAP32[((data)>>2)]=Module.ctx.getBufferParameter(target, value);
    }
  function _glBufferData(target, size, data, usage) {
      switch (usage) { // fix usages, WebGL only has *_DRAW
        case 0x88E1: // GL_STREAM_READ
        case 0x88E2: // GL_STREAM_COPY
          usage = 0x88E0; // GL_STREAM_DRAW
          break;
        case 0x88E5: // GL_STATIC_READ
        case 0x88E6: // GL_STATIC_COPY
          usage = 0x88E4; // GL_STATIC_DRAW
          break;
        case 0x88E9: // GL_DYNAMIC_READ
        case 0x88EA: // GL_DYNAMIC_COPY
          usage = 0x88E8; // GL_DYNAMIC_DRAW
          break;
      }
      Module.ctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
    }
  function _glBufferSubData(target, offset, size, data) {
      Module.ctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }
  function _glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return Module.ctx.isBuffer(b);
    }
  function _glGetRenderbufferParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.ctx.getRenderbufferParameter(target, pname);
    }
  function _glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return Module.ctx.isRenderbuffer(rb);
    }
  function _glGetUniformfv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformiv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
      var ptable = GL.uniformTable[program];
      if (!ptable) ptable = GL.uniformTable[program] = {};
      var id = ptable[name];
      if (id) return id;
      var loc = Module.ctx.getUniformLocation(GL.programs[program], name);
      if (!loc) return -1;
      id = GL.getNewId(GL.uniforms);
      GL.uniforms[id] = loc;
      ptable[name] = id;
      return id;
    }
  function _glGetVertexAttribfv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribiv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribPointerv(index, pname, pointer) {
      HEAP32[((pointer)>>2)]=Module.ctx.getVertexAttribOffset(index, pname);
    }
  function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveUniform(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glUniform1f(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1f(location, v0);
    }
  function _glUniform2f(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2f(location, v0, v1);
    }
  function _glUniform3f(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3f(location, v0, v1, v2);
    }
  function _glUniform4f(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4f(location, v0, v1, v2, v3);
    }
  function _glUniform1i(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1i(location, v0);
    }
  function _glUniform2i(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2i(location, v0, v1);
    }
  function _glUniform3i(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3i(location, v0, v1, v2);
    }
  function _glUniform4i(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4i(location, v0, v1, v2, v3);
    }
  function _glUniform1iv(location, count, value) {
      location = GL.uniforms[location];
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform1iv(location, value);
    }
  function _glUniform2iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 2;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform2iv(location, value);
    }
  function _glUniform3iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 3;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform3iv(location, value);
    }
  function _glUniform4iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 4;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform4iv(location, value);
    }
  function _glUniform1fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[0];
        view[0] = HEAPF32[((value)>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      Module.ctx.uniform1fv(location, view);
    }
  function _glUniform2fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[1];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      Module.ctx.uniform2fv(location, view);
    }
  function _glUniform3fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[2];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      Module.ctx.uniform3fv(location, view);
    }
  function _glUniform4fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[3];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
        view[3] = HEAPF32[(((value)+(12))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniform4fv(location, view);
    }
  function _glUniformMatrix2fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[3];
        for (var i = 0; i < 4; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniformMatrix2fv(location, transpose, view);
    }
  function _glUniformMatrix3fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[8];
        for (var i = 0; i < 9; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      Module.ctx.uniformMatrix3fv(location, transpose, view);
    }
  function _glUniformMatrix4fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[15];
        for (var i = 0; i < 16; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      Module.ctx.uniformMatrix4fv(location, transpose, view);
    }
  function _glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
      if (target == Module.ctx.ARRAY_BUFFER) {
        GL.currArrayBuffer = buffer;
      } else if (target == Module.ctx.ELEMENT_ARRAY_BUFFER) {
        GL.currElementArrayBuffer = buffer;
      }
      Module.ctx.bindBuffer(target, bufferObj);
    }
  function _glVertexAttrib1fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+4)>>2);
      Module.ctx.vertexAttrib1fv(index, v);
    }
  function _glVertexAttrib2fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+8)>>2);
      Module.ctx.vertexAttrib2fv(index, v);
    }
  function _glVertexAttrib3fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+12)>>2);
      Module.ctx.vertexAttrib3fv(index, v);
    }
  function _glVertexAttrib4fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+16)>>2);
      Module.ctx.vertexAttrib4fv(index, v);
    }
  function _glGetAttribLocation(program, name) {
      program = GL.programs[program];
      name = Pointer_stringify(name);
      return Module.ctx.getAttribLocation(program, name);
    }
  function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveAttrib(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = Module.ctx.createShader(shaderType);
      return id;
    }
  function _glDeleteShader(shader) {
      Module.ctx.deleteShader(GL.shaders[shader]);
      GL.shaders[shader] = null;
    }
  function _glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = Module.ctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        assert(id !== -1, 'shader not bound to local id');
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }
  function _glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
      Module.ctx.shaderSource(GL.shaders[shader], source);
    }
  function _glGetShaderSource(shader, bufSize, length, source) {
      var result = Module.ctx.getShaderSource(GL.shaders[shader]);
      result = result.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(result, source);
      if (length) {
        HEAP32[((length)>>2)]=result.length;
      }
    }
  function _glCompileShader(shader) {
      Module.ctx.compileShader(GL.shaders[shader]);
    }
  function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = Module.ctx.getShaderInfoLog(GL.shaders[shader]);
      // Work around a bug in Chromium which causes getShaderInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glGetShaderiv(shader, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getShaderInfoLog(GL.shaders[shader]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }
  function _glGetProgramiv(program, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getProgramInfoLog(GL.programs[program]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getProgramParameter(GL.programs[program], pname);
      }
    }
  function _glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return Module.ctx.isShader(s);
    }
  function _glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = Module.ctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }
  function _glDeleteProgram(program) {
      var program = GL.programs[program];
      Module.ctx.deleteProgram(program);
      program.name = 0;
      GL.programs[program] = null;
      GL.uniformTable[program] = null;
    }
  function _glAttachShader(program, shader) {
      Module.ctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glDetachShader(program, shader) {
      Module.ctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = Module.ctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }
  function _glLinkProgram(program) {
      Module.ctx.linkProgram(GL.programs[program]);
      GL.uniformTable[program] = {}; // uniforms no longer keep the same names after linking
    }
  function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = Module.ctx.getProgramInfoLog(GL.programs[program]);
      // Work around a bug in Chromium which causes getProgramInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glUseProgram(program) {
      Module.ctx.useProgram(program ? GL.programs[program] : null);
    }
  function _glValidateProgram(program) {
      Module.ctx.validateProgram(GL.programs[program]);
    }
  function _glIsProgram(program) {
      var program = GL.programs[program];
      if (!program) return 0;
      return Module.ctx.isProgram(program);
    }
  function _glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      Module.ctx.bindAttribLocation(GL.programs[program], index, name);
    }
  function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = Module.ctx.getFramebufferAttachmentParameter(target, attachment, pname);
      HEAP32[((params)>>2)]=params;
    }
  function _glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return Module.ctx.isFramebuffer(fb);
    }
  function _glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glGenVertexArrays(){ throw 'Legacy GL function (glGenVertexArrays) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glBegin(){ throw 'Legacy GL function (glBegin) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _gluPerspective(fov, aspect, near, far) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix[GL.immediate.currentMatrix] =
        GL.immediate.matrix.lib.mat4.perspective(fov, aspect, near, far,
                                                 GL.immediate.matrix[GL.immediate.currentMatrix]);
    }
  function _gluLookAt(ex, ey, ez, cx, cy, cz, ux, uy, uz) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix.lib.mat4.lookAt(GL.immediate.matrix[GL.immediate.currentMatrix], [ex, ey, ez],
          [cx, cy, cz], [ux, uy, uz]);
    }
  function _gluProject(objX, objY, objZ, model, proj, view, winX, winY, winZ) {
      // The algorithm for this functions comes from Mesa
      var inVec = new Float32Array(4);
      var outVec = new Float32Array(4);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((model)>>3,(model+128)>>3),
          [objX, objY, objZ, 1.0], outVec);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          outVec, inVec);
      if (inVec[3] == 0.0) {
        return 0 /* GL_FALSE */;
      }
      inVec[0] /= inVec[3];
      inVec[1] /= inVec[3];
      inVec[2] /= inVec[3];
      // Map x, y and z to range 0-1 */
      inVec[0] = inVec[0] * 0.5 + 0.5;
      inVec[1] = inVec[1] * 0.5 + 0.5;
      inVec[2] = inVec[2] * 0.5 + 0.5;
      // Map x, y to viewport
      inVec[0] = inVec[0] * HEAP32[(((view)+(8))>>2)] + HEAP32[((view)>>2)];
      inVec[1] = inVec[1] * HEAP32[(((view)+(12))>>2)] + HEAP32[(((view)+(4))>>2)];
      HEAPF64[((winX)>>3)]=inVec[0];
      HEAPF64[((winY)>>3)]=inVec[1];
      HEAPF64[((winZ)>>3)]=inVec[2];
      return 1 /* GL_TRUE */;
    }
  function _gluUnProject(winX, winY, winZ, model, proj, view, objX, objY, objZ) {
      var result = GL.immediate.matrix.lib.mat4.unproject([winX, winY, winZ],
          HEAPF64.subarray((model)>>3,(model+128)>>3),
          HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          HEAP32.subarray((view)>>2,(view+16)>>2));
      if (result === null) {
        return 0 /* GL_FALSE */;
      }
      HEAPF64[((objX)>>3)]=result[0];
      HEAPF64[((objY)>>3)]=result[1];
      HEAPF64[((objZ)>>3)]=result[2];
      return 1 /* GL_TRUE */;
    }
  function _gluOrtho2D(left, right, bottom, top) {
      _glOrtho(left, right, bottom, top, -1, 1);
    }
  function _glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      Module.ctx.vertexAttribPointer(index, size, type, normalized, stride, ptr);
    }
  function _glEnableVertexAttribArray(index) {
      Module.ctx.enableVertexAttribArray(index);
    }
  function _glDisableVertexAttribArray(index) {
      Module.ctx.disableVertexAttribArray(index);
    }
  function _glDrawElements(mode, count, type, indices) {
      Module.ctx.drawElements(mode, count, type, indices);
    }
  function _glFinish() { Module.ctx.finish() }
  function _glFlush() { Module.ctx.flush() }
  function _glClearDepth(x0) { Module.ctx.clearDepth(x0) }
  function _glClearDepthf(x0) { Module.ctx.clearDepth(x0) }
  function _glDepthFunc(x0) { Module.ctx.depthFunc(x0) }
  function _glFrontFace(x0) { Module.ctx.frontFace(x0) }
  function _glCullFace(x0) { Module.ctx.cullFace(x0) }
  function _glLineWidth(x0) { Module.ctx.lineWidth(x0) }
  function _glClearStencil(x0) { Module.ctx.clearStencil(x0) }
  function _glDepthMask(x0) { Module.ctx.depthMask(x0) }
  function _glStencilMask(x0) { Module.ctx.stencilMask(x0) }
  function _glGenerateMipmap(x0) { Module.ctx.generateMipmap(x0) }
  function _glActiveTexture(x0) { Module.ctx.activeTexture(x0) }
  function _glBlendEquation(x0) { Module.ctx.blendEquation(x0) }
  function _glSampleCoverage(x0) { Module.ctx.sampleCoverage(x0) }
  function _glIsEnabled(x0) { return Module.ctx.isEnabled(x0) }
  function _glBlendEquationSeparate(x0, x1) { Module.ctx.blendEquationSeparate(x0, x1) }
  function _glDepthRange(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glDepthRangef(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glStencilMaskSeparate(x0, x1) { Module.ctx.stencilMaskSeparate(x0, x1) }
  function _glHint(x0, x1) { Module.ctx.hint(x0, x1) }
  function _glPolygonOffset(x0, x1) { Module.ctx.polygonOffset(x0, x1) }
  function _glVertexAttrib1f(x0, x1) { Module.ctx.vertexAttrib1f(x0, x1) }
  function _glTexParameterf(x0, x1, x2) { Module.ctx.texParameterf(x0, x1, x2) }
  function _glVertexAttrib2f(x0, x1, x2) { Module.ctx.vertexAttrib2f(x0, x1, x2) }
  function _glStencilFunc(x0, x1, x2) { Module.ctx.stencilFunc(x0, x1, x2) }
  function _glStencilOp(x0, x1, x2) { Module.ctx.stencilOp(x0, x1, x2) }
  function _glScissor(x0, x1, x2, x3) { Module.ctx.scissor(x0, x1, x2, x3) }
  function _glVertexAttrib3f(x0, x1, x2, x3) { Module.ctx.vertexAttrib3f(x0, x1, x2, x3) }
  function _glColorMask(x0, x1, x2, x3) { Module.ctx.colorMask(x0, x1, x2, x3) }
  function _glBlendFuncSeparate(x0, x1, x2, x3) { Module.ctx.blendFuncSeparate(x0, x1, x2, x3) }
  function _glBlendColor(x0, x1, x2, x3) { Module.ctx.blendColor(x0, x1, x2, x3) }
  function _glStencilFuncSeparate(x0, x1, x2, x3) { Module.ctx.stencilFuncSeparate(x0, x1, x2, x3) }
  function _glStencilOpSeparate(x0, x1, x2, x3) { Module.ctx.stencilOpSeparate(x0, x1, x2, x3) }
  function _glVertexAttrib4f(x0, x1, x2, x3, x4) { Module.ctx.vertexAttrib4f(x0, x1, x2, x3, x4) }
  function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }
  function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }function _emscripten_procAddressTable(name) {
  switch(name) {
  case "glPixelStorei": return 646; break;
  case "glGetString": return 148; break;
  case "glGetIntegerv": return 258; break;
  case "glGetFloatv": return 292; break;
  case "glGetBooleanv": return 374; break;
  case "glGenTextures": return 256; break;
  case "glDeleteTextures": return 404; break;
  case "glCompressedTexImage2D": return 2; break;
  case "glCompressedTexSubImage2D": return 4; break;
  case "glTexImage2D": return 12; break;
  case "glTexSubImage2D": return 6; break;
  case "glReadPixels": return 24; break;
  case "glBindTexture": return 286; break;
  case "glGetTexParameterfv": return 86; break;
  case "glGetTexParameteriv": return 10; break;
  case "glTexParameterfv": return 52; break;
  case "glTexParameteriv": return 2; break;
  case "glIsTexture": return 208; break;
  case "glGenBuffers": return 368; break;
  case "glDeleteBuffers": return 126; break;
  case "glGetBufferParameteriv": return 88; break;
  case "glBufferData": return 50; break;
  case "glBufferSubData": return 22; break;
  case "glIsBuffer": return 134; break;
  case "glGenRenderbuffers": return 636; break;
  case "glDeleteRenderbuffers": return 478; break;
  case "glBindRenderbuffer": return 396; break;
  case "glGetRenderbufferParameteriv": return 58; break;
  case "glIsRenderbuffer": return 68; break;
  case "glGetUniformfv": return 54; break;
  case "glGetUniformiv": return 28; break;
  case "glGetUniformLocation": return 64; break;
  case "glGetVertexAttribfv": return 48; break;
  case "glGetVertexAttribiv": return 50; break;
  case "glGetVertexAttribPointerv": return 14; break;
  case "glGetActiveUniform": return 28; break;
  case "glUniform1f": return 4; break;
  case "glUniform2f": return 2; break;
  case "glUniform3f": return 2; break;
  case "glUniform4f": return 6; break;
  case "glUniform1i": return 600; break;
  case "glUniform2i": return 8; break;
  case "glUniform3i": return 26; break;
  case "glUniform4i": return 12; break;
  case "glUniform1iv": return 18; break;
  case "glUniform2iv": return 26; break;
  case "glUniform3iv": return 20; break;
  case "glUniform4iv": return 38; break;
  case "glUniform1fv": return 22; break;
  case "glUniform2fv": return 46; break;
  case "glUniform3fv": return 90; break;
  case "glUniform4fv": return 34; break;
  case "glUniformMatrix2fv": return 2; break;
  case "glUniformMatrix3fv": return 18; break;
  case "glUniformMatrix4fv": return 4; break;
  case "glBindBuffer": return 192; break;
  case "glVertexAttrib1fv": return 362; break;
  case "glVertexAttrib2fv": return 392; break;
  case "glVertexAttrib3fv": return 602; break;
  case "glVertexAttrib4fv": return 124; break;
  case "glGetAttribLocation": return 352; break;
  case "glGetActiveAttrib": return 26; break;
  case "glCreateShader": return 132; break;
  case "glDeleteShader": return 504; break;
  case "glGetAttachedShaders": return 52; break;
  case "glShaderSource": return 42; break;
  case "glGetShaderSource": return 40; break;
  case "glCompileShader": return 500; break;
  case "glGetShaderInfoLog": return 60; break;
  case "glGetShaderiv": return 32; break;
  case "glGetProgramiv": return 30; break;
  case "glIsShader": return 136; break;
  case "glCreateProgram": return 18; break;
  case "glDeleteProgram": return 78; break;
  case "glAttachShader": return 78; break;
  case "glDetachShader": return 428; break;
  case "glLinkProgram": return 120; break;
  case "glGetProgramInfoLog": return 66; break;
  case "glUseProgram": return 148; break;
  case "glValidateProgram": return 322; break;
  case "glIsProgram": return 218; break;
  case "glBindAttribLocation": return 36; break;
  case "glBindFramebuffer": return 266; break;
  case "glGenFramebuffers": return 268; break;
  case "glDeleteFramebuffers": return 274; break;
  case "glFramebufferRenderbuffer": return 8; break;
  case "glFramebufferTexture2D": return 10; break;
  case "glGetFramebufferAttachmentParameteriv": return 46; break;
  case "glIsFramebuffer": return 118; break;
  case "glVertexAttribPointer": return 30; break;
  case "glEnableVertexAttribArray": return 106; break;
  case "glDisableVertexAttribArray": return 12; break;
  case "glDrawArrays": return 12; break;
  case "glDrawElements": return 20; break;
  case "glGetError": return 4; break;
  case "glFinish": return 8; break;
  case "glFlush": return 52; break;
  case "glClearDepth": return 132; break;
  case "glClearDepthf": return 478; break;
  case "glDepthFunc": return 458; break;
  case "glEnable": return 336; break;
  case "glDisable": return 280; break;
  case "glFrontFace": return 240; break;
  case "glCullFace": return 74; break;
  case "glClear": return 124; break;
  case "glLineWidth": return 422; break;
  case "glClearStencil": return 2; break;
  case "glDepthMask": return 42; break;
  case "glStencilMask": return 542; break;
  case "glCheckFramebufferStatus": return 92; break;
  case "glGenerateMipmap": return 182; break;
  case "glActiveTexture": return 100; break;
  case "glBlendEquation": return 290; break;
  case "glSampleCoverage": return 386; break;
  case "glIsEnabled": return 152; break;
  case "glBlendFunc": return 350; break;
  case "glBlendEquationSeparate": return 170; break;
  case "glDepthRange": return 138; break;
  case "glDepthRangef": return 314; break;
  case "glStencilMaskSeparate": return 74; break;
  case "glHint": return 236; break;
  case "glPolygonOffset": return 202; break;
  case "glVertexAttrib1f": return 172; break;
  case "glTexParameteri": return 66; break;
  case "glTexParameterf": return 68; break;
  case "glVertexAttrib2f": return 78; break;
  case "glStencilFunc": return 44; break;
  case "glStencilOp": return 76; break;
  case "glViewport": return 12; break;
  case "glClearColor": return 16; break;
  case "glScissor": return 14; break;
  case "glVertexAttrib3f": return 64; break;
  case "glColorMask": return 58; break;
  case "glRenderbufferStorage": return 34; break;
  case "glBlendFuncSeparate": return 30; break;
  case "glBlendColor": return 36; break;
  case "glStencilFuncSeparate": return 38; break;
  case "glStencilOpSeparate": return 24; break;
  case "glVertexAttrib4f": return 2; break;
  case "glCopyTexImage2D": return 18; break;
  case "glCopyTexSubImage2D": return 8; break;
  }
  return 0;
  }function _emscripten_GetProcAddress(name) {
    name = name.replace('EXT', '').replace('ARB', '');
    switch(name) { // misc renamings
      case 'glCreateProgramObject': name = 'glCreateProgram'; break;
      case 'glUseProgramObject': name = 'glUseProgram'; break;
      case 'glCreateShaderObject': name = 'glCreateShader'; break;
      case 'glAttachObject': name = 'glAttachShader'; break;
      case 'glDetachObject': name = 'glDetachShader'; break;
    }
    var ret = _emscripten_procAddressTable(name);
    if (!ret) Module.printErr('WARNING: getProcAddress failed for ' + name);
    return ret;
  }function _eglGetProcAddress(name_) {
      return _emscripten_GetProcAddress(Pointer_stringify(name_));
    }
  function _emscripten_get_canvas_size(width, height, isFullscreen) {
      var canvas = Module['canvas'];
      HEAP32[((width)>>2)]=canvas.width;
      HEAP32[((height)>>2)]=canvas.height;
      HEAP32[((isFullscreen)>>2)]=Browser.isFullScreen ? 1 : 0;
    }
  var EGL={eglErrorCode:12288,setErrorCode:function (code) {
        EGL.eglErrorCode = code;
      },chooseConfig:function (display, attribList, config, config_size, numConfigs) { 
        if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
          EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
          return 0;
        }
        // TODO: read attribList.
        if ((!config || !config_size) && !numConfigs) {
          EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
          return 0;
        }
        if (numConfigs) {
          HEAP32[((numConfigs)>>2)]=1; // Total number of supported configs: 1.
        }
        if (config && config_size > 0) {
          HEAP32[((config)>>2)]=62002; 
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      }};function _eglBindAPI(api) {
      if (api == 0x30A0 /* EGL_OPENGL_ES_API */) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } else { // if (api == 0x30A1 /* EGL_OPENVG_API */ || api == 0x30A2 /* EGL_OPENGL_API */) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
    }
  function _eglMakeCurrent(display, draw, read, context) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      if (read != 62006 || draw != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _glutDestroyWindow(name) {
      Module.ctx = Browser.destroyContext(Module['canvas'], true, true);
      return 1;
    }function _eglDestroyContext(display, context) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglDestroySurface(display, surface) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0; 
      }
      if (surface != 62006 /* Magic ID for the only EGLSurface supported by Emscripten */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 1;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglTerminate(display) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      // TODO: Tear down EGL here. Currently a no-op since we don't need to actually do anything here for the browser.
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglGetDisplay(nativeDisplayType) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      // Note: As a 'conformant' implementation of EGL, we would prefer to init here only if the user
      //       calls this function with EGL_DEFAULT_DISPLAY. Other display IDs would be preferred to be unsupported
      //       and EGL_NO_DISPLAY returned. Uncomment the following code lines to do this.
      // Instead, an alternative route has been preferred, namely that the Emscripten EGL implementation
      // "emulates" X11, and eglGetDisplay is expected to accept/receive a pointer to an X11 Display object.
      // Therefore, be lax and allow anything to be passed in, and return the magic handle to our default EGLDisplay object.
  //    if (nativeDisplayType == 0 /* EGL_DEFAULT_DISPLAY */) {
          return 62000; // Magic ID for Emscripten 'default display'
  //    }
  //    else
  //      return 0; // EGL_NO_DISPLAY
    }
  function _eglInitialize(display, majorVersion, minorVersion) {
      if (display == 62000 /* Magic ID for Emscripten 'default display' */) {
        if (majorVersion) {
          HEAP32[((majorVersion)>>2)]=1; // Advertise EGL Major version: '1'
        }
        if (minorVersion) {
          HEAP32[((minorVersion)>>2)]=4; // Advertise EGL Minor version: '4'
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } 
      else {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
    }
  function _eglChooseConfig(display, attrib_list, configs, config_size, numConfigs) { 
      return EGL.chooseConfig(display, attrib_list, configs, config_size, numConfigs);
    }
  function _glutCreateWindow(name) {
      Module.ctx = Browser.createContext(Module['canvas'], true, true);
      return Module.ctx ? 1 /* a new GLUT window ID for the created context */ : 0 /* failure */;
    }function _eglCreateContext(display, config, hmm, contextAttribs) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      EGL.windowID = _glutCreateWindow();
      if (EGL.windowID != 0) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 62004; // Magic ID for Emscripten EGLContext
      } else {
        EGL.setErrorCode(0x3009 /* EGL_BAD_MATCH */); // By the EGL 1.4 spec, an implementation that does not support GLES2 (WebGL in this case), this error code is set.
        return 0; /* EGL_NO_CONTEXT */
      }
    }
  function _eglCreateWindowSurface(display, config, win, attrib_list) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      // TODO: Examine attrib_list! Parameters that can be present there are:
      // - EGL_RENDER_BUFFER (must be EGL_BACK_BUFFER)
      // - EGL_VG_COLORSPACE (can't be set)
      // - EGL_VG_ALPHA_FORMAT (can't be set)
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 62006; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglQuerySurface(display, surface, attribute, value) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (surface != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
      case 0x3028: // EGL_CONFIG_ID
        HEAP32[((value)>>2)]=62002;
          return 1;
      case 0x3058: // EGL_LARGEST_PBUFFER
        // Odd EGL API: If surface is not a pbuffer surface, 'value' should not be written to. It's not specified as an error, so true should(?) be returned.
        // Existing Android implementation seems to do so at least.
        return 1;
      case 0x3057: // EGL_WIDTH
        HEAP32[((value)>>2)]=Module.canvas.width;
        return 1;
      case 0x3056: // EGL_HEIGHT
        HEAP32[((value)>>2)]=Module.canvas.height;
        return 1;
      case 0x3090: // EGL_HORIZONTAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3091: // EGL_VERTICAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3092: // EGL_PIXEL_ASPECT_RATIO
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3086: // EGL_RENDER_BUFFER
        // The main surface is bound to the visible canvas window - it's always backbuffered. 
        // Alternative to EGL_BACK_BUFFER would be EGL_SINGLE_BUFFER.
        HEAP32[((value)>>2)]=0x3084; 
        return 1;
      case 0x3099: // EGL_MULTISAMPLE_RESOLVE
        HEAP32[((value)>>2)]=0x309A; 
        return 1;
      case 0x3093: // EGL_SWAP_BEHAVIOR
        // The two possibilities are EGL_BUFFER_PRESERVED and EGL_BUFFER_DESTROYED. Slightly unsure which is the
        // case for browser environment, but advertise the 'weaker' behavior to be sure.
        HEAP32[((value)>>2)]=0x3095;
        return 1;
      case 0x3080: // EGL_TEXTURE_FORMAT
      case 0x3081: // EGL_TEXTURE_TARGET
      case 0x3082: // EGL_MIPMAP_TEXTURE
      case 0x3083: // EGL_MIPMAP_LEVEL
        // This is a window surface, not a pbuffer surface. Spec:
        // "Querying EGL_TEXTURE_FORMAT, EGL_TEXTURE_TARGET, EGL_MIPMAP_TEXTURE, or EGL_MIPMAP_LEVEL for a non-pbuffer surface is not an error, but value is not modified."
        // So pass-through.
        return 1;
      default:
        EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
        return 0;
      }
    }
  function ___assert_func(filename, line, func, condition) {
      throw 'Assertion failed: ' + (condition ? Pointer_stringify(condition) : 'unknown condition') + ', at: ' + [filename ? Pointer_stringify(filename) : 'unknown filename', line, func ? Pointer_stringify(func) : 'unknown function'] + ' at ' + new Error().stack;
    }
  var _fseeko=_fseek;
  var _ftello=_ftell;
  function _llvm_umul_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm["setTempRet0"](x*y > 4294967295),(x*y)>>>0)|0);
    }
  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }var ___cxa_atexit=_atexit;
  Module["_strncpy"] = _strncpy;
  var _sqrtf=Math.sqrt;
  var _floor=Math.floor;
  var _ceilf=Math.ceil;
  function ___cxa_guard_acquire(variable) {
      if (!HEAP8[(variable)]) { // ignore SAFE_HEAP stuff because llvm mixes i64 and i8 here
        HEAP8[(variable)]=1;
        return 1;
      }
      return 0;
    }
  function ___cxa_guard_release() {}
  function _pthread_mutex_lock() {}
  function _pthread_mutex_unlock() {}
  function ___gxx_personality_v0() {
    }
  function __ZSt9terminatev() {
      _exit(-1234);
    }
  function _pthread_cond_broadcast() {
      return 0;
    }
  function _pthread_cond_wait() {
      return 0;
    }
  function ___cxa_allocate_exception(size) {
      return _malloc(size);
    }
  function ___cxa_free_exception(ptr) {
      try {
        return _free(ptr);
      } catch(e) { // XXX FIXME
      }
    }
  function _llvm_eh_exception() {
      return HEAP32[((_llvm_eh_exception.buf)>>2)];
    }
  function __ZSt18uncaught_exceptionv() { // std::uncaught_exception()
      return !!__ZSt18uncaught_exceptionv.uncaught_exception;
    }
  function ___cxa_is_number_type(type) {
      var isNumber = false;
      try { if (type == __ZTIi) isNumber = true } catch(e){}
      try { if (type == __ZTIj) isNumber = true } catch(e){}
      try { if (type == __ZTIl) isNumber = true } catch(e){}
      try { if (type == __ZTIm) isNumber = true } catch(e){}
      try { if (type == __ZTIx) isNumber = true } catch(e){}
      try { if (type == __ZTIy) isNumber = true } catch(e){}
      try { if (type == __ZTIf) isNumber = true } catch(e){}
      try { if (type == __ZTId) isNumber = true } catch(e){}
      try { if (type == __ZTIe) isNumber = true } catch(e){}
      try { if (type == __ZTIc) isNumber = true } catch(e){}
      try { if (type == __ZTIa) isNumber = true } catch(e){}
      try { if (type == __ZTIh) isNumber = true } catch(e){}
      try { if (type == __ZTIs) isNumber = true } catch(e){}
      try { if (type == __ZTIt) isNumber = true } catch(e){}
      return isNumber;
    }function ___cxa_does_inherit(definiteType, possibilityType, possibility) {
      if (possibility == 0) return false;
      if (possibilityType == 0 || possibilityType == definiteType)
        return true;
      var possibility_type_info;
      if (___cxa_is_number_type(possibilityType)) {
        possibility_type_info = possibilityType;
      } else {
        var possibility_type_infoAddr = HEAP32[((possibilityType)>>2)] - 8;
        possibility_type_info = HEAP32[((possibility_type_infoAddr)>>2)];
      }
      switch (possibility_type_info) {
      case 0: // possibility is a pointer
        // See if definite type is a pointer
        var definite_type_infoAddr = HEAP32[((definiteType)>>2)] - 8;
        var definite_type_info = HEAP32[((definite_type_infoAddr)>>2)];
        if (definite_type_info == 0) {
          // Also a pointer; compare base types of pointers
          var defPointerBaseAddr = definiteType+8;
          var defPointerBaseType = HEAP32[((defPointerBaseAddr)>>2)];
          var possPointerBaseAddr = possibilityType+8;
          var possPointerBaseType = HEAP32[((possPointerBaseAddr)>>2)];
          return ___cxa_does_inherit(defPointerBaseType, possPointerBaseType, possibility);
        } else
          return false; // one pointer and one non-pointer
      case 1: // class with no base class
        return false;
      case 2: // class with base class
        var parentTypeAddr = possibilityType + 8;
        var parentType = HEAP32[((parentTypeAddr)>>2)];
        return ___cxa_does_inherit(definiteType, parentType, possibility);
      default:
        return false; // some unencountered type
      }
    }
  function ___resumeException(ptr) {
      if (HEAP32[((_llvm_eh_exception.buf)>>2)] == 0) HEAP32[((_llvm_eh_exception.buf)>>2)]=ptr;
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";;
    }function ___cxa_find_matching_catch(thrown, throwntype) {
      if (thrown == -1) thrown = HEAP32[((_llvm_eh_exception.buf)>>2)];
      if (throwntype == -1) throwntype = HEAP32[(((_llvm_eh_exception.buf)+(4))>>2)];
      var typeArray = Array.prototype.slice.call(arguments, 2);
      // If throwntype is a pointer, this means a pointer has been
      // thrown. When a pointer is thrown, actually what's thrown
      // is a pointer to the pointer. We'll dereference it.
      if (throwntype != 0 && !___cxa_is_number_type(throwntype)) {
        var throwntypeInfoAddr= HEAP32[((throwntype)>>2)] - 8;
        var throwntypeInfo= HEAP32[((throwntypeInfoAddr)>>2)];
        if (throwntypeInfo == 0)
          thrown = HEAP32[((thrown)>>2)];
      }
      // The different catch blocks are denoted by different types.
      // Due to inheritance, those types may not precisely match the
      // type of the thrown object. Find one which matches, and
      // return the type of the catch block which should be called.
      for (var i = 0; i < typeArray.length; i++) {
        if (___cxa_does_inherit(typeArray[i], throwntype, thrown))
          return ((asm["setTempRet0"](typeArray[i]),thrown)|0);
      }
      // Shouldn't happen unless we have bogus data in typeArray
      // or encounter a type for which emscripten doesn't have suitable
      // typeinfo defined. Best-efforts match just in case.
      return ((asm["setTempRet0"](throwntype),thrown)|0);
    }function ___cxa_throw(ptr, type, destructor) {
      if (!___cxa_throw.initialized) {
        try {
          HEAP32[((__ZTVN10__cxxabiv119__pointer_type_infoE)>>2)]=0; // Workaround for libcxxabi integration bug
        } catch(e){}
        try {
          HEAP32[((__ZTVN10__cxxabiv117__class_type_infoE)>>2)]=1; // Workaround for libcxxabi integration bug
        } catch(e){}
        try {
          HEAP32[((__ZTVN10__cxxabiv120__si_class_type_infoE)>>2)]=2; // Workaround for libcxxabi integration bug
        } catch(e){}
        ___cxa_throw.initialized = true;
      }
      HEAP32[((_llvm_eh_exception.buf)>>2)]=ptr
      HEAP32[(((_llvm_eh_exception.buf)+(4))>>2)]=type
      HEAP32[(((_llvm_eh_exception.buf)+(8))>>2)]=destructor
      if (!("uncaught_exception" in __ZSt18uncaught_exceptionv)) {
        __ZSt18uncaught_exceptionv.uncaught_exception = 1;
      } else {
        __ZSt18uncaught_exceptionv.uncaught_exception++;
      }
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";;
    }
  function ___cxa_begin_catch(ptr) {
      __ZSt18uncaught_exceptionv.uncaught_exception--;
      return ptr;
    }
  function ___cxa_end_catch() {
      if (___cxa_end_catch.rethrown) {
        ___cxa_end_catch.rethrown = false;
        return;
      }
      // Clear state flag.
      asm['setThrew'](0);
      // Clear type.
      HEAP32[(((_llvm_eh_exception.buf)+(4))>>2)]=0
      // Call destructor if one is registered then clear it.
      var ptr = HEAP32[((_llvm_eh_exception.buf)>>2)];
      var destructor = HEAP32[(((_llvm_eh_exception.buf)+(8))>>2)];
      if (destructor) {
        Runtime.dynCall('vi', destructor, [ptr]);
        HEAP32[(((_llvm_eh_exception.buf)+(8))>>2)]=0
      }
      // Free ptr if it isn't null.
      if (ptr) {
        ___cxa_free_exception(ptr);
        HEAP32[((_llvm_eh_exception.buf)>>2)]=0
      }
    }
  function _ungetc(c, stream) {
      // int ungetc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ungetc.html
      stream = FS.getStream(stream);
      if (!stream) {
        return -1;
      }
      if (c === -1) {
        // do nothing for EOF character
        return c;
      }
      c = unSign(c & 0xFF);
      stream.ungotten.push(c);
      stream.eof = false;
      return c;
    }
  function _strerror_r(errnum, strerrbuf, buflen) {
      if (errnum in ERRNO_MESSAGES) {
        if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
          return ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          var msg = ERRNO_MESSAGES[errnum];
          for (var i = 0; i < msg.length; i++) {
            HEAP8[(((strerrbuf)+(i))|0)]=msg.charCodeAt(i)
          }
          HEAP8[(((strerrbuf)+(i))|0)]=0
          return 0;
        }
      } else {
        return ___setErrNo(ERRNO_CODES.EINVAL);
      }
    }function _strerror(errnum) {
      if (!_strerror.buffer) _strerror.buffer = _malloc(256);
      _strerror_r(errnum, _strerror.buffer, 256);
      return _strerror.buffer;
    }
  function _abort() {
      Module['abort']();
    }
  function ___cxa_rethrow() {
      ___cxa_end_catch.rethrown = true;
      throw HEAP32[((_llvm_eh_exception.buf)>>2)] + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";;
    }
  function _memchr(ptr, chr, num) {
      chr = unSign(chr);
      for (var i = 0; i < num; i++) {
        if (HEAP8[(ptr)] == chr) return ptr;
        ptr++;
      }
      return 0;
    }
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
        case 10: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
  function ___cxa_guard_abort() {}
  function _isxdigit(chr) {
      return (chr >= 48 && chr <= 57) ||
             (chr >= 97 && chr <= 102) ||
             (chr >= 65 && chr <= 70);
    }var _isxdigit_l=_isxdigit;
  function _isdigit(chr) {
      return chr >= 48 && chr <= 57;
    }var _isdigit_l=_isdigit;
  function __isFloat(text) {
      return !!(/^[+-]?[0-9]*\.?[0-9]+([eE][+-]?[0-9]+)?$/.exec(text));
    }function __scanString(format, get, unget, varargs) {
      if (!__scanString.whiteSpace) {
        __scanString.whiteSpace = {};
        __scanString.whiteSpace[32] = 1;
        __scanString.whiteSpace[9] = 1;
        __scanString.whiteSpace[10] = 1;
        __scanString.whiteSpace[11] = 1;
        __scanString.whiteSpace[12] = 1;
        __scanString.whiteSpace[13] = 1;
        __scanString.whiteSpace[' '] = 1;
        __scanString.whiteSpace['\t'] = 1;
        __scanString.whiteSpace['\n'] = 1;
        __scanString.whiteSpace['\v'] = 1;
        __scanString.whiteSpace['\f'] = 1;
        __scanString.whiteSpace['\r'] = 1;
      }
      // Supports %x, %4x, %d.%d, %lld, %s, %f, %lf.
      // TODO: Support all format specifiers.
      format = Pointer_stringify(format);
      var soFar = 0;
      if (format.indexOf('%n') >= 0) {
        // need to track soFar
        var _get = get;
        get = function() {
          soFar++;
          return _get();
        }
        var _unget = unget;
        unget = function() {
          soFar--;
          return _unget();
        }
      }
      var formatIndex = 0;
      var argsi = 0;
      var fields = 0;
      var argIndex = 0;
      var next;
      mainLoop:
      for (var formatIndex = 0; formatIndex < format.length;) {
        if (format[formatIndex] === '%' && format[formatIndex+1] == 'n') {
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          HEAP32[((argPtr)>>2)]=soFar;
          formatIndex += 2;
          continue;
        }
        if (format[formatIndex] === '%') {
          var nextC = format.indexOf('c', formatIndex+1);
          if (nextC > 0) {
            var maxx = 1;
            if (nextC > formatIndex+1) {
              var sub = format.substring(formatIndex+1, nextC)
              maxx = parseInt(sub);
              if (maxx != sub) maxx = 0;
            }
            if (maxx) {
              var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
              argIndex += Runtime.getAlignSize('void*', null, true);
              fields++;
              for (var i = 0; i < maxx; i++) {
                next = get();
                HEAP8[((argPtr++)|0)]=next;
              }
              formatIndex += nextC - formatIndex + 1;
              continue;
            }
          }
        }
        // remove whitespace
        while (1) {
          next = get();
          if (next == 0) return fields;
          if (!(next in __scanString.whiteSpace)) break;
        }
        unget();
        if (format[formatIndex] === '%') {
          formatIndex++;
          var suppressAssignment = false;
          if (format[formatIndex] == '*') {
            suppressAssignment = true;
            formatIndex++;
          }
          var maxSpecifierStart = formatIndex;
          while (format[formatIndex].charCodeAt(0) >= 48 &&
                 format[formatIndex].charCodeAt(0) <= 57) {
            formatIndex++;
          }
          var max_;
          if (formatIndex != maxSpecifierStart) {
            max_ = parseInt(format.slice(maxSpecifierStart, formatIndex), 10);
          }
          var long_ = false;
          var half = false;
          var longLong = false;
          if (format[formatIndex] == 'l') {
            long_ = true;
            formatIndex++;
            if (format[formatIndex] == 'l') {
              longLong = true;
              formatIndex++;
            }
          } else if (format[formatIndex] == 'h') {
            half = true;
            formatIndex++;
          }
          var type = format[formatIndex];
          formatIndex++;
          var curr = 0;
          var buffer = [];
          // Read characters according to the format. floats are trickier, they may be in an unfloat state in the middle, then be a valid float later
          if (type == 'f' || type == 'e' || type == 'g' ||
              type == 'F' || type == 'E' || type == 'G') {
            var last = 0;
            next = get();
            while (next > 0) {
              buffer.push(String.fromCharCode(next));
              if (__isFloat(buffer.join(''))) {
                last = buffer.length;
              }
              next = get();
            }
            for (var i = 0; i < buffer.length - last + 1; i++) {
              unget();
            }
            buffer.length = last;
          } else {
            next = get();
            var first = true;
            while ((curr < max_ || isNaN(max_)) && next > 0) {
              if (!(next in __scanString.whiteSpace) && // stop on whitespace
                  (type == 's' ||
                   ((type === 'd' || type == 'u' || type == 'i') && ((next >= 48 && next <= 57) ||
                                                                     (first && next == 45))) ||
                   ((type === 'x' || type === 'X') && (next >= 48 && next <= 57 ||
                                     next >= 97 && next <= 102 ||
                                     next >= 65 && next <= 70))) &&
                  (formatIndex >= format.length || next !== format[formatIndex].charCodeAt(0))) { // Stop when we read something that is coming up
                buffer.push(String.fromCharCode(next));
                next = get();
                curr++;
                first = false;
              } else {
                break;
              }
            }
            unget();
          }
          if (buffer.length === 0) return 0;  // Failure.
          if (suppressAssignment) continue;
          var text = buffer.join('');
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          switch (type) {
            case 'd': case 'u': case 'i':
              if (half) {
                HEAP16[((argPtr)>>1)]=parseInt(text, 10);
              } else if (longLong) {
                (tempI64 = [parseInt(text, 10)>>>0,(tempDouble=parseInt(text, 10),(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)],HEAP32[((argPtr)>>2)]=tempI64[0],HEAP32[(((argPtr)+(4))>>2)]=tempI64[1]);
              } else {
                HEAP32[((argPtr)>>2)]=parseInt(text, 10);
              }
              break;
            case 'X':
            case 'x':
              HEAP32[((argPtr)>>2)]=parseInt(text, 16)
              break;
            case 'F':
            case 'f':
            case 'E':
            case 'e':
            case 'G':
            case 'g':
            case 'E':
              // fallthrough intended
              if (long_) {
                HEAPF64[((argPtr)>>3)]=parseFloat(text)
              } else {
                HEAPF32[((argPtr)>>2)]=parseFloat(text)
              }
              break;
            case 's':
              var array = intArrayFromString(text);
              for (var j = 0; j < array.length; j++) {
                HEAP8[(((argPtr)+(j))|0)]=array[j]
              }
              break;
          }
          fields++;
        } else if (format[formatIndex] in __scanString.whiteSpace) {
          next = get();
          while (next in __scanString.whiteSpace) {
            if (next <= 0) break mainLoop;  // End of input.
            next = get();
          }
          unget(next);
          formatIndex++;
        } else {
          // Not a specifier.
          next = get();
          if (format[formatIndex].charCodeAt(0) !== next) {
            unget(next);
            break mainLoop;
          }
          formatIndex++;
        }
      }
      return fields;
    }function _sscanf(s, format, varargs) {
      // int sscanf(const char *restrict s, const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var index = 0;
      var get = function() { return HEAP8[(((s)+(index++))|0)]; };
      var unget = function() { index--; };
      return __scanString(format, get, unget, varargs);
    }
  function __Z7catopenPKci() { throw 'catopen not implemented' }
  function __Z7catgetsP8_nl_catdiiPKc() { throw 'catgets not implemented' }
  function __Z8catcloseP8_nl_catd() { throw 'catclose not implemented' }
  function _newlocale(mask, locale, base) {
      return 0;
    }
  function _freelocale(locale) {}
  function ___ctype_b_loc() {
      // http://refspecs.freestandards.org/LSB_3.0.0/LSB-Core-generic/LSB-Core-generic/baselib---ctype-b-loc.html
      var me = ___ctype_b_loc;
      if (!me.ret) {
        var values = [
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2,2,8195,8194,8194,8194,8194,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,24577,49156,49156,49156,
          49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,55304,55304,55304,55304,55304,55304,55304,55304,
          55304,55304,49156,49156,49156,49156,49156,49156,49156,54536,54536,54536,54536,54536,54536,50440,50440,50440,50440,50440,
          50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,49156,49156,49156,49156,49156,
          49156,54792,54792,54792,54792,54792,54792,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,
          50696,50696,50696,50696,50696,50696,50696,49156,49156,49156,49156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
        ];
        var i16size = 2;
        var arr = _malloc(values.length * i16size);
        for (var i = 0; i < values.length; i++) {
          HEAP16[(((arr)+(i * i16size))>>1)]=values[i]
        }
        me.ret = allocate([arr + 128 * i16size], 'i16*', ALLOC_NORMAL);
      }
      return me.ret;
    }
  function ___ctype_tolower_loc() {
      // http://refspecs.freestandards.org/LSB_3.1.1/LSB-Core-generic/LSB-Core-generic/libutil---ctype-tolower-loc.html
      var me = ___ctype_tolower_loc;
      if (!me.ret) {
        var values = [
          128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,
          158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,
          188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,
          218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,
          248,249,250,251,252,253,254,-1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,
          33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,97,98,99,100,101,102,103,
          104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,91,92,93,94,95,96,97,98,99,100,101,102,103,
          104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,
          134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,
          164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,
          194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,
          224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,
          254,255
        ];
        var i32size = 4;
        var arr = _malloc(values.length * i32size);
        for (var i = 0; i < values.length; i++) {
          HEAP32[(((arr)+(i * i32size))>>2)]=values[i]
        }
        me.ret = allocate([arr + 128 * i32size], 'i32*', ALLOC_NORMAL);
      }
      return me.ret;
    }
  function ___ctype_toupper_loc() {
      // http://refspecs.freestandards.org/LSB_3.1.1/LSB-Core-generic/LSB-Core-generic/libutil---ctype-toupper-loc.html
      var me = ___ctype_toupper_loc;
      if (!me.ret) {
        var values = [
          128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,
          158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,
          188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,
          218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,
          248,249,250,251,252,253,254,-1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,
          33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,
          73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,
          81,82,83,84,85,86,87,88,89,90,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,
          145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,
          175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,
          205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,
          235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255
        ];
        var i32size = 4;
        var arr = _malloc(values.length * i32size);
        for (var i = 0; i < values.length; i++) {
          HEAP32[(((arr)+(i * i32size))>>2)]=values[i]
        }
        me.ret = allocate([arr + 128 * i32size], 'i32*', ALLOC_NORMAL);
      }
      return me.ret;
    }
  var _strftime_l=_strftime;
  var _strtoull_l=_strtoull;
  function _strtoll(str, endptr, base) {
      return __parseInt64(str, endptr, base, '-9223372036854775808', '9223372036854775807');  // LLONG_MIN, LLONG_MAX.
    }var _strtoll_l=_strtoll;
  function _uselocale(locale) {
      return 0;
    }
  function ___locale_mb_cur_max() { throw '__locale_mb_cur_max not implemented' }
  var _llvm_va_start=undefined;
  function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }function _asprintf(s, format, varargs) {
      return _sprintf(-s, format, varargs);
    }function _vasprintf(s, format, va_arg) {
      return _asprintf(s, format, HEAP32[((va_arg)>>2)]);
    }
  function _llvm_va_end() {}
  function _vsnprintf(s, n, format, va_arg) {
      return _snprintf(s, n, format, HEAP32[((va_arg)>>2)]);
    }
  function _vsscanf(s, format, va_arg) {
      return _sscanf(s, format, HEAP32[((va_arg)>>2)]);
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }
  function ___cxa_call_unexpected(exception) {
      Module.printErr('Unexpected exception thrown, this is not properly supported - aborting');
      ABORT = true;
      throw exception;
    }
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
___buildEnvironment(ENV);
Module["requestFullScreen"] = function(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function() { Browser.getUserMedia() }
GL.init()
_llvm_eh_exception.buf = allocate(12, "void*", ALLOC_STATIC);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true; // seal the static portion of memory
STACK_MAX = STACK_BASE + 5242880;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
assert(DYNAMIC_BASE < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);
var Math_min = Math.min;
function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vif(index,a1,a2) {
  try {
    Module["dynCall_vif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viffff(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viffff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_if(index,a1) {
  try {
    return Module["dynCall_if"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiif(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiif"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viff(index,a1,a2,a3) {
  try {
    Module["dynCall_viff"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vifff(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_vifff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiif(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iif(index,a1,a2) {
  try {
    return Module["dynCall_iif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ff(index,a1) {
  try {
    return Module["dynCall_ff"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiif(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiif"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_fii(index,a1,a2) {
  try {
    return Module["dynCall_fii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_f(index) {
  try {
    return Module["dynCall_f"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    return Module["dynCall_iiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env.__ZTVN10__cxxabiv117__class_type_infoE|0;var p=env.___fsmu8|0;var q=env._stdout|0;var r=env.___dso_handle|0;var s=env._stdin|0;var t=env._stderr|0;var u=env.__ZTVN10__cxxabiv120__si_class_type_infoE|0;var v=+env.NaN;var w=+env.Infinity;var x=0;var y=0;var z=0;var A=0;var B=0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0.0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=0;var Q=0;var R=0;var S=0;var T=0;var U=global.Math.floor;var V=global.Math.abs;var W=global.Math.sqrt;var X=global.Math.pow;var Y=global.Math.cos;var Z=global.Math.sin;var _=global.Math.tan;var $=global.Math.acos;var aa=global.Math.asin;var ab=global.Math.atan;var ac=global.Math.atan2;var ad=global.Math.exp;var ae=global.Math.log;var af=global.Math.ceil;var ag=global.Math.imul;var ah=env.abort;var ai=env.assert;var aj=env.asmPrintInt;var ak=env.asmPrintFloat;var al=env.min;var am=env.invoke_iiiiiiii;var an=env.invoke_vif;var ao=env.invoke_viiiii;var ap=env.invoke_vi;var aq=env.invoke_vii;var ar=env.invoke_iiiiiii;var as=env.invoke_ii;var at=env.invoke_viiiiiiiiiii;var au=env.invoke_viffff;var av=env.invoke_if;var aw=env.invoke_iiiiii;var ax=env.invoke_iiii;var ay=env.invoke_viiiiif;var az=env.invoke_viff;var aA=env.invoke_vifff;var aB=env.invoke_viiiiii;var aC=env.invoke_iiif;var aD=env.invoke_viiiiiiii;var aE=env.invoke_iif;var aF=env.invoke_viiiiiii;var aG=env.invoke_ff;var aH=env.invoke_viiiiiiiii;var aI=env.invoke_viiiiiif;var aJ=env.invoke_iii;var aK=env.invoke_fii;var aL=env.invoke_f;var aM=env.invoke_i;var aN=env.invoke_iiiii;var aO=env.invoke_viii;var aP=env.invoke_v;var aQ=env.invoke_iiiiiiiii;var aR=env.invoke_viiii;var aS=env._llvm_lifetime_end;var aT=env._lseek;var aU=env._RWebInputDestroy;var aV=env._RWebAudioStop;var aW=env._glClearColor;var aX=env._sysconf;var aY=env.__scanString;var aZ=env._pthread_mutex_unlock;var a_=env._fclose;var a$=env._RWebAudioInit;var a0=env._glGetVertexAttribPointerv;var a1=env._pthread_mutex_lock;var a2=env._glGetRenderbufferParameteriv;var a3=env._eglDestroySurface;var a4=env._strtoul;var a5=env._strtoull;var a6=env._glBindTexture;var a7=env._fflush;var a8=env._isxdigit;var a9=env._glGetUniformiv;var ba=env._fabsf;var bb=env._strtol;var bc=env._fputc;var bd=env._glGetString;var be=env._fwrite;var bf=env._gluUnProject;var bg=env._send;var bh=env._fputs;var bi=env._glLineWidth;var bj=env._glUniform2fv;var bk=env._emscripten_get_now;var bl=env._asprintf;var bm=env._eglCreateContext;var bn=env._glBindAttribLocation;var bo=env._glCompileShader;var bp=env._isspace;var bq=env._localtime;var br=env._glDeleteTextures;var bs=env._eglBindAPI;var bt=env._glCompressedTexImage2D;var bu=env._sbrk;var bv=env._glStencilFuncSeparate;var bw=env._read;var bx=env._RWebAudioBufferSize;var by=env._glDeleteShader;var bz=env._RWebInputInit;var bA=env._glClearDepthf;var bB=env._glUniform4iv;var bC=env._glGetTexParameteriv;var bD=env._glClearStencil;var bE=env._glLoadIdentity;var bF=env._glUniform1fv;var bG=env.___cxa_guard_abort;var bH=env._glIsShader;var bI=env.__Z7catopenPKci;var bJ=env._strstr;var bK=env._glSampleCoverage;var bL=env._fsync;var bM=env._glGenTextures;var bN=env._newlocale;var bO=env._glDepthFunc;var bP=env._remove;var bQ=env._glCompressedTexSubImage2D;var bR=env._pthread_cond_wait;var bS=env._glUniform1f;var bT=env._opendir;var bU=env.___resumeException;var bV=env._glGetTexParameterfv;var bW=env._RWebAudioWrite;var bX=env._glStencilMaskSeparate;var bY=env._glCreateShader;var bZ=env._round;var b_=env._glUniform1i;var b$=env.___cxa_end_catch;var b0=env._strncmp;var b1=env._cosf;var b2=env._vsscanf;var b3=env._glDeleteRenderbuffers;var b4=env._glLinkProgram;var b5=env._snprintf;var b6=env._glUniform2i;var b7=env._fgetc;var b8=env._glStencilFunc;var b9=env._strerror_r;var ca=env._glShaderSource;var cb=env._ceilf;var cc=env._readdir;var cd=env._glVertexAttribPointer;var ce=env._glHint;var cf=env._glBindBuffer;var cg=env._llvm_umul_with_overflow_i32;var ch=env._glVertexPointer;var ci=env._fgets;var cj=env._close;var ck=env._getgid;var cl=env._glGetAttachedShaders;var cm=env._glBindFramebuffer;var cn=env._glIsFramebuffer;var co=env._strchr;var cp=env._glUniform4fv;var cq=env._abort;var cr=env.___setErrNo;var cs=env._glDeleteFramebuffers;var ct=env._eglTerminate;var cu=env._glGetVertexAttribfv;var cv=env._glIsBuffer;var cw=env._emscripten_GetProcAddress;var cx=env._eglGetProcAddress;var cy=env._ftell;var cz=env._glDeleteProgram;var cA=env._exit;var cB=env._sprintf;var cC=env._glRenderbufferStorage;var cD=env.___ctype_b_loc;var cE=env._strrchr;var cF=env._freelocale;var cG=env._glAttachShader;var cH=env._RWebInputPoll;var cI=env._glUniform3i;var cJ=env._glIsProgram;var cK=env._glCheckFramebufferStatus;var cL=env.__isLeapYear;var cM=env._gluProject;var cN=env.___cxa_find_matching_catch;var cO=env._llvm_uadd_with_overflow_i32;var cP=env._localtime_r;var cQ=env._glUniform3f;var cR=env.___cxa_guard_acquire;var cS=env._glGetBufferParameteriv;var cT=env._glFlush;var cU=env._glBlendEquationSeparate;var cV=env._emscripten_get_canvas_size;var cW=env._glCopyTexImage2D;var cX=env._glDrawElements;var cY=env._glColorMask;var cZ=env._sinf;var c_=env._gluLookAt;var c$=env._eglInitialize;var c0=env._recv;var c1=env.__parseInt64;var c2=env._glVertexAttrib1fv;var c3=env._glUniform2iv;var c4=env.__ZSt18uncaught_exceptionv;var c5=env._putchar;var c6=env._glUniform1iv;var c7=env.___cxa_call_unexpected;var c8=env._glActiveTexture;var c9=env._glMatrixMode;var da=env._glBlendEquation;var db=env._strcmp;var dc=env._glVertexAttrib1f;var dd=env._RWebAudioWriteAvail;var de=env._glGenerateMipmap;var df=env._memchr;var dg=env._glDetachShader;var dh=env._glGetShaderiv;var di=env.__exit;var dj=env._strftime;var dk=env._glVertexAttrib3f;var dl=env._glGenRenderbuffers;var dm=env._tzset;var dn=env._RWebAudioSampleRate;var dp=env._glGetShaderPrecisionFormat;var dq=env._glVertexAttrib4fv;var dr=env.___cxa_throw;var ds=env._glDepthMask;var dt=env._glDisableVertexAttribArray;var du=env._glBegin;var dv=env._llvm_eh_exception;var dw=env._printf;var dx=env._glBindRenderbuffer;var dy=env._pread;var dz=env.___locale_mb_cur_max;var dA=env._fopen;var dB=env._open;var dC=env._glDrawArrays;var dD=env._usleep;var dE=env._llvm_pow_f32;var dF=env.__arraySum;var dG=env._glCopyTexSubImage2D;var dH=env._sqrtf;var dI=env._glDisable;var dJ=env._puts;var dK=env._glUniform4i;var dL=env.___assert_func;var dM=env._nanosleep;var dN=env._glClear;var dO=env._qsort;var dP=env._glUniform2f;var dQ=env._eglDestroyContext;var dR=env._isalpha;var dS=env._glEnableVertexAttribArray;var dT=env._rmdir;var dU=env._glUniform3fv;var dV=env._glStencilOp;var dW=env._strdup;var dX=env._glDepthRange;var dY=env.___cxa_free_exception;var dZ=env._glUniform4f;var d_=env._glFramebufferTexture2D;var d$=env._glUniformMatrix2fv;var d0=env._glGenVertexArrays;var d1=env._eglMakeCurrent;var d2=env._glUniformMatrix3fv;var d3=env._glutCreateWindow;var d4=env._glBufferData;var d5=env._glBlendColor;var d6=env._glGetUniformLocation;var d7=env._glIsEnabled;var d8=env.__formatString;var d9=env._pthread_cond_broadcast;var ea=env.__Z8catcloseP8_nl_catd;var eb=env._getenv;var ec=env.___cxa_does_inherit;var ed=env._glGetError;var ee=env._glGetVertexAttribiv;var ef=env._glTexParameteriv;var eg=env._glGetProgramiv;var eh=env._glVertexAttrib3fv;var ei=env._glGetFloatv;var ej=env._glBufferSubData;var ek=env._glUniform3iv;var el=env._glReadPixels;var em=env._glGenFramebuffers;var en=env._glFramebufferRenderbuffer;var eo=env._emscripten_procAddressTable;var ep=env._atexit;var eq=env._ceil;var er=env.___errno_location;var es=env._strerror;var et=env._glGetIntegerv;var eu=env._RWebAudioFree;var ev=env._llvm_lifetime_start;var ew=env._glIsRenderbuffer;var ex=env._llvm_bswap_i32;var ey=env._vsnprintf;var ez=env.__parseInt;var eA=env.___cxa_guard_release;var eB=env._ungetc;var eC=env._RWebAudioSetNonblockState;var eD=env._glVertexAttrib2fv;var eE=env._uselocale;var eF=env._glGetFramebufferAttachmentParameteriv;var eG=env._glUseProgram;var eH=env._sscanf;var eI=env._glTexImage2D;var eJ=env._glGetProgramInfoLog;var eK=env._glTexSubImage2D;var eL=env._glStencilMask;var eM=env._fread;var eN=env._glStencilOpSeparate;var eO=env._strtok_r;var eP=env._glGetShaderInfoLog;var eQ=env._glIsTexture;var eR=env._eglCreateWindowSurface;var eS=env._fprintf;var eT=env._glGetShaderSource;var eU=env._gluPerspective;var eV=env._strtoll;var eW=env._isdigit;var eX=env._eglChooseConfig;var eY=env.___buildEnvironment;var eZ=env._feof;var e_=env.__addDays;var e$=env.___cxa_rethrow;var e0=env._glScissor;var e1=env._glEnable;var e2=env._glBlendFuncSeparate;var e3=env._floor;var e4=env.__reallyNegative;var e5=env._glGetActiveAttrib;var e6=env._fseek;var e7=env._sqrt;var e8=env._glTexParameterfv;var e9=env._write;var fa=env._glGenBuffers;var fb=env._glFinish;var fc=env._glGetAttribLocation;var fd=env._glVertexAttrib4f;var fe=env._rewind;var ff=env.___cxa_allocate_exception;var fg=env._sin;var fh=env._glBlendFunc;var fi=env._glCreateProgram;var fj=env._realpath;var fk=env._stat;var fl=env._longjmp;var fm=env._vasprintf;var fn=env._glViewport;var fo=env._emscripten_set_main_loop;var fp=env._time;var fq=env.___ctype_toupper_loc;var fr=env.___cxa_begin_catch;var fs=env._glVertexAttrib2f;var ft=env._closedir;var fu=env._isgraph;var fv=env._readlink;var fw=env.___ctype_tolower_loc;var fx=env._glGetUniformfv;var fy=env._llvm_va_end;var fz=env._unlink;var fA=env._gluOrtho2D;var fB=env._glUniformMatrix4fv;var fC=env._glClearDepth;var fD=env._glGetActiveUniform;var fE=env._glutDestroyWindow;var fF=env._pwrite;var fG=env.__isFloat;var fH=env._fabs;var fI=env._glTexParameterf;var fJ=env.__ZSt9terminatev;var fK=env._RWebAudioStart;var fL=env._glTexParameteri;var fM=env._glFrontFace;var fN=env._glCullFace;var fO=env._glDepthRangef;var fP=env._glDeleteBuffers;var fQ=env._eglGetDisplay;var fR=env._emscripten_set_canvas_size;var fS=env.___cxa_is_number_type;var fT=env._glGetBooleanv;var fU=env._eglQuerySurface;var fV=env._glPixelStorei;var fW=env._readdir_r;var fX=env._glValidateProgram;var fY=env._glPolygonOffset;var fZ=env.__Z7catgetsP8_nl_catdiiPKc;var f_=env.___gxx_personality_v0;
// EMSCRIPTEN_START_FUNCS
function gv(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7>>3<<3;return b|0}function gw(){return i|0}function gx(a){a=a|0;i=a}function gy(a,b){a=a|0;b=b|0;if((x|0)==0){x=a;y=b}}function gz(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function gA(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function gB(a){a=a|0;K=a}function gC(a){a=a|0;L=a}function gD(a){a=a|0;M=a}function gE(a){a=a|0;N=a}function gF(a){a=a|0;O=a}function gG(a){a=a|0;P=a}function gH(a){a=a|0;Q=a}function gI(a){a=a|0;R=a}function gJ(a){a=a|0;S=a}function gK(a){a=a|0;T=a}function gL(){c[u+8>>2]=524;c[u+12>>2]=378;c[u+16>>2]=134;c[u+20>>2]=320;c[u+24>>2]=36;c[u+28>>2]=14;c[u+32>>2]=8;c[u+36>>2]=28;c[o+8>>2]=524;c[o+12>>2]=400;c[o+16>>2]=134;c[o+20>>2]=320;c[o+24>>2]=36;c[o+28>>2]=6;c[o+32>>2]=4;c[o+36>>2]=44;c[19760]=o+8;c[19762]=o+8;c[19764]=u+8;c[19768]=u+8;c[19772]=u+8;c[19776]=u+8;c[19780]=u+8;c[19784]=u+8;c[19788]=o+8;c[19822]=u+8;c[19826]=u+8;c[19890]=u+8;c[19894]=u+8;c[19914]=o+8;c[19916]=u+8;c[19952]=u+8;c[19956]=u+8;c[19992]=u+8;c[19996]=u+8;c[20016]=o+8;c[20018]=o+8;c[20020]=u+8;c[20024]=u+8;c[20028]=u+8;c[20032]=o+8;c[20034]=o+8;c[20036]=o+8;c[20038]=o+8;c[20040]=o+8;c[20042]=o+8;c[20044]=o+8;c[20070]=u+8;c[20074]=o+8;c[20076]=u+8;c[20080]=u+8;c[20084]=u+8;c[20088]=o+8;c[20090]=o+8;c[20092]=o+8;c[20094]=o+8;c[20128]=o+8;c[20130]=o+8;c[20132]=o+8;c[20134]=u+8;c[20138]=u+8;c[20142]=u+8;c[20146]=u+8;c[20150]=u+8;c[20154]=u+8}function gM(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+20480|0;f=e|0;h=e+12288|0;fR(800,600);yB(303024,0,102392);j=c[140620]|0;if((j|0)!=0){a_(j|0)|0}yB(405432,0,158128);a[405434]=1;a[405433]=1;c[102392]=0;c[101359]=1;c[101360]=1;c[101361]=1;c[101362]=1;c[101363]=1;c[101364]=1;c[101365]=1;c[101366]=1;gX();j=g4(b,d)|0;if((j|0)!=0){k=j;i=e;return k|0}j=e+16384|0;d=ys(113728)|0;b=(d|0)==0;do{if(!b){if((c[d-4>>2]&3|0)==0){break}yB(d|0,0,113728)}}while(0);l=d;c[d+28>>2]=86184;c[d+32>>2]=640;c[d+4152>>2]=8392;m=4096;n=d+54|0;o=401313;while(1){p=m-1|0;if((p|0)==0){q=10;break}r=a[o]|0;a[n]=r;if(r<<24>>24==0){break}else{m=p;n=n+1|0;o=o+1|0}}do{if((q|0)==10){a[n]=0;if((a[o]|0)==0){break}else{s=o}do{s=s+1|0;}while((a[s]|0)!=0)}}while(0);s=ys(12)|0;o=(s|0)==0;do{if(!o){if((c[s-4>>2]&3|0)==0){break}yB(s|0,0,12)}}while(0);c[d+40>>2]=s;n=ys(12)|0;do{if((n|0)!=0){if((c[n-4>>2]&3|0)==0){break}yB(n|0,0,12)}}while(0);c[d+44>>2]=n;if(!o){o=s+8|0;n=s+4|0;m=c[n>>2]|0;if((c[o>>2]|0)>>>0<m>>>0){u=s}else{p=(m<<1)+2|0;c[n>>2]=p;n=s;c[n>>2]=yu(c[n>>2]|0,p*12|0)|0;u=n}n=dW(564064)|0;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)>>2]=n;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=4;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1}c[d+48>>2]=0;jh(l);o=c[140916]|0;do{if((o|0)==0){v=1.3333333730697632}else{if(!((c[140607]|0)==0|(c[140608]|0)==0)){v=1.3333333730697632;break}f3[c[(c[140913]|0)+44>>2]&1023](o,562420);v=+((c[140607]|0)>>>0>>>0)/+((c[140608]|0)>>>0>>>0)}}while(0);g[2711]=v;c[21160]=l;if(b){b=c[140620]|0;l=(b|0)!=0?b:c[t>>2]|0;be(41512,48,1,l|0)|0;l=c[140620]|0;b=(l|0)!=0?l:c[t>>2]|0;a7(b|0)|0;if((a[562485]&1)==0){b=c[140620]|0;l=(b|0)!=0?b:c[t>>2]|0;eS(l|0,35072,(w=i,i=i+16|0,c[w>>2]=33952,c[w+8>>2]=832,w)|0)|0;i=w;l=c[140620]|0;b=(l|0)!=0?l:c[t>>2]|0;a7(b|0)|0;cA(2);return 0}else{a[562487]=109;a[562488]=101;a[562489]=110;a[562490]=117;a[562491]=95;a[562492]=105;a[562493]=110;a[562494]=105;a[562495]=116;a[562496]=40;a[562497]=41;a[562498]=0;fl(563512,1);return 0}}yB(d|0,0,17);a[d+36|0]=1;c[d+113708>>2]=0;c[d+4160>>2]=26728;c[d+4164>>2]=34200;a[d+4172|0]=0;a[d+4173|0]=0;c[d+4168>>2]=28696;b=h|0;h=cE(303140,46)|0;l=(h|0)==0?564064:h+1|0;L44:do{if((db(l|0,50088)|0)==0){q=32}else{if((db(l|0,50664)|0)==0){q=32;break}do{if((db(l|0,42248)|0)!=0){if((db(l|0,29872)|0)==0){break}h=(a[311341]|0)!=0?311341:397180;hm(b,h,47152);o=hC(b,0)|0;if((o|0)==0){hm(b,h,47048);h=hC(b,0)|0;if((h|0)==0){break L44}else{x=h}}else{x=o}o=d+4180|0;if(iX(x,o)|0){i$(o,b)}hA(x);break L44}}while(0);o=4096;h=d+4256|0;u=303140;while(1){n=o-1|0;if((n|0)==0){q=41;break}p=a[u]|0;a[h]=p;if(p<<24>>24==0){break}else{o=n;h=h+1|0;u=u+1|0}}do{if((q|0)==41){a[h]=0;if((a[u]|0)==0){break}else{y=u}do{y=y+1|0;}while((a[y]|0)!=0)}}while(0);c[d+4252>>2]=1}}while(0);do{if((q|0)==32){y=hC(303140,0)|0;if((y|0)==0){break}x=d+4180|0;if(iX(y,x)|0){i$(x,303140)}hA(y)}}while(0);if((a[425962]|0)!=0){L74:do{if((a[376696]|0)==0){hw(j,425962,39456)}else{d=4096;y=j;x=376696;while(1){l=d-1|0;if((l|0)==0){break}u=a[x]|0;a[y]=u;if(u<<24>>24==0){break L74}else{d=l;y=y+1|0;x=x+1|0}}a[y]=0;if((a[x]|0)==0){break}else{z=x}do{z=z+1|0;}while((a[z]|0)!=0)}}while(0);if((a[405432]&1)!=0){z=c[140620]|0;x=(z|0)!=0?z:c[t>>2]|0;eS(x|0,38152,(w=i,i=i+8|0,c[w>>2]=j,w)|0)|0;i=w;x=c[140620]|0;z=(x|0)!=0?x:c[t>>2]|0;a7(z|0)|0}z=c[95198]|0;x=ys(16)|0;do{if((x|0)==0){A=0}else{if((c[x-4>>2]&3|0)!=0){yB(x|0,0,16)}y=x;do{if((z|0)==0){B=0}else{d=z*12|0;if(z>>>0<=65535){B=d;break}B=((d>>>0)/(z>>>0)|0|0)==12?d:-1}}while(0);d=ys(B)|0;if((d|0)==0){c[x>>2]=0;jo(y);A=0;break}if((c[d-4>>2]&3|0)==0){l=x;c[l>>2]=d;C=l}else{yB(d|0,0,B|0);l=x;c[l>>2]=d;C=l}l=x+8|0;c[l>>2]=z;d=f|0;u=dA(j|0,11144)|0;if((u|0)!=0){h=x+4|0;c[h>>2]=0;L104:do{if((c[l>>2]|0)!=0){o=f+4096|0;n=f+8192|0;do{a[d]=0;if((ci(d|0,4096,u|0)|0)==0){break L104}p=cE(d|0,10)|0;if((p|0)!=0){a[p]=0}a[o]=0;if((ci(o|0,4096,u|0)|0)==0){break L104}p=cE(o|0,10)|0;if((p|0)!=0){a[p]=0}a[n]=0;if((ci(n|0,4096,u|0)|0)==0){break L104}p=cE(n|0,10)|0;if((p|0)!=0){a[p]=0}p=c[h>>2]|0;s=c[C>>2]|0;if((a[o]|0)==0){break L104}if((a[n]|0)==0){break L104}if((a[d]|0)!=0){c[s+(p*12|0)>>2]=dW(d|0)|0}c[s+(p*12|0)+4>>2]=dW(o|0)|0;c[s+(p*12|0)+8>>2]=dW(n|0)|0;p=(c[h>>2]|0)+1|0;c[h>>2]=p;}while(p>>>0<(c[l>>2]|0)>>>0)}}while(0);a_(u|0)|0}c[x+12>>2]=dW(j|0)|0;A=y}}while(0);c[(c[21160]|0)+113712>>2]=A}v=+bk()*1.0e3;A=+V(v)>=1.0?v>0.0?(al(+U(v/4294967296.0),4294967295.0)|0)>>>0:~~+af((v- +(~~v>>>0))/4294967296.0)>>>0:0;x=(c[21160]|0)+113720|0;c[x>>2]=~~v>>>0;c[x+4>>2]=A;A=562472;x=c[A+4>>2]|0;C=562472;c[C>>2]=c[A>>2]|1;c[C+4>>2]=x;do{if((a[563557]&1)==0){L131:do{if((a[405468]&1)==0){x=4096;C=j;A=442346;while(1){f=x-1|0;if((f|0)==0){break}z=a[A]|0;a[C]=z;if(z<<24>>24==0){break L131}else{x=f;C=C+1|0;A=A+1|0}}a[C]=0;if((a[A]|0)==0){break}else{D=A}do{D=D+1|0;}while((a[D]|0)!=0)}else{b5(j|0,4096,49280,(w=i,i=i+8|0,c[w>>2]=438250,w)|0)|0;i=w}}while(0);L140:do{if((a[j]|0)!=0){y=4096;u=b;A=j;while(1){C=y-1|0;if((C|0)==0){q=99;break}x=a[A]|0;a[u]=x;if(x<<24>>24==0){break}else{y=C;u=u+1|0;A=A+1|0}}do{if((q|0)==99){a[u]=0;if((a[A]|0)==0){break}else{E=A}do{E=E+1|0;}while((a[E]|0)!=0)}}while(0);if((fj(b|0,j|0)|0)==0){F=4096;G=j;H=b}else{break}while(1){A=F-1|0;if((A|0)==0){break}u=a[H]|0;a[G]=u;if(u<<24>>24==0){break L140}else{F=A;G=G+1|0;H=H+1|0}}a[G]=0;if((a[H]|0)==0){break}else{I=H}do{I=I+1|0;}while((a[I]|0)!=0)}}while(0);A=c[(c[21160]|0)+113712>>2]|0;if((A|0)==0){break}jn(A,(a[j]|0)!=0?j:0,c[124930]|0)}}while(0);fo(56,((a[303112]&1)!=0?0:2147483647)|0,1);k=0;i=e;return k|0}function gN(){var b=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,ag=0,ah=0,ai=0,aj=0,ak=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=i;i=i+8664|0;e=b|0;f=b+8|0;j=b+136|0;k=b+264|0;l=b+4360|0;m=b+8456|0;n=b+8464|0;o=b+8592|0;p=b+8656|0;if((a[499784]&1)!=0){a[499784]=0;q=c[21160]|0;if((a[q+4156|0]&1)!=0){yt(c[q+4152>>2]|0)}r=c[q+40>>2]|0;s=r+8|0;u=r|0;v=c[u>>2]|0;if((c[s>>2]|0)==0){w=v}else{x=0;y=v;while(1){yt(c[y+(x*12|0)>>2]|0);v=x+1|0;z=c[u>>2]|0;if(v>>>0<(c[s>>2]|0)>>>0){x=v;y=z}else{w=z;break}}}yt(w);yt(r);r=c[q+44>>2]|0;q=r+8|0;w=r|0;y=c[w>>2]|0;if((c[q>>2]|0)==0){A=y}else{x=0;s=y;while(1){yt(c[s+(x*12|0)>>2]|0);y=x+1|0;u=c[w>>2]|0;if(y>>>0<(c[q>>2]|0)>>>0){x=y;s=u}else{A=u;break}}}yt(A);yt(r);jo(c[(c[21160]|0)+113712>>2]|0);yt(c[21160]|0);L173:do{if(!((a[562486]&1)==0|(a[425962]|0)==0)){r=o|0;A=hC(425962,0)|0;do{if((A|0)==0){s=ys(20)|0;if((s|0)==0){break L173}if((c[s-4>>2]&3|0)==0){B=s;break}else{yB(s|0,0,20);B=s;break}}else{B=A}}while(0);if((a[405432]&1)!=0){A=c[140620]|0;s=(A|0)!=0?A:c[t>>2]|0;eS(s|0,51904,(C=i,i=i+8|0,c[C>>2]=425962,C)|0)|0;i=C;s=c[140620]|0;A=(s|0)!=0?s:c[t>>2]|0;a7(A|0)|0}hF(B,17432,380796);hF(B,13432,384892);hF(B,15344,(a[401276]&1)!=0?53312:31792);A=c[100321]|0;s=n|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,14840,s);hF(B,28768,303140);hF(B,28352,(a[307236]&1)!=0?53312:31792);D=+g[75782];b5(s|0,128,44088,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hF(B,30904,s);D=+g[75772];b5(s|0,128,44088,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hF(B,50648,s);D=+g[75773];b5(s|0,128,44088,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hF(B,48504,s);hF(B,31248,(a[303126]&1)!=0?53312:31792);hF(B,31648,(a[303133]&1)!=0?53312:31792);hF(B,32992,(a[303124]&1)!=0?53312:31792);D=+g[77834];b5(s|0,128,44088,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hF(B,29208,s);hF(B,4e4,(a[303112]&1)!=0?53312:31792);hF(B,39e3,(a[303113]&1)!=0?53312:31792);A=c[75780]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,37520,s);hF(B,35840,(a[303114]&1)!=0?53312:31792);A=c[75779]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,34576,s);A=c[75784]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,30472,s);hF(B,20096,319620);hF(B,19472,(a[327817]&1)!=0?53312:31792);D=+g[81955];b5(s|0,128,44088,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hF(B,19144,s);if((a[397180]|0)==0){hF(B,52592,21912)}else{hF(B,52592,397180)}if((a[475114]|0)==0){hF(B,54008,21912)}else{hF(B,54008,475114)}if((a[479210]|0)==0){hF(B,53416,21912)}else{hF(B,53416,479210)}if((a[311341]|0)==0){hF(B,22448,21912)}else{hF(B,22448,311341)}if((a[401313]|0)==0){hF(B,16112,21912)}else{hF(B,16112,401313)}if((a[483306]|0)==0){hF(B,15976,21912)}else{hF(B,15976,483306)}hF(B,15840,364400);D=+g[92124];b5(s|0,128,44088,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hF(B,15656,s);D=+g[92125];b5(s|0,128,44088,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hF(B,15480,s);hF(B,51408,(c[140612]|0)!=0?53312:31792);A=562472;if((c[A>>2]&16384|0)==0&(c[A+4>>2]&0|0)==0){hF(B,51080,31792)}else{hF(B,51080,53312)}A=562472;if((c[A>>2]&128|0)==0&(c[A+4>>2]&0|0)==0){hF(B,50632,31792)}else{hF(B,50632,53312)}A=562472;if((c[A>>2]&65536|0)==0&(c[A+4>>2]&0|0)==0){hF(B,50504,31792)}else{hF(B,50504,53312)}A=562472;if((c[A>>2]&32768|0)==0&(c[A+4>>2]&0|0)==0){hF(B,50312,31792)}else{hF(B,50312,53312)}A=d[562452]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,50064,s);A=d[562453]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,49848,s);A=c[140599]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,49680,s);A=c[140607]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,24192,s);A=c[140608]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,23888,s);A=c[140605]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,24672,s);A=c[140606]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,24440,s);D=+g[79884];b5(s|0,128,44088,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hF(B,27176,s);hF(B,54176,(a[562486]&1)!=0?53312:31792);A=c[140614]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,49552,s);A=c[124924]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,49264,s);A=a[504561]&1;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,15760,s);A=c[140611]|0;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hF(B,48712,s);A=562472;if((c[A>>2]&524288|0)==0&(c[A+4>>2]&0|0)==0){hF(B,48480,31792);E=0}else{hF(B,48480,53312);E=0}while(1){A=E+1|0;b5(r|0,64,48384,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=c[364356+(E<<2)>>2],C)|0)|0;i=C;hF(B,r,s);b5(r|0,64,48296,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=c[363812+(E<<2)>>2],C)|0)|0;i=C;hF(B,r,s);b5(r|0,64,20640,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;b5(s|0,128,11016,(C=i,i=i+8|0,c[C>>2]=c[363780+(E<<2)>>2],C)|0)|0;i=C;hF(B,r,s);if(A>>>0<8){E=A}else{break}}hG(B,425962)|0;hA(B)}}while(0);if((a[562484]&1)!=0){g7()}B=c[138489]|0;if((B|0)!=0){E=B+4|0;n=c[E>>2]|0;o=B|0;if(n>>>0>1){s=1;r=n;while(1){n=c[(c[o>>2]|0)+(s<<2)>>2]|0;if((n|0)==0){F=r}else{yt(c[n+8>>2]|0);yt(c[(c[o>>2]|0)+(s<<2)>>2]|0);c[(c[o>>2]|0)+(s<<2)>>2]=0;F=c[E>>2]|0}n=s+1|0;if(n>>>0<F>>>0){s=n;r=F}else{break}}}c[E>>2]=1;E=B+12|0;yt(c[E>>2]|0);c[E>>2]=0;yt(c[o>>2]|0);yt(B);c[138489]=0}yB(303024,0,102392);B=c[140620]|0;if((B|0)==0){yB(405432,0,158128);a[405434]=1;a[405433]=1;c[102392]=0;c[101359]=1;c[101360]=1;c[101361]=1;c[101362]=1;c[101363]=1;c[101364]=1;c[101365]=1;c[101366]=1;cA(0)}a_(B|0)|0;yB(405432,0,158128);a[405434]=1;a[405433]=1;c[102392]=0;c[101359]=1;c[101360]=1;c[101361]=1;c[101362]=1;c[101363]=1;c[101364]=1;c[101365]=1;c[101366]=1;cA(0)}B=562472;o=c[B>>2]|0;E=c[B+4>>2]|0;if(a[6072]|0){if(!((o&32|0)==0&(E&0|0)==0)){B=c[21160]|0;a[B+52|0]=1;F=562472;r=c[F+4>>2]|0;s=562472;c[s>>2]=c[F>>2]&-33;c[s+4>>2]=r;r=B|0;B=c[r+4>>2]|0;c[r>>2]=c[r>>2]|256;c[r+4>>2]=B}gU();if((c[140958]|0)!=0){do{if((a[563679]&1)==0){B=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,51)|0;r=563840;if((c[r>>2]&0|B&1|0)==0&(c[r+4>>2]&524288|0)==0){G=0;break}if((a[85944]&1)!=0){G=1;break}r=c[140958]|0;B=r+28|0;s=c[B>>2]|0;F=r+20|0;c[F>>2]=s;n=c[r+12>>2]|0;A=r+16|0;c[A>>2]=n+(s*136|0);x=r+4|0;q=c[(c[x>>2]|0)+4>>2]|0;w=r|0;u=c[w>>2]|0;y=c[n+(s*136|0)+8>>2]|0;z=c[n+(s*136|0)+12>>2]|0;v=c[n+(s*136|0)+16>>2]|0;gq[q&31](u,y,z,v)|0;v=c[A>>2]|0;f7[c[(c[x>>2]|0)+12>>2]&7](c[w>>2]|0,+g[v+24>>2],+g[v+28>>2],+g[v+32>>2],+g[v+36>>2]);f3[c[(c[x>>2]|0)+16>>2]&1023](c[w>>2]|0,(a[(c[A>>2]|0)+68|0]&1)!=0);a[r+9|0]=1;c[B>>2]=(((c[F>>2]|0)+1|0)>>>0)%((c[r+24>>2]|0)>>>0)|0;G=1}else{G=0}}while(0);a[85944]=G}if((a[563679]&1)==0){G=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,30)|0;r=563840;if((c[r>>2]&1073741824|G&1|0)==0&(c[r+4>>2]&0|0)==0){H=184}else{H=185}}else{H=184}do{if((H|0)==184){if(f5[c[(c[140913]|0)+12>>2]&255](c[140916]|0)|0){I=0;J=0;L=0}else{H=185;break}do{r=c[1480+(L<<2)>>2]|0;if((f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,1544,0,1,0,r)|0)<<16>>16==0){M=0;N=0}else{G=yN(1,0,c[1480+((L|1)<<2)>>2]|0)|0;F=K;M=F;N=G}G=563840;F=c[G>>2]|0;B=c[G+4>>2]|0;G=yN(1,0,r|0)|0;r=K;if((F&G|0)==0&(B&r|0)==0){O=0;P=0}else{r=yN(1,0,c[1480+((L|1)<<2)>>2]|0)|0;B=K;O=B;P=r}J=N|J|P;I=M|I|O;L=L+2|0;}while(L>>>0<16);if((a[563679]&1)==0){r=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,55)|0;B=563840;G=(c[B>>2]&0|r&1|0)!=0|(c[B+4>>2]&8388608|0)!=0;Q=G?0:0;R=G?256:0}else{Q=0;R=0}G=R|J;B=Q|I;r=c[21160]|0;F=r|0;A=B&~c[F+4>>2];w=r+8|0;c[w>>2]=G&~c[F>>2];c[w+4>>2]=A;do{if((J&15|0)==0&(I&0|0)==0){a[r+16|0]=0;H=200}else{A=((G>>>8|B<<24)&1^1)&255;a[r+16|0]=A;if((A&1)==0){H=200;break}if(!(a[6088]|0)){a[6088]=1;c[r+20>>2]=a[6080]|0?6:12;c[r+24>>2]=0;S=1;T=0;break}A=c[r+24>>2]|0;if(A>>>0<(c[r+20>>2]|0)>>>0){S=1;T=A;break}a[6088]=0;c[w>>2]=G;c[w+4>>2]=B;S=1;T=A}}while(0);if((H|0)==200){a[6088]=0;S=0;T=c[r+24>>2]|0}a[6080]=S;c[r+24>>2]=T+1;c[F>>2]=G;c[F+4>>2]=B;w=ji(r)|0;A=c[140964]|0;do{if((A|0)!=0){x=c[A+24>>2]|0;if((x|0)==0){break}gr[x&127](c[140916]|0,(a[(c[21160]|0)+36|0]&1)!=0,0)}}while(0);gQ();D=+bk()*1.0e3;A=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;r=(c[21160]|0)+113720|0;B=yM(~~D>>>0,A,c[r>>2]|0,c[r+4>>2]|0)|0;r=yT(B,K,1e3,0)|0;B=K;D=750.0/+g[77834];A=yM(~~D>>>0,+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0,r,B)|0;B=K;r=0;if((B|0)>(r|0)|(B|0)==(r|0)&A>>>0>0>>>0){r=A;A=m;c[m>>2]=0;c[m+4>>2]=0;c[m>>2]=(r>>>0)/1e3|0;c[A+4>>2]=((r>>>0)%1e3|0)*1e6|0;dM(A|0,0)|0}D=+bk()*1.0e3;A=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;r=c[21160]|0;B=r+113720|0;c[B>>2]=~~D>>>0;c[B+4>>2]=A;A=c[140964]|0;do{if((A|0)==0){W=r}else{B=c[A+24>>2]|0;if((B|0)==0){W=r;break}gr[B&127](c[140916]|0,0,0);W=c[21160]|0}}while(0);r=W+8|0;do{if((c[r>>2]&256|0)==0&(c[r+4>>2]&0|0)==0){X=0}else{if((a[562484]&1)==0){X=0;break}if((a[563557]&1)!=0){X=0;break}A=562472;B=c[A+4>>2]|0;F=562472;c[F>>2]=c[A>>2]|65;c[F+4>>2]=B;X=-1}}while(0);r=562472;B=c[r>>2]|0;F=c[r+4>>2]|0;if(!((B&64|0)==0&(F&0|0)==0)){r=562472;c[r>>2]=B&-65;c[r+4>>2]=F|0}do{if((X|0)<0){F=c[W+40>>2]|0;r=c[F+8>>2]|0;if((r|0)==0){Y=0;Z=W;_=F;$=0}else{B=c[(c[F>>2]|0)+((r-1|0)*12|0)+4>>2]|0;if((B|0)==4){break}else{Y=B;Z=W;_=F;$=r}}while(1){r=Z+48|0;F=_+8|0;if(($|0)!=0){B=$-1|0;c[F>>2]=B;yt(c[(c[_>>2]|0)+(B*12|0)>>2]|0)}if((r|0)!=0){c[r>>2]=c[(c[_>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]}F=c[21160]|0;r=c[F+40>>2]|0;B=c[r+8>>2]|0;if((B|0)==0){aa=Y}else{aa=c[(c[r>>2]|0)+((B-1|0)*12|0)+4>>2]|0}if((aa|0)==4){break}else{Y=aa;Z=F;_=r;$=B}}}}while(0);if((X|w|0)!=0){break}i=b;return}}while(0);if((H|0)==185){X=562472;$=c[X+4>>2]|0;_=562472;c[_>>2]=c[X>>2]|1;c[_+4>>2]=$}a[6072]=0;$=(a[563680]&1)!=0;_=c[140916]|0;if((a[405434]&1)!=0&(_|0)!=0){if((a[303112]&1)==0){H=229}else{if((a[499797]&1)==0){ab=$}else{H=229}}if((H|0)==229){ab=1}f3[c[(c[140913]|0)+8>>2]&1023](_,ab)}ab=c[140915]|0;if((a[405433]&1)!=0&(ab|0)!=0){f3[c[(c[140912]|0)+16>>2]&1023](ab,(a[323720]&1)==0|$);ac=c[140915]|0}else{ac=ab}c[126134]=$?c[126135]|0:c[126136]|0;do{if((ac|0)!=0){if(f5[c[(c[140912]|0)+12>>2]&255](ac)|0){break}$=c[140620]|0;ab=($|0)!=0?$:c[t>>2]|0;be(12560,81,1,ab|0)|0;ab=c[140620]|0;$=(ab|0)!=0?ab:c[t>>2]|0;a7($|0)|0;a[405433]=0}}while(0);ac=562472;$=c[ac+4>>2]|0;ab=562472;c[ab>>2]=c[ac>>2]&-5;c[ab+4>>2]=$;i=b;return}if((o&2|0)==0&(E&0|0)==0){if((o&1|0)==0&(E&0|0)==0){if((o&4|0)==0&(E&0|0)==0){a[499784]=1;i=b;return}$=562472;c[$>>2]=o|32;c[$+4>>2]=E;f3[c[(c[140913]|0)+8>>2]&1023](c[140916]|0,0);$=c[140915]|0;if(($|0)!=0){ab=c[(c[140912]|0)+8>>2]|0;f5[ab&255]($)|0}a[6072]=1;i=b;return}do{if((a[562183]&1)==0){H=295}else{if((a[562184]&1)!=0){H=295;break}if((a[563679]&1)==0){$=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,30)|0;ab=563840;if(!((c[ab>>2]&1073741824|$&1|0)==0&(c[ab+4>>2]&0|0)==0)){break}}if(!(f5[c[(c[140913]|0)+12>>2]&255](c[140916]|0)|0)){break}g5();gU();ab=p;c[p>>2]=0;c[p+4>>2]=0;c[p>>2]=0;c[ab+4>>2]=1e7;dM(ab|0,0)|0;i=b;return}}while(0);L367:do{if((H|0)==295){if((a[563679]&1)==0){p=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,30)|0;ab=563840;if(!((c[ab>>2]&1073741824|p&1|0)==0&(c[ab+4>>2]&0|0)==0)){break}}if(!(f5[c[(c[140913]|0)+12>>2]&255](c[140916]|0)|0)){break}do{if((a[563679]&1)==0){ab=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,55)|0;p=563840;if((c[p>>2]&0|ab&1|0)==0&(c[p+4>>2]&8388608|0)==0){H=301;break}ad=a[8360]|0;H=303}else{H=301}}while(0);do{if((H|0)==301){if((a[563557]&1)==0){ae=0;break}w=a[8360]|0;if((w&1)==0){ad=w;H=303}else{ae=0}}}while(0);do{if((H|0)==303){if((ad&1)!=0){ae=1;break}w=562472;p=c[w+4>>2]|0;ab=562472;c[ab>>2]=c[w>>2]|4;c[ab+4>>2]=p;a[8360]=1;p=504504;c[p>>2]=0;c[p+4>>2]=0;break L367}}while(0);a[8360]=ae;if((a[553960]&1)!=0){a[553960]=0;break}g5();p=c[138495]|0;if((p|0)!=0){ab=cy(c[p>>2]|0)|0;c[(c[p+12>>2]|0)+(c[p+20>>2]<<2)>>2]=ab}if((c[126122]|0)!=0){D=+bk()*1.0e3;ab=~~D>>>0;p=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;do{if((a[562183]&1)==0){w=(a[563680]&1)!=0;$=504504;ac=c[$>>2]|0;_=c[$+4>>2]|0;$=(ac|0)==0&(_|0)==0|w;X=504496;Z=c[X>>2]|0;aa=c[X+4>>2]|0;X=yM(ab,p,ac,_)|0;_=$?Z:X;X=$?aa:K;if(w){ag=X;ah=_;ai=0;aj=0;break}if((a[562185]&1)==0){ag=X;ah=_;ai=p;aj=ab;break}D=(+(_>>>0)+ +(X|0)*4294967296.0)/+g[100322];ag=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;ah=~~D>>>0;ai=p;aj=ab}else{X=504496;ag=c[X+4>>2]|0;ah=c[X>>2]|0;ai=0;aj=0}}while(0);ab=504504;c[ab>>2]=aj;c[ab+4>>2]=ai;f3[c[126122]&1023](ah,ag)}gs[c[21510]&63]();do{if(+g[100323]>=0.0){D=+bk()*1.0e3;ab=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;p=499712;X=499704;_=c[X>>2]|0;w=c[X+4>>2]|0;X=yM(c[p>>2]|0,c[p+4>>2]|0,~~D>>>0,ab)|0;ab=yL(X,K,_,w)|0;w=K;_=0;if((w|0)>(_|0)|(w|0)==(_|0)&ab>>>0>999>>>0){_=yT(ab,w,1e3,0)|0;w=_;_=e;c[e>>2]=0;c[e+4>>2]=0;c[e>>2]=(w>>>0)/1e3|0;c[_+4>>2]=((w>>>0)%1e3|0)*1e6|0;dM(_|0,0)|0;_=499704;w=499712;ab=yL(c[w>>2]|0,c[w+4>>2]|0,c[_>>2]|0,c[_+4>>2]|0)|0;_=499712;c[_>>2]=ab;c[_+4>>2]=K;break}else{D=+bk()*1.0e3;_=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;ab=499712;c[ab>>2]=~~D>>>0;c[ab+4>>2]=_;break}}}while(0);_=c[138495]|0;if((_|0)==0){i=b;return}ab=_+20|0;c[ab>>2]=(c[ab>>2]|0)+1&c[_+16>>2];ab=_+33|0;a[_+32|0]=a[ab]&1^1;a[ab]=0;i=b;return}}while(0);e=562472;ag=c[e+4>>2]|0;ah=562472;c[ah>>2]=c[e>>2]&-2;c[ah+4>>2]=ag;i=b;return}ag=k|0;k=l|0;L411:do{if((a[442346]|0)==0){l=c[21160]|0;if((a[l+4176|0]&1)==0){ak=l}else{H=248}}else{if((o&128|0)==0&(E&0|0)==0){H=248;break}hu(ag,442346,4096);b5(k|0,4096,47640,(C=i,i=i+8|0,c[C>>2]=ag,C)|0)|0;i=C;l=c[138489]|0;ah=l+4|0;if((c[ah>>2]|0)>>>0>=(c[l+8>>2]|0)>>>0){H=248;break}e=ys(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}yB(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=1;ai=dW(k|0)|0;aj=c[ah>>2]|0;c[e+8>>2]=ai;ai=l|0;c[(c[ai>>2]|0)+(aj<<2)>>2]=e;aj=c[ah>>2]|0;c[ah>>2]=aj+1;if(aj>>>0>1){am=aj}else{H=248;break}while(1){aj=am>>>1;ae=c[ai>>2]|0;ad=ae+(aj<<2)|0;ab=c[ad>>2]|0;_=c[ae+(am<<2)>>2]|0;if((c[_+4>>2]|0)>>>0<=(c[ab+4>>2]|0)>>>0){H=248;break L411}c[ad>>2]=_;c[(c[ai>>2]|0)+(am<<2)>>2]=ab;if(am>>>0>3){am=aj}else{H=248;break}}}}while(0);do{if((H|0)==248){am=c[21160]|0;E=c[am+4160>>2]|0;o=c[am+113712>>2]|0;if((o|0)==0){ak=am;break}jn(o,(a[442346]|0)!=0?442346:0,(E|0)==0?564064:E);ak=c[21160]|0}}while(0);yB(ak|0,0,17);a[ak+53|0]=1;ji(ak)|0;ak=c[140964]|0;do{if((ak|0)!=0){H=c[ak+24>>2]|0;if((H|0)==0){break}gr[H&127](c[140916]|0,(a[(c[21160]|0)+36|0]&1)!=0,0)}}while(0);if((c[140913]|0)!=0){gQ()}ak=c[140964]|0;do{if((ak|0)!=0){H=c[ak+24>>2]|0;if((H|0)==0){break}gr[H&127](c[140916]|0,0,0)}}while(0);if((a[562484]&1)!=0){g7()}ak=a[405432]&1;H=(a[425962]|0)!=0;E=H?425962:0;o=(a[475114]|0)!=0;am=o?475114:0;ai=(a[479210]|0)!=0;ah=ai?479210:0;e=(a[442346]|0)!=0;l=e?442346:0;aj=(c[21160]|0)+4176|0;ab=a[aj]&1;a[aj]=0;aj=f;_=j;if((a[562484]&1)!=0){g7()}yB(aj|0,0,128);ad=f|0;c[ad>>2]=dW(23816)|0;do{if(ab<<24>>24==0){ae=(a[405432]&1)!=0;if(e){if(ae){w=c[140620]|0;X=(w|0)!=0?w:c[t>>2]|0;eS(X|0,23480,(C=i,i=i+8|0,c[C>>2]=l,C)|0)|0;i=C;X=c[140620]|0;w=(X|0)!=0?X:c[t>>2]|0;a7(w|0)|0}c[f+4>>2]=dW(l|0)|0;an=2;break}else{if(ae){ae=c[140620]|0;w=(ae|0)!=0?ae:c[t>>2]|0;be(23240,40,1,w|0)|0;w=c[140620]|0;ae=(w|0)!=0?w:c[t>>2]|0;a7(ae|0)|0}c[f+4>>2]=dW(22960)|0;an=2;break}}else{an=1}}while(0);if(o){c[f+(an<<2)>>2]=dW(22792)|0;c[f+(an+1<<2)>>2]=dW(am|0)|0;ao=an+2|0}else{ao=an}if(ai){c[f+(ao<<2)>>2]=dW(22416)|0;c[f+(ao+1<<2)>>2]=dW(ah|0)|0;ap=ao+2|0}else{ap=ao}if(H){c[f+(ap<<2)>>2]=dW(21656)|0;c[f+(ap+1<<2)>>2]=dW(E|0)|0;aq=ap+2|0}else{aq=ap}if(ak<<24>>24==0){ar=aq}else{c[f+(aq<<2)>>2]=dW(21256)|0;ar=aq+1|0}yE(_|0,aj|0,128)|0;aj=g4(ar,ad)|0;ad=0;do{yt(c[j+(ad<<2)>>2]|0);ad=ad+1|0;}while(ad>>>0<32);if((aj|0)==0){if((a[405432]&1)!=0){aj=c[140620]|0;ad=(aj|0)!=0?aj:c[t>>2]|0;be(45200,45,1,ad|0)|0;ad=c[140620]|0;aj=(ad|0)!=0?ad:c[t>>2]|0;a7(aj|0)|0}aj=562472;ad=c[aj+4>>2]|0|0;j=562472;c[j>>2]=c[aj>>2]&-4|1;c[j+4>>2]=ad;i=b;return}hu(ag,442346,4096);b5(k|0,4096,43680,(C=i,i=i+8|0,c[C>>2]=ag,C)|0)|0;i=C;C=c[138489]|0;ag=C+4|0;L478:do{if((c[ag>>2]|0)>>>0<(c[C+8>>2]|0)>>>0){ad=ys(12)|0;do{if((ad|0)!=0){if((c[ad-4>>2]&3|0)==0){break}yB(ad|0,0,12)}}while(0);c[ad+4>>2]=1;c[ad>>2]=90;j=dW(k|0)|0;aj=c[ag>>2]|0;c[ad+8>>2]=j;j=C|0;c[(c[j>>2]|0)+(aj<<2)>>2]=ad;aj=c[ag>>2]|0;c[ag>>2]=aj+1;if(aj>>>0>1){as=aj}else{break}while(1){aj=as>>>1;ar=c[j>>2]|0;_=ar+(aj<<2)|0;aq=c[_>>2]|0;f=c[ar+(as<<2)>>2]|0;if((c[f+4>>2]|0)>>>0<=(c[aq+4>>2]|0)>>>0){break L478}c[_>>2]=f;c[(c[j>>2]|0)+(as<<2)>>2]=aq;if(as>>>0>3){as=aj}else{break}}}}while(0);a[(c[21160]|0)+53|0]=1;as=c[140620]|0;be(42512,52,1,((as|0)!=0?as:c[t>>2]|0)|0)|0;as=c[140620]|0;a7(((as|0)!=0?as:c[t>>2]|0)|0)|0;i=b;return}function gO(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=d<<1;if((e|0)==0){return d|0}else{f=0}do{g=b[a+(f<<1)>>1]|0;h=(c[126144]|0)-1|0;c[126144]=h;b[(c[126143]|0)+(h<<1)>>1]=g;f=f+1|0;}while(f>>>0<e>>>0);return d|0}function gP(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+24|0;d=b|0;if((a[393084]|0)==0){i=b;return}do{if((a[319567]&1)!=0|(c[126111]|0)!=0){e=c[140913]|0;if((c[e+48>>2]|0)==0){f=360;break}g=e+44|0;if((c[g>>2]|0)==0){f=360;break}yB(d|0,0,24);f3[c[g>>2]&1023](c[140916]|0,d);g=d+8|0;e=c[g>>2]|0;if((e|0)==0){f=365;break}h=d+12|0;j=c[h>>2]|0;if((j|0)==0){f=365;break}k=ys(ag(e*3|0,j)|0)|0;if((k|0)==0){f=365;break}if(gm[c[(c[140913]|0)+48>>2]&127](c[140916]|0,k)|0){j=c[g>>2]|0;g=it(k,j,c[h>>2]|0,j*3|0,1)|0;yt(k);if(g){f=363;break}else{f=365;break}}else{yt(k);f=365;break}}else{f=360}}while(0);do{if((f|0)==360){d=c[140556]|0;k=d;if((k|0)==(-1|0)|(k|0)==0){k=c[140620]|0;g=(k|0)!=0?k:c[t>>2]|0;be(55112,103,1,g|0)|0;g=c[140620]|0;k=(g|0)!=0?g:c[t>>2]|0;a7(k|0)|0;f=365;break}else{k=c[140557]|0;g=c[140558]|0;j=c[140559]|0;if(it(d+(ag(g-1|0,j)|0)|0,k,g,-j|0,0)|0){f=363;break}else{f=365;break}}}}while(0);do{if((f|0)==363){if((a[405432]&1)==0){l=39720;break}j=c[140620]|0;g=(j|0)!=0?j:c[t>>2]|0;be(49640,30,1,g|0)|0;g=c[140620]|0;j=(g|0)!=0?g:c[t>>2]|0;a7(j|0)|0;l=39720}else if((f|0)==365){j=c[140620]|0;be(30848,50,1,((j|0)!=0?j:c[t>>2]|0)|0)|0;j=c[140620]|0;a7(((j|0)!=0?j:c[t>>2]|0)|0)|0;l=26312}}while(0);j=c[138489]|0;g=j+4|0;k=c[g>>2]|0;if(k>>>0>1){d=j|0;h=1;e=k;while(1){k=c[(c[d>>2]|0)+(h<<2)>>2]|0;if((k|0)==0){m=e}else{yt(c[k+8>>2]|0);yt(c[(c[d>>2]|0)+(h<<2)>>2]|0);c[(c[d>>2]|0)+(h<<2)>>2]=0;m=c[g>>2]|0}k=h+1|0;if(k>>>0<m>>>0){h=k;e=m}else{break}}}c[g>>2]=1;g=j+12|0;yt(c[g>>2]|0);c[g>>2]=0;g=c[138489]|0;j=g+4|0;m=(c[j>>2]|0)>>>0<(c[g+8>>2]|0)>>>0;if((a[562183]&1)!=0){L529:do{if(m){e=ys(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}yB(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=1;h=dW(l|0)|0;d=c[j>>2]|0;c[e+8>>2]=h;h=g|0;c[(c[h>>2]|0)+(d<<2)>>2]=e;d=c[j>>2]|0;c[j>>2]=d+1;if(d>>>0>1){n=d}else{break}while(1){d=n>>>1;k=c[h>>2]|0;o=k+(d<<2)|0;p=c[o>>2]|0;q=c[k+(n<<2)>>2]|0;if((c[q+4>>2]|0)>>>0<=(c[p+4>>2]|0)>>>0){break L529}c[o>>2]=q;c[(c[h>>2]|0)+(n<<2)>>2]=p;if(n>>>0>3){n=d}else{break}}}}while(0);gQ();i=b;return}if(!m){i=b;return}m=ys(12)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}yB(m|0,0,12)}}while(0);c[m+4>>2]=1;c[m>>2]=180;n=dW(l|0)|0;l=c[j>>2]|0;c[m+8>>2]=n;n=g|0;c[(c[n>>2]|0)+(l<<2)>>2]=m;m=c[j>>2]|0;c[j>>2]=m+1;if(m>>>0>1){r=m}else{i=b;return}while(1){m=r>>>1;j=c[n>>2]|0;l=j+(m<<2)|0;g=c[l>>2]|0;h=c[j+(r<<2)>>2]|0;if((c[h+4>>2]|0)>>>0<=(c[g+4>>2]|0)>>>0){f=389;break}c[l>>2]=h;c[(c[n>>2]|0)+(r<<2)>>2]=g;if(r>>>0>3){r=m}else{f=390;break}}if((f|0)==389){i=b;return}else if((f|0)==390){i=b;return}}function gQ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[140556]|0;d=(b|0)==-1?0:b;b=c[140557]|0;e=c[140558]|0;f=c[140559]|0;if((a[405434]&1)==0){return}c[140556]=d;c[140557]=b;c[140558]=e;c[140559]=f;do{if((c[124948]|0)==0){g=d;if((g|0)==(-1|0)|(g|0)==0){h=d;i=f;break}c[140924]=b;c[140925]=e;c[140927]=b;c[140928]=e;c[140926]=f;c[140929]=b<<1;iS(563696,c[140956]|0,d);h=c[140956]|0;i=c[140929]|0}else{h=d;i=f}}while(0);f=h7(c[138489]|0)|0;c[140965]=f;if(f4[c[(c[140913]|0)+4>>2]&15](c[140916]|0,h,b,e,i,f)|0){return}a[405434]=0;return}function gR(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[405434]&1)==0){return}c[140556]=b;c[140557]=d;c[140558]=e;c[140559]=f;do{if((c[124948]|0)==0){g=b;if((g|0)==(-1|0)|(g|0)==0){h=b;i=f;break}c[140924]=d;c[140925]=e;c[140927]=d;c[140928]=e;c[140926]=f;c[140929]=d<<1;iS(563696,c[140956]|0,b);h=c[140956]|0;i=c[140929]|0}else{h=b;i=f}}while(0);f=h7(c[138489]|0)|0;c[140965]=f;if(f4[c[(c[140913]|0)+4>>2]&15](c[140916]|0,h,d,e,i,f)|0){return}a[405434]=0;return}function gS(b,c){b=b|0;c=c|0;var d=0,e=0;d=c>>>0>1024?1024:c;if(gT(b,d<<1)|0){e=a[405433]&1}else{e=0}a[405433]=e;return d|0}function gT(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0.0,q=0,r=0;f=i;i=i+24|0;j=f|0;if((a[562183]&1)!=0){k=1;i=f;return k|0}if((a[504561]&1)!=0){k=1;i=f;return k|0}if((a[405433]&1)==0){k=0;i=f;return k|0}yB(j|0,0,24);l=c[126132]|0;m=+g[126154]*30517578125.0e-15;if((e|0)==0){n=l}else{o=0;do{g[l+(o<<2)>>2]=m*+(b[d+(o<<1)>>1]|0);o=o+1|0;}while(o>>>0<e>>>0);n=c[126132]|0}c[j>>2]=n;c[j+8>>2]=e>>>1;c[j+4>>2]=c[126141];if((a[504596]&1)==0){p=+h[63069]}else{e=f5[c[(c[140912]|0)+32>>2]&255](c[140915]|0)|0;n=537392;o=c[n>>2]|0;d=yL(o,c[n+4>>2]|0,1,0)|0;n=537392;c[n>>2]=d;c[n+4>>2]=K;c[504624+((o&8191)<<2)>>2]=e;o=(c[126152]|0)>>>1;m=+h[63075]*(+(e-o|0)/+(o|0)*+g[81955]+1.0);h[63069]=m;p=m}o=j+16|0;h[o>>3]=p;if((a[562185]&1)!=0){h[o>>3]=p*+g[100322]}f3[c[(c[126131]|0)+4>>2]&1023](c[126130]|0,j);o=c[126141]|0;e=c[j+12>>2]|0;if((a[504560]&1)!=0){if((ga[c[(c[140912]|0)+4>>2]&127](c[140915]|0,o,e<<3)|0)>=0){k=1;i=f;return k|0}j=c[140620]|0;n=(j|0)!=0?j:c[t>>2]|0;be(32096,81,1,n|0)|0;n=c[140620]|0;j=(n|0)!=0?n:c[t>>2]|0;a7(j|0)|0;k=0;i=f;return k|0}j=c[126142]|0;n=e<<1;if((n|0)==0){q=j}else{d=0;do{l=~~(+g[o+(d<<2)>>2]*32768.0);if((l|0)>32767){r=32767}else{r=(l|0)<-32768?-32768:l&65535}b[j+(d<<1)>>1]=r;d=d+1|0;}while(d>>>0<n>>>0);q=c[126142]|0}if((ga[c[(c[140912]|0)+4>>2]&127](c[140915]|0,q,e<<2)|0)>=0){k=1;i=f;return k|0}e=c[140620]|0;be(32096,81,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[140620]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;k=0;i=f;return k|0}function gU(){var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0,S=0.0,T=0,U=0,W=0.0,X=0.0;d=i;i=i+16|0;e=d|0;f2[c[(c[140914]|0)+4>>2]&1023](c[140917]|0);f=c[140958]|0;if((f|0)==0){i=d;return}h=e;yB(563840,0,16);j=(a[(c[f+16>>2]|0)+68|0]&1)!=0?65542:6;if((f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,0,0,j,0,2)|0)<<16>>16==0){a[(c[140958]|0)+9|0]=0;i=d;return}f=e|0;k=e+8|0;l=e+10|0;m=e+12|0;n=e+14|0;o=0;do{p=f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,0,0,j,o,0)|0;q=f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,0,0,j,o,1)|0;r=c[140958]|0;yB(h|0,0,16);L635:do{if((a[r+8|0]&1)==0){a[r+9|0]=0;s=0;t=0}else{u=c[r+16>>2]|0;v=(+((p<<16>>16)+32767|0)/65535.0- +g[u+24>>2])/+g[u+32>>2];w=(+((q<<16>>16)+32767|0)/65535.0- +g[u+28>>2])/+g[u+36>>2];x=u+4|0;y=c[x>>2]|0;do{if((y|0)==0){z=r+9|0}else{A=r+28|0;B=0;C=y;while(1){D=u|0;E=c[D>>2]|0;F=E+(B*104|0)|0;G=c[E+(B*104|0)+8>>2]|0;do{if((G|0)==1){H=+g[F>>2];I=+V(+(v-H));J=+g[E+(B*104|0)+12>>2];if(I>J){K=C;break}I=+g[E+(B*104|0)+4>>2];L=+V(+(w-I));M=+g[E+(B*104|0)+16>>2];if(L>M){K=C}else{N=H;O=J;P=I;Q=M;R=458}}else if((G|0)==0){M=+g[F>>2];I=+g[E+(B*104|0)+12>>2];J=(v-M)/I;H=+g[E+(B*104|0)+4>>2];L=+g[E+(B*104|0)+16>>2];S=(w-H)/L;if(J*J+S*S>1.0){K=C}else{N=M;O=I;P=H;Q=L;R=458}}else{K=C}}while(0);do{if((R|0)==458){R=0;F=c[E+(B*104|0)+20>>2]|0;if((F|0)==0){G=E+(B*104|0)+24|0;T=c[G>>2]|0;U=c[G+4>>2]|0;G=c[f+4>>2]|U;c[f>>2]=c[f>>2]|T;c[f+4>>2]=G;if((T&0|0)==0&(U&524288|0)==0){K=C;break}c[A>>2]=c[(c[D>>2]|0)+(B*104|0)+36>>2];K=c[x>>2]|0;break}L=+g[E+(B*104|0)+32>>2];H=(v-N)/O/L;I=(w-P)/Q/L;if(+V(+H)>1.0){W=H>0.0?1.0:-1.0}else{W=H}if(+V(+I)>1.0){X=I>0.0?1.0:-1.0}else{X=I}U=(F|0)==2?2:0;b[e+8+(U<<1)>>1]=~~(W*32767.0);b[e+8+((U|1)<<1)>>1]=~~(X*32767.0);K=C}}while(0);E=B+1|0;if(E>>>0<K>>>0){B=E;C=K}else{break}}C=c[f>>2]|0;B=c[f+4>>2]|0;A=r+9|0;if((C|0)==0&(B|0)==0){z=A;break}if((a[A]&1)==0){s=B;t=C;break L635}yB(h|0,0,16);s=0;t=0;break L635}}while(0);a[z]=0;s=0;t=0}}while(0);r=563840;q=c[r+4>>2]|s;p=563840;c[p>>2]=c[r>>2]|t;c[p+4>>2]=q;if((b[281924]|0)==0){b[281924]=b[k>>1]|0}if((b[281925]|0)==0){b[281925]=b[l>>1]|0}if((b[281926]|0)==0){b[281926]=b[m>>1]|0}if((b[281927]|0)==0){b[281927]=b[n>>1]|0}o=o+1|0;}while((f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,0,0,j,o,2)|0)<<16>>16!=0);i=d;return}function gV(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;if((a[401276]&1)==0|(c[138491]|0)!=0){i=b;return}if((c[126103]|0)!=0){d=c[140620]|0;e=(d|0)!=0?d:c[t>>2]|0;be(17576,76,1,e|0)|0;e=c[140620]|0;d=(e|0)!=0?e:c[t>>2]|0;a7(d|0)|0;i=b;return}d=gp[c[21506]&31]()|0;c[138493]=d;if((d|0)==0){e=c[140620]|0;f=(e|0)!=0?e:c[t>>2]|0;be(15256,85,1,f|0)|0;f=c[140620]|0;e=(f|0)!=0?f:c[t>>2]|0;a7(e|0)|0;i=b;return}e=d+3|0;f=e&-4;g=ys(f)|0;if((g|0)==0){c[138492]=0;h=c[140620]|0;j=(h|0)!=0?h:c[t>>2]|0;be(12776,66,1,j|0)|0;j=c[140620]|0;h=(j|0)!=0?j:c[t>>2]|0;a7(h|0)|0;i=b;return}if((c[g-4>>2]&3|0)!=0){yB(g|0,0,f|0)}c[138492]=g;if(!(gm[c[21508]&127](g,d)|0)){d=c[140620]|0;g=(d|0)!=0?d:c[t>>2]|0;be(55032,73,1,g|0)|0;g=c[140620]|0;d=(g|0)!=0?g:c[t>>2]|0;a7(d|0)|0;yt(c[138492]|0);c[138492]=0;i=b;return}if((a[405432]&1)!=0){d=c[140620]|0;g=(d|0)!=0?d:c[t>>2]|0;d=((c[100320]|0)>>>0)/1e6|0;eS(g|0,52528,(k=i,i=i+8|0,c[k>>2]=d,k)|0)|0;i=k;d=c[140620]|0;g=(d|0)!=0?d:c[t>>2]|0;a7(g|0)|0}g=c[100320]|0;d=c[138492]|0;L704:do{if(f<<2>>>0<g>>>0){h=ys(32)|0;if((h|0)==0){l=514;break}if((c[h-4>>2]&3|0)!=0){yB(h|0,0,32)}j=h;c[h+16>>2]=1;m=e>>>2;c[h+24>>2]=m;n=g-1|0;o=n>>>1|n;n=o>>>2|o;o=n>>>4|n;n=o>>>8|o;o=(n>>>16|n)+1|0;n=o>>>1;p=(o-g|0)>>>0<(g-n|0)>>>0?o:n;n=p>>>3;c[h+4>>2]=n;c[h+8>>2]=n-1;if((a[405432]&1)!=0){o=c[140620]|0;q=(o|0)!=0?o:c[t>>2]|0;o=p>>>23<<3;eS(q|0,31584,(k=i,i=i+8|0,c[k>>2]=o,k)|0)|0;i=k;o=c[140620]|0;q=(o|0)!=0?o:c[t>>2]|0;a7(q|0)|0}q=n<<3;n=ys(q)|0;do{if((n|0)==0){c[h>>2]=0;r=h+12|0}else{if((c[n-4>>2]&3|0)==0){c[h>>2]=n}else{yB(n|0,0,q|0);c[h>>2]=n}o=m<<2;p=ys(o)|0;if((p|0)==0){s=h+12|0;c[s>>2]=0;r=s;break}if((c[p-4>>2]&3|0)==0){c[h+12>>2]=p;yE(p|0,d|0,f)|0;c[138491]=j;if((h|0)==0){break L704}i=b;return}else{yB(p|0,0,o|0);c[h+12>>2]=p;yE(p|0,d|0,f)|0;c[138491]=j;i=b;return}}}while(0);yt(n);yt(c[r>>2]|0);yt(h);l=514}else{l=514}}while(0);if((l|0)==514){c[138491]=0}l=c[140620]|0;be(48920,78,1,((l|0)!=0?l:c[t>>2]|0)|0)|0;l=c[140620]|0;a7(((l|0)!=0?l:c[t>>2]|0)|0)|0;i=b;return}function gW(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;a=i;i=i+4608|0;b=c[124924]|0;d=a|0;if((b|0)==0){b5(d|0,4096,32576,(e=i,i=i+8|0,c[e>>2]=466922,e)|0)|0;i=e}else{b5(d|0,4096,47920,(e=i,i=i+16|0,c[e>>2]=466922,c[e+8>>2]=b,e)|0)|0;i=e}b=a+4096|0;if(he(d)|0){f=c[124924]|0;b5(b|0,512,45400,(e=i,i=i+8|0,c[e>>2]=f,e)|0)|0;i=e}else{b5(b|0,512,43984,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e}e=c[138489]|0;d=e+4|0;f=c[d>>2]|0;if(f>>>0>1){g=e|0;h=1;j=f;while(1){f=c[(c[g>>2]|0)+(h<<2)>>2]|0;if((f|0)==0){k=j}else{yt(c[f+8>>2]|0);yt(c[(c[g>>2]|0)+(h<<2)>>2]|0);c[(c[g>>2]|0)+(h<<2)>>2]=0;k=c[d>>2]|0}f=h+1|0;if(f>>>0<k>>>0){h=f;j=k}else{break}}}c[d>>2]=1;d=e+12|0;yt(c[d>>2]|0);c[d>>2]=0;d=c[138489]|0;e=d+4|0;if((c[e>>2]|0)>>>0>=(c[d+8>>2]|0)>>>0){i=a;return}k=ys(12)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}yB(k|0,0,12)}}while(0);c[k+4>>2]=2;c[k>>2]=180;j=dW(b|0)|0;b=c[e>>2]|0;c[k+8>>2]=j;j=d|0;c[(c[j>>2]|0)+(b<<2)>>2]=k;k=c[e>>2]|0;c[e>>2]=k+1;if(k>>>0>1){l=k}else{i=a;return}while(1){k=l>>>1;e=c[j>>2]|0;b=e+(k<<2)|0;d=c[b>>2]|0;h=c[e+(l<<2)>>2]|0;if((c[h+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){m=547;break}c[b>>2]=h;c[(c[j>>2]|0)+(l<<2)>>2]=d;if(l>>>0>3){l=k}else{m=548;break}}if((m|0)==547){i=a;return}else if((m|0)==548){i=a;return}}function gX(){var a=0,b=0,d=0;a=i;if((c[138489]|0)!=0){i=a;return}b=ys(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)!=0){yB(b|0,0,16)}c[b+8>>2]=9;d=ys(36)|0;if((d|0)==0){c[b>>2]=0;yt(b);break}if((c[d-4>>2]&3|0)!=0){yB(d|0,0,36)}c[b>>2]=d;c[b+4>>2]=1;c[138489]=b;i=a;return}}while(0);c[138489]=0;a=c[140620]|0;eS(((a|0)!=0?a:c[t>>2]|0)|0,35072,(a=i,i=i+16|0,c[a>>2]=19960,c[a+8>>2]=1408,a)|0)|0;i=a;a=c[140620]|0;a7(((a|0)!=0?a:c[t>>2]|0)|0)|0;cA(2)}function gY(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+4608|0;d=c[124924]|0;if((a[401305]&1)==0){e=d}else{f=d+1|0;c[124924]=f;e=f}f=b|0;if((e|0)==0){b5(f|0,4096,32576,(g=i,i=i+8|0,c[g>>2]=466922,g)|0)|0;i=g}else{b5(f|0,4096,47920,(g=i,i=i+16|0,c[g>>2]=466922,c[g+8>>2]=e,g)|0)|0;i=g}e=b+4096|0;if(hd(f)|0){d=c[124924]|0;b5(e|0,512,42752,(g=i,i=i+8|0,c[g>>2]=d,g)|0)|0;i=g}else{b5(e|0,512,41792,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g}g=c[138489]|0;f=g+4|0;d=c[f>>2]|0;if(d>>>0>1){h=g|0;j=1;k=d;while(1){d=c[(c[h>>2]|0)+(j<<2)>>2]|0;if((d|0)==0){l=k}else{yt(c[d+8>>2]|0);yt(c[(c[h>>2]|0)+(j<<2)>>2]|0);c[(c[h>>2]|0)+(j<<2)>>2]=0;l=c[f>>2]|0}d=j+1|0;if(d>>>0<l>>>0){j=d;k=l}else{break}}}c[f>>2]=1;f=g+12|0;yt(c[f>>2]|0);c[f>>2]=0;f=c[138489]|0;g=f+4|0;if((c[g>>2]|0)>>>0>=(c[f+8>>2]|0)>>>0){i=b;return}l=ys(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}yB(l|0,0,12)}}while(0);c[l+4>>2]=2;c[l>>2]=180;k=dW(e|0)|0;e=c[g>>2]|0;c[l+8>>2]=k;k=f|0;c[(c[k>>2]|0)+(e<<2)>>2]=l;l=c[g>>2]|0;c[g>>2]=l+1;if(l>>>0>1){m=l}else{i=b;return}while(1){l=m>>>1;g=c[k>>2]|0;e=g+(l<<2)|0;f=c[e>>2]|0;j=c[g+(m<<2)>>2]|0;if((c[j+4>>2]|0)>>>0<=(c[f+4>>2]|0)>>>0){n=585;break}c[e>>2]=j;c[(c[k>>2]|0)+(m<<2)>>2]=f;if(m>>>0>3){m=l}else{n=583;break}}if((n|0)==583){i=b;return}else if((n|0)==585){i=b;return}}function gZ(b){b=b|0;a[303096]=b&1;a[563673]=a[504472]&1;a[563674]=0;hy();b=c[126119]|0;do{if((b|0)!=0){if((a[563673]&1)!=0){break}gs[b&63]()}}while(0);hz();if((a[563675]&1)!=0){c[140916]=0}if((a[563676]&1)!=0){c[140915]=0}if((a[563677]&1)!=0){c[140917]=0}a[563675]=0;a[563676]=0;a[563677]=0;hx();a[563673]=0;b=c[140914]|0;if((b|0)==0){return}f2[c[b+4>>2]&1023](c[140917]|0);return}function g_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[405432]&1)!=0){b=c[140620]|0;d=(b|0)!=0?b:c[t>>2]|0;be(38664,27,1,d|0)|0;d=c[140620]|0;b=(d|0)!=0?d:c[t>>2]|0;a7(b|0)|0}b=c[138489]|0;d=b+4|0;e=c[d>>2]|0;if(e>>>0>1){f=b|0;g=1;h=e;while(1){e=c[(c[f>>2]|0)+(g<<2)>>2]|0;if((e|0)==0){i=h}else{yt(c[e+8>>2]|0);yt(c[(c[f>>2]|0)+(g<<2)>>2]|0);c[(c[f>>2]|0)+(g<<2)>>2]=0;i=c[d>>2]|0}e=g+1|0;if(e>>>0<i>>>0){g=e;h=i}else{break}}}c[d>>2]=1;d=b+12|0;yt(c[d>>2]|0);c[d>>2]=0;d=c[138489]|0;b=d+4|0;if((c[b>>2]|0)>>>0>=(c[d+8>>2]|0)>>>0){j=c[21512]|0;gs[j&63]();g$();return}i=ys(12)|0;do{if((i|0)!=0){if((c[i-4>>2]&3|0)==0){break}yB(i|0,0,12)}}while(0);c[i+4>>2]=1;c[i>>2]=120;h=dW(36688)|0;g=c[b>>2]|0;c[i+8>>2]=h;h=d|0;c[(c[h>>2]|0)+(g<<2)>>2]=i;i=c[b>>2]|0;c[b>>2]=i+1;if(i>>>0>1){k=i}else{j=c[21512]|0;gs[j&63]();g$();return}while(1){i=k>>>1;b=c[h>>2]|0;g=b+(i<<2)|0;d=c[g>>2]|0;f=c[b+(k<<2)>>2]|0;if((c[f+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){l=617;break}c[g>>2]=f;c[(c[h>>2]|0)+(k<<2)>>2]=d;if(k>>>0>3){k=i}else{l=618;break}}if((l|0)==617){j=c[21512]|0;gs[j&63]();g$();return}else if((l|0)==618){j=c[21512]|0;gs[j&63]();g$();return}}function g$(){var b=0,d=0,e=0,f=0,g=0;b=i;d=0;do{e=c[405436+(d<<2)>>2]|0;L865:do{if((e|0)!=1){f3[c[21500]&1023](d,e);switch(e|0){case 5:{if((a[405432]&1)==0){break L865}f=c[140620]|0;eS(((f|0)!=0?f:c[t>>2]|0)|0,32776,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[140620]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 0:{if((a[405432]&1)==0){break L865}f=c[140620]|0;eS(((f|0)!=0?f:c[t>>2]|0)|0,32824,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[140620]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 772:{if((a[405432]&1)==0){break L865}f=c[140620]|0;eS(((f|0)!=0?f:c[t>>2]|0)|0,32624,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[140620]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 260:{if((a[405432]&1)==0){break L865}f=c[140620]|0;eS(((f|0)!=0?f:c[t>>2]|0)|0,32280,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[140620]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 516:{if((a[405432]&1)==0){break L865}f=c[140620]|0;eS(((f|0)!=0?f:c[t>>2]|0)|0,32672,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[140620]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 257:{if((a[405432]&1)==0){break L865}f=c[140620]|0;eS(((f|0)!=0?f:c[t>>2]|0)|0,32440,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[140620]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 2:{if((a[405432]&1)==0){break L865}f=c[140620]|0;eS(((f|0)!=0?f:c[t>>2]|0)|0,32728,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[140620]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};default:{break L865}}}}while(0);d=d+1|0;}while(d>>>0<8);i=b;return}function g0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+256|0;if((c[126108]|0)==0){i=e;return}f=e|0;a[f]=0;if(f5[c[126104]&255](b)|0){g=b?33448:32720;b5(f|0,256,34176,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=0}else{g=b?31640:31208;b5(f|0,256,31952,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=1}if((a[f]|0)==0){i=e;return}do{if(j){g=c[140620]|0;b=(g|0)!=0?g:c[t>>2]|0;eS(b|0,30816,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[140620]|0;g=(b|0)!=0?b:c[t>>2]|0;a7(g|0)|0}else{if((a[405432]&1)==0){break}g=c[140620]|0;b=(g|0)!=0?g:c[t>>2]|0;eS(b|0,50096,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[140620]|0;g=(b|0)!=0?b:c[t>>2]|0;a7(g|0)|0}}while(0);if(!d){i=e;return}d=c[138489]|0;h=d+4|0;j=c[h>>2]|0;if(j>>>0>1){g=d|0;b=1;k=j;while(1){j=c[(c[g>>2]|0)+(b<<2)>>2]|0;if((j|0)==0){l=k}else{yt(c[j+8>>2]|0);yt(c[(c[g>>2]|0)+(b<<2)>>2]|0);c[(c[g>>2]|0)+(b<<2)>>2]=0;l=c[h>>2]|0}j=b+1|0;if(j>>>0<l>>>0){b=j;k=l}else{break}}}c[h>>2]=1;h=d+12|0;yt(c[h>>2]|0);c[h>>2]=0;h=c[138489]|0;d=h+4|0;if((c[d>>2]|0)>>>0>=(c[h+8>>2]|0)>>>0){i=e;return}l=ys(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}yB(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;k=dW(f|0)|0;f=c[d>>2]|0;c[l+8>>2]=k;k=h|0;c[(c[k>>2]|0)+(f<<2)>>2]=l;l=c[d>>2]|0;c[d>>2]=l+1;if(l>>>0>1){m=l}else{i=e;return}while(1){l=m>>>1;d=c[k>>2]|0;f=d+(l<<2)|0;h=c[f>>2]|0;b=c[d+(m<<2)>>2]|0;if((c[b+4>>2]|0)>>>0<=(c[h+4>>2]|0)>>>0){n=663;break}c[f>>2]=b;c[(c[k>>2]|0)+(m<<2)>>2]=h;if(m>>>0>3){m=l}else{n=666;break}}if((n|0)==663){i=e;return}else if((n|0)==666){i=e;return}}function g1(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+256|0;e=c[126108]|0;if((e|0)==0){i=d;return}f=d|0;a[f]=0;g=gp[e&31]()|0;e=g>>>0>b>>>0;do{if(f5[c[126107]&255](b)|0){if(e){h=b+1|0;b5(f|0,256,30408,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=0;break}else{b5(f|0,256,29480,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=0;break}}else{if(e){h=b+1|0;b5(f|0,256,29048,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=1;break}else{b5(f|0,256,28656,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=1;break}}}while(0);if((a[f]|0)==0){i=d;return}do{if(k){g=c[140620]|0;b=(g|0)!=0?g:c[t>>2]|0;eS(b|0,30816,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[140620]|0;g=(b|0)!=0?b:c[t>>2]|0;a7(g|0)|0}else{if((a[405432]&1)==0){break}g=c[140620]|0;b=(g|0)!=0?g:c[t>>2]|0;eS(b|0,50096,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[140620]|0;g=(b|0)!=0?b:c[t>>2]|0;a7(g|0)|0}}while(0);j=c[138489]|0;k=j+4|0;g=c[k>>2]|0;if(g>>>0>1){b=j|0;e=1;h=g;while(1){g=c[(c[b>>2]|0)+(e<<2)>>2]|0;if((g|0)==0){l=h}else{yt(c[g+8>>2]|0);yt(c[(c[b>>2]|0)+(e<<2)>>2]|0);c[(c[b>>2]|0)+(e<<2)>>2]=0;l=c[k>>2]|0}g=e+1|0;if(g>>>0<l>>>0){e=g;h=l}else{break}}}c[k>>2]=1;k=j+12|0;yt(c[k>>2]|0);c[k>>2]=0;k=c[138489]|0;j=k+4|0;if((c[j>>2]|0)>>>0>=(c[k+8>>2]|0)>>>0){i=d;return}l=ys(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}yB(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;h=dW(f|0)|0;f=c[j>>2]|0;c[l+8>>2]=h;h=k|0;c[(c[h>>2]|0)+(f<<2)>>2]=l;l=c[j>>2]|0;c[j>>2]=l+1;if(l>>>0>1){m=l}else{i=d;return}while(1){l=m>>>1;j=c[h>>2]|0;f=j+(l<<2)|0;k=c[f>>2]|0;e=c[j+(m<<2)>>2]|0;if((c[e+4>>2]|0)>>>0<=(c[k+4>>2]|0)>>>0){n=699;break}c[f>>2]=e;c[(c[h>>2]|0)+(m<<2)>>2]=k;if(m>>>0>3){m=l}else{n=700;break}}if((n|0)==699){i=d;return}else if((n|0)==700){i=d;return}}function g2(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;d=i;i=i+216|0;e=d|0;f=d+72|0;g=d+144|0;h=4096;j=442346;k=b;while(1){l=h-1|0;if((l|0)==0){m=704;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=4096;p=438250;q=b;break}else{h=l;j=j+1|0;k=k+1|0}}do{if((m|0)==704){a[j]=0;if((a[k]|0)==0){o=4096;p=438250;q=b;break}else{r=k}while(1){h=r+1|0;if((a[h]|0)==0){o=4096;p=438250;q=b;break}else{r=h}}}}while(0);while(1){r=o-1|0;if((r|0)==0){m=708;break}k=a[q]|0;a[p]=k;if(k<<24>>24==0){break}else{o=r;p=p+1|0;q=q+1|0}}do{if((m|0)==708){a[p]=0;if((a[q]|0)==0){break}else{s=q}do{s=s+1|0;}while((a[s]|0)!=0)}}while(0);s=cE(438250,46)|0;if((s|0)!=0){a[s]=0}if((a[425960]&1)==0){ho(446442,438250,53784)}if((a[425961]&1)==0){ho(466922,438250,53232)}do{if((fk(446442,g|0)|0)>=0){if((c[g+8>>2]&61440|0)!=16384){break}hp(446442,53784);if((a[405432]&1)==0){break}s=c[140620]|0;q=(s|0)!=0?s:c[t>>2]|0;eS(q|0,33224,(u=i,i=i+8|0,c[u>>2]=446442,u)|0)|0;i=u;q=c[140620]|0;s=(q|0)!=0?q:c[t>>2]|0;a7(s|0)|0}}while(0);do{if((fk(466922,f|0)|0)>=0){if((c[f+8>>2]&61440|0)!=16384){break}hp(466922,53232);if((a[405432]&1)==0){break}g=c[140620]|0;s=(g|0)!=0?g:c[t>>2]|0;eS(s|0,33136,(u=i,i=i+8|0,c[u>>2]=466922,u)|0)|0;i=u;s=c[140620]|0;g=(s|0)!=0?s:c[t>>2]|0;a7(g|0)|0}}while(0);if((a[397180]|0)==0){hv(397180,b)}if((a[425962]|0)==0){i=d;return}if((fk(425962,e|0)|0)<0){i=d;return}if((c[e+8>>2]&61440|0)!=16384){i=d;return}hp(425962,33024);if((a[405432]&1)!=0){e=c[140620]|0;b=(e|0)!=0?e:c[t>>2]|0;eS(b|0,32944,(u=i,i=i+8|0,c[u>>2]=425962,u)|0)|0;i=u;u=c[140620]|0;b=(u|0)!=0?u:c[t>>2]|0;a7(b|0)|0}b=dA(425962,12144)|0;if((b|0)!=0){a_(b|0)|0;i=d;return}a[425962]=0;if((a[405432]&1)==0){i=d;return}b=c[140620]|0;be(32880,59,1,((b|0)!=0?b:c[t>>2]|0)|0)|0;b=c[140620]|0;a7(((b|0)!=0?b:c[t>>2]|0)|0)|0;i=d;return}function g3(){var b=0,d=0,e=0;b=c[102392]|0;do{if((b|0)==2|(b|0)==3){if((a[425960]&1)==0){hn(446442,413672,53784)}hn(454634,446442,33664);if((a[425961]&1)!=0){break}hn(466922,413672,53232)}else if((b|0)==1){if((a[425960]&1)==0){hn(446442,409576,53784)}if((a[425961]&1)==0){hn(466922,409576,53232)}hn(450538,446442,24464)}else if((b|0)==4){if(!((a[425960]&1)==0|(a[417768]|0)==0|(a[421864]|0)==0)){d=c[140620]|0;e=(d|0)!=0?d:c[t>>2]|0;be(33520,109,1,e|0)|0;e=c[140620]|0;d=(e|0)!=0?e:c[t>>2]|0;a7(d|0)|0}hn(458730,417768,53784);hn(462826,421864,53784);if((a[425961]&1)!=0){break}hn(466922,(a[417768]|0)!=0?417768:421864,53232)}else{hn(450538,446442,24464)}}while(0);hn(553984,446442,564064);if((a[438250]|0)==0){return}if((a[487406]|0)==0){ho(487406,438250,33496)}if((a[491502]|0)==0){ho(491502,438250,33456)}if((a[495598]|0)==0){ho(495598,438250,33440)}if((a[471018]|0)==0){ho(471018,438250,33432)}if((a[393084]|0)!=0){return}hv(393084,438250);return}function g4(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,ag=0,ah=0,ai=0,aj=0,ak=0,am=0,an=0,ao=0,ar=0,at=0,au=0,av=0,aw=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aH=0,aI=0,aK=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0.0,dV=0.0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0;f=i;i=i+13008|0;j=1;k=0;l=i;i=i+168|0;c[l>>2]=0;while(1)switch(j|0){case 1:m=f|0;n=f+8|0;o=f+16|0;p=f+24|0;q=f+32|0;r=f+40|0;s=f+48|0;u=f+56|0;v=f+64|0;w=f+72|0;z=f+144|0;A=f+216|0;B=f+4312|0;C=f+8408|0;D=f+12504|0;E=f+12512|0;a[405434]=1;a[405433]=1;c[102392]=0;c[101359]=1;c[101360]=1;c[101361]=1;c[101362]=1;c[101363]=1;c[101364]=1;c[101365]=1;c[101366]=1;F=yC(563512,j,l)|0;j=510;break;case 510:if((F|0)>0){j=2;break}else{j=3;break};case 2:G=c[140620]|0;ax(86,((G|0)!=0?G:c[t>>2]|0)|0,26672,(H=i,i=i+8|0,c[H>>2]=562487,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;I=F;j=509;break;case 3:a[562485]=1;a[563556]=0;a[563557]=0;a[425960]=0;a[425961]=0;if((d|0)<2){j=4;break}else{j=5;break};case 4:a[563557]=1;j=182;break;case 5:c[1516]=0;c[D>>2]=0;c[E>>2]=50608;c[E+4>>2]=0;c[E+8>>2]=D;c[E+12>>2]=77;c[E+16>>2]=50496;c[E+20>>2]=0;c[E+24>>2]=0;c[E+28>>2]=104;c[E+32>>2]=50248;c[E+36>>2]=1;c[E+40>>2]=0;c[E+44>>2]=115;c[E+48>>2]=5e4;c[E+52>>2]=0;c[E+56>>2]=0;c[E+60>>2]=102;c[E+64>>2]=49808;c[E+68>>2]=0;c[E+72>>2]=0;c[E+76>>2]=118;c[E+80>>2]=49632;c[E+84>>2]=1;c[E+88>>2]=0;c[E+92>>2]=103;c[E+96>>2]=49536;c[E+100>>2]=1;c[E+104>>2]=0;c[E+108>>2]=99;c[E+112>>2]=49144;c[E+116>>2]=1;c[E+120>>2]=D;c[E+124>>2]=67;c[E+128>>2]=48736;c[E+132>>2]=1;c[E+136>>2]=0;c[E+140>>2]=109;c[E+144>>2]=48616;c[E+148>>2]=1;c[E+152>>2]=0;c[E+156>>2]=78;c[E+160>>2]=48472;c[E+164>>2]=0;c[E+168>>2]=0;c[E+172>>2]=112;c[E+176>>2]=48360;c[E+180>>2]=0;c[E+184>>2]=0;c[E+188>>2]=106;c[E+192>>2]=48224;c[E+196>>2]=0;c[E+200>>2]=0;c[E+204>>2]=74;c[E+208>>2]=48104;c[E+212>>2]=1;c[E+216>>2]=0;c[E+220>>2]=65;c[E+224>>2]=47976;c[E+228>>2]=1;c[E+232>>2]=0;c[E+236>>2]=83;c[E+240>>2]=47912;c[E+244>>2]=1;c[E+248>>2]=0;c[E+252>>2]=98;c[E+256>>2]=47856;c[E+260>>2]=1;c[E+264>>2]=0;c[E+268>>2]=66;c[E+272>>2]=47504;c[E+276>>2]=0;c[E+280>>2]=0;c[E+284>>2]=52;c[E+288>>2]=47384;c[E+292>>2]=1;c[E+296>>2]=0;c[E+300>>2]=89;c[E+304>>2]=47312;c[E+308>>2]=1;c[E+312>>2]=0;c[E+316>>2]=90;c[E+320>>2]=47240;c[E+324>>2]=1;c[E+328>>2]=0;c[E+332>>2]=80;c[E+336>>2]=47168;c[E+340>>2]=1;c[E+344>>2]=0;c[E+348>>2]=82;c[E+352>>2]=47064;c[E+356>>2]=1;c[E+360>>2]=0;c[E+364>>2]=77;c[E+368>>2]=46984;c[E+372>>2]=1;c[E+376>>2]=0;c[E+380>>2]=85;c[E+384>>2]=46920;c[E+388>>2]=1;c[E+392>>2]=D;c[E+396>>2]=66;c[E+400>>2]=46848;c[E+404>>2]=1;c[E+408>>2]=D;c[E+412>>2]=73;c[E+416>>2]=46768;c[E+420>>2]=0;c[E+424>>2]=D;c[E+428>>2]=110;c[E+432>>2]=46432;c[E+436>>2]=1;c[E+440>>2]=0;c[E+444>>2]=88;c[E+448>>2]=46280;c[E+452>>2]=0;c[E+456>>2]=0;c[E+460>>2]=68;c[E+464>>2]=46144;c[E+468>>2]=0;c[E+472>>2]=D;c[E+476>>2]=102;yB(E+480|0,0,16);J=e+(d<<2)|0;K=0;j=6;break;case 6:c[D>>2]=0;if((K|0)==0){j=7;break}else{L=K;j=8;break};case 7:c[1516]=1;L=1;j=8;break;case 8:if((d|0)==1){M=L;j=162;break}else{j=9;break};case 9:N=e+(L<<2)|0;O=c[N>>2]|0;if((O|0)==0){P=-1;Q=-1;j=17;break}else{R=0;S=O;j=10;break};case 10:if((a[S]|0)==45){j=11;break}else{j=12;break};case 11:if((a[S+1|0]|0)==45){j=12;break}else{T=R;j=13;break};case 12:G=R+1|0;W=c[e+(G+L<<2)>>2]|0;if((W|0)==0){T=-1;j=13;break}else{R=G;S=W;j=10;break};case 13:X=0;Y=O;j=14;break;case 14:if((a[Y]|0)==45){j=15;break}else{j=16;break};case 15:if((a[Y+1|0]|0)==45){P=X;Q=T;j=17;break}else{j=16;break};case 16:W=X+1|0;G=c[e+(W+L<<2)>>2]|0;if((G|0)==0){P=-1;Q=T;j=17;break}else{X=W;Y=G;j=14;break};case 17:Z=(Q|0)==-1;_=(P|0)==-1;if(Z&_){M=L;j=162;break}else{j=18;break};case 18:if((Q|0)>0){j=19;break}else{j=21;break};case 19:if((Q|0)<(P|0)|_){j=20;break}else{j=21;break};case 20:aO(16,N|0,e+(Q+L<<2)|0,J|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=28;break;case 21:if((P|0)>0){j=22;break}else{j=25;break};case 22:if((P|0)<(Q|0)|Z){j=23;break}else{j=25;break};case 23:aO(16,N|0,e+(P+L<<2)|0,J|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((Q|0)==0){j=28;break}else{j=24;break};case 24:$=c[1516]|0;j=40;break;case 25:aa=(Q|0)==0;ab=(P|0)==0;if(aa|ab){j=27;break}else{j=26;break};case 26:G=c[140620]|0;ax(86,((G|0)!=0?G:c[t>>2]|0)|0,35072,(H=i,i=i+16|0,c[H>>2]=52256,c[H+8>>2]=190,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(140,2);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 27:if(aa){j=28;break}else{j=39;break};case 28:ac=c[1516]|0;ad=c[e+(ac<<2)>>2]|0;ae=ad+1|0;ag=a[ae]|0;if(ag<<24>>24==58){j=160;break}else{j=29;break};case 29:ah=ax(10,46e3,ag<<24>>24|0,41)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((ah|0)==0){j=160;break}else{j=30;break};case 30:ai=ad+2|0;G=(a[ah+1|0]|0)==58;aj=G&(a[ai]|0)!=0;if(G){j=31;break}else{j=36;break};case 31:if(aj){j=32;break}else{j=33;break};case 32:c[21538]=ai;ak=ac+1|0;am=ai;j=34;break;case 33:G=c[e+(ac+1<<2)>>2]|0;c[21538]=G;ak=ac+2|0;am=G;j=34;break;case 34:c[1516]=ak;if((am|0)==0){j=160;break}else{j=35;break};case 35:an=a[ah]|0;ao=ak;j=49;break;case 36:if(aj){j=37;break}else{j=38;break};case 37:G=as(130,ai|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aO(42,ae|0,ai|0,G+1|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;an=a[ah]|0;ao=ac;j=49;break;case 38:G=ac+1|0;c[1516]=G;an=a[ah]|0;ao=G;j=49;break;case 39:if(ab){$=L;j=40;break}else{j=160;break};case 40:ar=0;j=41;break;case 41:at=c[E+(ar<<4)>>2]|0;if((at|0)==0){j=160;break}else{j=42;break};case 42:G=aJ(80,at|0,(c[e+($<<2)>>2]|0)+2|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=44;break}else{j=43;break};case 43:ar=ar+1|0;j=41;break;case 44:au=$+1|0;if((c[E+(ar<<4)+4>>2]|0)==0){av=au;j=47;break}else{j=45;break};case 45:aw=c[e+(au<<2)>>2]|0;if((aw|0)==0){j=160;break}else{j=46;break};case 46:c[21538]=aw;av=$+2|0;j=47;break;case 47:c[1516]=av;ay=c[E+(ar<<4)+8>>2]|0;az=c[E+(ar<<4)+12>>2]|0;if((ay|0)==0){an=az;ao=av;j=49;break}else{j=48;break};case 48:c[ay>>2]=az;j=139;break;case 49:switch(an|0){case 68:{j=50;break};case 104:{j=51;break};case 52:{j=52;break};case 106:{j=53;break};case 74:{j=54;break};case 65:{j=55;break};case 115:{j=58;break};case 102:{j=64;break};case 103:{j=65;break};case 98:{j=71;break};case 66:{j=77;break};case 89:{j=83;break};case 90:{j=89;break};case 83:{j=95;break};case 118:{j=101;break};case 109:{j=102;break};case 78:{j=105;break};case 112:{j=108;break};case 99:{j=109;break};case 80:case 82:{j=114;break};case 77:{j=120;break};case 85:{j=128;break};case 88:{j=134;break};case 0:{j=139;break};case 63:{j=160;break};case-1:{M=ao;j=162;break};default:{j=161;break}}break;case 50:K=c[1516]|0;j=6;break;case 51:aP(6);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(140,0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 52:c[101360]=257;j=50;break;case 53:c[101360]=516;j=50;break;case 54:c[101360]=772;j=50;break;case 55:G=ax(104,c[21538]|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aA=G-1|0;if(aA>>>0>7){j=56;break}else{j=57;break};case 56:G=c[140620]|0;aN(6,45872,57,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(6);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(258,45744);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 57:c[405436+(aA<<2)>>2]=5;j=50;break;case 58:aB=4096;aC=446442;aD=c[21538]|0;j=59;break;case 59:aE=aB-1|0;if((aE|0)==0){j=61;break}else{j=60;break};case 60:G=a[aD]|0;a[aC]=G;if(G<<24>>24==0){j=63;break}else{aB=aE;aC=aC+1|0;aD=aD+1|0;j=59;break};case 61:a[aC]=0;if((a[aD]|0)==0){j=63;break}else{aF=aD;j=62;break};case 62:G=aF+1|0;if((a[G]|0)==0){j=63;break}else{aF=G;j=62;break};case 63:a[425960]=1;j=50;break;case 64:a[405435]=1;j=50;break;case 65:aH=4096;aI=409576;aK=c[21538]|0;j=66;break;case 66:aQ=aH-1|0;if((aQ|0)==0){j=68;break}else{j=67;break};case 67:G=a[aK]|0;a[aI]=G;if(G<<24>>24==0){j=70;break}else{aH=aQ;aI=aI+1|0;aK=aK+1|0;j=66;break};case 68:a[aI]=0;if((a[aK]|0)==0){j=70;break}else{aR=aK;j=69;break};case 69:G=aR+1|0;if((a[G]|0)==0){j=70;break}else{aR=G;j=69;break};case 70:c[102392]=1;j=50;break;case 71:aS=4096;aT=413672;aU=c[21538]|0;j=72;break;case 72:aV=aS-1|0;if((aV|0)==0){j=74;break}else{j=73;break};case 73:G=a[aU]|0;a[aT]=G;if(G<<24>>24==0){j=76;break}else{aS=aV;aT=aT+1|0;aU=aU+1|0;j=72;break};case 74:a[aT]=0;if((a[aU]|0)==0){j=76;break}else{aW=aU;j=75;break};case 75:G=aW+1|0;if((a[G]|0)==0){j=76;break}else{aW=G;j=75;break};case 76:c[102392]=2;j=50;break;case 77:aX=4096;aY=413672;aZ=c[21538]|0;j=78;break;case 78:a_=aX-1|0;if((a_|0)==0){j=80;break}else{j=79;break};case 79:G=a[aZ]|0;a[aY]=G;if(G<<24>>24==0){j=82;break}else{aX=a_;aY=aY+1|0;aZ=aZ+1|0;j=78;break};case 80:a[aY]=0;if((a[aZ]|0)==0){j=82;break}else{a$=aZ;j=81;break};case 81:G=a$+1|0;if((a[G]|0)==0){j=82;break}else{a$=G;j=81;break};case 82:c[102392]=3;j=50;break;case 83:a0=4096;a1=417768;a2=c[21538]|0;j=84;break;case 84:a3=a0-1|0;if((a3|0)==0){j=86;break}else{j=85;break};case 85:G=a[a2]|0;a[a1]=G;if(G<<24>>24==0){j=88;break}else{a0=a3;a1=a1+1|0;a2=a2+1|0;j=84;break};case 86:a[a1]=0;if((a[a2]|0)==0){j=88;break}else{a4=a2;j=87;break};case 87:G=a4+1|0;if((a[G]|0)==0){j=88;break}else{a4=G;j=87;break};case 88:c[102392]=4;j=50;break;case 89:a5=4096;a6=421864;a7=c[21538]|0;j=90;break;case 90:a8=a5-1|0;if((a8|0)==0){j=92;break}else{j=91;break};case 91:G=a[a7]|0;a[a6]=G;if(G<<24>>24==0){j=94;break}else{a5=a8;a6=a6+1|0;a7=a7+1|0;j=90;break};case 92:a[a6]=0;if((a[a7]|0)==0){j=94;break}else{a9=a7;j=93;break};case 93:G=a9+1|0;if((a[G]|0)==0){j=94;break}else{a9=G;j=93;break};case 94:c[102392]=4;j=50;break;case 95:ba=4096;bb=466922;bc=c[21538]|0;j=96;break;case 96:bd=ba-1|0;if((bd|0)==0){j=98;break}else{j=97;break};case 97:G=a[bc]|0;a[bb]=G;if(G<<24>>24==0){j=100;break}else{ba=bd;bb=bb+1|0;bc=bc+1|0;j=96;break};case 98:a[bb]=0;if((a[bc]|0)==0){j=100;break}else{be=bc;j=99;break};case 99:G=be+1|0;if((a[G]|0)==0){j=100;break}else{be=G;j=99;break};case 100:a[425961]=1;j=50;break;case 101:a[405432]=1;j=50;break;case 102:G=ax(104,c[21538]|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;bf=G-1|0;if(bf>>>0>7){j=103;break}else{j=104;break};case 103:G=c[140620]|0;aN(6,45624,52,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(6);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(258,45744);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 104:c[405436+(bf<<2)>>2]=2;j=50;break;case 105:G=ax(104,c[21538]|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;bg=G-1|0;if(bg>>>0>7){j=106;break}else{j=107;break};case 106:G=c[140620]|0;aN(6,45456,58,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(6);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(258,45744);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 107:c[405436+(bg<<2)>>2]=0;j=50;break;case 108:c[101360]=260;j=50;break;case 109:bh=4096;bi=425962;bj=c[21538]|0;j=110;break;case 110:bk=bh-1|0;if((bk|0)==0){j=112;break}else{j=111;break};case 111:G=a[bj]|0;a[bi]=G;if(G<<24>>24==0){j=50;break}else{bh=bk;bi=bi+1|0;bj=bj+1|0;j=110;break};case 112:a[bi]=0;if((a[bj]|0)==0){j=50;break}else{bl=bj;j=113;break};case 113:G=bl+1|0;if((a[G]|0)==0){j=50;break}else{bl=G;j=113;break};case 114:bm=4096;bn=558081;bo=c[21538]|0;j=115;break;case 115:bp=bm-1|0;if((bp|0)==0){j=117;break}else{j=116;break};case 116:G=a[bo]|0;a[bn]=G;if(G<<24>>24==0){j=119;break}else{bm=bp;bn=bn+1|0;bo=bo+1|0;j=115;break};case 117:a[bn]=0;if((a[bo]|0)==0){j=119;break}else{bq=bo;j=118;break};case 118:G=bq+1|0;if((a[G]|0)==0){j=119;break}else{bq=G;j=118;break};case 119:a[562178]=(an|0)==80|0;a[562177]=(an|0)==82|0;j=50;break;case 120:br=c[21538]|0;G=aJ(80,br|0,45384)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=121;break}else{j=122;break};case 121:a[562180]=1;a[562181]=1;j=50;break;case 122:G=aJ(80,br|0,45328)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=123;break}else{j=124;break};case 123:a[562180]=1;j=50;break;case 124:G=aJ(80,br|0,45e3)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=125;break}else{j=126;break};case 125:a[562181]=1;j=50;break;case 126:G=aJ(80,br|0,44864)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=50;break}else{j=127;break};case 127:G=c[140620]|0;aN(6,44552,54,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(6);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(258,45744);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 128:bs=4096;bt=487406;bu=c[21538]|0;j=129;break;case 129:bv=bs-1|0;if((bv|0)==0){j=131;break}else{j=130;break};case 130:G=a[bu]|0;a[bt]=G;if(G<<24>>24==0){j=133;break}else{bs=bv;bt=bt+1|0;bu=bu+1|0;j=129;break};case 131:a[bt]=0;if((a[bu]|0)==0){j=133;break}else{bw=bu;j=132;break};case 132:G=bw+1|0;if((a[G]|0)==0){j=133;break}else{bw=G;j=132;break};case 133:a[487403]=1;j=50;break;case 134:bx=4096;by=471018;bz=c[21538]|0;j=135;break;case 135:bA=bx-1|0;if((bA|0)==0){j=137;break}else{j=136;break};case 136:G=a[bz]|0;a[by]=G;if(G<<24>>24==0){j=50;break}else{bx=bA;by=by+1|0;bz=bz+1|0;j=135;break};case 137:a[by]=0;if((a[bz]|0)==0){j=50;break}else{bB=bz;j=138;break};case 138:G=bB+1|0;if((a[G]|0)==0){j=50;break}else{bB=G;j=138;break};case 139:switch(c[D>>2]|0){case 77:{j=140;break};case 67:{j=141;break};case 66:{j=146;break};case 73:{j=152;break};case 110:{j=158;break};case 102:{j=159;break};default:{j=50;break}}break;case 140:a[563557]=1;j=50;break;case 141:bC=4096;bD=430058;bE=c[21538]|0;j=142;break;case 142:bF=bC-1|0;if((bF|0)==0){j=144;break}else{j=143;break};case 143:G=a[bE]|0;a[bD]=G;if(G<<24>>24==0){j=50;break}else{bC=bF;bD=bD+1|0;bE=bE+1|0;j=142;break};case 144:a[bD]=0;if((a[bE]|0)==0){j=50;break}else{bG=bE;j=145;break};case 145:G=bG+1|0;if((a[G]|0)==0){j=50;break}else{bG=G;j=145;break};case 146:bH=4096;bI=491502;bJ=c[21538]|0;j=147;break;case 147:bK=bH-1|0;if((bK|0)==0){j=149;break}else{j=148;break};case 148:G=a[bJ]|0;a[bI]=G;if(G<<24>>24==0){j=151;break}else{bH=bK;bI=bI+1|0;bJ=bJ+1|0;j=147;break};case 149:a[bI]=0;if((a[bJ]|0)==0){j=151;break}else{bL=bJ;j=150;break};case 150:G=bL+1|0;if((a[G]|0)==0){j=151;break}else{bL=G;j=150;break};case 151:a[487404]=1;j=50;break;case 152:bM=4096;bN=495598;bO=c[21538]|0;j=153;break;case 153:bP=bM-1|0;if((bP|0)==0){j=155;break}else{j=154;break};case 154:G=a[bO]|0;a[bN]=G;if(G<<24>>24==0){j=157;break}else{bM=bP;bN=bN+1|0;bO=bO+1|0;j=153;break};case 155:a[bN]=0;if((a[bO]|0)==0){j=157;break}else{bQ=bO;j=156;break};case 156:G=bQ+1|0;if((a[G]|0)==0){j=157;break}else{bQ=G;j=156;break};case 157:a[487405]=1;j=50;break;case 158:a[487402]=1;j=50;break;case 159:as(76,10)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;as(224,44144)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=43976,c[H+8>>2]=43904,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=43528,c[H+8>>2]=43432,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=43312,c[H+8>>2]=43136,c[H+16>>2]=24664,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=42992,c[H+8>>2]=42904,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=42880,c[H+8>>2]=42808,c[H+16>>2]=24664,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=42744,c[H+8>>2]=42688,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=42392,c[H+8>>2]=42256,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=42136,c[H+8>>2]=42032,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=41992,c[H+8>>2]=42032,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=41944,c[H+8>>2]=42032,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=41904,c[H+8>>2]=42032,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=41840,c[H+8>>2]=42032,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=41776,c[H+8>>2]=42032,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=41736,c[H+8>>2]=42032,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=41328,c[H+8>>2]=42032,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=41248,c[H+8>>2]=41112,c[H+16>>2]=24664,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=40984,c[H+8>>2]=42032,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=40888,c[H+8>>2]=40792,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=40752,c[H+8>>2]=40680,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=40608,c[H+8>>2]=40552,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=40296,c[H+8>>2]=40192,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=40032,c[H+8>>2]=39936,c[H+16>>2]=24664,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=39912,c[H+8>>2]=39864,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=39832,c[H+8>>2]=39760,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=39704,c[H+8>>2]=39648,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=39280,c[H+8>>2]=39192,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(12,44072,(H=i,i=i+24|0,c[H>>2]=39048,c[H+8>>2]=38952,c[H+16>>2]=24416,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;ap(140,0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 160:aP(6);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(258,45744);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 161:G=c[140620]|0;aN(6,44424,46,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(258,45744);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 162:bR=(M|0)<(d|0);if((a[563557]&1)==0){j=165;break}else{j=163;break};case 163:if(bR){j=164;break}else{j=168;break};case 164:G=c[140620]|0;aN(6,44304,71,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(258,45744);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 165:if(bR){j=166;break}else{j=167;break};case 166:ap(68,c[e+(M<<2)>>2]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=168;break;case 167:a[563556]=1;j=168;break;case 168:if((a[425960]&1)==0){j=175;break}else{j=169;break};case 169:G=aJ(10,446442,z|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)<0){j=175;break}else{j=170;break};case 170:if((c[z+8>>2]&61440|0)==16384){bS=4096;bT=475114;bU=446442;j=171;break}else{j=175;break};case 171:bV=bS-1|0;if((bV|0)==0){j=173;break}else{j=172;break};case 172:G=a[bU]|0;a[bT]=G;if(G<<24>>24==0){j=175;break}else{bS=bV;bT=bT+1|0;bU=bU+1|0;j=171;break};case 173:a[bT]=0;if((a[bU]|0)==0){j=175;break}else{bW=bU;j=174;break};case 174:G=bW+1|0;if((a[G]|0)==0){j=175;break}else{bW=G;j=174;break};case 175:if((a[425961]&1)==0){j=182;break}else{j=176;break};case 176:G=aJ(10,466922,w|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)<0){j=182;break}else{j=177;break};case 177:if((c[w+8>>2]&61440|0)==16384){bX=4096;bY=479210;bZ=466922;j=178;break}else{j=182;break};case 178:b_=bX-1|0;if((b_|0)==0){j=180;break}else{j=179;break};case 179:G=a[bZ]|0;a[bY]=G;if(G<<24>>24==0){j=182;break}else{bX=b_;bY=bY+1|0;bZ=bZ+1|0;j=178;break};case 180:a[bY]=0;if((a[bZ]|0)==0){j=182;break}else{b$=bZ;j=181;break};case 181:G=b$+1|0;if((a[G]|0)==0){j=182;break}else{b$=G;j=181;break};case 182:if((a[405432]&1)==0){j=185;break}else{j=183;break};case 183:G=c[140620]|0;aN(6,26256,49,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[t>>2]|0;aN(6,52512,11,1,G|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ax(86,G|0,52208,(H=i,i=i+16|0,c[H>>2]=51544,c[H+8>>2]=32,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;ax(86,G|0,51232,(H=i,i=i+8|0,c[H>>2]=50944,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;if((a[405432]&1)==0){j=185;break}else{j=184;break};case 184:G=c[140620]|0;aN(6,25872,50,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=185;break;case 185:if((a[562388]&1)==0){j=186;break}else{j=233;break};case 186:a[303024]=103;a[303025]=108;a[303026]=0;a[319572]=114;a[319573]=119;a[319574]=101;a[319575]=98;a[319576]=97;a[319577]=117;a[319578]=100;a[319579]=105;a[319580]=111;a[319581]=0;a[327864]=114;a[327865]=119;a[327866]=101;a[327867]=98;a[327868]=105;a[327869]=110;a[327870]=112;a[327871]=117;a[327872]=116;a[327873]=0;g[75772]=3.0;g[75773]=3.0;a[303096]=a[405435]&1;a[303097]=1;c[75775]=0;c[75776]=0;c[75777]=0;a[319564]=0;a[303112]=1;a[303113]=0;c[75780]=0;a[303114]=0;c[75779]=1;a[311340]=0;a[303124]=1;a[303125]=1;a[303133]=0;a[303126]=1;g[75782]=-1.0;a[303132]=0;c[75784]=4;a[307236]=0;a[319568]=1;a[319540]=1;g[79884]=48.0;a[319541]=1;g[79886]=.05000000074505806;g[79887]=.05000000074505806;g[79888]=1.0;g[79889]=1.0;g[79890]=0.0;g[77834]=59.95000076293945;a[319565]=0;a[319566]=0;a[319567]=1;a[319604]=1;c[79902]=48e3;c[79903]=0;g[79904]=48.0e3;c[80929]=64;a[323720]=1;a[327817]=1;g[81955]=.004999999888241291;g[81956]=0.0;a[401276]=0;c[100320]=20971520;c[100321]=1;g[100322]=3.0;g[100323]=-1.0;a[401296]=0;yB(401300,0,7);a[401307]=1;a[401308]=0;b[200655]=-10181;a[401312]=0;c[95198]=100;yE(327928,2848,2240)|0;yE(330168,1848,1e3)|0;yE(332408,1848,1e3)|0;yE(334648,1848,1e3)|0;yE(336888,1848,1e3)|0;yE(339128,1848,1e3)|0;yE(341368,1848,1e3)|0;yE(343608,1848,1e3)|0;b0=0;j=187;break;case 187:G=345864+(b0*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[345880+(b0*40|0)>>2]=-1;G=b0+1|0;if(G>>>0<56){b0=G;j=187;break}else{b1=0;j=213;break};case 188:if((a[327928+(b2*40|0)|0]&1)==0){j=191;break}else{j=189;break};case 189:if((b2|0)==(c[327932+(b2*40|0)>>2]|0)){j=191;break}else{j=190;break};case 190:G=c[140620]|0;ax(86,((G|0)!=0?G:c[t>>2]|0)|0,35072,(H=i,i=i+16|0,c[H>>2]=24216,c[H+8>>2]=251,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(140,2);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 191:G=b2+1|0;if((G|0)<56){b2=G;j=188;break}else{b3=0;j=192;break};case 192:if((a[330168+(b3*40|0)|0]&1)==0){j=194;break}else{j=193;break};case 193:if((b3|0)==(c[330172+(b3*40|0)>>2]|0)){j=194;break}else{j=190;break};case 194:G=b3+1|0;if((G|0)<56){b3=G;j=192;break}else{b4=0;j=195;break};case 195:if((a[332408+(b4*40|0)|0]&1)==0){j=197;break}else{j=196;break};case 196:if((b4|0)==(c[332412+(b4*40|0)>>2]|0)){j=197;break}else{j=190;break};case 197:G=b4+1|0;if((G|0)<56){b4=G;j=195;break}else{b5=0;j=198;break};case 198:if((a[334648+(b5*40|0)|0]&1)==0){j=200;break}else{j=199;break};case 199:if((b5|0)==(c[334652+(b5*40|0)>>2]|0)){j=200;break}else{j=190;break};case 200:G=b5+1|0;if((G|0)<56){b5=G;j=198;break}else{b6=0;j=201;break};case 201:if((a[336888+(b6*40|0)|0]&1)==0){j=203;break}else{j=202;break};case 202:if((b6|0)==(c[336892+(b6*40|0)>>2]|0)){j=203;break}else{j=190;break};case 203:G=b6+1|0;if((G|0)<56){b6=G;j=201;break}else{b7=0;j=204;break};case 204:if((a[339128+(b7*40|0)|0]&1)==0){j=206;break}else{j=205;break};case 205:if((b7|0)==(c[339132+(b7*40|0)>>2]|0)){j=206;break}else{j=190;break};case 206:G=b7+1|0;if((G|0)<56){b7=G;j=204;break}else{b8=0;j=207;break};case 207:if((a[341368+(b8*40|0)|0]&1)==0){j=209;break}else{j=208;break};case 208:if((b8|0)==(c[341372+(b8*40|0)>>2]|0)){j=209;break}else{j=190;break};case 209:G=b8+1|0;if((G|0)<56){b8=G;j=207;break}else{b9=0;j=210;break};case 210:if((a[343608+(b9*40|0)|0]&1)==0){j=212;break}else{j=211;break};case 211:if((b9|0)==(c[343612+(b9*40|0)>>2]|0)){j=212;break}else{j=190;break};case 212:G=b9+1|0;if((G|0)<56){b9=G;j=210;break}else{j=220;break};case 213:G=348104+(b1*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[348120+(b1*40|0)>>2]=-1;G=b1+1|0;if(G>>>0<56){b1=G;j=213;break}else{ca=0;j=214;break};case 214:G=350344+(ca*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[350360+(ca*40|0)>>2]=-1;G=ca+1|0;if(G>>>0<56){ca=G;j=214;break}else{cb=0;j=215;break};case 215:G=352584+(cb*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[352600+(cb*40|0)>>2]=-1;G=cb+1|0;if(G>>>0<56){cb=G;j=215;break}else{cc=0;j=216;break};case 216:G=354824+(cc*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[354840+(cc*40|0)>>2]=-1;G=cc+1|0;if(G>>>0<56){cc=G;j=216;break}else{cd=0;j=217;break};case 217:G=357064+(cd*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[357080+(cd*40|0)>>2]=-1;G=cd+1|0;if(G>>>0<56){cd=G;j=217;break}else{ce=0;j=218;break};case 218:G=359304+(ce*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[359320+(ce*40|0)>>2]=-1;G=ce+1|0;if(G>>>0<56){ce=G;j=218;break}else{cf=0;j=219;break};case 219:G=361544+(cf*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[361560+(cf*40|0)>>2]=-1;G=cf+1|0;if(G>>>0<56){cf=G;j=219;break}else{b2=0;j=188;break};case 220:g[90944]=.5;a[364390]=1;c[91098]=6;c[91099]=3;g[92124]=1.0;g[92125]=1.0;a[364388]=0;a[364389]=1;c[90945]=0;c[90946]=1;c[90947]=2;c[90948]=3;c[90949]=4;c[90950]=5;c[90951]=6;c[90952]=7;a[562486]=0;yB(562420,0,16);a[562388]=1;aP(44);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cg=(a[405432]&1)!=0;if((a[425962]|0)==0){j=224;break}else{j=221;break};case 221:if(cg){j=222;break}else{j=223;break};case 222:G=c[140620]|0;ax(86,((G|0)!=0?G:c[t>>2]|0)|0,45944,(H=i,i=i+8|0,c[H>>2]=425962,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=223;break;case 223:G=as(166,425962)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(G){j=233;break}else{j=230;break};case 224:if(cg){j=225;break}else{j=226;break};case 225:G=c[140620]|0;aN(6,45816,35,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=226;break;case 226:ch=as(166,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[425962]|0)==0){j=229;break}else{j=227;break};case 227:if((a[405432]&1)==0){j=229;break}else{j=228;break};case 228:G=c[140620]|0;ax(86,((G|0)!=0?G:c[t>>2]|0)|0,45688,(H=i,i=i+8|0,c[H>>2]=425962,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(ch){j=233;break}else{j=230;break};case 229:if(ch){j=233;break}else{j=230;break};case 230:G=c[140620]|0;ax(86,((G|0)!=0?G:c[t>>2]|0)|0,45528,(H=i,i=i+8|0,c[H>>2]=425962,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[562485]&1)==0){j=231;break}else{j=232;break};case 231:G=c[140620]|0;ax(86,((G|0)!=0?G:c[t>>2]|0)|0,35072,(H=i,i=i+16|0,c[H>>2]=45352,c[H+8>>2]=832,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[140620]|0;as(112,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(140,2);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 232:a[562487]=112;a[562488]=97;a[562489]=114;a[562490]=115;a[562491]=101;a[562492]=95;a[562493]=99;a[562494]=111;a[562495]=110;a[562496]=102;a[562497]=105;a[562498]=103;a[562499]=95;a[562500]=102;a[562501]=105;a[562502]=108;a[562503]=101;a[562504]=40;a[562505]=41;a[562506]=0;aq(412,563512,1);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 233:G=(a[563557]&1)!=0;W=G?66:414;c[21518]=G?16:40;c[21530]=G?10:14;c[21536]=G?22:12;c[21520]=G?452:512;c[21522]=G?52:260;c[21498]=W;c[21492]=G?314:348;c[21504]=G?226:186;c[21502]=G?118:190;c[21496]=G?60:200;c[21494]=G?506:142;c[21500]=G?14:68;c[21512]=G?2:34;c[21510]=G?50:58;c[21506]=G?6:8;c[21508]=G?14:22;c[21488]=G?44:58;c[21534]=G?28:18;c[21532]=G?56:74;c[21516]=G?78:62;c[21514]=G?66:2;c[21490]=G?26:20;c[21524]=G?30:10;c[21528]=G?38:2;c[21526]=G?98:170;ap(W|0,70);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[21520]|0,499720);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[124930]|0;if((W|0)==0){j=234;break}else{ci=W;j=235;break};case 234:c[124930]=20544;ci=20544;j=235;break;case 235:W=c[124931]|0;if((W|0)==0){j=236;break}else{cj=W;j=237;break};case 236:c[124931]=27912;cj=27912;j=237;break;case 237:aN(12,562244,64,27448,(H=i,i=i+16|0,c[H>>2]=ci,c[H+8>>2]=cj,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[124932]|0;ck=4096;cl=500312;cm=(W|0)==0?27128:W;j=238;break;case 238:cn=ck-1|0;if((cn|0)==0){j=240;break}else{j=239;break};case 239:W=a[cm]|0;a[cl]=W;if(W<<24>>24==0){j=242;break}else{ck=cn;cl=cl+1|0;cm=cm+1|0;j=238;break};case 240:a[cl]=0;if((a[cm]|0)==0){j=242;break}else{co=cm;j=241;break};case 241:W=co+1|0;if((a[W]|0)==0){j=242;break}else{co=W;j=241;break};case 242:a[499796]=a[499733]&1;cp=0;j=243;break;case 243:if(cp>>>0<2){j=244;break}else{j=245;break};case 244:cq=c[10296+(cp<<2)>>2]|0;W=aJ(86,319572,c[cq+28>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=252;break}else{cp=cp+1|0;j=243;break};case 245:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,27192,(H=i,i=i+8|0,c[H>>2]=319572,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=a[405432]|0;if((W&1)==0){cr=W;j=247;break}else{j=246;break};case 246:W=c[140620]|0;aN(6,26840,29,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cr=a[405432]|0;j=247;break;case 247:if((cr&1)==0){cs=cr;j=249;break}else{j=248;break};case 248:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,29232,(H=i,i=i+8|0,c[H>>2]=50928,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cs=a[405432]|0;j=249;break;case 249:if((cs&1)==0){j=251;break}else{j=250;break};case 250:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,29232,(H=i,i=i+8|0,c[H>>2]=46240,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=251;break;case 251:ap(84,26488);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 252:c[140912]=cq;W=aJ(86,303024,37176)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=258;break}else{j=253;break};case 253:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,28376,(H=i,i=i+8|0,c[H>>2]=303024,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=a[405432]|0;if((W&1)==0){ct=W;j=255;break}else{j=254;break};case 254:W=c[140620]|0;aN(6,27992,29,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ct=a[405432]|0;j=255;break;case 255:if((ct&1)==0){j=257;break}else{j=256;break};case 256:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,29232,(H=i,i=i+8|0,c[H>>2]=37176,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=257;break;case 257:ap(84,27592);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 258:c[140913]=72;W=aJ(86,327864,53768)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=264;break}else{j=259;break};case 259:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,30512,(H=i,i=i+8|0,c[H>>2]=327864,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=a[405432]|0;if((W&1)==0){cu=W;j=261;break}else{j=260;break};case 260:W=c[140620]|0;aN(6,29928,29,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cu=a[405432]|0;j=261;break;case 261:if((cu&1)==0){j=263;break}else{j=262;break};case 262:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,29232,(H=i,i=i+8|0,c[H>>2]=53768,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=263;break;case 263:ap(84,28784);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 264:c[140914]=6128;W=a[405432]|0;if((W&1)==0){cv=W;j=266;break}else{j=265;break};case 265:W=c[140620]|0;G=(W|0)!=0?W:c[t>>2]|0;W=aM(c[21536]|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ax(86,G|0,53320,(H=i,i=i+8|0,c[H>>2]=W,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cv=a[405432]|0;j=266;break;case 266:if((cv&1)==0){j=268;break}else{j=267;break};case 267:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,53192,(H=i,i=i+8|0,c[H>>2]=1,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=268;break;case 268:W=aM(c[21536]|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==1){j=270;break}else{j=269;break};case 269:W=c[140620]|0;aN(6,52744,117,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=270;break;case 270:aP(c[21518]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cw=(a[563557]&1)==0;W=a[563556]&1;a[562182]=cw?W^1:0;if(W<<24>>24==0){j=273;break}else{j=271;break};case 271:if(cw){j=272;break}else{j=369;break};case 272:W=as(202,c[102392]|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(W){j=369;break}else{j=493;break};case 273:if(cw){j=274;break}else{j=369;break};case 274:aP(54);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=as(202,c[102392]|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(W){j=275;break}else{j=493;break};case 275:cx=A|0;cy=B|0;cz=C|0;if((a[401305]&1)==0){j=289;break}else{j=276;break};case 276:aq(538,cx|0,466922);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aO(62,cy|0,466922,4096);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cA=ax(72,cx|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cA|0)==0){j=289;break}else{j=277;break};case 277:cB=cA+4|0;cC=cA|0;if((c[cB>>2]|0)==0){j=278;break}else{cD=0;cE=0;j=279;break};case 278:cF=c[cC>>2]|0;cG=0;j=287;break;case 279:cH=c[(c[cC>>2]|0)+(cD<<3)>>2]|0;aO(62,cz|0,cH|0,4096);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=as(130,cy|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=ax(56,cz|0,cy|0,W|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=280;break}else{cI=cE;j=284;break};case 280:G=as(130,cH|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cJ=cH+G|0;j=281;break;case 281:if(cJ>>>0>cH>>>0){j=282;break}else{j=283;break};case 282:G=cJ-1|0;if(((a[G]|0)-48|0)>>>0<10){cJ=G;j=281;break}else{j=283;break};case 283:G=ax(26,cJ|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cI=G>>>0>cE>>>0?G:cE;j=284;break;case 284:G=cD+1|0;cK=c[cB>>2]|0;if(G>>>0<cK>>>0){cD=G;cE=cI;j=279;break}else{j=285;break};case 285:G=c[cC>>2]|0;if((cK|0)==0){cF=G;cG=cI;j=287;break}else{cL=0;cM=G;j=286;break};case 286:ap(174,c[cM+(cL<<3)>>2]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=cL+1|0;W=c[cC>>2]|0;if(G>>>0<(c[cB>>2]|0)>>>0){cL=G;cM=W;j=286;break}else{cF=W;cG=cI;j=287;break};case 287:ap(174,cF|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(174,cA|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[124924]=cG;if((a[405432]&1)==0){j=289;break}else{j=288;break};case 288:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,53536,(H=i,i=i+8|0,c[H>>2]=cG,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=289;break;case 289:if((a[562180]&1)==0){j=290;break}else{j=323;break};case 290:switch(c[102392]|0){case 0:{j=291;break};case 1:{j=299;break};case 2:case 3:{j=307;break};case 4:{j=315;break};default:{j=325;break}}break;case 291:cN=as(c[21526]|0,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cO=as(c[21528]|0,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cN|0)==0|(cO|0)==0){j=295;break}else{j=292;break};case 292:c[v>>2]=0;cP=aJ(8,446442,v|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cQ=c[v>>2]|0;if((cP|0)<1|(cP|0)>(cN|0)){j=294;break}else{j=293;break};case 293:yE(cO|0,cQ|0,cP)|0;j=294;break;case 294:ap(174,cQ|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=295;break;case 295:cR=as(c[21526]|0,1)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cS=as(c[21528]|0,1)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cR|0)==0|(cS|0)==0){j=325;break}else{j=296;break};case 296:c[u>>2]=0;cT=aJ(8,450538,u|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cU=c[u>>2]|0;if((cT|0)<1|(cT|0)>(cR|0)){j=298;break}else{j=297;break};case 297:yE(cS|0,cU|0,cT)|0;j=298;break;case 298:ap(174,cU|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=325;break;case 299:cV=as(c[21526]|0,1280)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cW=as(c[21528]|0,1280)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cV|0)==0|(cW|0)==0){j=303;break}else{j=300;break};case 300:c[s>>2]=0;cX=aJ(8,446442,s|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cY=c[s>>2]|0;if((cX|0)<1|(cX|0)>(cV|0)){j=302;break}else{j=301;break};case 301:yE(cW|0,cY|0,cX)|0;j=302;break;case 302:ap(174,cY|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=303;break;case 303:cZ=as(c[21526]|0,1537)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c_=as(c[21528]|0,1537)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cZ|0)==0|(c_|0)==0){j=325;break}else{j=304;break};case 304:c[r>>2]=0;c$=aJ(8,450538,r|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c0=c[r>>2]|0;if((c$|0)<1|(c$|0)>(cZ|0)){j=306;break}else{j=305;break};case 305:yE(c_|0,c0|0,c$)|0;j=306;break;case 306:ap(174,c0|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=325;break;case 307:c1=as(c[21526]|0,256)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c2=as(c[21528]|0,256)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((c1|0)==0|(c2|0)==0){j=311;break}else{j=308;break};case 308:c[q>>2]=0;c3=aJ(8,446442,q|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c4=c[q>>2]|0;if((c3|0)<1|(c3|0)>(c1|0)){j=310;break}else{j=309;break};case 309:yE(c2|0,c4|0,c3)|0;j=310;break;case 310:ap(174,c4|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=311;break;case 311:c5=as(c[21526]|0,512)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c6=as(c[21528]|0,512)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((c5|0)==0|(c6|0)==0){j=325;break}else{j=312;break};case 312:c[p>>2]=0;c7=aJ(8,454634,p|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c8=c[p>>2]|0;if((c7|0)<1|(c7|0)>(c5|0)){j=314;break}else{j=313;break};case 313:yE(c6|0,c8|0,c7)|0;j=314;break;case 314:ap(174,c8|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=325;break;case 315:c9=as(c[21526]|0,768)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;da=as(c[21528]|0,768)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((c9|0)==0|(da|0)==0){j=319;break}else{j=316;break};case 316:c[o>>2]=0;db=aJ(8,458730,o|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dc=c[o>>2]|0;if((db|0)<1|(db|0)>(c9|0)){j=318;break}else{j=317;break};case 317:yE(da|0,dc|0,db)|0;j=318;break;case 318:ap(174,dc|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=319;break;case 319:dd=as(c[21526]|0,1024)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;de=as(c[21528]|0,1024)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dd|0)==0|(de|0)==0){j=325;break}else{j=320;break};case 320:c[n>>2]=0;df=aJ(8,462826,n|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dg=c[n>>2]|0;if((df|0)<1|(df|0)>(dd|0)){j=322;break}else{j=321;break};case 321:yE(de|0,dg|0,df)|0;j=322;break;case 322:ap(174,dg|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=325;break;case 323:if((a[405432]&1)==0){j=325;break}else{j=324;break};case 324:W=c[140620]|0;aN(6,24832,31,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=325;break;case 325:if((a[401307]&1)==0){j=338;break}else{j=326;break};case 326:aO(72,cx|0,466922,20760);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dh=aJ(24,cx|0,12144)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dh|0)==0){j=338;break}else{j=327;break};case 327:as(156,dh|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[405432]&1)==0){j=329;break}else{j=328;break};case 328:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,53888,(H=i,i=i+8|0,c[H>>2]=cx,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=329;break;case 329:W=as(150,cx|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aN(12,cy|0,4096,53712,(H=i,i=i+16|0,c[H>>2]=cx,c[H+8>>2]=W?20488:20400,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;di=c[138489]|0;dj=di+4|0;if((c[dj>>2]|0)>>>0<(c[di+8>>2]|0)>>>0){j=330;break}else{j=336;break};case 330:dk=as(42,12)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dk|0)==0){j=333;break}else{j=331;break};case 331:if((c[dk-4>>2]&3|0)==0){j=333;break}else{j=332;break};case 332:yB(dk|0,0,12);j=333;break;case 333:W=dk;c[dk+4>>2]=1;c[dk>>2]=180;G=as(116,cy|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dl=c[dj>>2]|0;c[dk+8>>2]=G;dm=di|0;c[(c[dm>>2]|0)+(dl<<2)>>2]=W;W=c[dj>>2]|0;c[dj>>2]=W+1;if(W>>>0>1){dn=W;j=334;break}else{j=336;break};case 334:dp=dn>>>1;W=c[dm>>2]|0;dq=W+(dp<<2)|0;dr=c[dq>>2]|0;ds=c[W+(dn<<2)>>2]|0;if((c[ds+4>>2]|0)>>>0>(c[dr+4>>2]|0)>>>0){j=335;break}else{j=336;break};case 335:c[dq>>2]=ds;c[(c[dm>>2]|0)+(dn<<2)>>2]=dr;if(dn>>>0>3){dn=dp;j=334;break}else{j=336;break};case 336:if((a[405432]&1)==0){j=338;break}else{j=337;break};case 337:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,50096,(H=i,i=i+8|0,c[H>>2]=cy,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=338;break;case 338:if((a[562178]&1)==0){j=351;break}else{j=339;break};case 339:W=aJ(66,558081,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[138495]=W;if((W|0)==0){j=340;break}else{j=341;break};case 340:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,10912,(H=i,i=i+8|0,c[H>>2]=558081,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(258,55016);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 341:a[558080]=1;dt=c[138489]|0;du=dt+4|0;if((c[du>>2]|0)>>>0<(c[dt+8>>2]|0)>>>0){j=342;break}else{j=348;break};case 342:dv=as(42,12)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dv|0)==0){j=345;break}else{j=343;break};case 343:if((c[dv-4>>2]&3|0)==0){j=345;break}else{j=344;break};case 344:yB(dv|0,0,12);j=345;break;case 345:W=dv;c[dv+4>>2]=2;c[dv>>2]=180;dl=as(116,54888)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[du>>2]|0;c[dv+8>>2]=dl;dw=dt|0;c[(c[dw>>2]|0)+(G<<2)>>2]=W;W=c[du>>2]|0;c[du>>2]=W+1;if(W>>>0>1){dx=W;j=346;break}else{j=348;break};case 346:dy=dx>>>1;W=c[dw>>2]|0;dz=W+(dy<<2)|0;dA=c[dz>>2]|0;dB=c[W+(dx<<2)>>2]|0;if((c[dB+4>>2]|0)>>>0>(c[dA+4>>2]|0)>>>0){j=347;break}else{j=348;break};case 347:c[dz>>2]=dB;c[(c[dw>>2]|0)+(dx<<2)>>2]=dA;if(dx>>>0>3){dx=dy;j=346;break}else{j=348;break};case 348:if((a[405432]&1)==0){j=350;break}else{j=349;break};case 349:W=c[140620]|0;aN(6,54248,36,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=350;break;case 350:c[100321]=1;j=369;break;case 351:if((a[562177]&1)==0){j=369;break}else{j=352;break};case 352:aN(12,cx|0,4096,15432,(H=i,i=i+8|0,c[H>>2]=558081,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=aJ(66,558081,1)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[138495]=W;dC=c[138489]|0;dD=dC+4|0;dE=c[dD>>2]|0;if(dE>>>0>1){j=353;break}else{j=357;break};case 353:dF=dC|0;dG=1;dH=dE;j=354;break;case 354:dI=c[(c[dF>>2]|0)+(dG<<2)>>2]|0;if((dI|0)==0){dJ=dH;j=356;break}else{j=355;break};case 355:ap(174,c[dI+8>>2]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(174,c[(c[dF>>2]|0)+(dG<<2)>>2]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[(c[dF>>2]|0)+(dG<<2)>>2]=0;dJ=c[dD>>2]|0;j=356;break;case 356:W=dG+1|0;if(W>>>0<dJ>>>0){dG=W;dH=dJ;j=354;break}else{j=357;break};case 357:c[dD>>2]=1;W=dC+12|0;ap(174,c[W>>2]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[W>>2]=0;dK=c[138489]|0;dL=dK+4|0;if((c[dL>>2]|0)>>>0<(c[dK+8>>2]|0)>>>0){j=358;break}else{j=364;break};case 358:dM=(c[138495]|0)!=0?cx:15224;dN=as(42,12)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dN|0)==0){j=361;break}else{j=359;break};case 359:if((c[dN-4>>2]&3|0)==0){j=361;break}else{j=360;break};case 360:yB(dN|0,0,12);j=361;break;case 361:W=dN;c[dN+4>>2]=1;c[dN>>2]=180;G=as(116,dM|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dl=c[dL>>2]|0;c[dN+8>>2]=G;dO=dK|0;c[(c[dO>>2]|0)+(dl<<2)>>2]=W;W=c[dL>>2]|0;c[dL>>2]=W+1;if(W>>>0>1){dP=W;j=362;break}else{j=364;break};case 362:dQ=dP>>>1;W=c[dO>>2]|0;dR=W+(dQ<<2)|0;dS=c[dR>>2]|0;dT=c[W+(dP<<2)>>2]|0;if((c[dT+4>>2]|0)>>>0>(c[dS+4>>2]|0)>>>0){j=363;break}else{j=364;break};case 363:c[dR>>2]=dT;c[(c[dO>>2]|0)+(dP<<2)>>2]=dS;if(dP>>>0>3){dP=dQ;j=362;break}else{j=364;break};case 364:if((c[138495]|0)==0){j=368;break}else{j=365;break};case 365:if((a[405432]&1)==0){j=367;break}else{j=366;break};case 366:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,15064,(H=i,i=i+8|0,c[H>>2]=558081,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=367;break;case 367:c[100321]=1;j=369;break;case 368:W=c[140620]|0;aN(6,14512,51,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=369;break;case 369:ap(c[21492]|0,10);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[21504]|0,344);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[21502]|0,54);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[21494]|0,2);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[21496]|0,30);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[21522]|0,499736);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dU=+aL(2);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dV=dU*1.0e3;W=+V(dV)>=1.0?dV>0.0?(al(+U(dV/4294967296.0),4294967295.0)|0)>>>0:~~+af((dV- +(~~dV>>>0))/4294967296.0)>>>0:0;dl=499712;c[dl>>2]=~~dV>>>0;c[dl+4>>2]=W;dV=+aG(2,+(1.0e6/(+h[62470]*+g[100323])));if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=+V(dV)>=1.0?dV>0.0?(al(+U(dV/4294967296.0),4294967295.0)|0)>>>0:~~+af((dV- +(~~dV>>>0))/4294967296.0)>>>0:0;dl=499704;c[dl>>2]=~~dV>>>0;c[dl+4>>2]=W;aP(32);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(42);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(22);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[562182]&1)==0){j=370;break}else{j=371;break};case 370:a[562182]=0;j=372;break;case 371:W=a[562181]&1;a[562182]=W^1;if(W<<24>>24==0){j=374;break}else{j=372;break};case 372:if((a[405432]&1)==0){j=374;break}else{j=373;break};case 373:W=c[140620]|0;aN(6,24600,35,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=374;break;case 374:if((c[138495]|0)!=0|(a[384892]|0)==0){j=492;break}else{j=375;break};case 375:aP(c[21534]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dW=as(42,16)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dW|0)==0){dX=0;j=491;break}else{j=376;break};case 376:if((c[dW-4>>2]&3|0)==0){j=378;break}else{j=377;break};case 377:yB(dW|0,0,16);j=378;break;case 378:dY=dW;dZ=dW+12|0;c[dZ>>2]=1;d_=as(42,12)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((d_|0)==0){j=382;break}else{j=379;break};case 379:if((c[d_-4>>2]&3|0)==0){j=380;break}else{j=381;break};case 380:W=dW;c[W>>2]=d_;d$=W;j=383;break;case 381:yB(d_|0,0,12);W=dW;c[W>>2]=d_;d$=W;j=383;break;case 382:c[dW>>2]=0;c[dZ>>2]=0;j=484;break;case 383:d0=as(58,384892)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((d0|0)==0){j=384;break}else{j=385;break};case 384:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,21968,(H=i,i=i+8|0,c[H>>2]=384892,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=484;break;case 385:d1=d0|0;W=c[d1>>2]|0;if((W|0)==0){j=386;break}else{d2=W;j=387;break};case 386:ap(198,dY|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=486;break;case 387:if((c[d2+20>>2]|0)==0){j=388;break}else{j=389;break};case 388:W=aJ(80,c[d2>>2]|0,52184)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=390;break}else{j=389;break};case 389:W=c[d2+16>>2]|0;if((W|0)==0){j=485;break}else{d2=W;j=387;break};case 390:d3=c[d2+12>>2]|0;if((d3|0)==0){j=485;break}else{j=391;break};case 391:if((a[562316]|0)==0){d4=d3;j=392;break}else{d5=d3;j=398;break};case 392:if((c[d4+20>>2]|0)==0){j=393;break}else{j=397;break};case 393:W=aJ(80,c[d4>>2]|0,38360)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=394;break}else{j=397;break};case 394:d6=d4+8|0;j=395;break;case 395:d7=c[d6>>2]|0;if((d7|0)==0){j=397;break}else{j=396;break};case 396:W=aJ(80,30304,c[d7>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=397;break}else{d6=d7+8|0;j=395;break};case 397:W=c[d4+16>>2]|0;if((W|0)==0){j=485;break}else{d4=W;j=392;break};case 398:if((c[d5+20>>2]|0)==0){j=399;break}else{j=405;break};case 399:W=aJ(80,c[d5>>2]|0,38360)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=400;break}else{j=405;break};case 400:d8=d5+8|0;j=401;break;case 401:d9=c[d8>>2]|0;if((d9|0)==0){j=405;break}else{j=402;break};case 402:W=aJ(80,30304,c[d9>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=403;break}else{d8=d9+8|0;j=401;break};case 403:ea=c[d9+4>>2]|0;if((ea|0)==0){j=405;break}else{j=404;break};case 404:W=aJ(80,ea|0,562316)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=406;break}else{j=405;break};case 405:W=c[d5+16>>2]|0;if((W|0)==0){j=485;break}else{d5=W;j=398;break};case 406:W=c[d5+12>>2]|0;eb=dW+8|0;if((W|0)==0){j=465;break}else{ec=W;j=407;break};case 407:ed=c[ec>>2]|0;W=aJ(80,ed|0,46712)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=408;break}else{j=411;break};case 408:ee=c[ec+4>>2]|0;if((ee|0)==0){j=463;break}else{j=409;break};case 409:if((a[405432]&1)==0){j=463;break}else{j=410;break};case 410:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,45288,(H=i,i=i+8|0,c[H>>2]=ee,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=463;break;case 411:W=aJ(80,ed|0,43888)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=412;break}else{j=463;break};case 412:ef=c[eb>>2]|0;if((ef|0)==(c[dZ>>2]|0)){j=414;break}else{j=413;break};case 413:eg=ef;eh=c[d$>>2]|0;j=416;break;case 414:c[dZ>>2]=ef<<1;W=aJ(46,c[d$>>2]|0,ef*24|0|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ei=W;c[d$>>2]=ei;if((W|0)==0){j=464;break}else{j=415;break};case 415:eg=c[eb>>2]|0;eh=ei;j=416;break;case 416:ej=eh+(eg*12|0)|0;ek=c[ec+12>>2]|0;if((ek|0)==0){j=463;break}else{j=417;break};case 417:yB(ej|0,0,12);el=ej|0;em=eh+(eg*12|0)+8|0;en=ek;eo=1;ep=0;eq=0;j=418;break;case 418:er=c[en>>2]|0;W=aJ(80,er|0,42656)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=419;break}else{j=420;break};case 419:c[el>>2]=c[en+4>>2];es=eo;et=ep;eu=eq;j=461;break;case 420:W=aJ(80,er|0,41728)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=421;break}else{es=eo;et=ep;eu=eq;j=461;break};case 421:if(eo){ev=ep;j=440;break}else{j=422;break};case 422:ew=(eq|0)!=0;if(ew){j=423;break}else{ex=2;j=424;break};case 423:W=as(130,eq|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ex=W+2|0;j=424;break;case 424:ey=aJ(46,eq|0,ex|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((ey|0)==0){j=425;break}else{j=426;break};case 425:c[em>>2]=0;j=463;break;case 426:if(ew){j=427;break}else{j=434;break};case 427:ez=as(130,ey|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;eA=ez>>>0>ex>>>0?0:ex-ez|0;if((eA|0)==0){eB=40528;j=431;break}else{j=428;break};case 428:eC=ey+ez|0;if((eA|0)==1){eD=40528;eE=eC;j=430;break}else{j=429;break};case 429:eF=ey+(ez+1)|0;a[eC]=43;if((eA|0)==2){eD=40529;eE=eF;j=430;break}else{j=490;break};case 430:a[eE]=0;eB=eD;j=431;break;case 431:if((a[eB]|0)==0){j=433;break}else{eG=eB;j=432;break};case 432:W=eG+1|0;if((a[W]|0)==0){j=433;break}else{eG=W;j=432;break};case 433:c[em>>2]=ey;ev=ey;j=440;break;case 434:if((ex|0)==1){eH=40528;eI=ey;j=436;break}else if((ex|0)==0){eJ=40528;j=437;break}else{j=435;break};case 435:eK=ey+1|0;a[ey]=43;if((ex|0)==2){eH=40529;eI=eK;j=436;break}else{j=489;break};case 436:a[eI]=0;eJ=eH;j=437;break;case 437:if((a[eJ]|0)==0){j=439;break}else{eL=eJ;j=438;break};case 438:W=eL+1|0;if((a[W]|0)==0){j=439;break}else{eL=W;j=438;break};case 439:c[em>>2]=ey;ev=ey;j=440;break;case 440:eM=c[en+4>>2]|0;if((eM|0)==0){j=463;break}else{j=441;break};case 441:eN=(ev|0)!=0;if(eN){j=442;break}else{eO=1;j=443;break};case 442:W=as(130,ev|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;eO=W+1|0;j=443;break;case 443:W=as(130,eM|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;eP=W+eO|0;eQ=aJ(46,ev|0,eP|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((eQ|0)==0){j=444;break}else{j=445;break};case 444:c[em>>2]=0;j=463;break;case 445:if(eN){j=446;break}else{j=454;break};case 446:eR=as(130,eQ|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;eS=eR>>>0>eP>>>0?0:eP-eR|0;if((eS|0)==0){eT=eM;j=451;break}else{j=447;break};case 447:eU=eS;eV=eQ+eR|0;eW=eM;j=448;break;case 448:eX=eU-1|0;if((eX|0)==0){j=450;break}else{j=449;break};case 449:W=a[eW]|0;a[eV]=W;if(W<<24>>24==0){j=453;break}else{eU=eX;eV=eV+1|0;eW=eW+1|0;j=448;break};case 450:a[eV]=0;eT=eW;j=451;break;case 451:if((a[eT]|0)==0){j=453;break}else{eY=eT;j=452;break};case 452:W=eY+1|0;if((a[W]|0)==0){j=453;break}else{eY=W;j=452;break};case 453:c[em>>2]=eQ;es=0;et=eQ;eu=eQ;j=461;break;case 454:if((eP|0)==0){eZ=eM;j=458;break}else{e_=eP;e$=eQ;e0=eM;j=455;break};case 455:e1=e_-1|0;if((e1|0)==0){j=457;break}else{j=456;break};case 456:W=a[e0]|0;a[e$]=W;if(W<<24>>24==0){j=460;break}else{e_=e1;e$=e$+1|0;e0=e0+1|0;j=455;break};case 457:a[e$]=0;eZ=e0;j=458;break;case 458:if((a[eZ]|0)==0){j=460;break}else{e2=eZ;j=459;break};case 459:W=e2+1|0;if((a[W]|0)==0){j=460;break}else{e2=W;j=459;break};case 460:c[em>>2]=eQ;es=0;et=eQ;eu=eQ;j=461;break;case 461:W=c[en+16>>2]|0;if((W|0)==0){j=462;break}else{en=W;eo=es;ep=et;eq=eu;j=418;break};case 462:c[eb>>2]=(c[eb>>2]|0)+1;j=463;break;case 463:W=c[ec+16>>2]|0;if((W|0)==0){j=465;break}else{ec=W;j=407;break};case 464:W=c[140620]|0;aN(6,25760,68,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=485;break;case 465:if((c[eb>>2]|0)==0){j=466;break}else{j=467;break};case 466:W=c[140620]|0;ax(86,((W|0)!=0?W:c[t>>2]|0)|0,22312,(H=i,i=i+8|0,c[H>>2]=384892,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[140620]|0;as(112,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=485;break;case 467:if((a[388988]|0)==0){j=481;break}else{j=468;break};case 468:e3=aJ(18,388988,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((e3|0)==0){j=481;break}else{j=469;break};case 469:e4=e3+4|0;j=470;break;case 470:e5=c[e4>>2]|0;if((e5|0)==0){j=472;break}else{j=471;break};case 471:W=aJ(80,562316,c[e5+4>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=473;break}else{e4=e5+12|0;j=470;break};case 472:ap(138,e3|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=481;break;case 473:e6=as(116,c[e5+8>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=ax(116,e6|0,28640,m|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=477;break}else{e7=W;j=474;break};case 474:e8=ax(26,e7|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(e8>>>0<(c[eb>>2]|0)>>>0){j=475;break}else{j=476;break};case 475:a[(c[d$>>2]|0)+(e8*12|0)+4|0]=1;j=476;break;case 476:W=ax(116,0,28640,m|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=477;break}else{e7=W;j=474;break};case 477:ap(174,e6|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(138,e3|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(c[21534]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[eb>>2]|0;if((W|0)==0){j=481;break}else{e9=0;fa=0;fb=W;j=478;break};case 478:fc=c[d$>>2]|0;if((a[fc+(fa*12|0)+4|0]&1)==0){fd=e9;fe=fb;j=480;break}else{j=479;break};case 479:W=e9+1|0;aO(c[21532]|0,e9|0,1,c[fc+(fa*12|0)+8>>2]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fd=W;fe=c[eb>>2]|0;j=480;break;case 480:W=fa+1|0;if(W>>>0<fe>>>0){e9=fd;fa=W;fb=fe;j=478;break}else{j=481;break};case 481:ff=c[d1>>2]|0;if((ff|0)==0){j=483;break}else{j=482;break};case 482:ap(446,ff|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=483;break;case 483:ap(174,d0|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dX=dY;j=491;break;case 484:ap(198,dY|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dX=0;j=491;break;case 485:ap(198,dY|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=486;break;case 486:fg=c[d1>>2]|0;if((fg|0)==0){j=488;break}else{j=487;break};case 487:ap(446,fg|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=488;break;case 488:ap(174,d0|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dX=0;j=491;break;case 489:a[eK]=0;j=439;break;case 490:a[eF]=0;j=433;break;case 491:c[140596]=dX;j=492;break;case 492:a[562485]=0;a[562484]=1;I=0;j=509;break;case 493:aP(4);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fh=c[126119]|0;if((fh|0)==0){j=496;break}else{j=494;break};case 494:if((a[563673]&1)==0){j=495;break}else{j=496;break};case 495:aP(fh|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=496;break;case 496:aP(38);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[563675]&1)==0){j=498;break}else{j=497;break};case 497:c[140916]=0;j=498;break;case 498:if((a[563676]&1)==0){j=500;break}else{j=499;break};case 499:c[140915]=0;j=500;break;case 500:if((a[563677]&1)==0){j=502;break}else{j=501;break};case 501:c[140917]=0;j=502;break;case 502:a[563675]=0;a[563676]=0;a[563677]=0;aP(c[21490]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(c[21530]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fi=c[126128]|0;if((fi|0)==0){j=508;break}else{j=503;break};case 503:fj=fi+4104|0;if((c[fj>>2]|0)==0){j=504;break}else{j=505;break};case 504:fk=fi|0;j=507;break;case 505:fl=fi|0;fm=0;j=506;break;case 506:W=c[fi+4100>>2]|0;aO(82,c[fl>>2]|0,c[W+(fm<<4)+4>>2]|0,c[(c[c[W+(fm<<4)+8>>2]>>2]|0)+(c[W+(fm<<4)+12>>2]<<3)>>2]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=fm+1|0;if(W>>>0<(c[fj>>2]|0)>>>0){fm=W;j=506;break}else{fk=fl;j=507;break};case 507:aJ(68,c[fk>>2]|0,fi+4|0)|0;if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(204,c[126128]|0);if((x|0)!=0&(y|0)!=0){k=yD(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=508;break;case 508:yB(499720,0,4800);a[562484]=0;I=1;j=509;break;case 509:i=f;return I|0;case-1:if((k|0)==1){F=y;j=510}x=y=0;break}return 0}function g5(){var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a8=0,a9=0,ba=0,bb=0,bc=0;d=i;i=i+9216|0;e=d|0;f=d+256|0;j=d+768|0;k=d+4864|0;l=d+8960|0;a[563679]=0;m=329864;if((c[82465]|0)==0&((c[m>>2]|0)==65535&(c[m+4>>2]|0)==0)&(c[82470]|0)==-1){n=774}else{m=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,48)|0;o=563840;p=(c[o>>2]&0|m&1|0)==0&(c[o+4>>2]&65536|0)==0;a[563679]=p&1;if(p){q=0}else{n=774}}do{if((n|0)==774){p=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,43)|0;o=563840;if((c[o>>2]&0|p&1|0)==0&(c[o+4>>2]&2048|0)==0){q=0;break}if((a[563896]&1)!=0){q=1;break}gP();q=1}}while(0);a[563896]=q;q=a[405433]|0;if((q&1)==0){r=q}else{do{if((a[563679]&1)==0){q=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,45)|0;o=563840;if((c[o>>2]&0|q&1|0)==0&(c[o+4>>2]&8192|0)==0){s=0;break}if((a[563960]&1)!=0){s=1;break}o=a[504561]&1;a[504561]=o^1;q=o<<24>>24==0?11352:11200;o=c[138489]|0;p=o+4|0;m=c[p>>2]|0;if(m>>>0>1){u=o|0;v=1;w=m;while(1){m=c[(c[u>>2]|0)+(v<<2)>>2]|0;if((m|0)==0){x=w}else{yt(c[m+8>>2]|0);yt(c[(c[u>>2]|0)+(v<<2)>>2]|0);c[(c[u>>2]|0)+(v<<2)>>2]=0;x=c[p>>2]|0}m=v+1|0;if(m>>>0<x>>>0){v=m;w=x}else{break}}}c[p>>2]=1;w=o+12|0;yt(c[w>>2]|0);c[w>>2]=0;w=c[138489]|0;v=w+4|0;L1091:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){u=ys(12)|0;do{if((u|0)!=0){if((c[u-4>>2]&3|0)==0){break}yB(u|0,0,12)}}while(0);c[u+4>>2]=1;c[u>>2]=180;m=dW(q|0)|0;y=c[v>>2]|0;c[u+8>>2]=m;m=w|0;c[(c[m>>2]|0)+(y<<2)>>2]=u;y=c[v>>2]|0;c[v>>2]=y+1;if(y>>>0>1){z=y}else{break}while(1){y=z>>>1;A=c[m>>2]|0;B=A+(y<<2)|0;C=c[B>>2]|0;D=c[A+(z<<2)>>2]|0;if((c[D+4>>2]|0)>>>0<=(c[C+4>>2]|0)>>>0){break L1091}c[B>>2]=D;c[(c[m>>2]|0)+(z<<2)>>2]=C;if(z>>>0>3){z=y}else{break}}}}while(0);v=c[140915]|0;do{if((v|0)!=0){w=c[140912]|0;if((a[504561]&1)!=0){o=c[w+8>>2]|0;f5[o&255](v)|0;break}if(f5[c[w+12>>2]&255](v)|0){break}w=c[140620]|0;o=(w|0)!=0?w:c[t>>2]|0;be(11072,45,1,o|0)|0;o=c[140620]|0;w=(o|0)!=0?o:c[t>>2]|0;a7(w|0)|0;a[405433]=0}}while(0);if((a[405432]&1)==0){s=1;break}v=c[140620]|0;w=(v|0)!=0?v:c[t>>2]|0;eS(w|0,50096,(E=i,i=i+8|0,c[E>>2]=q,E)|0)|0;i=E;w=c[140620]|0;v=(w|0)!=0?w:c[t>>2]|0;a7(v|0)|0;s=1}else{s=0}}while(0);a[563960]=s;r=a[405433]|0}s=l|0;do{if((r&1)!=0){l=a[563679]|0;if((l&1)==0){z=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,49)|0;x=563840;F=(c[x>>2]&0|z&1|0)!=0|(c[x+4>>2]&131072|0)!=0;G=a[563679]|0}else{F=0;G=l}if((G&1)==0){l=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,50)|0;x=563840;H=(c[x>>2]&0|l&1|0)!=0|(c[x+4>>2]&262144|0)!=0}else{H=0}if(!(F|H)){break}I=F?.5:0.0;if(H){J=I+-.5}else{J=I}I=J+ +g[126153];g[126153]=I;do{if(I>12.0){g[126153]=12.0;L=12.0}else{if(I>=-80.0){L=I;break}g[126153]=-80.0;L=-80.0}}while(0);I=L;b5(s|0,256,11496,(E=i,i=i+8|0,h[E>>3]=I,E)|0)|0;i=E;q=c[138489]|0;x=q+4|0;l=c[x>>2]|0;if(l>>>0>1){z=q|0;v=1;w=l;while(1){l=c[(c[z>>2]|0)+(v<<2)>>2]|0;if((l|0)==0){M=w}else{yt(c[l+8>>2]|0);yt(c[(c[z>>2]|0)+(v<<2)>>2]|0);c[(c[z>>2]|0)+(v<<2)>>2]=0;M=c[x>>2]|0}l=v+1|0;if(l>>>0<M>>>0){v=l;w=M}else{break}}}c[x>>2]=1;w=q+12|0;yt(c[w>>2]|0);c[w>>2]=0;w=c[138489]|0;v=w+4|0;L1136:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){z=ys(12)|0;do{if((z|0)!=0){if((c[z-4>>2]&3|0)==0){break}yB(z|0,0,12)}}while(0);c[z+4>>2]=1;c[z>>2]=180;l=dW(s|0)|0;o=c[v>>2]|0;c[z+8>>2]=l;l=w|0;c[(c[l>>2]|0)+(o<<2)>>2]=z;o=c[v>>2]|0;c[v>>2]=o+1;if(o>>>0>1){N=o}else{break}while(1){o=N>>>1;p=c[l>>2]|0;m=p+(o<<2)|0;u=c[m>>2]|0;y=c[p+(N<<2)>>2]|0;if((c[y+4>>2]|0)>>>0<=(c[u+4>>2]|0)>>>0){break L1136}c[m>>2]=y;c[(c[l>>2]|0)+(N<<2)>>2]=u;if(N>>>0>3){N=o}else{break}}}}while(0);if((a[405432]&1)!=0){v=c[140620]|0;w=(v|0)!=0?v:c[t>>2]|0;eS(w|0,50096,(E=i,i=i+8|0,c[E>>2]=s,E)|0)|0;i=E;w=c[140620]|0;v=(w|0)!=0?w:c[t>>2]|0;a7(v|0)|0}g[126154]=+X(10.0,+(+g[126153]/20.0))}}while(0);c[140553]=(c[140553]|0)+1;a[562186]=(f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,8312,0,1,0,16)|0)<<16>>16!=0|0;a[562187]=(f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,8312,1,1,0,16)|0)<<16>>16!=0|0;a[562188]=(f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,8312,2,1,0,16)|0)<<16>>16!=0|0;a[562189]=(f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,8312,3,1,0,16)|0)<<16>>16!=0|0;a[562190]=(f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,8312,4,1,0,16)|0)<<16>>16!=0|0;a[562191]=(f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,8312,5,1,0,16)|0)<<16>>16!=0|0;a[562192]=(f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,8312,6,1,0,16)|0)<<16>>16!=0|0;a[562193]=(f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,8312,7,1,0,16)|0)<<16>>16!=0|0;do{if((a[563679]&1)==0){s=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,54)|0;N=563840;if((c[N>>2]&0|s&1|0)==0&(c[N+4>>2]&4194304|0)==0){O=0;break}N=c[(c[140914]|0)+28>>2]|0;if((N|0)==0){O=0;break}if((a[563976]&1)!=0){O=1;break}s=a[563984]&1;M=s^1;a[563984]=M;if((a[405432]&1)==0){P=N;Q=M}else{M=c[140620]|0;N=(M|0)!=0?M:c[t>>2]|0;M=s<<24>>24==0?24664:24416;eS(N|0,12104,(E=i,i=i+8|0,c[E>>2]=M,E)|0)|0;i=E;M=c[140620]|0;N=(M|0)!=0?M:c[t>>2]|0;a7(N|0)|0;P=c[(c[140914]|0)+28>>2]|0;Q=a[563984]|0}f3[P&1023](c[140917]|0,(Q&1)!=0);N=c[140964]|0;if((N|0)==0){O=1;break}M=c[N+32>>2]|0;if((M|0)==0){O=1;break}f3[M&1023](c[140916]|0,(a[563984]&1)==0);O=1}else{O=0}}while(0);a[563976]=O;if((c[140958]|0)!=0){do{if((a[563679]&1)==0){O=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,51)|0;Q=563840;if((c[Q>>2]&0|O&1|0)==0&(c[Q+4>>2]&524288|0)==0){R=0;break}if((a[85944]&1)!=0){R=1;break}Q=c[140958]|0;O=Q+28|0;P=c[O>>2]|0;M=Q+20|0;c[M>>2]=P;N=c[Q+12>>2]|0;s=Q+16|0;c[s>>2]=N+(P*136|0);H=Q+4|0;F=c[(c[H>>2]|0)+4>>2]|0;G=Q|0;r=c[G>>2]|0;v=c[N+(P*136|0)+8>>2]|0;w=c[N+(P*136|0)+12>>2]|0;q=c[N+(P*136|0)+16>>2]|0;gq[F&31](r,v,w,q)|0;q=c[s>>2]|0;f7[c[(c[H>>2]|0)+12>>2]&7](c[G>>2]|0,+g[q+24>>2],+g[q+28>>2],+g[q+32>>2],+g[q+36>>2]);f3[c[(c[H>>2]|0)+16>>2]&1023](c[G>>2]|0,(a[(c[s>>2]|0)+68|0]&1)!=0);a[Q+9|0]=1;c[O>>2]=(((c[M>>2]|0)+1|0)>>>0)%((c[Q+24>>2]|0)>>>0)|0;R=1}else{R=0}}while(0);a[85944]=R}if((a[563679]&1)==0){R=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,35)|0;Q=563840;S=((c[Q>>2]&0|R&1|0)!=0|(c[Q+4>>2]&8|0)!=0)&1}else{S=0}do{if((a[562183]&1)==0){if((a[563679]&1)!=0){T=0;break}Q=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,36)|0;R=563840;T=((c[R>>2]&0|Q&1|0)!=0|(c[R+4>>2]&16|0)!=0)&1}else{T=0}}while(0);R=T|S;if((a[401296]&1)==0){U=1}else{U=f5[c[(c[140913]|0)+16>>2]&255](c[140916]|0)|0}do{if(R<<24>>24==0|U^1){n=863}else{if((a[563936]&1)!=0){n=863;break}S=a[562183]&1;a[562183]=S^1;T=(a[405432]&1)!=0;if(S<<24>>24==0){if(T){S=c[140620]|0;Q=(S|0)!=0?S:c[t>>2]|0;be(12976,19,1,Q|0)|0;Q=c[140620]|0;S=(Q|0)!=0?Q:c[t>>2]|0;a7(S|0)|0}S=c[140915]|0;if((S|0)==0){break}Q=c[(c[140912]|0)+8>>2]|0;f5[Q&255](S)|0;break}if(T){T=c[140620]|0;S=(T|0)!=0?T:c[t>>2]|0;be(12752,21,1,S|0)|0;S=c[140620]|0;T=(S|0)!=0?S:c[t>>2]|0;a7(T|0)|0}T=c[140915]|0;if((T|0)==0){break}if((a[504561]&1)!=0){break}if(f5[c[(c[140912]|0)+12>>2]&255](T)|0){break}T=c[140620]|0;S=(T|0)!=0?T:c[t>>2]|0;be(12560,81,1,S|0)|0;S=c[140620]|0;T=(S|0)!=0?S:c[t>>2]|0;a7(T|0)|0;a[405433]=0}}while(0);do{if((n|0)==863){T=(a[8352]&1)==0;if(!U){if(T){break}if((a[405432]&1)!=0){S=c[140620]|0;Q=(S|0)!=0?S:c[t>>2]|0;be(12976,19,1,Q|0)|0;Q=c[140620]|0;S=(Q|0)!=0?Q:c[t>>2]|0;a7(S|0)|0}a[562183]=1;S=c[140915]|0;if((S|0)==0){break}Q=c[(c[140912]|0)+8>>2]|0;f5[Q&255](S)|0;break}if(!T){break}if((a[405432]&1)!=0){T=c[140620]|0;S=(T|0)!=0?T:c[t>>2]|0;be(12752,21,1,S|0)|0;S=c[140620]|0;T=(S|0)!=0?S:c[t>>2]|0;a7(T|0)|0}a[562183]=0;T=c[140915]|0;if((T|0)==0){break}if((a[504561]&1)!=0){break}if(f5[c[(c[140912]|0)+12>>2]&255](T)|0){break}T=c[140620]|0;S=(T|0)!=0?T:c[t>>2]|0;be(12560,81,1,S|0)|0;S=c[140620]|0;T=(S|0)!=0?S:c[t>>2]|0;a7(T|0)|0;a[405433]=0}}while(0);a[8352]=U&1;a[563936]=R;do{if((a[563679]&1)==0){R=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,36)|0;U=563840;if((c[U>>2]&0|R&1|0)==0&(c[U+4>>2]&16|0)==0){V=0;W=0;break}V=a[563944]&1^1;W=1}else{V=0;W=0}}while(0);a[562184]=V;a[563944]=W;do{if((a[563679]&1)==0){W=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,33)|0;V=563840;if((c[V>>2]&0|W&1|0)==0&(c[V+4>>2]&2|0)==0){Y=0;Z=0;break}Y=a[563952]&1^1;Z=1}else{Y=0;Z=0}}while(0);a[562184]=(a[562184]&1|Y|0)!=0|0;a[563952]=Z;do{if((a[563679]&1)==0){Z=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,29)|0;Y=563840;if((c[Y>>2]&536870912|Z&1|0)==0&(c[Y+4>>2]&0|0)==0){_=0;n=896;break}if((a[563992]&1)!=0){_=1;n=896;break}a[303096]=a[303096]&1^1;a[563673]=a[504472]&1;a[563674]=0;hy();Y=c[126119]|0;do{if((Y|0)!=0){if((a[563673]&1)!=0){break}gs[Y&63]()}}while(0);hz();if((a[563675]&1)!=0){c[140916]=0}if((a[563676]&1)!=0){c[140915]=0}if((a[563677]&1)!=0){c[140917]=0}a[563675]=0;a[563676]=0;a[563677]=0;hx();a[563673]=0;Y=c[140914]|0;if((Y|0)!=0){f2[c[Y+4>>2]&1023](c[140917]|0)}a[563992]=1;if((a[562183]&1)==0){break}gQ()}else{_=0;n=896}}while(0);if((n|0)==896){a[563992]=_}do{if((a[562183]&1)!=0){if((a[562184]&1)!=0){break}i=d;return}}while(0);_=a[563679]|0;if((_&1)==0){Y=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,25)|0;Z=563840;$=(c[Z>>2]&33554432|Y&1|0)!=0|(c[Z+4>>2]&0|0)!=0;aa=a[563679]|0}else{$=0;aa=_}if((aa&1)==0){aa=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,26)|0;_=563840;ab=(c[_>>2]&67108864|aa&1|0)!=0|(c[_+4>>2]&0|0)!=0}else{ab=0}do{if($){if((a[564008]&1)!=0){n=915;break}_=a[563680]&1;a[563680]=_^1;aa=_<<24>>24==0;Z=c[140916]|0;if((a[405434]&1)!=0&(Z|0)!=0){if((a[303112]&1)==0){n=910}else{if((a[499797]&1)==0){ac=aa}else{n=910}}if((n|0)==910){ac=1}f3[c[(c[140913]|0)+8>>2]&1023](Z,ac)}Z=c[140915]|0;if((a[405433]&1)!=0&(Z|0)!=0){f3[c[(c[140912]|0)+16>>2]&1023](Z,(_&a[323720])<<24>>24==0)}c[126134]=aa?c[126135]|0:c[126136]|0}else{n=915}}while(0);do{if((n|0)==915){if((a[564e3]&1|0)==(ab&1|0)){break}a[563680]=ab&1;ac=c[140916]|0;if((a[405434]&1)!=0&(ac|0)!=0){if((a[303112]&1)==0){n=919}else{if((a[499797]&1)==0){ad=ab}else{n=919}}if((n|0)==919){ad=1}f3[c[(c[140913]|0)+8>>2]&1023](ac,ad)}ac=c[140915]|0;if((a[405433]&1)!=0&(ac|0)!=0){f3[c[(c[140912]|0)+16>>2]&1023](ac,(a[323720]&1)==0|ab)}c[126134]=ab?c[126135]|0:c[126136]|0}}while(0);a[564008]=$&1;a[564e3]=ab&1;do{if((a[563679]&1)==0){ab=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,31)|0;$=563840;if((c[$>>2]&-2147483648|ab&1|0)==0&(c[$+4>>2]&0|0)==0){ae=0;break}if((a[563864]&1)!=0){ae=1;break}$=e|0;ab=(c[124924]|0)+1|0;c[124924]=ab;ad=c[138489]|0;if((ad|0)==0){af=ab}else{ab=ad+4|0;ac=c[ab>>2]|0;if(ac>>>0>1){aa=ad|0;_=1;Z=ac;while(1){ac=c[(c[aa>>2]|0)+(_<<2)>>2]|0;if((ac|0)==0){ag=Z}else{yt(c[ac+8>>2]|0);yt(c[(c[aa>>2]|0)+(_<<2)>>2]|0);c[(c[aa>>2]|0)+(_<<2)>>2]=0;ag=c[ab>>2]|0}ac=_+1|0;if(ac>>>0<ag>>>0){_=ac;Z=ag}else{break}}}c[ab>>2]=1;Z=ad+12|0;yt(c[Z>>2]|0);c[Z>>2]=0;af=c[124924]|0}b5($|0,256,40616,(E=i,i=i+8|0,c[E>>2]=af,E)|0)|0;i=E;Z=c[138489]|0;L1299:do{if((Z|0)!=0){_=Z+4|0;if((c[_>>2]|0)>>>0>=(c[Z+8>>2]|0)>>>0){break}aa=ys(12)|0;do{if((aa|0)!=0){if((c[aa-4>>2]&3|0)==0){break}yB(aa|0,0,12)}}while(0);c[aa+4>>2]=1;c[aa>>2]=180;ac=dW($|0)|0;Y=c[_>>2]|0;c[aa+8>>2]=ac;ac=Z|0;c[(c[ac>>2]|0)+(Y<<2)>>2]=aa;Y=c[_>>2]|0;c[_>>2]=Y+1;if(Y>>>0>1){ah=Y}else{break}while(1){Y=ah>>>1;V=c[ac>>2]|0;W=V+(Y<<2)|0;U=c[W>>2]|0;R=c[V+(ah<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[U+4>>2]|0)>>>0){break L1299}c[W>>2]=R;c[(c[ac>>2]|0)+(ah<<2)>>2]=U;if(ah>>>0>3){ah=Y}else{break}}}}while(0);if((a[405432]&1)==0){ae=1;break}Z=c[140620]|0;ad=(Z|0)!=0?Z:c[t>>2]|0;eS(ad|0,50096,(E=i,i=i+8|0,c[E>>2]=$,E)|0)|0;i=E;ad=c[140620]|0;Z=(ad|0)!=0?ad:c[t>>2]|0;a7(Z|0)|0;ae=1}else{ae=0}}while(0);a[563864]=ae;do{if((a[563679]&1)==0){ae=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,32)|0;ah=563840;if((c[ah>>2]&0|ae&1|0)==0&(c[ah+4>>2]&1|0)==0){ai=0;break}if((a[563872]&1)!=0){ai=1;break}ah=e|0;ae=c[124924]|0;if((ae|0)==0){aj=0}else{af=ae-1|0;c[124924]=af;aj=af}af=c[138489]|0;if((af|0)==0){ak=aj}else{ae=af+4|0;ag=c[ae>>2]|0;if(ag>>>0>1){Z=af|0;ad=1;ab=ag;while(1){ag=c[(c[Z>>2]|0)+(ad<<2)>>2]|0;if((ag|0)==0){al=ab}else{yt(c[ag+8>>2]|0);yt(c[(c[Z>>2]|0)+(ad<<2)>>2]|0);c[(c[Z>>2]|0)+(ad<<2)>>2]=0;al=c[ae>>2]|0}ag=ad+1|0;if(ag>>>0<al>>>0){ad=ag;ab=al}else{break}}}c[ae>>2]=1;ab=af+12|0;yt(c[ab>>2]|0);c[ab>>2]=0;ak=c[124924]|0}b5(ah|0,256,40616,(E=i,i=i+8|0,c[E>>2]=ak,E)|0)|0;i=E;ab=c[138489]|0;L1330:do{if((ab|0)!=0){ad=ab+4|0;if((c[ad>>2]|0)>>>0>=(c[ab+8>>2]|0)>>>0){break}Z=ys(12)|0;do{if((Z|0)!=0){if((c[Z-4>>2]&3|0)==0){break}yB(Z|0,0,12)}}while(0);c[Z+4>>2]=1;c[Z>>2]=180;$=dW(ah|0)|0;ag=c[ad>>2]|0;c[Z+8>>2]=$;$=ab|0;c[(c[$>>2]|0)+(ag<<2)>>2]=Z;ag=c[ad>>2]|0;c[ad>>2]=ag+1;if(ag>>>0>1){am=ag}else{break}while(1){ag=am>>>1;ac=c[$>>2]|0;_=ac+(ag<<2)|0;aa=c[_>>2]|0;Y=c[ac+(am<<2)>>2]|0;if((c[Y+4>>2]|0)>>>0<=(c[aa+4>>2]|0)>>>0){break L1330}c[_>>2]=Y;c[(c[$>>2]|0)+(am<<2)>>2]=aa;if(am>>>0>3){am=ag}else{break}}}}while(0);if((a[405432]&1)==0){ai=1;break}ab=c[140620]|0;af=(ab|0)!=0?ab:c[t>>2]|0;eS(af|0,50096,(E=i,i=i+8|0,c[E>>2]=ah,E)|0)|0;i=E;af=c[140620]|0;ab=(af|0)!=0?af:c[t>>2]|0;a7(ab|0)|0;ai=1}else{ai=0}}while(0);a[563872]=ai;ai=(c[138495]|0)==0;do{if((a[563679]&1)==0){am=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,28)|0;ak=563840;if((c[ak>>2]&268435456|am&1|0)==0&(c[ak+4>>2]&0|0)==0){an=0;break}if((a[563904]&1)!=0){an=1;break}gY();an=1}else{an=0}}while(0);a[563904]=an&1;if(ai){do{if((a[563679]&1)==0){ai=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,27)|0;ak=563840;am=(c[ak>>2]&134217728|ai&1|0)!=0|(c[ak+4>>2]&0|0)!=0;if(an|am^1){ao=am;break}if((a[563912]&1)!=0){ao=am;break}gW();ao=am}else{ao=0}}while(0);a[563912]=ao&1}if((a[553976]&1)!=0){ao=c[126144]|0;if(gT((c[126143]|0)+(ao<<1)|0,(c[126145]|0)-ao|0)|0){ap=a[405433]&1}else{ap=0}a[405433]=ap}a[553976]=0;do{if(a[8344]|0){if((c[138491]|0)==0){break}L1366:do{if((a[563679]&1)==0){ap=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,33)|0;ao=563840;if((c[ao>>2]&0|ap&1|0)==0&(c[ao+4>>2]&2|0)==0){n=1027;break}ao=c[138489]|0;ap=ao+4|0;an=c[ap>>2]|0;if(an>>>0>1){am=ao|0;ak=1;ai=an;while(1){an=c[(c[am>>2]|0)+(ak<<2)>>2]|0;if((an|0)==0){aq=ai}else{yt(c[an+8>>2]|0);yt(c[(c[am>>2]|0)+(ak<<2)>>2]|0);c[(c[am>>2]|0)+(ak<<2)>>2]=0;aq=c[ap>>2]|0}an=ak+1|0;if(an>>>0<aq>>>0){ak=an;ai=aq}else{break}}}c[ap>>2]=1;ai=ao+12|0;yt(c[ai>>2]|0);c[ai>>2]=0;ai=c[138491]|0;ak=ai+12|0;am=c[ak>>2]|0;an=am;al=ai+28|0;do{if((a[al]&1)==0){aj=ai+16|0;e=ai+8|0;ab=c[e>>2]|0;af=(c[aj>>2]|0)-1&ab;c[aj>>2]=af;ae=ai+20|0;$=c[ae>>2]|0;if((af|0)==($|0)){c[aj>>2]=af+1&ab;ad=c[138489]|0;Z=ad+4|0;if((c[Z>>2]|0)>>>0>=(c[ad+8>>2]|0)>>>0){break L1366}ag=ys(12)|0;do{if((ag|0)!=0){if((c[ag-4>>2]&3|0)==0){break}yB(ag|0,0,12)}}while(0);c[ag+4>>2]=0;c[ag>>2]=30;aa=dW(13240)|0;Y=c[Z>>2]|0;c[ag+8>>2]=aa;aa=ad|0;c[(c[aa>>2]|0)+(Y<<2)>>2]=ag;Y=c[Z>>2]|0;c[Z>>2]=Y+1;if(Y>>>0>1){ar=Y}else{break L1366}while(1){Y=ar>>>1;_=c[aa>>2]|0;ac=_+(Y<<2)|0;U=c[ac>>2]|0;R=c[_+(ar<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[U+4>>2]|0)>>>0){break L1366}c[ac>>2]=R;c[(c[aa>>2]|0)+(ar<<2)>>2]=U;if(ar>>>0>3){ar=Y}else{break L1366}}}else{aa=ai|0;Z=(c[aa>>2]|0)+(af<<3)|0;ag=c[Z>>2]|0;ad=c[Z+4>>2]|0;if((ag|0)==0&(ad|0)==0){as=af;at=$;au=ab}else{Z=ad;ad=ag;ag=am;while(1){Y=ag+(Z<<2)|0;c[Y>>2]=c[Y>>2]^ad;av=c[e>>2]|0;aw=(c[aj>>2]|0)-1&av;c[aj>>2]=aw;Y=(c[aa>>2]|0)+(aw<<3)|0;U=c[Y>>2]|0;R=c[Y+4>>2]|0;if((U|0)==0&(R|0)==0){break}Z=R;ad=U;ag=c[ak>>2]|0}as=aw;at=c[ae>>2]|0;au=av}if((as|0)!=(at|0)){break}c[aj>>2]=at+1&au;break}}else{a[al]=0}}while(0);a[553976]=1;al=c[126145]|0;c[126144]=al;L1400:do{if((c[126133]|0)!=0){ak=0;am=al;while(1){ai=b[(c[126142]|0)+((ak|1)<<1)>>1]|0;ao=am-1|0;c[126144]=ao;b[(c[126143]|0)+(ao<<1)>>1]=ai;ai=b[(c[126142]|0)+(ak<<1)>>1]|0;ao=(c[126144]|0)-1|0;c[126144]=ao;b[(c[126143]|0)+(ao<<1)>>1]=ai;ai=ak+2|0;if(ai>>>0>=(c[126133]|0)>>>0){break L1400}ak=ai;am=c[126144]|0}}}while(0);c[126133]=0;al=c[138489]|0;am=al+4|0;L1405:do{if((c[am>>2]|0)>>>0<(c[al+8>>2]|0)>>>0){ak=(a[562183]&1)!=0?1:30;aj=ys(12)|0;do{if((aj|0)!=0){if((c[aj-4>>2]&3|0)==0){break}yB(aj|0,0,12)}}while(0);c[aj+4>>2]=0;c[aj>>2]=ak;ae=dW(13360)|0;ai=c[am>>2]|0;c[aj+8>>2]=ae;ae=al|0;c[(c[ae>>2]|0)+(ai<<2)>>2]=aj;ai=c[am>>2]|0;c[am>>2]=ai+1;if(ai>>>0>1){ax=ai}else{break}while(1){ai=ax>>>1;ao=c[ae>>2]|0;ap=ao+(ai<<2)|0;ag=c[ap>>2]|0;ad=c[ao+(ax<<2)>>2]|0;if((c[ad+4>>2]|0)>>>0<=(c[ag+4>>2]|0)>>>0){break L1405}c[ap>>2]=ad;c[(c[ae>>2]|0)+(ax<<2)>>2]=ag;if(ax>>>0>3){ax=ai}else{break}}}}while(0);am=c[21488]|0;al=c[138493]|0;gm[am&127](an,al)|0;al=c[138495]|0;if((al|0)==0){break}a[al+33|0]=1;am=al+20|0;ae=c[am>>2]|0;aj=c[al+12>>2]|0;do{if(ae>>>0<2){ak=c[aj>>2]|0;ai=al+28|0;if((ak|0)!=(c[ai>>2]|0)){ay=ai;n=1015;break}c[am>>2]=0;ag=c[al>>2]|0;e6(ag|0,ak|0,0)|0;az=ai}else{ay=al+28|0;n=1015}}while(0);if((n|0)==1015){an=ae-((a[al+32|0]&1)!=0?1:2)&c[al+16>>2];c[am>>2]=an;ai=c[al>>2]|0;ak=c[aj+(an<<2)>>2]|0;e6(ai|0,ak|0,0)|0;az=ay}ak=al|0;ai=cy(c[ak>>2]|0)|0;an=c[az>>2]|0;if((ai|0)>(an|0)){break}ai=c[ak>>2]|0;if((a[al+24|0]&1)==0){e6(ai|0,16,0)|0;ag=c[21508]|0;ad=al+4|0;ap=c[ad>>2]|0;ao=al+8|0;Z=c[ao>>2]|0;gm[ag&127](ap,Z)|0;Z=c[ad>>2]|0;ad=c[ao>>2]|0;ao=c[ak>>2]|0;be(Z|0,1,ad|0,ao|0)|0;break}else{e6(ai|0,an|0,0)|0;break}}else{n=1027}}while(0);do{if((n|0)==1027){ah=c[100321]|0;an=(((c[140980]|0)+1|0)>>>0)%(((ah|0)!=0?ah:1)>>>0)|0;c[140980]=an;if(!((an|0)==0|(c[138495]|0)!=0)){break}an=c[21508]|0;ah=c[138492]|0;ai=c[138493]|0;gm[an&127](ah,ai)|0;ai=c[138491]|0;ah=c[138492]|0;an=ai+12|0;ao=c[an>>2]|0;ad=ah;Z=ai+16|0;ak=c[Z>>2]|0;c[Z>>2]=ak+1;ap=ai|0;ag=(c[ap>>2]|0)+(ak<<3)|0;c[ag>>2]=0;c[ag+4>>2]=0;ag=ai+8|0;ak=c[ag>>2]|0;aa=c[Z>>2]&ak;c[Z>>2]=aa;e=ai+20|0;ab=(aa|0)==(c[e>>2]|0);$=ai+24|0;af=c[$>>2]|0;if((af|0)==0){aA=ab;aB=aa;aC=ak;aD=0}else{U=0;R=0;Y=ab;ab=aa;aa=ak;ak=af;while(1){af=R;ac=c[ao+(af<<2)>>2]|0;_=c[ad+(af<<2)>>2]|0;if((ac|0)==(_|0)){aE=Y;aF=ab;aG=aa;aH=ak}else{af=(c[ap>>2]|0)+(ab<<3)|0;c[af>>2]=_^ac;c[af+4>>2]=R;af=c[ag>>2]|0;ac=(c[Z>>2]|0)+1&af;c[Z>>2]=ac;aE=(ac|0)==(c[e>>2]|0)|Y;aF=ac;aG=af;aH=c[$>>2]|0}af=yL(R,U,1,0)|0;ac=K;_=0;if(ac>>>0<_>>>0|ac>>>0==_>>>0&af>>>0<aH>>>0){U=ac;R=af;Y=aE;ab=aF;aa=aG;ak=aH}else{aA=aE;aB=aF;aC=aG;aD=aH;break}}}do{if(aA){ak=aB+1&aC;c[e>>2]=ak;aa=c[ap>>2]|0;ab=aa+(ak<<3)|0;if((c[ab>>2]|0)==0&(c[ab+4>>2]|0)==0){break}else{aI=ak}do{aI=aI+1&aC;c[e>>2]=aI;ak=aa+(aI<<3)|0;}while(!((c[ak>>2]|0)==0&(c[ak+4>>2]|0)==0))}}while(0);e=c[an>>2]|0;ap=aD<<2;yE(e|0,ah|0,ap)|0;a[ai+28|0]=1}}while(0);f2[c[21504]&1023]((a[553976]&1)!=0?604:344);f2[c[21502]&1023]((a[553976]&1)!=0?74:54)}else{a[8344]=1}}while(0);L1444:do{if((a[563679]&1)==0){aD=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,47)|0;aI=563840;aC=(c[aI>>2]&0|aD&1|0)!=0|(c[aI+4>>2]&32768|0)!=0;a[562185]=aC&1;if(!aC){break}aC=c[138489]|0;aI=aC+4|0;aD=c[aI>>2]|0;if(aD>>>0>1){aB=aC|0;aA=1;aH=aD;while(1){aD=c[(c[aB>>2]|0)+(aA<<2)>>2]|0;if((aD|0)==0){aJ=aH}else{yt(c[aD+8>>2]|0);yt(c[(c[aB>>2]|0)+(aA<<2)>>2]|0);c[(c[aB>>2]|0)+(aA<<2)>>2]=0;aJ=c[aI>>2]|0}aD=aA+1|0;if(aD>>>0<aJ>>>0){aA=aD;aH=aJ}else{break}}}c[aI>>2]=1;aH=aC+12|0;yt(c[aH>>2]|0);c[aH>>2]=0;aH=c[138489]|0;aA=aH+4|0;if((c[aA>>2]|0)>>>0>=(c[aH+8>>2]|0)>>>0){break}aB=(a[553976]&1)!=0?13696:13536;aD=ys(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}yB(aD|0,0,12)}}while(0);c[aD+4>>2]=0;c[aD>>2]=30;aC=dW(aB|0)|0;aI=c[aA>>2]|0;c[aD+8>>2]=aC;aC=aH|0;c[(c[aC>>2]|0)+(aI<<2)>>2]=aD;aI=c[aA>>2]|0;c[aA>>2]=aI+1;if(aI>>>0>1){aK=aI}else{break}while(1){aI=aK>>>1;aG=c[aC>>2]|0;aF=aG+(aI<<2)|0;aE=c[aF>>2]|0;az=c[aG+(aK<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[aE+4>>2]|0)>>>0){break L1444}c[aF>>2]=az;c[(c[aC>>2]|0)+(aK<<2)>>2]=aE;if(aK>>>0>3){aK=aI}else{break}}}else{a[562185]=0}}while(0);do{if((a[563679]&1)==0){aK=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,34)|0;aJ=563840;if((c[aJ>>2]&0|aK&1|0)==0&(c[aJ+4>>2]&4|0)==0){aL=0;aM=0;break}aL=(a[563968]&1)==0;aM=1}else{aL=0;aM=0}}while(0);do{if((a[558080]&1)==0){if(!aL){break}aJ=j|0;aK=k|0;if((c[138495]|0)==0){c[100321]=1;aC=c[124924]|0;if((aC|0)==0){b5(aJ|0,4096,15648,(E=i,i=i+8|0,c[E>>2]=553984,E)|0)|0;i=E}else{b5(aJ|0,4096,15776,(E=i,i=i+16|0,c[E>>2]=553984,c[E+8>>2]=aC,E)|0)|0;i=E}b5(aK|0,4096,15432,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;c[138495]=h8(aJ,1)|0;aC=c[138489]|0;aA=aC+4|0;aD=c[aA>>2]|0;if(aD>>>0>1){aH=aC|0;aB=1;aI=aD;while(1){aD=c[(c[aH>>2]|0)+(aB<<2)>>2]|0;if((aD|0)==0){aN=aI}else{yt(c[aD+8>>2]|0);yt(c[(c[aH>>2]|0)+(aB<<2)>>2]|0);c[(c[aH>>2]|0)+(aB<<2)>>2]=0;aN=c[aA>>2]|0}aD=aB+1|0;if(aD>>>0<aN>>>0){aB=aD;aI=aN}else{break}}}c[aA>>2]=1;aI=aC+12|0;yt(c[aI>>2]|0);c[aI>>2]=0;aI=c[138489]|0;aB=aI+4|0;L1535:do{if((c[aB>>2]|0)>>>0<(c[aI+8>>2]|0)>>>0){aH=(c[138495]|0)!=0?aK:15224;aD=ys(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}yB(aD|0,0,12)}}while(0);c[aD+4>>2]=1;c[aD>>2]=180;ai=dW(aH|0)|0;ah=c[aB>>2]|0;c[aD+8>>2]=ai;ai=aI|0;c[(c[ai>>2]|0)+(ah<<2)>>2]=aD;ah=c[aB>>2]|0;c[aB>>2]=ah+1;if(ah>>>0>1){aO=ah}else{break}while(1){ah=aO>>>1;an=c[ai>>2]|0;aE=an+(ah<<2)|0;az=c[aE>>2]|0;aF=c[an+(aO<<2)>>2]|0;if((c[aF+4>>2]|0)>>>0<=(c[az+4>>2]|0)>>>0){break L1535}c[aE>>2]=aF;c[(c[ai>>2]|0)+(aO<<2)>>2]=az;if(aO>>>0>3){aO=ah}else{break}}}}while(0);if((c[138495]|0)==0){aB=c[140620]|0;aI=(aB|0)!=0?aB:c[t>>2]|0;be(14512,51,1,aI|0)|0;aI=c[140620]|0;aB=(aI|0)!=0?aI:c[t>>2]|0;a7(aB|0)|0;break}if((a[405432]&1)==0){break}aB=c[140620]|0;aI=(aB|0)!=0?aB:c[t>>2]|0;eS(aI|0,15064,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;aI=c[140620]|0;aB=(aI|0)!=0?aI:c[t>>2]|0;a7(aB|0)|0;break}else{aB=c[138489]|0;aI=aB+4|0;aK=c[aI>>2]|0;if(aK>>>0>1){aC=aB|0;aA=1;ai=aK;while(1){aK=c[(c[aC>>2]|0)+(aA<<2)>>2]|0;if((aK|0)==0){aP=ai}else{yt(c[aK+8>>2]|0);yt(c[(c[aC>>2]|0)+(aA<<2)>>2]|0);c[(c[aC>>2]|0)+(aA<<2)>>2]=0;aP=c[aI>>2]|0}aK=aA+1|0;if(aK>>>0<aP>>>0){aA=aK;ai=aP}else{break}}}c[aI>>2]=1;ai=aB+12|0;yt(c[ai>>2]|0);c[ai>>2]=0;ai=c[138489]|0;aA=ai+4|0;L1503:do{if((c[aA>>2]|0)>>>0<(c[ai+8>>2]|0)>>>0){aC=ys(12)|0;do{if((aC|0)!=0){if((c[aC-4>>2]&3|0)==0){break}yB(aC|0,0,12)}}while(0);c[aC+4>>2]=2;c[aC>>2]=180;aJ=dW(16072)|0;aK=c[aA>>2]|0;c[aC+8>>2]=aJ;aJ=ai|0;c[(c[aJ>>2]|0)+(aK<<2)>>2]=aC;aK=c[aA>>2]|0;c[aA>>2]=aK+1;if(aK>>>0>1){aQ=aK}else{break}while(1){aK=aQ>>>1;aD=c[aJ>>2]|0;aH=aD+(aK<<2)|0;ah=c[aH>>2]|0;az=c[aD+(aQ<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1503}c[aH>>2]=az;c[(c[aJ>>2]|0)+(aQ<<2)>>2]=ah;if(aQ>>>0>3){aQ=aK}else{break}}}}while(0);if((a[405432]&1)!=0){aA=c[140620]|0;ai=(aA|0)!=0?aA:c[t>>2]|0;be(15936,34,1,ai|0)|0;ai=c[140620]|0;aA=(ai|0)!=0?ai:c[t>>2]|0;a7(aA|0)|0}aA=c[138495]|0;if((aA|0)!=0){ai=c[aA>>2]|0;if((ai|0)!=0){a_(ai|0)|0}yt(c[aA+4>>2]|0);yt(c[aA+12>>2]|0);yt(aA)}c[138495]=0;break}}else{if(!((a[562179]&1)!=0|aL)){break}aA=c[138489]|0;ai=aA+4|0;L1472:do{if((c[ai>>2]|0)>>>0<(c[aA+8>>2]|0)>>>0){aB=ys(12)|0;do{if((aB|0)!=0){if((c[aB-4>>2]&3|0)==0){break}yB(aB|0,0,12)}}while(0);c[aB+4>>2]=1;c[aB>>2]=180;aI=dW(14272)|0;aJ=c[ai>>2]|0;c[aB+8>>2]=aI;aI=aA|0;c[(c[aI>>2]|0)+(aJ<<2)>>2]=aB;aJ=c[ai>>2]|0;c[ai>>2]=aJ+1;if(aJ>>>0>1){aR=aJ}else{break}while(1){aJ=aR>>>1;aC=c[aI>>2]|0;aK=aC+(aJ<<2)|0;ah=c[aK>>2]|0;az=c[aC+(aR<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1472}c[aK>>2]=az;c[(c[aI>>2]|0)+(aR<<2)>>2]=ah;if(aR>>>0>3){aR=aJ}else{break}}}}while(0);if((a[405432]&1)!=0){ai=c[140620]|0;aA=(ai|0)!=0?ai:c[t>>2]|0;be(13888,33,1,aA|0)|0;aA=c[140620]|0;ai=(aA|0)!=0?aA:c[t>>2]|0;a7(ai|0)|0}ai=c[138495]|0;if((ai|0)!=0){aA=c[ai>>2]|0;if((aA|0)!=0){a_(aA|0)|0}yt(c[ai+4>>2]|0);yt(c[ai+12>>2]|0);yt(ai)}c[138495]=0;a[562179]=0;a[558080]=0}}while(0);a[563968]=aM;aM=f|0;L1550:do{if((c[140577]|0)!=0){if((c[(c[140913]|0)+20>>2]|0)==0){break}f=a[563679]|0;if((f&1)==0){aR=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,38)|0;aL=563840;aS=(c[aL>>2]&0|aR&1|0)!=0|(c[aL+4>>2]&64|0)!=0;aT=a[563679]|0}else{aS=0;aT=f}if((aT&1)==0){f=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,39)|0;aL=563840;aU=(c[aL>>2]&0|f&1|0)!=0|(c[aL+4>>2]&128|0)!=0}else{aU=0}do{if(aS){if((a[563888]&1)!=0){n=1120;break}aL=c[140577]|0;f=(((c[140578]|0)+1|0)>>>0)%((c[aL+4>>2]|0)>>>0)|0;c[140578]=f;aV=f;aW=aL;n=1125}else{n=1120}}while(0);do{if((n|0)==1120){if(!aU){break}if((a[563880]&1)!=0){break}aL=c[140578]|0;if((aL|0)==0){f=c[140577]|0;aR=(c[f+4>>2]|0)-1|0;c[140578]=aR;aV=aR;aW=f;n=1125;break}else{f=aL-1|0;c[140578]=f;aV=f;aW=c[140577]|0;n=1125;break}}}while(0);do{if((n|0)==1125){f=c[(c[aW>>2]|0)+(aV<<3)>>2]|0;aL=cE(f|0,46)|0;if((aL|0)==0){break L1550}do{if((db(aL|0,17776)|0)==0){aX=2}else{if((db(aL|0,17568)|0)==0){aX=0;break}if((db(aL|0,17400)|0)==0){aX=0}else{break L1550}}}while(0);aL=c[138489]|0;aR=aL+4|0;aQ=c[aR>>2]|0;if(aQ>>>0>1){aP=aL|0;aO=1;aN=aQ;while(1){aQ=c[(c[aP>>2]|0)+(aO<<2)>>2]|0;if((aQ|0)==0){aY=aN}else{yt(c[aQ+8>>2]|0);yt(c[(c[aP>>2]|0)+(aO<<2)>>2]|0);c[(c[aP>>2]|0)+(aO<<2)>>2]=0;aY=c[aR>>2]|0}aQ=aO+1|0;if(aQ>>>0<aY>>>0){aO=aQ;aN=aY}else{break}}}c[aR>>2]=1;aN=aL+12|0;yt(c[aN>>2]|0);c[aN>>2]=0;aN=c[140578]|0;b5(aM|0,512,16888,(E=i,i=i+16|0,c[E>>2]=aN,c[E+8>>2]=f,E)|0)|0;i=E;aN=c[138489]|0;aO=aN+4|0;L1584:do{if((c[aO>>2]|0)>>>0<(c[aN+8>>2]|0)>>>0){aP=ys(12)|0;do{if((aP|0)!=0){if((c[aP-4>>2]&3|0)==0){break}yB(aP|0,0,12)}}while(0);c[aP+4>>2]=1;c[aP>>2]=120;aQ=dW(aM|0)|0;k=c[aO>>2]|0;c[aP+8>>2]=aQ;aQ=aN|0;c[(c[aQ>>2]|0)+(k<<2)>>2]=aP;k=c[aO>>2]|0;c[aO>>2]=k+1;if(k>>>0>1){aZ=k}else{break}while(1){k=aZ>>>1;j=c[aQ>>2]|0;ai=j+(k<<2)|0;aA=c[ai>>2]|0;aI=c[j+(aZ<<2)>>2]|0;if((c[aI+4>>2]|0)>>>0<=(c[aA+4>>2]|0)>>>0){break L1584}c[ai>>2]=aI;c[(c[aQ>>2]|0)+(aZ<<2)>>2]=aA;if(aZ>>>0>3){aZ=k}else{break}}}}while(0);if((a[405432]&1)!=0){aO=c[140620]|0;aN=(aO|0)!=0?aO:c[t>>2]|0;eS(aN|0,16640,(E=i,i=i+8|0,c[E>>2]=f,E)|0)|0;i=E;aN=c[140620]|0;aO=(aN|0)!=0?aN:c[t>>2]|0;a7(aO|0)|0}if(ga[c[(c[140913]|0)+20>>2]&127](c[140916]|0,aX,f)|0){break}aO=c[140620]|0;aN=(aO|0)!=0?aO:c[t>>2]|0;be(16320,44,1,aN|0)|0;aN=c[140620]|0;aO=(aN|0)!=0?aN:c[t>>2]|0;a7(aO|0)|0}}while(0);a[563888]=aS&1;a[563880]=aU&1}}while(0);if((c[140596]|0)!=0){aU=a[563679]|0;if((aU&1)==0){aS=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,40)|0;aX=563840;a$=(c[aX>>2]&0|aS&1|0)!=0|(c[aX+4>>2]&256|0)!=0;a0=a[563679]|0}else{a$=0;a0=aU}if((a0&1)==0){aU=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,41)|0;aX=563840;a1=(c[aX>>2]&0|aU&1|0)!=0|(c[aX+4>>2]&512|0)!=0;a2=a[563679]|0}else{a1=0;a2=a0}if((a2&1)==0){a2=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,42)|0;a0=563840;a3=(c[a0>>2]&0|a2&1|0)!=0|(c[a0+4>>2]&1024|0)!=0}else{a3=0}do{if(a$){if((a[564048]&1)!=0){n=1156;break}a0=c[140596]|0;a2=a0+4|0;c[a2>>2]=(((c[a2>>2]|0)+1|0)>>>0)%((c[a0+8>>2]|0)>>>0)|0;iv(a0)}else{n=1156}}while(0);L1614:do{if((n|0)==1156){do{if(a1){if((a[564040]&1)!=0){break}a0=c[140596]|0;a2=a0+4|0;aX=c[a2>>2]|0;if((aX|0)==0){a4=c[a0+8>>2]|0}else{a4=aX}c[a2>>2]=a4-1;iv(a0);break L1614}}while(0);if(!a3){break}if((a[564032]&1)!=0){break}a0=c[140596]|0;a2=a0|0;aX=(c[a2>>2]|0)+((c[a0+4>>2]|0)*12|0)+4|0;a[aX]=a[aX]&1^1;gs[c[21534]&63]();aX=a0+8|0;aU=c[aX>>2]|0;if((aU|0)!=0){aS=0;E=0;aZ=aU;while(1){aU=c[a2>>2]|0;if((a[aU+(E*12|0)+4|0]&1)==0){a5=aS;a6=aZ}else{gr[c[21532]&127](aS,1,c[aU+(E*12|0)+8>>2]|0);a5=aS+1|0;a6=c[aX>>2]|0}aU=E+1|0;if(aU>>>0<a6>>>0){aS=a5;E=aU;aZ=a6}else{break}}}iv(a0)}}while(0);a[564040]=a1&1;a[564048]=a$&1;a[564032]=a3&1}if((c[126108]|0)!=0){a3=a[563679]|0;if((a3&1)==0){a$=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,52)|0;a1=563840;a8=(c[a1>>2]&0|a$&1|0)!=0|(c[a1+4>>2]&1048576|0)!=0;a9=a[563679]|0}else{a8=0;a9=a3}if((a9&1)==0){a9=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,53)|0;a3=563840;ba=(c[a3>>2]&0|a9&1|0)!=0|(c[a3+4>>2]&2097152|0)!=0}else{ba=0}do{if(a8){if((a[564024]&1)!=0){n=1177;break}g0((gp[c[126105]&31]()|0)^1,1)}else{n=1177}}while(0);do{if((n|0)==1177){if(!ba){break}if((a[564016]&1)!=0){break}a3=gp[c[126108]&31]()|0;a9=gp[c[126106]&31]()|0;if((a3|0)==(-1|0)|(a3|0)==0){a1=c[140620]|0;a$=(a1|0)!=0?a1:c[t>>2]|0;be(18056,59,1,a$|0)|0;a$=c[140620]|0;a1=(a$|0)!=0?a$:c[t>>2]|0;a7(a1|0)|0;break}if(a9>>>0<a3>>>0){bb=((a9+1|0)>>>0)%((a3+1|0)>>>0)|0}else{bb=0}g1(bb)}}while(0);a[564024]=a8&1;a[564016]=ba&1}do{if((a[563679]&1)==0){ba=gm[c[(c[140914]|0)+12>>2]&127](c[140917]|0,37)|0;a8=563840;if((c[a8>>2]&0|ba&1|0)==0&(c[a8+4>>2]&32|0)==0){bc=0;break}if((a[563928]&1)!=0){bc=1;break}g_();bc=1}else{bc=0}}while(0);a[563928]=bc;i=d;return}function g6(a,d){a=a|0;d=d|0;var e=0;e=(c[126144]|0)-1|0;c[126144]=e;b[(c[126143]|0)+(e<<1)>>1]=d;d=(c[126144]|0)-1|0;c[126144]=d;b[(c[126143]|0)+(d<<1)>>1]=a;return}function g7(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+4096|0;d=b|0;L1665:do{if((a[562182]&1)!=0){switch(c[102392]|0){case 0:{e=a[405432]|0;if((e&1)==0){f=e}else{e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;be(20248,32,1,g|0)|0;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;f=a[405432]|0}if((f&1)==0){h=f}else{e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;eS(g|0,20056,(j=i,i=i+8|0,c[j>>2]=446442,j)|0)|0;i=j;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;h=a[405432]|0}if((h&1)!=0){e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;eS(g|0,19936,(j=i,i=i+8|0,c[j>>2]=450538,j)|0)|0;i=j;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0}hf(446442,0);hf(450538,1);break L1665;break};case 4:{e=a[405432]|0;if((e&1)==0){k=e}else{e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;be(18624,40,1,g|0)|0;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;k=a[405432]|0}if((k&1)==0){l=k}else{e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;eS(g|0,18472,(j=i,i=i+8|0,c[j>>2]=458730,j)|0)|0;i=j;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;l=a[405432]|0}if((l&1)!=0){e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;eS(g|0,18264,(j=i,i=i+8|0,c[j>>2]=462826,j)|0)|0;i=j;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0}hf(458730,768);hf(462826,1024);break L1665;break};case 1:{e=a[405432]|0;if((e&1)==0){m=e}else{e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;be(19768,32,1,g|0)|0;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;m=a[405432]|0}if((m&1)==0){n=m}else{e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;eS(g|0,20056,(j=i,i=i+8|0,c[j>>2]=446442,j)|0)|0;i=j;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;n=a[405432]|0}if((n&1)!=0){e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;eS(g|0,19936,(j=i,i=i+8|0,c[j>>2]=450538,j)|0)|0;i=j;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0}hf(446442,1280);hf(450538,1537);break L1665;break};case 2:case 3:{e=a[405432]|0;if((e&1)==0){o=e}else{e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;be(19256,30,1,g|0)|0;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;o=a[405432]|0}if((o&1)==0){p=o}else{e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;eS(g|0,19048,(j=i,i=i+8|0,c[j>>2]=446442,j)|0)|0;i=j;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;p=a[405432]|0}if((p&1)!=0){e=c[140620]|0;g=(e|0)!=0?e:c[t>>2]|0;eS(g|0,18856,(j=i,i=i+8|0,c[j>>2]=454634,j)|0)|0;i=j;g=c[140620]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0}hf(446442,256);hf(454634,512);break L1665;break};default:{break L1665}}}}while(0);p=c[138491]|0;if((p|0)!=0){yt(c[p>>2]|0);yt(c[p+12>>2]|0);yt(p)}c[138491]=0;yt(c[138492]|0);c[138492]=0;p=c[140596]|0;if((p|0)!=0){iu(p)}p=c[138495]|0;if((p|0)!=0){o=c[p>>2]|0;if((o|0)!=0){a_(o|0)|0}yt(c[p+4>>2]|0);yt(c[p+12>>2]|0);yt(p)}do{if((a[563557]&1)==0){if((a[563556]&1)!=0){break}p=d|0;if((a[401306]&1)==0){break}ho(p,466922,20760);o=hd(p)|0;if((a[405432]&1)==0){break}n=c[140620]|0;m=(n|0)!=0?n:c[t>>2]|0;n=o?20488:20400;eS(m|0,20576,(j=i,i=i+16|0,c[j>>2]=p,c[j+8>>2]=n,j)|0)|0;i=j;n=c[140620]|0;p=(n|0)!=0?n:c[t>>2]|0;a7(p|0)|0}}while(0);hy();d=c[126119]|0;do{if((d|0)!=0){if((a[563673]&1)!=0){break}gs[d&63]()}}while(0);hz();if((a[563675]&1)!=0){c[140916]=0}if((a[563676]&1)!=0){c[140915]=0}if((a[563677]&1)!=0){c[140917]=0}a[563675]=0;a[563676]=0;a[563677]=0;gs[c[21490]&63]();gs[c[21530]&63]();d=c[126128]|0;if((d|0)!=0){p=d+4104|0;if((c[p>>2]|0)==0){q=d|0}else{n=d+4100|0;m=d|0;o=0;while(1){l=c[n>>2]|0;hF(c[m>>2]|0,c[l+(o<<4)+4>>2]|0,c[(c[c[l+(o<<4)+8>>2]>>2]|0)+(c[l+(o<<4)+12>>2]<<3)>>2]|0);l=o+1|0;if(l>>>0<(c[p>>2]|0)>>>0){o=l}else{q=m;break}}}m=c[q>>2]|0;q=d+4|0;hG(m,q)|0;ij(c[126128]|0)}yB(499720,0,4800);if((a[405468]&1)==0){a[562484]=0;i=b;return}if((a[405432]&1)!=0){q=c[140620]|0;m=(q|0)!=0?q:c[t>>2]|0;eS(m|0,24352,(j=i,i=i+8|0,c[j>>2]=405469,j)|0)|0;i=j;m=c[140620]|0;q=(m|0)!=0?m:c[t>>2]|0;a7(q|0)|0}if((bP(405469)|0)<0){q=c[140620]|0;m=(q|0)!=0?q:c[t>>2]|0;eS(m|0,24056,(j=i,i=i+8|0,c[j>>2]=405469,j)|0)|0;i=j;j=c[140620]|0;m=(j|0)!=0?j:c[t>>2]|0;a7(m|0)|0}a[405468]=0;a[562484]=0;i=b;return}function g8(d,e){d=d|0;e=e|0;var f=0,g=0;f=c[126133]|0;c[126133]=f+1;b[(c[126142]|0)+(f<<1)>>1]=d;d=c[126133]|0;c[126133]=d+1;b[(c[126142]|0)+(d<<1)>>1]=e;e=c[126133]|0;if(e>>>0<(c[126134]|0)>>>0){return}if(gT(c[126142]|0,e)|0){g=a[405433]&1}else{g=0}a[405433]=g;c[126133]=0;return}function g9(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=f&255;f=c[138495]|0;do{if((f|0)!=0){if((a[558080]&1)==0){break}if((eM(l|0,2,1,c[f>>2]|0)|0)!=1){a[562179]=1;break}n=b[l>>1]|0;i=j;return n|0}}while(0);if(h>>>0<25|(m|0)==3){o=f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,6096,d,m,g,h)|0}else{o=0}l=(m|0)==1;f=(d|0)==0;do{if(l&f){p=563840;q=c[p>>2]|0;r=c[p+4>>2]|0;p=yN(1,0,h|0)|0;s=K;t=((q&p|0)!=0|(r&s|0)!=0)&1|o}else{if(!((m|0)==5&f)){t=o;break}t=(b[563848+(((h|0)==1|((g|0)==1?2:0))<<1)>>1]|0)+o&65535}}while(0);do{if(l){if((h-4|0)>>>0<=3){u=t;break}o=t<<16>>16!=0;do{if(o){if((a[562186+d|0]&1)==0){v=b[562194+(d<<1)>>1]|0;w=1<<h;break}else{g=1<<h;f=562194+(d<<1)|0;m=(e[f>>1]|0|g)&65535;b[f>>1]=m;v=m;w=g;break}}else{g=1<<h;m=562194+(d<<1)|0;f=(e[m>>1]|0)&(g^65535)&65535;b[m>>1]=f;v=f;w=g}}while(0);if((v&65535&w|0)==0){x=o}else{x=(((c[140553]|0)>>>0)%((c[91098]|0)>>>0)|0)>>>0<(c[91099]|0)>>>0&o}u=x&1}else{u=t}}while(0);t=c[138495]|0;if((t|0)==0){n=u;i=j;return n|0}if((a[558080]&1)!=0){n=u;i=j;return n|0}b[k>>1]=u;be(k|0,2,1,c[t>>2]|0)|0;n=u;i=j;return n|0}function ha(){var a=0,b=0,d=0;a=i;dJ(38880|0)|0;dJ(38800|0)|0;b=c[q>>2]|0;be(52512|0,11,1,b|0)|0;eS(b|0,52208|0,(d=i,i=i+16|0,c[d>>2]=51544,c[d+8>>2]=32,d)|0)|0;i=d;eS(b|0,51232|0,(d=i,i=i+8|0,c[d>>2]=50944,d)|0)|0;i=d;dJ(38880|0)|0;dJ(38752|0)|0;dJ(38696|0)|0;dJ(38576|0)|0;dJ(38440|0)|0;dJ(37944|0)|0;dJ(37816|0)|0;dJ(37720|0)|0;dJ(37384|0)|0;dJ(37200|0)|0;dJ(37048|0)|0;dJ(36864|0)|0;dJ(36696|0)|0;dJ(36624|0)|0;dJ(36544|0)|0;dJ(36240|0)|0;dJ(36112|0)|0;dw(35896|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;dw(35768|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;dw(35696|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;dJ(35560|0)|0;dJ(35472|0)|0;dJ(35344|0)|0;dJ(35248|0)|0;dJ(35200|0)|0;dJ(34888|0)|0;dJ(34744|0)|0;dJ(34624|0)|0;dJ(34488|0)|0;dJ(34456|0)|0;dJ(34352|0)|0;dJ(34280|0)|0;dJ(34208|0)|0;dJ(34120|0)|0;dJ(34072|0)|0;dJ(33752|0)|0;i=a;return}function hb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=dA(b|0,12144|0)|0;do{if((e|0)!=0){e6(e|0,0,2)|0;b=cy(e|0)|0;fe(e|0);f=ys(b+1|0)|0;if((f|0)==0){g=c[140620]|0;h=(g|0)!=0?g:c[t>>2]|0;be(35648|0,47,1,h|0)|0;h=c[140620]|0;g=(h|0)!=0?h:c[t>>2]|0;a7(g|0)|0;a_(e|0)|0;break}g=eM(f|0,1,b|0,e|0)|0;if((g|0)<(b|0)){h=c[140620]|0;i=(h|0)!=0?h:c[t>>2]|0;be(29160|0,44,1,i|0)|0;i=c[140620]|0;h=(i|0)!=0?i:c[t>>2]|0;a7(h|0)|0}c[d>>2]=f;a[f+b|0]=0;a_(e|0)|0;j=g;return j|0}}while(0);c[d>>2]=0;j=-1;return j|0}function hc(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[562485]&1)==0){d=c[140620]|0;e=(d|0)!=0?d:c[t>>2]|0;eS(e|0,35072,(e=i,i=i+16|0,c[e>>2]=45352,c[e+8>>2]=832,e)|0)|0;i=e;e=c[140620]|0;d=(e|0)!=0?e:c[t>>2]|0;a7(d|0)|0;cA(2)}else{f=1024;g=562487;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=1317;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==1317){fl(563512,1)}a[g]=0;if((a[h]|0)==0){fl(563512,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);fl(563512,1)}function hd(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a[405432]&1)!=0){e=c[140620]|0;f=(e|0)!=0?e:c[t>>2]|0;eS(f|0,21288,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;f=c[140620]|0;e=(f|0)!=0?f:c[t>>2]|0;a7(e|0)|0}e=gp[c[21506]&31]()|0;if((e|0)==0){h=0;i=d;return h|0}f=ys(e)|0;if((f|0)==0){j=c[140620]|0;k=(j|0)!=0?j:c[t>>2]|0;be(19072,70,1,k|0)|0;k=c[140620]|0;j=(k|0)!=0?k:c[t>>2]|0;a7(j|0)|0;h=0;i=d;return h|0}if((a[405432]&1)!=0){j=c[140620]|0;k=(j|0)!=0?j:c[t>>2]|0;eS(k|0,16696,(g=i,i=i+8|0,c[g>>2]=e,g)|0)|0;i=g;k=c[140620]|0;j=(k|0)!=0?k:c[t>>2]|0;a7(j|0)|0}do{if(gm[c[21508]&127](f,e)|0){j=dA(b|0,52200)|0;if((j|0)==0){l=1328;break}k=(be(f|0,1,e|0,j|0)|0)==(e|0);a_(j|0)|0;if(k){m=1}else{l=1328}}else{l=1328}}while(0);if((l|0)==1328){l=c[140620]|0;e=(l|0)!=0?l:c[t>>2]|0;eS(e|0,14312,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;g=c[140620]|0;b=(g|0)!=0?g:c[t>>2]|0;a7(b|0)|0;m=0}yt(f);h=m;i=d;return h|0}function he(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+16|0;e=d|0;f=d+8|0;if((a[405432]&1)!=0){g=c[140620]|0;h=(g|0)!=0?g:c[t>>2]|0;eS(h|0,11888,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;h=c[140620]|0;g=(h|0)!=0?h:c[t>>2]|0;a7(g|0)|0}c[e>>2]=0;g=hb(b,e)|0;if((g|0)<0){h=c[140620]|0;k=(h|0)!=0?h:c[t>>2]|0;eS(k|0,54120,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;b=c[140620]|0;k=(b|0)!=0?b:c[t>>2]|0;a7(k|0)|0;l=0;i=d;return l|0}if((a[405432]&1)!=0){k=c[140620]|0;b=(k|0)!=0?k:c[t>>2]|0;eS(b|0,51360,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;j=c[140620]|0;b=(j|0)!=0?j:c[t>>2]|0;a7(b|0)|0}c[f>>2]=0;L1864:do{if((a[401304]&1)==0){m=1351}else{if((a[405432]&1)!=0){b=c[140620]|0;j=(b|0)!=0?b:c[t>>2]|0;be(49008,36,1,j|0)|0;j=c[140620]|0;b=(j|0)!=0?j:c[t>>2]|0;a7(b|0)|0}switch(c[102392]|0){case 0:{n=0;o=1;break};case 1:{n=1280;o=1537;break};case 2:case 3:{n=256;o=512;break};case 4:{n=768;o=1024;break};default:{m=1351;break L1864}}b=f5[c[21526]&255](n)|0;j=f5[c[21526]&255](o)|0;if((b|0)==0){p=0;q=0}else{p=ys(b)|0;q=b}if((j|0)==0){r=0;s=0}else{b=ys(j)|0;c[f>>2]=b;r=b;s=j}do{if((p|0)!=0){j=f5[c[21528]&255](n)|0;if((j|0)==0){break}yE(p|0,j|0,q)|0}}while(0);j=f;if((r|0)==0){u=0;v=s;w=n;x=o;y=q;z=p;A=j;break}b=f5[c[21528]&255](o)|0;if((b|0)==0){u=r;v=s;w=n;x=o;y=q;z=p;A=j;break}yE(r|0,b|0,s)|0;u=r;v=s;w=n;x=o;y=q;z=p;A=j}}while(0);if((m|0)==1351){u=0;v=0;w=-1;x=-1;y=0;z=0;A=f}f=c[e>>2]|0;e=gm[c[21488]&127](f,g)|0;do{if(e){do{if((z|0)!=0){g=f5[c[21528]&255](w)|0;if((g|0)==0){break}yE(g|0,z|0,y)|0}}while(0);if((u|0)==0){break}g=f5[c[21528]&255](x)|0;if((g|0)==0){break}yE(g|0,u|0,v)|0}}while(0);if((z|0)==0){B=u}else{yt(z);B=c[A>>2]|0}if((B|0)!=0){yt(B)}yt(f);l=e;i=d;return l|0}function hf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+8200|0;f=e|0;g=e+4096|0;h=e+8192|0;j=f5[c[21526]&255](d)|0;k=f5[c[21528]&255](d)|0;if((k|0)==0|(j|0)==0){i=e;return}l=dA(b|0,52200)|0;do{if((l|0)!=0){m=(be(k|0,1,j|0,l|0)|0)==(j|0);a_(l|0)|0;if(!m){break}if((a[405432]&1)==0){i=e;return}m=c[140620]|0;n=(m|0)!=0?m:c[t>>2]|0;eS(n|0,44888,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;n=c[140620]|0;m=(n|0)!=0?n:c[t>>2]|0;a7(m|0)|0;i=e;return}}while(0);b=c[140620]|0;be(47400,42,1,((b|0)!=0?b:c[t>>2]|0)|0)|0;b=c[140620]|0;a7(((b|0)!=0?b:c[t>>2]|0)|0)|0;b=c[140620]|0;be(46304,46,1,((b|0)!=0?b:c[t>>2]|0)|0)|0;b=c[140620]|0;a7(((b|0)!=0?b:c[t>>2]|0)|0)|0;b=f|0;l=g|0;g=eb(46936)|0;do{if((g|0)!=0){b5(b|0,4096,26872,(o=i,i=i+8|0,c[o>>2]=g,o)|0)|0;i=o;fp(h|0)|0;m=bq(h|0)|0;dj(l|0,4096,26512,m|0)|0;m=yA(b|0)|0;n=m>>>0>4096?0:4096-m|0;L1919:do{if((n|0)==0){p=l;q=1382}else{r=n;s=f+m|0;u=l;while(1){v=r-1|0;if((v|0)==0){break}w=a[u]|0;a[s]=w;if(w<<24>>24==0){break L1919}else{r=v;s=s+1|0;u=u+1|0}}a[s]=0;p=u;q=1382}}while(0);do{if((q|0)==1382){if((a[p]|0)==0){break}else{x=p}do{x=x+1|0;}while((a[x]|0)!=0)}}while(0);switch(d|0){case 1:case 1537:{y=24464;break};case 512:{y=24232;break};case 768:{y=23912;break};case 1024:{y=23624;break};case 0:case 1280:case 256:{y=53784;break};default:{y=564064}}u=yA(b|0)|0;s=u>>>0>4096?0:4096-u|0;L1937:do{if((s|0)==0){z=y;q=1395}else{m=s;n=f+u|0;r=y;while(1){v=m-1|0;if((v|0)==0){break}w=a[r]|0;a[n]=w;if(w<<24>>24==0){break L1937}else{m=v;n=n+1|0;r=r+1|0}}a[n]=0;z=r;q=1395}}while(0);do{if((q|0)==1395){if((a[z]|0)==0){break}else{A=z}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);r=dA(b|0,52200)|0;if((r|0)==0){break}n=(be(k|0,1,j|0,r|0)|0)==(j|0);a_(r|0)|0;if(!n){break}n=c[140620]|0;r=(n|0)!=0?n:c[t>>2]|0;eS(r|0,26016,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;r=c[140620]|0;n=(r|0)!=0?r:c[t>>2]|0;a7(n|0)|0;i=e;return}}while(0);o=c[140620]|0;be(25400,57,1,((o|0)!=0?o:c[t>>2]|0)|0)|0;o=c[140620]|0;a7(((o|0)!=0?o:c[t>>2]|0)|0)|0;i=e;return}function hg(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;e=i;i=i+8280|0;f=e|0;g=e+48|0;h=e+56|0;j=e+4152|0;k=e+8248|0;l=e+8264|0;m=e+8272|0;L1954:do{if((a[442346]|0)!=0){if((a[499796]&1)!=0){break}n=cE(442346,46)|0;o=(n|0)==0?564064:n+1|0;if((o|0)==0){break}if((yH(o|0,43456)|0)!=0){break}a[405468]=1;o=h|0;n=j|0;p=hk(500312,49872)|0;do{if((p|0)!=0){c[g>>2]=0;q=hb(442346,g)|0;if((q|0)<22){r=c[140620]|0;s=(r|0)!=0?r:c[t>>2]|0;eS(s|0,36800,(u=i,i=i+8|0,c[u>>2]=107,u)|0)|0;i=u;s=c[140620]|0;r=(s|0)!=0?s:c[t>>2]|0;a7(r|0)|0;yt(c[g>>2]|0);v=0}else{r=q-22|0;L1964:do{if((r|0)>22){s=c[g>>2]|0;w=s+q|0;x=s+22|0;y=s+r|0;while(1){if((d[y+1|0]<<8|d[y]|d[y+2|0]<<16|d[y+3|0]<<24|0)==101010256){if((y+((d[y+21|0]<<8|d[y+20|0])+22)|0)==(w|0)){break}}z=y-1|0;if(z>>>0>x>>>0){y=z}else{A=1419;break L1964}}x=d[y+17|0]<<8|d[y+16|0]|d[y+18|0]<<16|d[y+19|0]<<24;w=s+x|0;L1972:do{if((d[s+(x+1)|0]<<8|d[w]|d[s+(x+2)|0]<<16|d[s+(x+3)|0]<<24|0)==33639248){z=p|0;B=p+4|0;C=w;L1974:while(1){D=a[C+10|0]|0;E=a[C+11|0]|0;F=a[C+16|0]|0;G=a[C+17|0]|0;H=a[C+18|0]|0;I=a[C+19|0]|0;J=d[C+21|0]<<8|d[C+20|0]|d[C+22|0]<<16|d[C+23|0]<<24;K=d[C+25|0]<<8|d[C+24|0]|d[C+26|0]<<16|d[C+27|0]<<24;L=d[C+29|0]<<8|d[C+28|0];M=d[C+33|0]<<8|d[C+32|0];N=d[C+31|0]<<8|d[C+30|0];yB(o|0,0,4096);if(L>>>0>4095){A=1425;break}O=C+46|0;yE(o|0,O|0,L)|0;O=d[C+43|0]<<8|d[C+42|0]|d[C+44|0]<<16|d[C+45|0]<<24;P=O+30+(d[s+(O+27)|0]<<8|d[s+(O+26)|0])+(d[s+(O+29)|0]<<8|d[s+(O+28)|0])|0;if((a[405432]&1)!=0){O=c[140620]|0;Q=(O|0)!=0?O:c[t>>2]|0;eS(Q|0,29536,(u=i,i=i+24|0,c[u>>2]=P,c[u+8>>2]=J,c[u+16>>2]=K,u)|0)|0;i=u;Q=c[140620]|0;O=(Q|0)!=0?Q:c[t>>2]|0;a7(O|0)|0}O=cE(o|0,46)|0;Q=(O|0)==0?564064:O+1|0;L1980:do{if((Q|0)!=0){O=c[B>>2]|0;R=0;while(1){if(R>>>0>=O>>>0){break L1980}if((yH(c[(c[z>>2]|0)+(R<<3)>>2]|0,Q|0)|0)==0){break L1974}else{R=R+1|0}}}}while(0);Q=L+46+N+M|0;R=C+Q|0;if((d[C+(Q+1)|0]<<8|d[R]|d[C+(Q+2)|0]<<16|d[C+(Q+3)|0]<<24|0)==33639248){C=R}else{break L1972}}if((A|0)==1425){C=c[140620]|0;z=(C|0)!=0?C:c[t>>2]|0;eS(z|0,36800,(u=i,i=i+8|0,c[u>>2]=141,u)|0)|0;i=u;z=c[140620]|0;C=(z|0)!=0?z:c[t>>2]|0;a7(C|0)|0;S=0;break L1964}C=(G&255)<<8|F&255|(H&255)<<16|(I&255)<<24;z=(E&255)<<8|D&255;B=s+P|0;R=cE(o|0,47)|0;hw(n,442346,(R|0)==0?o:R+1|0);if((z|0)==8){R=ys(K)|0;if((R|0)!=0){yB(f|0,0,48);Q=ys(43784)|0;do{if((Q|0)==0){O=c[140620]|0;T=(O|0)!=0?O:c[t>>2]|0;eS(T|0,36800,(u=i,i=i+8|0,c[u>>2]=61,u)|0)|0;i=u;T=c[140620]|0;O=(T|0)!=0?T:c[t>>2]|0;a7(O|0)|0}else{O=f+28|0;c[O>>2]=Q;c[Q>>2]=0;c[Q+10992>>2]=0;c[Q+10996>>2]=0;c[Q+43780>>2]=1;c[Q+11e3>>2]=1;c[Q+11004>>2]=0;c[Q+11008>>2]=-15;c[f>>2]=B;c[f+4>>2]=J;c[f+12>>2]=R;c[f+16>>2]=K;T=(kv(f)|0)==1;U=c[O>>2]|0;if((U|0)!=0){yt(U);c[O>>2]=0}if(!T){T=c[140620]|0;O=(T|0)!=0?T:c[t>>2]|0;eS(O|0,36800,(u=i,i=i+8|0,c[u>>2]=71,u)|0)|0;i=u;O=c[140620]|0;T=(O|0)!=0?O:c[t>>2]|0;a7(T|0)|0;break}if((K|0)==0){V=0}else{T=K;O=R;U=-1;while(1){W=T-1|0;X=d[O]|0;Y=c[8176+(((X^U)&15)<<2)>>2]^U>>>4;Z=Y>>>4^c[8176+((Y&15^X>>>4)<<2)>>2];if((W|0)==0){break}else{T=W;O=O+1|0;U=Z}}V=~Z}if((V|0)!=(C|0)){U=c[140620]|0;O=(U|0)!=0?U:c[t>>2]|0;eS(O|0,21696,(u=i,i=i+16|0,c[u>>2]=V,c[u+8>>2]=C,u)|0)|0;i=u;O=c[140620]|0;U=(O|0)!=0?O:c[t>>2]|0;a7(U|0)|0}U=dA(n|0,52200)|0;do{if((U|0)!=0){O=(be(R|0,1,K|0,U|0)|0)==(K|0);a_(U|0)|0;if(!O){break}yt(R);O=4096;T=442346;M=n;while(1){N=O-1|0;if((N|0)==0){break}L=a[M]|0;a[T]=L;if(L<<24>>24==0){S=1;break L1964}else{O=N;T=T+1|0;M=M+1|0}}a[T]=0;if((a[M]|0)==0){S=1;break L1964}else{_=M}while(1){O=_+1|0;if((a[O]|0)==0){S=1;break L1964}else{_=O}}}}while(0);U=c[140620]|0;M=(U|0)!=0?U:c[t>>2]|0;eS(M|0,36800,(u=i,i=i+8|0,c[u>>2]=81,u)|0)|0;i=u;M=c[140620]|0;U=(M|0)!=0?M:c[t>>2]|0;a7(U|0)|0}}while(0);yt(R)}C=c[140620]|0;Q=(C|0)!=0?C:c[t>>2]|0;eS(Q|0,36800,(u=i,i=i+8|0,c[u>>2]=175,u)|0)|0;i=u;Q=c[140620]|0;C=(Q|0)!=0?Q:c[t>>2]|0;a7(C|0)|0;S=0;break L1964}else if((z|0)==0){C=dA(n|0,52200)|0;if((C|0)!=0){Q=(be(B|0,1,K|0,C|0)|0)==(K|0);a_(C|0)|0;if(Q){S=1;break L1964}}Q=c[140620]|0;eS(((Q|0)!=0?Q:c[t>>2]|0)|0,36800,(u=i,i=i+8|0,c[u>>2]=165,u)|0)|0;i=u;Q=c[140620]|0;a7(((Q|0)!=0?Q:c[t>>2]|0)|0)|0;S=0;break L1964}else{Q=c[140620]|0;eS(((Q|0)!=0?Q:c[t>>2]|0)|0,36800,(u=i,i=i+8|0,c[u>>2]=178,u)|0)|0;i=u;Q=c[140620]|0;a7(((Q|0)!=0?Q:c[t>>2]|0)|0)|0;S=0;break L1964}}}while(0);s=c[140620]|0;be(24888,101,1,((s|0)!=0?s:c[t>>2]|0)|0)|0;s=c[140620]|0;a7(((s|0)!=0?s:c[t>>2]|0)|0)|0;s=c[140620]|0;eS(((s|0)!=0?s:c[t>>2]|0)|0,36800,(u=i,i=i+8|0,c[u>>2]=186,u)|0)|0;i=u;s=c[140620]|0;a7(((s|0)!=0?s:c[t>>2]|0)|0)|0;S=0}else{A=1419}}while(0);if((A|0)==1419){r=c[140620]|0;q=(r|0)!=0?r:c[t>>2]|0;eS(q|0,36800,(u=i,i=i+8|0,c[u>>2]=113,u)|0)|0;i=u;q=c[140620]|0;r=(q|0)!=0?q:c[t>>2]|0;a7(r|0)|0;S=0}yt(c[g>>2]|0);v=S}r=p+4|0;q=p|0;s=c[q>>2]|0;if((c[r>>2]|0)==0){$=s}else{w=0;x=s;while(1){yt(c[x+(w<<3)>>2]|0);s=w+1|0;y=c[q>>2]|0;if(s>>>0<(c[r>>2]|0)>>>0){w=s;x=y}else{$=y;break}}}yt($);yt(p);if(v){aa=4096;ab=405469;ac=442346}else{break}while(1){x=aa-1|0;if((x|0)==0){break}w=a[ac]|0;a[ab]=w;if(w<<24>>24==0){break L1954}else{aa=x;ab=ab+1|0;ac=ac+1|0}}a[ab]=0;if((a[ac]|0)==0){break L1954}else{ad=ac}while(1){ad=ad+1|0;if((a[ad]|0)==0){break L1954}}}}while(0);p=c[140620]|0;n=(p|0)!=0?p:c[t>>2]|0;eS(n|0,42272,(u=i,i=i+8|0,c[u>>2]=442346,u)|0)|0;i=u;n=c[140620]|0;p=(n|0)!=0?n:c[t>>2]|0;a7(p|0)|0;a[405468]=0;ae=0;i=e;return ae|0}}while(0);L2045:do{switch(b|0){case 1:{u=m|0;c[u>>2]=(a[442346]|0)!=0?442346:0;c[m+4>>2]=409576;if(hh(260,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 0:{if((a[563556]&1)==0){c[l>>2]=442346;if(hh(0,l,1)|0){break L2045}else{ae=0}i=e;return ae|0}if((a[499798]&1)==0){u=c[140620]|0;ad=(u|0)!=0?u:c[t>>2]|0;be(27616,78,1,ad|0)|0;ad=c[140620]|0;u=(ad|0)!=0?ad:c[t>>2]|0;a7(u|0)|0;ae=0;i=e;return ae|0}else{if(f5[c[21516]&255](0)|0){break L2045}else{ae=0}i=e;return ae|0}break};case 2:{u=m|0;c[u>>2]=(a[442346]|0)!=0?442346:0;c[m+4>>2]=413672;if(hh(257,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 3:{u=m|0;c[u>>2]=(a[442346]|0)!=0?442346:0;c[m+4>>2]=413672;if(hh(258,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 4:{u=k|0;c[u>>2]=(a[442346]|0)!=0?442346:0;c[k+4>>2]=(a[417768]|0)!=0?417768:0;c[k+8>>2]=(a[421864]|0)!=0?421864:0;if(hh(259,u,3)|0){break L2045}else{ae=0}i=e;return ae|0};default:{u=c[140620]|0;be(41256,39,1,((u|0)!=0?u:c[t>>2]|0)|0)|0;u=c[140620]|0;a7(((u|0)!=0?u:c[t>>2]|0)|0)|0;ae=0;i=e;return ae|0}}}while(0);ae=1;i=e;return ae|0}function hh(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=i;i=i+520|0;h=g|0;j=g+368|0;k=g+400|0;l=g+408|0;m=g+416|0;n=g+424|0;o=g+440|0;p=g+456|0;if((f|0)==0|f>>>0>4){q=0;i=g;return q|0}yB(n|0,0,16);yB(o|0,0,16);yB(p|0,0,64);do{if((a[471018]|0)==0){r=0}else{s=dA(471018,11144)|0;if((s|0)==0){r=0;break}e6(s|0,0,2)|0;u=(cy(s|0)|0)+2|0;fe(s|0);v=(u|0)==0?0:u;w=ys(v)|0;if((w|0)==0){a_(s|0)|0;r=0;break}if((c[w-4>>2]&3|0)!=0){yB(w|0,0,v|0)}v=w;x=w;while(1){if((eZ(s|0)|0)!=0){y=x;break}ci(x|0,u-x+v|0,s|0)|0;z=x+(yA(x|0)|0)|0;if((z|0)==0){y=0;break}else{x=z}}x=co(y|0,-1|0)|0;if((x|0)!=0){a[x]=0}a_(s|0)|0;if((a[405432]&1)==0){r=w;break}x=c[140620]|0;eS(((x|0)!=0?x:c[t>>2]|0)|0,28024,(A=i,i=i+8|0,c[A>>2]=471018,A)|0)|0;i=A;x=c[140620]|0;a7(((x|0)!=0?x:c[t>>2]|0)|0)|0;r=w}}while(0);y=(a[405432]&1)!=0;do{if((a[499732]&1)==0){if(y){x=c[140620]|0;v=(x|0)!=0?x:c[t>>2]|0;x=c[e>>2]|0;eS(v|0,40216,(A=i,i=i+8|0,c[A>>2]=x,A)|0)|0;i=A;x=c[140620]|0;v=(x|0)!=0?x:c[t>>2]|0;a7(v|0)|0}v=c[e>>2]|0;x=n|0;c[m>>2]=0;u=hb(v,m)|0;if((u|0)<1){B=u;C=0}else{L2097:do{if((a[487402]&1)==0){v=c[m>>2]|0;c[k>>2]=0;z=a[487403]|0;D=a[487404]|0;E=a[487405]|0;if(((D&1)+(z&1)+(E&1)|0)>1){F=c[140620]|0;G=(F|0)!=0?F:c[t>>2]|0;be(32328,77,1,G|0)|0;G=c[140620]|0;F=(G|0)!=0?G:c[t>>2]|0;a7(F|0)|0;H=u;I=v;break}F=(E|z)&1;G=((D|z)&1)!=0;if(((E|D)&1)!=0|(a[487406]|0)==0){J=1517}else{D=hb(487406,k)|0;if((D|0)>-1){K=31784;L=487406;M=4;N=D}else{J=1517}}do{if((J|0)==1517){if(!(F<<24>>24!=0|(a[491502]|0)==0)){D=hb(491502,k)|0;if((D|0)>-1){K=31384;L=491502;M=6;N=D;break}}if(!(G|(a[495598]|0)==0)){D=hb(495598,k)|0;if((D|0)>-1){K=30992;L=495598;M=8;N=D;break}}if((a[405432]&1)==0){H=u;I=v;break L2097}D=c[140620]|0;E=(D|0)!=0?D:c[t>>2]|0;be(30576,43,1,E|0)|0;E=c[140620]|0;D=(E|0)!=0?E:c[t>>2]|0;a7(D|0)|0;H=u;I=v;break L2097}}while(0);if((a[405432]&1)!=0){G=c[140620]|0;F=(G|0)!=0?G:c[t>>2]|0;eS(F|0,29960,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=L,A)|0)|0;i=A;F=c[140620]|0;G=(F|0)!=0?F:c[t>>2]|0;a7(G|0)|0}G=u<<2;c[l>>2]=G;F=ys(G)|0;if((F|0)==0){G=c[140620]|0;D=(G|0)!=0?G:c[t>>2]|0;be(29256,67,1,D|0)|0;D=c[140620]|0;G=(D|0)!=0?D:c[t>>2]|0;a7(G|0)|0;c[m>>2]=v;yt(c[k>>2]|0);H=u;I=v;break}G=c[k>>2]|0;D=f4[M&15](G,N,v,u,F,l)|0;if((D|0)==1){if((a[405432]&1)!=0){E=c[140620]|0;z=(E|0)!=0?E:c[t>>2]|0;eS(z|0,28808,(A=i,i=i+8|0,c[A>>2]=K,A)|0)|0;i=A;z=c[140620]|0;E=(z|0)!=0?z:c[t>>2]|0;a7(E|0)|0}yt(v);c[m>>2]=F;O=c[l>>2]|0;P=F}else{F=c[140620]|0;E=(F|0)!=0?F:c[t>>2]|0;eS(E|0,28440,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=D,A)|0)|0;i=A;D=c[140620]|0;E=(D|0)!=0?D:c[t>>2]|0;a7(E|0)|0;O=u;P=v}yt(G);H=O;I=P}else{H=u;I=c[m>>2]|0}}while(0);u=(H|0)==0;if((I|0)==0|u){Q=0}else{w=H;s=I;G=-1;while(1){E=w-1|0;D=d[s]|0;F=c[8176+(((D^G)&15)<<2)>>2]^G>>>4;R=F>>>4^c[8176+((F&15^D>>>4)<<2)>>2];if((E|0)==0){break}else{w=E;s=s+1|0;G=R}}Q=~R}c[102393]=Q;G=h;yB(G|0,0,360);s=h+324|0;yE(s|0,84600,32)|0;s=h+360|0;c[s>>2]=H;c[s+4>>2]=0;w=h+64|0;if(u){S=0}else{E=H;D=I;F=0;while(1){z=64-F|0;T=E>>>0<z>>>0?E:z;z=G+F|0;yE(z|0,D|0,T)|0;z=T+(c[w>>2]|0)|0;c[w>>2]=z;if((z|0)==64){hI(h);U=c[w>>2]|0}else{U=z}if((E|0)==(T|0)){S=U;break}else{E=E-T|0;D=D+T|0;F=U}}}c[w>>2]=S+1;a[h+S|0]=-128;F=c[w>>2]|0;if(F>>>0>56){yB(G+F|0,0,64-F|0);hI(h);V=c[w>>2]|0}else{V=F}yB(G+V|0,0,56-V|0);F=c[s>>2]|0;c[h+56>>2]=ex(F>>>29|c[s+4>>2]<<3|0)|0;c[h+60>>2]=ex(F<<3|0>>>29|0)|0;hI(h);c[j>>2]=ex(c[h+324>>2]|0)|0;c[j+4>>2]=ex(c[h+328>>2]|0)|0;c[j+8>>2]=ex(c[h+332>>2]|0)|0;c[j+12>>2]=ex(c[h+336>>2]|0)|0;c[j+16>>2]=ex(c[h+340>>2]|0)|0;c[j+20>>2]=ex(c[h+344>>2]|0)|0;c[j+24>>2]=ex(c[h+348>>2]|0)|0;c[j+28>>2]=ex(c[h+352>>2]|0)|0;F=j;D=0;do{b5(562316+(D<<1)|0,3,18712,(A=i,i=i+8|0,c[A>>2]=d[F+D|0]|0,A)|0)|0;i=A;D=D+1|0;}while(D>>>0<32);if((a[405432]&1)!=0){D=c[140620]|0;F=(D|0)!=0?D:c[t>>2]|0;D=c[102393]|0;eS(F|0,33184,(A=i,i=i+16|0,c[A>>2]=D,c[A+8>>2]=562316,A)|0)|0;i=A;D=c[140620]|0;F=(D|0)!=0?D:c[t>>2]|0;a7(F|0)|0}c[x>>2]=I;B=H;C=I}c[o>>2]=B;if((B|0)==-1){F=c[140620]|0;D=(F|0)!=0?F:c[t>>2]|0;be(39216,46,1,D|0)|0;D=c[140620]|0;F=(D|0)!=0?D:c[t>>2]|0;a7(F|0)|0;W=0;break}if((a[405432]&1)==0){X=C;Y=B;J=1553;break}F=c[140620]|0;D=(F|0)!=0?F:c[t>>2]|0;eS(D|0,37856,(A=i,i=i+8|0,c[A>>2]=B,A)|0)|0;i=A;D=c[140620]|0;F=(D|0)!=0?D:c[t>>2]|0;a7(F|0)|0;X=C;Y=B;J=1553}else{if(!y){X=0;Y=0;J=1553;break}F=c[140620]|0;D=(F|0)!=0?F:c[t>>2]|0;be(36160,72,1,D|0)|0;D=c[140620]|0;F=(D|0)!=0?D:c[t>>2]|0;a7(F|0)|0;X=0;Y=0;J=1553}}while(0);L2157:do{if((J|0)==1553){y=p|0;c[p>>2]=c[e>>2];c[p+4>>2]=X;c[p+8>>2]=Y;c[p+12>>2]=r;L2159:do{if(f>>>0>1){B=1;L2160:while(1){Z=e+(B<<2)|0;C=c[Z>>2]|0;do{if((C|0)==0){_=0}else{if((a[499732]&1)!=0){_=C;break}I=hb(C,n+(B<<2)|0)|0;c[o+(B<<2)>>2]=I;if((I|0)==-1){break L2160}_=c[Z>>2]|0}}while(0);c[p+(B<<4)>>2]=_;c[p+(B<<4)+4>>2]=c[n+(B<<2)>>2];c[p+(B<<4)+8>>2]=c[o+(B<<2)>>2];B=B+1|0;if(B>>>0>=f>>>0){break L2159}}B=c[140620]|0;eS(((B|0)!=0?B:c[t>>2]|0)|0,34832,(A=i,i=i+8|0,c[A>>2]=c[Z>>2],A)|0)|0;i=A;B=c[140620]|0;a7(((B|0)!=0?B:c[t>>2]|0)|0)|0;W=0;break L2157}}while(0);if((b|0)==0){if(f5[c[21516]&255](y)|0){W=1;break}}else{if(ga[c[21514]&127](b,y,f)|0){W=1;break}}x=c[140620]|0;B=(x|0)!=0?x:c[t>>2]|0;be(33704,42,1,B|0)|0;B=c[140620]|0;x=(B|0)!=0?B:c[t>>2]|0;a7(x|0)|0;W=0}}while(0);yt(c[n>>2]|0);yt(c[n+4>>2]|0);yt(c[n+8>>2]|0);yt(c[n+12>>2]|0);yt(r);q=W;i=g;return q|0}function hi(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=a[b+4|0]&1;f=a[d+4|0]&1;if(e<<24>>24==f<<24>>24){g=yH(c[b>>2]|0,c[d>>2]|0)|0;return g|0}else{g=(f&255)-(e&255)|0;return g|0}return 0}function hj(a,b){a=a|0;b=b|0;return yH(c[a>>2]|0,c[b>>2]|0)|0}function hk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+8|0;e=d|0;f=ys(12)|0;do{if((f|0)==0){g=0}else{do{if((c[f-4>>2]&3|0)==0){h=f+4|0;j=c[h>>2]|0;if(j>>>0<32){k=h;l=j;m=f;break}j=c[140620]|0;h=(j|0)!=0?j:c[t>>2]|0;eS(h|0,35072,(n=i,i=i+16|0,c[n>>2]=14128,c[n+8>>2]=69,n)|0)|0;i=n;h=c[140620]|0;j=(h|0)!=0?h:c[t>>2]|0;a7(j|0)|0;cA(2);return 0}else{yB(f|0,0,12);k=f+4|0;l=0;m=f}}while(0);j=f;h=c[j>>2]|0;o=h;p=yu(o,256)|0;if((p|0)==0){if((l|0)!=0){q=0;do{yt(c[h+(q<<3)>>2]|0);q=q+1|0;}while(q>>>0<l>>>0)}yt(o);yt(f);g=0;break}q=p;c[j>>2]=q;h=f+8|0;c[h>>2]=32;r=dW(a|0)|0;L2197:do{if((r|0)==0){s=0;u=l;v=q}else{w=eO(r|0,b|0,e|0)|0;L2199:do{if((w|0)!=0){x=w;y=q;z=l;A=32;while(1){if(z>>>0<A>>>0){B=y;C=A}else{D=A<<1;if(z>>>0>=D>>>0){break}E=yu(y,A<<4)|0;if((E|0)==0){s=r;u=z;v=y;break L2197}F=E;c[j>>2]=F;c[h>>2]=D;B=F;C=D}D=dW(x|0)|0;if((D|0)==0){s=r;u=z;v=B;break L2197}c[B+(z<<3)>>2]=D;D=c[k>>2]|0;F=c[j>>2]|0;c[F+(D<<3)+4>>2]=0;E=D+1|0;c[k>>2]=E;D=eO(0,b|0,e|0)|0;if((D|0)==0){break L2199}else{x=D;y=F;z=E;A=C}}A=c[140620]|0;eS(((A|0)!=0?A:c[t>>2]|0)|0,35072,(n=i,i=i+16|0,c[n>>2]=14128,c[n+8>>2]=69,n)|0)|0;i=n;A=c[140620]|0;a7(((A|0)!=0?A:c[t>>2]|0)|0)|0;cA(2);return 0}}while(0);yt(r);G=m;i=d;return G|0}}while(0);if((u|0)!=0){r=0;do{yt(c[v+(r<<3)>>2]|0);r=r+1|0;}while(r>>>0<u>>>0)}yt(v);yt(f);g=s}}while(0);yt(g);G=0;i=d;return G|0}function hl(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;i=i+8264|0;g=f|0;h=f+4096|0;j=f+4168|0;k=ys(12)|0;if((k|0)==0){l=0;i=f;return l|0}do{if((c[k-4>>2]&3|0)==0){m=k+4|0;n=c[m>>2]|0;if(n>>>0<32){o=m;p=n;q=k;break}n=c[140620]|0;m=(n|0)!=0?n:c[t>>2]|0;eS(m|0,35072,(r=i,i=i+16|0,c[r>>2]=14128,c[r+8>>2]=69,r)|0)|0;i=r;m=c[140620]|0;n=(m|0)!=0?m:c[t>>2]|0;a7(n|0)|0;cA(2);return 0}else{yB(k|0,0,12);o=k+4|0;p=0;q=k}}while(0);n=k;m=c[n>>2]|0;s=m;u=yu(s,256)|0;if((u|0)==0){if((p|0)!=0){v=0;do{yt(c[m+(v<<3)>>2]|0);v=v+1|0;}while(v>>>0<p>>>0)}yt(s);yt(k);l=0;i=f;return l|0}s=u;c[n>>2]=s;u=k+8|0;c[u>>2]=32;if((d|0)==0){w=0}else{w=hk(d,49872)|0}d=bT(b|0)|0;L2238:do{if((d|0)==0){v=c[140620]|0;m=(v|0)!=0?v:c[t>>2]|0;eS(m|0,20928,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;m=c[140620]|0;v=(m|0)!=0?m:c[t>>2]|0;a7(v|0)|0;x=p;y=s}else{v=cc(d|0)|0;L2240:do{if((v|0)!=0){m=j|0;z=(w|0)==0;A=g|0;B=w|0;C=w+4|0;D=h+8|0;E=v;F=s;G=p;H=32;L2242:while(1){I=E+4|0;J=cE(I|0,46)|0;K=(J|0)==0?564064:J+1|0;hm(m,b,I);J=a[E+1036|0]|0;do{if((J<<24>>24|0)==0|(J<<24>>24|0)==10){if((fk(m|0,h|0)|0)<0){L=0;M=1619;break}N=(c[D>>2]&61440|0)==16384;M=1618}else if((J<<24>>24|0)==4){N=1;M=1618}else{L=0;M=1619}}while(0);if((M|0)==1618){M=0;if(e|N^1){L=N;M=1619}else{O=F;P=G;Q=H}}L2249:do{if((M|0)==1619){M=0;if((db(I|0,36104)|0)==0){O=F;P=G;Q=H;break}if((db(I|0,24472)|0)==0){O=F;P=G;Q=H;break}L2253:do{if(!(L|z)){b5(A|0,4096,31832,(r=i,i=i+16|0,c[r>>2]=36104,c[r+8>>2]=K,r)|0)|0;i=r;J=c[C>>2]|0;R=0;while(1){if(R>>>0>=J>>>0){O=F;P=G;Q=H;break L2249}S=c[(c[B>>2]|0)+(R<<3)>>2]|0;if((yH(S|0,K|0)|0)==0){break L2253}if((yH(S|0,A|0)|0)==0){break}else{R=R+1|0}}}}while(0);R=L&1;if(G>>>0<H>>>0){T=F;U=H}else{J=H<<1;if(G>>>0>=J>>>0){M=1629;break L2242}S=yu(F,H<<4)|0;if((S|0)==0){V=F;M=1638;break L2242}W=S;c[n>>2]=W;c[u>>2]=J;T=W;U=J}J=dW(m|0)|0;if((J|0)==0){V=T;M=1638;break L2242}c[T+(G<<3)>>2]=J;J=c[o>>2]|0;W=c[n>>2]|0;c[W+(J<<3)+4>>2]=R;R=J+1|0;c[o>>2]=R;O=W;P=R;Q=U}}while(0);K=cc(d|0)|0;if((K|0)==0){break L2240}else{E=K;F=O;G=P;H=Q}}if((M|0)==1629){H=c[140620]|0;F=(H|0)!=0?H:c[t>>2]|0;eS(F|0,35072,(r=i,i=i+16|0,c[r>>2]=14128,c[r+8>>2]=69,r)|0)|0;i=r;F=c[140620]|0;H=(F|0)!=0?F:c[t>>2]|0;a7(H|0)|0;cA(2);return 0}else if((M|0)==1638){H=c[140620]|0;eS(((H|0)!=0?H:c[t>>2]|0)|0,20928,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;H=c[140620]|0;a7(((H|0)!=0?H:c[t>>2]|0)|0)|0;ft(d|0)|0;x=G;y=V;break L2238}}}while(0);ft(d|0)|0;if((w|0)==0){l=q;i=f;return l|0}v=w+4|0;H=w|0;F=c[H>>2]|0;if((c[v>>2]|0)==0){X=F}else{E=0;m=F;while(1){yt(c[m+(E<<3)>>2]|0);F=E+1|0;A=c[H>>2]|0;if(F>>>0<(c[v>>2]|0)>>>0){E=F;m=A}else{X=A;break}}}yt(X);yt(w);l=q;i=f;return l|0}}while(0);if((x|0)!=0){q=0;do{yt(c[y+(q<<3)>>2]|0);q=q+1|0;}while(q>>>0<x>>>0)}yt(y);yt(k);if((w|0)==0){l=0;i=f;return l|0}k=w+4|0;y=w|0;x=c[y>>2]|0;if((c[k>>2]|0)==0){Y=x}else{q=0;X=x;while(1){yt(c[X+(q<<3)>>2]|0);x=q+1|0;d=c[y>>2]|0;if(x>>>0<(c[k>>2]|0)>>>0){q=x;X=d}else{Y=d;break}}}yt(Y);yt(w);l=0;i=f;return l|0}function hm(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1656;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1656){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;p=h}while(1){g=o+1|0;d=p+1|0;if((a[g]|0)==0){n=d;break}else{o=g;p=d}}}}while(0);if(n>>>0>=4096){n=c[140620]|0;p=(n|0)!=0?n:c[t>>2]|0;eS(p|0,35072,(q=i,i=i+16|0,c[q>>2]=14128,c[q+8>>2]=573,q)|0)|0;i=q;p=c[140620]|0;n=(p|0)!=0?p:c[t>>2]|0;a7(n|0)|0;cA(2)}if((a[b]|0)!=0){ht(b)}n=yA(b|0)|0;p=n>>>0>4096?0:4096-n|0;L2308:do{if((p|0)==0){r=0;s=e;l=1667}else{o=p;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){u=h;break L2308}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;r=h;s=j;l=1667}}while(0);do{if((l|0)==1667){if((a[s]|0)==0){u=r;break}else{v=s;w=r}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){u=b;break}else{v=e;w=b}}}}while(0);if((u+n|0)>>>0<4096){i=f;return}else{f=c[140620]|0;n=(f|0)!=0?f:c[t>>2]|0;eS(n|0,35072,(q=i,i=i+16|0,c[q>>2]=14128,c[q+8>>2]=578,q)|0)|0;i=q;q=c[140620]|0;n=(q|0)!=0?q:c[t>>2]|0;a7(n|0)|0;cA(2)}}function hn(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+4096|0;g=f|0;h=4096;j=0;k=g;l=d;while(1){d=h-1|0;if((d|0)==0){m=1675;break}n=a[l]|0;a[k]=n;if(n<<24>>24==0){o=j;break}else{h=d;j=j+1|0;k=k+1|0;l=l+1|0}}do{if((m|0)==1675){a[k]=0;if((a[l]|0)==0){o=j;break}else{p=l;q=j}while(1){h=p+1|0;d=q+1|0;if((a[h]|0)==0){o=d;break}else{p=h;q=d}}}}while(0);if(o>>>0>=4096){o=c[140620]|0;q=(o|0)!=0?o:c[t>>2]|0;eS(q|0,35072,(r=i,i=i+16|0,c[r>>2]=14128,c[r+8>>2]=409,r)|0)|0;i=r;q=c[140620]|0;o=(q|0)!=0?q:c[t>>2]|0;a7(o|0)|0;cA(2)}o=cE(g|0,46)|0;if((o|0)==0){s=4096;u=0;v=b;w=g}else{a[o]=0;s=4096;u=0;v=b;w=g}while(1){g=s-1|0;if((g|0)==0){m=1683;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=u;break}else{s=g;u=u+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1683){a[v]=0;if((a[w]|0)==0){x=u;break}else{y=w;z=u}while(1){s=y+1|0;g=z+1|0;if((a[s]|0)==0){x=g;break}else{y=s;z=g}}}}while(0);if(x>>>0>=4096){x=c[140620]|0;z=(x|0)!=0?x:c[t>>2]|0;eS(z|0,35072,(r=i,i=i+16|0,c[r>>2]=14128,c[r+8>>2]=414,r)|0)|0;i=r;z=c[140620]|0;x=(z|0)!=0?z:c[t>>2]|0;a7(x|0)|0;cA(2)}x=yA(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2347:do{if((z|0)==0){A=0;B=e;m=1692}else{y=z;u=0;w=b+x|0;v=e;while(1){g=y-1|0;if((g|0)==0){break}s=a[v]|0;a[w]=s;if(s<<24>>24==0){C=u;break L2347}else{y=g;u=u+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=u;B=v;m=1692}}while(0);do{if((m|0)==1692){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[140620]|0;x=(f|0)!=0?f:c[t>>2]|0;eS(x|0,35072,(r=i,i=i+16|0,c[r>>2]=14128,c[r+8>>2]=415,r)|0)|0;i=r;r=c[140620]|0;x=(r|0)!=0?r:c[t>>2]|0;a7(x|0)|0;cA(2)}}function ho(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1700;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1700){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;p=h}while(1){g=o+1|0;d=p+1|0;if((a[g]|0)==0){n=d;break}else{o=g;p=d}}}}while(0);if(n>>>0>=4096){n=c[140620]|0;p=(n|0)!=0?n:c[t>>2]|0;eS(p|0,35072,(q=i,i=i+16|0,c[q>>2]=14128,c[q+8>>2]=420,q)|0)|0;i=q;p=c[140620]|0;n=(p|0)!=0?p:c[t>>2]|0;a7(n|0)|0;cA(2)}n=yA(b|0)|0;p=n>>>0>4096?0:4096-n|0;L2373:do{if((p|0)==0){r=0;s=e;l=1709}else{o=p;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){u=h;break L2373}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;r=h;s=j;l=1709}}while(0);do{if((l|0)==1709){if((a[s]|0)==0){u=r;break}else{v=s;w=r}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){u=b;break}else{v=e;w=b}}}}while(0);if((u+n|0)>>>0<4096){i=f;return}else{f=c[140620]|0;n=(f|0)!=0?f:c[t>>2]|0;eS(n|0,35072,(q=i,i=i+16|0,c[q>>2]=14128,c[q+8>>2]=421,q)|0)|0;i=q;q=c[140620]|0;n=(q|0)!=0?q:c[t>>2]|0;a7(n|0)|0;cA(2)}}function hp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;ht(b);f=cE(438250,47)|0;g=(f|0)==0?438250:f+1|0;f=yA(b|0)|0;h=f>>>0>4096?0:4096-f|0;L2388:do{if((h|0)==0){j=0;k=g;l=1719}else{m=h;n=0;o=b+f|0;p=g;while(1){q=m-1|0;if((q|0)==0){break}r=a[p]|0;a[o]=r;if(r<<24>>24==0){s=n;break L2388}else{m=q;n=n+1|0;o=o+1|0;p=p+1|0}}a[o]=0;j=n;k=p;l=1719}}while(0);do{if((l|0)==1719){if((a[k]|0)==0){s=j;break}else{u=k;v=j}while(1){g=u+1|0;h=v+1|0;if((a[g]|0)==0){s=h;break}else{u=g;v=h}}}}while(0);if((s+f|0)>>>0>=4096){f=c[140620]|0;s=(f|0)!=0?f:c[t>>2]|0;eS(s|0,35072,(w=i,i=i+16|0,c[w>>2]=14128,c[w+8>>2]=457,w)|0)|0;i=w;s=c[140620]|0;f=(s|0)!=0?s:c[t>>2]|0;a7(f|0)|0;cA(2)}f=yA(b|0)|0;s=f>>>0>4096?0:4096-f|0;L2402:do{if((s|0)==0){x=0;y=d;l=1728}else{v=s;u=0;j=b+f|0;k=d;while(1){p=v-1|0;if((p|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=u;break L2402}else{v=p;u=u+1|0;j=j+1|0;k=k+1|0}}a[j]=0;x=u;y=k;l=1728}}while(0);do{if((l|0)==1728){if((a[y]|0)==0){z=x;break}else{A=y;B=x}while(1){d=A+1|0;b=B+1|0;if((a[d]|0)==0){z=b;break}else{A=d;B=b}}}}while(0);if((z+f|0)>>>0<4096){i=e;return}else{e=c[140620]|0;f=(e|0)!=0?e:c[t>>2]|0;eS(f|0,35072,(w=i,i=i+16|0,c[w>>2]=14128,c[w+8>>2]=458,w)|0)|0;i=w;w=c[140620]|0;f=(w|0)!=0?w:c[t>>2]|0;a7(f|0)|0;cA(2)}}function hq(){var b=0,d=0.0,e=0.0,f=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0,p=0.0;b=i;a[499797]=0;d=+h[62470];if(d<=0.0){i=b;return}e=+h[62471];if(e<=0.0){i=b;return}f=+g[77834];j=f;if(+V(+(1.0-d/j))>.05000000074505806){if((a[405432]&1)==0){k=d;l=f}else{m=c[140620]|0;n=(m|0)!=0?m:c[t>>2]|0;f=d;eS(n|0,31688,(o=i,i=i+16|0,h[o>>3]=j,h[o+8>>3]=f,o)|0)|0;i=o;n=c[140620]|0;m=(n|0)!=0?n:c[t>>2]|0;a7(m|0)|0;k=+h[62470];l=+g[77834]}do{if(k>l){a[499797]=1;if((a[405432]&1)==0){break}m=c[140620]|0;n=(m|0)!=0?m:c[t>>2]|0;be(31320,57,1,n|0)|0;n=c[140620]|0;m=(n|0)!=0?n:c[t>>2]|0;a7(m|0)|0}}while(0);p=+h[62471]}else{p=e*(j/d)}d=p;g[79904]=d;if((a[405432]&1)!=0){m=c[140620]|0;n=(m|0)!=0?m:c[t>>2]|0;p=d;eS(n|0,30944,(o=i,i=i+8|0,h[o>>3]=p,o)|0)|0;i=o;o=c[140620]|0;n=(o|0)!=0?o:c[t>>2]|0;a7(n|0)|0}n=c[140916]|0;if((n|0)==0){i=b;return}if((a[499797]&1)!=0){f3[c[(c[140913]|0)+8>>2]&1023](n,1);i=b;return}o=(a[563680]&1)!=0;if((a[405434]&1)!=0){f3[c[(c[140913]|0)+8>>2]&1023](n,(a[303112]&1)==0|o)}n=c[140915]|0;if((a[405433]&1)!=0&(n|0)!=0){f3[c[(c[140912]|0)+16>>2]&1023](n,(a[323720]&1)==0|o)}c[126134]=o?c[126135]|0:c[126136]|0;i=b;return}function hr(){var a=0,b=0,d=0;a=c[140964]|0;if((a|0)==0){b=0;return b|0}d=c[a+4>>2]|0;if((d|0)==0){b=0;return b|0}b=f5[d&255](c[140916]|0)|0;return b|0}function hs(a){a=a|0;var b=0,d=0,e=0;b=c[140964]|0;if((b|0)==0){d=0;return d|0}e=c[b+8>>2]|0;if((e|0)==0){d=0;return d|0}d=gm[e&127](c[140916]|0,a)|0;return d|0}function ht(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=cE(b|0,47)|0;g=yA(b|0)|0;if((f|0)==0){h=g>>>0>4096?0:4096-g|0;L2470:do{if((h|0)==0){j=0;k=19896;l=1788}else{m=b+g|0;do{if((h|0)==1){n=19896;o=m;p=0}else{q=b+(g+1)|0;a[m]=47;if((h|0)==2){n=19897;o=q;p=1;break}a[q]=0;r=1;break L2470}}while(0);a[o]=0;j=p;k=n;l=1788}}while(0);do{if((l|0)==1788){if((a[k]|0)==0){r=j;break}else{s=k;u=j}while(1){n=s+1|0;p=u+1|0;if((a[n]|0)==0){r=p;break}else{s=n;u=p}}}}while(0);if((r+g|0)>>>0<4096){i=d;return}else{r=c[140620]|0;u=(r|0)!=0?r:c[t>>2]|0;eS(u|0,35072,(v=i,i=i+16|0,c[v>>2]=14128,c[v+8>>2]=450,v)|0)|0;i=v;u=c[140620]|0;r=(u|0)!=0?u:c[t>>2]|0;a7(r|0)|0;cA(2)}}if((f|0)==(b+(g-1)|0)){i=d;return}g=e|0;r=a[f]|0;a[g]=r;a[e+1|0]=0;e=yA(b|0)|0;f=e>>>0>4096?0:4096-e|0;L2488:do{if((f|0)==0){w=0;x=g;y=r;l=1780}else{u=f;s=0;j=b+e|0;k=g;while(1){p=u-1|0;if((p|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=s;break L2488}else{u=p;s=s+1|0;j=j+1|0;k=k+1|0}}a[j]=0;w=s;x=k;y=a[k]|0;l=1780}}while(0);do{if((l|0)==1780){if(y<<24>>24==0){z=w;break}else{A=x;B=w}while(1){g=A+1|0;b=B+1|0;if((a[g]|0)==0){z=b;break}else{A=g;B=b}}}}while(0);if((z+e|0)>>>0<4096){i=d;return}else{d=c[140620]|0;e=(d|0)!=0?d:c[t>>2]|0;eS(e|0,35072,(v=i,i=i+16|0,c[v>>2]=14128,c[v+8>>2]=447,v)|0)|0;i=v;v=c[140620]|0;e=(v|0)!=0?v:c[t>>2]|0;a7(e|0)|0;cA(2)}}function hu(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=cE(d|0,47)|0;h=(g|0)==0?d:g+1|0;L2503:do{if((e|0)==0){j=0;k=h;l=1801}else{g=e;d=0;m=b;n=h;while(1){o=g-1|0;if((o|0)==0){break}p=a[n]|0;a[m]=p;if(p<<24>>24==0){q=d;break L2503}else{g=o;d=d+1|0;m=m+1|0;n=n+1|0}}a[m]=0;j=d;k=n;l=1801}}while(0);do{if((l|0)==1801){if((a[k]|0)==0){q=j;break}else{r=k;s=j}while(1){h=r+1|0;b=s+1|0;if((a[h]|0)==0){q=b;break}else{r=h;s=b}}}}while(0);if(q>>>0<e>>>0){i=f;return}else{f=c[140620]|0;e=(f|0)!=0?f:c[t>>2]|0;eS(e|0,35072,(e=i,i=i+16|0,c[e>>2]=14128,c[e+8>>2]=470,e)|0)|0;i=e;e=c[140620]|0;f=(e|0)!=0?e:c[t>>2]|0;a7(f|0)|0;cA(2)}}function hv(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=4096;g=0;h=b;j=d;while(1){d=f-1|0;if((d|0)==0){k=1809;break}l=a[j]|0;a[h]=l;if(l<<24>>24==0){m=g;break}else{f=d;g=g+1|0;h=h+1|0;j=j+1|0}}do{if((k|0)==1809){a[h]=0;if((a[j]|0)==0){m=g;break}else{n=j;o=g}while(1){f=n+1|0;d=o+1|0;if((a[f]|0)==0){m=d;break}else{n=f;o=d}}}}while(0);if(m>>>0>=4096){m=c[140620]|0;o=(m|0)!=0?m:c[t>>2]|0;eS(o|0,35072,(p=i,i=i+16|0,c[p>>2]=14128,c[p+8>>2]=475,p)|0)|0;i=p;o=c[140620]|0;m=(o|0)!=0?o:c[t>>2]|0;a7(m|0)|0;cA(2)}if((yA(b|0)|0)>>>0<2){i=e;return}m=cE(b|0,47)|0;if((m|0)==0){b5(b|0,3,54032,(p=i,i=i+8|0,c[p>>2]=19896,p)|0)|0;i=p;i=e;return}else{a[m+1|0]=0;i=e;return}}function hw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;if((a[e]|0)==47){g=4096;h=0;j=b;k=e;while(1){l=g-1|0;if((l|0)==0){m=1824;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=h;break}else{g=l;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((m|0)==1824){a[j]=0;if((a[k]|0)==0){o=h;break}else{p=k;q=h}while(1){g=p+1|0;l=q+1|0;if((a[g]|0)==0){o=l;break}else{p=g;q=l}}}}while(0);if(o>>>0<4096){i=f;return}else{o=c[140620]|0;q=(o|0)!=0?o:c[t>>2]|0;eS(q|0,35072,(r=i,i=i+16|0,c[r>>2]=14128,c[r+8>>2]=562,r)|0)|0;i=r;q=c[140620]|0;o=(q|0)!=0?q:c[t>>2]|0;a7(o|0)|0;cA(2)}}else{s=4096;u=0;v=b;w=d}while(1){d=s-1|0;if((d|0)==0){m=1830;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=u;break}else{s=d;u=u+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1830){a[v]=0;if((a[w]|0)==0){x=u;break}else{y=w;z=u}while(1){s=y+1|0;d=z+1|0;if((a[s]|0)==0){x=d;break}else{y=s;z=d}}}}while(0);if(x>>>0>=4096){x=c[140620]|0;z=(x|0)!=0?x:c[t>>2]|0;eS(z|0,35072,(r=i,i=i+16|0,c[r>>2]=14128,c[r+8>>2]=565,r)|0)|0;i=r;z=c[140620]|0;x=(z|0)!=0?z:c[t>>2]|0;a7(x|0)|0;cA(2)}do{if((yA(b|0)|0)>>>0>=2){x=cE(b|0,47)|0;if((x|0)==0){b5(b|0,3,54032,(r=i,i=i+8|0,c[r>>2]=19896,r)|0)|0;i=r;break}else{a[x+1|0]=0;break}}}while(0);x=yA(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2566:do{if((z|0)==0){A=0;B=e;m=1843}else{y=z;u=0;w=b+x|0;v=e;while(1){d=y-1|0;if((d|0)==0){break}s=a[v]|0;a[w]=s;if(s<<24>>24==0){C=u;break L2566}else{y=d;u=u+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=u;B=v;m=1843}}while(0);do{if((m|0)==1843){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[140620]|0;x=(f|0)!=0?f:c[t>>2]|0;eS(x|0,35072,(r=i,i=i+16|0,c[r>>2]=14128,c[r+8>>2]=567,r)|0)|0;i=r;r=c[140620]|0;x=(r|0)!=0?r:c[t>>2]|0;a7(x|0)|0;cA(2)}}function hx(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0,s=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+24|0;d=b|0;a[563675]=(c[140916]|0)==0|0;a[563676]=(c[140915]|0)==0|0;a[563677]=(c[140917]|0)==0|0;hq();c[140560]=0;e=d;L2581:do{if((a[311341]|0)!=0){f=hl(311341,34712,0)|0;c[140577]=f;do{if((f|0)!=0){j=f+4|0;if((c[j>>2]|0)==0){yt(c[f>>2]|0);yt(f);break}c[140578]=0;dO(c[f>>2]|0,c[j>>2]|0,8,30);j=c[140577]|0;if((c[j+4>>2]|0)==0){break L2581}else{k=0;l=j}while(1){if((a[405432]&1)==0){m=l}else{j=c[140620]|0;n=(j|0)!=0?j:c[t>>2]|0;j=c[(c[l>>2]|0)+(k<<3)>>2]|0;eS(n|0,33672,(o=i,i=i+8|0,c[o>>2]=j,o)|0)|0;i=o;j=c[140620]|0;n=(j|0)!=0?j:c[t>>2]|0;a7(n|0)|0;m=c[140577]|0}n=k+1|0;if(n>>>0<(c[m+4>>2]|0)>>>0){k=n;l=m}else{break L2581}}}}while(0);c[140577]=0;c[140578]=0}}while(0);m=c[124936]|0;l=c[124937]|0;k=(m>>>0>l>>>0?m:l)-1|0;l=k>>>1|k;k=l>>>2|l;l=k>>>4|k;k=l>>>8|l;l=((k>>>16|k)+1|0)>>>8;k=(a[553792]&1)==0?l>>>0>1?l:1:c[138453]|0;p=+g[75782];g[124944]=p;do{if(p<0.0){q=+g[124938];if(q>0.0){if((a[303132]&1)==0){r=1862}else{s=q}}else{r=1862}if((r|0)==1862){s=+((c[124934]|0)>>>0>>>0)/+((c[124935]|0)>>>0>>>0)}g[124944]=s;if((a[405432]&1)==0){break}l=c[140620]|0;m=(l|0)!=0?l:c[t>>2]|0;q=s;eS(m|0,11664,(o=i,i=i+8|0,h[o>>3]=q,o)|0)|0;i=o;m=c[140620]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0}}while(0);do{if((a[303096]&1)==0){if((a[303125]&1)==0){r=~~+bZ(+(+((c[124934]|0)>>>0>>>0)*+g[75772]));u=r;v=~~+bZ(+(+((c[124935]|0)>>>0>>>0)*+g[75773]));break}else{s=+((c[124935]|0)>>>0>>>0);p=+(~~+bZ(+(s*+g[124944]))>>>0>>>0);r=~~+bZ(+(+g[75772]*p));u=r;v=~~+bZ(+(s*+g[75773]));break}}else{u=c[75776]|0;v=c[75777]|0}}while(0);r=(a[405432]&1)==0;do{if((u|0)==0|(v|0)==0){if(r){break}l=c[140620]|0;m=(l|0)!=0?l:c[t>>2]|0;be(51048,30,1,m|0)|0;m=c[140620]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0}else{if(r){break}l=c[140620]|0;m=(l|0)!=0?l:c[t>>2]|0;eS(m|0,53976,(o=i,i=i+16|0,c[o>>2]=u,c[o+8>>2]=v,o)|0)|0;i=o;m=c[140620]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0}}while(0);c[140923]=0;c[140921]=0;c[140922]=0;r=k<<8;yt(c[140940]|0);yt(c[140943]|0);yt(c[140944]|0);yt(c[140947]|0);yt(c[140950]|0);yt(c[140948]|0);yt(c[140954]|0);yB(563696,0,128);yt(c[140956]|0);c[140956]=0;if((c[124948]|0)==0){l=c[140620]|0;m=(l|0)!=0?l:c[t>>2]|0;be(35976,120,1,m|0)|0;m=c[140620]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0;c[140932]=1;c[140930]=2;c[140931]=3;if(!(iG(563696)|0)){l=c[140620]|0;m=(l|0)!=0?l:c[t>>2]|0;be(48656,53,1,m|0)|0;m=c[140620]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0;hB(47328)}l=ag(r,r)|0;r=l<<1;if(l>>>0>65535){w=(l&2147418112|0)==(l|0)?r:-1}else{w=r}r=ys(w)|0;do{if((r|0)!=0){if((c[r-4>>2]&3|0)==0){break}yB(r|0,0,w|0)}}while(0);c[140956]=r}c[e>>2]=c[1966];c[e+4>>2]=c[1967];c[e+8>>2]=c[1968];c[e+12>>2]=c[1969];c[e+16>>2]=c[1970];c[d>>2]=u;c[d+4>>2]=v;a[d+8|0]=a[303096]&1;if((a[303112]&1)==0){x=0}else{x=a[499797]&1^1}a[d+9|0]=x;a[d+10|0]=a[303125]&1;a[d+11|0]=a[303124]&1;c[d+12>>2]=k;if((a[553792]&1)==0){y=(c[124948]|0)==1|0}else{y=1}a[d+16|0]=y;y=c[140914]|0;k=ga[c[c[140913]>>2]&127](d,563656,563668)|0;c[140916]=k;if((k|0)==0){d=c[140620]|0;x=(d|0)!=0?d:c[t>>2]|0;be(46168,62,1,x|0)|0;x=c[140620]|0;d=(x|0)!=0?x:c[t>>2]|0;a7(d|0)|0;hB(47328)}c[140964]=0;d=c[140913]|0;x=c[d+56>>2]|0;if((x|0)==0){z=d}else{f3[x&1023](k,563856);z=c[140913]|0}k=c[z+40>>2]|0;z=c[124945]|0;if((k|0)!=0&(z|0)!=0){f3[k&1023](c[140916]|0,z)}z=c[140964]|0;do{if((z|0)!=0){k=c[z+12>>2]|0;x=c[75784]|0;if(!((k|0)!=0&(x|0)!=4)){break}f3[k&1023](c[140916]|0,x)}}while(0);do{if((c[140914]|0)==0){if((a[405432]&1)!=0){z=c[140620]|0;x=(z|0)!=0?z:c[t>>2]|0;be(44624,101,1,x|0)|0;x=c[140620]|0;z=(x|0)!=0?x:c[t>>2]|0;a7(z|0)|0}c[140914]=y;if((y|0)==0){z=c[140620]|0;x=(z|0)!=0?z:c[t>>2]|0;be(42144,59,1,x|0)|0;x=c[140620]|0;z=(x|0)!=0?x:c[t>>2]|0;a7(z|0)|0;hB(47328)}z=gp[c[y>>2]&31]()|0;c[140917]=z;if((z|0)!=0){break}z=c[140620]|0;x=(z|0)!=0?z:c[t>>2]|0;be(43320,59,1,x|0)|0;x=c[140620]|0;z=(x|0)!=0?x:c[t>>2]|0;a7(z|0)|0;hB(47328)}}while(0);y=c[140958]|0;if((y|0)!=0){z=y+24|0;x=y+12|0;k=c[x>>2]|0;if((c[z>>2]|0)==0){A=k}else{d=0;v=k;while(1){yt(c[v+(d*136|0)>>2]|0);yt(c[v+(d*136|0)+8>>2]|0);k=d+1|0;u=c[x>>2]|0;if(k>>>0<(c[z>>2]|0)>>>0){d=k;v=u}else{A=u;break}}}yt(A);A=c[y+4>>2]|0;if((A|0)!=0){f3[c[A>>2]&1023](c[y>>2]|0,0)}yt(y);c[140958]=0}do{if((a[364400]|0)!=0){y=iF()|0;c[140958]=y;if((y|0)!=0){break}y=c[140620]|0;A=(y|0)!=0?y:c[t>>2]|0;be(37472,45,1,A|0)|0;A=c[140620]|0;y=(A|0)!=0?A:c[t>>2]|0;a7(y|0)|0}}while(0);y=553784;c[y>>2]=0;c[y+4>>2]=0;y=c[126112]|0;if((a[563674]&1)==0&(y|0)!=0){gs[y&63]()}a[563674]=0;do{if((c[140915]|0)==0){y=~~(+g[100322]*65536.0);A=ys(y<<1)|0;c[126142]=A;if((A|0)==0){A=c[140620]|0;v=(A|0)!=0?A:c[t>>2]|0;eS(v|0,35072,(o=i,i=i+16|0,c[o>>2]=24424,c[o+8>>2]=497,o)|0)|0;i=o;v=c[140620]|0;A=(v|0)!=0?v:c[t>>2]|0;a7(A|0)|0;cA(2)}c[126136]=512;c[126135]=2048;c[126134]=512;A=ys(8192)|0;c[126143]=A;if((A|0)==0){A=c[140620]|0;v=(A|0)!=0?A:c[t>>2]|0;eS(v|0,35072,(o=i,i=i+16|0,c[o>>2]=24424,c[o+8>>2]=504,o)|0)|0;i=o;v=c[140620]|0;A=(v|0)!=0?v:c[t>>2]|0;a7(A|0)|0;cA(2)}c[126145]=4096;if((a[319604]&1)==0){a[405433]=0;break}A=ga[c[c[140912]>>2]&127]((a[319620]|0)!=0?319620:0,c[79902]|0,c[80929]|0)|0;c[140915]=A;do{if((A|0)==0){v=c[140620]|0;d=(v|0)!=0?v:c[t>>2]|0;be(20808,85,1,d|0)|0;d=c[140620]|0;v=(d|0)!=0?d:c[t>>2]|0;a7(v|0)|0;a[405433]=0}else{if((a[405433]&1)==0){break}v=c[(c[140912]|0)+24>>2]|0;if((v|0)==0){break}if(!(f5[v&255](A)|0)){break}a[504560]=1}}while(0);do{if((a[323720]&1)==0){if((a[405433]&1)==0){break}f3[c[(c[140912]|0)+16>>2]&1023](c[140915]|0,1);c[126134]=c[126135]}}while(0);s=+((c[79902]|0)>>>0>>>0)/+g[79904];h[63069]=s;h[63075]=s;A=a[327828]|0;v=c[126130]|0;do{if((v|0)!=0){d=c[126131]|0;if((d|0)==0){break}f2[c[d+8>>2]&1023](v)}}while(0);c[126131]=1288;v=je(s)|0;c[126130]=v;if((v|0)==0){c[126131]=0;v=c[140620]|0;d=(v|0)!=0?v:c[t>>2]|0;v=A<<24>>24!=0?327828:16408;eS(d|0,18880,(o=i,i=i+8|0,c[o>>2]=v,o)|0)|0;i=o;v=c[140620]|0;d=(v|0)!=0?v:c[t>>2]|0;a7(d|0)|0;a[405433]=0}d=ys(16384)|0;c[126132]=d;if((d|0)==0){d=c[140620]|0;v=(d|0)!=0?d:c[t>>2]|0;eS(v|0,35072,(o=i,i=i+16|0,c[o>>2]=24424,c[o+8>>2]=561,o)|0)|0;i=o;v=c[140620]|0;d=(v|0)!=0?v:c[t>>2]|0;a7(d|0)|0;cA(2)}c[126133]=0;if(+((c[79902]|0)>>>0>>>0)>=+g[79904]*16.0){d=c[140620]|0;v=(d|0)!=0?d:c[t>>2]|0;eS(v|0,35072,(o=i,i=i+16|0,c[o>>2]=24424,c[o+8>>2]=565,o)|0)|0;i=o;v=c[140620]|0;d=(v|0)!=0?v:c[t>>2]|0;a7(d|0)|0;cA(2)}d=ys(y<<2)|0;c[126141]=d;if((d|0)==0){d=c[140620]|0;v=(d|0)!=0?d:c[t>>2]|0;eS(v|0,35072,(o=i,i=i+16|0,c[o>>2]=24424,c[o+8>>2]=566,o)|0)|0;i=o;v=c[140620]|0;d=(v|0)!=0?v:c[t>>2]|0;a7(d|0)|0;cA(2)}a[504596]=0;L2714:do{if((c[126103]|0)==0){if((a[405433]&1)==0){break}if((a[327817]&1)==0){break}d=c[140912]|0;v=c[d+36>>2]|0;do{if((v|0)!=0){if((c[d+32>>2]|0)==0){break}c[126152]=f5[v&255](c[140915]|0)|0;a[504596]=1;break L2714}}while(0);v=c[140620]|0;d=(v|0)!=0?v:c[t>>2]|0;be(14e3,97,1,d|0)|0;d=c[140620]|0;v=(d|0)!=0?d:c[t>>2]|0;a7(v|0)|0}}while(0);s=+g[81956];g[126153]=s;g[126154]=+X(10.0,+(s/20.0));y=537392;c[y>>2]=0;c[y+4>>2]=0;if((a[405433]&1)==0){break}if(!((a[504561]&1)==0&(c[126103]|0)!=0)){break}y=c[(c[140912]|0)+12>>2]|0;A=c[140915]|0;f5[y&255](A)|0}}while(0);if((a[563680]&1)==0){B=504504;C=0;D=0;E=B|0;c[E>>2]=C;F=B+4|0;c[F>>2]=D;i=b;return}o=c[140916]|0;if((a[405434]&1)!=0&(o|0)!=0){f3[c[(c[140913]|0)+8>>2]&1023](o,1)}o=c[140915]|0;if((a[405433]&1)!=0&(o|0)!=0){f3[c[(c[140912]|0)+16>>2]&1023](o,1)}c[126134]=c[126135];B=504504;C=0;D=0;E=B|0;c[E>>2]=C;F=B+4|0;c[F>>2]=D;i=b;return}function hy(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0,q=0,r=0,s=0,u=0.0,v=0;b=i;d=c[140915]|0;e=c[140912]|0;if((d|0)!=0&(e|0)!=0){f2[c[e+20>>2]&1023](d)}yt(c[126142]|0);c[126142]=0;c[126133]=0;yt(c[126143]|0);c[126143]=0;if((a[319604]&1)==0){a[405433]=0;i=b;return}d=c[126131]|0;e=c[126130]|0;if((d|0)!=0&(e|0)!=0){f2[c[d+8>>2]&1023](e)}c[126131]=0;c[126130]=0;yt(c[126132]|0);c[126132]=0;yt(c[126141]|0);c[126141]=0;e=537392;d=c[e>>2]|0;f=c[e+4>>2]|0;e=0;g=f>>>0<e>>>0|f>>>0==e>>>0&d>>>0<8192>>>0?d:8192;if(g>>>0<3){i=b;return}else{j=1;k=0;l=0}do{l=yL(c[504624+(j<<2)>>2]|0,0,l,k)|0;k=K;j=j+1|0;}while(j>>>0<g>>>0);j=g-1|0;d=yW(l,k,j,0)|0;k=d;d=1;l=0;e=0;do{f=k-(c[504624+(d<<2)>>2]|0)|0;e=yL(ag(f,f)|0,0,e,l)|0;l=K;d=d+1|0;}while(d>>>0<g>>>0);m=+W(+((+(e>>>0)+ +(l>>>0)*4294967296.0)/+((g-2|0)>>>0>>>0)));l=c[126152]|0;n=+(l>>>0>>>0);o=+(k|0)/n;k=(l*3|0)>>>2;e=l>>>2;l=0;d=0;f=1;while(1){p=c[504624+(f<<2)>>2]|0;if(p>>>0<k>>>0){q=(p>>>0<=e>>>0)+d|0;r=l}else{q=d;r=l+1|0}p=f+1|0;if(p>>>0<g>>>0){l=r;d=q;f=p}else{break}}f=a[405432]|0;if((f&1)==0){s=f}else{f=c[140620]|0;d=(f|0)!=0?f:c[t>>2]|0;u=(1.0-o)*100.0;o=+(~~m>>>0>>>0)/n*100.0;eS(d|0,33032,(v=i,i=i+16|0,h[v>>3]=u,h[v+8>>3]=o,v)|0)|0;i=v;d=c[140620]|0;f=(d|0)!=0?d:c[t>>2]|0;a7(f|0)|0;s=a[405432]|0}if((s&1)==0){i=b;return}s=c[140620]|0;o=+(j>>>0>>>0);eS(((s|0)!=0?s:c[t>>2]|0)|0,32184,(v=i,i=i+16|0,h[v>>3]=+(r>>>0>>>0)*100.0/o,h[v+8>>3]=+(q>>>0>>>0)*100.0/o,v)|0)|0;i=v;v=c[140620]|0;a7(((v|0)!=0?v:c[t>>2]|0)|0)|0;i=b;return}function hz(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0.0,v=0.0;b=i;d=c[140958]|0;if((d|0)!=0){e=d+24|0;f=d+12|0;g=c[f>>2]|0;if((c[e>>2]|0)==0){j=g}else{k=0;l=g;while(1){yt(c[l+(k*136|0)>>2]|0);yt(c[l+(k*136|0)+8>>2]|0);g=k+1|0;m=c[f>>2]|0;if(g>>>0<(c[e>>2]|0)>>>0){k=g;l=m}else{j=m;break}}}yt(j);j=c[d+4>>2]|0;if((j|0)!=0){f3[c[j>>2]&1023](c[d>>2]|0,0)}yt(d);c[140958]=0;yB(563840,0,16)}d=c[140917]|0;j=c[140916]|0;l=c[140914]|0;if((d|0)!=(j|0)&(l|0)!=0){f2[c[l+16>>2]&1023](d);n=c[140916]|0}else{n=j}j=c[140913]|0;if((n|0)!=0&(j|0)!=0){f2[c[j+24>>2]&1023](n)}yt(c[140940]|0);yt(c[140943]|0);yt(c[140944]|0);yt(c[140947]|0);yt(c[140950]|0);yt(c[140948]|0);yt(c[140954]|0);yB(563696,0,128);yt(c[140956]|0);c[140956]=0;n=c[140577]|0;if((n|0)!=0){j=n+4|0;d=n|0;l=c[d>>2]|0;if((c[j>>2]|0)==0){o=l}else{k=0;e=l;while(1){yt(c[e+(k<<3)>>2]|0);l=k+1|0;f=c[d>>2]|0;if(l>>>0<(c[j>>2]|0)>>>0){k=l;e=f}else{o=f;break}}}yt(o);yt(n)}c[140577]=0;c[140578]=0;if((a[311340]&1)!=0){if((a[405432]&1)==0){i=b;return}n=c[140620]|0;o=(n|0)!=0?n:c[t>>2]|0;be(41152,66,1,o|0)|0;o=c[140620]|0;n=(o|0)!=0?o:c[t>>2]|0;a7(n|0)|0;i=b;return}n=553784;o=c[n+4>>2]|0;e=0;if(o>>>0<e>>>0|o>>>0==e>>>0&(c[n>>2]|0)>>>0<4096>>>0){if((a[405432]&1)==0){i=b;return}n=c[140620]|0;e=(n|0)!=0?n:c[t>>2]|0;eS(e|0,40040,(p=i,i=i+8|0,c[p>>2]=4096,p)|0)|0;i=p;e=c[140620]|0;n=(e|0)!=0?e:c[t>>2]|0;a7(n|0)|0;i=b;return}else{q=0;r=0;s=0}do{n=537400+(q<<3)|0;s=yL(c[n>>2]|0,c[n+4>>2]|0,s,r)|0;r=K;q=q+1|0;}while(q>>>0<2048);q=yT(s,r,2048,0)|0;r=K;s=0;n=0;e=0;do{o=537400+(e<<3)|0;k=yM(c[o>>2]|0,c[o+4>>2]|0,q,r)|0;o=K;j=yV(k,o,k,o)|0;n=yL(j,K,n,s)|0;s=K;e=e+1|0;}while(e>>>0<2048);u=+(q>>>0)+ +(r|0)*4294967296.0;if((a[405432]&1)==0){i=b;return}v=+W(+((+(n>>>0)+ +(s|0)*4294967296.0)/2047.0))/u;s=c[140620]|0;eS(((s|0)!=0?s:c[t>>2]|0)|0,39056,(p=i,i=i+24|0,h[p>>3]=1.0e6/u,h[p+8>>3]=v*100.0,c[p+16>>2]=2048,p)|0)|0;i=p;p=c[140620]|0;a7(((p|0)!=0?p:c[t>>2]|0)|0)|0;i=b;return}function hA(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=c[a+4>>2]|0;if((b|0)!=0){d=b;while(1){yt(c[d+4>>2]|0);yt(c[d+8>>2]|0);b=c[d+12>>2]|0;yt(d|0);if((b|0)==0){break}else{d=b}}}d=c[a+16>>2]|0;if((d|0)!=0){b=d;while(1){yt(c[b>>2]|0);d=c[b+4>>2]|0;yt(b);if((d|0)==0){break}else{b=d}}}yt(c[a>>2]|0);yt(a);return}function hB(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[562485]&1)==0){d=c[140620]|0;e=(d|0)!=0?d:c[t>>2]|0;eS(e|0,35072,(e=i,i=i+16|0,c[e>>2]=45352,c[e+8>>2]=832,e)|0)|0;i=e;e=c[140620]|0;d=(e|0)!=0?e:c[t>>2]|0;a7(d|0)|0;cA(2)}else{f=1024;g=562487;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=2034;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==2034){fl(563512,1)}a[g]=0;if((a[h]|0)==0){fl(563512,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);fl(563512,1)}function hC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+4112|0;f=e|0;g=e+8|0;h=e+4104|0;j=ys(20)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){yB(j|0,0,20)}l=j;if((b|0)==0){k=l;i=e;return k|0}m=dW(b|0)|0;n=j;c[n>>2]=m;if((m|0)==0){yt(j);k=0;i=e;return k|0}o=j+12|0;c[o>>2]=d;d=dA(b|0,11144)|0;if((d|0)==0){yt(m);yt(j);k=0;i=e;return k|0}if((eZ(d|0)|0)==0){m=j+8|0;b=j+4|0;p=g|0;q=j+16|0;do{j=ys(16)|0;do{if((j|0)!=0){if((c[j-4>>2]&3|0)==0){break}yB(j|0,0,16)}}while(0);r=j;s=ys(9)|0;u=b7(d|0)|0;v=0;w=8;x=s;while(1){if((u|0)==(-1|0)|(u|0)==10){break}if((v|0)==(w|0)){s=w<<1;y=s;z=yu(x,s|1)|0}else{y=w;z=x}a[z+v|0]=u&255;u=b7(d|0)|0;v=v+1|0;w=y;x=z}a[x+v|0]=0;if((x|0)!=0){w=co(x|0,35)|0;if((w|0)!=0){a[w]=0}u=c[o>>2]|0;do{if((w|0)==(x|0)){if(u>>>0>=16){A=2105;break}if((b0(x+1|0,39016,8)|0)!=0){B=x;A=2106;break}s=x+9|0;while(1){D=s+1|0;if((bp(a[s]|0)|0)==0){break}else{s=D}}E=a[s]|0;if((E<<24>>24|0)==0){break}else if((E<<24>>24|0)==34){E=eO(D|0,35872,f|0)|0;if((E|0)==0){break}F=dW(E|0)|0}else{E=eO(s|0,34600,f|0)|0;if((E|0)==0){break}F=dW(E|0)|0}if((F|0)==0){break}E=c[q>>2]|0;G=ys(8)|0;do{if((G|0)!=0){if((c[G-4>>2]&3|0)==0){break}H=G;I=H|0;C=0;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=H+4|0;C=0;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255}}while(0);s=G;c[G>>2]=dW(F|0)|0;if((E|0)==0){c[q>>2]=s}else{I=E;do{J=I+4|0;I=c[J>>2]|0;}while((I|0)!=0);c[J>>2]=s}L2906:do{if((a[F]|0)==126){I=eb(46936)|0;E=4096;G=p;H=(I|0)!=0?I:564064;while(1){I=E-1|0;if((I|0)==0){A=2079;break}K=a[H]|0;a[G]=K;if(K<<24>>24==0){break}else{E=I;G=G+1|0;H=H+1|0}}do{if((A|0)==2079){A=0;a[G]=0;if((a[H]|0)==0){break}else{L=H}do{L=L+1|0;}while((a[L]|0)!=0)}}while(0);H=F+1|0;G=yA(p|0)|0;E=G>>>0>4096?0:4096-G|0;if((E|0)==0){M=H}else{I=E;E=g+G|0;G=H;while(1){H=I-1|0;if((H|0)==0){break}K=a[G]|0;a[E]=K;if(K<<24>>24==0){break L2906}else{I=H;E=E+1|0;G=G+1|0}}a[E]=0;M=G}if((a[M]|0)==0){break}else{N=M}do{N=N+1|0;}while((a[N]|0)!=0)}else{hw(p,c[n>>2]|0,F)}}while(0);s=hC(p,(c[o>>2]|0)+1|0)|0;if((s|0)==0){yt(F);break}G=c[b>>2]|0;if((G|0)==0){E=s+4|0;I=c[E>>2]|0;if((I|0)==0){O=0}else{H=I;do{a[H|0]=1;H=c[H+12>>2]|0;}while((H|0)!=0);O=c[E>>2]|0}c[b>>2]=O;P=O}else{H=G;do{Q=H+12|0;H=c[Q>>2]|0;}while((H|0)!=0);H=s+4|0;G=c[H>>2]|0;if((G|0)==0){R=0}else{E=G;do{a[E|0]=1;E=c[E+12>>2]|0;}while((E|0)!=0);R=c[H>>2]|0}c[Q>>2]=R;P=c[b>>2]|0}c[s+4>>2]=0;if((P|0)==0){S=0}else{E=P;while(1){G=c[E+12>>2]|0;if((G|0)==0){S=E;break}else{E=G}}}c[m>>2]=S;hA(s);yt(F)}else{if(u>>>0>15){A=2105}else{B=x;A=2106}}}while(0);if((A|0)==2105){A=0;u=c[t>>2]|0;be(37600,58,1,u|0)|0;B=x;A=2106}L2952:do{if((A|0)==2106){while(1){A=0;if((bp(a[B]|0)|0)==0){break}else{B=B+1|0;A=2106}}s=ys(9)|0;if((fu(a[B]|0)|0)==0){T=B;U=s;V=0}else{u=B;w=s;s=8;v=0;while(1){if((v|0)==(s|0)){E=v<<1;W=E;X=yu(w,E|1)|0}else{W=s;X=w}E=u+1|0;H=v+1|0;a[X+v|0]=a[u]|0;if((fu(a[E]|0)|0)==0){T=E;U=X;V=H;break}else{u=E;w=X;s=W;v=H}}}a[U+V|0]=0;v=j+4|0;c[v>>2]=U;s=T;while(1){Y=s+1|0;if((bp(a[s]|0)|0)==0){break}else{s=Y}}do{if((a[s]|0)==61){w=Y;while(1){Z=w+1|0;if((bp(a[w]|0)|0)==0){break}else{w=Z}}u=a[w]|0;if((u<<24>>24|0)==0){A=2120;break}else if((u<<24>>24|0)==34){u=eO(Z|0,35872,h|0)|0;if((u|0)==0){A=2120;break}_=dW(u|0)|0}else{u=eO(w|0,34600,h|0)|0;if((u|0)==0){A=2120;break}_=dW(u|0)|0}c[j+8>>2]=_;if((_|0)==0){break}if((c[b>>2]|0)==0){c[b>>2]=r;c[m>>2]=r;break L2952}else{c[(c[m>>2]|0)+12>>2]=r;c[m>>2]=r;break L2952}}else{A=2120}}while(0);if((A|0)==2120){A=0;c[j+8>>2]=0}c[v>>2]=0;yt(U)}}while(0);yt(x)}if((r|0)!=(c[m>>2]|0)){yt(j)}}while((eZ(d|0)|0)==0)}a_(d|0)|0;k=l;i=e;return k|0}function hD(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+8192|0;g=f|0;h=f+4096|0;j=b+4|0;while(1){k=c[j>>2]|0;if((k|0)==0){l=0;m=2178;break}if((db(d|0,c[k+4>>2]|0)|0)==0){break}else{j=k+12|0}}if((m|0)==2178){i=f;return l|0}j=c[k+8>>2]|0;k=a[j]|0;do{if((k<<24>>24|0)==58){if((a[j+1|0]|0)!=47){n=e;o=j;p=4096;m=2167;break}d=h|0;b=g|0;a[d]=0;q=ck()|0;r=0;while(1){if(r>>>0>=3){m=2153;break}s=c[8160+(r<<2)>>2]|0;b5(b|0,4096,46248,(u=i,i=i+16|0,c[u>>2]=q,c[u+8>>2]=s,u)|0)|0;i=u;v=fv(b|0,d|0,4095)|0;if((v|0)>-1){m=2152;break}else{r=r+1|0}}if((m|0)==2152){a[h+v|0]=0}else if((m|0)==2153){r=c[140620]|0;be(44752,78,1,((r|0)!=0?r:c[t>>2]|0)|0)|0;r=c[140620]|0;a7(((r|0)!=0?r:c[t>>2]|0)|0)|0}if((a[405432]&1)!=0){r=c[140620]|0;b=(r|0)!=0?r:c[t>>2]|0;eS(b|0,34e3,(u=i,i=i+8|0,c[u>>2]=d,u)|0)|0;i=u;b=c[140620]|0;r=(b|0)!=0?b:c[t>>2]|0;a7(r|0)|0}do{if((yA(d|0)|0)>>>0<2){w=4096;x=0;y=e;z=d}else{r=cE(d|0,47)|0;if((r|0)==0){b5(d|0,3,54032,(u=i,i=i+8|0,c[u>>2]=19896,u)|0)|0;i=u;w=4096;x=0;y=e;z=d;break}else{a[r+1|0]=0;w=4096;x=0;y=e;z=d;break}}}while(0);while(1){d=w-1|0;if((d|0)==0){m=2162;break}r=a[z]|0;a[y]=r;if(r<<24>>24==0){A=x;break}else{w=d;x=x+1|0;y=y+1|0;z=z+1|0}}do{if((m|0)==2162){a[y]=0;if((a[z]|0)==0){A=x;break}else{B=z;C=x}while(1){d=B+1|0;r=C+1|0;if((a[d]|0)==0){A=r;break}else{B=d;C=r}}}}while(0);if(A>>>0<4096){D=A;E=j+2|0;m=2166;break}else{l=0;i=f;return l|0}}else if((k<<24>>24|0)==126){r=eb(46936)|0;if((r|0)==0){n=e;o=j;p=4096;m=2167;break}else{F=4096;G=0;H=e;I=r}while(1){r=F-1|0;if((r|0)==0){m=2144;break}d=a[I]|0;a[H]=d;if(d<<24>>24==0){J=G;break}else{F=r;G=G+1|0;H=H+1|0;I=I+1|0}}do{if((m|0)==2144){a[H]=0;if((a[I]|0)==0){J=G;break}else{K=I;L=G}while(1){r=K+1|0;d=L+1|0;if((a[r]|0)==0){J=d;break}else{K=r;L=d}}}}while(0);if(J>>>0<4096){D=J;E=j+1|0;m=2166;break}else{l=0;i=f;return l|0}}else{n=e;o=j;p=4096;m=2167}}while(0);if((m|0)==2166){if((D|0)==4096){M=0;N=E;O=0;m=2171}else{n=e+D|0;o=E;p=4096-D|0;m=2167}}L3040:do{if((m|0)==2167){D=p;E=0;e=n;j=o;while(1){J=D-1|0;if((J|0)==0){break}L=a[j]|0;a[e]=L;if(L<<24>>24==0){P=E;Q=p;break L3040}else{D=J;E=E+1|0;e=e+1|0;j=j+1|0}}a[e]=0;M=E;N=j;O=p;m=2171}}while(0);do{if((m|0)==2171){if((a[N]|0)==0){P=M;Q=O;break}else{R=N;S=M}while(1){p=R+1|0;o=S+1|0;if((a[p]|0)==0){P=o;Q=O;break}else{R=p;S=o}}}}while(0);l=P>>>0<Q>>>0;i=f;return l|0}function hE(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;while(1){g=c[f>>2]|0;if((g|0)==0){h=0;i=2196;break}if((db(d|0,c[g+4>>2]|0)|0)==0){break}else{f=g+12|0}}if((i|0)==2196){return h|0}i=c[g+8>>2]|0;if((yH(i|0,53312)|0)==0){a[e]=1;h=1;return h|0}if((yH(i|0,24336)|0)==0){a[e]=1;h=1;return h|0}if((yH(i|0,31792)|0)==0){a[e]=0;h=1;return h|0}if((yH(i|0,47016)|0)!=0){h=0;return h|0}a[e]=0;h=1;return h|0}function hF(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;b=c[f>>2]|0;L3076:do{if((b|0)==0){g=0}else{h=b;while(1){if((a[h|0]&1)==0){if((db(d|0,c[h+4>>2]|0)|0)==0){break}}i=c[h+12>>2]|0;if((i|0)==0){g=h;break L3076}else{h=i}}i=h+8|0;yt(c[i>>2]|0);c[i>>2]=dW(e|0)|0;return}}while(0);b=ys(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)==0){break}yB(b|0,0,16)}}while(0);i=b;c[b+4>>2]=dW(d|0)|0;c[b+8>>2]=dW(e|0)|0;if((g|0)==0){c[f>>2]=i;return}else{c[g+12>>2]=i;return}}function hG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=(d|0)!=0;do{if(f){g=dA(d|0,76e3)|0;if((g|0)==0){h=0}else{j=g;break}i=e;return h|0}else{j=c[q>>2]|0}}while(0);d=c[b+16>>2]|0;if((d|0)!=0){g=d;do{eS(j|0,46096,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0)|0;i=k;g=c[g+4>>2]|0;}while((g|0)!=0)}g=c[b+4>>2]|0;if((g|0)!=0){b=g;do{if((a[b|0]&1)==0){g=c[b+4>>2]|0;d=c[b+8>>2]|0;eS(j|0,44528,(k=i,i=i+16|0,c[k>>2]=g,c[k+8>>2]=d,k)|0)|0;i=k}b=c[b+12>>2]|0;}while((b|0)!=0)}if(!f){h=1;i=e;return h|0}a_(j|0)|0;h=1;i=e;return h|0}function hH(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a5=0,a6=0,a8=0,a9=0,ba=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0.0,bI=0.0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0;e=i;i=i+12848|0;f=e|0;h=e+72|0;j=e+144|0;k=e+4312|0;l=e+4320|0;m=e+8416|0;n=e+12512|0;o=e+12520|0;p=e+12528|0;q=e+12536|0;r=e+12544|0;s=e+12552|0;u=e+12560|0;v=e+12568|0;w=e+12576|0;x=e+12584|0;y=e+12592|0;z=e+12600|0;A=e+12608|0;B=e+12616|0;C=e+12624|0;D=e+12632|0;E=e+12640|0;F=e+12648|0;G=e+12656|0;H=e+12664|0;I=e+12672|0;J=e+12736|0;K=e+12744|0;L=e+12752|0;M=e+12760|0;N=e+12768|0;O=e+12776|0;P=e+12784|0;Q=e+12792|0;R=e+12800|0;S=e+12808|0;T=e+12816|0;U=e+12824|0;V=e+12832|0;W=e+12840|0;do{if((d|0)==0){X=e+216|0;Y=eb(47e3)|0;Z=eb(46936)|0;do{if((Y|0)==0){if((Z|0)==0){_=2240;break}b5(X|0,4096,46792,($=i,i=i+8|0,c[$>>2]=Z,$)|0)|0;i=$;_=2233}else{b5(X|0,4096,46864,($=i,i=i+8|0,c[$>>2]=Y,$)|0)|0;i=$;_=2233}}while(0);if((_|0)==2233){if((a[405432]&1)!=0){Y=c[140620]|0;aa=(Y|0)!=0?Y:c[t>>2]|0;eS(aa|0,46536,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[140620]|0;Y=(aa|0)!=0?aa:c[t>>2]|0;a7(Y|0)|0}Y=hC(X,0)|0;if((Y|0)!=0|(Z|0)==0){ab=Y}else{b5(X|0,4096,46352,($=i,i=i+8|0,c[$>>2]=Z,$)|0)|0;i=$;if((a[405432]&1)!=0){Y=c[140620]|0;aa=(Y|0)!=0?Y:c[t>>2]|0;eS(aa|0,46536,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[140620]|0;Y=(aa|0)!=0?aa:c[t>>2]|0;a7(Y|0)|0}ab=hC(X,0)|0}if((ab|0)==0){_=2240}else{ac=ab}}do{if((_|0)==2240){hm(X,46232,46056);if((a[405432]&1)!=0){Y=c[140620]|0;aa=(Y|0)!=0?Y:c[t>>2]|0;eS(aa|0,46536,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[140620]|0;Y=(aa|0)!=0?aa:c[t>>2]|0;a7(Y|0)|0}Y=hC(X,0)|0;if((Y|0)==0){ad=1}else{ac=Y;break}i=e;return ad|0}}while(0);Z=4096;Y=425962;aa=X;while(1){ae=Z-1|0;if((ae|0)==0){_=2246;break}af=a[aa]|0;a[Y]=af;if(af<<24>>24==0){break}else{Z=ae;Y=Y+1|0;aa=aa+1|0}}do{if((_|0)==2246){a[Y]=0;if((a[aa]|0)==0){break}else{ag=aa}do{ag=ag+1|0;}while((a[ag]|0)!=0)}}while(0);if((ac|0)==0){ad=1}else{ah=ac;break}i=e;return ad|0}else{aa=hC(d,0)|0;if((aa|0)==0){ad=0}else{ah=aa;break}i=e;return ad|0}}while(0);d=l|0;l=4096;ac=d;ag=430058;while(1){ab=l-1|0;if((ab|0)==0){_=2252;break}aa=a[ag]|0;a[ac]=aa;if(aa<<24>>24==0){break}else{l=ab;ac=ac+1|0;ag=ag+1|0}}do{if((_|0)==2252){a[ac]=0;if((a[ag]|0)==0){break}else{ai=ag}do{ai=ai+1|0;}while((a[ai]|0)!=0)}}while(0);ai=eO(d|0,20672,k|0)|0;d=(a[405432]&1)!=0;if((ai|0)==0){aj=d}else{ag=ah+4|0;ac=ai;ai=d;while(1){if(ai){d=c[140620]|0;l=(d|0)!=0?d:c[t>>2]|0;eS(l|0,18720,($=i,i=i+8|0,c[$>>2]=ac,$)|0)|0;i=$;l=c[140620]|0;d=(l|0)!=0?l:c[t>>2]|0;a7(d|0)|0}d=hC(ac,0)|0;if((d|0)==0){l=c[140620]|0;ab=(l|0)!=0?l:c[t>>2]|0;eS(ab|0,16136,($=i,i=i+8|0,c[$>>2]=ac,$)|0)|0;i=$;ab=c[140620]|0;l=(ab|0)!=0?ab:c[t>>2]|0;a7(l|0)|0}else{l=c[d+8>>2]|0;if((l|0)!=0){c[l+12>>2]=c[ag>>2];l=d+4|0;c[ag>>2]=c[l>>2];c[l>>2]=0}hA(d)}d=eO(0,28640,k|0)|0;l=(a[405432]&1)!=0;if((d|0)==0){aj=l;break}else{ac=d;ai=l}}}do{if(aj){ai=c[140620]|0;ac=(ai|0)!=0?ai:c[t>>2]|0;be(11560,15,1,ac|0)|0;ac=c[140620]|0;ai=(ac|0)!=0?ac:c[t>>2]|0;a7(ai|0)|0;ai=c[t>>2]|0;ac=c[ah+16>>2]|0;if((ac|0)!=0){k=ac;do{eS(ai|0,46096,($=i,i=i+8|0,c[$>>2]=c[k>>2],$)|0)|0;i=$;k=c[k+4>>2]|0;}while((k|0)!=0)}k=ah+4|0;ac=c[k>>2]|0;if((ac|0)!=0){ag=ac;do{ac=c[ag+8>>2]|0;l=(a[ag|0]&1)!=0?42096:564064;eS(ai|0,43208,($=i,i=i+24|0,c[$>>2]=c[ag+4>>2],c[$+8>>2]=ac,c[$+16>>2]=l,$)|0)|0;i=$;ag=c[ag+12>>2]|0;}while((ag|0)!=0)}if((a[405432]&1)==0){ak=k;break}ag=c[140620]|0;ai=(ag|0)!=0?ag:c[t>>2]|0;be(53792,19,1,ai|0)|0;ai=c[140620]|0;ag=(ai|0)!=0?ai:c[t>>2]|0;a7(ag|0)|0;ak=k}else{ak=ah+4|0}}while(0);aj=ak;while(1){al=c[aj>>2]|0;if((al|0)==0){am=ak;break}if((db(50648,c[al+4>>2]|0)|0)==0){_=2276;break}aj=al+12|0}if((_|0)==2276){g[75772]=+yz(c[al+8>>2]|0,0);am=ak}while(1){an=c[am>>2]|0;if((an|0)==0){ao=ak;break}if((db(48504,c[an+4>>2]|0)|0)==0){_=2280;break}am=an+12|0}if((_|0)==2280){g[75773]=+yz(c[an+8>>2]|0,0);ao=ak}while(1){ap=c[ao>>2]|0;if((ap|0)==0){aq=ak;break}if((db(47256,c[ap+4>>2]|0)|0)==0){_=2284;break}ao=ap+12|0}do{if((_|0)==2284){c[(er()|0)>>2]=0;ao=bb(c[ap+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){aq=ak;break}c[75776]=ao;aq=ak}}while(0);while(1){ar=c[aq>>2]|0;if((ar|0)==0){break}if((db(46072,c[ar+4>>2]|0)|0)==0){_=2289;break}aq=ar+12|0}do{if((_|0)==2289){c[(er()|0)>>2]=0;aq=bb(c[ar+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[75777]=aq}}while(0);do{if((a[405435]&1)==0){a[n]=0;if(!(hE(ah,44504,n)|0)){break}a[303096]=a[n]&1}}while(0);a[o]=0;if(hE(ah,43176,o)|0){a[303097]=a[o]&1;as=ak}else{as=ak}while(1){at=c[as>>2]|0;if((at|0)==0){break}if((db(42072,c[at+4>>2]|0)|0)==0){_=2298;break}else{as=at+12|0}}do{if((_|0)==2298){c[(er()|0)>>2]=0;as=bb(c[at+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[75775]=as}}while(0);a[p]=0;if(hE(ah,40992,p)|0){a[319564]=a[p]&1}a[q]=0;if(hE(ah,4e4,q)|0){a[303112]=a[q]&1}a[r]=0;if(hE(ah,39e3,r)|0){a[303113]=a[r]&1;au=ak}else{au=ak}while(1){av=c[au>>2]|0;if((av|0)==0){_=2310;break}if((db(37520,c[av+4>>2]|0)|0)==0){_=2308;break}else{au=av+12|0}}do{if((_|0)==2308){c[(er()|0)>>2]=0;au=bb(c[av+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){_=2310;break}c[75780]=au;aw=au}}while(0);if((_|0)==2310){aw=c[75780]|0}if(aw>>>0>3){c[75780]=3}a[s]=0;if(hE(ah,35840,s)|0){a[303114]=a[s]&1;ax=ak}else{ax=ak}while(1){ay=c[ax>>2]|0;if((ay|0)==0){_=2318;break}if((db(34576,c[ay+4>>2]|0)|0)==0){_=2317;break}else{ax=ay+12|0}}do{if((_|0)==2317){c[(er()|0)>>2]=0;ax=bb(c[ay+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){_=2318;break}c[75779]=ax;az=ax}}while(0);if((_|0)==2318){az=c[75779]|0}ay=az>>>0>1?az:1;c[75779]=ay>>>0<4?ay:4;a[u]=0;if(hE(ah,33632,u)|0){a[311340]=a[u]&1}a[v]=0;if(hE(ah,32992,v)|0){a[303124]=a[v]&1}a[w]=0;if(hE(ah,32056,w)|0){a[303125]=a[w]&1}a[x]=0;if(hE(ah,31648,x)|0){a[303133]=a[x]&1}a[y]=0;if(hE(ah,31248,y)|0){a[303126]=a[y]&1;aA=ak}else{aA=ak}while(1){aB=c[aA>>2]|0;if((aB|0)==0){aC=ak;break}if((db(30904,c[aB+4>>2]|0)|0)==0){_=2332;break}else{aA=aB+12|0}}if((_|0)==2332){g[75782]=+yz(c[aB+8>>2]|0,0);aC=ak}while(1){aD=c[aC>>2]|0;if((aD|0)==0){break}if((db(30472,c[aD+4>>2]|0)|0)==0){_=2335;break}else{aC=aD+12|0}}do{if((_|0)==2335){c[(er()|0)>>2]=0;aC=bb(c[aD+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[75784]=aC}}while(0);a[z]=0;if(hE(ah,29848,z)|0){a[303132]=a[z]&1;aE=ak}else{aE=ak}while(1){aF=c[aE>>2]|0;if((aF|0)==0){break}if((db(29208,c[aF+4>>2]|0)|0)==0){_=2341;break}else{aE=aF+12|0}}if((_|0)==2341){g[77834]=+yz(c[aF+8>>2]|0,0)}hD(ah,28768,303140)|0;a[A]=0;if(hE(ah,28352,A)|0){a[307236]=a[A]&1}a[B]=0;if(hE(ah,27968,B)|0){a[319568]=a[B]&1}hD(ah,27576,315437)|0;B=ak;while(1){aG=c[B>>2]|0;if((aG|0)==0){break}if((db(27176,c[aG+4>>2]|0)|0)==0){_=2349;break}else{B=aG+12|0}}if((_|0)==2349){g[79884]=+yz(c[aG+8>>2]|0,0)}a[C]=0;if(hE(ah,26816,C)|0){a[319540]=a[C]&1}a[D]=0;if(hE(ah,26464,D)|0){a[319541]=a[D]&1;aH=ak}else{aH=ak}while(1){aI=c[aH>>2]|0;if((aI|0)==0){aJ=ak;break}if((db(25992,c[aI+4>>2]|0)|0)==0){_=2356;break}else{aH=aI+12|0}}if((_|0)==2356){g[79886]=+yz(c[aI+8>>2]|0,0);aJ=ak}while(1){aK=c[aJ>>2]|0;if((aK|0)==0){aL=ak;break}if((db(25312,c[aK+4>>2]|0)|0)==0){_=2359;break}else{aJ=aK+12|0}}if((_|0)==2359){g[79887]=+yz(c[aK+8>>2]|0,0);aL=ak}while(1){aM=c[aL>>2]|0;if((aM|0)==0){aN=ak;break}if((db(24672,c[aM+4>>2]|0)|0)==0){_=2362;break}else{aL=aM+12|0}}do{if((_|0)==2362){c[(er()|0)>>2]=0;aL=bb(c[aM+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){aN=ak;break}c[140605]=aL;aN=ak}}while(0);while(1){aO=c[aN>>2]|0;if((aO|0)==0){aP=ak;break}if((db(24440,c[aO+4>>2]|0)|0)==0){_=2366;break}else{aN=aO+12|0}}do{if((_|0)==2366){c[(er()|0)>>2]=0;aN=bb(c[aO+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){aP=ak;break}c[140606]=aN;aP=ak}}while(0);while(1){aQ=c[aP>>2]|0;if((aQ|0)==0){aR=ak;break}if((db(24192,c[aQ+4>>2]|0)|0)==0){_=2370;break}else{aP=aQ+12|0}}do{if((_|0)==2370){c[(er()|0)>>2]=0;aP=bb(c[aQ+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){aR=ak;break}c[140607]=aP;aR=ak}}while(0);while(1){aS=c[aR>>2]|0;if((aS|0)==0){aT=ak;break}if((db(23888,c[aS+4>>2]|0)|0)==0){_=2374;break}else{aR=aS+12|0}}do{if((_|0)==2374){c[(er()|0)>>2]=0;aR=bb(c[aS+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){aT=ak;break}c[140608]=aR;aT=ak}}while(0);while(1){aU=c[aT>>2]|0;if((aU|0)==0){break}if((db(23600,c[aU+4>>2]|0)|0)==0){_=2378;break}else{aT=aU+12|0}}do{if((_|0)==2378){c[(er()|0)>>2]=0;aT=a4(c[aU+8>>2]|0,0,16)|0;if((c[(er()|0)>>2]|0)!=0){break}g[79888]=+((aT>>>16&255)>>>0>>>0)/255.0;g[79889]=+((aT>>>8&255)>>>0>>>0)/255.0;g[79890]=+((aT&255)>>>0>>>0)/255.0}}while(0);a[E]=0;if(hE(ah,23328,E)|0){a[319565]=a[E]&1}a[F]=0;if(hE(ah,23032,F)|0){a[319566]=a[F]&1}a[G]=0;if(hE(ah,22800,G)|0){a[319567]=a[G]&1}hD(ah,22448,311341)|0;if((db(311341,21912)|0)==0){a[311341]=0;aV=ak}else{aV=ak}while(1){aW=c[aV>>2]|0;if((aW|0)==0){break}if((db(21320,c[aW+4>>2]|0)|0)==0){_=2390;break}else{aV=aW+12|0}}if((_|0)==2390){g[90944]=+yz(c[aW+8>>2]|0,0)}a[H]=0;if(hE(ah,20896,H)|0){a[364390]=a[H]&1}H=I|0;b5(H|0,64,20640,($=i,i=i+8|0,c[$>>2]=1,$)|0)|0;i=$;I=ak;while(1){aX=c[I>>2]|0;if((aX|0)==0){break}if((db(H|0,c[aX+4>>2]|0)|0)==0){_=2396;break}else{I=aX+12|0}}do{if((_|0)==2396){c[(er()|0)>>2]=0;I=bb(c[aX+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[90945]=I}}while(0);b5(H|0,64,20640,($=i,i=i+8|0,c[$>>2]=2,$)|0)|0;i=$;aX=ak;while(1){aY=c[aX>>2]|0;if((aY|0)==0){break}if((db(H|0,c[aY+4>>2]|0)|0)==0){_=2401;break}else{aX=aY+12|0}}do{if((_|0)==2401){c[(er()|0)>>2]=0;aX=bb(c[aY+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[90946]=aX}}while(0);b5(H|0,64,20640,($=i,i=i+8|0,c[$>>2]=3,$)|0)|0;i=$;aY=ak;while(1){aZ=c[aY>>2]|0;if((aZ|0)==0){break}if((db(H|0,c[aZ+4>>2]|0)|0)==0){_=2606;break}else{aY=aZ+12|0}}do{if((_|0)==2606){c[(er()|0)>>2]=0;aY=bb(c[aZ+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[90947]=aY}}while(0);b5(H|0,64,20640,($=i,i=i+8|0,c[$>>2]=4,$)|0)|0;i=$;aZ=ak;while(1){a_=c[aZ>>2]|0;if((a_|0)==0){break}if((db(H|0,c[a_+4>>2]|0)|0)==0){_=2611;break}else{aZ=a_+12|0}}do{if((_|0)==2611){c[(er()|0)>>2]=0;aZ=bb(c[a_+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[90948]=aZ}}while(0);b5(H|0,64,20640,($=i,i=i+8|0,c[$>>2]=5,$)|0)|0;i=$;a_=ak;while(1){a$=c[a_>>2]|0;if((a$|0)==0){break}if((db(H|0,c[a$+4>>2]|0)|0)==0){_=2616;break}else{a_=a$+12|0}}do{if((_|0)==2616){c[(er()|0)>>2]=0;a_=bb(c[a$+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[90949]=a_}}while(0);b5(H|0,64,20640,($=i,i=i+8|0,c[$>>2]=6,$)|0)|0;i=$;a$=ak;while(1){a0=c[a$>>2]|0;if((a0|0)==0){break}if((db(H|0,c[a0+4>>2]|0)|0)==0){_=2621;break}else{a$=a0+12|0}}do{if((_|0)==2621){c[(er()|0)>>2]=0;a$=bb(c[a0+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[90950]=a$}}while(0);b5(H|0,64,20640,($=i,i=i+8|0,c[$>>2]=7,$)|0)|0;i=$;a0=ak;while(1){a1=c[a0>>2]|0;if((a1|0)==0){break}if((db(H|0,c[a1+4>>2]|0)|0)==0){_=2626;break}else{a0=a1+12|0}}do{if((_|0)==2626){c[(er()|0)>>2]=0;a0=bb(c[a1+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[90951]=a0}}while(0);b5(H|0,64,20640,($=i,i=i+8|0,c[$>>2]=8,$)|0)|0;i=$;a1=ak;while(1){a2=c[a1>>2]|0;if((a2|0)==0){break}if((db(H|0,c[a2+4>>2]|0)|0)==0){_=2631;break}else{a1=a2+12|0}}do{if((_|0)==2631){c[(er()|0)>>2]=0;a1=bb(c[a2+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[90952]=a1}}while(0);a[J]=0;if(hE(ah,20504,J)|0){a[319604]=a[J]&1;a3=ak}else{a3=ak}while(1){a5=c[a3>>2]|0;if((a5|0)==0){a6=ak;break}if((db(20424,c[a5+4>>2]|0)|0)==0){_=2405;break}else{a3=a5+12|0}}do{if((_|0)==2405){c[(er()|0)>>2]=0;a3=bb(c[a5+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){a6=ak;break}c[79902]=a3;a6=ak}}while(0);while(1){a8=c[a6>>2]|0;if((a8|0)==0){a9=ak;break}if((db(20288,c[a8+4>>2]|0)|0)==0){_=2409;break}else{a6=a8+12|0}}do{if((_|0)==2409){c[(er()|0)>>2]=0;a6=bb(c[a8+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){a9=ak;break}c[79903]=a6;a9=ak}}while(0);while(1){ba=c[a9>>2]|0;if((ba|0)==0){bc=ak;break}if((db(20096,c[ba+4>>2]|0)|0)==0){_=2413;break}else{a9=ba+12|0}}L3444:do{if((_|0)==2413){a9=4096;a8=319620;a6=c[ba+8>>2]|0;while(1){a5=a9-1|0;if((a5|0)==0){break}a3=a[a6]|0;a[a8]=a3;if(a3<<24>>24==0){bc=ak;break L3444}else{a9=a5;a8=a8+1|0;a6=a6+1|0}}a[a8]=0;if((a[a6]|0)==0){bc=ak;break}else{bd=a6}while(1){a9=bd+1|0;if((a[a9]|0)==0){bc=ak;break}else{bd=a9}}}}while(0);while(1){bf=c[bc>>2]|0;if((bf|0)==0){break}if((db(19976,c[bf+4>>2]|0)|0)==0){_=2420;break}else{bc=bf+12|0}}do{if((_|0)==2420){c[(er()|0)>>2]=0;bc=bb(c[bf+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[80929]=bc}}while(0);a[K]=0;if(hE(ah,19832,K)|0){a[323720]=a[K]&1}a[L]=0;if(hE(ah,19472,L)|0){a[327817]=a[L]&1;bg=ak}else{bg=ak}while(1){bh=c[bg>>2]|0;if((bh|0)==0){bi=ak;break}if((db(19144,c[bh+4>>2]|0)|0)==0){_=2428;break}else{bg=bh+12|0}}if((_|0)==2428){g[81955]=+yz(c[bh+8>>2]|0,0);bi=ak}while(1){bj=c[bi>>2]|0;if((bj|0)==0){bk=ak;break}if((db(18944,c[bj+4>>2]|0)|0)==0){_=2431;break}else{bi=bj+12|0}}if((_|0)==2431){g[81956]=+yz(c[bj+8>>2]|0,0);bk=ak}while(1){bl=c[bk>>2]|0;if((bl|0)==0){bm=ak;break}if((db(18696,c[bl+4>>2]|0)|0)==0){_=2434;break}else{bk=bl+12|0}}L3477:do{if((_|0)==2434){bk=32;bj=303024;bi=c[bl+8>>2]|0;while(1){bh=bk-1|0;if((bh|0)==0){break}bg=a[bi]|0;a[bj]=bg;if(bg<<24>>24==0){bm=ak;break L3477}else{bk=bh;bj=bj+1|0;bi=bi+1|0}}a[bj]=0;if((a[bi]|0)==0){bm=ak;break}else{bn=bi}while(1){bk=bn+1|0;if((a[bk]|0)==0){bm=ak;break}else{bn=bk}}}}while(0);while(1){bo=c[bm>>2]|0;if((bo|0)==0){bp=ak;break}if((db(18496,c[bo+4>>2]|0)|0)==0){_=2441;break}else{bm=bo+12|0}}L3488:do{if((_|0)==2441){bm=32;bn=303056;bl=c[bo+8>>2]|0;while(1){bi=bm-1|0;if((bi|0)==0){break}bj=a[bl]|0;a[bn]=bj;if(bj<<24>>24==0){bp=ak;break L3488}else{bm=bi;bn=bn+1|0;bl=bl+1|0}}a[bn]=0;if((a[bl]|0)==0){bp=ak;break}else{bq=bl}while(1){bm=bq+1|0;if((a[bm]|0)==0){bp=ak;break}else{bq=bm}}}}while(0);while(1){br=c[bp>>2]|0;if((br|0)==0){break}if((db(18352,c[br+4>>2]|0)|0)==0){_=2448;break}else{bp=br+12|0}}L3499:do{if((_|0)==2448){bp=32;bq=319572;bo=c[br+8>>2]|0;while(1){bl=bp-1|0;if((bl|0)==0){break}bn=a[bo]|0;a[bq]=bn;if(bn<<24>>24==0){break L3499}else{bp=bl;bq=bq+1|0;bo=bo+1|0}}a[bq]=0;if((a[bo]|0)==0){break}else{bs=bo}do{bs=bs+1|0;}while((a[bs]|0)!=0)}}while(0);hD(ah,18120,323721)|0;bs=ak;while(1){bt=c[bs>>2]|0;if((bt|0)==0){bu=ak;break}if((db(41312,c[bt+4>>2]|0)|0)==0){_=2456;break}else{bs=bt+12|0}}L3511:do{if((_|0)==2456){bs=32;br=327864;bo=c[bt+8>>2]|0;while(1){bq=bs-1|0;if((bq|0)==0){break}bp=a[bo]|0;a[br]=bp;if(bp<<24>>24==0){bu=ak;break L3511}else{bs=bq;br=br+1|0;bo=bo+1|0}}a[br]=0;if((a[bo]|0)==0){bu=ak;break}else{bv=bo}while(1){bs=bv+1|0;if((a[bs]|0)==0){bu=ak;break}else{bv=bs}}}}while(0);while(1){bw=c[bu>>2]|0;if((bw|0)==0){break}if((db(17656,c[bw+4>>2]|0)|0)==0){_=2463;break}else{bu=bw+12|0}}L3522:do{if((_|0)==2463){bu=32;bv=327896;bt=c[bw+8>>2]|0;while(1){bo=bu-1|0;if((bo|0)==0){break}br=a[bt]|0;a[bv]=br;if(br<<24>>24==0){break L3522}else{bu=bo;bv=bv+1|0;bt=bt+1|0}}a[bv]=0;if((a[bt]|0)==0){break}else{bx=bt}do{bx=bx+1|0;}while((a[bx]|0)!=0)}}while(0);if((a[380796]|0)==0){hD(ah,17432,380796)|0}hD(ah,17112,372600)|0;hD(ah,16736,393084)|0;do{if((a[393084]|0)!=0){if((fk(393084,j|0)|0)>=0){if((c[j+8>>2]&61440|0)==16384){break}}bx=c[140620]|0;bw=(bx|0)!=0?bx:c[t>>2]|0;be(16424,84,1,bw|0)|0;bw=c[140620]|0;bx=(bw|0)!=0?bw:c[t>>2]|0;a7(bx|0)|0;a[393084]=0}}while(0);hD(ah,16112,401313)|0;if((db(401313,21912)|0)==0){a[401313]=0}hD(ah,15976,483306)|0;if((db(483306,21912)|0)==0){a[483306]=0}hD(ah,15840,364400)|0;j=ak;while(1){by=c[j>>2]|0;if((by|0)==0){bz=ak;break}if((db(15656,c[by+4>>2]|0)|0)==0){_=2481;break}else{j=by+12|0}}if((_|0)==2481){g[92124]=+yz(c[by+8>>2]|0,0);bz=ak}while(1){bA=c[bz>>2]|0;if((bA|0)==0){break}if((db(15480,c[bA+4>>2]|0)|0)==0){_=2484;break}else{bz=bA+12|0}}if((_|0)==2484){g[92125]=+yz(c[bA+8>>2]|0,0)}a[M]=0;if(hE(ah,15344,M)|0){a[401276]=a[M]&1;bB=ak}else{bB=ak}while(1){bC=c[bB>>2]|0;if((bC|0)==0){bD=ak;break}if((db(15128,c[bC+4>>2]|0)|0)==0){_=2489;break}else{bB=bC+12|0}}do{if((_|0)==2489){c[(er()|0)>>2]=0;bB=bb(c[bC+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){bD=ak;break}c[100320]=bB*1e6|0;bD=ak}}while(0);while(1){bE=c[bD>>2]|0;if((bE|0)==0){bF=ak;break}if((db(14840,c[bE+4>>2]|0)|0)==0){_=2493;break}else{bD=bE+12|0}}do{if((_|0)==2493){c[(er()|0)>>2]=0;bD=bb(c[bE+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){bF=ak;break}c[100321]=bD;bF=ak}}while(0);while(1){bG=c[bF>>2]|0;if((bG|0)==0){_=2498;break}if((db(14368,c[bG+4>>2]|0)|0)==0){_=2497;break}else{bF=bG+12|0}}if((_|0)==2497){bH=+yz(c[bG+8>>2]|0,0);g[100322]=bH;bI=bH}else if((_|0)==2498){bI=+g[100322]}if(bI<1.0){g[100322]=1.0;bJ=ak}else{bJ=ak}while(1){bK=c[bJ>>2]|0;if((bK|0)==0){break}if((db(14104,c[bK+4>>2]|0)|0)==0){_=2503;break}else{bJ=bK+12|0}}if((_|0)==2503){g[100323]=+yz(c[bK+8>>2]|0,0)}a[N]=0;if(hE(ah,13736,N)|0){a[401296]=a[N]&1;bL=ak}else{bL=ak}while(1){bM=c[bL>>2]|0;if((bM|0)==0){break}if((db(13552,c[bM+4>>2]|0)|0)==0){_=2508;break}else{bL=bM+12|0}}do{if((_|0)==2508){c[(er()|0)>>2]=0;bL=bb(c[bM+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[100325]=bL}}while(0);hD(ah,13432,384892)|0;hD(ah,13272,388988)|0;a[O]=0;if(hE(ah,13016,O)|0){a[401304]=a[O]&1}a[P]=0;if(hE(ah,12848,P)|0){a[401305]=a[P]&1}a[Q]=0;if(hE(ah,12664,Q)|0){a[401306]=a[Q]&1}a[R]=0;if(hE(ah,12408,R)|0){a[401307]=a[R]&1}a[S]=0;if(hE(ah,11928,S)|0){a[401308]=a[S]&1;bN=ak}else{bN=ak}while(1){bO=c[bN>>2]|0;if((bO|0)==0){break}if((db(11712,c[bO+4>>2]|0)|0)==0){_=2522;break}else{bN=bO+12|0}}do{if((_|0)==2522){c[(er()|0)>>2]=0;bN=bb(c[bO+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}b[200655]=bN&65535}}while(0);a[T]=0;if(hE(ah,11536,T)|0){a[401312]=a[T]&1}hD(ah,11368,376696)|0;T=ak;while(1){bP=c[T>>2]|0;if((bP|0)==0){bQ=ak;break}if((db(11272,c[bP+4>>2]|0)|0)==0){_=2529;break}else{T=bP+12|0}}do{if((_|0)==2529){c[(er()|0)>>2]=0;T=bb(c[bP+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){bQ=ak;break}c[95198]=T;bQ=ak}}while(0);while(1){bR=c[bQ>>2]|0;if((bR|0)==0){bS=ak;break}if((db(11120,c[bR+4>>2]|0)|0)==0){_=2533;break}else{bQ=bR+12|0}}do{if((_|0)==2533){c[(er()|0)>>2]=0;bQ=bb(c[bR+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){bS=ak;break}c[91098]=bQ;bS=ak}}while(0);while(1){bT=c[bS>>2]|0;if((bT|0)==0){break}if((db(10984,c[bT+4>>2]|0)|0)==0){_=2537;break}else{bS=bT+12|0}}do{if((_|0)==2537){c[(er()|0)>>2]=0;bS=bb(c[bT+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[91099]=bS}}while(0);a[U]=0;if(hE(ah,10848,U)|0){a[364388]=a[U]&1}a[V]=0;if(hE(ah,54936,V)|0){a[364389]=a[V]&1}hD(ah,54672,368504)|0;a[W]=0;if(hE(ah,54176,W)|0){a[562486]=a[W]&1}L3647:do{if((a[425960]&1)==0){W=m|0;if(!(hD(ah,54008,W)|0)){break}if((db(W|0,21912)|0)==0){a[475114]=0;break}do{if((fk(W|0,h|0)|0)>=0){if((c[h+8>>2]&61440|0)==16384){bU=4096;bV=475114;bW=W}else{break}while(1){V=bU-1|0;if((V|0)==0){_=2553;break}U=a[bW]|0;a[bV]=U;if(U<<24>>24==0){bX=4096;bY=446442;bZ=W;break}else{bU=V;bV=bV+1|0;bW=bW+1|0}}do{if((_|0)==2553){a[bV]=0;if((a[bW]|0)==0){bX=4096;bY=446442;bZ=W;break}else{b_=bW}while(1){V=b_+1|0;if((a[V]|0)==0){bX=4096;bY=446442;bZ=W;break}else{b_=V}}}}while(0);while(1){V=bX-1|0;if((V|0)==0){_=2557;break}U=a[bZ]|0;a[bY]=U;if(U<<24>>24==0){break}else{bX=V;bY=bY+1|0;bZ=bZ+1|0}}do{if((_|0)==2557){a[bY]=0;if((a[bZ]|0)==0){break}else{b$=bZ}do{b$=b$+1|0;}while((a[b$]|0)!=0)}}while(0);hp(446442,53784);break L3647}}while(0);W=c[140620]|0;V=(W|0)!=0?W:c[t>>2]|0;be(53576,72,1,V|0)|0;V=c[140620]|0;W=(V|0)!=0?V:c[t>>2]|0;a7(W|0)|0}}while(0);L3672:do{if((a[425961]&1)==0){b$=m|0;if(!(hD(ah,53416,b$)|0)){break}if((db(b$|0,21912)|0)==0){a[479210]=0;break}do{if((fk(b$|0,f|0)|0)>=0){if((c[f+8>>2]&61440|0)==16384){b0=4096;b1=479210;b2=b$}else{break}while(1){bZ=b0-1|0;if((bZ|0)==0){_=2569;break}bY=a[b2]|0;a[b1]=bY;if(bY<<24>>24==0){b3=4096;b4=466922;b6=b$;break}else{b0=bZ;b1=b1+1|0;b2=b2+1|0}}do{if((_|0)==2569){a[b1]=0;if((a[b2]|0)==0){b3=4096;b4=466922;b6=b$;break}else{b7=b2}while(1){bZ=b7+1|0;if((a[bZ]|0)==0){b3=4096;b4=466922;b6=b$;break}else{b7=bZ}}}}while(0);while(1){bZ=b3-1|0;if((bZ|0)==0){_=2573;break}bY=a[b6]|0;a[b4]=bY;if(bY<<24>>24==0){break}else{b3=bZ;b4=b4+1|0;b6=b6+1|0}}do{if((_|0)==2573){a[b4]=0;if((a[b6]|0)==0){break}else{b8=b6}do{b8=b8+1|0;}while((a[b8]|0)!=0)}}while(0);hp(466922,53232);break L3672}}while(0);b$=c[140620]|0;bZ=(b$|0)!=0?b$:c[t>>2]|0;be(52968,73,1,bZ|0)|0;bZ=c[140620]|0;b$=(bZ|0)!=0?bZ:c[t>>2]|0;a7(b$|0)|0}}while(0);if(!(hD(ah,52592,397180)|0)){b8=c[140620]|0;b6=(b8|0)!=0?b8:c[t>>2]|0;eS(b6|0,52272,($=i,i=i+8|0,c[$>>2]=397180,$)|0)|0;i=$;$=c[140620]|0;b6=($|0)!=0?$:c[t>>2]|0;a7(b6|0)|0}if((db(397180,21912)|0)==0){a[397180]=0;b9=0}else{b9=0}do{b6=10184+(b9<<2)|0;L3704:do{if((b9|0)==0){$=0;b8=6704;while(1){b4=327928+($*40|0)|0;do{if((a[b4|0]&1)==0){_=2588}else{b3=c[6712+($*20|0)>>2]|0;if(($|0)==56){ca=57;break}b7=($-25|0)>>>0<31?41936:40872;h9(ah,b7,b3,b4);b2=a[b8]|0;if((b2&1)==0){cb=b2}else{ia(ah,b7,b3,b4);cb=a[b8]|0}if((cb&1)==0){_=2588;break}ib(ah,b7,b3,b4);_=2588}}while(0);if((_|0)==2588){_=0;b4=$+1|0;if((b4|0)==56){break L3704}else{ca=b4}}$=ca;b8=6704+(ca*20|0)|0}}else{b8=0;$=6704;while(1){b4=327928+(b9*2240|0)+(b8*40|0)|0;do{if((a[b4|0]&1)==0){_=2597}else{b3=c[6712+(b8*20|0)>>2]|0;if((b8|0)==56){cc=57;break}if((b8-25|0)>>>0<31){_=2597;break}b7=c[b6>>2]|0;h9(ah,b7,b3,b4);b2=a[$]|0;if((b2&1)==0){cd=b2}else{ia(ah,b7,b3,b4);cd=a[$]|0}if((cd&1)==0){_=2597;break}ib(ah,b7,b3,b4);_=2597}}while(0);if((_|0)==2597){_=0;b4=b8+1|0;if((b4|0)==56){break L3704}else{cc=b4}}b8=cc;$=6704+(cc*20|0)|0}}}while(0);b9=b9+1|0;}while(b9>>>0<8);hA(ah);ad=1;i=e;return ad|0}function hI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=ex(c[a>>2]|0)|0;c[a+68>>2]=b;c[a+72>>2]=ex(c[a+4>>2]|0)|0;c[a+76>>2]=ex(c[a+8>>2]|0)|0;c[a+80>>2]=ex(c[a+12>>2]|0)|0;c[a+84>>2]=ex(c[a+16>>2]|0)|0;c[a+88>>2]=ex(c[a+20>>2]|0)|0;c[a+92>>2]=ex(c[a+24>>2]|0)|0;c[a+96>>2]=ex(c[a+28>>2]|0)|0;c[a+100>>2]=ex(c[a+32>>2]|0)|0;c[a+104>>2]=ex(c[a+36>>2]|0)|0;c[a+108>>2]=ex(c[a+40>>2]|0)|0;c[a+112>>2]=ex(c[a+44>>2]|0)|0;c[a+116>>2]=ex(c[a+48>>2]|0)|0;c[a+120>>2]=ex(c[a+52>>2]|0)|0;c[a+124>>2]=ex(c[a+56>>2]|0)|0;c[a+128>>2]=ex(c[a+60>>2]|0)|0;d=16;e=b;while(1){b=c[a+68+(d-15<<2)>>2]|0;f=c[a+68+(d-2<<2)>>2]|0;c[a+68+(d<<2)>>2]=(c[a+68+(d-7<<2)>>2]|0)+e+((b>>>18|b<<14)^b>>>3^(b>>>7|b<<25))+((f>>>19|f<<13)^f>>>10^(f>>>17|f<<15));f=d+1|0;if(f>>>0<64){d=f;e=b}else{break}}e=a+324|0;d=c[e>>2]|0;b=a+328|0;f=c[b>>2]|0;g=a+332|0;h=c[g>>2]|0;i=a+336|0;j=c[i>>2]|0;k=a+340|0;l=c[k>>2]|0;m=a+344|0;n=c[m>>2]|0;o=a+348|0;p=c[o>>2]|0;q=a+352|0;r=c[q>>2]|0;s=f;t=h;u=j;v=l;w=n;x=p;y=r;z=d;A=0;while(1){B=(x&~v^v&w)+y+((v>>>6|v<<26)^(v>>>11|v<<21)^(v>>>25|v<<7))+(c[84344+(A<<2)>>2]|0)+(c[a+68+(A<<2)>>2]|0)|0;C=B+u|0;D=((s^t)&z^s&t)+((z>>>2|z<<30)^(z>>>13|z<<19)^(z>>>22|z<<10))+B|0;B=A+1|0;if(B>>>0<64){u=t;t=s;s=z;y=x;x=w;w=v;v=C;z=D;A=B}else{break}}c[e>>2]=D+d;c[b>>2]=z+f;c[g>>2]=s+h;c[i>>2]=t+j;c[k>>2]=C+l;c[m>>2]=v+n;c[o>>2]=w+p;c[q>>2]=x+r;c[a+64>>2]=0;return}function hJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+4096|0;f=e|0;if((b|0)==11){yB(499800,0,512);g=c[d+16>>2]|0;if((g|0)!=0){h=d;j=g;while(1){g=c[h>>2]|0;do{if(g>>>0<=7){if((c[h+4>>2]|0)!=1){break}k=c[h+12>>2]|0;if(k>>>0>15){break}c[499800+(g<<6)+(k<<2)>>2]=j}}while(0);g=c[h+36>>2]|0;if((g|0)==0){break}else{h=h+20|0;j=g}}}if((a[405432]&1)==0){l=0}else{j=c[140620]|0;h=(j|0)!=0?j:c[t>>2]|0;be(29112,42,1,h|0)|0;h=c[140620]|0;j=(h|0)!=0?h:c[t>>2]|0;a7(j|0)|0;l=0}while(1){j=l+1|0;h=0;do{g=c[499800+(l<<6)+(h<<2)>>2]|0;do{if((g|0)!=0){if((a[405432]&1)==0){break}k=c[140620]|0;m=(k|0)!=0?k:c[t>>2]|0;k=c[5768+(h<<2)>>2]|0;eS(m|0,28712,(n=i,i=i+24|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=g,n)|0)|0;i=n;k=c[140620]|0;m=(k|0)!=0?k:c[t>>2]|0;a7(m|0)|0}}while(0);h=h+1|0;}while(h>>>0<16);if(j>>>0<8){l=j}else{o=1;break}}i=e;return o|0}else if((b|0)==1){l=c[d>>2]|0;if((a[405432]&1)!=0){h=c[140620]|0;g=(h|0)!=0?h:c[t>>2]|0;eS(g|0,11232,(n=i,i=i+8|0,c[n>>2]=l,n)|0)|0;i=n;g=c[140620]|0;h=(g|0)!=0?g:c[t>>2]|0;a7(h|0)|0}if((a[319568]&1)==0){o=1;i=e;return o|0}c[124945]=l;h=c[140913]|0;if((h|0)==0){o=0;i=e;return o|0}g=c[h+40>>2]|0;if((g|0)==0){o=0;i=e;return o|0}h=c[140916]|0;if((h|0)==0){o=1;i=e;return o|0}f3[g&1023](h,l);o=1;i=e;return o|0}else if((b|0)==13){if((a[405432]&1)!=0){l=c[140620]|0;h=(l|0)!=0?l:c[t>>2]|0;be(27920,47,1,h|0)|0;h=c[140620]|0;l=(h|0)!=0?h:c[t>>2]|0;a7(l|0)|0}c[126104]=c[d>>2];c[504420>>2]=c[d+4>>2];c[504424>>2]=c[d+8>>2];c[504428>>2]=c[d+12>>2];c[504432>>2]=c[d+16>>2];c[504436>>2]=c[d+20>>2];c[504440>>2]=c[d+24>>2];o=1;i=e;return o|0}else if((b|0)==14|(b|0)==65550){if((a[405432]&1)!=0){l=c[140620]|0;h=(l|0)!=0?l:c[t>>2]|0;be(27496,34,1,h|0)|0;h=c[140620]|0;l=(h|0)!=0?h:c[t>>2]|0;a7(l|0)|0}l=c[d>>2]|0;do{if((l|0)==0){if((a[405432]&1)==0){break}h=c[140620]|0;g=(h|0)!=0?h:c[t>>2]|0;be(27136,37,1,g|0)|0;g=c[140620]|0;h=(g|0)!=0?g:c[t>>2]|0;a7(h|0)|0}else if((l|0)==2){if((a[405432]&1)!=0){h=c[140620]|0;g=(h|0)!=0?h:c[t>>2]|0;be(26768,41,1,g|0)|0;g=c[140620]|0;h=(g|0)!=0?g:c[t>>2]|0;a7(h|0)|0}c[140913]=72}else if((l|0)==1|(l|0)==3){h=c[140620]|0;be(26344,116,1,((h|0)!=0?h:c[t>>2]|0)|0)|0;h=c[140620]|0;a7(((h|0)!=0?h:c[t>>2]|0)|0)|0;o=0;i=e;return o|0}else{if((a[405432]&1)==0){o=0;i=e;return o|0}h=c[140620]|0;be(25952,39,1,((h|0)!=0?h:c[t>>2]|0)|0)|0;h=c[140620]|0;a7(((h|0)!=0?h:c[t>>2]|0)|0)|0;o=0;i=e;return o|0}}while(0);c[d+8>>2]=20;c[d+12>>2]=82;if((b&65536|0)==0){yE(504444,d|0,40)|0;o=1;i=e;return o|0}else{c[126111]=c[d>>2];c[504448>>2]=c[d+4>>2];c[504452>>2]=c[d+8>>2];c[504456>>2]=c[d+12>>2];a[504460|0]=a[d+16|0]|0;o=1;i=e;return o|0}}else if((b|0)==7){if((a[405432]&1)!=0){l=c[140620]|0;h=(l|0)!=0?l:c[t>>2]|0;be(53384,29,1,h|0)|0;h=c[140620]|0;l=(h|0)!=0?h:c[t>>2]|0;a7(l|0)|0}a[499784]=1;o=1;i=e;return o|0}else if((b|0)==8){l=c[d>>2]|0;c[124947]=l;if((a[405432]&1)==0){o=1;i=e;return o|0}h=c[140620]|0;eS(((h|0)!=0?h:c[t>>2]|0)|0,50264,(n=i,i=i+8|0,c[n>>2]=l,n)|0)|0;i=n;l=c[140620]|0;a7(((l|0)!=0?l:c[t>>2]|0)|0)|0;o=1;i=e;return o|0}else if((b|0)==12){if((a[405432]&1)!=0){l=c[140620]|0;h=(l|0)!=0?l:c[t>>2]|0;be(28304,42,1,h|0)|0;h=c[140620]|0;l=(h|0)!=0?h:c[t>>2]|0;a7(l|0)|0}c[126102]=c[d>>2];o=1;i=e;return o|0}else if((b|0)==3){a[d]=1;if((a[405432]&1)==0){o=1;i=e;return o|0}l=c[140620]|0;be(32016,38,1,((l|0)!=0?l:c[t>>2]|0)|0)|0;l=c[140620]|0;a7(((l|0)!=0?l:c[t>>2]|0)|0)|0;o=1;i=e;return o|0}else if((b|0)==15){if((a[405432]&1)!=0){l=c[140620]|0;h=(l|0)!=0?l:c[t>>2]|0;l=c[d>>2]|0;eS(h|0,27536,(n=i,i=i+8|0,c[n>>2]=l,n)|0)|0;i=n;l=c[140620]|0;h=(l|0)!=0?l:c[t>>2]|0;a7(h|0)|0}h=c[126128]|0;do{if((h|0)==0){c[d+4>>2]=0;p=0}else{a[h+4108|0]=0;l=c[h+4104>>2]|0;g=h+4100|0;m=d;k=0;while(1){if(k>>>0>=l>>>0){q=2655;break}r=c[g>>2]|0;if((db(c[r+(k<<4)+4>>2]|0,c[m>>2]|0)|0)==0){q=2654;break}else{k=k+1|0}}if((q|0)==2655){c[d+4>>2]=0;p=0;break}else if((q|0)==2654){m=c[(c[c[r+(k<<4)+8>>2]>>2]|0)+(c[r+(k<<4)+12>>2]<<3)>>2]|0;c[d+4>>2]=m;p=m;break}}}while(0);if((a[405432]&1)==0){o=1;i=e;return o|0}r=c[140620]|0;eS(((r|0)!=0?r:c[t>>2]|0)|0,23584,(n=i,i=i+8|0,c[n>>2]=(p|0)==0?17136:p,n)|0)|0;i=n;p=c[140620]|0;a7(((p|0)!=0?p:c[t>>2]|0)|0)|0;o=1;i=e;return o|0}else if((b|0)==2){a[d]=a[303126]&1^1;if((a[405432]&1)==0){o=1;i=e;return o|0}p=c[140620]|0;eS(((p|0)!=0?p:c[t>>2]|0)|0,43096,(n=i,i=i+8|0,c[n>>2]=(a[303126]&1^1)&255,n)|0)|0;i=n;p=c[140620]|0;a7(((p|0)!=0?p:c[t>>2]|0)|0)|0;o=1;i=e;return o|0}else if((b|0)==18){p=a[d]|0;if((a[405432]&1)==0){s=p&1}else{r=c[140620]|0;h=(r|0)!=0?r:c[t>>2]|0;r=p&1;p=r<<24>>24!=0?24664:24416;eS(h|0,25160,(n=i,i=i+8|0,c[n>>2]=p,n)|0)|0;i=n;p=c[140620]|0;h=(p|0)!=0?p:c[t>>2]|0;a7(h|0)|0;s=r}a[499798]=s;o=1;i=e;return o|0}else if((b|0)==19){c[d>>2]=0;o=1;i=e;return o|0}else if((b|0)==21){if((a[405432]&1)!=0){s=c[140620]|0;r=(s|0)!=0?s:c[t>>2]|0;be(24144,44,1,r|0)|0;r=c[140620]|0;s=(r|0)!=0?r:c[t>>2]|0;a7(s|0)|0}c[126122]=c[d>>2];c[504492>>2]=c[d+4>>2];c[504496>>2]=c[d+8>>2];c[504500>>2]=c[d+12>>2];o=1;i=e;return o|0}else if((b|0)==131072){if((a[405432]&1)!=0){s=c[140620]|0;r=(s|0)!=0?s:c[t>>2]|0;be(23832,48,1,r|0)|0;r=c[140620]|0;s=(r|0)!=0?r:c[t>>2]|0;a7(s|0)|0}s=dA(d|0,12144)|0;if((s|0)==0){o=0;i=e;return o|0}a_(s|0)|0;s=4096;r=380796;h=d;while(1){p=s-1|0;if((p|0)==0){break}m=a[h]|0;a[r]=m;if(m<<24>>24==0){o=1;q=2872;break}else{s=p;r=r+1|0;h=h+1|0}}if((q|0)==2872){i=e;return o|0}a[r]=0;if((a[h]|0)==0){o=1;i=e;return o|0}else{u=h}while(1){h=u+1|0;if((a[h]|0)==0){o=1;break}else{u=h}}i=e;return o|0}else if((b|0)==16){if((a[405432]&1)!=0){u=c[140620]|0;h=(u|0)!=0?u:c[t>>2]|0;be(18312,34,1,h|0)|0;h=c[140620]|0;u=(h|0)!=0?h:c[t>>2]|0;a7(u|0)|0}u=c[126128]|0;if((u|0)!=0){h=u+4104|0;if((c[h>>2]|0)==0){v=u|0}else{r=u+4100|0;s=u|0;p=0;while(1){m=c[r>>2]|0;hF(c[s>>2]|0,c[m+(p<<4)+4>>2]|0,c[(c[c[m+(p<<4)+8>>2]>>2]|0)+(c[m+(p<<4)+12>>2]<<3)>>2]|0);m=p+1|0;if(m>>>0<(c[h>>2]|0)>>>0){p=m}else{v=s;break}}}s=c[v>>2]|0;v=u+4|0;hG(s,v)|0;ij(c[126128]|0)}v=d;if((a[372600]|0)!=0|(a[425962]|0)==0){w=372600}else{s=f|0;hw(s,425962,15808);w=s}s=ys(4112)|0;L3901:do{if((s|0)==0){x=0}else{if((c[s-4>>2]&3|0)!=0){yB(s|0,0,4112)}f=s;if((a[w]|0)==0){y=c[s>>2]|0}else{u=hC(w,0)|0;c[s>>2]=u;y=u}u=s;if((y|0)==0){p=ys(20)|0;do{if((p|0)!=0){if((c[p-4>>2]&3|0)==0){break}yB(p|0,0,20)}}while(0);c[u>>2]=p}k=4096;h=s+4|0;r=w;while(1){m=k-1|0;if((m|0)==0){q=2686;break}g=a[r]|0;a[h]=g;if(g<<24>>24==0){break}else{k=m;h=h+1|0;r=r+1|0}}do{if((q|0)==2686){a[h]=0;if((a[r]|0)==0){break}else{z=r}do{z=z+1|0;}while((a[z]|0)!=0)}}while(0);do{if((c[u>>2]|0)!=0){r=d;h=c[r>>2]|0;k=(h|0)==0;do{if(k){A=0;B=0}else{p=0;m=v;while(1){if((c[m+4>>2]|0)==0){C=p;break}g=p+1|0;l=m+8|0;if((c[l>>2]|0)==0){C=g;break}else{p=g;m=l}}if((C|0)==0){A=0;B=0;break}m=C<<4;if(C>>>0<=65535){A=m;B=C;break}A=((m>>>0)/(C>>>0)|0|0)==16?m:-1;B=C}}while(0);m=ys(A)|0;if((m|0)==0){c[s+4100>>2]=0;break}if((c[m-4>>2]&3|0)==0){p=s+4100|0;c[p>>2]=m;D=p}else{yB(m|0,0,A|0);p=s+4100|0;c[p>>2]=m;D=p}c[s+4104>>2]=B;if(k){x=f;break L3901}else{E=0;F=r;G=h}while(1){p=F+4|0;if((c[p>>2]|0)==0){x=f;break L3901}m=c[D>>2]|0;l=m+(E<<4)+4|0;c[l>>2]=dW(G|0)|0;H=dW(c[p>>2]|0)|0;p=bJ(H|0,53704)|0;if((p|0)==0){q=2703;break}a[p]=0;g=m+(E<<4)|0;c[g>>2]=dW(H|0)|0;j=hk(p+2|0,49872)|0;p=m+(E<<4)+8|0;c[p>>2]=j;if((j|0)==0){q=2705;break}j=c[l>>2]|0;I=(c[u>>2]|0)+4|0;while(1){J=c[I>>2]|0;if((J|0)==0){break}if((db(j|0,c[J+4>>2]|0)|0)==0){q=2709;break}else{I=J+12|0}}if((q|0)==2709){q=0;I=dW(c[J+8>>2]|0)|0;j=c[p>>2]|0;K=c[j+4>>2]|0;L=j|0;j=0;while(1){if(j>>>0>=K>>>0){break}if((db(c[(c[L>>2]|0)+(j<<3)>>2]|0,I|0)|0)==0){q=2712;break}else{j=j+1|0}}if((q|0)==2712){q=0;c[m+(E<<4)+12>>2]=j}yt(I)}yt(H);L=a[405432]|0;if((L&1)==0){M=L}else{L=c[140620]|0;K=(L|0)!=0?L:c[t>>2]|0;be(38544,24,1,K|0)|0;K=c[140620]|0;L=(K|0)!=0?K:c[t>>2]|0;a7(L|0)|0;M=a[405432]|0}if((M&1)==0){N=M}else{L=c[140620]|0;K=(L|0)!=0?L:c[t>>2]|0;L=c[g>>2]|0;eS(K|0,30376,(n=i,i=i+8|0,c[n>>2]=L,n)|0)|0;i=n;L=c[140620]|0;K=(L|0)!=0?L:c[t>>2]|0;a7(K|0)|0;N=a[405432]|0}if((N&1)==0){O=N}else{K=c[140620]|0;L=(K|0)!=0?K:c[t>>2]|0;K=c[l>>2]|0;eS(L|0,25848,(n=i,i=i+8|0,c[n>>2]=K,n)|0)|0;i=n;K=c[140620]|0;L=(K|0)!=0?K:c[t>>2]|0;a7(L|0)|0;O=a[405432]|0}if((O&1)==0){P=O}else{L=c[140620]|0;K=(L|0)!=0?L:c[t>>2]|0;L=c[D>>2]|0;Q=c[(c[c[L+(E<<4)+8>>2]>>2]|0)+(c[L+(E<<4)+12>>2]<<3)>>2]|0;eS(K|0,22384,(n=i,i=i+8|0,c[n>>2]=Q,n)|0)|0;i=n;Q=c[140620]|0;K=(Q|0)!=0?Q:c[t>>2]|0;a7(K|0)|0;P=a[405432]|0}if((P&1)!=0){K=c[140620]|0;Q=(K|0)!=0?K:c[t>>2]|0;be(19736,29,1,Q|0)|0;Q=c[140620]|0;K=(Q|0)!=0?Q:c[t>>2]|0;a7(K|0)|0}K=c[p>>2]|0;if((c[K+4>>2]|0)!=0){Q=0;L=K;while(1){if((a[405432]&1)==0){R=L}else{K=c[140620]|0;S=(K|0)!=0?K:c[t>>2]|0;K=c[(c[L>>2]|0)+(Q<<3)>>2]|0;eS(S|0,17376,(n=i,i=i+8|0,c[n>>2]=K,n)|0)|0;i=n;K=c[140620]|0;S=(K|0)!=0?K:c[t>>2]|0;a7(S|0)|0;R=c[p>>2]|0}S=Q+1|0;if(S>>>0<(c[R+4>>2]|0)>>>0){Q=S;L=R}else{break}}}L=F+8|0;Q=c[L>>2]|0;if((Q|0)==0){x=f;break L3901}else{E=E+1|0;F=L;G=Q}}if((q|0)==2705){yt(H);break}else if((q|0)==2703){yt(H);break}}}while(0);ij(f);x=0}}while(0);c[126128]=x;o=1;i=e;return o|0}else if((b|0)==9){c[d>>2]=(a[397180]|0)!=0?397180:0;if((a[405432]&1)==0){o=1;i=e;return o|0}x=c[140620]|0;eS(((x|0)!=0?x:c[t>>2]|0)|0,48248,(n=i,i=i+8|0,c[n>>2]=397180,n)|0)|0;i=n;x=c[140620]|0;a7(((x|0)!=0?x:c[t>>2]|0)|0)|0;o=1;i=e;return o|0}else if((b|0)==10){x=c[d>>2]|0;do{if((x|0)==0){if((a[405432]&1)==0){break}H=c[140620]|0;G=(H|0)!=0?H:c[t>>2]|0;be(47088,47,1,G|0)|0;G=c[140620]|0;H=(G|0)!=0?G:c[t>>2]|0;a7(H|0)|0}else if((x|0)==2){if((a[405432]&1)==0){break}H=c[140620]|0;be(45768,45,1,((H|0)!=0?H:c[t>>2]|0)|0)|0;H=c[140620]|0;a7(((H|0)!=0?H:c[t>>2]|0)|0)|0}else if((x|0)==1){if((a[405432]&1)==0){break}H=c[140620]|0;be(44216,47,1,((H|0)!=0?H:c[t>>2]|0)|0)|0;H=c[140620]|0;a7(((H|0)!=0?H:c[t>>2]|0)|0)|0}else{o=0;i=e;return o|0}}while(0);c[124948]=x;o=1;i=e;return o|0}else if((b|0)==6){if((a[405432]&1)!=0){x=c[140620]|0;H=(x|0)!=0?x:c[t>>2]|0;x=c[d>>2]|0;eS(H|0,13392,(n=i,i=i+8|0,c[n>>2]=x,n)|0)|0;i=n;x=c[140620]|0;H=(x|0)!=0?x:c[t>>2]|0;a7(H|0)|0}H=c[138489]|0;if((H|0)==0){o=1;i=e;return o|0}x=H+4|0;G=c[x>>2]|0;if(G>>>0>1){F=H|0;E=1;R=G;while(1){G=c[(c[F>>2]|0)+(E<<2)>>2]|0;if((G|0)==0){T=R}else{yt(c[G+8>>2]|0);yt(c[(c[F>>2]|0)+(E<<2)>>2]|0);c[(c[F>>2]|0)+(E<<2)>>2]=0;T=c[x>>2]|0}G=E+1|0;if(G>>>0<T>>>0){E=G;R=T}else{break}}}c[x>>2]=1;x=H+12|0;yt(c[x>>2]|0);c[x>>2]=0;x=c[138489]|0;H=c[d>>2]|0;T=x+4|0;R=c[T>>2]|0;if(R>>>0>=(c[x+8>>2]|0)>>>0){o=1;i=e;return o|0}E=c[d+4>>2]|0;F=ys(12)|0;do{if((F|0)!=0){if((c[F-4>>2]&3|0)==0){break}yB(F|0,0,12)}}while(0);c[F+4>>2]=1;c[F>>2]=E;if((H|0)==0){U=0;V=R}else{R=dW(H|0)|0;U=R;V=c[T>>2]|0}c[F+8>>2]=U;U=x|0;c[(c[U>>2]|0)+(V<<2)>>2]=F;F=c[T>>2]|0;c[T>>2]=F+1;if(F>>>0>1){W=F}else{o=1;i=e;return o|0}while(1){F=W>>>1;T=c[U>>2]|0;V=T+(F<<2)|0;x=c[V>>2]|0;R=c[T+(W<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[x+4>>2]|0)>>>0){o=1;q=2869;break}c[V>>2]=R;c[(c[U>>2]|0)+(W<<2)>>2]=x;if(W>>>0>3){W=F}else{o=1;q=2870;break}}if((q|0)==2869){i=e;return o|0}else if((q|0)==2870){i=e;return o|0}}else if((b|0)==131073|(b|0)==131074){L4037:do{if((d|0)==0){a[442346]=0}else{q=4096;W=442346;U=d;while(1){F=q-1|0;if((F|0)==0){break}x=a[U]|0;a[W]=x;if(x<<24>>24==0){break L4037}else{q=F;W=W+1|0;U=U+1|0}}a[W]=0;if((a[U]|0)==0){break}else{X=U}do{X=X+1|0;}while((a[X]|0)!=0)}}while(0);X=(a[405432]&1)!=0;if((b|0)==131074){if(X){U=c[140620]|0;W=(U|0)!=0?U:c[t>>2]|0;be(23536,42,1,W|0)|0;W=c[140620]|0;U=(W|0)!=0?W:c[t>>2]|0;a7(U|0)|0}a[553960]=1;o=1;i=e;return o|0}else{if(!X){o=1;i=e;return o|0}X=c[140620]|0;U=(X|0)!=0?X:c[t>>2]|0;be(23288,35,1,U|0)|0;U=c[140620]|0;X=(U|0)!=0?U:c[t>>2]|0;a7(X|0)|0;o=1;i=e;return o|0}}else if((b|0)==17){X=c[126128]|0;if((X|0)==0){Y=0}else{Y=a[X+4108|0]&1}a[d]=Y;o=1;i=e;return o|0}else{if((a[405432]&1)==0){o=0;i=e;return o|0}Y=c[140620]|0;eS(((Y|0)!=0?Y:c[t>>2]|0)|0,22992,(n=i,i=i+8|0,c[n>>2]=b,n)|0)|0;i=n;n=c[140620]|0;a7(((n|0)!=0?n:c[t>>2]|0)|0)|0;o=0;i=e;return o|0}return 0}function hK(){return 1}function hL(a,b){a=a|0;b=b|0;return}function hM(a){a=a|0;c[140908]=a;return}function hN(a){a=a|0;c[140910]=a;return}function hO(a){a=a|0;c[140904]=a;return}function hP(a){a=a|0;c[140902]=a;return}function hQ(a){a=a|0;c[140900]=a;return}function hR(){return}function hS(a){a=a|0;return 0}function hT(){return}function hU(){return 0}function hV(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function hW(){return 0}function hX(a,b){a=a|0;b=b|0;return 0}function hY(a,b){a=a|0;b=b|0;return 0}function hZ(a){a=a|0;return 0}function h_(a){a=a|0;return 0}function h$(){return}function h0(a,b,c){a=a|0;b=b|0;c=c|0;return}function h1(a){a=a|0;h[a+24>>3]=60.0;h[a+32>>3]=3.0e4;c[a>>2]=320;c[a+4>>2]=240;c[a+8>>2]=320;c[a+12>>2]=240;g[a+16>>2]=1.3333333730697632;return}function h2(){var a=0;a=ys(153600)|0;do{if((a|0)!=0){if((c[a-4>>2]&3|0)==0){break}yB(a|0,0,153600)}}while(0);c[140898]=a;return}function h3(){yt(c[140898]|0);c[140898]=0;return}function h4(b){b=b|0;yB(b|0,0,16);c[b>>2]=39448;c[b+4>>2]=564064;a[b+12|0]=0;c[b+8>>2]=564064;return}function h5(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[140906]=a;c[d>>2]=2;gm[a&127](10,d)|0;i=b;return}function h6(){var a=0,d=0;gs[c[140904]&63]();a=c[140898]|0;d=0;do{b[a+(d<<1)>>1]=128;d=d+1|0;}while(d>>>0<76800);gu[c[140900]&127](a,320,240,640);return}function h7(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+4|0;if((c[b>>2]|0)==1){d=0;return d|0}e=a|0;f=c[(c[e>>2]|0)+4>>2]|0;g=f|0;h=(c[g>>2]|0)-1|0;c[g>>2]=h;if((h|0)!=0){d=c[f+8>>2]|0;return d|0}h=a+12|0;yt(c[h>>2]|0);a=f+8|0;c[h>>2]=c[a>>2];c[a>>2]=0;a=c[e>>2]|0;f=a+4|0;g=c[f>>2]|0;i=(c[b>>2]|0)-1|0;c[b>>2]=i;c[f>>2]=c[a+(i<<2)>>2];yt(g);g=1;while(1){i=g<<1;a=c[b>>2]|0;if(i>>>0>a>>>0){j=0}else{f=c[e>>2]|0;j=(c[f+(g<<2)>>2]|0)>>>0<(c[f+(i<<2)>>2]|0)>>>0}f=i|1;if(f>>>0>a>>>0){k=0}else{a=c[e>>2]|0;k=(c[a+(g<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0}if(!(j|k)){break}do{if(k|j^1){if(!(j|k^1)){l=f;break}a=c[e>>2]|0;l=(c[a+(i<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0?f:i}else{l=i}}while(0);i=c[e>>2]|0;f=i+(g<<2)|0;a=c[f>>2]|0;c[f>>2]=c[i+(l<<2)>>2];c[(c[e>>2]|0)+(l<<2)>>2]=a;g=l}d=c[h>>2]|0;return d|0}function h8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+16|0;f=e|0;g=f|0;h=f;j=ys(36)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){yB(j|0,0,36)}l=j;m=f;L4129:do{if((d|0)==0){a[j+24|0]=1;n=dA(b|0,12144)|0;c[j>>2]=n;if((n|0)==0){o=c[140620]|0;p=(o|0)!=0?o:c[t>>2]|0;eS(p|0,26920,(q=i,i=i+8|0,c[q>>2]=b,q)|0)|0;i=q;p=c[140620]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0;break}yB(m|0,0,16);if((eM(m|0,4,4,n|0)|0)!=4){o=c[140620]|0;p=(o|0)!=0?o:c[t>>2]|0;be(23072,49,1,p|0)|0;p=c[140620]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0;r=n;s=2960;break}o=c[f>>2]|0;if(!((o|0)==1112757809|(o|0)==827740994)){o=c[140620]|0;p=(o|0)!=0?o:c[t>>2]|0;be(20152,58,1,p|0)|0;p=c[140620]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0;u=n;s=2959;break}if((c[f+8>>2]|0)!=(c[102393]|0)){o=c[140620]|0;p=(o|0)!=0?o:c[t>>2]|0;be(17800,151,1,p|0)|0;p=c[140620]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0}o=c[h+12>>2]|0;do{if((o|0)!=0){p=ys(o)|0;c[j+4>>2]=p;c[j+8>>2]=o;if((p|0)==0){u=n;s=2959;break L4129}if((eM(p|0,1,o|0,n|0)|0)!=(o|0)){v=c[140620]|0;w=(v|0)!=0?v:c[t>>2]|0;be(15504,53,1,w|0)|0;w=c[140620]|0;v=(w|0)!=0?w:c[t>>2]|0;a7(v|0)|0;u=n;s=2959;break L4129}if((gp[c[21506]&31]()|0)==(o|0)){v=c[21488]|0;gm[v&127](p,o)|0;break}else{p=c[140620]|0;v=(p|0)!=0?p:c[t>>2]|0;be(13056,102,1,v|0)|0;v=c[140620]|0;p=(v|0)!=0?v:c[t>>2]|0;a7(p|0)|0;break}}}while(0);p=o+16|0;c[j+28>>2]=p;x=n;y=p;s=2954}else{p=dA(b|0,52200)|0;c[j>>2]=p;if((p|0)==0){v=c[140620]|0;w=(v|0)!=0?v:c[t>>2]|0;eS(w|0,41408,(q=i,i=i+8|0,c[q>>2]=b,q)|0)|0;i=q;w=c[140620]|0;v=(w|0)!=0?w:c[t>>2]|0;a7(v|0)|0;break}c[g>>2]=0;c[g+4>>2]=0;c[f>>2]=827740994;c[f+8>>2]=c[102393];v=gp[c[21506]&31]()|0;c[h+12>>2]=v;be(m|0,4,4,p|0)|0;w=v+16|0;c[j+28>>2]=w;c[j+8>>2]=v;if((v|0)==0){x=p;y=w;s=2954;break}z=ys(v)|0;c[j+4>>2]=z;if((z|0)==0){u=p;s=2959;break}A=c[21508]|0;gm[A&127](z,v)|0;be(z|0,1,v|0,p|0)|0;x=p;y=w;s=2954}}while(0);do{if((s|0)==2954){m=ys(4194304)|0;if((m|0)==0){c[j+12>>2]=0;u=x;s=2959;break}if((c[m-4>>2]&3|0)!=0){yB(m|0,0,4194304)}h=m;c[j+12>>2]=h;c[h>>2]=y;c[j+16>>2]=1048575;k=l;i=e;return k|0}}while(0);if((s|0)==2959){if((u|0)!=0){r=u;s=2960}}if((s|0)==2960){a_(r|0)|0}yt(c[j+4>>2]|0);yt(c[j+12>>2]|0);yt(j);k=0;i=e;return k|0}function h9(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+128|0;h=g+64|0;b5(h|0,64,41984,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=e,j)|0)|0;i=j;j=g|0;e=b+4|0;while(1){k=c[e>>2]|0;if((k|0)==0){l=2983;break}if((db(h|0,c[k+4>>2]|0)|0)==0){break}else{e=k+12|0}}if((l|0)==2983){i=g;return}e=64;h=0;b=j;d=c[k+8>>2]|0;while(1){k=e-1|0;if((k|0)==0){l=2972;break}m=a[d]|0;a[b]=m;if(m<<24>>24==0){n=h;break}else{e=k;h=h+1|0;b=b+1|0;d=d+1|0}}do{if((l|0)==2972){a[b]=0;if((a[d]|0)==0){n=h;break}else{o=d;p=h}while(1){e=o+1|0;k=p+1|0;if((a[e]|0)==0){n=k;break}else{o=e;p=k}}}}while(0);if(n>>>0>=64){i=g;return}do{if((yA(j|0)|0)==1){n=a[j]|0;if((dR(n|0)|0)==0){q=0;l=2978;break}r=yF(n|0)|0}else{q=0;l=2978}}while(0);L4195:do{if((l|0)==2978){while(1){l=0;if((q|0)==67){r=0;break L4195}if((yH(c[6160+(q<<3)>>2]|0,j|0)|0)==0){break}else{q=q+1|0;l=2978}}r=c[6164+(q<<3)>>2]|0}}while(0);c[f+12>>2]=r;i=g;return}function ia(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+136|0;h=g|0;j=g+8|0;k=g+72|0;b5(k|0,64,41888,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;l=j|0;e=b+4|0;while(1){m=c[e>>2]|0;if((m|0)==0){n=3010;break}if((db(k|0,c[m+4>>2]|0)|0)==0){break}else{e=m+12|0}}if((n|0)==3010){i=g;return}e=64;k=0;b=l;d=c[m+8>>2]|0;while(1){m=e-1|0;if((m|0)==0){n=2992;break}o=a[d]|0;a[b]=o;if(o<<24>>24==0){p=k;break}else{e=m;k=k+1|0;b=b+1|0;d=d+1|0}}do{if((n|0)==2992){a[b]=0;if((a[d]|0)==0){p=k;break}else{q=d;r=k}while(1){e=q+1|0;m=r+1|0;if((a[e]|0)==0){p=m;break}else{q=e;r=m}}}}while(0);if(p>>>0>=64){i=g;return}if((db(l|0,42024)|0)==0){p=f+16|0;c[p>>2]=65535;c[p+4>>2]=0;i=g;return}if((a[l]|0)!=104){p=a5(l|0,0,0)|0;l=f+16|0;c[l>>2]=p;c[l+4>>2]=K;i=g;return}l=j+1|0;if(((a[l]|0)-48|0)>>>0>=10){i=g;return}c[h>>2]=0;j=a4(l|0,h|0,0)|0;l=c[h>>2]|0;if((l|0)==0){h=c[140620]|0;p=(h|0)!=0?h:c[t>>2]|0;be(40928,49,1,p|0)|0;p=c[140620]|0;h=(p|0)!=0?p:c[t>>2]|0;a7(h|0)|0;i=g;return}do{if((yH(l|0,27864)|0)==0){s=-32768}else{if((yH(l|0,27440)|0)==0){s=16384;break}if((yH(l|0,27120)|0)==0){s=8192;break}h=(yH(l|0,26664)|0)==0;if(h){s=h?4096:0;break}i=g;return}}while(0);l=f+16|0;c[l>>2]=s&65535|j&4095;c[l+4>>2]=0;i=g;return}function ib(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+128|0;h=g|0;j=g+64|0;b5(j|0,64,41824,(k=i,i=i+16|0,c[k>>2]=d,c[k+8>>2]=e,k)|0)|0;i=k;k=h|0;e=b+4|0;while(1){l=c[e>>2]|0;if((l|0)==0){m=3033;break}if((db(j|0,c[l+4>>2]|0)|0)==0){break}else{e=l+12|0}}if((m|0)==3033){i=g;return}e=64;j=0;b=k;d=c[l+8>>2]|0;while(1){l=e-1|0;if((l|0)==0){m=3022;break}n=a[d]|0;a[b]=n;if(n<<24>>24==0){o=j;break}else{e=l;j=j+1|0;b=b+1|0;d=d+1|0}}do{if((m|0)==3022){a[b]=0;if((a[d]|0)==0){o=j;break}else{p=d;q=j}while(1){e=p+1|0;l=q+1|0;if((a[e]|0)==0){o=l;break}else{p=e;q=l}}}}while(0);if(o>>>0>=64){i=g;return}if((db(k|0,42024)|0)==0){c[f+32>>2]=-1;i=g;return}if((yA(k|0)|0)>>>0<=1){i=g;return}o=a[k]|0;if(!((o<<24>>24|0)==43|(o<<24>>24|0)==45)){i=g;return}o=bb(h+1|0,0,0)|0;if((a[k]|0)==43){c[f+32>>2]=o|-65536;i=g;return}else{c[f+32>>2]=o<<16|65535;i=g;return}}function ic(){var a=0,b=0,d=0,e=0,f=0;a=ys(48)|0;if((a|0)==0){b=0;return b|0}if((c[a-4>>2]&3|0)!=0){yB(a|0,0,48)}d=bz()|0;c[a+44>>2]=d;if((d|0)==0){yt(a);b=0;return b|0}yB(84648,0,1292);d=5088;e=276;while(1){c[84648+(e<<2)>>2]=c[d>>2];f=c[d+12>>2]|0;if((f|0)==0){b=a;break}else{d=d+8|0;e=f}}return b|0}function id(a){a=a|0;var b=0;b=cH(c[a+44>>2]|0)|0;yE(a|0,b|0,44)|0;return}function ie(a,b){a=a|0;b=b|0;return}function ig(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;g=b;do{if((f|0)==1){i=c[d+(e<<2)>>2]|0;if(h>>>0>=56){j=0;break}if((a[i+(h*40|0)|0]&1)==0){j=0;break}k=c[i+(h*40|0)+12>>2]|0;if((k|0)>322){j=0;break}i=c[84648+(k<<2)>>2]|0;j=(a[g+(i>>>3)|0]&1<<(i&7)|0)!=0|0}else if((f|0)==2){if((h|0)==3){j=a[b+41|0]|0;break}else if((h|0)==0){j=c[b+32>>2]&65535;break}else if((h|0)==1){j=c[b+36>>2]&65535;break}else if((h|0)==2){j=a[b+40|0]|0;break}else{j=0;break}}else if((f|0)==3){if((h|0)>322){j=0;break}i=c[84648+(h<<2)>>2]|0;j=(a[g+(i>>>3)|0]&1<<(i&7)|0)!=0|0}else{j=0}}while(0);return j|0}function ih(b,d){b=b|0;d=d|0;var e=0,f=0;if(d>>>0>=56){e=0;return e|0}if((a[327928+(d*40|0)|0]&1)==0){e=0;return e|0}f=c[327940+(d*40|0)>>2]|0;if((f|0)>322){e=0;return e|0}d=c[84648+(f<<2)>>2]|0;e=(a[b+(d>>>3)|0]&1<<(d&7)|0)!=0;return e|0}function ii(a){a=a|0;aU(c[a+44>>2]|0);yt(a);return}function ij(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)==0){return}b=a+4104|0;if((c[b>>2]|0)!=0){d=a+4100|0;e=0;do{yt(c[(c[d>>2]|0)+(e<<4)>>2]|0);yt(c[(c[d>>2]|0)+(e<<4)+4>>2]|0);f=c[(c[d>>2]|0)+(e<<4)+8>>2]|0;if((f|0)!=0){g=f+4|0;h=f|0;i=c[h>>2]|0;if((c[g>>2]|0)==0){j=i}else{k=0;l=i;while(1){yt(c[l+(k<<3)>>2]|0);i=k+1|0;m=c[h>>2]|0;if(i>>>0<(c[g>>2]|0)>>>0){k=i;l=m}else{j=m;break}}}yt(j);yt(f)}e=e+1|0;}while(e>>>0<(c[b>>2]|0)>>>0)}b=c[a>>2]|0;if((b|0)!=0){hA(b)}yt(c[a+4100>>2]|0);yt(a);return}
function ik(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;if(e>>>0<19){j=2;return j|0}k=c[i>>2]|0;l=a[b]|0;m=l&255;n=c[8176+((m&15^15)<<2)>>2]^268435455;o=n>>>4^c[8176+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=66){j=3;return j|0}l=a[b+1|0]|0;m=l&255;n=c[8176+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[8176+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=80){j=3;return j|0}l=a[b+2|0]|0;m=l&255;n=c[8176+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[8176+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=83){j=3;return j|0}l=a[b+3|0]|0;m=l&255;n=c[8176+(((m^o)&15)<<2)>>2]^o>>>4;if(l<<24>>24!=49){j=3;return j|0}l=0;o=0;p=0;q=1;r=n>>>4^c[8176+((n&15^m>>>4)<<2)>>2];m=4;n=7;while(1){s=d[b+m|0]|0;t=c[8176+(((s^r)&15)<<2)>>2]^r>>>4;u=t>>>4^c[8176+((t&15^s>>>4)<<2)>>2];t=m+1|0;v=yV(s&127,0,q,p)|0;w=yL(v,K,o,l)|0;if((s&128|0)!=0){x=0;y=0;z=0;A=1;B=u;C=t;D=n;break}s=q<<7|0>>>25;v=p<<7|q>>>25;E=yL(w,K,s,v)|0;l=K;o=E;p=v;q=s;r=u;m=t;n=n+1|0}while(1){n=d[b+C|0]|0;m=c[8176+(((n^B)&15)<<2)>>2]^B>>>4;r=m>>>4^c[8176+((m&15^n>>>4)<<2)>>2];m=C+1|0;q=yV(n&127,0,A,z)|0;F=yL(q,K,y,x)|0;if((n&128|0)!=0){G=0;H=0;I=0;J=1;L=r;M=m;N=D;break}n=A<<7|0>>>25;q=z<<7|A>>>25;p=yL(F,K,n,q)|0;x=K;y=p;z=q;A=n;B=r;C=m;D=D+1|0}while(1){O=a[b+M|0]|0;D=O&255;C=c[8176+(((D^L)&15)<<2)>>2]^L>>>4;P=C>>>4^c[8176+((C&15^D>>>4)<<2)>>2];Q=M+1|0;C=yV(D&127,0,J,I)|0;R=yL(C,K,H,G)|0;if((D&128|0)!=0){break}D=J<<7|0>>>25;C=I<<7|J>>>25;B=yL(R,K,D,C)|0;G=K;H=B;I=C;J=D;L=P;M=Q;N=N+1|0}M=w;w=F;F=R;if((F|0)==0){S=P;T=Q}else{R=yV(O&127,0,J,I)|0;I=yL(R,K,H,G)|0;G=P;P=Q;Q=0;while(1){H=d[b+P|0]|0;R=c[8176+(((H^G)&15)<<2)>>2]^G>>>4;U=R>>>4^c[8176+((R&15^H>>>4)<<2)>>2];H=Q+1|0;if(H>>>0<F>>>0){G=U;P=P+1|0;Q=H}else{break}}S=U;T=I+N|0}if(M>>>0>g>>>0){j=5;return j|0}if(w>>>0>k>>>0){j=6;return j|0}k=e-12|0;e=T;T=0;M=0;N=S;S=-1;I=0;L4376:while(1){U=e;Q=T;P=N;G=S;F=I;while(1){H=U;R=P;V=G;W=F;L4380:while(1){X=H;Y=R;while(1){if(X>>>0<k>>>0){Z=0;_=0;$=0;aa=1;ab=Y;ac=X}else{break L4376}while(1){J=d[b+ac|0]|0;O=c[8176+(((J^ab)&15)<<2)>>2]^ab>>>4;ad=O>>>4^c[8176+((O&15^J>>>4)<<2)>>2];ae=ac+1|0;O=yV(J&127,0,aa,$)|0;af=yL(O,K,_,Z)|0;if((J&128|0)!=0){break}J=aa<<7|0>>>25;O=$<<7|aa>>>25;L=yL(af,K,J,O)|0;Z=K;_=L;$=O;aa=J;ab=ad;ac=ae}ag=af;ah=ag&3;if((ah|0)==0){ai=3124;break}else if((ah|0)==1){ai=3126;break}else if((ah|0)==2|(ah|0)==3){break L4380}else{X=ae;Y=ad}}if((ai|0)==3124){ai=0;J=(ag>>>2)+1|0;O=W;L=V;D=J;while(1){C=a[f+O|0]|0;a[h+O|0]=C;B=C&255;C=c[8176+(((B^L)&15)<<2)>>2]^L>>>4;A=C>>>4^c[8176+((C&15^B>>>4)<<2)>>2];B=D-1|0;if((B|0)==0){aj=ae;ak=ad;al=A;am=J;break}else{O=O+1|0;L=A;D=B}}}else if((ai|0)==3126){ai=0;D=(ag>>>2)+1|0;L=W;O=V;J=ad;B=ae;A=D;while(1){C=A-1|0;z=a[b+B|0]|0;y=z&255;x=c[8176+(((y^J)&15)<<2)>>2]^J>>>4;m=y>>>4;an=x>>>4^c[8176+((x&15^m)<<2)>>2];a[h+L|0]=z;z=c[8176+(((y^O)&15)<<2)>>2]^O>>>4;ao=z>>>4^c[8176+((z&15^m)<<2)>>2];if((C|0)==0){break}else{L=L+1|0;O=ao;J=an;B=B+1|0;A=C}}aj=D+ae|0;ak=an;al=ao;am=D}H=aj;R=ak;V=al;W=am+W|0}ap=(ag>>>2)+1|0;R=0;H=0;A=0;B=1;J=ad;O=ae;while(1){L=d[b+O|0]|0;C=c[8176+(((L^J)&15)<<2)>>2]^J>>>4;aq=C>>>4^c[8176+((C&15^L>>>4)<<2)>>2];ar=O+1|0;C=yV(L&127,0,B,A)|0;as=yL(C,K,H,R)|0;if((L&128|0)!=0){break}L=B<<7|0>>>25;C=A<<7|B>>>25;m=yL(as,K,L,C)|0;R=K;H=m;A=C;B=L;J=aq;O=ar}O=as;J=O>>1;at=(O&1|0)==0?J:-J|0;if((ah|0)!=2){break}J=W;O=V;B=at+Q|0;A=ap;while(1){H=A-1|0;R=a[f+B|0]|0;a[h+J|0]=R;L=R&255;R=c[8176+(((L^O)&15)<<2)>>2]^O>>>4;au=R>>>4^c[8176+((R&15^L>>>4)<<2)>>2];if((H|0)==0){break}else{J=J+1|0;O=au;B=B+1|0;A=H}}U=ar;Q=ap+Q+at|0;P=aq;G=au;F=ap+W|0}F=W;G=V;P=at+M|0;U=ap;while(1){A=U-1|0;B=a[h+P|0]|0;a[h+F|0]=B;O=B&255;B=c[8176+(((O^G)&15)<<2)>>2]^G>>>4;av=B>>>4^c[8176+((B&15^O>>>4)<<2)>>2];if((A|0)==0){break}else{F=F+1|0;G=av;P=P+1|0;U=A}}e=ar;T=Q;M=ap+M+at|0;N=aq;S=av;I=ap+W|0}W=d[b+X|0]|0;ap=c[8176+(((W^Y)&15)<<2)>>2]^Y>>>4;Y=ap>>>4^c[8176+((ap&15^W>>>4)<<2)>>2];ap=d[b+(X+1)|0]|0;I=c[8176+(((ap^Y)&15)<<2)>>2]^Y>>>4;Y=I>>>4^c[8176+((I&15^ap>>>4)<<2)>>2];I=d[b+(X+2)|0]|0;av=c[8176+(((I^Y)&15)<<2)>>2]^Y>>>4;Y=av>>>4^c[8176+((av&15^I>>>4)<<2)>>2];av=d[b+(X+3)|0]|0;S=c[8176+(((av^Y)&15)<<2)>>2]^Y>>>4;Y=S>>>4^c[8176+((S&15^av>>>4)<<2)>>2];S=d[b+(X+4)|0]|0;aq=c[8176+(((S^Y)&15)<<2)>>2]^Y>>>4;Y=aq>>>4^c[8176+((aq&15^S>>>4)<<2)>>2];aq=ap<<8|W|I<<16|av<<24;av=d[b+(X+5)|0]|0;I=c[8176+(((av^Y)&15)<<2)>>2]^Y>>>4;Y=I>>>4^c[8176+((I&15^av>>>4)<<2)>>2];I=d[b+(X+6)|0]|0;W=c[8176+(((I^Y)&15)<<2)>>2]^Y>>>4;Y=W>>>4^c[8176+((W&15^I>>>4)<<2)>>2];W=d[b+(X+7)|0]|0;ap=c[8176+(((W^Y)&15)<<2)>>2]^Y>>>4;Y=~(ap>>>4^c[8176+((ap&15^W>>>4)<<2)>>2]);ap=(d[b+(X+9)|0]|0)<<8|(d[b+(X+8)|0]|0)|(d[b+(X+10)|0]|0)<<16|(d[b+(X+11)|0]|0)<<24;if((f|0)==0|(g|0)==0){aw=0}else{X=g;g=f;f=-1;while(1){b=X-1|0;N=d[g]|0;at=c[8176+(((N^f)&15)<<2)>>2]^f>>>4;ax=at>>>4^c[8176+((at&15^N>>>4)<<2)>>2];if((b|0)==0){break}else{X=b;g=g+1|0;f=ax}}aw=~ax}if((aw|0)!=(aq|0)){j=9;return j|0}if((av<<8|S|I<<16|W<<24|0)!=(~V|0)){j=10;return j|0}if((ap|0)!=(Y|0)){j=11;return j|0}c[i>>2]=w;j=1;return j|0}function il(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;j=c[i>>2]|0;if(e>>>0<=17){k=4;return k|0}l=a[b]|0;m=l&255;n=c[8176+((m&15^15)<<2)>>2]^268435455;o=n>>>4^c[8176+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=85){k=4;return k|0}l=a[b+1|0]|0;m=l&255;n=c[8176+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[8176+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=80){k=4;return k|0}l=a[b+2|0]|0;m=l&255;n=c[8176+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[8176+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=83){k=4;return k|0}l=a[b+3|0]|0;m=l&255;n=c[8176+(((m^o)&15)<<2)>>2]^o>>>4;if(l<<24>>24!=49){k=4;return k|0}l=0;o=0;p=0;q=1;r=4;s=n>>>4^c[8176+((n&15^m>>>4)<<2)>>2];while(1){if(r>>>0<e>>>0){m=d[b+r|0]|0;n=c[8176+(((m^s)&15)<<2)>>2]^s>>>4;t=n>>>4^c[8176+((n&15^m>>>4)<<2)>>2];n=r+1|0;u=yV(m&127,0,q,p)|0;v=yL(u,K,o,l)|0;if((m&128|0)==0){w=K;x=v;y=n;z=t}else{A=0;B=0;C=0;D=1;E=n;F=t;break}}else{w=l;x=o;y=r;z=s}t=q<<7|0>>>25;n=p<<7|q>>>25;m=yL(x,w,t,n)|0;l=K;o=m;p=n;q=t;r=y;s=z}while(1){if(E>>>0<e>>>0){z=d[b+E|0]|0;s=c[8176+(((z^F)&15)<<2)>>2]^F>>>4;G=s>>>4^c[8176+((s&15^z>>>4)<<2)>>2];H=E+1|0;s=yV(z&127,0,D,C)|0;I=yL(s,K,B,A)|0;if((z&128|0)==0){J=K;L=I;M=H;N=G}else{break}}else{J=A;L=B;M=E;N=F}z=D<<7|0>>>25;s=C<<7|D>>>25;y=yL(L,J,z,s)|0;A=K;B=y;C=s;D=z;E=M;F=N}N=v;v=I;I=(N|0)==(g|0);F=(v|0)==(g|0);if(!(I|F)){k=7;return k|0}M=I?v:N;c[i>>2]=M;if(j>>>0<M>>>0){k=6;return k|0}j=e-12|0;if(H>>>0<j>>>0){i=-1;E=-1;D=G;C=0;B=0;A=H;while(1){J=0;L=0;z=0;s=1;y=A;r=D;while(1){if(y>>>0<e>>>0){q=d[b+y|0]|0;p=c[8176+(((q^r)&15)<<2)>>2]^r>>>4;O=p>>>4^c[8176+((p&15^q>>>4)<<2)>>2];P=y+1|0;p=yV(q&127,0,s,z)|0;Q=yL(p,K,L,J)|0;if((q&128|0)==0){R=K;S=Q;T=P;U=O}else{break}}else{R=J;S=L;T=y;U=r}q=s<<7|0>>>25;p=z<<7|s>>>25;o=yL(S,R,q,p)|0;J=K;L=o;z=p;s=q;y=T;r=U}r=Q;if((r|0)==0){V=P;W=B;X=C;Y=O;Z=E;_=i}else{y=i;s=E;z=C;L=B;J=r;while(1){q=J-1|0;if(L>>>0<g>>>0){p=a[f+L|0]|0;o=p&255;l=c[8176+(((o^s)&15)<<2)>>2]^s>>>4;$=p;aa=L+1|0;ab=l>>>4^c[8176+((l&15^o>>>4)<<2)>>2]}else{$=0;aa=L;ab=s}if(z>>>0<M>>>0){a[h+z|0]=$;o=$&255;l=c[8176+(((o^y)&15)<<2)>>2]^y>>>4;ac=l>>>4^c[8176+((l&15^o>>>4)<<2)>>2]}else{ac=y}if((q|0)==0){break}else{y=ac;s=ab;z=z+1|0;L=aa;J=q}}V=P;W=aa;X=r+C|0;Y=O;Z=ab;_=ac}while(1){if(V>>>0<e>>>0){J=a[b+V|0]|0;L=J&255;z=c[8176+(((L^Y)&15)<<2)>>2]^Y>>>4;ad=J;ae=V+1|0;af=z>>>4^c[8176+((z&15^L>>>4)<<2)>>2]}else{ad=0;ae=V;af=Y}if(W>>>0<g>>>0){L=a[f+W|0]|0;z=L&255;J=c[8176+(((z^Z)&15)<<2)>>2]^Z>>>4;ag=L;ah=W+1|0;ai=J>>>4^c[8176+((J&15^z>>>4)<<2)>>2]}else{ag=0;ah=W;ai=Z}z=ag^ad;if(X>>>0<M>>>0){a[h+X|0]=z;J=z&255;z=c[8176+(((J^_)&15)<<2)>>2]^_>>>4;aj=z>>>4^c[8176+((z&15^J>>>4)<<2)>>2]}else{aj=_}ak=X+1|0;if(ad<<24>>24==0){break}else{V=ae;W=ah;X=ak;Y=af;Z=ai;_=aj}}if(ae>>>0<j>>>0){i=aj;E=ai;D=af;C=ak;B=ah;A=ae}else{al=aj;am=ai;an=af;ao=ak;ap=ah;aq=ae;break}}}else{al=-1;am=-1;an=G;ao=0;ap=0;aq=H}if(ap>>>0<g>>>0){H=al;G=am;ae=ao;ah=ap;while(1){ak=a[f+ah|0]|0;af=ak&255;ai=c[8176+(((af^G)&15)<<2)>>2]^G>>>4;aj=af>>>4;ar=ai>>>4^c[8176+((ai&15^aj)<<2)>>2];ai=ah+1|0;if(ae>>>0<M>>>0){a[h+ae|0]=ak;ak=c[8176+(((af^H)&15)<<2)>>2]^H>>>4;as=ak>>>4^c[8176+((ak&15^aj)<<2)>>2]}else{as=H}if(ai>>>0<g>>>0){H=as;G=ar;ae=ae+1|0;ah=ai}else{break}}at=as;au=ar;av=g-ap+ao|0;aw=g}else{at=al;au=am;av=ao;aw=ap}if(av>>>0<M>>>0){ap=at;ao=au;am=av;av=aw;while(1){if(av>>>0<g>>>0){aw=a[f+av|0]|0;al=aw&255;ar=c[8176+(((al^ao)&15)<<2)>>2]^ao>>>4;ax=aw;ay=av+1|0;az=ar>>>4^c[8176+((ar&15^al>>>4)<<2)>>2]}else{ax=0;ay=av;az=ao}a[h+am|0]=ax;al=ax&255;ar=c[8176+(((al^ap)&15)<<2)>>2]^ap>>>4;aw=ar>>>4^c[8176+((ar&15^al>>>4)<<2)>>2];al=am+1|0;if(al>>>0<M>>>0){ap=aw;ao=az;am=al;av=ay}else{aA=aw;aB=az;break}}}else{aA=at;aB=au}if(aq>>>0<e>>>0){au=d[b+aq|0]|0;at=c[8176+(((au^an)&15)<<2)>>2]^an>>>4;aC=au;aD=aq+1|0;aE=at>>>4^c[8176+((at&15^au>>>4)<<2)>>2]}else{aC=0;aD=aq;aE=an}if(aD>>>0<e>>>0){an=d[b+aD|0]|0;aq=c[8176+(((an^aE)&15)<<2)>>2]^aE>>>4;aF=an<<8;aG=aD+1|0;aH=aq>>>4^c[8176+((aq&15^an>>>4)<<2)>>2]}else{aF=0;aG=aD;aH=aE}if(aG>>>0<e>>>0){aE=d[b+aG|0]|0;aD=c[8176+(((aE^aH)&15)<<2)>>2]^aH>>>4;aI=aE<<16;aJ=aG+1|0;aK=aD>>>4^c[8176+((aD&15^aE>>>4)<<2)>>2]}else{aI=0;aJ=aG;aK=aH}if(aJ>>>0<e>>>0){aH=d[b+aJ|0]|0;aG=c[8176+(((aH^aK)&15)<<2)>>2]^aK>>>4;aL=aH<<24;aM=aJ+1|0;aN=aG>>>4^c[8176+((aG&15^aH>>>4)<<2)>>2]}else{aL=0;aM=aJ;aN=aK}aK=aF|aC|aI|aL;if(aM>>>0<e>>>0){aL=d[b+aM|0]|0;aI=c[8176+(((aL^aN)&15)<<2)>>2]^aN>>>4;aO=aL;aP=aM+1|0;aQ=aI>>>4^c[8176+((aI&15^aL>>>4)<<2)>>2]}else{aO=0;aP=aM;aQ=aN}if(aP>>>0<e>>>0){aN=d[b+aP|0]|0;aM=c[8176+(((aN^aQ)&15)<<2)>>2]^aQ>>>4;aR=aN<<8;aS=aP+1|0;aT=aM>>>4^c[8176+((aM&15^aN>>>4)<<2)>>2]}else{aR=0;aS=aP;aT=aQ}if(aS>>>0<e>>>0){aQ=d[b+aS|0]|0;aP=c[8176+(((aQ^aT)&15)<<2)>>2]^aT>>>4;aU=aQ<<16;aV=aS+1|0;aW=aP>>>4^c[8176+((aP&15^aQ>>>4)<<2)>>2]}else{aU=0;aV=aS;aW=aT}if(aV>>>0<e>>>0){aT=d[b+aV|0]|0;aS=c[8176+(((aT^aW)&15)<<2)>>2]^aW>>>4;aX=aT<<24;aY=aV+1|0;aZ=aS>>>4^c[8176+((aS&15^aT>>>4)<<2)>>2]}else{aX=0;aY=aV;aZ=aW}aW=aR|aO|aU|aX;aX=~aB;if(aY>>>0<e>>>0){a_=d[b+aY|0]|0;a$=aY+1|0}else{a_=0;a$=aY}if(a$>>>0<e>>>0){a0=(d[b+a$|0]|0)<<8;a1=a$+1|0}else{a0=0;a1=a$}if(a1>>>0<e>>>0){a2=(d[b+a1|0]|0)<<16;a3=a1+1|0}else{a2=0;a3=a1}if(a3>>>0<e>>>0){a4=(d[b+a3|0]|0)<<24}else{a4=0}a3=~aA;if((a0|a_|a2|a4|0)!=(~aZ|0)){k=4;return k|0}if(!((aK|0)!=(aX|0)|I^1)){return((aW|0)==(a3|0)&(M|0)==(v|0)?1:8)|0}if((aW|0)!=(aX|0)|F^1){k=7;return k|0}k=(aK|0)==(a3|0)&(M|0)==(N|0)?1:8;return k|0}function im(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if(e>>>0<8){j=4;return j|0}if((a[b]|0)!=80){j=4;return j|0}if((a[b+1|0]|0)!=65){j=4;return j|0}if((a[b+2|0]|0)!=84){j=4;return j|0}if((a[b+3|0]|0)!=67){j=4;return j|0}if((a[b+4|0]|0)!=72){j=4;return j|0}yE(h|0,f|0,g)|0;c[i>>2]=g;g=e-3|0;if(g>>>0<5){j=4;return j|0}f=e-2|0;k=5;while(1){l=k+3|0;m=d[b+(k+1)|0]<<8|d[b+k|0]<<16|d[b+(k+2)|0];if((m|0)==4542278){if((l|0)==(e|0)){j=1;n=3264;break}if((l|0)==(g|0)){n=3245;break}}if(l>>>0>f>>>0){j=4;n=3265;break}o=k+5|0;p=d[b+l|0]<<8|d[b+(k+4)|0];if((p|0)==0){if(o>>>0>g>>>0){j=4;n=3260;break}l=d[b+o|0]<<8|d[b+(k+6)|0];if((l|0)==0){j=4;n=3268;break}q=b+(k+7)|0;r=m;s=l;while(1){t=s-1|0;a[h+r|0]=a[q]|0;if((t|0)==0){break}else{r=r+1|0;s=t}}u=l;v=k+8|0}else{if(o>>>0>(e-p|0)>>>0){j=4;n=3273;break}else{w=o;x=m;y=p}while(1){s=y-1|0;a[h+x|0]=a[b+w|0]|0;if((s|0)==0){break}else{w=w+1|0;x=x+1|0;y=s}}u=p;v=p+o|0}l=u+m|0;if(l>>>0>(c[i>>2]|0)>>>0){c[i>>2]=l}if(v>>>0>g>>>0){j=4;n=3272;break}else{k=v}}if((n|0)==3264){return j|0}else if((n|0)==3260){return j|0}else if((n|0)==3245){c[i>>2]=d[b+(k+4)|0]<<8|d[b+g|0]<<16|d[b+(k+5)|0];j=1;return j|0}else if((n|0)==3272){return j|0}else if((n|0)==3273){return j|0}else if((n|0)==3265){return j|0}else if((n|0)==3268){return j|0}return 0}function io(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+8|0;e=d|0;f=c[140620]|0;be(52880,85,1,((f|0)!=0?f:c[t>>2]|0)|0)|0;f=c[140620]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;c[e>>2]=0;f=dA(b|0,11144)|0;if((f|0)==0){g=0;i=d;return g|0}b=ys(4)|0;if((b|0)==0){a_(f|0)|0;g=0;i=d;return g|0}if((c[b-4>>2]&3|0)!=0){h=b;C=0;a[h]=C&255;C=C>>8;a[h+1|0]=C&255;C=C>>8;a[h+2|0]=C&255;C=C>>8;a[h+3|0]=C&255}h=b;e6(f|0,0,2)|0;j=cy(f|0)|0;fe(f|0);k=ys(j+1|0)|0;do{if((k|0)==0){l=0;m=3288}else{a[k+j|0]=0;if((eM(k|0,1,j|0,f|0)|0)!=(j|0)){l=k;m=3288;break}a_(f|0)|0;c[e>>2]=k;do{if((yJ(k|0,52176,5)|0)==0){n=bJ(k|0,49528)|0;if((n|0)==0){o=k;break}p=n+3|0;c[e>>2]=p;q=p;m=3283}else{q=k;m=3283}}while(0);do{if((m|0)==3283){p=yA(q|0)|0;n=ys(p+1|0)|0;if((n|0)==0){o=k;break}a[n+p|0]=0;p=bJ(q|0,12552)|0;r=bJ(q|0,54880)|0;if((p|0)==0|(r|0)==0){s=q;u=n}else{v=q;w=n;x=p;p=r;while(1){r=x-v|0;yE(w|0,v|0,r)|0;y=w+r|0;r=p+3|0;z=bJ(r|0,12552)|0;A=bJ(r|0,54880)|0;if((z|0)==0|(A|0)==0){s=r;u=y;break}else{v=r;w=y;x=z;p=A}}}p=yA(s|0)|0;yE(u|0,s|0,p)|0;a[u+p|0]=0;yt(k);c[e>>2]=n;p=ip(e)|0;c[b>>2]=p;if((p|0)==0){o=n;break}yt(n);g=h;i=d;return g|0}}while(0);yt(o)}}while(0);if((m|0)==3288){yt(l);a_(f|0)|0}f=c[b>>2]|0;if((f|0)!=0){iq(f)}yt(b);g=0;i=d;return g|0}function ip(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=ys(24)|0;if((g|0)==0){h=0;i=d;return h|0}if((c[g-4>>2]&3|0)!=0){yB(g|0,0,24)}j=g;k=c[b>>2]|0;while(1){l=k+1|0;if((bp(a[k]|0)|0)==0){break}else{k=l}}c[b>>2]=k;L4649:do{if((a[k]|0)==60){m=co(k|0,62)|0;if((m|0)==0){n=0;break}o=m-l|0;p=ys(o+1|0)|0;if((p|0)==0){n=0;break}yE(p|0,l|0,o)|0;a[p+o|0]=0;o=p;while(1){if((bp(a[o]|0)|0)==0){q=o;break}else{o=o+1|0}}while(1){r=a[q]|0;if(r<<24>>24==0){s=0;break}if((bp(r<<24>>24|0)|0)==0){q=q+1|0}else{t=3311;break}}if((t|0)==3311){s=a[q]|0}r=(bp(s|0)|0)!=0?q:0;if((r|0)==0){u=dW(o|0)|0;c[g>>2]=u;if((u|0)==0){n=p;break}if((a[u]|0)==0){n=p;break}}else{u=r-o|0;v=ys(u+1|0)|0;if((v|0)==0){c[g>>2]=0;n=p;break}yE(v|0,o|0,u)|0;a[v+u|0]=0;c[g>>2]=v;if((a[v]|0)==0){n=p;break}v=dW(r|0)|0;if((v|0)==0){w=0}else{r=v+((yA(v|0)|0)-1)|0;if((a[r]|0)==47){a[r]=0}r=eO(v|0,17368,e|0)|0;L4674:do{if((r|0)==0){x=0}else{u=r;y=0;z=0;while(1){A=bJ(u|0,15056)|0;if((A|0)==0){x=z;break L4674}B=A+2|0;C=cE(B|0,34)|0;if((C|0)==0){x=z;break L4674}if((C|0)!=(u+((yA(u|0)|0)-1)|0)){x=z;break L4674}D=A-u|0;A=ys(D+1|0)|0;if((A|0)==0){E=0}else{yE(A|0,u|0,D)|0;a[A+D|0]=0;E=A}A=C-B|0;C=ys(A+1|0)|0;if((C|0)==0){x=z;break L4674}yE(C|0,B|0,A)|0;a[C+A|0]=0;if((E|0)==0){x=z;break L4674}A=ys(12)|0;if((A|0)==0){x=z;break L4674}if((c[A-4>>2]&3|0)!=0){yB(A|0,0,12)}B=A;c[A>>2]=E;c[A+4>>2]=C;if((y|0)==0){F=B}else{c[y+8>>2]=B;F=z}C=eO(0,17368,e|0)|0;if((C|0)==0){x=F;break}else{u=C;y=B;z=F}}}}while(0);yt(v);w=x}c[g+8>>2]=w}if(((bJ(k|0,38536)|0)+1|0)==(m|0)){c[b>>2]=m+1}else{r=c[g>>2]|0;o=(yA(r|0)|0)+4|0;z=ys(o)|0;if((z|0)==0){n=p;break}b5(z|0,o|0,30368,(o=i,i=i+8|0,c[o>>2]=r,o)|0)|0;i=o;o=m+1|0;r=bJ(o|0,25832)|0;y=co(o|0,60)|0;u=bJ(o|0,z|0)|0;if((u|0)==0){yt(z);n=p;break}L4702:do{if((r|0)==0){t=3349}else{B=o;while(1){if(B>>>0>=r>>>0){break}if((bp(a[B]|0)|0)==0){t=3349;break L4702}else{B=B+1|0}}B=bJ(r|0,22376)|0;if((B|0)==0){yt(z);n=p;break L4649}C=r+9|0;A=B-C|0;B=ys(A+1|0)|0;if((B|0)==0){G=0}else{yE(B|0,C|0,A)|0;a[B+A|0]=0;G=B}c[g+4>>2]=G;H=u}}while(0);do{if((t|0)==3349){if((u|0)==(y|0)){r=y-o|0;m=ys(r+1|0)|0;if((m|0)==0){I=0}else{yE(m|0,o|0,r)|0;a[m+r|0]=0;I=m}c[g+4>>2]=I;H=y;break}c[f>>2]=y;m=co(y|0,60)|0;r=bJ(y|0,19728)|0;L4721:do{if((r|0)!=0&(m|0)!=0&m>>>0<r>>>0){v=0;B=0;while(1){A=ip(f)|0;if((A|0)==0){break}if((B|0)==0){J=A}else{c[B+16>>2]=A;J=v}C=c[f>>2]|0;D=co(C|0,60)|0;K=bJ(C|0,19728)|0;if((K|0)!=0&(D|0)!=0&D>>>0<K>>>0){v=J;B=A}else{L=J;M=C;break L4721}}yt(z);n=p;break L4649}else{L=0;M=y}}while(0);c[g+12>>2]=L;r=bJ(M|0,z|0)|0;if((r|0)!=0){H=r;break}yt(z);n=p;break L4649}}while(0);c[b>>2]=H+(yA(z|0)|0);yt(z)}yt(p);h=j;i=d;return h|0}else{n=0}}while(0);yt(n);iq(j);h=0;i=d;return h|0}function iq(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((b|0)!=0){d=b;while(1){b=c[d+16>>2]|0;iq(d);if((b|0)==0){break}else{d=b}}}d=c[a+8>>2]|0;if((d|0)!=0){b=d;while(1){d=c[b+8>>2]|0;yt(c[b>>2]|0);yt(c[b+4>>2]|0);yt(b);if((d|0)==0){break}else{b=d}}}yt(c[a>>2]|0);yt(c[a+4>>2]|0);yt(a);return}function ir(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b;g=f-a|0;h=g>>2;do{if((h|0)==0){j=0}else{if(h>>>0<=65535){j=g;break}j=((g>>>0)/(h>>>0)|0|0)==4?g:-1}}while(0);k=ys(j)|0;if((k|0)==0){l=c[140620]|0;m=(l|0)!=0?l:c[t>>2]|0;eS(m|0,35072,(m=i,i=i+16|0,c[m>>2]=52256,c[m+8>>2]=150,m)|0)|0;i=m;m=c[140620]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0;cA(2)}if((c[k-4>>2]&3|0)!=0){yB(k|0,0,j|0)}j=a;yE(k|0,j|0,g)|0;yI(j|0,b|0,d-f|0);f=d+(-h<<2)|0;yE(f|0,k|0,g)|0;yt(k);i=e;return}function is(a){a=a|0;return 1}function it(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=i;i=i+8256|0;k=j|0;l=j+8|0;m=j+64|0;n=j+4160|0;o=n|0;fp(k|0)|0;dj(o|0,4096,11736,bq(k|0)|0)|0;k=yA(o|0)|0;p=k>>>0>4096?0:4096-k|0;L4758:do{if((p|0)==0){q=52584;r=3387}else{s=n+k|0;do{if((p|0)==1){u=52584;v=s}else{w=n+(k+1)|0;a[s]=98;if((p|0)==2){u=52585;v=w;break}x=n+(k+2)|0;a[w]=109;if((p|0)==3){u=52586;v=x;break}w=n+(k+3)|0;a[x]=112;if((p|0)==4){u=52587;v=w;break}a[w]=0;break L4758}}while(0);a[v]=0;q=u;r=3387}}while(0);do{if((r|0)==3387){if((a[q]|0)==0){break}else{y=q}do{y=y+1|0;}while((a[y]|0)!=0)}}while(0);y=m|0;hm(y,393084,o);o=dA(y|0,52200)|0;if((o|0)==0){m=c[140620]|0;q=(m|0)!=0?m:c[t>>2]|0;eS(q|0,38376,(q=i,i=i+8|0,c[q>>2]=y,q)|0)|0;i=q;q=c[140620]|0;y=(q|0)!=0?q:c[t>>2]|0;a7(y|0)|0;z=0;i=j;return z|0}y=l|0;q=e*3|0;m=q+3&-4;u=ag(m,f)|0;v=u+54|0;a[y]=66;a[l+1|0]=77;a[l+2|0]=v&255;a[l+3|0]=v>>>8&255;a[l+4|0]=v>>>16&255;a[l+5|0]=v>>>24&255;v=l+6|0;C=0;a[v]=C&255;C=C>>8;a[v+1|0]=C&255;C=C>>8;a[v+2|0]=C&255;C=C>>8;a[v+3|0]=C&255;a[l+10|0]=54;a[l+11|0]=0;a[l+12|0]=0;a[l+13|0]=0;a[l+14|0]=40;a[l+15|0]=0;a[l+16|0]=0;a[l+17|0]=0;a[l+18|0]=e&255;a[l+19|0]=e>>>8&255;a[l+20|0]=e>>>16&255;a[l+21|0]=e>>>24&255;a[l+22|0]=f&255;a[l+23|0]=f>>>8&255;a[l+24|0]=f>>>16&255;a[l+25|0]=f>>>24&255;a[l+26|0]=1;a[l+27|0]=0;a[l+28|0]=24;yB(l+29|0,0,5);a[l+34|0]=u&255;a[l+35|0]=u>>>8&255;a[l+36|0]=u>>>16&255;a[l+37|0]=u>>>24&255;a[l+38|0]=19;a[l+39|0]=11;a[l+40|0]=0;a[l+41|0]=0;a[l+42|0]=19;a[l+43|0]=11;yB(l+44|0,0,10);l=(be(y|0,1,54,o|0)|0)==54;do{if(l){y=(f|0)==0;do{if(y){A=0}else{u=f<<2;if(f>>>0<=65535){A=u;break}A=((u>>>0)/(f>>>0)|0|0)==4?u:-1}}while(0);u=ys(A)|0;if((u|0)==0){break}if((c[u-4>>2]&3|0)!=0){yB(u|0,0,A|0)}v=u;p=0;while(1){if((p|0)>=(f|0)){r=3405;break}k=ys(m)|0;if((k|0)==0){r=3404;break}if((c[k-4>>2]&3|0)!=0){yB(k|0,0,m|0)}c[v+(p<<2)>>2]=k;p=p+1|0}do{if((r|0)==3405){do{if(h){if((f|0)>0){B=d;D=0}else{r=3419;break}while(1){k=c[v+(D<<2)>>2]|0;yE(k|0,B|0,q)|0;k=D+1|0;if((k|0)<(f|0)){B=B+g|0;D=k}else{r=3419;break}}}else{k=(f|0)>0;if((c[124948]|0)==1){if(!k){r=3419;break}if((e|0)==0){E=0;break}else{F=d;G=0}while(1){n=F;s=0;w=c[v+(G<<2)>>2]|0;while(1){x=c[n>>2]|0;a[w]=x&255;a[w+1|0]=x>>>8&255;a[w+2|0]=x>>>16&255;x=s+1|0;if(x>>>0<e>>>0){n=n+4|0;s=x;w=w+3|0}else{break}}w=G+1|0;if((w|0)<(f|0)){F=F+g|0;G=w}else{r=3419;break}}}else{if(!k){r=3419;break}if((e|0)==0){E=0;break}else{H=d;I=0}while(1){w=0;s=H;n=c[v+(I<<2)>>2]|0;while(1){x=b[s>>1]|0;J=x&255;a[n]=(J&255)>>>2&7|J<<3;a[n+1|0]=(x&65535)>>>5<<2&255|(x&65535)>>>9&3;J=(x&65535)>>>11&65535;a[n+2|0]=(J<<3|J>>>2)&255;J=w+1|0;if(J>>>0<e>>>0){w=J;s=s+2|0;n=n+3|0}else{break}}n=I+1|0;if((n|0)<(f|0)){H=H+g|0;I=n}else{r=3419;break}}}}}while(0);if((r|0)==3419){if(y){break}else{E=0}}while(1){be(c[v+(E<<2)>>2]|0,1,m|0,o|0)|0;k=E+1|0;if(k>>>0<f>>>0){E=k}else{r=3421;break}}}else if((r|0)==3404){c[v+(p<<2)>>2]=0;r=3421}}while(0);do{if((r|0)==3421){if((f|0)>0){K=0}else{break}do{yt(c[v+(K<<2)>>2]|0);K=K+1|0;}while((K|0)<(f|0))}}while(0);yt(u)}else{v=c[140620]|0;be(30312,51,1,((v|0)!=0?v:c[t>>2]|0)|0)|0;v=c[140620]|0;a7(((v|0)!=0?v:c[t>>2]|0)|0)|0}}while(0);a_(o|0)|0;z=l;i=j;return z|0}function iu(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+544|0;e=d|0;if((b|0)==0){i=d;return}f=b|0;if((c[f>>2]|0)!=0){g=e|0;h=d+512|0;do{if((a[388988]|0)!=0){j=hC(388988,0)|0;if((j|0)==0){k=ys(20)|0;if((k|0)==0){l=c[140620]|0;m=(l|0)!=0?l:c[t>>2]|0;be(54824,53,1,m|0)|0;m=c[140620]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0;break}if((c[k-4>>2]&3|0)!=0){yB(k|0,0,20)}n=k}else{n=j}yB(g|0,0,512);yB(h|0,0,32);j=b+8|0;k=c[j>>2]|0;do{if((k|0)!=0){l=0;m=k;while(1){if((a[(c[f>>2]|0)+(l*12|0)+4|0]&1)==0){o=m}else{b5(h|0,32,52168,(p=i,i=i+8|0,c[p>>2]=l,p)|0)|0;i=p;q=yA(g|0)|0;r=q>>>0>512?0:512-q|0;L4849:do{if((r|0)==0){s=h;u=3448}else{v=r;w=e+q|0;x=h;while(1){y=v-1|0;if((y|0)==0){break}z=a[x]|0;a[w]=z;if(z<<24>>24==0){break L4849}else{v=y;w=w+1|0;x=x+1|0}}a[w]=0;s=x;u=3448}}while(0);do{if((u|0)==3448){u=0;if((a[s]|0)==0){break}else{A=s}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);o=c[j>>2]|0}x=l+1|0;if(x>>>0<o>>>0){l=x;m=o}else{break}}if((a[g]|0)==0){break}a[e+((yA(g|0)|0)-1)|0]=0}}while(0);hF(n,562316,g);if(!(hG(n,388988)|0)){j=c[140620]|0;k=(j|0)!=0?j:c[t>>2]|0;eS(k|0,49440,(p=i,i=i+8|0,c[p>>2]=388988,p)|0)|0;i=p;k=c[140620]|0;j=(k|0)!=0?k:c[t>>2]|0;a7(j|0)|0}hA(n)}}while(0);n=b+8|0;p=c[f>>2]|0;if((c[n>>2]|0)==0){B=p}else{g=0;e=p;while(1){yt(c[e+(g*12|0)+8>>2]|0);p=g+1|0;o=c[f>>2]|0;if(p>>>0<(c[n>>2]|0)>>>0){g=p;e=o}else{B=o;break}}}yt(B)}yt(b);i=d;return}function iv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+256|0;e=d|0;f=c[138489]|0;g=f+4|0;h=c[g>>2]|0;if(h>>>0>1){j=f|0;k=1;l=h;while(1){h=c[(c[j>>2]|0)+(k<<2)>>2]|0;if((h|0)==0){m=l}else{yt(c[h+8>>2]|0);yt(c[(c[j>>2]|0)+(k<<2)>>2]|0);c[(c[j>>2]|0)+(k<<2)>>2]=0;m=c[g>>2]|0}h=k+1|0;if(h>>>0<m>>>0){k=h;l=m}else{break}}}c[g>>2]=1;g=f+12|0;yt(c[g>>2]|0);c[g>>2]=0;g=e|0;e=c[b+4>>2]|0;f=c[b>>2]|0;b=(a[f+(e*12|0)+4|0]&1)!=0?30720:30184;m=c[f+(e*12|0)>>2]|0;b5(g|0,256,19704,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=b,c[f+16>>2]=m,f)|0)|0;i=f;m=c[138489]|0;b=m+4|0;L4883:do{if((c[b>>2]|0)>>>0<(c[m+8>>2]|0)>>>0){e=ys(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}yB(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=180;l=dW(g|0)|0;k=c[b>>2]|0;c[e+8>>2]=l;l=m|0;c[(c[l>>2]|0)+(k<<2)>>2]=e;k=c[b>>2]|0;c[b>>2]=k+1;if(k>>>0>1){n=k}else{break}while(1){k=n>>>1;j=c[l>>2]|0;h=j+(k<<2)|0;o=c[h>>2]|0;p=c[j+(n<<2)>>2]|0;if((c[p+4>>2]|0)>>>0<=(c[o+4>>2]|0)>>>0){break L4883}c[h>>2]=p;c[(c[l>>2]|0)+(n<<2)>>2]=o;if(n>>>0>3){n=k}else{break}}}}while(0);if((a[405432]&1)==0){i=d;return}n=c[140620]|0;eS(((n|0)!=0?n:c[t>>2]|0)|0,50096,(f=i,i=i+8|0,c[f>>2]=g,f)|0)|0;i=f;f=c[140620]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;i=d;return}function iw(a,b,d){a=a|0;b=b|0;d=d|0;b=a$(d|0)|0;if((b|0)==0){return b|0}c[79902]=dn()|0;return b|0}function ix(a,b,c){a=a|0;b=b|0;c=c|0;return bW(b|0,c|0)|0}function iy(a){a=a|0;return aV()|0}function iz(a){a=a|0;return fK()|0}function iA(a,b){a=a|0;b=b|0;eC(b|0);return}function iB(a){a=a|0;eu();return}function iC(a){a=a|0;return dd()|0}function iD(a){a=a|0;return bx()|0}function iE(b,d){b=b|0;d=+d;var e=0,f=0,h=0,i=0,j=0.0;e=b+24|0;if((c[e>>2]|0)!=0){f=b+12|0;h=0;do{i=c[f>>2]|0;if((a[i+(h*136|0)+20|0]&1)==0){g[i+(h*136|0)+56>>2]=d;g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2]*d;g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]*d;j=+g[i+(h*136|0)+60>>2];g[i+(h*136|0)+24>>2]=j+(+g[i+(h*136|0)+40>>2]-j)*d;j=+g[i+(h*136|0)+64>>2];g[i+(h*136|0)+28>>2]=j+(+g[i+(h*136|0)+44>>2]-j)*d}else{g[i+(h*136|0)+24>>2]=+g[i+(h*136|0)+40>>2];g[i+(h*136|0)+28>>2]=+g[i+(h*136|0)+44>>2];g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2];g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]}h=h+1|0;}while(h>>>0<(c[e>>2]|0)>>>0)}e=c[b+16>>2]|0;f7[c[(c[b+4>>2]|0)+12>>2]&7](c[b>>2]|0,+g[e+24>>2],+g[e+28>>2],+g[e+32>>2],+g[e+36>>2]);return}function iF(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0.0,aY=0.0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a5=0,a6=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0;b=i;i=i+9240|0;d=b|0;e=b+64|0;f=b+320|0;h=b+328|0;j=b+392|0;k=b+456|0;l=b+520|0;m=b+584|0;n=b+4680|0;o=b+8776|0;p=b+8792|0;q=b+8856|0;r=b+9112|0;s=b+9176|0;u=ys(32)|0;if((u|0)==0){v=0;i=b;return v|0}if((c[u-4>>2]&3|0)!=0){yB(u|0,0,32)}w=u;x=c[(c[140913]|0)+52>>2]|0;do{if((x|0)==0){y=c[140620]|0;z=(y|0)!=0?y:c[t>>2]|0;be(50672,71,1,z|0)|0;z=c[140620]|0;y=(z|0)!=0?z:c[t>>2]|0;a7(y|0)|0}else{y=u+4|0;f3[x&1023](c[140916]|0,y);z=u;c[z>>2]=c[140916];if((c[y>>2]|0)==0){break}A=hC(364400,0)|0;if((A|0)==0){B=c[140620]|0;C=(B|0)!=0?B:c[t>>2]|0;eS(C|0,51960,(D=i,i=i+8|0,c[D>>2]=364400,D)|0)|0;i=D;C=c[140620]|0;B=(C|0)!=0?C:c[t>>2]|0;a7(B|0)|0;break}B=A+4|0;C=B;while(1){E=c[C>>2]|0;if((E|0)==0){F=3512;break}if((db(38200,c[E+4>>2]|0)|0)==0){F=3511;break}else{C=E+12|0}}L4936:do{if((F|0)==3511){c[(er()|0)>>2]=0;C=a4(c[E+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){F=3512;break}if((C|0)==0){break}G=C*136|0;if(C>>>0>65535){H=((G>>>0)/(C>>>0)|0|0)==136?G:-1}else{H=G}G=ys(H)|0;if((G|0)==0){c[u+12>>2]=0;break}if((c[G-4>>2]&3|0)!=0){yB(G|0,0,H|0)}I=G;G=u+12|0;c[G>>2]=I;J=u+24|0;c[J>>2]=C;C=k|0;L=l|0;M=m|0;N=n|0;O=o;P=p|0;Q=q|0;R=r|0;S=s|0;T=o+8|0;U=o|0;V=o+4|0;W=d|0;X=e|0;Y=h|0;Z=j|0;b5(C|0,64,17320,(D=i,i=i+8|0,c[D>>2]=0,D)|0)|0;i=D;L4949:do{if(hD(A,C,M)|0){_=I;$=0;L4950:while(1){b5(L|0,64,12528,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;aa=_+($*136|0)+69|0;ab=B;while(1){ac=c[ab>>2]|0;if((ac|0)==0){break}if((db(L|0,c[ac+4>>2]|0)|0)==0){F=3526;break}else{ab=ac+12|0}}L4955:do{if((F|0)==3526){F=0;ab=64;ad=aa;ae=c[ac+8>>2]|0;while(1){af=ab-1|0;if((af|0)==0){break}ag=a[ae]|0;a[ad]=ag;if(ag<<24>>24==0){break L4955}else{ab=af;ad=ad+1|0;ae=ae+1|0}}a[ad]=0;if((a[ae]|0)==0){break}else{ah=ae}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);hw(N,364400,M);yB(O|0,0,12);if((a[563828]&1)==0){if(!(i5(N,o,16,0)|0)){F=3534;break}}else{if(!(i5(N,o,0,16)|0)){F=3534;break}}c[_+($*136|0)+8>>2]=c[T>>2];c[_+($*136|0)+12>>2]=c[U>>2];c[_+($*136|0)+16>>2]=c[V>>2];aa=_+($*136|0)+44|0;g[aa>>2]=0.0;ae=_+($*136|0)+40|0;g[ae>>2]=0.0;ad=_+($*136|0)+52|0;g[ad>>2]=1.0;ab=_+($*136|0)+48|0;g[ab>>2]=1.0;b5(P|0,64,52112,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;af=B;while(1){ai=c[af>>2]|0;if((ai|0)==0){break}if((db(P|0,c[ai+4>>2]|0)|0)==0){F=3538;break}else{af=ai+12|0}}do{if((F|0)==3538){F=0;af=256;ag=0;aj=Q;ak=c[ai+8>>2]|0;while(1){al=af-1|0;if((al|0)==0){F=3541;break}am=a[ak]|0;a[aj]=am;if(am<<24>>24==0){an=ag;break}else{af=al;ag=ag+1|0;aj=aj+1|0;ak=ak+1|0}}do{if((F|0)==3541){F=0;a[aj]=0;if((a[ak]|0)==0){an=ag;break}else{ao=ak;ap=ag}while(1){af=ao+1|0;al=ap+1|0;if((a[af]|0)==0){an=al;break}else{ao=af;ap=al}}}}while(0);if(an>>>0>=256){break}ag=hk(Q,49376)|0;ak=ag+4|0;if((c[ak>>2]|0)>>>0<4){F=3545;break L4950}aj=ag|0;g[ae>>2]=+yz(c[c[aj>>2]>>2]|0,0);g[aa>>2]=+yz(c[(c[aj>>2]|0)+8>>2]|0,0);g[ab>>2]=+yz(c[(c[aj>>2]|0)+16>>2]|0,0);g[ad>>2]=+yz(c[(c[aj>>2]|0)+24>>2]|0,0);if((ag|0)==0){break}al=c[aj>>2]|0;if((c[ak>>2]|0)==0){aq=al}else{af=0;am=al;while(1){yt(c[am+(af<<3)>>2]|0);al=af+1|0;ar=c[aj>>2]|0;if(al>>>0<(c[ak>>2]|0)>>>0){af=al;am=ar}else{aq=ar;break}}}yt(aq);yt(ag)}}while(0);b5(R|0,64,46688,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;am=_+($*136|0)+68|0;a[am]=0;hE(A,R,am)|0;b5(S|0,64,45272,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;am=B;while(1){as=c[am>>2]|0;if((as|0)==0){F=3554;break L4950}if((db(S|0,c[as+4>>2]|0)|0)==0){break}else{am=as+12|0}}c[(er()|0)>>2]=0;am=a4(c[as+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){F=3554;break}af=(am|0)==0;do{if(af){at=0}else{ak=am*104|0;if(am>>>0<=65535){at=ak;break}at=((ak>>>0)/(am>>>0)|0|0)==104?ak:-1}}while(0);ak=ys(at)|0;if((ak|0)==0){F=3561;break}if((c[ak-4>>2]&3|0)!=0){yB(ak|0,0,at|0)}aj=ak;ak=_+($*136|0)|0;c[ak>>2]=aj;ar=_+($*136|0)+4|0;c[ar>>2]=am;L5002:do{if(!af){al=c[U>>2]|0;au=c[V>>2]|0;b5(W|0,64,40504,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=0,D)|0)|0;i=D;av=B;while(1){aw=c[av>>2]|0;if((aw|0)==0){ax=0;F=3572;break L4950}if((db(W|0,c[aw+4>>2]|0)|0)==0){break}else{av=aw+12|0}}av=256;ag=0;ay=X;az=c[aw+8>>2]|0;while(1){aA=av-1|0;if((aA|0)==0){F=3569;break}aB=a[az]|0;a[ay]=aB;if(aB<<24>>24==0){aC=ag;break}else{av=aA;ag=ag+1|0;ay=ay+1|0;az=az+1|0}}do{if((F|0)==3569){F=0;a[ay]=0;if((a[az]|0)==0){aC=ag;break}else{aD=az;aE=ag}while(1){av=aD+1|0;aA=aE+1|0;if((a[av]|0)==0){aC=aA;break}else{aD=av;aE=aA}}}}while(0);if(aC>>>0<256){aF=aj;aG=0;aH=al;aI=au}else{ax=0;F=3572;break L4950}while(1){aJ=hk(X,49376)|0;if((aJ|0)==0){F=3574;break L4950}aK=aJ+4|0;aL=c[aK>>2]|0;if(aL>>>0<6){F=3576;break L4950}aM=aJ|0;ag=c[aM>>2]|0;az=c[ag+8>>2]|0;ay=c[ag+16>>2]|0;aN=c[ag+24>>2]|0;aA=c[ag>>2]|0;ag=aF+(aG*104|0)+24|0;c[ag>>2]=0;c[ag+4>>2]=0;L5020:do{if((db(aA|0,35184)|0)==0){c[aF+(aG*104|0)+20>>2]=1}else{av=aF+(aG*104|0)+20|0;if((db(aA|0,34056)|0)==0){c[av>>2]=2;break}c[av>>2]=0;av=eO(aA|0,49872,f|0)|0;if((av|0)!=0){aB=av;do{av=0;while(1){if(av>>>0>=56){aO=0;aP=56;break}if((db(c[840+(av<<3)>>2]|0,aB|0)|0)==0){F=3587;break}else{av=av+1|0}}if((F|0)==3587){F=0;aO=0;aP=c[844+(av<<3)>>2]|0}aQ=yN(1,0,aP|0)|0;aR=K;aS=c[ag+4>>2]|aR;c[ag>>2]=c[ag>>2]|aQ;c[ag+4>>2]=aS;aB=eO(0,49872,f|0)|0;}while((aB|0)!=0)}if((c[ag>>2]&0|0)==0&(c[ag+4>>2]&524288|0)==0){break}b5(Y|0,64,32592,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aG,D)|0)|0;i=D;aB=aF+(aG*104|0)+40|0;aS=B;while(1){aT=c[aS>>2]|0;if((aT|0)==0){break L5020}if((db(Y|0,c[aT+4>>2]|0)|0)==0){break}else{aS=aT+12|0}}aS=64;aQ=aB;aR=c[aT+8>>2]|0;while(1){aU=aS-1|0;if((aU|0)==0){break}aV=a[aR]|0;a[aQ]=aV;if(aV<<24>>24==0){break L5020}else{aS=aU;aQ=aQ+1|0;aR=aR+1|0}}a[aQ]=0;if((a[aR]|0)==0){break}else{aW=aR}do{aW=aW+1|0;}while((a[aW]|0)!=0)}}while(0);aX=+(aH>>>0>>>0);g[aF+(aG*104|0)>>2]=+yz(az,0)/aX;aY=+(aI>>>0>>>0);g[aF+(aG*104|0)+4>>2]=+yz(ay,0)/aY;if((db(aN|0,31944)|0)==0){c[aF+(aG*104|0)+8>>2]=0;aZ=0}else{if((db(aN|0,31576)|0)!=0){F=3602;break L4950}c[aF+(aG*104|0)+8>>2]=1;aZ=1}do{if((c[aF+(aG*104|0)+20>>2]|0)!=0){if((aZ|0)!=0){F=3607;break L4950}b5(Z|0,64,30272,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aG,D)|0)|0;i=D;ag=aF+(aG*104|0)+32|0;aA=B;while(1){a_=c[aA>>2]|0;if((a_|0)==0){F=3614;break}if((db(Z|0,c[a_+4>>2]|0)|0)==0){F=3613;break}else{aA=a_+12|0}}if((F|0)==3613){F=0;g[ag>>2]=+yz(c[a_+8>>2]|0,0);break}else if((F|0)==3614){F=0;g[ag>>2]=1.0;break}}}while(0);g[aF+(aG*104|0)+12>>2]=+yz(c[(c[aM>>2]|0)+32>>2]|0,0)/aX;g[aF+(aG*104|0)+16>>2]=+yz(c[(c[aM>>2]|0)+40>>2]|0,0)/aY;ay=c[aM>>2]|0;if((c[aK>>2]|0)==0){a$=ay}else{az=0;aA=ay;while(1){yt(c[aA+(az<<3)>>2]|0);ay=az+1|0;aR=c[aM>>2]|0;if(ay>>>0<(c[aK>>2]|0)>>>0){az=ay;aA=aR}else{a$=aR;break}}}yt(a$);yt(aJ);aA=aG+1|0;if(aA>>>0>=(c[ar>>2]|0)>>>0){break L5002}az=c[ak>>2]|0;aR=c[U>>2]|0;ay=c[V>>2]|0;b5(W|0,64,40504,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aA,D)|0)|0;i=D;aQ=B;while(1){a0=c[aQ>>2]|0;if((a0|0)==0){ax=aA;F=3572;break L4950}if((db(W|0,c[a0+4>>2]|0)|0)==0){break}else{aQ=a0+12|0}}aQ=256;aS=0;aB=X;aU=c[a0+8>>2]|0;while(1){aV=aQ-1|0;if((aV|0)==0){F=3624;break}a1=a[aU]|0;a[aB]=a1;if(a1<<24>>24==0){a2=aS;break}else{aQ=aV;aS=aS+1|0;aB=aB+1|0;aU=aU+1|0}}do{if((F|0)==3624){F=0;a[aB]=0;if((a[aU]|0)==0){a2=aS;break}else{a3=aU;a5=aS}while(1){aQ=a3+1|0;aV=a5+1|0;if((a[aQ]|0)==0){a2=aV;break}else{a3=aQ;a5=aV}}}}while(0);if(a2>>>0<256){aF=az;aG=aA;aH=aR;aI=ay}else{ax=aA;F=3572;break L4950}}}}while(0);a[_+($*136|0)+20|0]=0;g[_+($*136|0)+60>>2]=+g[ae>>2]+ +g[ab>>2]*.5;g[_+($*136|0)+64>>2]=+g[aa>>2]+ +g[ad>>2]*.5;ak=$+1|0;a6=c[J>>2]|0;if(ak>>>0>=a6>>>0){F=3521;break}ar=c[G>>2]|0;b5(C|0,64,17320,(D=i,i=i+8|0,c[D>>2]=ak,D)|0)|0;i=D;if(hD(A,C,M)|0){_=ar;$=ak}else{a8=ak;F=3522;break L4949}}if((F|0)==3602){ak=c[140620]|0;ar=(ak|0)!=0?ak:c[t>>2]|0;eS(ar|0,31120,(D=i,i=i+8|0,c[D>>2]=aN,D)|0)|0;i=D;ar=c[140620]|0;ak=(ar|0)!=0?ar:c[t>>2]|0;a7(ak|0)|0;ak=c[aM>>2]|0;if((c[aK>>2]|0)==0){a9=ak}else{ar=0;aj=ak;while(1){yt(c[aj+(ar<<3)>>2]|0);ak=ar+1|0;af=c[aM>>2]|0;if(ak>>>0<(c[aK>>2]|0)>>>0){ar=ak;aj=af}else{a9=af;break}}}yt(a9);yt(aJ);ba=aG}else if((F|0)==3545){aj=c[140620]|0;eS(((aj|0)!=0?aj:c[t>>2]|0)|0,47752,(D=i,i=i+8|0,c[D>>2]=Q,D)|0)|0;i=D;aj=c[140620]|0;a7(((aj|0)!=0?aj:c[t>>2]|0)|0)|0;bb=$;break}else if((F|0)==3574){aj=c[140620]|0;be(38296,62,1,((aj|0)!=0?aj:c[t>>2]|0)|0)|0;aj=c[140620]|0;a7(((aj|0)!=0?aj:c[t>>2]|0)|0)|0;ba=aG}else if((F|0)==3576){aj=aJ|0;ar=c[aj>>2]|0;if((aL|0)==0){bc=ar}else{af=0;ak=ar;while(1){yt(c[ak+(af<<3)>>2]|0);ar=af+1|0;am=c[aj>>2]|0;if(ar>>>0<(c[aK>>2]|0)>>>0){af=ar;ak=am}else{bc=am;break}}}yt(bc);yt(aJ);ak=c[140620]|0;be(36456,85,1,((ak|0)!=0?ak:c[t>>2]|0)|0)|0;ak=c[140620]|0;a7(((ak|0)!=0?ak:c[t>>2]|0)|0)|0;ba=aG}else if((F|0)==3521){L5096:do{if((a6|0)!=0){ak=0;af=a6;L5097:while(1){aj=c[G>>2]|0;am=aj+(ak*136|0)+4|0;if((c[am>>2]|0)==0){bd=af;bf=ak+1|0}else{ar=aj+(ak*136|0)|0;au=ak+1|0;al=0;do{aS=c[ar>>2]|0;bg=aS+(al*104|0)+40|0;if((a[bg]|0)==0){c[aS+(al*104|0)+36>>2]=(au>>>0)%(af>>>0)|0}else{aU=0;while(1){if(aU>>>0>=af>>>0){break L5097}if((db(aj+(aU*136|0)+69|0,bg|0)|0)==0){break}else{aU=aU+1|0}}if((aU|0)<0){break L5097}c[aS+(al*104|0)+36>>2]=aU}al=al+1|0;}while(al>>>0<(c[am>>2]|0)>>>0);bd=c[J>>2]|0;bf=au}if(bf>>>0<bd>>>0){ak=bf;af=bd}else{break L5096}}af=c[140620]|0;eS(((af|0)!=0?af:c[t>>2]|0)|0,19592,(D=i,i=i+8|0,c[D>>2]=bg,D)|0)|0;i=D;af=c[140620]|0;a7(((af|0)!=0?af:c[t>>2]|0)|0)|0;af=c[140620]|0;be(22208,64,1,((af|0)!=0?af:c[t>>2]|0)|0)|0;af=c[140620]|0;a7(((af|0)!=0?af:c[t>>2]|0)|0)|0;break L4936}}while(0);hA(A);af=c[G>>2]|0;ak=u+16|0;c[ak>>2]=af;gq[c[(c[y>>2]|0)+4>>2]&31](c[z>>2]|0,c[af+8>>2]|0,c[af+12>>2]|0,c[af+16>>2]|0)|0;af=c[ak>>2]|0;f7[c[(c[y>>2]|0)+12>>2]&7](c[z>>2]|0,+g[af+24>>2],+g[af+28>>2],+g[af+32>>2],+g[af+36>>2]);f3[c[(c[y>>2]|0)+16>>2]&1023](c[z>>2]|0,(a[(c[ak>>2]|0)+68|0]&1)!=0);f3[c[c[y>>2]>>2]&1023](c[z>>2]|0,1);a[u+8|0]=1;f0[c[(c[y>>2]|0)+20>>2]&7](c[z>>2]|0,+g[92124]);iE(w,1.0);c[u+28>>2]=(((c[u+20>>2]|0)+1|0)>>>0)%((c[J>>2]|0)>>>0)|0;v=w;i=b;return v|0}else if((F|0)==3554){ak=c[140620]|0;eS(((ak|0)!=0?ak:c[t>>2]|0)|0,43800,(D=i,i=i+8|0,c[D>>2]=S,D)|0)|0;i=D;ak=c[140620]|0;a7(((ak|0)!=0?ak:c[t>>2]|0)|0)|0;bb=$;break}else if((F|0)==3534){ak=c[140620]|0;eS(((ak|0)!=0?ak:c[t>>2]|0)|0,54768,(D=i,i=i+8|0,c[D>>2]=M,D)|0)|0;i=D;ak=c[140620]|0;a7(((ak|0)!=0?ak:c[t>>2]|0)|0)|0;bb=$;break}else if((F|0)==3572){ak=c[140620]|0;eS(((ak|0)!=0?ak:c[t>>2]|0)|0,39592,(D=i,i=i+8|0,c[D>>2]=W,D)|0)|0;i=D;ak=c[140620]|0;a7(((ak|0)!=0?ak:c[t>>2]|0)|0)|0;ba=ax}else if((F|0)==3607){ak=c[140620]|0;be(30744,69,1,((ak|0)!=0?ak:c[t>>2]|0)|0)|0;ak=c[140620]|0;a7(((ak|0)!=0?ak:c[t>>2]|0)|0)|0;ak=c[aM>>2]|0;if((c[aK>>2]|0)==0){bh=ak}else{af=0;ad=ak;while(1){yt(c[ad+(af<<3)>>2]|0);ak=af+1|0;aa=c[aM>>2]|0;if(ak>>>0<(c[aK>>2]|0)>>>0){af=ak;ad=aa}else{bh=aa;break}}}yt(bh);yt(aJ);ba=aG}else if((F|0)==3561){c[_+($*136|0)>>2]=0;ad=c[140620]|0;be(42592,58,1,((ad|0)!=0?ad:c[t>>2]|0)|0)|0;ad=c[140620]|0;a7(((ad|0)!=0?ad:c[t>>2]|0)|0)|0;bb=$;break}ad=c[140620]|0;eS(((ad|0)!=0?ad:c[t>>2]|0)|0,41648,(D=i,i=i+8|0,c[D>>2]=ba,D)|0)|0;i=D;ad=c[140620]|0;a7(((ad|0)!=0?ad:c[t>>2]|0)|0)|0;bb=$}else{a8=0;F=3522}}while(0);if((F|0)==3522){W=c[140620]|0;M=(W|0)!=0?W:c[t>>2]|0;eS(M|0,14912,(D=i,i=i+8|0,c[D>>2]=C,D)|0)|0;i=D;M=c[140620]|0;W=(M|0)!=0?M:c[t>>2]|0;a7(W|0)|0;bb=a8}W=c[140620]|0;M=(W|0)!=0?W:c[t>>2]|0;eS(M|0,25696,(D=i,i=i+8|0,c[D>>2]=bb,D)|0)|0;i=D;M=c[140620]|0;W=(M|0)!=0?M:c[t>>2]|0;a7(W|0)|0}}while(0);if((F|0)==3512){z=c[140620]|0;y=(z|0)!=0?z:c[t>>2]|0;be(30192,62,1,y|0)|0;y=c[140620]|0;z=(y|0)!=0?y:c[t>>2]|0;a7(z|0)|0}hA(A)}}while(0);F=u+24|0;D=u+12|0;bb=c[D>>2]|0;if((c[F>>2]|0)==0){bi=bb}else{a8=0;ba=bb;while(1){yt(c[ba+(a8*136|0)>>2]|0);yt(c[ba+(a8*136|0)+8>>2]|0);bb=a8+1|0;aG=c[D>>2]|0;if(bb>>>0<(c[F>>2]|0)>>>0){a8=bb;ba=aG}else{bi=aG;break}}}yt(bi);bi=c[u+4>>2]|0;if((bi|0)!=0){f3[c[bi>>2]&1023](c[u>>2]|0,0)}yt(u);v=0;i=b;return v|0}function iG(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0,R=0.0,S=0.0,T=0.0,U=0.0,W=0.0,X=0.0,Y=0,_=0,$=0.0,aa=0.0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;e=i;f=d+64|0;yt(c[f>>2]|0);g=d+76|0;yt(c[g>>2]|0);h=d+80|0;yt(c[h>>2]|0);j=d+92|0;yt(c[j>>2]|0);k=d+104|0;yt(c[k>>2]|0);l=d+96|0;yt(c[l>>2]|0);m=d+120|0;yt(c[m>>2]|0);yB(f|0,0,64);n=d|0;o=c[n>>2]|0;p=d+12|0;q=c[p>>2]|0;r=d+4|0;s=c[r>>2]|0;do{if((o|0)==(q|0)){if((s|0)!=(c[d+16>>2]|0)){u=3658;break}a[d+60|0]=1;v=1}else{u=3658}}while(0);if((u|0)==3658){c[d+36>>2]=84;c[d+40>>2]=64;a[d+60|0]=0;v=0}w=d+44|0;c[w>>2]=0;x=(q<<3)+56&-64;c[d+116>>2]=x;c[d+108>>2]=q;c[d+112>>2]=s;y=ag(x,s)|0;x=y>>3;if(x>>>0>65535){z=(y>>>3|0)==(x|0)?y:-1}else{z=y}y=ys(z)|0;if((y|0)==0){c[k>>2]=0;A=0;i=e;return A|0}if((c[y-4>>2]&3|0)!=0){yB(y|0,0,z|0)}c[k>>2]=y;y=c[d+24>>2]|0;if((y|0)!=0){k=(o<<2)+28&-32;c[d+100>>2]=k;o=ag(k,s)|0;s=o>>2;if(s>>>0>65535){B=(o>>>2|0)==(s|0)?o:-1}else{B=o}o=ys(B)|0;if((o|0)==0){c[l>>2]=0;A=0;i=e;return A|0}if((c[o-4>>2]&3|0)!=0){yB(o|0,0,B|0)}c[l>>2]=o}o=c[d+28>>2]|0;l=(o|0)==0;if(!l){B=(q<<2)+28&-32;c[d+124>>2]=B;q=ag(c[d+16>>2]|0,B)|0;B=q>>2;if(B>>>0>65535){C=(q>>>2|0)==(B|0)?q:-1}else{C=q}q=ys(C)|0;if((q|0)==0){c[m>>2]=0;A=0;i=e;return A|0}if((c[q-4>>2]&3|0)!=0){yB(q|0,0,C|0)}c[m>>2]=q}q=v<<24>>24==0;L5185:do{if(q){if((y|0)==2){c[d+48>>2]=4}else if((y|0)==3){c[d+48>>2]=58}else if((y|0)==4){c[d+48>>2]=2}else if((y|0)!=0){A=0;i=e;return A|0}if((o|0)==2){c[d+52>>2]=54;break}else if((o|0)==4){c[d+52>>2]=36;break}else if((o|0)==0){break}else{A=0;i=e;return A|0}}else{if((y|0)==(o|0)){c[d+56>>2]=32;A=1;i=e;return A|0}v=(y|0)==2;if(v&l){c[d+56>>2]=4;A=1;i=e;return A|0}if(!((y|0)!=3|l^1)){c[d+56>>2]=58;break}m=(y|0)==3;C=(o|0)==4;if(m&C){c[d+56>>2]=24;break}if(v&(o|0)==3){c[d+56>>2]=22;break}do{if(m){if((o|0)!=2){D=0;break}c[d+56>>2]=50;break L5185}else{if((y|0)==4){if(!l){D=0;break}c[d+56>>2]=2;break L5185}else if((y|0)!=0){D=0;break}if((o|0)==2){c[d+56>>2]=54;break L5185}else if((o|0)==4){c[d+56>>2]=36;break L5185}else{D=1;break}}}while(0);if(v&C){c[d+56>>2]=48;break}if(D&(o|0)==1){c[d+56>>2]=8;break}else{A=0;i=e;return A|0}}}while(0);if(!q){A=1;i=e;return A|0}q=c[d+32>>2]|0;L5237:do{if((q|0)==3){o=c[n>>2]|0;D=c[p>>2]|0;if((o|0)>(D|0)){y=((o|0)/(D|0)|0)-1|0;o=y>>>1|y;y=o>>>2|o;o=y>>>4|y;y=o>>>8|o;E=((y>>>16|y)<<3)+8|0}else{E=8}y=d+68|0;c[y>>2]=E;c[d+72>>2]=E;o=d+84|0;c[o>>2]=E;l=d+88|0;c[l>>2]=E;m=ag(E,D)|0;D=m<<1;if(m>>>0>65535){F=(m&2147483647|0)==(m|0)?D:-1}else{F=D}D=ys(F)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}yB(D|0,0,F|0)}}while(0);C=d+64|0;c[C>>2]=D;v=c[p>>2]|0;m=v<<2;if(v>>>0>65535){G=(v&1073741823|0)==(v|0)?m:-1}else{G=m}m=ys(G)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}yB(m|0,0,G|0)}}while(0);c[g>>2]=m;D=d+16|0;v=ag(c[D>>2]|0,c[l>>2]|0)|0;B=v<<1;if(v>>>0>65535){H=(v&2147483647|0)==(v|0)?B:-1}else{H=B}B=ys(H)|0;do{if((B|0)!=0){if((c[B-4>>2]&3|0)==0){break}yB(B|0,0,H|0)}}while(0);c[h>>2]=B;l=c[D>>2]|0;m=l<<2;if(l>>>0>65535){I=(l&1073741823|0)==(l|0)?m:-1}else{I=m}m=ys(I)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}yB(m|0,0,I|0)}}while(0);c[j>>2]=m;if((c[C>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}B=c[n>>2]|0;l=c[p>>2]|0;v=-32768-(E<<15)|0;s=((B<<15|0)/(l|0)|0)+v|0;k=(B<<16|0)/(l|0)|0;z=c[r>>2]|0;x=c[D>>2]|0;J=((z<<15|0)/(x|0)|0)+v|0;v=(z<<16|0)/(x|0)|0;if((B|0)>(l|0)){K=+(l|0)/+(B|0)}else{K=1.0}if((z|0)>(x|0)){L=+(x|0)/+(z|0)}else{L=1.0}z=c[y>>2]|0;L5282:do{if((l|0)>0){x=z<<15;M=+(z>>1|0);if((z|0)>0){N=0;O=s}else{B=0;P=s;while(1){c[(c[g>>2]|0)+(B<<2)>>2]=P>>16;Q=B+1|0;if((Q|0)<(l|0)){B=Q;P=P+k|0}else{break L5282}}}while(1){c[(c[g>>2]|0)+(N<<2)>>2]=O>>16;R=+((O&65535)+x|0)*152587890625.0e-16;P=ag(N,z)|0;B=0;do{S=(R- +(B|0))*3.141592653589793;T=S/M;U=K*S;if(+V(+U)<1.0e-4){W=16384.0}else{W=+Z(+U)/U*16384.0}if(+V(+T)<1.0e-4){X=1.0}else{X=+Z(+T)/T}b[(c[C>>2]|0)+(B+P<<1)>>1]=~~(K*W*X);B=B+1|0;}while((B|0)<(z|0));B=N+1|0;if((B|0)<(l|0)){N=B;O=O+k|0}else{break}}}}while(0);k=c[D>>2]|0;l=c[o>>2]|0;if((k|0)<=0){break}z=l<<15;M=+(l>>1|0);if((l|0)>0){Y=0;_=J}else{C=0;s=J;while(1){c[(c[j>>2]|0)+(C<<2)>>2]=s>>16;y=C+1|0;if((y|0)>=(k|0)){break L5237}C=y;s=s+v|0}}while(1){c[(c[j>>2]|0)+(Y<<2)>>2]=_>>16;R=+((_&65535)+z|0)*152587890625.0e-16;s=ag(Y,l)|0;C=0;do{T=(R- +(C|0))*3.141592653589793;U=T/M;S=L*T;if(+V(+S)<1.0e-4){$=16384.0}else{$=+Z(+S)/S*16384.0}if(+V(+U)<1.0e-4){aa=1.0}else{aa=+Z(+U)/U}b[(c[h>>2]|0)+(C+s<<1)>>1]=~~(L*$*aa);C=C+1|0;}while((C|0)<(l|0));C=Y+1|0;if((C|0)>=(k|0)){break L5237}Y=C;_=_+v|0}}else if((q|0)==2){c[d+68>>2]=2;c[d+72>>2]=2;c[d+84>>2]=2;v=d+88|0;c[v>>2]=2;k=c[p>>2]|0;l=k<<1;z=k<<2;if(l>>>0>65535){ab=(l&2147483646|0)==(l|0)?z:-1}else{ab=z}z=ys(ab)|0;do{if((z|0)!=0){if((c[z-4>>2]&3|0)==0){break}yB(z|0,0,ab|0)}}while(0);l=d+64|0;c[l>>2]=z;k=c[p>>2]|0;C=k<<2;if(k>>>0>65535){ac=(k&1073741823|0)==(k|0)?C:-1}else{ac=C}C=ys(ac)|0;do{if((C|0)!=0){if((c[C-4>>2]&3|0)==0){break}yB(C|0,0,ac|0)}}while(0);c[g>>2]=C;z=d+16|0;k=ag(c[z>>2]|0,c[v>>2]|0)|0;s=k<<1;if(k>>>0>65535){ad=(k&2147483647|0)==(k|0)?s:-1}else{ad=s}s=ys(ad)|0;do{if((s|0)!=0){if((c[s-4>>2]&3|0)==0){break}yB(s|0,0,ad|0)}}while(0);c[h>>2]=s;v=c[z>>2]|0;C=v<<2;if(v>>>0>65535){ae=(v&1073741823|0)==(v|0)?C:-1}else{ae=C}C=ys(ae)|0;do{if((C|0)!=0){if((c[C-4>>2]&3|0)==0){break}yB(C|0,0,ae|0)}}while(0);c[j>>2]=C;if((c[l>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}s=c[n>>2]|0;v=c[p>>2]|0;k=(s<<16|0)/(v|0)|0;J=c[r>>2]|0;o=c[z>>2]|0;D=((J<<15|0)/(o|0)|0)-32768|0;y=(J<<16|0)/(o|0)|0;if((v|0)>0){J=((s<<15|0)/(v|0)|0)-32768|0;s=0;while(1){c[(c[g>>2]|0)+(s<<2)>>2]=J>>16;m=s<<1;x=m|1;b[(c[l>>2]|0)+(x<<1)>>1]=J>>>2&16383;B=c[l>>2]|0;b[B+(m<<1)>>1]=16384-(b[B+(x<<1)>>1]|0)&65535;x=s+1|0;if((x|0)<(v|0)){J=J+k|0;s=x}else{break}}af=c[z>>2]|0}else{af=o}if((af|0)>0){ah=D;ai=0}else{break}while(1){c[(c[j>>2]|0)+(ai<<2)>>2]=ah>>16;s=ai<<1;k=s|1;b[(c[h>>2]|0)+(k<<1)>>1]=ah>>>2&16383;J=c[h>>2]|0;b[J+(s<<1)>>1]=16384-(b[J+(k<<1)>>1]|0)&65535;k=ai+1|0;if((k|0)>=(af|0)){break L5237}ah=ah+y|0;ai=k}}else if((q|0)==1){c[d+68>>2]=1;c[d+72>>2]=1;c[d+84>>2]=1;y=d+88|0;c[y>>2]=1;D=c[p>>2]|0;o=D<<1;if(D>>>0>65535){aj=(D&2147483647|0)==(D|0)?o:-1}else{aj=o}o=ys(aj)|0;do{if((o|0)!=0){if((c[o-4>>2]&3|0)==0){break}yB(o|0,0,aj|0)}}while(0);D=d+64|0;c[D>>2]=o;z=c[p>>2]|0;k=z<<2;if(z>>>0>65535){ak=(z&1073741823|0)==(z|0)?k:-1}else{ak=k}k=ys(ak)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}yB(k|0,0,ak|0)}}while(0);c[g>>2]=k;o=d+16|0;z=ag(c[o>>2]|0,c[y>>2]|0)|0;J=z<<1;if(z>>>0>65535){al=(z&2147483647|0)==(z|0)?J:-1}else{al=J}J=ys(al)|0;do{if((J|0)!=0){if((c[J-4>>2]&3|0)==0){break}yB(J|0,0,al|0)}}while(0);c[h>>2]=J;y=c[o>>2]|0;k=y<<2;if(y>>>0>65535){am=(y&1073741823|0)==(y|0)?k:-1}else{am=k}k=ys(am)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}yB(k|0,0,am|0)}}while(0);c[j>>2]=k;if((c[D>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}J=c[n>>2]|0;y=c[p>>2]|0;z=(J<<16|0)/(y|0)|0;s=c[r>>2]|0;v=c[o>>2]|0;l=((s<<15|0)/(v|0)|0)-32768|0;C=(s<<16|0)/(v|0)|0;if((y|0)>0){s=((J<<15|0)/(y|0)|0)-32768|0;J=0;while(1){c[(c[g>>2]|0)+(J<<2)>>2]=s>>16;b[(c[D>>2]|0)+(J<<1)>>1]=16384;x=J+1|0;if((x|0)<(y|0)){s=s+z|0;J=x}else{break}}an=c[o>>2]|0}else{an=v}L5402:do{if((an|0)>0){J=l;z=0;while(1){c[(c[j>>2]|0)+(z<<2)>>2]=J>>16;b[(c[h>>2]|0)+(z<<1)>>1]=16384;s=z+1|0;if((s|0)>=(an|0)){break L5402}J=J+C|0;z=s}}}while(0);c[w>>2]=2}else{A=0;i=e;return A|0}}while(0);iW(f,c[p>>2]|0,c[n>>2]|0);f=d+16|0;iW(d+80|0,c[f>>2]|0,c[r>>2]|0);w=(c[n>>2]|0)-(c[d+68>>2]|0)|0;n=c[p>>2]|0;p=0;while(1){if((p|0)>=(n|0)){break}ao=c[(c[g>>2]|0)+(p<<2)>>2]|0;if((ao|0)>(w|0)|(ao|0)<0){u=3826;break}else{p=p+1|0}}if((u|0)==3826){w=c[t>>2]|0;eS(w|0,48136,(ap=i,i=i+16|0,c[ap>>2]=p,c[ap+8>>2]=ao,ap)|0)|0;i=ap;A=0;i=e;return A|0}ao=(c[r>>2]|0)-(c[d+84>>2]|0)|0;d=c[f>>2]|0;f=0;while(1){if((f|0)>=(d|0)){A=1;u=3848;break}aq=c[(c[j>>2]|0)+(f<<2)>>2]|0;if((aq|0)>(ao|0)|(aq|0)<0){break}else{f=f+1|0}}if((u|0)==3848){i=e;return A|0}eS(c[t>>2]|0,51328,(ap=i,i=i+16|0,c[ap>>2]=f,c[ap+8>>2]=aq,ap)|0)|0;i=ap;A=0;i=e;return A|0}function iH(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=0;i=a;a=c;while(1){c=0;do{j=b[a+(c<<1)>>1]|0;b[i+(c<<1)>>1]=(j&65535)>>>1&32736|j&31;c=c+1|0;}while((c|0)<(d|0));c=g+1|0;if((c|0)<(e|0)){g=c;i=i+(h<<1)|0;a=a+(f<<1)|0}else{break}}return}function iI(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=0;i=a;a=c;while(1){c=0;do{j=b[a+(c<<1)>>1]|0;b[i+(c<<1)>>1]=j<<1&-64|j&31|(j&65535)>>>4&32;c=c+1|0;}while((c|0)<(d|0));c=g+1|0;if((c|0)<(e|0)){g=c;i=i+(h<<1)|0;a=a+(f<<1)|0}else{break}}return}function iJ(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=0;j=a;a=b;while(1){b=0;do{k=e[a+(b<<1)>>1]|0;l=k>>>10&31;m=k>>>5&31;n=k&31;c[j+(b<<2)>>2]=n<<3|n>>>2|(m<<3|m>>>2)<<8|(l<<3|l>>>2)<<16|-16777216;b=b+1|0;}while((b|0)<(d|0));b=h+1|0;if((b|0)<(f|0)){h=b;j=j+(i<<2)|0;a=a+(g<<1)|0}else{break}}return}function iK(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=0;j=a;a=b;while(1){b=0;do{k=e[a+(b<<1)>>1]|0;l=k>>>5&63;m=k&31;c[j+(b<<2)>>2]=m<<3|m>>>2|(k>>>11<<3|k>>>13)<<16|(l<<2|l>>>4)<<8|-16777216;b=b+1|0;}while((b|0)<(d|0));b=h+1|0;if((b|0)<(f|0)){h=b;j=j+(i<<2)|0;a=a+(g<<1)|0}else{break}}return}function iL(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<3|m>>>7&7)&255;a[l+2|0]=(m>>>10<<3|m>>>12&7)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function iM(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<2|m>>>9&3)&255;a[l+2|0]=(m>>>11<<3|m>>>13)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function iN(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>2;g=0;k=a;a=b;while(1){if(i){b=a;l=0;while(1){c[k+(l<<2)>>2]=d[b]|0|(d[b+1|0]|0)<<8|(d[b+2|0]|0)<<16|-16777216;m=l+1|0;if((m|0)<(e|0)){b=b+3|0;l=m}else{break}}}l=g+1|0;if((l|0)<(f|0)){g=l;k=k+(j<<2)|0;a=a+h|0}else{break}}return}function iO(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>1;g=h>>2;h=0;k=a;a=d;while(1){if(i){d=0;do{l=c[a+(d<<2)>>2]|0;b[k+(d<<1)>>1]=(l>>>11<<5&992|l>>>3&31|l>>>19<<10&31744)&65535;d=d+1|0;}while((d|0)<(e|0))}d=h+1|0;if((d|0)<(f|0)){h=d;k=k+(j<<1)|0;a=a+(g<<2)|0}else{break}}return}function iP(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=h>>2;h=b;b=0;k=d;while(1){if(i){d=h;l=0;while(1){m=c[k+(l<<2)>>2]|0;a[d]=m&255;a[d+1|0]=m>>>8&255;a[d+2|0]=m>>>16&255;m=l+1|0;if((m|0)<(e|0)){d=d+3|0;l=m}else{break}}}l=b+1|0;if((l|0)<(f|0)){h=h+g|0;b=l;k=k+(j<<2)|0}else{break}}return}function iQ(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)<=0){return}h=(d|0)>0;i=f>>2;f=g>>2;g=a;a=0;j=b;while(1){if(h){b=0;do{k=c[j+(b<<2)>>2]|0;c[g+(b<<2)>>2]=k>>>16&255|k&-16711936|k<<16&16711680;b=b+1|0;}while((b|0)<(d|0))}b=a+1|0;if((b|0)<(e|0)){g=g+(i<<2)|0;a=b;j=j+(f<<2)|0}else{break}}return}function iR(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[a+104>>2]|0;g=a+16|0;h=c[g>>2]|0;if((h|0)<=0){return}i=a+92|0;j=a+116|0;k=a+12|0;l=a+88|0;m=e>>2;e=a+84|0;n=0;o=c[a+80>>2]|0;a=d;d=c[k>>2]|0;p=h;while(1){h=ag(c[j>>2]>>3,c[(c[i>>2]|0)+(n<<2)>>2]|0)|0;if((d|0)>0){q=0;do{r=c[e>>2]|0;if((r|0)==0){s=0;t=0;u=0;v=0}else{w=c[j>>2]>>3;x=0;y=0;z=f+(q+h<<3)|0;A=0;B=0;C=0;while(1){D=c[z>>2]|0;E=c[z+4>>2]|0;F=b[o+(A<<1)>>1]|0;G=ag(((E>>>16|0<<16)&65535)<<16>>16,F)|0;H=ag((E&65535)<<16>>16,F)|0;I=ag(((D>>>16|E<<16)&65535)<<16>>16,F)|0;E=A+1|0;J=G+(C<<16)>>16;K=H+(B<<16)>>16;L=I+(x<<16)>>16;M=(ag((D&65535)<<16>>16,F)|0)+(y<<16)>>16;if(E>>>0<r>>>0){x=L;y=M;z=z+(w<<3)|0;A=E;B=K;C=J}else{break}}s=L>>>3;t=M>>>3;u=K>>>3;v=J>>>3}C=v&65535;B=u&65535;A=s&65535;w=t&65535;if(C<<16>>16>255){N=-16777216}else{N=C<<16>>16<0?0:v<<24}if(B<<16>>16>255){O=16711680}else{O=B<<16>>16<0?0:u<<16&16711680}if(A<<16>>16>255){P=65280}else{P=A<<16>>16<0?0:s<<8&65280}if(w<<16>>16>255){Q=255}else{Q=w<<16>>16<0?0:t&255}c[a+(q<<2)>>2]=O|N|P|Q;q=q+1|0;R=c[k>>2]|0;}while((q|0)<(R|0));S=R;T=c[g>>2]|0}else{S=d;T=p}q=n+1|0;if((q|0)>=(T|0)){break}n=q;o=o+(c[l>>2]<<1)|0;a=a+(m<<2)|0;d=S;p=T}return}function iS(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[b+60|0]&1)!=0){ge[c[b+56>>2]&63](d,e,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[b+8>>2]|0);return}f=b+44|0;if((c[f>>2]|0)==0){if((c[b+24>>2]|0)==0){gr[c[b+36>>2]&127](b,e,c[b+8>>2]|0)}else{g=b+96|0;h=b+100|0;ge[c[b+48>>2]&63](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,c[b+8>>2]|0);gr[c[b+36>>2]&127](b,c[g>>2]|0,c[h>>2]|0)}h=c[b+40>>2]|0;if((c[b+28>>2]|0)==0){gr[h&127](b,d,c[b+20>>2]|0);return}else{g=b+120|0;i=b+124|0;gr[h&127](b,c[g>>2]|0,c[i>>2]|0);ge[c[b+52>>2]&63](d,c[g>>2]|0,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[i>>2]|0);return}}else{i=c[b+8>>2]|0;if((c[b+24>>2]|0)==0){j=e;k=i}else{g=b+96|0;h=b+100|0;ge[c[b+48>>2]&63](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,i);j=c[g>>2]|0;k=c[h>>2]|0}h=(c[b+28>>2]|0)!=0;g=b+20|0;if(h){l=b+124|0;m=c[b+120>>2]|0}else{l=g;m=d}i=b+12|0;e=b+16|0;gk[c[f>>2]&15](b,m,j,c[i>>2]|0,c[e>>2]|0,c[b>>2]|0,c[b+4>>2]|0,c[l>>2]|0,k);if(!h){return}ge[c[b+52>>2]&63](d,c[b+120>>2]|0,c[i>>2]|0,c[e>>2]|0,c[g>>2]|0,c[b+124>>2]|0);return}}function iT(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c=(e|0)>-1?e:-e|0;g=(f|0)>-1?f:-f|0;h=(g|0)<(c|0)?g:c;if((d|0)>0){i=b;j=a;k=0}else{return}while(1){yE(j|0,i|0,h)|0;a=k+1|0;if((a|0)<(d|0)){i=i+f|0;j=j+e|0;k=a}else{break}}return}function iU(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=a+112|0;g=c[f>>2]|0;if((g|0)<=0){return}h=a+64|0;i=a+108|0;j=e>>2;e=a+116|0;k=a+76|0;l=a+68|0;m=a+72|0;n=0;o=c[a+104>>2]|0;a=d;d=c[i>>2]|0;p=g;while(1){if((d|0)>0){g=0;q=c[h>>2]|0;while(1){r=c[(c[k>>2]|0)+(g<<2)>>2]|0;s=c[l>>2]|0;if((s|0)==0){t=0;u=0;v=0;w=0;x=0;y=0;z=0;A=0}else{B=0;C=0;D=0;E=0;F=0;while(1){G=c[a+(E+r<<2)>>2]|0;H=b[q+(E<<1)>>1]|0;I=((ag(G>>>17&32640,H)|0)>>>16)+(F&65535)|0;J=((ag(G>>>9&32640,H)|0)>>>16)+(B&65535)|0;K=((ag(G>>>1&32640,H)|0)>>>16)+(C&65535)|0;L=((ag(G<<7&32640,H)|0)>>>16)+(D&65535)|0;H=E+1|0;if(H>>>0<s>>>0){B=J&65535;C=K&65535;D=L&65535;E=H;F=I&65535}else{break}}F=K&65535;t=J&65535;u=0;v=0<<16|F>>>16;w=F<<16|0>>>16;x=0;y=L&65535;z=I<<16|0>>>16;A=0<<16|0>>>16}F=o+(g<<3)|0;c[F>>2]=y|A|w|u;c[F+4>>2]=x|z|v|t;F=g+1|0;M=c[i>>2]|0;if((F|0)<(M|0)){g=F;q=q+(c[m>>2]<<1)|0}else{break}}N=M;O=c[f>>2]|0}else{N=d;O=p}q=n+1|0;if((q|0)<(O|0)){n=q;o=o+(c[e>>2]>>3<<3)|0;a=a+(j<<2)|0;d=N;p=O}else{break}}return}function iV(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;a=((g<<15|0)/(e|0)|0)-32768|0;k=(g<<16|0)/(e|0)|0;g=((h<<15|0)/(f|0)|0)-32768|0;l=(h<<16|0)/(f|0)|0;h=(a|0)<0?0:a;a=d;if((f|0)<=0){return}d=j>>2;j=i>>2;if((e|0)<=0){return}i=(g|0)<0?0:g;g=b;b=0;while(1){m=ag(i>>16,d)|0;n=h;o=0;while(1){c[g+(o<<2)>>2]=c[a+((n>>16)+m<<2)>>2];p=o+1|0;if((p|0)<(e|0)){n=n+k|0;o=p}else{break}}o=b+1|0;if((o|0)<(f|0)){i=i+l|0;g=g+(j<<2)|0;b=o}else{break}}return}function iW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=a+4|0;f=d-(c[e>>2]|0)|0;if((b|0)<=0){return}d=a+12|0;g=a|0;h=a+8|0;a=0;do{i=(c[d>>2]|0)+(a<<2)|0;j=c[i>>2]|0;k=j-f|0;l=-j|0;do{if((k|0)>0){c[i>>2]=f;m=c[g>>2]|0;n=ag(c[h>>2]|0,a)|0;o=m+(n<<1)|0;p=c[e>>2]|0;if((k|0)>(p|0)){yB(o|0,0,p<<1|0);break}else{q=o;yI(m+(n+k<<1)|0,q|0,p-k<<1|0);yB(q|0,0,k<<1|0);break}}}while(0);do{if((j|0)<0){k=(c[d>>2]|0)+(a<<2)|0;c[k>>2]=(c[k>>2]|0)-j;k=c[g>>2]|0;i=ag(c[h>>2]|0,a)|0;q=c[e>>2]|0;p=k+(i<<1)|0;if((q|0)<(l|0)){yB(p|0,0,q<<1|0);break}else{yI(p|0,k+(i-j<<1)|0,q+j<<1|0);yB(k+(i+j+(c[e>>2]|0)<<1)|0,0,l<<1|0);break}}}while(0);a=a+1|0;}while((a|0)<(b|0));return}function iX(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a5=0;f=i;i=i+1824|0;h=f|0;j=f+8|0;k=f+1032|0;l=f+1040|0;m=f+1048|0;n=f+1112|0;o=f+1176|0;p=f+1184|0;q=f+1248|0;r=f+1312|0;s=f+1376|0;u=f+1440|0;v=f+1504|0;w=f+1568|0;x=f+1632|0;y=f+1696|0;z=f+1760|0;yB(e|0,0,109528);c[e>>2]=0;A=d+4|0;B=A;while(1){C=c[B>>2]|0;if((C|0)==0){break}if((db(48096,c[C+4>>2]|0)|0)==0){D=4027;break}else{B=C+12|0}}do{if((D|0)==4027){c[(er()|0)>>2]=0;B=a4(c[C+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}if((B|0)==0){E=c[140620]|0;F=(E|0)!=0?E:c[t>>2]|0;be(37888,55,1,F|0)|0;F=c[140620]|0;E=(F|0)!=0?F:c[t>>2]|0;a7(E|0)|0;G=0;i=f;return G|0}E=B>>>0<16?B:16;B=e+72|0;c[B>>2]=E;F=m|0;H=n|0;I=p|0;J=q|0;K=r|0;L=s|0;M=u|0;N=v|0;O=w|0;P=x|0;Q=y|0;R=z|0;L5665:do{if((E|0)!=0){S=0;while(1){b5(F|0,64,30728,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;L5668:do{if(hD(d,F,e+76+(S*4148|0)|0)|0){b5(H|0,64,30256,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;a[o]=0;if(hE(d,H,o)|0){c[e+76+(S*4148|0)+4136>>2]=(a[o]&1)!=0?1:2}else{c[e+76+(S*4148|0)+4136>>2]=0}b5(I|0,64,29464,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;U=A;while(1){V=c[U>>2]|0;if((V|0)==0){break}if((db(I|0,c[V+4>>2]|0)|0)==0){D=4040;break}else{U=V+12|0}}do{if((D|0)==4040){D=0;U=64;W=0;X=J;Y=c[V+8>>2]|0;while(1){Z=U-1|0;if((Z|0)==0){D=4043;break}_=a[Y]|0;a[X]=_;if(_<<24>>24==0){$=W;break}else{U=Z;W=W+1|0;X=X+1|0;Y=Y+1|0}}do{if((D|0)==4043){D=0;a[X]=0;if((a[Y]|0)==0){$=W;break}else{aa=Y;ab=W}while(1){U=aa+1|0;Z=ab+1|0;if((a[U]|0)==0){$=Z;break}else{aa=U;ab=Z}}}}while(0);if($>>>0>=64){break}c[e+76+(S*4148|0)+4140>>2]=i0(J)|0}}while(0);yB(K|0,0,64);b5(L|0,64,29024,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;W=A;while(1){ac=c[W>>2]|0;if((ac|0)==0){break}if((db(L|0,c[ac+4>>2]|0)|0)==0){D=4050;break}else{W=ac+12|0}}do{if((D|0)==4050){D=0;W=64;Y=0;X=K;Z=c[ac+8>>2]|0;while(1){U=W-1|0;if((U|0)==0){D=4053;break}_=a[Z]|0;a[X]=_;if(_<<24>>24==0){ad=Y;break}else{W=U;Y=Y+1|0;X=X+1|0;Z=Z+1|0}}do{if((D|0)==4053){D=0;a[X]=0;if((a[Z]|0)==0){ad=Y;break}else{ae=Z;af=Y}while(1){W=ae+1|0;U=af+1|0;if((a[W]|0)==0){ad=U;break}else{ae=W;af=U}}}}while(0);if(ad>>>0>=64){break}c[e+76+(S*4148|0)+4144>>2]=a4(K|0,0,0)|0}}while(0);yB(M|0,0,64);yB(N|0,0,64);yB(O|0,0,64);b5(P|0,64,48456,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;Y=A;while(1){ag=c[Y>>2]|0;if((ag|0)==0){break}if((db(P|0,c[ag+4>>2]|0)|0)==0){D=4060;break}else{Y=ag+12|0}}L5708:do{if((D|0)==4060){D=0;Y=64;Z=M;X=c[ag+8>>2]|0;while(1){U=Y-1|0;if((U|0)==0){break}W=a[X]|0;a[Z]=W;if(W<<24>>24==0){break L5708}else{Y=U;Z=Z+1|0;X=X+1|0}}a[Z]=0;if((a[X]|0)==0){break}else{ah=X}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);b5(P|0,64,48344,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;X=A;while(1){ai=c[X>>2]|0;if((ai|0)==0){break}if((db(P|0,c[ai+4>>2]|0)|0)==0){D=4068;break}else{X=ai+12|0}}L5720:do{if((D|0)==4068){D=0;X=64;Z=N;Y=c[ai+8>>2]|0;while(1){U=X-1|0;if((U|0)==0){break}W=a[Y]|0;a[Z]=W;if(W<<24>>24==0){break L5720}else{X=U;Z=Z+1|0;Y=Y+1|0}}a[Z]=0;if((a[Y]|0)==0){break}else{aj=Y}do{aj=aj+1|0;}while((a[aj]|0)!=0)}}while(0);b5(P|0,64,48208,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;Y=A;while(1){ak=c[Y>>2]|0;if((ak|0)==0){break}if((db(P|0,c[ak+4>>2]|0)|0)==0){D=4076;break}else{Y=ak+12|0}}L5732:do{if((D|0)==4076){D=0;Y=64;Z=O;X=c[ak+8>>2]|0;while(1){U=Y-1|0;if((U|0)==0){break}W=a[X]|0;a[Z]=W;if(W<<24>>24==0){break L5732}else{Y=U;Z=Z+1|0;X=X+1|0}}a[Z]=0;if((a[X]|0)==0){break}else{al=X}do{al=al+1|0;}while((a[al]|0)!=0)}}while(0);L5741:do{if((a[M]|0)==0){if((a[N]|0)!=0){break}if((a[O]|0)==0){am=1;break L5668}}else{X=64;Z=N;Y=M;while(1){U=X-1|0;if((U|0)==0){D=4086;break}W=a[Y]|0;a[Z]=W;if(W<<24>>24==0){an=64;ao=O;ap=M;break}else{X=U;Z=Z+1|0;Y=Y+1|0}}do{if((D|0)==4086){D=0;a[Z]=0;if((a[Y]|0)==0){an=64;ao=O;ap=M;break}else{aq=Y}while(1){X=aq+1|0;if((a[X]|0)==0){an=64;ao=O;ap=M;break}else{aq=X}}}}while(0);while(1){Y=an-1|0;if((Y|0)==0){break}Z=a[ap]|0;a[ao]=Z;if(Z<<24>>24==0){break L5741}else{an=Y;ao=ao+1|0;ap=ap+1|0}}a[ao]=0;if((a[ap]|0)==0){break}else{ar=ap}do{ar=ar+1|0;}while((a[ar]|0)!=0)}}while(0);a[e+76+(S*4148|0)+4104|0]=1;Y=e+76+(S*4148|0)+4108|0;c[Y>>2]=0;Z=e+76+(S*4148|0)+4112|0;c[Z>>2]=0;X=e+76+(S*4148|0)+4116|0;g[X>>2]=1.0;U=e+76+(S*4148|0)+4120|0;g[U>>2]=1.0;b5(R|0,64,20352,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;hE(d,R,e+76+(S*4148|0)+4132|0)|0;do{if((a[N]|0)!=0){if((db(N|0,19232)|0)==0){c[Y>>2]=0;break}if((db(N|0,19008)|0)==0){c[Y>>2]=2;break}if((db(N|0,18816)|0)==0){c[Y>>2]=1;break}else{W=c[140620]|0;_=(W|0)!=0?W:c[t>>2]|0;be(48048,40,1,_|0)|0;_=c[140620]|0;W=(_|0)!=0?_:c[t>>2]|0;a7(W|0)|0;am=0;break L5668}}}while(0);do{if((a[O]|0)!=0){if((db(O|0,19232)|0)==0){c[Z>>2]=0;break}if((db(O|0,19008)|0)==0){c[Z>>2]=2;break}if((db(O|0,18816)|0)==0){c[Z>>2]=1;break}else{W=c[140620]|0;_=(W|0)!=0?W:c[t>>2]|0;be(48048,40,1,_|0)|0;_=c[140620]|0;W=(_|0)!=0?_:c[t>>2]|0;a7(W|0)|0;am=0;break L5668}}}while(0);W=(c[Y>>2]|0)==1;b5(Q|0,64,47968,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;L5782:do{if(W){_=A;while(1){as=c[_>>2]|0;if((as|0)==0){break}if((db(Q|0,c[as+4>>2]|0)|0)==0){D=4111;break}else{_=as+12|0}}do{if((D|0)==4111){D=0;c[(er()|0)>>2]=0;_=bb(c[as+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4124>>2]=_;break L5782}}while(0);b5(Q|0,64,47896,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;_=A;while(1){at=c[_>>2]|0;if((at|0)==0){break L5782}if((db(Q|0,c[at+4>>2]|0)|0)==0){break}else{_=at+12|0}}c[(er()|0)>>2]=0;_=bb(c[at+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4124>>2]=_}else{_=A;while(1){au=c[_>>2]|0;if((au|0)==0){break}if((db(Q|0,c[au+4>>2]|0)|0)==0){D=4120;break}else{_=au+12|0}}if((D|0)==4120){D=0;g[X>>2]=+yz(c[au+8>>2]|0,0);break}b5(Q|0,64,47896,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;_=A;while(1){av=c[_>>2]|0;if((av|0)==0){break L5782}if((db(Q|0,c[av+4>>2]|0)|0)==0){break}else{_=av+12|0}}g[X>>2]=+yz(c[av+8>>2]|0,0)}}while(0);X=(c[Z>>2]|0)==1;b5(Q|0,64,47968,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;if(X){aw=A}else{X=A;while(1){ax=c[X>>2]|0;if((ax|0)==0){break}if((db(Q|0,c[ax+4>>2]|0)|0)==0){D=4137;break}else{X=ax+12|0}}if((D|0)==4137){D=0;g[U>>2]=+yz(c[ax+8>>2]|0,0);am=1;break}b5(Q|0,64,47840,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;X=A;while(1){ay=c[X>>2]|0;if((ay|0)==0){am=1;break L5668}if((db(Q|0,c[ay+4>>2]|0)|0)==0){break}else{X=ay+12|0}}g[U>>2]=+yz(c[ay+8>>2]|0,0);am=1;break}while(1){az=c[aw>>2]|0;if((az|0)==0){break}if((db(Q|0,c[az+4>>2]|0)|0)==0){D=4128;break}else{aw=az+12|0}}do{if((D|0)==4128){D=0;c[(er()|0)>>2]=0;U=bb(c[az+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4128>>2]=U;am=1;break L5668}}while(0);b5(Q|0,64,47840,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;U=A;while(1){aA=c[U>>2]|0;if((aA|0)==0){am=1;break L5668}if((db(Q|0,c[aA+4>>2]|0)|0)==0){break}else{U=aA+12|0}}c[(er()|0)>>2]=0;U=bb(c[aA+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){am=1;break}c[e+76+(S*4148|0)+4128>>2]=U;am=1}else{U=c[140620]|0;eS(((U|0)!=0?U:c[t>>2]|0)|0,48552,(T=i,i=i+8|0,c[T>>2]=F,T)|0)|0;i=T;U=c[140620]|0;a7(((U|0)!=0?U:c[t>>2]|0)|0)|0;am=0}}while(0);if(!am){G=0;break}S=S+1|0;if(S>>>0>=(c[B>>2]|0)>>>0){break L5665}}i=f;return G|0}}while(0);B=j|0;Q=A;while(1){aB=c[Q>>2]|0;if((aB|0)==0){break}if((db(28264,c[aB+4>>2]|0)|0)==0){D=4147;break}else{Q=aB+12|0}}L5836:do{if((D|0)==4147){Q=1024;O=0;N=B;R=c[aB+8>>2]|0;while(1){M=Q-1|0;if((M|0)==0){D=4150;break}P=a[R]|0;a[N]=P;if(P<<24>>24==0){aC=O;break}else{Q=M;O=O+1|0;N=N+1|0;R=R+1|0}}do{if((D|0)==4150){a[N]=0;if((a[R]|0)==0){aC=O;break}else{aD=R;aE=O}while(1){Q=aD+1|0;M=aE+1|0;if((a[Q]|0)==0){aC=M;break}else{aD=Q;aE=M}}}}while(0);if(aC>>>0>=1024){break}O=eO(B|0,28640,k|0)|0;if((O|0)==0){break}R=e+66444|0;N=O;L5848:while(1){O=c[R>>2]|0;if(O>>>0>=8){break L5836}M=e+66448+(O*4168|0)+64|0;O=A;while(1){aF=c[O>>2]|0;if((aF|0)==0){break L5848}if((db(N|0,c[aF+4>>2]|0)|0)==0){break}else{O=aF+12|0}}O=4096;Q=0;P=M;E=c[aF+8>>2]|0;while(1){S=O-1|0;if((S|0)==0){D=4162;break}U=a[E]|0;a[P]=U;if(U<<24>>24==0){aG=Q;break}else{O=S;Q=Q+1|0;P=P+1|0;E=E+1|0}}do{if((D|0)==4162){D=0;a[P]=0;if((a[E]|0)==0){aG=Q;break}else{aH=E;aI=Q}while(1){O=aH+1|0;M=aI+1|0;if((a[O]|0)==0){aG=M;break}else{aH=O;aI=M}}}}while(0);if(aG>>>0>=4096){break}Q=64;E=e+66448+((c[R>>2]|0)*4168|0)|0;P=N;while(1){M=Q-1|0;if((M|0)==0){D=4169;break}O=a[P]|0;a[E]=O;if(O<<24>>24==0){break}else{Q=M;E=E+1|0;P=P+1|0}}do{if((D|0)==4169){D=0;a[E]=0;if((a[P]|0)==0){break}else{aJ=P}do{aJ=aJ+1|0;}while((a[aJ]|0)!=0)}}while(0);b5(F|0,64,27848,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;a[l]=0;if(hE(d,F,l)|0){c[e+66448+((c[R>>2]|0)*4168|0)+4160>>2]=(a[l]&1)!=0?1:2}else{c[e+66448+((c[R>>2]|0)*4168|0)+4160>>2]=0}b5(H|0,64,27424,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;P=A;while(1){aK=c[P>>2]|0;if((aK|0)==0){break}if((db(H|0,c[aK+4>>2]|0)|0)==0){D=4177;break}else{P=aK+12|0}}do{if((D|0)==4177){D=0;P=64;E=0;Q=I;M=c[aK+8>>2]|0;while(1){O=P-1|0;if((O|0)==0){D=4180;break}S=a[M]|0;a[Q]=S;if(S<<24>>24==0){aL=E;break}else{P=O;E=E+1|0;Q=Q+1|0;M=M+1|0}}do{if((D|0)==4180){D=0;a[Q]=0;if((a[M]|0)==0){aL=E;break}else{aM=M;aN=E}while(1){P=aM+1|0;O=aN+1|0;if((a[P]|0)==0){aL=O;break}else{aM=P;aN=O}}}}while(0);if(aL>>>0>=64){break}E=i0(I)|0;c[e+66448+((c[R>>2]|0)*4168|0)+4164>>2]=E}}while(0);c[R>>2]=(c[R>>2]|0)+1;E=eO(0,28640,k|0)|0;if((E|0)==0){break L5836}else{N=E}}R=c[140620]|0;eS(((R|0)!=0?R:c[t>>2]|0)|0,49080,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;R=c[140620]|0;a7(((R|0)!=0?R:c[t>>2]|0)|0)|0;G=0;i=f;return G|0}}while(0);R=A;while(1){aO=c[R>>2]|0;if((aO|0)==0){G=1;D=4261;break}if((db(26248,c[aO+4>>2]|0)|0)==0){break}else{R=aO+12|0}}if((D|0)==4261){i=f;return G|0}R=1024;E=0;M=B;Q=c[aO+8>>2]|0;while(1){O=R-1|0;if((O|0)==0){D=4191;break}P=a[Q]|0;a[M]=P;if(P<<24>>24==0){aP=E;break}else{R=O;E=E+1|0;M=M+1|0;Q=Q+1|0}}do{if((D|0)==4191){a[M]=0;if((a[Q]|0)==0){aP=E;break}else{aQ=Q;aR=E}while(1){R=aQ+1|0;O=aR+1|0;if((a[R]|0)==0){aP=O;break}else{aQ=R;aR=O}}}}while(0);if(aP>>>0>=1024){G=1;i=f;return G|0}E=eO(B|0,28640,h|0)|0;L5911:do{if((E|0)!=0){Q=e+99792|0;M=E;L5913:while(1){N=c[Q>>2]|0;if(N>>>0>=64){break L5911}O=64;R=e+99796+(N*80|0)|0;P=M;while(1){S=O-1|0;if((S|0)==0){D=4200;break}U=a[P]|0;a[R]=U;if(U<<24>>24==0){break}else{O=S;R=R+1|0;P=P+1|0}}do{if((D|0)==4200){D=0;a[R]=0;if((a[P]|0)==0){break}else{aS=P}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);b5(F|0,64,24032,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;b5(H|0,64,23800,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;b5(I|0,64,23456,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;b5(J|0,64,23224,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;b5(K|0,64,22928,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;P=A;while(1){aT=c[P>>2]|0;if((aT|0)==0){D=4211;break L5913}if((db(F|0,c[aT+4>>2]|0)|0)==0){break}else{P=aT+12|0}}P=64;R=0;O=L;S=c[aT+8>>2]|0;while(1){U=P-1|0;if((U|0)==0){D=4208;break}X=a[S]|0;a[O]=X;if(X<<24>>24==0){aU=R;break}else{P=U;R=R+1|0;O=O+1|0;S=S+1|0}}do{if((D|0)==4208){D=0;a[O]=0;if((a[S]|0)==0){aU=R;break}else{aV=S;aW=R}while(1){P=aV+1|0;U=aW+1|0;if((a[P]|0)==0){aU=U;break}else{aV=P;aW=U}}}}while(0);if(aU>>>0>=64){D=4211;break}do{if((db(L|0,22768)|0)==0){c[e+99796+(N*80|0)+68>>2]=0;aX=A;D=4225}else{if((db(L|0,22280)|0)==0){c[e+99796+(N*80|0)+68>>2]=2;aX=A;D=4225;break}if((db(L|0,21616)|0)==0){c[e+99796+(N*80|0)+68>>2]=3;aX=A;D=4225;break}if((db(L|0,21216)|0)==0){c[e+99796+(N*80|0)+68>>2]=1;aX=A;D=4225;break}if((db(L|0,20720)|0)==0){c[e+99796+(N*80|0)+68>>2]=4;aX=A;D=4225;break}if((db(L|0,20552)|0)!=0){D=4223;break L5913}c[e+99796+(N*80|0)+68>>2]=5;aY=A}}while(0);L5953:do{if((D|0)==4225){while(1){D=0;aZ=c[aX>>2]|0;if((aZ|0)==0){a_=A;break}if((db(I|0,c[aZ+4>>2]|0)|0)==0){D=4227;break}else{aX=aZ+12|0;D=4225}}do{if((D|0)==4227){D=0;c[(er()|0)>>2]=0;R=a4(c[aZ+8>>2]|0,0,0)|0;if((c[(er()|0)>>2]|0)!=0){a_=A;break}if((R|0)==1){c[e+99796+(N*80|0)+72>>2]=2;aY=A;break L5953}else if((R|0)==2){c[e+99796+(N*80|0)+72>>2]=3;aY=A;break L5953}else{D=4231;break L5913}}}while(0);while(1){a$=c[a_>>2]|0;if((a$|0)==0){D=4236;break L5913}if((db(H|0,c[a$+4>>2]|0)|0)==0){break}else{a_=a$+12|0}}c[(er()|0)>>2]=0;R=a4(c[a$+8>>2]|0,0,16)|0;if((c[(er()|0)>>2]|0)!=0){D=4236;break L5913}c[e+99796+(N*80|0)+72>>2]=1;c[e+99796+(N*80|0)+64>>2]=R;aY=A}}while(0);while(1){a0=c[aY>>2]|0;if((a0|0)==0){a1=A;break}if((db(J|0,c[a0+4>>2]|0)|0)==0){D=4239;break}else{aY=a0+12|0}}do{if((D|0)==4239){D=0;c[(er()|0)>>2]=0;R=a4(c[a0+8>>2]|0,0,16)|0;if((c[(er()|0)>>2]|0)!=0){a1=A;break}b[e+99796+(N*80|0)+76>>1]=R&65535;a1=A}}while(0);while(1){a2=c[a1>>2]|0;if((a2|0)==0){break}if((db(K|0,c[a2+4>>2]|0)|0)==0){D=4243;break}else{a1=a2+12|0}}do{if((D|0)==4243){D=0;c[(er()|0)>>2]=0;R=a4(c[a2+8>>2]|0,0,16)|0;if((c[(er()|0)>>2]|0)!=0){break}b[e+99796+(N*80|0)+78>>1]=R&65535}}while(0);c[Q>>2]=(c[Q>>2]|0)+1;M=eO(0,28640,h|0)|0;if((M|0)==0){break L5911}}if((D|0)==4223){M=c[140620]|0;Q=(M|0)!=0?M:c[t>>2]|0;be(49592,39,1,Q|0)|0;Q=c[140620]|0;M=(Q|0)!=0?Q:c[t>>2]|0;a7(M|0)|0;G=0;i=f;return G|0}else if((D|0)==4211){M=c[140620]|0;be(49752,54,1,((M|0)!=0?M:c[t>>2]|0)|0)|0;M=c[140620]|0;a7(((M|0)!=0?M:c[t>>2]|0)|0)|0;G=0;i=f;return G|0}else if((D|0)==4236){M=c[140620]|0;be(49384,54,1,((M|0)!=0?M:c[t>>2]|0)|0)|0;M=c[140620]|0;a7(((M|0)!=0?M:c[t>>2]|0)|0)|0;G=0;i=f;return G|0}else if((D|0)==4231){M=c[140620]|0;be(14200,52,1,((M|0)!=0?M:c[t>>2]|0)|0)|0;M=c[140620]|0;a7(((M|0)!=0?M:c[t>>2]|0)|0)|0;G=0;i=f;return G|0}}}while(0);hD(d,27104,e+104916|0)|0;K=e+109016|0;J=A;while(1){a3=c[J>>2]|0;if((a3|0)==0){G=1;D=4266;break}if((db(26640,c[a3+4>>2]|0)|0)==0){break}else{J=a3+12|0}}if((D|0)==4266){i=f;return G|0}J=512;H=K;I=c[a3+8>>2]|0;while(1){L=J-1|0;if((L|0)==0){break}F=a[I]|0;a[H]=F;if(F<<24>>24==0){G=1;D=4255;break}else{J=L;H=H+1|0;I=I+1|0}}if((D|0)==4255){i=f;return G|0}a[H]=0;if((a[I]|0)==0){G=1;i=f;return G|0}else{a5=I}while(1){J=a5+1|0;if((a[J]|0)==0){G=1;break}else{a5=J}}i=f;return G|0}}while(0);a5=c[140620]|0;be(51272,50,1,((a5|0)!=0?a5:c[t>>2]|0)|0)|0;a5=c[140620]|0;a7(((a5|0)!=0?a5:c[t>>2]|0)|0)|0;G=0;i=f;return G|0}function iY(){return 564064|0}function iZ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+8200|0;g=f|0;h=f+4104|0;c[g>>2]=b;j=f+8|0;k=e+8|0;while(1){l=c[k>>2]|0;if((l|0)==0){break}if((db(42584,c[l>>2]|0)|0)==0){m=4273;break}else{k=l+8|0}}do{if((m|0)==4273){k=c[l+4>>2]|0;if((k|0)==0){break}else{n=4096;o=0;p=j;q=k}while(1){k=n-1|0;if((k|0)==0){m=4277;break}e=a[q]|0;a[p]=e;if(e<<24>>24==0){r=o;break}else{n=k;o=o+1|0;p=p+1|0;q=q+1|0}}do{if((m|0)==4277){a[p]=0;if((a[q]|0)==0){r=o;break}else{s=q;u=o}while(1){k=s+1|0;e=u+1|0;if((a[k]|0)==0){r=e;break}else{s=k;u=e}}}}while(0);if(r>>>0>=4096){i=f;return b|0}yt(b);c[g>>2]=0;e=h|0;hw(e,d,j);if((a[405432]&1)==0){v=hb(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}k=c[140620]|0;eS(((k|0)!=0?k:c[t>>2]|0)|0,49952,(k=i,i=i+8|0,c[k>>2]=e,k)|0)|0;i=k;k=c[140620]|0;a7(((k|0)!=0?k:c[t>>2]|0)|0)|0;v=hb(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}}while(0);a[j]=0;i=f;return b|0}function i_(a,b){a=a|0;b=b|0;var c=0,d=0;if((a|0)==0){c=b;return c|0}d=cE(a|0,46)|0;a=(d|0)==0?564064:d+1|0;if((db(a|0,29872)|0)==0){c=0;return c|0}if((db(a|0,50664)|0)==0){c=0;return c|0}if((db(a|0,19552)|0)==0){c=2;return c|0}if((db(a|0,50088)|0)==0){c=2;return c|0}else{return((db(a|0,42248)|0)==0?2:b)|0}return 0}function i$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+4096|0;f=e|0;g=b+72|0;h=c[g>>2]|0;if((h|0)!=0){j=f|0;k=0;l=h;while(1){h=b+76+(k*4148|0)|0;if((a[h]|0)==0){m=l}else{n=4096;o=j;p=h;while(1){q=n-1|0;if((q|0)==0){r=4307;break}s=a[p]|0;a[o]=s;if(s<<24>>24==0){break}else{n=q;o=o+1|0;p=p+1|0}}do{if((r|0)==4307){r=0;a[o]=0;if((a[p]|0)==0){break}else{t=p}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);hw(h,d,j);m=c[g>>2]|0}p=k+1|0;if(p>>>0<m>>>0){k=p;l=m}else{break}}}m=b+66444|0;if((c[m>>2]|0)!=0){l=f|0;k=0;do{g=b+66448+(k*4168|0)+64|0;j=4096;t=l;p=g;while(1){o=j-1|0;if((o|0)==0){r=4314;break}n=a[p]|0;a[t]=n;if(n<<24>>24==0){break}else{j=o;t=t+1|0;p=p+1|0}}do{if((r|0)==4314){r=0;a[t]=0;if((a[p]|0)==0){break}else{u=p}do{u=u+1|0;}while((a[u]|0)!=0)}}while(0);hw(g,d,l);k=k+1|0;}while(k>>>0<(c[m>>2]|0)>>>0)}m=b+104916|0;if((a[m]|0)==0){i=e;return}b=f|0;f=4096;k=b;l=m;while(1){u=f-1|0;if((u|0)==0){r=4321;break}p=a[l]|0;a[k]=p;if(p<<24>>24==0){break}else{f=u;k=k+1|0;l=l+1|0}}do{if((r|0)==4321){a[k]=0;if((a[l]|0)==0){break}else{v=l}do{v=v+1|0;}while((a[v]|0)!=0)}}while(0);hw(m,d,b);i=e;return}function i0(a){a=a|0;var b=0,d=0,e=0;b=i;if((db(a|0,18600)|0)==0){d=0;i=b;return d|0}if((db(a|0,18432)|0)==0){d=1;i=b;return d|0}if((db(a|0,18240)|0)==0){d=2;i=b;return d|0}if((db(a|0,18024)|0)==0){d=3;i=b;return d|0}e=c[140620]|0;eS(((e|0)!=0?e:c[t>>2]|0)|0,48760,(e=i,i=i+8|0,c[e>>2]=a,e)|0)|0;i=e;e=c[140620]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;d=0;i=b;return d|0}function i1(b,e){b=b|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=ys(1032)|0;if((b|0)==0){f=0;return f|0}if((c[b-4>>2]&3|0)!=0){yB(b|0,0,1032)}g=b;h=~~+bZ(+(e/10.0));i=b;j=(h|0)==0?1:h;c[i>>2]=j;h=ys(ag(j*12800|0,j)|0)|0;k=b+1028|0;c[k>>2]=h;if((h|0)==0){yt(b);f=0;return f|0}else{l=0;m=j;n=h}while(1){h=ag(ag(m*50|0,m)|0,l)|0;c[g+4+(l<<2)>>2]=n+h;j=l*7|0;o=c[i>>2]|0;p=0;q=o;while(1){r=p*5|0;s=0;t=q;u=q;while(1){v=s+r|0;w=((1<<(v&7)&(d[8392+((v>>>3)+j)|0]|0)|0)!=0)<<31>>31;if((t|0)==0){x=0;y=u}else{v=0;z=u;while(1){if((z|0)==0){A=0}else{B=v+h|0;C=0;D=z;while(1){a[n+(B+(ag((((ag(D,p)|0)+C|0)*5|0)+s|0,D)|0))|0]=w;E=C+1|0;if(E>>>0<o>>>0){C=E;D=o}else{A=o;break}}}D=v+1|0;if(D>>>0<A>>>0){v=D;z=A}else{x=A;y=A;break}}}z=s+1|0;if(z>>>0<5){s=z;t=x;u=y}else{break}}u=p+1|0;if(u>>>0<10){p=u;q=y}else{break}}q=l+1|0;if(q>>>0>=256){f=b;break}l=q;m=o;n=c[k>>2]|0}return f|0}function i2(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=e|0;c[f>>2]=0;e=yA(d|0)|0;if((e|0)==0){return}g=b+4|0;h=b;b=0;i=0;j=0;while(1){k=ys(52)|0;if((k|0)==0){l=4368;break}if((c[k-4>>2]&3|0)!=0){yB(k|0,0,52)}m=k;c[k>>2]=c[g+(a[d+i|0]<<2)>>2];n=c[h>>2]|0;o=n*5|0;c[k+4>>2]=o;p=n*10|0;c[k+8>>2]=p;c[k+12>>2]=o;c[k+32>>2]=o;c[k+36>>2]=p;c[k+40>>2]=0;c[k+44>>2]=p;c[k+24>>2]=b;c[k+28>>2]=0;c[k+48>>2]=0;if((i|0)==0){c[f>>2]=m;q=c[h>>2]|0}else{c[j+48>>2]=m;q=n}n=i+1|0;if(n>>>0<e>>>0){b=(q*6|0)+b|0;i=n;j=m}else{l=4369;break}}if((l|0)==4368){return}else if((l|0)==4369){return}}function i3(a,b){a=a|0;b=b|0;var d=0;a=b|0;b=c[a>>2]|0;if((b|0)==0){c[a>>2]=0;return}else{d=b}while(1){b=c[d+48>>2]|0;yt(d);if((b|0)==0){break}else{d=b}}c[a>>2]=0;return}function i4(a){a=a|0;yt(c[a+1028>>2]|0);yt(a);return}function i5(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0;h=i;i=i+1912|0;j=h|0;k=h+16|0;l=h+784|0;m=h+792|0;n=h+840|0;o=h+856|0;p=h+1880|0;q=h+1888|0;r=h+1904|0;if((bJ(b|0,46512)|0)!=0){c[r>>2]=0;if((hb(b,r)|0)<0){s=c[140620]|0;u=(s|0)!=0?s:c[t>>2]|0;eS(u|0,29880,(v=i,i=i+8|0,c[v>>2]=b,v)|0)|0;i=v;u=c[140620]|0;s=(u|0)!=0?u:c[t>>2]|0;a7(s|0)|0;w=0;i=h;return w|0}s=c[r>>2]|0;if((a[s+2|0]|0)!=2){r=c[140620]|0;u=(r|0)!=0?r:c[t>>2]|0;be(25336,56,1,u|0)|0;u=c[140620]|0;r=(u|0)!=0?u:c[t>>2]|0;a7(r|0)|0;yt(s);w=0;i=h;return w|0}r=a[s+16|0]|0;u=d[s+13|0]<<8|d[s+12|0];x=d[s+15|0]<<8|d[s+14|0];if((a[405432]&1)!=0){y=r&255;z=c[140620]|0;A=(z|0)!=0?z:c[t>>2]|0;eS(A|0,21920,(v=i,i=i+24|0,c[v>>2]=u,c[v+8>>2]=x,c[v+16>>2]=y,v)|0)|0;i=v;y=c[140620]|0;A=(y|0)!=0?y:c[t>>2]|0;a7(A|0)|0}A=ag(x,u)|0;y=ys(A<<2)|0;z=y;B=e+8|0;c[B>>2]=z;c[e>>2]=u;c[e+4>>2]=x;if((y|0)==0){y=c[140620]|0;x=(y|0)!=0?y:c[t>>2]|0;be(19496,52,1,x|0)|0;x=c[140620]|0;y=(x|0)!=0?x:c[t>>2]|0;a7(y|0)|0;yt(s);w=0;i=h;return w|0}L6176:do{if((r<<24>>24|0)==24){if((A|0)==0){break}else{C=0;D=z}while(1){y=C*3|0;c[D+(C<<2)>>2]=d[s+(y+18)|0]<<g|d[s+(y+19)|0]<<8|d[s+(y+20)|0]<<f|-16777216;y=C+1|0;if(y>>>0>=A>>>0){break L6176}C=y;D=c[B>>2]|0}}else if((r<<24>>24|0)==32){if((A|0)==0){break}else{E=0;F=z}while(1){y=E<<2;c[F+(E<<2)>>2]=d[s+((y|1)+18)|0]<<8|d[s+(y+18)|0]<<g|d[s+((y|2)+18)|0]<<f|d[s+((y|3)+18)|0]<<24;y=E+1|0;if(y>>>0>=A>>>0){break L6176}E=y;F=c[B>>2]|0}}else{y=c[140620]|0;be(17144,88,1,((y|0)!=0?y:c[t>>2]|0)|0)|0;y=c[140620]|0;a7(((y|0)!=0?y:c[t>>2]|0)|0)|0;yt(s);yt(c[B>>2]|0);c[B>>2]=0;w=0;i=h;return w|0}}while(0);yt(s);w=1;i=h;return w|0}if((bJ(b|0,50808)|0)==0){w=0;i=h;return w|0}if((a[405432]&1)!=0){s=c[140620]|0;B=(s|0)!=0?s:c[t>>2]|0;be(37664,38,1,B|0)|0;B=c[140620]|0;s=(B|0)!=0?B:c[t>>2]|0;a7(s|0)|0}s=e+8|0;B=e|0;F=e+4|0;e=n;E=p|0;p=q;c[s>>2]=0;c[B>>2]=0;c[F>>2]=0;A=dA(b|0,12144)|0;if((A|0)==0){w=0;i=h;return w|0}e6(A|0,0,2)|0;b=cy(A|0)|0;fe(A|0);yB(m|0,0,48);c[e>>2]=c[326];c[e+4>>2]=c[327];c[e+8>>2]=c[328];c[e+12>>2]=c[329];yB(o|0,0,1024);if((eM(E|0,1,8,A|0)|0)==8){L6202:do{if((yJ(E|0,6056,8)|0)==0){z=cy(A|0)|0;do{if((z|0)<(b|0)&(z|0)>-1){r=l;D=r+1|0;C=r+2|0;y=r+3|0;x=q|0;u=q+4|0;G=q+8|0;H=n|0;I=n+4|0;J=n+8|0;K=n+9|0;L=n+10|0;M=n+11|0;N=n+12|0;O=k|0;P=0;Q=0;R=0;S=0;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;L6206:while(1){yB(p|0,0,12);c[l>>2]=0;if((eM(r|0,1,4,A|0)|0)!=4){_=4407;break}c[x>>2]=d[D]<<16|d[r]<<24|d[C]<<8|d[y];if((eM(u|0,1,4,A|0)|0)==4){$=0}else{_=4407;break}while(1){if($>>>0>=4){_=4411;break}if((yJ(u|0,c[8280+($<<3)>>2]|0,4)|0)==0){_=4410;break}else{$=$+1|0}}L6212:do{if((_|0)==4410){_=0;switch(c[8284+($<<3)>>2]|0){case 1:{_=4413;break L6206;break};case 2:{if(R|S|T){_=4415;break L6206}yt(c[G>>2]|0);aa=c[x>>2]|0;ab=aa+4|0;ac=ys(ab)|0;if((ac|0)==0){_=4417;break L6206}if((c[ac-4>>2]&3|0)!=0){yB(ac|0,0,ab|0)}c[G>>2]=ac;if((eM(ac|0,1,ab|0,A|0)|0)!=(ab|0)){_=4421;break L6206}if((aa|0)!=13){_=4423;break L6206}aa=d[ac+1|0]<<16|d[ac]<<24|d[ac+2|0]<<8|d[ac+3|0];c[H>>2]=aa;ab=d[ac+5|0]<<16|d[ac+4|0]<<24|d[ac+6|0]<<8|d[ac+7|0];c[I>>2]=ab;ad=a[ac+8|0]|0;a[J]=ad;ae=a[ac+9|0]|0;a[K]=ae;af=a[ac+10|0]|0;a[L]=af;a[M]=a[ac+11|0]|0;ah=a[ac+12|0]|0;a[N]=ah;if((aa|0)==0|(ab|0)==0){_=4425;break L6206}switch(ae<<24>>24){case 0:{ai=ad&255;aj=0;while(1){if(aj>>>0>=5){_=4433;break L6206}if((c[6032+(aj<<2)>>2]|0)==(ai|0)){break}else{aj=aj+1|0}}break};case 3:{aj=ad&255;ai=0;while(1){if(ai>>>0>=4){_=4436;break L6206}if((c[6016+(ai<<2)>>2]|0)==(aj|0)){break}else{ai=ai+1|0}}break};case 2:case 4:case 6:{if(!((ad<<24>>24|0)==8|(ad<<24>>24|0)==16)){_=4430;break L6206}break};default:{_=4437;break L6206}}if(af<<24>>24!=0){_=4439;break L6206}yt(ac);c[G>>2]=0;ak=U;al=0;am=0;an=1;ao=Q;ap=P;aq=ae;ar=ab;as=ah;at=aa;au=ad;break L6212;break};case 4:{if(U|R^1|T|S){_=4444;break L6206}ai=c[x>>2]|0;if(((ai>>>0)%3|0|0)!=0){_=4446;break L6206}aj=(ai>>>0)/3|0;if(ai>>>0>770){_=4452;break L6206}if((eM(O|0,3,aj|0,A|0)|0)!=(aj|0)){_=4452;break L6206}if(ai>>>0>=3){ai=0;do{av=ai*3|0;c[o+(ai<<2)>>2]=d[k+av|0]<<16|d[k+(av+1)|0]<<8|d[k+(av+2)|0]|-16777216;ai=ai+1|0;}while(ai>>>0<aj>>>0)}if((e6(A|0,4,1)|0)>-1){ak=1;al=0;am=0;an=R;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z;break L6212}else{_=4452;break L6206}break};case 3:{if(T|R^1){_=4455;break L6206}if(!(V<<24>>24!=3|U)){_=4455;break L6206}aj=c[x>>2]|0;ai=aj+P|0;ad=yu(Q,ai)|0;if((ad|0)==0){aw=Q;_=4459;break L6206}if((eM(ad+P|0,1,aj|0,A|0)|0)!=(aj|0)){aw=ad;_=4459;break L6206}if((e6(A|0,4,1)|0)<0){aw=ad;_=4459;break L6206}else{ak=U;al=0;am=1;an=R;ao=ad;ap=ai;aq=V;ar=W;as=X;at=Y;au=Z;break L6212}break};case 5:{if(!(R&S)){_=4461;break L6206}if((e6(A|0,4,1)|0)<0){_=4463;break L6206}else{ak=U;al=1;am=1;an=1;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z;break L6212}break};default:{_=4411;break L6212}}}}while(0);if((_|0)==4411){_=0;if((e6(A|0,(c[x>>2]|0)+4|0,1)|0)<0){_=4412;break}else{ak=U;al=T;am=S;an=R;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z}}ai=cy(A|0)|0;if((ai|0)<(b|0)&(ai|0)>-1){P=ap;Q=ao;R=an;S=am;T=al;U=ak;V=aq;W=ar;X=as;Y=at;Z=au}else{_=4465;break}}if((_|0)==4407){Z=c[t>>2]|0;eS(Z|0,49880,(v=i,i=i+8|0,c[v>>2]=613,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4412){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=620,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4413){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=624,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4415){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=628,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4417){c[G>>2]=0}else if((_|0)==4421){yt(ac)}else if((_|0)==4423){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=154,v)|0)|0;i=v;_=4440}else if((_|0)==4425){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=165,v)|0)|0;i=v;_=4440}else if((_|0)==4430){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=170,v)|0)|0;i=v;_=4440}else if((_|0)==4433){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=186,v)|0)|0;i=v;_=4440}else if((_|0)==4436){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=202,v)|0)|0;i=v;_=4440}else if((_|0)==4437){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=205,v)|0)|0;i=v;_=4440}else if((_|0)==4439){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=217,v)|0)|0;i=v;_=4440}else if((_|0)==4444){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=638,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4446){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=641,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4452){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=644,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4455){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=651,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4459){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=654,v)|0)|0;i=v;ax=0;ay=aw;break L6202}else if((_|0)==4461){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=661,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4463){eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=664,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4465){if(!(an&am&al)){az=ao;break}c[m+36>>2]=0;c[m+40>>2]=0;c[m+24>>2]=0;c[m+8>>2]=0;Z=m+20|0;c[Z>>2]=0;c[m+44>>2]=0;Y=ys(43784)|0;if((Y|0)==0){X=c[t>>2]|0;eS(X|0,49880,(v=i,i=i+8|0,c[v>>2]=675,v)|0)|0;i=v;ax=0;ay=ao;break L6202}X=m+28|0;c[X>>2]=Y;c[Y>>2]=0;c[Y+10992>>2]=0;c[Y+10996>>2]=0;c[Y+43780>>2]=1;c[Y+11e3>>2]=1;c[Y+11004>>2]=0;c[Y+11008>>2]=15;switch(aq&255|0){case 0:{aA=((ag(at,au&255)|0)+7|0)>>>3;break};case 2:{aA=((ag((au&255)*3|0,at)|0)+7|0)>>>3;break};case 3:{aA=((ag(at,au&255)|0)+7|0)>>>3;break};case 4:{aA=((ag((au&255)<<1,at)|0)+7|0)>>>3;break};case 6:{aA=((ag((au&255)<<2,at)|0)+7|0)>>>3;break};default:{aA=0}}Y=as<<24>>24==1;W=(ag(ar,aA+1|0)|0)<<(Y&1);V=ys(W)|0;if((V|0)==0){U=c[t>>2]|0;eS(U|0,49880,(v=i,i=i+8|0,c[v>>2]=683,v)|0)|0;i=v;ax=0;ay=ao;break L6202}c[m>>2]=ao;c[m+4>>2]=ap;c[m+16>>2]=W;c[m+12>>2]=V;W=(kv(m)|0)==1;U=c[X>>2]|0;if((U|0)!=0){yt(U);c[X>>2]=0}if(!W){W=c[t>>2]|0;eS(W|0,49880,(v=i,i=i+8|0,c[v>>2]=693,v)|0)|0;i=v;ax=V;ay=ao;break L6202}c[B>>2]=at;c[F>>2]=ar;W=ys(ag(ar<<2,at)|0)|0;X=W;c[s>>2]=X;if((W|0)==0){W=c[t>>2]|0;eS(W|0,49880,(v=i,i=i+8|0,c[v>>2]=701,v)|0)|0;i=v;ax=V;ay=ao;break L6202}W=c[Z>>2]|0;Z=o|0;L6300:do{if(Y){U=j;T=j|0;S=j+4|0;R=j+9|0;P=j+8|0;x=0;O=W;N=V;M=at;L6302:while(1){L=c[5904+(x<<4)>>2]|0;do{if(M>>>0>L>>>0){K=c[I>>2]|0;J=c[5908+(x<<4)>>2]|0;if(K>>>0<=J>>>0){aB=N;aC=O;break}u=c[5912+(x<<4)>>2]|0;y=((M-1-L+u|0)>>>0)/(u>>>0)|0;C=c[5916+(x<<4)>>2]|0;r=((K-1-J+C|0)>>>0)/(C>>>0)|0;K=y<<2;aD=ys(ag(r,K)|0)|0;D=aD;if((aD|0)==0){break L6302}c[U>>2]=c[e>>2];c[U+4>>2]=c[e+4>>2];c[U+8>>2]=c[e+8>>2];c[U+12>>2]=c[e+12>>2];c[T>>2]=y;c[S>>2]=r;switch(d[R]|0){case 0:{aE=((ag(d[P]|0,y)|0)+7|0)>>>3;break};case 2:{aE=((ag(y*3|0,d[P]|0)|0)+7|0)>>>3;break};case 3:{aE=((ag(d[P]|0,y)|0)+7|0)>>>3;break};case 4:{aE=((ag(y<<1,d[P]|0)|0)+7|0)>>>3;break};case 6:{aE=((ag(d[P]|0,K)|0)+7|0)>>>3;break};default:{aE=0}}K=ag(aE+1|0,r)|0;if(K>>>0>O>>>0){_=4495;break L6302}if(!(ku(D,j,N,K,Z)|0)){_=4497;break L6302}ai=N+K|0;ad=O-K|0;if(!((r|0)==0|(y|0)==0)){K=D;D=X+((ag(c[H>>2]|0,J)|0)+L<<2)|0;J=0;while(1){aj=D;aa=0;while(1){c[aj>>2]=c[K+(aa<<2)>>2];ah=aa+1|0;if(ah>>>0<y>>>0){aj=aj+(u<<2)|0;aa=ah}else{break}}aa=J+1|0;aj=D+((ag(c[H>>2]|0,C)|0)<<2)|0;if(aa>>>0<r>>>0){K=K+(y<<2)|0;D=aj;J=aa}else{break}}}yt(aD);aB=ai;aC=ad}else{aB=N;aC=O}}while(0);L=x+1|0;if(L>>>0>=7){break L6300}x=L;O=aC;N=aB;M=c[H>>2]|0}if((_|0)==4495){yt(aD)}else if((_|0)==4497){yt(aD)}eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=706,v)|0)|0;i=v;ax=V;ay=ao;break L6202}else{if(ku(X,n,V,W,Z)|0){break}eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=709,v)|0)|0;i=v;ax=V;ay=ao;break L6202}}while(0);a_(A|0)|0;yt(ao);yt(V);if((f|0)==16&(g|0)==0){w=1;i=h;return w|0}Z=ag(c[F>>2]|0,c[B>>2]|0)|0;W=c[s>>2]|0;if((Z|0)==0){w=1;i=h;return w|0}else{aF=0}while(1){X=W+(aF<<2)|0;H=c[X>>2]|0;c[X>>2]=(H&255)<<g|H&-16777216|(H>>>16&255)<<f|H&65280;H=aF+1|0;if(H>>>0<Z>>>0){aF=H}else{w=1;break}}i=h;return w|0}if((_|0)==4440){yt(ac);c[G>>2]=0}eS(c[t>>2]|0,49880,(v=i,i=i+8|0,c[v>>2]=631,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else{az=0}}while(0);z=c[t>>2]|0;eS(z|0,49880,(v=i,i=i+8|0,c[v>>2]=672,v)|0)|0;i=v;ax=0;ay=az}else{z=c[t>>2]|0;eS(z|0,49880,(v=i,i=i+8|0,c[v>>2]=606,v)|0)|0;i=v;ax=0;ay=0}}while(0);a_(A|0)|0;aG=ax;aH=ay}else{ay=c[t>>2]|0;eS(ay|0,49880,(v=i,i=i+8|0,c[v>>2]=603,v)|0)|0;i=v;a_(A|0)|0;aG=0;aH=0}yt(c[s>>2]|0);yt(aH);yt(aG);w=0;i=h;return w|0}function i6(a,b,c){a=a|0;b=b|0;c=c|0;return-1|0}function i7(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function i8(a){a=a|0;return 1}function i9(a){a=a|0;return 1}function ja(a,b){a=a|0;b=b|0;return}function jb(a){a=a|0;return}function jc(a){a=a|0;return 1}function jd(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0.0,N=0,O=0.0,P=0.0,Q=0,R=0.0,S=0.0;d=~~(16777216.0/+h[b+16>>3]);e=c[b+8>>2]|0;if((e|0)==0){f=0;i=b+12|0;c[i>>2]=f;return}j=a+20|0;k=a+4|0;l=a+16|0;m=a+8|0;n=a+12|0;o=a;a=c[b>>2]|0;p=c[b+4>>2]|0;q=e;e=0;r=c[j>>2]|0;while(1){L6363:do{if((q|0)==0){s=a;t=r;u=4541}else{v=a;w=q;x=r;while(1){if(x>>>0<=16777215){y=x;z=w;A=v;break L6363}B=c[l>>2]|0;if((B|0)==0){C=c[n>>2]|0;c[l>>2]=C;D=C}else{D=B}B=D-1|0;c[l>>2]=B;E=+g[v>>2];g[(c[k>>2]|0)+(B<<2)>>2]=E;g[(c[k>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;B=v+8|0;E=+g[v+4>>2];g[(c[m>>2]|0)+(c[l>>2]<<2)>>2]=E;g[(c[m>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;C=(c[j>>2]|0)-16777216|0;c[j>>2]=C;F=w-1|0;if((F|0)==0){s=B;t=C;u=4541;break}else{v=B;w=F;x=C}}}}while(0);if((u|0)==4541){u=0;if(t>>>0<16777216){y=t;z=0;A=s}else{f=e;u=4549;break}}x=p;w=e;v=y;do{C=c[k>>2]|0;F=c[l>>2]|0;B=c[m>>2]|0;G=c[n>>2]|0;H=c[o>>2]|0;I=ag(G<<1,v>>>16)|0;J=I+G|0;E=+((v&65535)>>>0>>>0)*152587890625.0e-16;if((G|0)==0){K=0.0;L=0.0}else{M=0.0;N=0;O=0.0;while(1){P=+g[H+(N+I<<2)>>2]+E*+g[H+(J+N<<2)>>2];Q=N+F|0;R=O+ +g[C+(Q<<2)>>2]*P;S=M+ +g[B+(Q<<2)>>2]*P;Q=N+1|0;if(Q>>>0<G>>>0){M=S;N=Q;O=R}else{K=S;L=R;break}}}g[x>>2]=L;g[x+4>>2]=K;x=x+8|0;w=w+1|0;v=(c[j>>2]|0)+d|0;c[j>>2]=v;}while(v>>>0<16777216);if((z|0)==0){f=w;u=4548;break}else{a=A;p=x;q=z;e=w;r=v}}if((u|0)==4548){i=b+12|0;c[i>>2]=f;return}else if((u|0)==4549){i=b+12|0;c[i>>2]=f;return}}function je(b){b=+b;var d=0,e=0,f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,u=0.0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0,F=0.0,G=0.0,H=0;d=i;e=ys(28)|0;if((e|0)==0){f=0;i=d;return f|0}if((c[e-4>>2]&3|0)!=0){yB(e|0,0,28)}yB(e|0,0,28);h=e+12|0;if(b<1.0){j=b*.825;k=~~+af(+(16.0/b))+3&-4}else{j=.825;k=16}c[h>>2]=k;l=k<<9;m=ys((l+(k<<2)<<2)+132|0)|0;k=m+132&-128;c[k-4>>2]=m;m=k;c[e+24>>2]=m;if((k|0)==0){yt(c[m-4>>2]|0);yt(e);f=0;i=d;return f|0}c[e>>2]=m;c[e+4>>2]=m+(l<<2);k=c[h>>2]|0;n=k<<1;c[e+8>>2]=m+(n+l<<2);b=1.0;o=0.0;p=1.0;q=1.0;r=0.0;l=0;while(1){s=r+q*p/(b*b);u=o+1.0;v=l+1|0;if(v>>>0<18){b=b*u;o=u;p=p*30.25;q=q*.25;r=s;l=v}else{break}}r=+(k|0)*.5;q=+(k<<8|0);if((k|0)>0){l=0;while(1){v=ag(l,n)|0;w=0;do{p=+((w<<8)+l|0)/q*2.0+-1.0;o=j*r*p*3.141592653589793;if(+V(+o)<1.0e-5){x=1.0}else{x=+Z(+o)/o}o=+W(+(1.0-p*p))*5.5;p=o*o;o=1.0;b=0.0;u=1.0;y=1.0;z=0.0;A=0;while(1){B=z+y*u/(o*o);C=b+1.0;D=A+1|0;if(D>>>0<18){o=o*C;b=C;u=p*u;y=y*.25;z=B;A=D}else{break}}g[m+(w+v<<2)>>2]=j*x*B/s;w=w+1|0;}while((w|0)<(k|0));w=l+1|0;if((w|0)<256){l=w}else{E=0;break}}while(1){l=E+1|0;w=ag(l,n)|0;v=E<<1;A=ag(v,k)|0;D=ag(v|1,k)|0;v=0;do{g[m+(v+D<<2)>>2]=+g[m+(v+w<<2)>>2]- +g[m+(v+A<<2)>>2];v=v+1|0;}while((v|0)<(k|0));if((l|0)<255){E=l}else{break}}E=k*510|0;n=k*511|0;v=0;do{B=+((v<<8)+256|0)/q*2.0+-1.0;x=j*r*B*3.141592653589793;if(+V(+x)<1.0e-5){F=1.0}else{F=+Z(+x)/x}x=+W(+(1.0-B*B))*5.5;B=x*x;x=1.0;z=0.0;y=1.0;u=1.0;p=0.0;A=0;while(1){G=p+u*y/(x*x);b=z+1.0;w=A+1|0;if(w>>>0<18){x=x*b;z=b;y=B*y;u=u*.25;p=G;A=w}else{break}}g[m+(v+n<<2)>>2]=j*F*G/s- +g[m+(v+E<<2)>>2];v=v+1|0;}while((v|0)<(k|0))}k=a[405432]|0;if((k&1)==0){H=k}else{k=c[140620]|0;v=(k|0)!=0?k:c[t>>2]|0;be(50744,30,1,v|0)|0;v=c[140620]|0;k=(v|0)!=0?v:c[t>>2]|0;a7(k|0)|0;H=a[405432]|0}if((H&1)==0){f=e;i=d;return f|0}H=c[140620]|0;k=c[h>>2]|0;eS(((H|0)!=0?H:c[t>>2]|0)|0,37544,(H=i,i=i+16|0,c[H>>2]=8,c[H+8>>2]=k,H)|0)|0;i=H;H=c[140620]|0;a7(((H|0)!=0?H:c[t>>2]|0)|0)|0;f=e;i=d;return f|0}function jf(a){a=a|0;if((a|0)==0){yt(a);return}yt(c[(c[a+24>>2]|0)-4>>2]|0);yt(a);return}function jg(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=yA(e|0)|0;if(g>>>0<=c>>>0){h=c+1|0;do{if((h|0)==0){i=e}else{j=h;k=b;l=e;while(1){m=j-1|0;if((m|0)==0){n=4594;break}o=a[l]|0;a[k]=o;if(o<<24>>24==0){n=4646;break}else{j=m;k=k+1|0;l=l+1|0}}if((n|0)==4646){return}else if((n|0)==4594){a[k]=0;i=l;break}}}while(0);if((a[i]|0)==0){return}else{p=i}do{p=p+1|0;}while((a[p]|0)!=0);return}if(!f){f=c+1|0;p=c-2|0;L6458:do{if((p|0)==0){q=e;n=4602}else{i=p;h=b;j=e;while(1){m=i-1|0;if((m|0)==0){break}o=a[j]|0;a[h]=o;if(o<<24>>24==0){break L6458}else{i=m;h=h+1|0;j=j+1|0}}a[h]=0;q=j;n=4602}}while(0);do{if((n|0)==4602){if((a[q]|0)==0){break}else{r=q}do{r=r+1|0;}while((a[r]|0)!=0)}}while(0);r=yA(b|0)|0;q=r>>>0>f>>>0?0:f-r|0;if((q|0)==0){s=36440}else{f=b+r|0;do{if((q|0)==1){t=36440;u=f}else{j=b+(r+1)|0;a[f]=46;if((q|0)==2){t=36441;u=j;break}h=b+(r+2)|0;a[j]=46;if((q|0)==3){t=36442;u=h;break}j=b+(r+3)|0;a[h]=46;if((q|0)==4){t=36443;u=j;break}a[j]=0;return}}while(0);a[u]=0;s=t}if((a[s]|0)==0){return}else{v=s}do{v=v+1|0;}while((a[v]|0)!=0);return}v=g-c|0;g=(d>>>0)%(((v<<1)+4|0)>>>0)|0;d=v+4|0;s=g-2|0;t=d+v-g|0;if(g>>>0<2){u=c+1|0;do{if((u|0)==0){w=e}else{q=u;r=b;f=e;while(1){j=q-1|0;if((j|0)==0){n=4614;break}h=a[f]|0;a[r]=h;if(h<<24>>24==0){n=4649;break}else{q=j;r=r+1|0;f=f+1|0}}if((n|0)==4614){a[r]=0;w=f;break}else if((n|0)==4649){return}}}while(0);if((a[w]|0)==0){return}else{x=w}do{x=x+1|0;}while((a[x]|0)!=0);return}if(g>>>0<(v+2|0)>>>0){x=e+s|0;s=c+1|0;do{if((s|0)==0){y=x}else{w=s;u=b;q=x;while(1){j=w-1|0;if((j|0)==0){n=4621;break}h=a[q]|0;a[u]=h;if(h<<24>>24==0){n=4650;break}else{w=j;u=u+1|0;q=q+1|0}}if((n|0)==4650){return}else if((n|0)==4621){a[u]=0;y=q;break}}}while(0);if((a[y]|0)==0){return}else{z=y}do{z=z+1|0;}while((a[z]|0)!=0);return}if(g>>>0<d>>>0){d=e+v|0;v=c+1|0;do{if((v|0)==0){A=d}else{g=v;z=b;y=d;while(1){x=g-1|0;if((x|0)==0){n=4628;break}s=a[y]|0;a[z]=s;if(s<<24>>24==0){n=4653;break}else{g=x;z=z+1|0;y=y+1|0}}if((n|0)==4653){return}else if((n|0)==4628){a[z]=0;A=y;break}}}while(0);if((a[A]|0)==0){return}else{B=A}do{B=B+1|0;}while((a[B]|0)!=0);return}else{B=e+t|0;t=c+1|0;do{if((t|0)==0){C=B}else{c=t;e=b;A=B;while(1){d=c-1|0;if((d|0)==0){n=4634;break}v=a[A]|0;a[e]=v;if(v<<24>>24==0){n=4652;break}else{c=d;e=e+1|0;A=A+1|0}}if((n|0)==4652){return}else if((n|0)==4634){a[e]=0;C=A;break}}}while(0);if((a[C]|0)==0){return}else{D=C}do{D=D+1|0;}while((a[D]|0)!=0);return}}function jh(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b+44|0;e=c[d>>2]|0;f=e+8|0;if((c[f>>2]|0)!=0){g=e|0;e=0;do{yt(c[(c[g>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while(e>>>0<(c[f>>2]|0)>>>0)}c[f>>2]=0;do{if((c[b+113712>>2]|0)==0){h=4668}else{f=c[d>>2]|0;if((f|0)==0){break}e=f+8|0;g=f+4|0;i=c[g>>2]|0;if((c[e>>2]|0)>>>0<i>>>0){j=f|0}else{k=(i<<1)+2|0;c[g>>2]=k;g=f|0;c[g>>2]=yu(c[g>>2]|0,k*12|0)|0;j=g}g=dW(46960)|0;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)>>2]=g;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=56;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1;h=4668}}while(0);do{if((h|0)==4668){j=c[d>>2]|0;if((j|0)==0){break}b=j+8|0;e=j+4|0;g=c[e>>2]|0;if((c[b>>2]|0)>>>0<g>>>0){l=j|0}else{k=(g<<1)+2|0;c[e>>2]=k;e=j|0;c[e>>2]=yu(c[e>>2]|0,k*12|0)|0;l=e}e=dW(46904)|0;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)>>2]=e;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)+4>>2]=55;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)+8>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[d>>2]|0;if((b|0)==0){break}e=b+8|0;k=b+4|0;j=c[k>>2]|0;if((c[e>>2]|0)>>>0<j>>>0){m=b|0}else{g=(j<<1)+2|0;c[k>>2]=g;k=b|0;c[k>>2]=yu(c[k>>2]|0,g*12|0)|0;m=k}k=dW(46832)|0;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)>>2]=k;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=58;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1;e=c[d>>2]|0;if((e|0)==0){break}k=e+8|0;g=e+4|0;b=c[g>>2]|0;if((c[k>>2]|0)>>>0<b>>>0){n=e|0}else{j=(b<<1)+2|0;c[g>>2]=j;g=e|0;c[g>>2]=yu(c[g>>2]|0,j*12|0)|0;n=g}g=dW(46672)|0;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)>>2]=g;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)+4>>2]=5;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)+8>>2]=0;c[k>>2]=(c[k>>2]|0)+1;k=c[d>>2]|0;if((k|0)==0){break}g=k+8|0;j=k+4|0;e=c[j>>2]|0;if((c[g>>2]|0)>>>0<e>>>0){o=k|0}else{b=(e<<1)+2|0;c[j>>2]=b;j=k|0;c[j>>2]=yu(c[j>>2]|0,b*12|0)|0;o=j}j=dW(46376)|0;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)>>2]=j;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)+4>>2]=59;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)+8>>2]=0;c[g>>2]=(c[g>>2]|0)+1;g=c[d>>2]|0;if((g|0)==0){break}j=g+8|0;b=g+4|0;k=c[b>>2]|0;if((c[j>>2]|0)>>>0<k>>>0){p=g|0}else{e=(k<<1)+2|0;c[b>>2]=e;b=g|0;c[b>>2]=yu(c[b>>2]|0,e*12|0)|0;p=b}b=dW(46264)|0;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)>>2]=b;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)+4>>2]=60;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)+8>>2]=0;c[j>>2]=(c[j>>2]|0)+1;j=c[d>>2]|0;if((j|0)==0){break}b=j+8|0;e=j+4|0;g=c[e>>2]|0;if((c[b>>2]|0)>>>0<g>>>0){q=j|0}else{k=(g<<1)+2|0;c[e>>2]=k;e=j|0;c[e>>2]=yu(c[e>>2]|0,k*12|0)|0;q=e}e=dW(46112)|0;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)>>2]=e;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)+4>>2]=61;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)+8>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[d>>2]|0;if((b|0)==0){break}e=b+8|0;k=b+4|0;j=c[k>>2]|0;if((c[e>>2]|0)>>>0<j>>>0){r=b|0}else{g=(j<<1)+2|0;c[k>>2]=g;k=b|0;c[k>>2]=yu(c[k>>2]|0,g*12|0)|0;r=k}k=dW(45984)|0;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)>>2]=k;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=62;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1}}while(0);do{if((a[562484]&1)!=0){if((a[563557]&1)!=0){break}if((c[126108]|0)!=0){r=c[d>>2]|0;if((r|0)==0){return}q=r+8|0;p=r+4|0;o=c[p>>2]|0;if((c[q>>2]|0)>>>0<o>>>0){s=r|0}else{n=(o<<1)+2|0;c[p>>2]=n;p=r|0;c[p>>2]=yu(c[p>>2]|0,n*12|0)|0;s=p}p=dW(45856)|0;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)>>2]=p;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)+4>>2]=69;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)+8>>2]=0;c[q>>2]=(c[q>>2]|0)+1}q=c[d>>2]|0;if((q|0)==0){return}p=q+8|0;n=q+4|0;r=c[n>>2]|0;if((c[p>>2]|0)>>>0<r>>>0){t=q|0}else{o=(r<<1)+2|0;c[n>>2]=o;n=q|0;c[n>>2]=yu(c[n>>2]|0,o*12|0)|0;t=n}n=dW(45728)|0;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)>>2]=n;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)+4>>2]=67;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)+8>>2]=0;c[p>>2]=(c[p>>2]|0)+1;p=c[d>>2]|0;if((p|0)==0){return}n=p+8|0;o=p+4|0;q=c[o>>2]|0;if((c[n>>2]|0)>>>0<q>>>0){u=p|0}else{r=(q<<1)+2|0;c[o>>2]=r;o=p|0;c[o>>2]=yu(c[o>>2]|0,r*12|0)|0;u=o}o=dW(45608)|0;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)>>2]=o;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)+4>>2]=68;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)+8>>2]=0;c[n>>2]=(c[n>>2]|0)+1;n=c[d>>2]|0;if((n|0)==0){return}o=n+8|0;r=n+4|0;p=c[r>>2]|0;if((c[o>>2]|0)>>>0<p>>>0){v=n|0}else{q=(p<<1)+2|0;c[r>>2]=q;r=n|0;c[r>>2]=yu(c[r>>2]|0,q*12|0)|0;v=r}r=dW(45440)|0;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)>>2]=r;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=72;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1;o=c[d>>2]|0;if((o|0)==0){return}r=o+8|0;q=o+4|0;n=c[q>>2]|0;if((c[r>>2]|0)>>>0<n>>>0){w=o|0}else{p=(n<<1)+2|0;c[q>>2]=p;q=o|0;c[q>>2]=yu(c[q>>2]|0,p*12|0)|0;w=q}q=dW(45368)|0;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)>>2]=q;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)+4>>2]=86;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)+8>>2]=0;c[r>>2]=(c[r>>2]|0)+1;r=c[d>>2]|0;if((r|0)==0){return}q=r+8|0;p=r+4|0;o=c[p>>2]|0;if((c[q>>2]|0)>>>0<o>>>0){x=r|0}else{n=(o<<1)+2|0;c[p>>2]=n;p=r|0;c[p>>2]=yu(c[p>>2]|0,n*12|0)|0;x=p}p=dW(45256)|0;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)>>2]=p;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)+4>>2]=80;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)+8>>2]=0;c[q>>2]=(c[q>>2]|0)+1}}while(0);x=c[d>>2]|0;if((x|0)==0){return}w=x+8|0;v=x+4|0;u=c[v>>2]|0;if((c[w>>2]|0)>>>0<u>>>0){y=x|0}else{t=(u<<1)+2|0;c[v>>2]=t;v=x|0;c[v>>2]=yu(c[v>>2]|0,t*12|0)|0;y=v}v=dW(44968)|0;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)>>2]=v;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)+4>>2]=85;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)+8>>2]=0;c[w>>2]=(c[w>>2]|0)+1;w=c[d>>2]|0;if((w|0)==0){return}d=w+8|0;y=w+4|0;v=c[y>>2]|0;if((c[d>>2]|0)>>>0<v>>>0){z=w|0}else{t=(v<<1)+2|0;c[y>>2]=t;y=w|0;c[y>>2]=yu(c[y>>2]|0,t*12|0)|0;z=y}y=dW(44848)|0;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)>>2]=y;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)+4>>2]=87;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)+8>>2]=0;c[d>>2]=(c[d>>2]|0)+1;return}function ji(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0;e=i;i=i+22120|0;f=e|0;h=e+16|0;j=e+528|0;k=e+1552|0;l=e+5648|0;m=e+9744|0;n=e+9768|0;o=e+9832|0;p=e+13928|0;q=e+18024|0;r=d+8|0;s=c[r>>2]|0;u=c[r+4>>2]|0;do{if((s&1|0)==0&(u&0|0)==0){if(!((s&2|0)==0&(u&0|0)==0)){v=1;break}if(!((s&4|0)==0&(u&0|0)==0)){v=2;break}if(!((s&8|0)==0&(u&0|0)==0)){v=3;break}if(!((s&32|0)==0&(u&0|0)==0)){v=5;break}if(!((s&16|0)==0&(u&0|0)==0)){v=4;break}if(!((s&128|0)==0&(u&0|0)==0)){v=8;break}v=(s&64|0)==0&(u&0|0)==0?10:7}else{v=0}}while(0);u=d+40|0;s=c[u>>2]|0;r=c[s+8>>2]|0;if((r|0)==0){w=0;x=0}else{y=r-1|0;r=c[s>>2]|0;w=c[r+(y*12|0)+4>>2]|0;x=c[r+(y*12|0)>>2]|0}y=c[140964]|0;do{if((y|0)!=0){if((c[y+24>>2]|0)==0){break}gb[c[y+20>>2]&15](c[140916]|0,86184,0,320,240,1.0)}}while(0);switch(w|0){case 69:case 62:case 61:case 59:case 58:case 26:case 5:case 4:case 60:{z=jj(d,v)|0;i=e;return z|0};default:{}}if((w-12|0)>>>0<2){y=n|0;n=c[u>>2]|0;r=n+8|0;s=c[r>>2]|0;A=(s|0)==0;if(A){B=0}else{B=c[(c[n>>2]|0)+((s-1|0)*12|0)+4>>2]|0}C=(a[303133]&1)==0;D=C?1:c[124934]|0;E=C?1:c[124935]|0;L6686:do{switch(v|0){case 1:{do{if((B|0)==12){c[140606]=(c[140606]|0)+E;F=c[140608]|0;if(F>>>0<E>>>0){break}c[140608]=F-E}else{c[140608]=(c[140608]|0)+E}}while(0);F=c[(c[140964]|0)+16>>2]|0;if((F|0)==0){break L6686}f2[F&1023](c[140916]|0);break};case 0:{do{if((B|0)==12){c[140606]=(c[140606]|0)-E;c[140608]=(c[140608]|0)+E}else{F=c[140608]|0;if(F>>>0<E>>>0){break}c[140608]=F-E}}while(0);F=c[(c[140964]|0)+16>>2]|0;if((F|0)==0){break L6686}f2[F&1023](c[140916]|0);break};case 7:{F=d+48|0;if(!A){G=s-1|0;c[r>>2]=G;yt(c[(c[n>>2]|0)+(G*12|0)>>2]|0)}if((F|0)==0){break L6686}c[F>>2]=c[(c[n>>2]|0)+((c[r>>2]|0)*12|0)+8>>2];break};case 4:{F=d+48|0;if(!A){G=s-1|0;c[r>>2]=G;yt(c[(c[n>>2]|0)+(G*12|0)>>2]|0)}if((F|0)!=0){c[F>>2]=c[(c[n>>2]|0)+((c[r>>2]|0)*12|0)+8>>2]}if((B|0)!=12){break L6686}if((a[303133]&1)!=0){break L6686}G=c[u>>2]|0;H=c[F>>2]|0;if((G|0)==0){break L6686}F=G+8|0;I=G+4|0;J=c[I>>2]|0;if((c[F>>2]|0)>>>0<J>>>0){L=G|0}else{M=(J<<1)+2|0;c[I>>2]=M;I=G|0;c[I>>2]=yu(c[I>>2]|0,M*12|0)|0;L=I}I=dW(564064)|0;c[(c[L>>2]|0)+((c[F>>2]|0)*12|0)>>2]=I;c[(c[L>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=13;c[(c[L>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=H;c[F>>2]=(c[F>>2]|0)+1;break};case 2:{do{if((B|0)==12){c[140605]=(c[140605]|0)-D;c[140607]=(c[140607]|0)+D}else{F=c[140607]|0;if(F>>>0<D>>>0){break}c[140607]=F-D}}while(0);F=c[(c[140964]|0)+16>>2]|0;if((F|0)==0){break L6686}f2[F&1023](c[140916]|0);break};case 3:{do{if((B|0)==12){c[140605]=(c[140605]|0)+D;F=c[140607]|0;if(F>>>0<D>>>0){break}c[140607]=F-D}else{c[140607]=(c[140607]|0)+D}}while(0);F=c[(c[140964]|0)+16>>2]|0;if((F|0)==0){break L6686}f2[F&1023](c[140916]|0);break};case 9:{a[d+53|0]=1;break};case 5:{F=d+48|0;if(!A){H=s-1|0;c[r>>2]=H;yt(c[(c[n>>2]|0)+(H*12|0)>>2]|0)}if((F|0)!=0){c[F>>2]=c[(c[n>>2]|0)+((c[r>>2]|0)*12|0)+8>>2]}if((B|0)!=13){break L6686}H=c[u>>2]|0;I=c[F>>2]|0;if((H|0)==0){break L6686}F=H+8|0;M=H+4|0;G=c[M>>2]|0;if((c[F>>2]|0)>>>0<G>>>0){N=H|0}else{J=(G<<1)+2|0;c[M>>2]=J;M=H|0;c[M>>2]=yu(c[M>>2]|0,J*12|0)|0;N=M}M=dW(564064)|0;c[(c[N>>2]|0)+((c[F>>2]|0)*12|0)>>2]=M;c[(c[N>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=12;c[(c[N>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=I;c[F>>2]=(c[F>>2]|0)+1;break};case 8:{if(!C){break L6686}f3[c[(c[140913]|0)+44>>2]&1023](c[140916]|0,m);if((B|0)==12){c[140607]=(c[140607]|0)+(c[140605]|0);c[140608]=(c[140608]|0)+(c[140606]|0);c[140605]=0;c[140606]=0}else{c[140607]=(c[m+16>>2]|0)-(c[140605]|0);c[140608]=(c[m+20>>2]|0)-(c[140606]|0)}F=c[(c[140964]|0)+16>>2]|0;if((F|0)==0){break L6686}f2[F&1023](c[140916]|0);break};default:{}}}while(0);m=c[u>>2]|0;C=c[m+8>>2]|0;if((C|0)==0){O=B}else{O=c[(c[m>>2]|0)+((C-1|0)*12|0)+4>>2]|0}jl(d);if((a[303133]&1)==0){if((O|0)==12){P=16784}else{P=(O|0)==13?16536:0}O=c[140605]|0;C=c[140606]|0;m=c[140607]|0;B=c[140608]|0;b5(y|0,64,16224,(Q=i,i=i+40|0,c[Q>>2]=P,c[Q+8>>2]=O,c[Q+16>>2]=C,c[Q+24>>2]=m,c[Q+32>>2]=B,Q)|0)|0;i=Q}else{c[140605]=0;c[140606]=0;B=c[124934]|0;m=(c[140607]|0)-1+B|0;C=m-((m>>>0)%(B>>>0)|0)|0;c[140607]=C;O=c[124935]|0;P=(c[140608]|0)-1+O|0;N=P-((P>>>0)%(O>>>0)|0)|0;c[140608]=N;r=(m>>>0)/(B>>>0)|0;B=(P>>>0)/(O>>>0)|0;b5(y|0,64,17288,(Q=i,i=i+40|0,c[Q>>2]=17488,c[Q+8>>2]=C,c[Q+16>>2]=N,c[Q+24>>2]=r,c[Q+32>>2]=B,Q)|0)|0;i=Q}if((a[y]|0)!=0){B=dW(y|0)|0;if((yA(B|0)|0)>>>0>48){a[B+46|0]=46;a[B+47|0]=46;a[B+48|0]=46;a[B+49|0]=0}y=(yA(B|0)|0)*6|0;r=y+15|0;N=(305-y|0)>>>1;C=d+28|0;O=c[C>>2]|0;P=d+32|0;m=N+5|0;n=c[P>>2]|0;s=y+5+m|0;A=n>>>1;if(s>>>0>m>>>0){L=112;do{F=ag(L,A)|0;I=L>>>1;M=m;do{J=((M>>>1)+I&1)+1|0;b[O+(M+F<<1)>>1]=(J<<13|J<<9|J<<5|12)&65535;M=M+1|0;}while(M>>>0<s>>>0);L=L+1|0;}while(L>>>0<128);R=c[C>>2]|0;S=c[P>>2]|0}else{R=O;S=n}n=y+10|0;y=N+n|0;O=S>>>1;if(y>>>0>N>>>0){L=107;do{s=ag(L,O)|0;A=L>>>1;M=N;do{F=((M>>>1)+A&1)+1|0;b[R+(M+s<<1)>>1]=(F<<13|F<<10|F<<5|12)&65535;M=M+1|0;}while(M>>>0<y>>>0);L=L+1|0;}while(L>>>0<112);T=c[C>>2]|0;U=c[P>>2]|0}else{T=R;U=S}S=N+r|0;r=cO(S|0,-5|0)|0;R=r;r=U>>>1;if(K){L=107;do{y=ag(L,r)|0;O=L>>>1;M=R;do{s=((M>>>1)+O&1)+1|0;b[T+(M+y<<1)>>1]=(s<<13|s<<10|s<<5|12)&65535;M=M+1|0;}while(M>>>0<S>>>0);L=L+1|0;}while(L>>>0<128);V=c[C>>2]|0;W=c[P>>2]|0}else{V=T;W=U}U=m+n|0;n=W>>>1;if(U>>>0>m>>>0){T=n<<7;L=m;do{S=(L>>>1&1)+1|0;b[V+(L+T<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;L=L+1|0;}while(L>>>0<U>>>0);L=n*129|0;T=m;do{S=(T>>>1&1)+1|0;b[V+(T+L<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;T=T+1|0;}while(T>>>0<U>>>0);T=n*130|0;L=m;do{S=2-(L>>>1&1)|0;b[V+(L+T<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;L=L+1|0;}while(L>>>0<U>>>0);L=n*131|0;T=m;do{S=2-(T>>>1&1)|0;b[V+(T+L<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;T=T+1|0;}while(T>>>0<U>>>0);T=n*132|0;n=m;do{L=(n>>>1&1)+1|0;b[V+(n+T<<1)>>1]=(L<<13|L<<10|L<<5|12)&65535;n=n+1|0;}while(n>>>0<U>>>0);X=c[C>>2]|0;Y=c[P>>2]|0}else{X=V;Y=W}W=Y>>>1;Y=112;do{V=ag(Y,W)|0;P=Y>>>1;C=N;do{U=((C>>>1)+P&1)+1|0;b[X+(C+V<<1)>>1]=(U<<13|U<<10|U<<5|12)&65535;C=C+1|0;}while(C>>>0<m>>>0);Y=Y+1|0;}while(Y>>>0<133);jm(d,N+8|0,115,B,0);yt(B)}B=c[140607]|0;if((B|0)==0){c[140607]=D;Z=D}else{Z=B}B=c[140608]|0;if((B|0)==0){c[140608]=E;_=E}else{_=B}g[2711]=+(Z>>>0>>>0)/+(_>>>0>>>0);_=c[(c[140964]|0)+16>>2]|0;if((_|0)==0){z=0;i=e;return z|0}f2[_&1023](c[140916]|0);z=0;i=e;return z|0}_=d+52|0;L6831:do{switch(((a[_]&1)==0?v:10)|0){case 7:{a[_]=1;Z=c[u>>2]|0;B=c[Z+8>>2]|0;if(B>>>0>1){E=d+48|0;D=(E|0)==0;N=Z;Z=B;do{B=N+8|0;if((Z|0)!=0){Y=Z-1|0;c[B>>2]=Y;yt(c[(c[N>>2]|0)+(Y*12|0)>>2]|0)}if(!D){c[E>>2]=c[(c[N>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]}N=c[u>>2]|0;Z=c[N+8>>2]|0;}while(Z>>>0>1)}z=jj(d,6)|0;i=e;return z|0};case 9:{a[d+53|0]=1;$=0;break};case 0:{Z=d+48|0;N=c[Z>>2]|0;if((N|0)==0){c[Z>>2]=(c[(c[d+44>>2]|0)+8>>2]|0)-1;$=0;break L6831}else{c[Z>>2]=N-1;$=0;break L6831}break};case 2:{N=d+48|0;Z=c[N>>2]|0;if(Z>>>0>8){c[N>>2]=Z-8;$=0;break L6831}else{c[N>>2]=0;$=0;break L6831}break};case 1:{N=d+48|0;Z=(c[N>>2]|0)+1|0;if(Z>>>0<(c[(c[d+44>>2]|0)+8>>2]|0)>>>0){c[N>>2]=Z;$=0;break L6831}else{c[N>>2]=0;$=0;break L6831}break};case 3:{N=d+48|0;Z=(c[N>>2]|0)+8|0;E=c[(c[d+44>>2]|0)+8>>2]|0;if(Z>>>0<E>>>0){c[N>>2]=Z;$=0;break L6831}else{c[N>>2]=E-1;$=0;break L6831}break};case 6:{c[d+48>>2]=0;a[_]=1;$=0;break};case 4:{E=c[d+44>>2]|0;if((c[E+8>>2]|0)==0){z=0;i=e;return z|0}N=d+48|0;Z=c[N>>2]|0;D=c[E>>2]|0;E=c[D+(Z*12|0)>>2]|0;B=c[D+(Z*12|0)+4>>2]|0;D=B-31|0;do{if(!(D>>>0<24&((D>>>0)%3|0|0)==0|(B|0)==28)){if((B-73|0)>>>0<4|(B|0)==78|(B|0)==79){break}if((B|0)==88|(B|0)==71|(B|0)==57|(B|0)==1){break}Y=w-31|0;m=(w|0)==28;if(Y>>>0<24&((Y>>>0)%3|0|0)==0|m){if(m){m=p|0;hm(m,x,E);jk(d+4180|0,i_(m,3)|0,m)}else{hm(d+4256+(((Y>>>0)/3|0)*4148|0)|0,x,E)}a[_]=1;Y=c[u>>2]|0;m=c[Y+8>>2]|0;if((m|0)==0){aa=0}else{X=c[(c[Y>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((X|0)==26){$=0;break L6831}else{aa=X}}X=(N|0)==0;W=aa;C=Y;Y=m;while(1){m=C+8|0;if((Y|0)!=0){V=Y-1|0;c[m>>2]=V;yt(c[(c[C>>2]|0)+(V*12|0)>>2]|0)}if(!X){c[N>>2]=c[(c[C>>2]|0)+((c[m>>2]|0)*12|0)+8>>2]}m=c[u>>2]|0;V=c[m+8>>2]|0;if((V|0)==0){ab=W}else{ab=c[(c[m>>2]|0)+((V-1|0)*12|0)+4>>2]|0}if((ab|0)==26){$=0;break L6831}else{W=ab;C=m;Y=V}}}switch(w|0){case 76:{Y=4096;C=475114;W=x;while(1){X=Y-1|0;if((X|0)==0){ac=5e3;break}V=a[W]|0;a[C]=V;if(V<<24>>24==0){break}else{Y=X;C=C+1|0;W=W+1|0}}do{if((ac|0)==5e3){a[C]=0;if((a[W]|0)==0){break}else{ad=W}do{ad=ad+1|0;}while((a[ad]|0)!=0)}}while(0);a[_]=1;W=c[u>>2]|0;C=c[W+8>>2]|0;if((C|0)==0){ae=0}else{Y=c[(c[W>>2]|0)+((C-1|0)*12|0)+4>>2]|0;if((Y|0)==61){$=0;break L6831}else{ae=Y}}Y=(N|0)==0;X=ae;V=W;W=C;while(1){C=V+8|0;if((W|0)!=0){m=W-1|0;c[C>>2]=m;yt(c[(c[V>>2]|0)+(m*12|0)>>2]|0)}if(!Y){c[N>>2]=c[(c[V>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]}C=c[u>>2]|0;m=c[C+8>>2]|0;if((m|0)==0){af=X}else{af=c[(c[C>>2]|0)+((m-1|0)*12|0)+4>>2]|0}if((af|0)==61){$=0;break L6831}else{X=af;V=C;W=m}}break};case 73:{W=4096;V=401313;X=x;while(1){Y=W-1|0;if((Y|0)==0){ac=4981;break}m=a[X]|0;a[V]=m;if(m<<24>>24==0){break}else{W=Y;V=V+1|0;X=X+1|0}}do{if((ac|0)==4981){a[V]=0;if((a[X]|0)==0){break}else{ah=X}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);X=4096;V=d+54|0;W=x;while(1){Y=X-1|0;if((Y|0)==0){ac=4986;break}m=a[W]|0;a[V]=m;if(m<<24>>24==0){break}else{X=Y;V=V+1|0;W=W+1|0}}do{if((ac|0)==4986){a[V]=0;if((a[W]|0)==0){break}else{ai=W}do{ai=ai+1|0;}while((a[ai]|0)!=0)}}while(0);a[_]=1;W=c[u>>2]|0;V=c[W+8>>2]|0;if((V|0)==0){aj=0}else{X=c[(c[W>>2]|0)+((V-1|0)*12|0)+4>>2]|0;if((X|0)==61){$=0;break L6831}else{aj=X}}X=(N|0)==0;Y=aj;m=W;W=V;while(1){V=m+8|0;if((W|0)!=0){C=W-1|0;c[V>>2]=C;yt(c[(c[m>>2]|0)+(C*12|0)>>2]|0)}if(!X){c[N>>2]=c[(c[m>>2]|0)+((c[V>>2]|0)*12|0)+8>>2]}V=c[u>>2]|0;C=c[V+8>>2]|0;if((C|0)==0){ak=Y}else{ak=c[(c[V>>2]|0)+((C-1|0)*12|0)+4>>2]|0}if((ak|0)==61){$=0;break L6831}else{Y=ak;m=V;W=C}}break};case 71:{W=q|0;hm(W,x,E);m=h|0;g0(1,0);gp[c[126110]&31]()|0;Y=gp[c[126108]&31]()|0;if((Y|0)!=0){X=Y-1|0;yB(f|0,0,16);c[f>>2]=W;Y=c[126109]|0;gm[Y&127](X,f)|0;g1(X);b5(m|0,512,35320,(Q=i,i=i+8|0,c[Q>>2]=W,Q)|0)|0;i=Q;if((a[405432]&1)!=0){X=c[140620]|0;Y=(X|0)!=0?X:c[t>>2]|0;eS(Y|0,50096,(Q=i,i=i+8|0,c[Q>>2]=m,Q)|0)|0;i=Q;Y=c[140620]|0;X=(Y|0)!=0?Y:c[t>>2]|0;a7(X|0)|0}X=c[138489]|0;Y=X+4|0;C=c[Y>>2]|0;if(C>>>0>1){V=X|0;P=1;U=C;while(1){C=c[(c[V>>2]|0)+(P<<2)>>2]|0;if((C|0)==0){al=U}else{yt(c[C+8>>2]|0);yt(c[(c[V>>2]|0)+(P<<2)>>2]|0);c[(c[V>>2]|0)+(P<<2)>>2]=0;al=c[Y>>2]|0}C=P+1|0;if(C>>>0<al>>>0){P=C;U=al}else{break}}}c[Y>>2]=1;U=X+12|0;yt(c[U>>2]|0);c[U>>2]=0;U=c[138489]|0;P=U+4|0;L6959:do{if((c[P>>2]|0)>>>0<(c[U+8>>2]|0)>>>0){V=ys(12)|0;do{if((V|0)!=0){if((c[V-4>>2]&3|0)==0){break}yB(V|0,0,12)}}while(0);c[V+4>>2]=0;c[V>>2]=180;C=dW(m|0)|0;n=c[P>>2]|0;c[V+8>>2]=C;C=U|0;c[(c[C>>2]|0)+(n<<2)>>2]=V;n=c[P>>2]|0;c[P>>2]=n+1;if(n>>>0>1){am=n}else{break}while(1){n=am>>>1;T=c[C>>2]|0;L=T+(n<<2)|0;S=c[L>>2]|0;R=c[T+(am<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[S+4>>2]|0)>>>0){break L6959}c[L>>2]=R;c[(c[C>>2]|0)+(am<<2)>>2]=S;if(am>>>0>3){am=n}else{break}}}}while(0);g2(W);g3();g0(0,0)}P=562472;U=c[P+4>>2]|0;m=562472;c[m>>2]=c[P>>2]|1;c[m+4>>2]=U;a[_]=1;U=c[u>>2]|0;m=c[U+8>>2]|0;if((m|0)==0){an=0;ao=U;ap=m}else{P=c[(c[U>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((P|0)==4){$=-1;break L6831}else{an=P;ao=U;ap=m}}while(1){m=ao+8|0;if((ap|0)==0){aq=0;ar=ao;as=ao|0}else{U=ap-1|0;c[m>>2]=U;P=ao|0;yt(c[(c[P>>2]|0)+(U*12|0)>>2]|0);aq=c[m>>2]|0;ar=c[u>>2]|0;as=P}c[N>>2]=c[(c[as>>2]|0)+(aq*12|0)+8>>2];P=c[ar+8>>2]|0;if((P|0)==0){at=an}else{at=c[(c[ar>>2]|0)+((P-1|0)*12|0)+4>>2]|0}if((at|0)==4){$=-1;break L6831}else{an=at;ao=ar;ap=P}}break};case 56:{W=c[c[(c[21160]|0)+113712>>2]>>2]|0;P=c[W+(Z*12|0)>>2]|0;hJ(131072,c[W+(Z*12|0)+4>>2]|0)|0;W=(P|0)==0;a[(c[21160]|0)+4176|0]=W&1;L6982:do{if(W){a[442346]=0}else{m=4096;U=442346;X=P;while(1){Y=m-1|0;if((Y|0)==0){break}C=a[X]|0;a[U]=C;if(C<<24>>24==0){break L6982}else{m=Y;U=U+1|0;X=X+1|0}}a[U]=0;if((a[X]|0)==0){break}else{au=X}do{au=au+1|0;}while((a[au]|0)!=0)}}while(0);if((a[405432]&1)!=0){P=c[140620]|0;W=(P|0)!=0?P:c[t>>2]|0;be(23288,35,1,W|0)|0;W=c[140620]|0;P=(W|0)!=0?W:c[t>>2]|0;a7(P|0)|0}a[_]=1;P=c[u>>2]|0;W=c[P+8>>2]|0;if((W|0)==0){av=0;aw=P;ax=W}else{X=c[(c[P>>2]|0)+((W-1|0)*12|0)+4>>2]|0;if((X|0)==4){$=-1;break L6831}else{av=X;aw=P;ax=W}}while(1){W=aw+8|0;if((ax|0)==0){ay=0;az=aw;aA=aw|0}else{P=ax-1|0;c[W>>2]=P;X=aw|0;yt(c[(c[X>>2]|0)+(P*12|0)>>2]|0);ay=c[W>>2]|0;az=c[u>>2]|0;aA=X}c[N>>2]=c[(c[aA>>2]|0)+(ay*12|0)+8>>2];X=c[az+8>>2]|0;if((X|0)==0){aB=av}else{aB=c[(c[az>>2]|0)+((X-1|0)*12|0)+4>>2]|0}if((aB|0)==4){$=-1;break L6831}else{av=aB;aw=az;ax=X}}break};case 75:{X=4096;W=479210;P=x;while(1){U=X-1|0;if((U|0)==0){ac=5028;break}m=a[P]|0;a[W]=m;if(m<<24>>24==0){break}else{X=U;W=W+1|0;P=P+1|0}}do{if((ac|0)==5028){a[W]=0;if((a[P]|0)==0){break}else{aC=P}do{aC=aC+1|0;}while((a[aC]|0)!=0)}}while(0);a[_]=1;P=c[u>>2]|0;W=c[P+8>>2]|0;if((W|0)==0){aD=0}else{X=c[(c[P>>2]|0)+((W-1|0)*12|0)+4>>2]|0;if((X|0)==61){$=0;break L6831}else{aD=X}}X=(N|0)==0;U=aD;m=P;P=W;while(1){W=m+8|0;if((P|0)!=0){Y=P-1|0;c[W>>2]=Y;yt(c[(c[m>>2]|0)+(Y*12|0)>>2]|0)}if(!X){c[N>>2]=c[(c[m>>2]|0)+((c[W>>2]|0)*12|0)+8>>2]}W=c[u>>2]|0;Y=c[W+8>>2]|0;if((Y|0)==0){aE=U}else{aE=c[(c[W>>2]|0)+((Y-1|0)*12|0)+4>>2]|0}if((aE|0)==61){$=0;break L6831}else{U=aE;m=W;P=Y}}break};case 88:{hm(364400,x,E);P=c[140958]|0;if((P|0)!=0){m=P+24|0;U=P+12|0;X=c[U>>2]|0;if((c[m>>2]|0)==0){aF=X}else{Y=0;W=X;while(1){yt(c[W+(Y*136|0)>>2]|0);yt(c[W+(Y*136|0)+8>>2]|0);X=Y+1|0;C=c[U>>2]|0;if(X>>>0<(c[m>>2]|0)>>>0){Y=X;W=C}else{aF=C;break}}}yt(aF);W=c[P+4>>2]|0;if((W|0)!=0){f3[c[W>>2]&1023](c[P>>2]|0,0)}yt(P)}W=iF()|0;c[140958]=W;if((W|0)==0){W=c[140620]|0;Y=(W|0)!=0?W:c[t>>2]|0;be(37472,45,1,Y|0)|0;Y=c[140620]|0;W=(Y|0)!=0?Y:c[t>>2]|0;a7(W|0)|0}a[_]=1;W=c[u>>2]|0;Y=c[W+8>>2]|0;if((Y|0)==0){aG=0}else{m=c[(c[W>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((m|0)==60){$=0;break L6831}else{aG=m}}m=(N|0)==0;U=aG;C=W;W=Y;while(1){Y=C+8|0;if((W|0)!=0){X=W-1|0;c[Y>>2]=X;yt(c[(c[C>>2]|0)+(X*12|0)>>2]|0)}if(!m){c[N>>2]=c[(c[C>>2]|0)+((c[Y>>2]|0)*12|0)+8>>2]}Y=c[u>>2]|0;X=c[Y+8>>2]|0;if((X|0)==0){aH=U}else{aH=c[(c[Y>>2]|0)+((X-1|0)*12|0)+4>>2]|0}if((aH|0)==60){$=0;break L6831}else{U=aH;C=Y;W=X}}break};case 79:{W=4096;C=397180;U=x;while(1){m=W-1|0;if((m|0)==0){ac=5056;break}P=a[U]|0;a[C]=P;if(P<<24>>24==0){break}else{W=m;C=C+1|0;U=U+1|0}}do{if((ac|0)==5056){a[C]=0;if((a[U]|0)==0){break}else{aI=U}do{aI=aI+1|0;}while((a[aI]|0)!=0)}}while(0);a[_]=1;U=c[u>>2]|0;C=c[U+8>>2]|0;if((C|0)==0){aJ=0}else{W=c[(c[U>>2]|0)+((C-1|0)*12|0)+4>>2]|0;if((W|0)==61){$=0;break L6831}else{aJ=W}}W=(N|0)==0;m=aJ;P=U;U=C;while(1){C=P+8|0;if((U|0)!=0){X=U-1|0;c[C>>2]=X;yt(c[(c[P>>2]|0)+(X*12|0)>>2]|0)}if(!W){c[N>>2]=c[(c[P>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]}C=c[u>>2]|0;X=c[C+8>>2]|0;if((X|0)==0){aK=m}else{aK=c[(c[C>>2]|0)+((X-1|0)*12|0)+4>>2]|0}if((aK|0)==61){$=0;break L6831}else{m=aK;P=C;U=X}}break};case 78:{U=4096;P=483306;m=x;while(1){W=U-1|0;if((W|0)==0){ac=5014;break}X=a[m]|0;a[P]=X;if(X<<24>>24==0){break}else{U=W;P=P+1|0;m=m+1|0}}do{if((ac|0)==5014){a[P]=0;if((a[m]|0)==0){break}else{aL=m}do{aL=aL+1|0;}while((a[aL]|0)!=0)}}while(0);a[_]=1;m=c[u>>2]|0;P=c[m+8>>2]|0;if((P|0)==0){aM=0}else{U=c[(c[m>>2]|0)+((P-1|0)*12|0)+4>>2]|0;if((U|0)==61){$=0;break L6831}else{aM=U}}U=(N|0)==0;W=aM;X=m;m=P;while(1){P=X+8|0;if((m|0)!=0){C=m-1|0;c[P>>2]=C;yt(c[(c[X>>2]|0)+(C*12|0)>>2]|0)}if(!U){c[N>>2]=c[(c[X>>2]|0)+((c[P>>2]|0)*12|0)+8>>2]}P=c[u>>2]|0;C=c[P+8>>2]|0;if((C|0)==0){aN=W}else{aN=c[(c[P>>2]|0)+((C-1|0)*12|0)+4>>2]|0}if((aN|0)==61){$=0;break L6831}else{W=aN;X=P;m=C}}break};case 57:{a[_]=1;m=c[u>>2]|0;X=c[m+8>>2]|0;if((X|0)==0){aO=0}else{W=c[(c[m>>2]|0)+((X-1|0)*12|0)+4>>2]|0;if((W|0)==4){$=0;break L6831}else{aO=W}}W=(N|0)==0;U=aO;C=m;m=X;while(1){X=C+8|0;if((m|0)!=0){P=m-1|0;c[X>>2]=P;yt(c[(c[C>>2]|0)+(P*12|0)>>2]|0)}if(!W){c[N>>2]=c[(c[C>>2]|0)+((c[X>>2]|0)*12|0)+8>>2]}X=c[u>>2]|0;P=c[X+8>>2]|0;if((P|0)==0){aP=U}else{aP=c[(c[X>>2]|0)+((P-1|0)*12|0)+4>>2]|0}if((aP|0)==4){$=0;break L6831}else{U=aP;C=X;m=P}}break};case 74:{m=4096;C=311341;U=x;while(1){W=m-1|0;if((W|0)==0){ac=5042;break}P=a[U]|0;a[C]=P;if(P<<24>>24==0){break}else{m=W;C=C+1|0;U=U+1|0}}do{if((ac|0)==5042){a[C]=0;if((a[U]|0)==0){break}else{aQ=U}do{aQ=aQ+1|0;}while((a[aQ]|0)!=0)}}while(0);a[_]=1;U=c[u>>2]|0;C=c[U+8>>2]|0;if((C|0)==0){aR=0}else{m=c[(c[U>>2]|0)+((C-1|0)*12|0)+4>>2]|0;if((m|0)==61){$=0;break L6831}else{aR=m}}m=(N|0)==0;W=aR;P=U;U=C;while(1){C=P+8|0;if((U|0)!=0){X=U-1|0;c[C>>2]=X;yt(c[(c[P>>2]|0)+(X*12|0)>>2]|0)}if(!m){c[N>>2]=c[(c[P>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]}C=c[u>>2]|0;X=c[C+8>>2]|0;if((X|0)==0){aS=W}else{aS=c[(c[C>>2]|0)+((X-1|0)*12|0)+4>>2]|0}if((aS|0)==61){$=0;break L6831}else{W=aS;P=C;U=X}}break};default:{hm(442346,x,E);U=562472;P=c[U+4>>2]|0;W=562472;c[W>>2]=c[U>>2]|2;c[W+4>>2]=P;a[_]=1;P=c[u>>2]|0;W=c[P+8>>2]|0;if((W|0)==0){aT=0;aU=P;aV=W;ac=5070}else{U=c[(c[P>>2]|0)+((W-1|0)*12|0)+4>>2]|0;if((U|0)!=4){aT=U;aU=P;aV=W;ac=5070}}if((ac|0)==5070){while(1){ac=0;W=aU+8|0;if((aV|0)==0){aW=0;aX=aU;aY=aU|0}else{P=aV-1|0;c[W>>2]=P;U=aU|0;yt(c[(c[U>>2]|0)+(P*12|0)>>2]|0);aW=c[W>>2]|0;aX=c[u>>2]|0;aY=U}c[N>>2]=c[(c[aY>>2]|0)+(aW*12|0)+8>>2];U=c[aX+8>>2]|0;if((U|0)==0){aZ=aT}else{aZ=c[(c[aX>>2]|0)+((U-1|0)*12|0)+4>>2]|0}if((aZ|0)==4){break}else{aT=aZ;aU=aX;aV=U;ac=5070}}}a[d+53|0]=1;$=-1;break L6831}}}}while(0);Z=o|0;hm(Z,x,E);D=c[u>>2]|0;U=c[N>>2]|0;if((D|0)!=0){W=D+8|0;P=D+4|0;m=c[P>>2]|0;if((c[W>>2]|0)>>>0<m>>>0){a_=D|0}else{X=(m<<1)+2|0;c[P>>2]=X;P=D|0;c[P>>2]=yu(c[P>>2]|0,X*12|0)|0;a_=P}P=dW(Z|0)|0;c[(c[a_>>2]|0)+((c[W>>2]|0)*12|0)>>2]=P;c[(c[a_>>2]|0)+((c[W>>2]|0)*12|0)+4>>2]=B;c[(c[a_>>2]|0)+((c[W>>2]|0)*12|0)+8>>2]=U;c[W>>2]=(c[W>>2]|0)+1}c[N>>2]=0;a[_]=1;$=0;break};case 5:{W=c[u>>2]|0;U=W+8|0;if((c[U>>2]|0)>>>0<=1){$=0;break L6831}a[_]=1;P=d+48|0;Z=c[U>>2]|0;if((Z|0)!=0){X=Z-1|0;c[U>>2]=X;yt(c[(c[W>>2]|0)+(X*12|0)>>2]|0)}if((P|0)==0){$=0;break L6831}c[P>>2]=c[(c[W>>2]|0)+((c[U>>2]|0)*12|0)+8>>2];$=0;break};default:{$=0}}}while(0);a_=c[u>>2]|0;u=c[a_+8>>2]|0;if((u|0)==0){a$=w;a0=x}else{x=u-1|0;u=c[a_>>2]|0;a$=c[u+(x*12|0)+4>>2]|0;a0=c[u+(x*12|0)>>2]|0}L7168:do{if((a[_]&1)!=0){do{if((a$|0)!=1){x=a$-31|0;if(x>>>0<24&((x>>>0)%3|0|0)==0|(a$|0)==28){break}if((a$-73|0)>>>0<4|(a$|0)==78|(a$|0)==79){break}if(!((a$|0)==88|(a$|0)==71|(a$|0)==57|(a$|0)==56)){break L7168}}}while(0);a[_]=0;N=d+44|0;B=c[N>>2]|0;E=B+8|0;if((c[E>>2]|0)!=0){x=B|0;B=0;do{yt(c[(c[x>>2]|0)+(B*12|0)>>2]|0);B=B+1|0;}while(B>>>0<(c[E>>2]|0)>>>0)}c[E>>2]=0;L7180:do{if((a$|0)==56){B=k|0;x=l|0;u=d+113712|0;a_=c[u>>2]|0;w=c[a_+4>>2]|0;if((w|0)==0){break}else{a1=0;a2=a_}while(1){a_=c[a2>>2]|0;o=c[a_+(a1*12|0)>>2]|0;ac=c[a_+(a1*12|0)+8>>2]|0;L7243:do{if((o|0)==0){a_=4096;aV=B;aX=ac;while(1){aU=a_-1|0;if((aU|0)==0){break}aZ=a[aX]|0;a[aV]=aZ;if(aZ<<24>>24==0){break L7243}else{a_=aU;aV=aV+1|0;aX=aX+1|0}}a[aV]=0;if((a[aX]|0)==0){break}else{a3=aX}do{a3=a3+1|0;}while((a[a3]|0)!=0)}else{aX=cE(o|0,47)|0;hn(x,(aX|0)==0?o:aX+1|0,564064);b5(B|0,4096,18424,(Q=i,i=i+16|0,c[Q>>2]=x,c[Q+8>>2]=ac,Q)|0)|0;i=Q}}while(0);ac=c[N>>2]|0;if((ac|0)!=0){o=ac+8|0;aX=ac+4|0;aV=c[aX>>2]|0;if((c[o>>2]|0)>>>0<aV>>>0){a4=ac|0}else{a_=(aV<<1)+2|0;c[aX>>2]=a_;aX=ac|0;c[aX>>2]=yu(c[aX>>2]|0,a_*12|0)|0;a4=aX}aX=dW(B|0)|0;c[(c[a4>>2]|0)+((c[o>>2]|0)*12|0)>>2]=aX;c[(c[a4>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=0;c[(c[a4>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1}o=a1+1|0;if(o>>>0>=w>>>0){break L7180}a1=o;a2=c[u>>2]|0}}else{u=c[N>>2]|0;w=j|0;if((a[a0]|0)==0){if((u|0)==0){break}B=u+8|0;x=u+4|0;o=c[x>>2]|0;if((c[B>>2]|0)>>>0<o>>>0){a5=u|0}else{aX=(o<<1)+2|0;c[x>>2]=aX;x=u|0;c[x>>2]=yu(c[x>>2]|0,aX*12|0)|0;a5=x}x=dW(19896)|0;c[(c[a5>>2]|0)+((c[B>>2]|0)*12|0)>>2]=x;c[(c[a5>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=a$;c[(c[a5>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;break}do{if((a$|0)==28){a6=19576}else if((a$|0)==57){a6=564064}else{B=a$-31|0;if(B>>>0<24&((B>>>0)%3|0|0)==0){a6=19224;break}if((a$|0)==88){a6=19e3;break}if((a$-73|0)>>>0<4|(a$|0)==78|(a$|0)==79){a6=564064;break}B=c[d+4168>>2]|0;if((B|0)==0){a6=500312;break}if((a[B]|0)==0){a[w]=0;a6=w;break}else{b5(w|0,1024,18808,(Q=i,i=i+8|0,c[Q>>2]=B,Q)|0)|0;i=Q;a6=w;break}}}while(0);w=hl(a0,a6,1)|0;if((w|0)==0){break}B=w|0;x=w+4|0;dO(c[B>>2]|0,c[x>>2]|0,8,28);aX=(a$-73|0)>>>0<4|(a$|0)==78|(a$|0)==79;o=(u|0)==0;if(!(o|aX^1)){a_=u+8|0;ac=u+4|0;aV=c[ac>>2]|0;if((c[a_>>2]|0)>>>0<aV>>>0){a8=u|0}else{aU=(aV<<1)+2|0;c[ac>>2]=aU;ac=u|0;c[ac>>2]=yu(c[ac>>2]|0,aU*12|0)|0;a8=ac}ac=dW(18576)|0;c[(c[a8>>2]|0)+((c[a_>>2]|0)*12|0)>>2]=ac;c[(c[a8>>2]|0)+((c[a_>>2]|0)*12|0)+4>>2]=3;c[(c[a8>>2]|0)+((c[a_>>2]|0)*12|0)+8>>2]=0;c[a_>>2]=(c[a_>>2]|0)+1}a_=c[x>>2]|0;do{if((a_|0)==0){a9=c[B>>2]|0}else{ac=u+8|0;aU=u+4|0;aV=u|0;if(aX){aZ=0;aT=a_;while(1){aW=c[B>>2]|0;do{if((a[aW+(aZ<<3)+4|0]&1)==0){ba=aT}else{aY=c[aW+(aZ<<3)>>2]|0;if((a[a0]|0)==0){bb=aY}else{aS=cE(aY|0,47)|0;bb=(aS|0)==0?aY:aS+1|0}if(o){ba=aT;break}aS=c[aU>>2]|0;if((c[ac>>2]|0)>>>0>=aS>>>0){aY=(aS<<1)+2|0;c[aU>>2]=aY;c[aV>>2]=yu(c[aV>>2]|0,aY*12|0)|0}aY=dW(bb|0)|0;c[(c[aV>>2]|0)+((c[ac>>2]|0)*12|0)>>2]=aY;c[(c[aV>>2]|0)+((c[ac>>2]|0)*12|0)+4>>2]=a$;c[(c[aV>>2]|0)+((c[ac>>2]|0)*12|0)+8>>2]=0;c[ac>>2]=(c[ac>>2]|0)+1;ba=c[x>>2]|0}}while(0);aW=aZ+1|0;if(aW>>>0<ba>>>0){aZ=aW;aT=ba}else{bc=ba;break}}}else{aT=0;aZ=a_;while(1){aW=c[B>>2]|0;aY=a[aW+(aT<<3)+4|0]|0;aS=c[aW+(aT<<3)>>2]|0;if((a[a0]|0)==0){bd=aS}else{aW=cE(aS|0,47)|0;bd=(aW|0)==0?aS:aW+1|0}aW=(aY&1)!=0?a$:0;if(o){bf=aZ}else{aY=c[aU>>2]|0;if((c[ac>>2]|0)>>>0>=aY>>>0){aS=(aY<<1)+2|0;c[aU>>2]=aS;c[aV>>2]=yu(c[aV>>2]|0,aS*12|0)|0}aS=dW(bd|0)|0;c[(c[aV>>2]|0)+((c[ac>>2]|0)*12|0)>>2]=aS;c[(c[aV>>2]|0)+((c[ac>>2]|0)*12|0)+4>>2]=aW;c[(c[aV>>2]|0)+((c[ac>>2]|0)*12|0)+8>>2]=0;c[ac>>2]=(c[ac>>2]|0)+1;bf=c[x>>2]|0}aW=aT+1|0;if(aW>>>0<bf>>>0){aT=aW;aZ=bf}else{bc=bf;break}}}aZ=c[B>>2]|0;if((bc|0)==0){a9=aZ;break}else{bg=0;bh=aZ}while(1){yt(c[bh+(bg<<3)>>2]|0);aZ=bg+1|0;aT=c[B>>2]|0;if(aZ>>>0<(c[x>>2]|0)>>>0){bg=aZ;bh=aT}else{a9=aT;break}}}}while(0);yt(a9);yt(w)}}while(0);E=d+48|0;x=c[(c[N>>2]|0)+8>>2]|0;B=(x|0)==0;if(!((c[E>>2]|0)>>>0<x>>>0|B)){c[E>>2]=x-1;break}if(!B){break}c[E>>2]=0}}while(0);jl(d);z=$;i=e;return z|0}function jj(b,d){b=b|0;d=d|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0.0,U=0.0,V=0.0,W=0.0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0.0,aT=0,aU=0,aV=0,aW=0,aX=0.0,aY=0,aZ=0.0,a_=0,a$=0.0,a0=0,a1=0.0,a2=0,a3=0,a4=0,a5=0,a6=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0;f=i;i=i+13184|0;j=f|0;k=f+128|0;l=f+192|0;m=f+256|0;n=f+320|0;o=f+384|0;p=f+448|0;q=f+512|0;r=f+4608|0;s=f+4672|0;u=f+8768|0;v=f+9024|0;w=f+9088|0;c[b+32>>2]=640;do{if((d|0)==6){x=0;y=0}else{z=c[b+48>>2]|0;A=c[c[b+44>>2]>>2]|0;B=c[A+(z*12|0)>>2]|0;C=c[A+(z*12|0)+4>>2]|0;if((C|0)==57){x=564064;y=57;break}else if((C|0)==71){x=b+54|0;y=71;break}else{x=B;y=C;break}}}while(0);C=b+40|0;B=c[C>>2]|0;z=B+8|0;A=c[z>>2]|0;if((A|0)==0){D=0}else{D=c[(c[B>>2]|0)+((A-1|0)*12|0)+4>>2]|0}E=b+52|0;F=(a[E]&1)==0?d:10;L10:do{switch(F|0){case 0:{d=b+48|0;G=c[d>>2]|0;if((G|0)==0){c[d>>2]=(c[(c[b+44>>2]|0)+8>>2]|0)-1;break L10}else{c[d>>2]=G-1;break L10}break};case 1:{G=b+48|0;d=(c[G>>2]|0)+1|0;if(d>>>0<(c[(c[b+44>>2]|0)+8>>2]|0)>>>0){c[G>>2]=d;break L10}else{c[G>>2]=0;break L10}break};case 5:{if(A>>>0<=1){break L10}G=b+48|0;d=A-1|0;c[z>>2]=d;H=B|0;yt(c[(c[H>>2]|0)+(d*12|0)>>2]|0);if((G|0)!=0){c[G>>2]=c[(c[H>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]}a[E]=1;break};case 2:case 3:case 4:case 8:{H=(F|0)==4;if((y|0)==55&H){G=b+54|0;d=b+48|0;I=c[d>>2]|0;if((B|0)!=0){J=B+4|0;L=c[J>>2]|0;if(A>>>0<L>>>0){M=B|0}else{N=(L<<1)+2|0;c[J>>2]=N;J=B|0;c[J>>2]=yu(c[J>>2]|0,N*12|0)|0;M=J}J=dW(G|0)|0;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)>>2]=J;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=1;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=I;c[z>>2]=(c[z>>2]|0)+1}c[d>>2]=0;a[E]=1;break L10}do{if((y|0)==56){if(!H){break L10}}else{if(((y-73|0)>>>0<4|(y|0)==78|(y|0)==79)&H){break}L38:do{switch(y|0){case 69:case 62:case 61:case 59:case 58:case 26:case 5:case 4:case 60:case 71:case 57:{if(!H){break L38}d=b+48|0;I=c[d>>2]|0;if((B|0)!=0){J=B+4|0;G=c[J>>2]|0;if(A>>>0<G>>>0){O=B|0}else{N=(G<<1)+2|0;c[J>>2]=N;J=B|0;c[J>>2]=yu(c[J>>2]|0,N*12|0)|0;O=J}J=dW(x|0)|0;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)>>2]=J;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=I;c[z>>2]=(c[z>>2]|0)+1}c[d>>2]=0;a[E]=1;break L10;break};default:{if(!((y|0)==12&H)){break L38}d=c[b+48>>2]|0;if((B|0)!=0){I=B+4|0;J=c[I>>2]|0;if(A>>>0<J>>>0){P=B|0}else{N=(J<<1)+2|0;c[I>>2]=N;I=B|0;c[I>>2]=yu(c[I>>2]|0,N*12|0)|0;P=I}I=dW(564064)|0;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)>>2]=I;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=12;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=d;c[z>>2]=(c[z>>2]|0)+1}f3[c[(c[140913]|0)+44>>2]&1023](c[140916]|0,562420);g[2711]=+((c[140607]|0)>>>0>>>0)/+((c[140608]|0)>>>0>>>0);c[75784]=7;d=c[(c[140964]|0)+12>>2]|0;if((d|0)==0){break L10}f3[d&1023](c[140916]|0,7);break L10}}}while(0);d=b+113708|0;I=c[d>>2]|0;if((y-6|0)>>>0<20){switch(y|0){case 15:{if((F|0)==8){g[81955]=.004999999888241291;a[327817]=1;f3[c[(c[140913]|0)+40>>2]&1023](c[140916]|0,c[140611]|0);break L10}else if((F|0)==2){N=c[140611]|0;if((N|0)==0){Q=0}else{J=N-1|0;c[140611]=J;Q=J}f3[c[(c[140913]|0)+40>>2]&1023](c[140916]|0,Q);break L10}else if((F|0)==3){J=c[140611]|0;if(J>>>0<3){N=J+1|0;c[140611]=N;R=N}else{R=J}f3[c[(c[140913]|0)+40>>2]&1023](c[140916]|0,R);break L10}else{break L10}break};case 7:{if((F|0)==8){S=1}else{S=a[303124]&1^1}a[303124]=S;J=c[c[140964]>>2]|0;if((J|0)==0){break L10}gr[J&127](c[140916]|0,1,(S&1)!=0);break L10;break};case 9:{if((F|0)==8){c[140612]=0;J=c[(c[140964]|0)+16>>2]|0;if((J|0)==0){break L10}f2[J&1023](c[140916]|0);break L10}else if((F|0)==2){J=c[140612]|0;if((J|0)==0){break L10}c[140612]=J-1;J=c[(c[140964]|0)+16>>2]|0;if((J|0)==0){break L10}f2[J&1023](c[140916]|0);break L10}else{if(!((F|0)==3&(c[140612]|0)==0)){break L10}c[140612]=1;J=c[(c[140964]|0)+16>>2]|0;if((J|0)==0){break L10}f2[J&1023](c[140916]|0);break L10}break};case 10:{do{if((F|0)==8){a[303133]=0}else{if((F-2|0)>>>0>=3){break}a[303133]=a[303133]&1^1}}while(0);J=c[(c[140964]|0)+16>>2]|0;if((J|0)==0){break L10}f2[J&1023](c[140916]|0);break L10;break};case 11:{do{if((F|0)==8){c[75784]=4}else if((F|0)==2){J=c[75784]|0;if((J|0)==0){break}c[75784]=J-1}else if((F|0)==3){J=c[75784]|0;if(J>>>0>=7){break}c[75784]=J+1}}while(0);J=c[(c[140964]|0)+12>>2]|0;if((J|0)==0){break L10}f3[J&1023](c[140916]|0,c[75784]|0);break L10;break};case 14:{if(!H){break L10}gZ((a[303096]&1)==0);break L10;break};case 16:{if((F|0)==8){a[303112]=1;break L10}else if((F|0)==2|(F|0)==3|(F|0)==4){a[303112]=a[303112]&1^1;break L10}else{break L10}break};case 17:{if((F|0)==8){a[303113]=0;break L10}else if((F|0)==2|(F|0)==3|(F|0)==4){a[303113]=a[303113]&1^1;break L10}else{break L10}break};case 19:{if((F|0)==8){a[303114]=0;break L10}else if((F|0)==2|(F|0)==3|(F|0)==4){a[303114]=a[303114]&1^1;break L10}else{break L10}break};case 23:{if((F|0)==8){a[303126]=1;break L10}else if((F|0)==2|(F|0)==3|(F|0)==4){a[303126]=a[303126]&1^1;break L10}else{break L10}break};case 21:case 22:{J=(y|0)==21?303088:303092;T=+g[J>>2];if((F|0)==8){g[J>>2]=3.0;U=3.0}else if((F|0)==2){V=T+-1.0;g[J>>2]=V;U=V}else if((F|0)==3){V=T+1.0;g[J>>2]=V;U=V}else{U=T}V=+bZ(+U);W=V>1.0?V:1.0;g[J>>2]=W;if(T==W){break L10}if((a[303096]&1)!=0){break L10}gZ(0);break L10;break};case 20:{J=c[75779]|0;if((F|0)==8){c[75779]=1;X=1}else if((F|0)==2){N=J-1|0;c[75779]=N;X=N}else if((F|0)==3|(F|0)==4){N=J+1|0;c[75779]=N;X=N}else{X=J}N=X>>>0<4?X:4;G=N>>>0>1?N:1;c[75779]=G;N=c[140913]|0;L=c[140916]|0;if(!((J|0)!=(G|0)&(N|0)!=0&(L|0)!=0)){break L10}f3[c[N+8>>2]&1023](L,0);break L10;break};case 18:{if((F|0)==8){c[75780]=0;break L10}else if((F|0)==2){L=c[75780]|0;if((L|0)==0){break L10}c[75780]=L-1;break L10}else if((F|0)==3|(F|0)==4){L=c[75780]|0;if(L>>>0>=3){break L10}c[75780]=L+1;break L10}else{break L10}break};case 24:{if((F|0)==8){L=553784;c[L>>2]=0;c[L+4>>2]=0;break L10}else if((F|0)!=4){break L10}if((a[311340]&1)!=0){break L10}L=553784;N=c[L>>2]|0;G=c[L+4>>2]|0;L=0;J=G>>>0>L>>>0|G>>>0==L>>>0&N>>>0>2048>>>0?2048:N;if(J>>>0<2){break L10}else{Y=0;Z=0;_=0}do{N=537400+(Y<<3)|0;_=yL(c[N>>2]|0,c[N+4>>2]|0,_,Z)|0;Z=K;Y=Y+1|0;}while(Y>>>0<J>>>0);N=yT(_,Z,J,0)|0;W=1.0e6/(+(N>>>0)+ +(K|0)*4294967296.0);N=u|0;b5(N|0,256,27872,($=i,i=i+8|0,h[$>>3]=W,$)|0)|0;i=$;L=c[138489]|0;G=L+4|0;L152:do{if((c[G>>2]|0)>>>0<(c[L+8>>2]|0)>>>0){aa=ys(12)|0;do{if((aa|0)!=0){if((c[aa-4>>2]&3|0)==0){break}yB(aa|0,0,12)}}while(0);c[aa+4>>2]=1;c[aa>>2]=180;ab=dW(N|0)|0;ac=c[G>>2]|0;c[aa+8>>2]=ab;ab=L|0;c[(c[ab>>2]|0)+(ac<<2)>>2]=aa;ac=c[G>>2]|0;c[G>>2]=ac+1;if(ac>>>0>1){ad=ac}else{break}while(1){ac=ad>>>1;ae=c[ab>>2]|0;af=ae+(ac<<2)|0;ag=c[af>>2]|0;ah=c[ae+(ad<<2)>>2]|0;if((c[ah+4>>2]|0)>>>0<=(c[ag+4>>2]|0)>>>0){break L152}c[af>>2]=ah;c[(c[ab>>2]|0)+(ad<<2)>>2]=ag;if(ad>>>0>3){ad=ac}else{break}}}}while(0);if((a[405432]&1)!=0){G=c[140620]|0;L=(G|0)!=0?G:c[t>>2]|0;eS(L|0,50096,($=i,i=i+8|0,c[$>>2]=N,$)|0)|0;i=$;L=c[140620]|0;G=(L|0)!=0?L:c[t>>2]|0;a7(G|0)|0}g[77834]=W;hq();T=+((c[79902]|0)>>>0>>>0)/+g[79904];h[63069]=T;h[63075]=T;f3[c[(c[140913]|0)+8>>2]&1023](c[140916]|0,0);break L10;break};default:{break L10}}}if((y-27|0)>>>0<28){G=w|0;L=y-31|0;J=y-32|0;ab=y-33|0;if((y|0)==27){if((F|0)==8){a[303124]=1;break L10}else if((F|0)==2|(F|0)==3|(F|0)==4){a[303124]=a[303124]&1^1;break L10}else{break L10}}else if((y|0)==29){if(!((c[(c[140913]|0)+20>>2]|0)!=0&H)){break L10}if((a[405432]&1)!=0){aa=c[140620]|0;ac=(aa|0)!=0?aa:c[t>>2]|0;be(47208,31,1,ac|0)|0;ac=c[140620]|0;aa=(ac|0)!=0?ac:c[t>>2]|0;a7(aa|0)|0}aa=b+4252|0;ac=c[aa>>2]|0;L178:do{if((ac|0)!=0){ag=3;ah=0;while(1){af=i_(b+4256+(ah*4148|0)|0,3)|0;if(!((af|0)==0|(af|0)==2)){break L178}if((ag|0)==3){ai=af}else{if((ag|0)==(af|0)){ai=ag}else{break L178}}af=ah+1|0;if(af>>>0<ac>>>0){ag=ai;ah=af}else{break}}if((ai|0)==3){break}hm(G,(a[311341]|0)!=0?311341:397180,(ai|0)==2?47152:47048);ah=ys(20)|0;if((ah|0)==0){break L10}if((c[ah-4>>2]&3|0)!=0){yB(ah|0,0,20)}ag=ah;ah=p|0;af=q|0;ae=r|0;aj=s|0;ak=j|0;b5(ak|0,128,11016,($=i,i=i+8|0,c[$>>2]=c[aa>>2],$)|0)|0;i=$;hF(ag,48096,ak);if((c[aa>>2]|0)!=0){al=l|0;am=k|0;an=0;do{b5(ah|0,64,30728,($=i,i=i+8|0,c[$>>2]=an,$)|0)|0;i=$;hF(ag,ah,b+4256+(an*4148|0)|0);ao=b+4256+(an*4148|0)+4136|0;if((c[ao>>2]|0)!=0){b5(ah|0,64,30256,($=i,i=i+8|0,c[$>>2]=an,$)|0)|0;i=$;hF(ag,ah,(c[ao>>2]|0)==1?53312:31792)}b5(ah|0,64,29464,($=i,i=i+8|0,c[$>>2]=an,$)|0)|0;i=$;ao=c[b+4256+(an*4148|0)+4140>>2]|0;if((ao|0)==1){ap=18432}else if((ao|0)==2){ap=18240}else if((ao|0)==3){ap=18024}else if((ao|0)==0){ap=18600}else{ap=17760}hF(ag,ah,ap);ao=b+4256+(an*4148|0)+4144|0;if((c[ao>>2]|0)!=0){b5(ah|0,64,29024,($=i,i=i+8|0,c[$>>2]=an,$)|0)|0;i=$;aq=c[ao>>2]|0;b5(ak|0,128,11016,($=i,i=i+8|0,c[$>>2]=aq,$)|0)|0;i=$;hF(ag,ah,ak)}b5(al|0,64,20352,($=i,i=i+8|0,c[$>>2]=an,$)|0)|0;i=$;hF(ag,al,(a[b+4256+(an*4148|0)+4132|0]&1)!=0?53312:31792);do{if((a[b+4256+(an*4148|0)+4104|0]&1)!=0){aq=c[b+4256+(an*4148|0)+4108>>2]|0;T=+g[b+4256+(an*4148|0)+4116>>2];ao=c[b+4256+(an*4148|0)+4124>>2]|0;b5(am|0,64,19904,($=i,i=i+16|0,c[$>>2]=75992,c[$+8>>2]=an,$)|0)|0;i=$;if((aq|0)==2){ar=19008}else if((aq|0)==1){ar=18816}else if((aq|0)==0){ar=19232}else{ar=20464}hF(ag,am,ar);b5(am|0,64,19664,($=i,i=i+16|0,c[$>>2]=75992,c[$+8>>2]=an,$)|0)|0;i=$;if((aq|0)==1){b5(ak|0,128,11016,($=i,i=i+8|0,c[$>>2]=ao,$)|0)|0;i=$;hF(ag,am,ak)}else{V=T;b5(ak|0,128,44088,($=i,i=i+8|0,h[$>>3]=V,$)|0)|0;i=$;hF(ag,am,ak)}ao=c[b+4256+(an*4148|0)+4112>>2]|0;V=+g[b+4256+(an*4148|0)+4120>>2];aq=c[b+4256+(an*4148|0)+4128>>2]|0;b5(am|0,64,19904,($=i,i=i+16|0,c[$>>2]=75984,c[$+8>>2]=an,$)|0)|0;i=$;if((ao|0)==2){as=19008}else if((ao|0)==1){as=18816}else if((ao|0)==0){as=19232}else{as=20464}hF(ag,am,as);b5(am|0,64,19664,($=i,i=i+16|0,c[$>>2]=75984,c[$+8>>2]=an,$)|0)|0;i=$;if((ao|0)==1){b5(ak|0,128,11016,($=i,i=i+8|0,c[$>>2]=aq,$)|0)|0;i=$;hF(ag,am,ak);break}else{T=V;b5(ak|0,128,44088,($=i,i=i+8|0,h[$>>3]=T,$)|0)|0;i=$;hF(ag,am,ak);break}}}while(0);an=an+1|0;}while(an>>>0<(c[aa>>2]|0)>>>0)}an=b+70624|0;do{if((c[an>>2]|0)!=0){yB(af|0,0,4096);am=4096;al=af;ah=b+70628|0;while(1){aq=am-1|0;if((aq|0)==0){at=183;break}ao=a[ah]|0;a[al]=ao;if(ao<<24>>24==0){break}else{am=aq;al=al+1|0;ah=ah+1|0}}do{if((at|0)==183){a[al]=0;if((a[ah]|0)==0){break}else{au=ah}do{au=au+1|0;}while((a[au]|0)!=0)}}while(0);if((c[an>>2]|0)>>>0>1){ah=1;do{al=yA(af|0)|0;am=al>>>0>4096?0:4096-al|0;L241:do{if((am|0)==0){av=28640;at=190}else{aq=q+al|0;do{if((am|0)==1){aw=28640;ax=aq}else{ao=q+(al+1)|0;a[aq]=59;if((am|0)==2){aw=28641;ax=ao;break}a[ao]=0;break L241}}while(0);a[ax]=0;av=aw;at=190}}while(0);do{if((at|0)==190){at=0;if((a[av]|0)==0){break}else{ay=av}do{ay=ay+1|0;}while((a[ay]|0)!=0)}}while(0);am=b+70628+(ah*4168|0)|0;al=yA(af|0)|0;aq=al>>>0>4096?0:4096-al|0;L252:do{if((aq|0)==0){az=am;at=197}else{ao=aq;aA=q+al|0;aB=am;while(1){aC=ao-1|0;if((aC|0)==0){break}aD=a[aB]|0;a[aA]=aD;if(aD<<24>>24==0){break L252}else{ao=aC;aA=aA+1|0;aB=aB+1|0}}a[aA]=0;az=aB;at=197}}while(0);do{if((at|0)==197){at=0;if((a[az]|0)==0){break}else{aE=az}do{aE=aE+1|0;}while((a[aE]|0)!=0)}}while(0);ah=ah+1|0;}while(ah>>>0<(c[an>>2]|0)>>>0)}hF(ag,28264,af);if((c[an>>2]|0)==0){break}else{aF=0}do{ah=b+70628+(aF*4168|0)|0;hF(ag,ah,b+70628+(aF*4168|0)+64|0);aB=b+70628+(aF*4168|0)+4160|0;if((c[aB>>2]|0)!=0){b5(ae|0,64,27848,($=i,i=i+8|0,c[$>>2]=ah,$)|0)|0;i=$;hF(ag,ae,(c[aB>>2]|0)!=1?53312:31792)}b5(ae|0,64,27424,($=i,i=i+8|0,c[$>>2]=ah,$)|0)|0;i=$;ah=c[b+70628+(aF*4168|0)+4164>>2]|0;if((ah|0)==1){aG=18432}else if((ah|0)==2){aG=18240}else if((ah|0)==3){aG=18024}else if((ah|0)==0){aG=18600}else{aG=17760}hF(ag,ae,aG);aF=aF+1|0;}while(aF>>>0<(c[an>>2]|0)>>>0)}}while(0);an=b+109096|0;if((a[an]|0)!=0){hF(ag,27104,an)}an=b+113196|0;if((a[an]|0)!=0){hF(ag,26640,an)}an=b+103972|0;L282:do{if((c[an>>2]|0)!=0){yB(aj|0,0,4096);ae=4096;af=aj;ah=b+103976|0;while(1){aB=ae-1|0;if((aB|0)==0){at=217;break}aA=a[ah]|0;a[af]=aA;if(aA<<24>>24==0){break}else{ae=aB;af=af+1|0;ah=ah+1|0}}do{if((at|0)==217){a[af]=0;if((a[ah]|0)==0){break}else{aH=ah}do{aH=aH+1|0;}while((a[aH]|0)!=0)}}while(0);if((c[an>>2]|0)>>>0>1){ah=1;do{af=yA(aj|0)|0;ae=af>>>0>4096?0:4096-af|0;L295:do{if((ae|0)==0){aI=28640;at=224}else{aB=s+af|0;do{if((ae|0)==1){aJ=28640;aK=aB}else{aA=s+(af+1)|0;a[aB]=59;if((ae|0)==2){aJ=28641;aK=aA;break}a[aA]=0;break L295}}while(0);a[aK]=0;aI=aJ;at=224}}while(0);do{if((at|0)==224){at=0;if((a[aI]|0)==0){break}else{aL=aI}do{aL=aL+1|0;}while((a[aL]|0)!=0)}}while(0);ae=b+103976+(ah*80|0)|0;af=yA(aj|0)|0;aB=af>>>0>4096?0:4096-af|0;L306:do{if((aB|0)==0){aM=ae;at=231}else{aA=aB;am=s+af|0;al=ae;while(1){aq=aA-1|0;if((aq|0)==0){break}ao=a[al]|0;a[am]=ao;if(ao<<24>>24==0){break L306}else{aA=aq;am=am+1|0;al=al+1|0}}a[am]=0;aM=al;at=231}}while(0);do{if((at|0)==231){at=0;if((a[aM]|0)==0){break}else{aN=aM}do{aN=aN+1|0;}while((a[aN]|0)!=0)}}while(0);ah=ah+1|0;}while(ah>>>0<(c[an>>2]|0)>>>0)}hF(ag,26248,aj);if((c[an>>2]|0)==0){break}ah=k|0;al=l|0;am=m|0;ae=n|0;af=o|0;aB=0;while(1){aA=b+103976+(aB*80|0)|0;b5(ah|0,64,24032,($=i,i=i+8|0,c[$>>2]=aA,$)|0)|0;i=$;b5(al|0,64,23800,($=i,i=i+8|0,c[$>>2]=aA,$)|0)|0;i=$;b5(am|0,64,23456,($=i,i=i+8|0,c[$>>2]=aA,$)|0)|0;i=$;b5(ae|0,64,23224,($=i,i=i+8|0,c[$>>2]=aA,$)|0)|0;i=$;b5(af|0,64,22928,($=i,i=i+8|0,c[$>>2]=aA,$)|0)|0;i=$;switch(c[b+103976+(aB*80|0)+68>>2]|0){case 2:{aO=22280;break};case 3:{aO=21616;break};case 1:{aO=21216;break};case 4:{aO=20720;break};case 5:{aO=20552;break};case 0:{aO=22768;break};default:{aO=20464}}hF(ag,ah,aO);b5(ak|0,128,53824,($=i,i=i+8|0,c[$>>2]=e[b+103976+(aB*80|0)+76>>1]|0,$)|0)|0;i=$;hF(ag,ae,ak);b5(ak|0,128,53824,($=i,i=i+8|0,c[$>>2]=e[b+103976+(aB*80|0)+78>>1]|0,$)|0)|0;i=$;hF(ag,af,ak);aA=c[b+103976+(aB*80|0)+72>>2]|0;if((aA|0)==2){b5(ak|0,128,11016,($=i,i=i+8|0,c[$>>2]=1,$)|0)|0;i=$;hF(ag,am,ak)}else if((aA|0)==3){b5(ak|0,128,11016,($=i,i=i+8|0,c[$>>2]=2,$)|0)|0;i=$;hF(ag,am,ak)}else if((aA|0)==1){b5(ak|0,128,53824,($=i,i=i+8|0,c[$>>2]=c[b+103976+(aB*80|0)+64>>2],$)|0)|0;i=$;hF(ag,al,ak)}aB=aB+1|0;if(aB>>>0>=(c[an>>2]|0)>>>0){break L282}}}}while(0);hG(ag,G)|0;hA(ag);jk(0,ai,G);break L10}}while(0);G=i_(564064,2)|0;jk(0,(G|0)==3?2:G,0);break L10}else if((y|0)==30){do{if((F|0)==8){c[b+4252>>2]=0}else if((F|0)==2){G=b+4252|0;aa=c[G>>2]|0;if((aa|0)==0){break}c[G>>2]=aa-1}else if((F|0)==3|(F|0)==4){aa=b+4252|0;G=c[aa>>2]|0;if(G>>>0>=8){break}c[aa>>2]=G+1}}while(0);a[E]=1;break L10}else{G=(y|0)==28;if(!(((L>>>0)%3|0|0)==0|G)){if(((J>>>0)%3|0|0)==0){aa=(J>>>0)/3|0;if((F|0)==8){c[b+4256+(aa*4148|0)+4136>>2]=0;break L10}else if((F|0)==2|(F|0)==3|(F|0)==4){ac=b+4256+(aa*4148|0)+4136|0;c[ac>>2]=(((c[ac>>2]|0)+((F|0)==2?2:1)|0)>>>0)%3|0;break L10}else{break L10}}if(((ab>>>0)%3|0|0)!=0){break L10}ac=(ab>>>0)/3|0;if((F|0)==8){g[b+4256+(ac*4148|0)+4120>>2]=0.0;g[b+4256+(ac*4148|0)+4116>>2]=0.0;a[b+4256+(ac*4148|0)+4104|0]=0;break L10}else if((F|0)==2|(F|0)==3|(F|0)==4){aa=b+4256+(ac*4148|0)+4116|0;N=((~~+g[aa>>2]+((F|0)==2?5:1)|0)>>>0)%6|0;a[b+4256+(ac*4148|0)+4104|0]=(N|0)!=0|0;W=+(N>>>0>>>0);g[b+4256+(ac*4148|0)+4120>>2]=W;g[aa>>2]=W;break L10}else{break L10}}if(G){aP=b+4256+(((L>>>0)/3|0)*4148|0)|0}else{aP=0}if((F|0)==8){if((aP|0)==0){break L10}a[aP|0]=0;break L10}else if((F|0)!=4){break L10}G=b+48|0;aa=c[G>>2]|0;if((B|0)!=0){ac=B+4|0;N=c[ac>>2]|0;if(A>>>0<N>>>0){aQ=B|0}else{an=(N<<1)+2|0;c[ac>>2]=an;ac=B|0;c[ac>>2]=yu(c[ac>>2]|0,an*12|0)|0;aQ=ac}ac=dW(311341)|0;c[(c[aQ>>2]|0)+((c[z>>2]|0)*12|0)>>2]=ac;c[(c[aQ>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[aQ>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=aa;c[z>>2]=(c[z>>2]|0)+1}c[G>>2]=0;a[E]=1;break L10}}if(y>>>0>65535){G=y-65536|0;if((F|0)==2){aa=c[126128]|0;ac=c[aa+4100>>2]|0;an=ac+(G<<4)+12|0;N=c[(c[ac+(G<<4)+8>>2]|0)+4>>2]|0;c[an>>2]=(((c[an>>2]|0)-1+N|0)>>>0)%(N>>>0)|0;a[aa+4108|0]=1;break L10}else if((F|0)==3|(F|0)==4){aa=c[126128]|0;N=c[aa+4100>>2]|0;an=N+(G<<4)+12|0;c[an>>2]=(((c[an>>2]|0)+1|0)>>>0)%((c[(c[N+(G<<4)+8>>2]|0)+4>>2]|0)>>>0)|0;a[aa+4108|0]=1;break L10}else if((F|0)==8){aa=c[126128]|0;c[(c[aa+4100>>2]|0)+(G<<4)+12>>2]=0;a[aa+4108|0]=1;break L10}else{break L10}}L380:do{switch(y|0){case 63:{if((F|0)==8){a[401276]=0;aa=c[138491]|0;if((aa|0)!=0){yt(c[aa>>2]|0);yt(c[aa+12>>2]|0);yt(aa)}c[138491]=0;yt(c[138492]|0);c[138492]=0;break L10}else if(!((F|0)==4|(F|0)==3|(F|0)==2)){break L10}aa=a[401276]&1;a[401276]=aa^1;if(aa<<24>>24==0){gV();break L10}aa=c[138491]|0;if((aa|0)!=0){yt(c[aa>>2]|0);yt(c[aa+12>>2]|0);yt(aa)}c[138491]=0;yt(c[138492]|0);c[138492]=0;break L10;break};case 64:{if((F-3|0)>>>0<2){c[100321]=(c[100321]|0)+1;break L10}if((F|0)==8){c[100321]=1;break L10}else if((F|0)!=2){break L10}aa=c[100321]|0;if(aa>>>0<=1){break L10}c[100321]=aa-1;break L10;break};case 65:{if((F-3|0)>>>0<2|(F|0)==2){a[562486]=a[562486]&1^1;break L10}if((F|0)!=8){break L10}a[562486]=1;break L10;break};case 67:case 68:{if((F|0)==4){if((y|0)==67){gY()}else{gW()}aa=562472;G=c[aa+4>>2]|0;N=562472;c[N>>2]=c[aa>>2]|1;c[N+4>>2]=G;aR=-1;i=f;return aR|0}else if((F|0)==8){c[124924]=0;break L10}else if((F|0)==2){G=c[124924]|0;if((G|0)==0){break L10}c[124924]=G-1;break L10}else if((F|0)==3){c[124924]=(c[124924]|0)+1;break L10}else{break L10}break};case 72:{if(!H){break L10}do{if((a[319567]&1)!=0|(c[126111]|0)!=0){G=c[140964]|0;do{if((G|0)!=0){N=c[G+24>>2]|0;if((N|0)==0){break}gr[N&127](c[140916]|0,0,0)}}while(0);if((c[140913]|0)==0){break}gQ()}}while(0);gP();break L10;break};case 80:{if(!H){break L10}g_();ag=562472;G=c[ag+4>>2]|0;N=562472;c[N>>2]=c[ag>>2]|1;c[N+4>>2]=G;aR=-1;i=f;return aR|0};case 81:{if((F|0)==8){a[504561]=0;break L10}else{a[504561]=a[504561]&1^1;break L10}break};case 82:{if((F|0)==8){g[81955]=.004999999888241291;a[327817]=1;break L10}else if((F|0)==2){W=+g[81955];if(W>0.0){T=W+-.001;g[81955]=T;aS=T}else{aS=W}if(aS<5.0e-4){a[327817]=0;g[81955]=0.0;break L10}else{a[327817]=1;break L10}}else if((F|0)==3){W=+g[81955];if(W<.2){g[81955]=W+.001}a[327817]=1;break L10}else{break L10}break};case 84:{if((F|0)==8|(F|0)==2){G=562472;N=c[G+4>>2]|0;ag=562472;c[ag>>2]=c[G>>2]&-257;c[ag+4>>2]=N;break L10}else if((F|0)==3){N=562472;ag=c[N+4>>2]|0;G=562472;c[G>>2]=c[N>>2]|256;c[G+4>>2]=ag;break L10}else{break L10}break};case 70:{ag=gp[c[126108]&31]()|0;G=gp[c[126106]&31]()|0;if((F-3|0)>>>0<2){aT=1}else{N=(F|0)==2;if(N){aT=N<<31>>31}else{break L10}}N=ag+1|0;g0(1,0);g1(((G+N+aT|0)>>>0)%(N>>>0)|0);g0(0,0);break L10;break};case 85:{if(!H){break L10}N=562472;G=c[N+4>>2]|0|0;ag=562472;c[ag>>2]=c[N>>2]&-1026|1024;c[ag+4>>2]=G;aR=-1;i=f;return aR|0};case 86:{if(!H){break L10}if((a[562484]&1)==0){break L10}G=562472;ag=c[G+4>>2]|0;N=562472;c[N>>2]=c[G>>2]|1;c[N+4>>2]=ag;aR=-1;i=f;return aR|0};case 87:{if(!H){break L10}ag=562472;N=c[ag+4>>2]|0;G=562472;c[G>>2]=c[ag>>2]&-2;c[G+4>>2]=N;aR=-1;i=f;return aR|0};case 88:{if((F|0)==4){N=b+48|0;G=c[N>>2]|0;if((B|0)!=0){ag=B+4|0;aa=c[ag>>2]|0;if(A>>>0<aa>>>0){aU=B|0}else{an=(aa<<1)+2|0;c[ag>>2]=an;ag=B|0;c[ag>>2]=yu(c[ag>>2]|0,an*12|0)|0;aU=ag}ag=dW(483306)|0;c[(c[aU>>2]|0)+((c[z>>2]|0)*12|0)>>2]=ag;c[(c[aU>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=88;c[(c[aU>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=G;c[z>>2]=(c[z>>2]|0)+1}c[N>>2]=0;a[E]=1;break L10}else if((F|0)!=8){break L10}N=c[140958]|0;if((N|0)!=0){G=N+24|0;ag=N+12|0;an=c[ag>>2]|0;if((c[G>>2]|0)==0){aV=an}else{aa=0;ac=an;while(1){yt(c[ac+(aa*136|0)>>2]|0);yt(c[ac+(aa*136|0)+8>>2]|0);an=aa+1|0;ak=c[ag>>2]|0;if(an>>>0<(c[G>>2]|0)>>>0){aa=an;ac=ak}else{aV=ak;break}}}yt(aV);ac=c[N+4>>2]|0;if((ac|0)!=0){f3[c[ac>>2]&1023](c[N>>2]|0,0)}yt(N)}c[140958]=0;a[364400]=0;break L10;break};case 89:{if((F|0)==2){W=+g[92124]+-.009999999776482582;g[92124]=W;aW=1;aX=W;at=368}else if((F|0)==3|(F|0)==4){W=+g[92124]+.009999999776482582;g[92124]=W;aW=1;aX=W;at=368}else if((F|0)==8){g[92124]=1.0;aY=1;aZ=1.0}else{aW=0;aX=+g[92124];at=368}do{if((at|0)==368){if(aX<0.0){g[92124]=0.0;aY=aW;aZ=0.0;break}if(aX<=1.0){aY=aW;aZ=aX;break}g[92124]=1.0;aY=aW;aZ=1.0}}while(0);N=c[140958]|0;if(!(aY&(N|0)!=0)){break L10}f0[c[(c[N+4>>2]|0)+20>>2]&7](c[N>>2]|0,aZ);break L10;break};case 90:{if((F|0)==2){W=+g[92125]+-.009999999776482582;g[92125]=W;a_=1;a$=W;at=379}else if((F|0)==3|(F|0)==4){W=+g[92125]+.009999999776482582;g[92125]=W;a_=1;a$=W;at=379}else if((F|0)==8){g[92125]=1.0;a0=1;a1=1.0}else{a_=0;a$=+g[92125];at=379}do{if((at|0)==379){if(a$<.009999999776482582){g[92125]=.009999999776482582;a0=a_;a1=.009999999776482582;break}if(a$<=2.0){a0=a_;a1=a$;break}g[92125]=2.0;a0=a_;a1=2.0}}while(0);N=c[140958]|0;if(!(a0&(N|0)!=0)){break L10}iE(N,a1);break L10;break};case 91:{if((F|0)==8){c[d>>2]=0;break L10}else if((F|0)==2){if((I|0)==0){break L10}c[d>>2]=I-1;break L10}else if((F|0)==3){if(I>>>0>=7){break L10}c[d>>2]=I+1;break L10}else{break L10}break};case 92:{N=(c[140914]|0)+20|0;if((c[N>>2]|0)==0){ac=363780+(I<<2)|0;if((F|0)==8){c[ac>>2]=I;a2=I}else if((F|0)==2){aa=(c[ac>>2]|0)-1|0;c[ac>>2]=aa;a2=aa}else if((F|0)==3){aa=(c[ac>>2]|0)+1|0;c[ac>>2]=aa;a2=aa}else{a2=c[ac>>2]|0}if((a2|0)<-1){c[ac>>2]=-1;break L10}if((a2|0)<=7){break L10}c[ac>>2]=7;break L10}else{ac=363812+(I<<2)|0;aa=c[ac>>2]|0;if((F|0)==8){c[ac>>2]=0;a3=0}else if((F|0)==2){G=aa-1|0;c[ac>>2]=G;a3=G}else if((F|0)==3){G=aa+1|0;c[ac>>2]=G;a3=G}else{a3=aa}aa=c[364356+(I<<2)>>2]|0;if((aa|0)==1){a4=80}else if((aa|0)==2){a4=144}else if((aa|0)==0){a4=48}else{a4=16}f1[c[N>>2]&15](c[140917]|0,a3,I,0,a4);break L10}break};case 93:{N=405436+(I<<2)|0;aa=c[N>>2]|0;G=0;while(1){if(G>>>0>=8){a5=0;break}if((aa|0)==(c[1448+(G<<2)>>2]|0)){a5=G;break}else{G=G+1|0}}if((F|0)==2){a6=c[1448+((a5+7&7)<<2)>>2]|0}else if((F|0)==3|(F|0)==4){a6=c[1448+((a5+1&7)<<2)>>2]|0}else if((F|0)==8){a6=1}else{break L10}c[N>>2]=a6;f3[c[21500]&1023](I,a6);break L10;break};case 94:{G=364356+(I<<2)|0;aa=c[G>>2]|0;ac=aa+4|0;c[G>>2]=ac;if((F|0)==8){c[G>>2]=1;a8=1}else if((F|0)==2){ag=aa+3|0;c[G>>2]=ag;a8=ag}else if((F|0)==3){ag=aa+5|0;c[G>>2]=ag;a8=ag}else{a8=ac}ac=a8&3;c[G>>2]=ac;G=c[(c[140914]|0)+20>>2]|0;if((G|0)==0){break L10}if((ac|0)==2){a9=128}else if((ac|0)==0){a9=32}else if((ac|0)==1){a9=64}else{break L10}f1[G&15](c[140917]|0,c[363812+(I<<2)>>2]|0,I,0,a9);break L10;break};case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:case 108:case 109:case 110:{G=c[(c[140914]|0)+20>>2]|0;if((G|0)==0){break L380}if((F|0)==2){ba=2}else if((F|0)==8){ba=8}else{ac=(F|0)==3;if(ac){ba=ac?4:0}else{break L380}}ac=y-95|0;f1[G&15](c[140917]|0,c[363812+(ac<<2)>>2]|0,I,c[1552+(ac<<2)>>2]|0,ba);break};case 73:{break};case 76:{if((F|0)!=8){break L10}a[475114]=0;break L10;break};case 78:{if((F|0)!=8){break L10}a[483306]=0;break L10;break};case 75:{if((F|0)!=8){break L10}a[479210]=0;break L10;break};case 74:{if((F|0)!=8){break L10}a[311341]=0;break L10;break};case 79:{if((F|0)!=8){break L10}a[397180]=0;break L10;break};default:{break L10}}}while(0);if((F|0)!=8){break L10}a[401313]=0;a[b+54|0]=0;break L10}}while(0);H=b+48|0;I=c[H>>2]|0;if((B|0)!=0){d=B+4|0;L=c[d>>2]|0;if(A>>>0<L>>>0){bb=B|0}else{ab=(L<<1)+2|0;c[d>>2]=ab;d=B|0;c[d>>2]=yu(c[d>>2]|0,ab*12|0)|0;bb=d}d=dW(564064)|0;c[(c[bb>>2]|0)+((c[z>>2]|0)*12|0)>>2]=d;c[(c[bb>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[bb>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=I;c[z>>2]=(c[z>>2]|0)+1}c[H>>2]=0;a[E]=1;break};case 6:{c[b+48>>2]=0;a[E]=1;break};case 9:{a[b+53|0]=1;break};default:{}}}while(0);z=c[C>>2]|0;C=c[z+8>>2]|0;if((C|0)==0){bc=D}else{bc=c[(c[z>>2]|0)+((C-1|0)*12|0)+4>>2]|0}L601:do{if(!((a[E]&1)==0|(bc|0)==1)){C=bc-31|0;if(C>>>0<24&((C>>>0)%3|0|0)==0|(bc|0)==28){break}if((bc-73|0)>>>0<4|(bc|0)==78|(bc|0)==79){break}if((bc|0)==88|(bc|0)==71|(bc|0)==57|(bc|0)==56){break}a[E]=0;switch(bc|0){case 60:{C=b+44|0;z=c[C>>2]|0;D=z+8|0;if((c[D>>2]|0)!=0){bb=z|0;z=0;do{yt(c[(c[bb>>2]|0)+(z*12|0)>>2]|0);z=z+1|0;}while(z>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;z=c[C>>2]|0;do{if((z|0)!=0){bb=z+8|0;y=z+4|0;B=c[y>>2]|0;if((c[bb>>2]|0)>>>0<B>>>0){bd=z|0}else{A=(B<<1)+2|0;c[y>>2]=A;y=z|0;c[y>>2]=yu(c[y>>2]|0,A*12|0)|0;bd=y}y=dW(51496)|0;c[(c[bd>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=y;c[(c[bd>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=88;c[(c[bd>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[C>>2]|0;if((bb|0)==0){break}y=bb+8|0;A=bb+4|0;B=c[A>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){bf=bb|0}else{F=(B<<1)+2|0;c[A>>2]=F;A=bb|0;c[A>>2]=yu(c[A>>2]|0,F*12|0)|0;bf=A}A=dW(51184)|0;c[(c[bf>>2]|0)+((c[y>>2]|0)*12|0)>>2]=A;c[(c[bf>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=89;c[(c[bf>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break}A=y+8|0;F=y+4|0;bb=c[F>>2]|0;if((c[A>>2]|0)>>>0<bb>>>0){bg=y|0}else{B=(bb<<1)+2|0;c[F>>2]=B;F=y|0;c[F>>2]=yu(c[F>>2]|0,B*12|0)|0;bg=F}F=dW(50816)|0;c[(c[bg>>2]|0)+((c[A>>2]|0)*12|0)>>2]=F;c[(c[bg>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=90;c[(c[bg>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break}F=A+8|0;B=A+4|0;y=c[B>>2]|0;if((c[F>>2]|0)>>>0<y>>>0){bh=A|0}else{bb=(y<<1)+2|0;c[B>>2]=bb;B=A|0;c[B>>2]=yu(c[B>>2]|0,bb*12|0)|0;bh=B}B=dW(50560)|0;c[(c[bh>>2]|0)+((c[F>>2]|0)*12|0)>>2]=B;c[(c[bh>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=91;c[(c[bh>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[C>>2]|0;if((F|0)==0){break}B=F+8|0;bb=F+4|0;A=c[bb>>2]|0;if((c[B>>2]|0)>>>0<A>>>0){bi=F|0}else{y=(A<<1)+2|0;c[bb>>2]=y;bb=F|0;c[bb>>2]=yu(c[bb>>2]|0,y*12|0)|0;bi=bb}bb=dW(50448)|0;c[(c[bi>>2]|0)+((c[B>>2]|0)*12|0)>>2]=bb;c[(c[bi>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=92;c[(c[bi>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[C>>2]|0;if((B|0)==0){break}bb=B+8|0;y=B+4|0;F=c[y>>2]|0;if((c[bb>>2]|0)>>>0<F>>>0){bj=B|0}else{A=(F<<1)+2|0;c[y>>2]=A;y=B|0;c[y>>2]=yu(c[y>>2]|0,A*12|0)|0;bj=y}y=dW(50192)|0;c[(c[bj>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=y;c[(c[bj>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=93;c[(c[bj>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1}}while(0);z=c[140914]|0;if((z|0)==0){break L601}if((c[z+20>>2]|0)==0){break L601}z=c[C>>2]|0;if((z|0)==0){break L601}D=z+8|0;bb=z+4|0;y=c[bb>>2]|0;if((c[D>>2]|0)>>>0<y>>>0){bk=z|0}else{A=(y<<1)+2|0;c[bb>>2]=A;bb=z|0;c[bb>>2]=yu(c[bb>>2]|0,A*12|0)|0;bk=bb}bb=dW(49936)|0;c[(c[bk>>2]|0)+((c[D>>2]|0)*12|0)>>2]=bb;c[(c[bk>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=94;c[(c[bk>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L601}bb=D+8|0;A=D+4|0;z=c[A>>2]|0;if((c[bb>>2]|0)>>>0<z>>>0){bl=D|0}else{y=(z<<1)+2|0;c[A>>2]=y;A=D|0;c[A>>2]=yu(c[A>>2]|0,y*12|0)|0;bl=A}A=dW(49744)|0;c[(c[bl>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=A;c[(c[bl>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=95;c[(c[bl>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[C>>2]|0;if((bb|0)==0){break L601}A=bb+8|0;y=bb+4|0;D=c[y>>2]|0;if((c[A>>2]|0)>>>0<D>>>0){bm=bb|0}else{z=(D<<1)+2|0;c[y>>2]=z;y=bb|0;c[y>>2]=yu(c[y>>2]|0,z*12|0)|0;bm=y}y=dW(49584)|0;c[(c[bm>>2]|0)+((c[A>>2]|0)*12|0)>>2]=y;c[(c[bm>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=96;c[(c[bm>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L601}y=A+8|0;z=A+4|0;bb=c[z>>2]|0;if((c[y>>2]|0)>>>0<bb>>>0){bn=A|0}else{D=(bb<<1)+2|0;c[z>>2]=D;z=A|0;c[z>>2]=yu(c[z>>2]|0,D*12|0)|0;bn=z}z=dW(49368)|0;c[(c[bn>>2]|0)+((c[y>>2]|0)*12|0)>>2]=z;c[(c[bn>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=97;c[(c[bn>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L601}z=y+8|0;D=y+4|0;A=c[D>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){bo=y|0}else{bb=(A<<1)+2|0;c[D>>2]=bb;D=y|0;c[D>>2]=yu(c[D>>2]|0,bb*12|0)|0;bo=D}D=dW(49072)|0;c[(c[bo>>2]|0)+((c[z>>2]|0)*12|0)>>2]=D;c[(c[bo>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=98;c[(c[bo>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[C>>2]|0;if((z|0)==0){break L601}D=z+8|0;bb=z+4|0;y=c[bb>>2]|0;if((c[D>>2]|0)>>>0<y>>>0){bp=z|0}else{A=(y<<1)+2|0;c[bb>>2]=A;bb=z|0;c[bb>>2]=yu(c[bb>>2]|0,A*12|0)|0;bp=bb}bb=dW(44928)|0;c[(c[bp>>2]|0)+((c[D>>2]|0)*12|0)>>2]=bb;c[(c[bp>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=99;c[(c[bp>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L601}bb=D+8|0;A=D+4|0;z=c[A>>2]|0;if((c[bb>>2]|0)>>>0<z>>>0){bq=D|0}else{y=(z<<1)+2|0;c[A>>2]=y;A=D|0;c[A>>2]=yu(c[A>>2]|0,y*12|0)|0;bq=A}A=dW(43464)|0;c[(c[bq>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=A;c[(c[bq>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=100;c[(c[bq>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[C>>2]|0;if((bb|0)==0){break L601}A=bb+8|0;y=bb+4|0;D=c[y>>2]|0;if((c[A>>2]|0)>>>0<D>>>0){br=bb|0}else{z=(D<<1)+2|0;c[y>>2]=z;y=bb|0;c[y>>2]=yu(c[y>>2]|0,z*12|0)|0;br=y}y=dW(26536)|0;c[(c[br>>2]|0)+((c[A>>2]|0)*12|0)>>2]=y;c[(c[br>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=101;c[(c[br>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L601}y=A+8|0;z=A+4|0;bb=c[z>>2]|0;if((c[y>>2]|0)>>>0<bb>>>0){bs=A|0}else{D=(bb<<1)+2|0;c[z>>2]=D;z=A|0;c[z>>2]=yu(c[z>>2]|0,D*12|0)|0;bs=z}z=dW(26080)|0;c[(c[bs>>2]|0)+((c[y>>2]|0)*12|0)>>2]=z;c[(c[bs>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=102;c[(c[bs>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L601}z=y+8|0;D=y+4|0;A=c[D>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){bt=y|0}else{bb=(A<<1)+2|0;c[D>>2]=bb;D=y|0;c[D>>2]=yu(c[D>>2]|0,bb*12|0)|0;bt=D}D=dW(48200)|0;c[(c[bt>>2]|0)+((c[z>>2]|0)*12|0)>>2]=D;c[(c[bt>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=103;c[(c[bt>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[C>>2]|0;if((z|0)==0){break L601}D=z+8|0;bb=z+4|0;y=c[bb>>2]|0;if((c[D>>2]|0)>>>0<y>>>0){bu=z|0}else{A=(y<<1)+2|0;c[bb>>2]=A;bb=z|0;c[bb>>2]=yu(c[bb>>2]|0,A*12|0)|0;bu=bb}bb=dW(48040)|0;c[(c[bu>>2]|0)+((c[D>>2]|0)*12|0)>>2]=bb;c[(c[bu>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=104;c[(c[bu>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L601}bb=D+8|0;A=D+4|0;z=c[A>>2]|0;if((c[bb>>2]|0)>>>0<z>>>0){bv=D|0}else{y=(z<<1)+2|0;c[A>>2]=y;A=D|0;c[A>>2]=yu(c[A>>2]|0,y*12|0)|0;bv=A}A=dW(32408)|0;c[(c[bv>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=A;c[(c[bv>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=105;c[(c[bv>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[C>>2]|0;if((bb|0)==0){break L601}A=bb+8|0;y=bb+4|0;D=c[y>>2]|0;if((c[A>>2]|0)>>>0<D>>>0){bw=bb|0}else{z=(D<<1)+2|0;c[y>>2]=z;y=bb|0;c[y>>2]=yu(c[y>>2]|0,z*12|0)|0;bw=y}y=dW(28856)|0;c[(c[bw>>2]|0)+((c[A>>2]|0)*12|0)>>2]=y;c[(c[bw>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=106;c[(c[bw>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L601}y=A+8|0;z=A+4|0;bb=c[z>>2]|0;if((c[y>>2]|0)>>>0<bb>>>0){bx=A|0}else{D=(bb<<1)+2|0;c[z>>2]=D;z=A|0;c[z>>2]=yu(c[z>>2]|0,D*12|0)|0;bx=z}z=dW(47744)|0;c[(c[bx>>2]|0)+((c[y>>2]|0)*12|0)>>2]=z;c[(c[bx>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=107;c[(c[bx>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L601}z=y+8|0;D=y+4|0;A=c[D>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){by=y|0}else{bb=(A<<1)+2|0;c[D>>2]=bb;D=y|0;c[D>>2]=yu(c[D>>2]|0,bb*12|0)|0;by=D}D=dW(47488)|0;c[(c[by>>2]|0)+((c[z>>2]|0)*12|0)>>2]=D;c[(c[by>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=108;c[(c[by>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[C>>2]|0;if((z|0)==0){break L601}D=z+8|0;bb=z+4|0;y=c[bb>>2]|0;if((c[D>>2]|0)>>>0<y>>>0){bz=z|0}else{A=(y<<1)+2|0;c[bb>>2]=A;bb=z|0;c[bb>>2]=yu(c[bb>>2]|0,A*12|0)|0;bz=bb}bb=dW(47376)|0;c[(c[bz>>2]|0)+((c[D>>2]|0)*12|0)>>2]=bb;c[(c[bz>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=109;c[(c[bz>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L601}bb=D+8|0;A=D+4|0;z=c[A>>2]|0;if((c[bb>>2]|0)>>>0<z>>>0){bA=D|0}else{y=(z<<1)+2|0;c[A>>2]=y;A=D|0;c[A>>2]=yu(c[A>>2]|0,y*12|0)|0;bA=A}A=dW(47296)|0;c[(c[bA>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=A;c[(c[bA>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=110;c[(c[bA>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;break L601;break};case 61:{bb=b+44|0;A=c[bb>>2]|0;y=A+8|0;if((c[y>>2]|0)!=0){D=A|0;A=0;do{yt(c[(c[D>>2]|0)+(A*12|0)>>2]|0);A=A+1|0;}while(A>>>0<(c[y>>2]|0)>>>0)}c[y>>2]=0;A=c[bb>>2]|0;if((A|0)==0){break L601}D=A+8|0;C=A+4|0;z=c[C>>2]|0;if((c[D>>2]|0)>>>0<z>>>0){bB=A|0}else{B=(z<<1)+2|0;c[C>>2]=B;C=A|0;c[C>>2]=yu(c[C>>2]|0,B*12|0)|0;bB=C}C=dW(53488)|0;c[(c[bB>>2]|0)+((c[D>>2]|0)*12|0)>>2]=C;c[(c[bB>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=73;c[(c[bB>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[bb>>2]|0;if((D|0)==0){break L601}C=D+8|0;B=D+4|0;A=c[B>>2]|0;if((c[C>>2]|0)>>>0<A>>>0){bC=D|0}else{z=(A<<1)+2|0;c[B>>2]=z;B=D|0;c[B>>2]=yu(c[B>>2]|0,z*12|0)|0;bC=B}B=dW(53288)|0;c[(c[bC>>2]|0)+((c[C>>2]|0)*12|0)>>2]=B;c[(c[bC>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=74;c[(c[bC>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[bb>>2]|0;if((C|0)==0){break L601}B=C+8|0;z=C+4|0;D=c[z>>2]|0;if((c[B>>2]|0)>>>0<D>>>0){bD=C|0}else{A=(D<<1)+2|0;c[z>>2]=A;z=C|0;c[z>>2]=yu(c[z>>2]|0,A*12|0)|0;bD=z}z=dW(53120)|0;c[(c[bD>>2]|0)+((c[B>>2]|0)*12|0)>>2]=z;c[(c[bD>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=75;c[(c[bD>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[bb>>2]|0;if((B|0)==0){break L601}z=B+8|0;A=B+4|0;C=c[A>>2]|0;if((c[z>>2]|0)>>>0<C>>>0){bE=B|0}else{D=(C<<1)+2|0;c[A>>2]=D;A=B|0;c[A>>2]=yu(c[A>>2]|0,D*12|0)|0;bE=A}A=dW(52680)|0;c[(c[bE>>2]|0)+((c[z>>2]|0)*12|0)>>2]=A;c[(c[bE>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=76;c[(c[bE>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[bb>>2]|0;if((z|0)==0){break L601}A=z+8|0;D=z+4|0;B=c[D>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bF=z|0}else{C=(B<<1)+2|0;c[D>>2]=C;D=z|0;c[D>>2]=yu(c[D>>2]|0,C*12|0)|0;bF=D}D=dW(52448)|0;c[(c[bF>>2]|0)+((c[A>>2]|0)*12|0)>>2]=D;c[(c[bF>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=78;c[(c[bF>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[bb>>2]|0;if((A|0)==0){break L601}D=A+8|0;C=A+4|0;z=c[C>>2]|0;if((c[D>>2]|0)>>>0<z>>>0){bG=A|0}else{B=(z<<1)+2|0;c[C>>2]=B;C=A|0;c[C>>2]=yu(c[C>>2]|0,B*12|0)|0;bG=C}C=dW(52088)|0;c[(c[bG>>2]|0)+((c[D>>2]|0)*12|0)>>2]=C;c[(c[bG>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=79;c[(c[bG>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;break L601;break};case 62:{D=b+44|0;C=c[D>>2]|0;B=C+8|0;if((c[B>>2]|0)!=0){A=C|0;C=0;do{yt(c[(c[A>>2]|0)+(C*12|0)>>2]|0);C=C+1|0;}while(C>>>0<(c[B>>2]|0)>>>0)}c[B>>2]=0;C=c[D>>2]|0;if((C|0)==0){break L601}A=C+8|0;bb=C+4|0;y=c[bb>>2]|0;if((c[A>>2]|0)>>>0<y>>>0){bH=C|0}else{z=(y<<1)+2|0;c[bb>>2]=z;bb=C|0;c[bb>>2]=yu(c[bb>>2]|0,z*12|0)|0;bH=bb}bb=dW(54224)|0;c[(c[bH>>2]|0)+((c[A>>2]|0)*12|0)>>2]=bb;c[(c[bH>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=63;c[(c[bH>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[D>>2]|0;if((A|0)==0){break L601}bb=A+8|0;z=A+4|0;C=c[z>>2]|0;if((c[bb>>2]|0)>>>0<C>>>0){bI=A|0}else{y=(C<<1)+2|0;c[z>>2]=y;z=A|0;c[z>>2]=yu(c[z>>2]|0,y*12|0)|0;bI=z}z=dW(54064)|0;c[(c[bI>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=z;c[(c[bI>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=64;c[(c[bI>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[D>>2]|0;if((bb|0)==0){break L601}z=bb+8|0;y=bb+4|0;A=c[y>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){bJ=bb|0}else{C=(A<<1)+2|0;c[y>>2]=C;y=bb|0;c[y>>2]=yu(c[y>>2]|0,C*12|0)|0;bJ=y}y=dW(53848)|0;c[(c[bJ>>2]|0)+((c[z>>2]|0)*12|0)>>2]=y;c[(c[bJ>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=65;c[(c[bJ>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[D>>2]|0;if((z|0)==0){break L601}y=z+8|0;C=z+4|0;bb=c[C>>2]|0;if((c[y>>2]|0)>>>0<bb>>>0){bK=z|0}else{A=(bb<<1)+2|0;c[C>>2]=A;C=z|0;c[C>>2]=yu(c[C>>2]|0,A*12|0)|0;bK=C}C=dW(53664)|0;c[(c[bK>>2]|0)+((c[y>>2]|0)*12|0)>>2]=C;c[(c[bK>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=84;c[(c[bK>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;break L601;break};case 58:{y=b+44|0;C=c[y>>2]|0;A=C+8|0;if((c[A>>2]|0)!=0){z=C|0;C=0;do{yt(c[(c[z>>2]|0)+(C*12|0)>>2]|0);C=C+1|0;}while(C>>>0<(c[A>>2]|0)>>>0)}c[A>>2]=0;C=c[126128]|0;if((C|0)==0){z=c[y>>2]|0;if((z|0)==0){break L601}D=z+8|0;B=z+4|0;bb=c[B>>2]|0;if((c[D>>2]|0)>>>0<bb>>>0){bL=z|0}else{F=(bb<<1)+2|0;c[B>>2]=F;B=z|0;c[B>>2]=yu(c[B>>2]|0,F*12|0)|0;bL=B}B=dW(54744)|0;c[(c[bL>>2]|0)+((c[D>>2]|0)*12|0)>>2]=B;c[(c[bL>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=65535;c[(c[bL>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;break L601}D=c[C+4104>>2]|0;if((D|0)==0){break L601}else{bM=0;bN=C}while(1){C=c[y>>2]|0;B=c[(c[bN+4100>>2]|0)+(bM<<4)>>2]|0;F=bM+65536|0;if((C|0)!=0){z=C+8|0;bb=C+4|0;ba=c[bb>>2]|0;if((c[z>>2]|0)>>>0<ba>>>0){bO=C|0}else{a9=(ba<<1)+2|0;c[bb>>2]=a9;bb=C|0;c[bb>>2]=yu(c[bb>>2]|0,a9*12|0)|0;bO=bb}bb=dW(B|0)|0;c[(c[bO>>2]|0)+((c[z>>2]|0)*12|0)>>2]=bb;c[(c[bO>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=F;c[(c[bO>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1}z=bM+1|0;if(z>>>0>=D>>>0){break L601}bM=z;bN=c[126128]|0}break};case 59:{D=b+44|0;y=c[D>>2]|0;A=y+8|0;if((c[A>>2]|0)!=0){z=y|0;y=0;do{yt(c[(c[z>>2]|0)+(y*12|0)>>2]|0);y=y+1|0;}while(y>>>0<(c[A>>2]|0)>>>0)}c[A>>2]=0;y=c[D>>2]|0;if((y|0)==0){break L601}z=y+8|0;F=y+4|0;bb=c[F>>2]|0;if((c[z>>2]|0)>>>0<bb>>>0){bP=y|0}else{B=(bb<<1)+2|0;c[F>>2]=B;F=y|0;c[F>>2]=yu(c[F>>2]|0,B*12|0)|0;bP=F}F=dW(10888)|0;c[(c[bP>>2]|0)+((c[z>>2]|0)*12|0)>>2]=F;c[(c[bP>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=81;c[(c[bP>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[D>>2]|0;if((z|0)==0){break L601}F=z+8|0;B=z+4|0;y=c[B>>2]|0;if((c[F>>2]|0)>>>0<y>>>0){bQ=z|0}else{bb=(y<<1)+2|0;c[B>>2]=bb;B=z|0;c[B>>2]=yu(c[B>>2]|0,bb*12|0)|0;bQ=B}B=dW(54984)|0;c[(c[bQ>>2]|0)+((c[F>>2]|0)*12|0)>>2]=B;c[(c[bQ>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=82;c[(c[bQ>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;break L601;break};case 69:{F=b+44|0;B=c[F>>2]|0;bb=B+8|0;if((c[bb>>2]|0)!=0){z=B|0;B=0;do{yt(c[(c[z>>2]|0)+(B*12|0)>>2]|0);B=B+1|0;}while(B>>>0<(c[bb>>2]|0)>>>0)}c[bb>>2]=0;B=c[F>>2]|0;if((B|0)==0){break L601}z=B+8|0;D=B+4|0;A=c[D>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){bR=B|0}else{y=(A<<1)+2|0;c[D>>2]=y;D=B|0;c[D>>2]=yu(c[D>>2]|0,y*12|0)|0;bR=D}D=dW(11176)|0;c[(c[bR>>2]|0)+((c[z>>2]|0)*12|0)>>2]=D;c[(c[bR>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=70;c[(c[bR>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[F>>2]|0;if((z|0)==0){break L601}D=z+8|0;y=z+4|0;B=c[y>>2]|0;if((c[D>>2]|0)>>>0<B>>>0){bS=z|0}else{A=(B<<1)+2|0;c[y>>2]=A;y=z|0;c[y>>2]=yu(c[y>>2]|0,A*12|0)|0;bS=y}y=dW(11040)|0;c[(c[bS>>2]|0)+((c[D>>2]|0)*12|0)>>2]=y;c[(c[bS>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=71;c[(c[bS>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;break L601;break};case 5:{D=b+44|0;y=c[D>>2]|0;A=y+8|0;if((c[A>>2]|0)!=0){z=y|0;y=0;do{yt(c[(c[z>>2]|0)+(y*12|0)>>2]|0);y=y+1|0;}while(y>>>0<(c[A>>2]|0)>>>0)}c[A>>2]=0;y=c[D>>2]|0;if((y|0)==0){break L601}z=y+8|0;F=y+4|0;bb=c[F>>2]|0;if((c[z>>2]|0)>>>0<bb>>>0){bT=y|0}else{B=(bb<<1)+2|0;c[F>>2]=B;F=y|0;c[F>>2]=yu(c[F>>2]|0,B*12|0)|0;bT=F}F=dW(14416)|0;c[(c[bT>>2]|0)+((c[z>>2]|0)*12|0)>>2]=F;c[(c[bT>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=26;c[(c[bT>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[D>>2]|0;if((z|0)==0){break L601}F=z+8|0;B=z+4|0;y=c[B>>2]|0;if((c[F>>2]|0)>>>0<y>>>0){bU=z|0}else{bb=(y<<1)+2|0;c[B>>2]=bb;B=z|0;c[B>>2]=yu(c[B>>2]|0,bb*12|0)|0;bU=B}B=dW(14184)|0;c[(c[bU>>2]|0)+((c[F>>2]|0)*12|0)>>2]=B;c[(c[bU>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=10;c[(c[bU>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[D>>2]|0;if((F|0)==0){break L601}B=F+8|0;bb=F+4|0;z=c[bb>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){bV=F|0}else{y=(z<<1)+2|0;c[bb>>2]=y;bb=F|0;c[bb>>2]=yu(c[bb>>2]|0,y*12|0)|0;bV=bb}bb=dW(13776)|0;c[(c[bV>>2]|0)+((c[B>>2]|0)*12|0)>>2]=bb;c[(c[bV>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=11;c[(c[bV>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[D>>2]|0;if((B|0)==0){break L601}bb=B+8|0;y=B+4|0;F=c[y>>2]|0;if((c[bb>>2]|0)>>>0<F>>>0){bW=B|0}else{z=(F<<1)+2|0;c[y>>2]=z;y=B|0;c[y>>2]=yu(c[y>>2]|0,z*12|0)|0;bW=y}y=dW(13600)|0;c[(c[bW>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=y;c[(c[bW>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=12;c[(c[bW>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[D>>2]|0;if((bb|0)==0){break L601}y=bb+8|0;z=bb+4|0;B=c[z>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){bX=bb|0}else{F=(B<<1)+2|0;c[z>>2]=F;z=bb|0;c[z>>2]=yu(c[z>>2]|0,F*12|0)|0;bX=z}z=dW(13480)|0;c[(c[bX>>2]|0)+((c[y>>2]|0)*12|0)>>2]=z;c[(c[bX>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=14;c[(c[bX>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[D>>2]|0;if((y|0)==0){break L601}z=y+8|0;F=y+4|0;bb=c[F>>2]|0;if((c[z>>2]|0)>>>0<bb>>>0){bY=y|0}else{B=(bb<<1)+2|0;c[F>>2]=B;F=y|0;c[F>>2]=yu(c[F>>2]|0,B*12|0)|0;bY=F}F=dW(13320)|0;c[(c[bY>>2]|0)+((c[z>>2]|0)*12|0)>>2]=F;c[(c[bY>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=15;c[(c[bY>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[D>>2]|0;if((z|0)==0){break L601}F=z+8|0;B=z+4|0;y=c[B>>2]|0;if((c[F>>2]|0)>>>0<y>>>0){b_=z|0}else{bb=(y<<1)+2|0;c[B>>2]=bb;B=z|0;c[B>>2]=yu(c[B>>2]|0,bb*12|0)|0;b_=B}B=dW(13176)|0;c[(c[b_>>2]|0)+((c[F>>2]|0)*12|0)>>2]=B;c[(c[b_>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=16;c[(c[b_>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[D>>2]|0;if((F|0)==0){break L601}B=F+8|0;bb=F+4|0;z=c[bb>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){b$=F|0}else{y=(z<<1)+2|0;c[bb>>2]=y;bb=F|0;c[bb>>2]=yu(c[bb>>2]|0,y*12|0)|0;b$=bb}bb=dW(12896)|0;c[(c[b$>>2]|0)+((c[B>>2]|0)*12|0)>>2]=bb;c[(c[b$>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=17;c[(c[b$>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[D>>2]|0;if((B|0)==0){break L601}bb=B+8|0;y=B+4|0;F=c[y>>2]|0;if((c[bb>>2]|0)>>>0<F>>>0){b0=B|0}else{z=(F<<1)+2|0;c[y>>2]=z;y=B|0;c[y>>2]=yu(c[y>>2]|0,z*12|0)|0;b0=y}y=dW(12720)|0;c[(c[b0>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=y;c[(c[b0>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=18;c[(c[b0>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[D>>2]|0;if((bb|0)==0){break L601}y=bb+8|0;z=bb+4|0;B=c[z>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){b1=bb|0}else{F=(B<<1)+2|0;c[z>>2]=F;z=bb|0;c[z>>2]=yu(c[z>>2]|0,F*12|0)|0;b1=z}z=dW(12504)|0;c[(c[b1>>2]|0)+((c[y>>2]|0)*12|0)>>2]=z;c[(c[b1>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=19;c[(c[b1>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[D>>2]|0;if((y|0)==0){break L601}z=y+8|0;F=y+4|0;bb=c[F>>2]|0;if((c[z>>2]|0)>>>0<bb>>>0){b2=y|0}else{B=(bb<<1)+2|0;c[F>>2]=B;F=y|0;c[F>>2]=yu(c[F>>2]|0,B*12|0)|0;b2=F}F=dW(11992)|0;c[(c[b2>>2]|0)+((c[z>>2]|0)*12|0)>>2]=F;c[(c[b2>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=20;c[(c[b2>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[D>>2]|0;if((z|0)==0){break L601}F=z+8|0;B=z+4|0;y=c[B>>2]|0;if((c[F>>2]|0)>>>0<y>>>0){b3=z|0}else{bb=(y<<1)+2|0;c[B>>2]=bb;B=z|0;c[B>>2]=yu(c[B>>2]|0,bb*12|0)|0;b3=B}B=dW(11792)|0;c[(c[b3>>2]|0)+((c[F>>2]|0)*12|0)>>2]=B;c[(c[b3>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=21;c[(c[b3>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[D>>2]|0;if((F|0)==0){break L601}B=F+8|0;bb=F+4|0;z=c[bb>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){b4=F|0}else{y=(z<<1)+2|0;c[bb>>2]=y;bb=F|0;c[bb>>2]=yu(c[bb>>2]|0,y*12|0)|0;b4=bb}bb=dW(11592)|0;c[(c[b4>>2]|0)+((c[B>>2]|0)*12|0)>>2]=bb;c[(c[b4>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=22;c[(c[b4>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[D>>2]|0;if((B|0)==0){break L601}bb=B+8|0;y=B+4|0;F=c[y>>2]|0;if((c[bb>>2]|0)>>>0<F>>>0){b6=B|0}else{z=(F<<1)+2|0;c[y>>2]=z;y=B|0;c[y>>2]=yu(c[y>>2]|0,z*12|0)|0;b6=y}y=dW(11416)|0;c[(c[b6>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=y;c[(c[b6>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=23;c[(c[b6>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[D>>2]|0;if((bb|0)==0){break L601}y=bb+8|0;z=bb+4|0;B=c[z>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){b7=bb|0}else{F=(B<<1)+2|0;c[z>>2]=F;z=bb|0;c[z>>2]=yu(c[z>>2]|0,F*12|0)|0;b7=z}z=dW(11320)|0;c[(c[b7>>2]|0)+((c[y>>2]|0)*12|0)>>2]=z;c[(c[b7>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=24;c[(c[b7>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;break L601;break};case 26:{y=v|0;z=b+44|0;F=c[z>>2]|0;bb=F+8|0;if((c[bb>>2]|0)!=0){B=F|0;F=0;do{yt(c[(c[B>>2]|0)+(F*12|0)>>2]|0);F=F+1|0;}while(F>>>0<(c[bb>>2]|0)>>>0)}c[bb>>2]=0;F=c[z>>2]|0;do{if((F|0)!=0){B=F+8|0;D=F+4|0;A=c[D>>2]|0;if((c[B>>2]|0)>>>0<A>>>0){b8=F|0}else{a9=(A<<1)+2|0;c[D>>2]=a9;D=F|0;c[D>>2]=yu(c[D>>2]|0,a9*12|0)|0;b8=D}D=dW(16024)|0;c[(c[b8>>2]|0)+((c[B>>2]|0)*12|0)>>2]=D;c[(c[b8>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=29;c[(c[b8>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[z>>2]|0;if((B|0)==0){break}D=B+8|0;a9=B+4|0;A=c[a9>>2]|0;if((c[D>>2]|0)>>>0<A>>>0){b9=B|0}else{C=(A<<1)+2|0;c[a9>>2]=C;a9=B|0;c[a9>>2]=yu(c[a9>>2]|0,C*12|0)|0;b9=a9}a9=dW(15888)|0;c[(c[b9>>2]|0)+((c[D>>2]|0)*12|0)>>2]=a9;c[(c[b9>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=27;c[(c[b9>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[z>>2]|0;if((D|0)==0){break}a9=D+8|0;C=D+4|0;B=c[C>>2]|0;if((c[a9>>2]|0)>>>0<B>>>0){ca=D|0}else{A=(B<<1)+2|0;c[C>>2]=A;C=D|0;c[C>>2]=yu(c[C>>2]|0,A*12|0)|0;ca=C}C=dW(15728)|0;c[(c[ca>>2]|0)+((c[a9>>2]|0)*12|0)>>2]=C;c[(c[ca>>2]|0)+((c[a9>>2]|0)*12|0)+4>>2]=28;c[(c[ca>>2]|0)+((c[a9>>2]|0)*12|0)+8>>2]=0;c[a9>>2]=(c[a9>>2]|0)+1;a9=c[z>>2]|0;if((a9|0)==0){break}C=a9+8|0;A=a9+4|0;D=c[A>>2]|0;if((c[C>>2]|0)>>>0<D>>>0){cb=a9|0}else{B=(D<<1)+2|0;c[A>>2]=B;A=a9|0;c[A>>2]=yu(c[A>>2]|0,B*12|0)|0;cb=A}A=dW(15592)|0;c[(c[cb>>2]|0)+((c[C>>2]|0)*12|0)>>2]=A;c[(c[cb>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=30;c[(c[cb>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1}}while(0);F=b+4252|0;if((c[F>>2]|0)==0){break L601}else{cc=0}do{b5(y|0,64,15392,($=i,i=i+8|0,c[$>>2]=cc,$)|0)|0;i=$;bb=c[z>>2]|0;C=cc*3|0;A=C+31|0;if((bb|0)!=0){B=bb+8|0;a9=bb+4|0;D=c[a9>>2]|0;if((c[B>>2]|0)>>>0<D>>>0){cd=bb|0}else{ba=(D<<1)+2|0;c[a9>>2]=ba;a9=bb|0;c[a9>>2]=yu(c[a9>>2]|0,ba*12|0)|0;cd=a9}a9=dW(y|0)|0;c[(c[cd>>2]|0)+((c[B>>2]|0)*12|0)>>2]=a9;c[(c[cd>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=A;c[(c[cd>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1}b5(y|0,64,15176,($=i,i=i+8|0,c[$>>2]=cc,$)|0)|0;i=$;B=c[z>>2]|0;A=C+32|0;if((B|0)!=0){a9=B+8|0;ba=B+4|0;bb=c[ba>>2]|0;if((c[a9>>2]|0)>>>0<bb>>>0){ce=B|0}else{D=(bb<<1)+2|0;c[ba>>2]=D;ba=B|0;c[ba>>2]=yu(c[ba>>2]|0,D*12|0)|0;ce=ba}ba=dW(y|0)|0;c[(c[ce>>2]|0)+((c[a9>>2]|0)*12|0)>>2]=ba;c[(c[ce>>2]|0)+((c[a9>>2]|0)*12|0)+4>>2]=A;c[(c[ce>>2]|0)+((c[a9>>2]|0)*12|0)+8>>2]=0;c[a9>>2]=(c[a9>>2]|0)+1}b5(y|0,64,14888,($=i,i=i+8|0,c[$>>2]=cc,$)|0)|0;i=$;a9=c[z>>2]|0;A=C+33|0;if((a9|0)!=0){C=a9+8|0;ba=a9+4|0;D=c[ba>>2]|0;if((c[C>>2]|0)>>>0<D>>>0){cf=a9|0}else{B=(D<<1)+2|0;c[ba>>2]=B;ba=a9|0;c[ba>>2]=yu(c[ba>>2]|0,B*12|0)|0;cf=ba}ba=dW(y|0)|0;c[(c[cf>>2]|0)+((c[C>>2]|0)*12|0)>>2]=ba;c[(c[cf>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=A;c[(c[cf>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1}cc=cc+1|0;}while(cc>>>0<(c[F>>2]|0)>>>0);break};default:{jh(b);break L601}}}}while(0);jl(b);aR=0;i=f;return aR|0}function jk(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;if((a[405432]&1)!=0){g=c[140620]|0;h=(g|0)!=0?g:c[t>>2]|0;g=(e|0)!=0?e:18008;eS(h|0,18200,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;h=c[140620]|0;g=(h|0)!=0?h:c[t>>2]|0;a7(g|0)|0}if(!(ga[c[(c[140913]|0)+20>>2]&127](c[140916]|0,d,e)|0)){d=c[140620]|0;g=(d|0)!=0?d:c[t>>2]|0;be(17712,46,1,g|0)|0;g=c[140620]|0;d=(g|0)!=0?g:c[t>>2]|0;a7(d|0)|0;a[307236]=0;i=f;return}d=(e|0)!=0;g=4096;h=303140;j=d?e:564064;while(1){k=g-1|0;if((k|0)==0){l=756;break}m=a[j]|0;a[h]=m;if(m<<24>>24==0){break}else{g=k;h=h+1|0;j=j+1|0}}do{if((l|0)==756){a[h]=0;if((a[j]|0)==0){break}else{n=j}do{n=n+1|0;}while((a[n]|0)!=0)}}while(0);a[307236]=1;if((b|0)==0|d^1){i=f;return}d=hC(e,0)|0;if((d|0)!=0){iX(d,b)|0;i$(b,e);hA(d)}a[(c[21160]|0)+52|0]=1;i=f;return}function jl(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0.0,aO=0.0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0;e=i;i=i+1480|0;f=e|0;j=e+256|0;k=e+512|0;l=e+576|0;m=e+832|0;n=e+1088|0;o=e+1160|0;p=e+1416|0;do{if((a[d+52|0]&1)!=0){q=562472;if((c[q>>2]&4|0)==0&(c[q+4>>2]&0|0)==0){break}if((a[d+53|0]&1)!=0){break}i=e;return}}while(0);q=d+48|0;r=c[q>>2]|0;s=r+17|0;t=d+44|0;u=c[(c[t>>2]|0)+8>>2]|0;v=s>>>0>u>>>0?u:s;s=u>>>0>17?r>>>0<8?0:r-8|0:0;r=(v-s|0)>>>0>17?s+17|0:v;v=d+28|0;u=c[v>>2]|0;w=d+32|0;x=(c[w>>2]|0)>>>1;y=0;do{z=ag(y,x)|0;A=y>>>1;B=0;do{C=((B>>>1)+A&1)+1|0;b[u+(B+z<<1)>>1]=(C<<9|C<<13|C<<5|12)&65535;B=B+1|0;}while(B>>>0<320);y=y+1|0;}while(y>>>0<240);y=c[v>>2]|0;u=(c[w>>2]|0)>>>1;x=u*5|0;B=5;do{z=(B>>>1&1)+1|0;b[y+(B+x<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=u*6|0;x=5;do{z=2-(x>>>1&1)|0;b[y+(x+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=u*7|0;B=5;do{z=2-(B>>>1&1)|0;b[y+(B+x<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=u<<3;x=5;do{z=(x>>>1&1)+1|0;b[y+(x+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=u*9|0;u=5;do{B=(u>>>1&1)+1|0;b[y+(u+x<<1)>>1]=(B<<10|B<<13|B<<5|12)&65535;u=u+1|0;}while(u>>>0<315);u=c[v>>2]|0;x=(c[w>>2]|0)>>>1;y=x*230|0;B=5;do{z=2-(B>>>1&1)|0;b[u+(B+y<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=x*231|0;y=5;do{z=2-(y>>>1&1)|0;b[u+(y+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;y=y+1|0;}while(y>>>0<315);y=x*232|0;B=5;do{z=(B>>>1&1)+1|0;b[u+(B+y<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=x*233|0;y=5;do{z=(y>>>1&1)+1|0;b[u+(y+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;y=y+1|0;}while(y>>>0<315);y=x*234|0;x=5;do{B=2-(x>>>1&1)|0;b[u+(x+y<<1)>>1]=(B<<10|B<<13|B<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=c[v>>2]|0;y=(c[w>>2]|0)>>>1;u=5;do{B=ag(u,y)|0;z=u>>>1&1;A=z+1|0;C=(A<<10|A<<13|A<<5|12)&65535;b[x+(B+5<<1)>>1]=C;A=2-z|0;z=(A<<10|A<<13|A<<5|12)&65535;b[x+(B+6<<1)>>1]=z;b[x+(B+7<<1)>>1]=z;b[x+(B+8<<1)>>1]=C;b[x+(B+9<<1)>>1]=C;u=u+1|0;}while(u>>>0<235);u=c[v>>2]|0;v=(c[w>>2]|0)>>>1;w=5;do{x=ag(w,v)|0;y=w>>>1&1;C=2-y|0;B=(C<<10|C<<13|C<<5|12)&65535;b[u+(x+310<<1)>>1]=B;b[u+(x+311<<1)>>1]=B;C=y+1|0;y=(C<<10|C<<13|C<<5|12)&65535;b[u+(x+312<<1)>>1]=y;b[u+(x+313<<1)>>1]=y;b[u+(x+314<<1)>>1]=B;w=w+1|0;}while(w>>>0<235);w=c[d+40>>2]|0;u=c[w+8>>2]|0;L1056:do{if((u|0)==0){D=0;E=0;F=802}else{v=u-1|0;B=c[w>>2]|0;x=c[B+(v*12|0)>>2]|0;y=c[B+(v*12|0)+4>>2]|0;switch(y|0){case 5:{a[f|0]=86;a[f+1|0]=73;a[f+2|0]=68;a[f+3|0]=69;a[f+4|0]=79;a[f+5|0]=32;a[f+6|0]=79;a[f+7|0]=80;a[f+8|0]=84;a[f+9|0]=73;a[f+10|0]=79;a[f+11|0]=78;a[f+12|0]=83;a[f+13|0]=0;G=5;break L1056;break};case 26:{a[f|0]=83;a[f+1|0]=72;a[f+2|0]=65;a[f+3|0]=68;a[f+4|0]=69;a[f+5|0]=82;a[f+6|0]=32;a[f+7|0]=79;a[f+8|0]=80;a[f+9|0]=84;a[f+10|0]=73;a[f+11|0]=79;a[f+12|0]=78;a[f+13|0]=83;a[f+14|0]=0;G=26;break L1056;break};case 59:{a[f|0]=65;a[f+1|0]=85;a[f+2|0]=68;a[f+3|0]=73;a[f+4|0]=79;a[f+5|0]=32;a[f+6|0]=79;a[f+7|0]=80;a[f+8|0]=84;a[f+9|0]=73;a[f+10|0]=79;a[f+11|0]=78;a[f+12|0]=83;a[f+13|0]=0;G=59;break L1056;break};case 69:{a[f|0]=68;a[f+1|0]=73;a[f+2|0]=83;a[f+3|0]=75;a[f+4|0]=32;a[f+5|0]=79;a[f+6|0]=80;a[f+7|0]=84;a[f+8|0]=73;a[f+9|0]=79;a[f+10|0]=78;a[f+11|0]=83;a[f+12|0]=0;G=69;break L1056;break};case 58:{a[f|0]=67;a[f+1|0]=79;a[f+2|0]=82;a[f+3|0]=69;a[f+4|0]=32;a[f+5|0]=79;a[f+6|0]=80;a[f+7|0]=84;a[f+8|0]=73;a[f+9|0]=79;a[f+10|0]=78;a[f+11|0]=83;a[f+12|0]=0;G=58;break L1056;break};case 57:{b5(f|0,256,29824,(H=i,i=i+8|0,c[H>>2]=x,H)|0)|0;i=H;G=57;break L1056;break};case 71:{b5(f|0,256,25296,(H=i,i=i+8|0,c[H>>2]=x,H)|0)|0;i=H;G=71;break L1056;break};default:{D=x;E=y;F=802;break L1056}}}}while(0);L1066:do{if((F|0)==802){w=E-31|0;if(w>>>0<24&((w>>>0)%3|0|0)==0|(E|0)==28){w=f|0;b5(w|0,256,54696,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;G=E;break}if((E-60|0)>>>0<3|(E|0)==12|(E|0)==13|(E|0)==4){w=f|0;b5(w|0,256,51944,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;G=E;break}switch(E|0){case 56:{a[f|0]=76;a[f+1|0]=79;a[f+2|0]=65;a[f+3|0]=68;a[f+4|0]=32;a[f+5|0]=72;a[f+6|0]=73;a[f+7|0]=83;a[f+8|0]=84;a[f+9|0]=79;a[f+10|0]=82;a[f+11|0]=89;a[f+12|0]=0;G=56;break L1066;break};case 88:{b5(f|0,256,47624,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;G=88;break L1066;break};case 73:{b5(f|0,256,46584,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;G=73;break L1066;break};case 74:{b5(f|0,256,45184,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;G=74;break L1066;break};case 75:{b5(f|0,256,43656,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;G=75;break L1066;break};case 76:{b5(f|0,256,42496,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;G=76;break L1066;break};case 78:{b5(f|0,256,41496,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;G=78;break L1066;break};case 79:{b5(f|0,256,40472,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;G=79;break L1066;break};default:{w=c[d+4160>>2]|0;u=(w|0)==0?c[124930]|0:w;b5(f|0,256,38136,(H=i,i=i+16|0,c[H>>2]=(u|0)==0?39448:u,c[H+8>>2]=D,H)|0)|0;i=H;G=E;break L1066}}}}while(0);E=j|0;jg(E,45,((c[140560]|0)>>>0)/15|0,f|0,1);jm(d,30,15,E,1);E=c[d+4160>>2]|0;f=(E|0)==0?c[124930]|0:E;E=c[d+4164>>2]|0;j=(E|0)==0?c[124931]|0:E;E=k|0;b5(E|0,64,36424,(H=i,i=i+24|0,c[H>>2]=35064,c[H+8>>2]=(f|0)==0?39448:f,c[H+16>>2]=(j|0)==0?564064:j,H)|0)|0;i=H;jm(d,30,216,E,1);if(s>>>0>=r>>>0){i=e;return}E=d+113708|0;j=m|0;f=o|0;o=p|0;p=l|0;l=n+8|0;k=n|0;D=n;u=(G|0)==60?24:(G|0)==61?24:19;w=G-31|0;y=w>>>0<24&((w>>>0)%3|0|0)==0|(G|0)==28;w=m+1|0;x=m+2|0;v=m+3|0;B=m+4|0;C=m+5|0;z=m+6|0;A=m+7|0;I=m+8|0;J=m+9|0;L=m+10|0;M=d+4252|0;N=(G-73|0)>>>0<4|(G|0)==78|(G|0)==79;O=(G|0)==56;P=m+11|0;Q=m+12|0;R=m+13|0;S=m+14|0;T=m+15|0;U=m+16|0;V=m+17|0;X=m+18|0;m=n+9|0;Y=n+10|0;Z=n+11|0;_=n+12|0;$=n+13|0;aa=n+14|0;ab=n+15|0;n=s;s=27;while(1){ac=c[c[t>>2]>>2]|0;ad=c[ac+(n*12|0)>>2]|0;ae=c[ac+(n*12|0)+4>>2]|0;ac=c[E>>2]|0;L1090:do{if((ae-27|0)>>>0<28){do{if(y){af=ae-31|0;if(!(af>>>0<24&((af>>>0)%3|0|0)==0|(ae|0)==28)){break}a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break L1090}}while(0);if((ae|0)==28){a[j]=46;a[w]=46;a[x]=46;a[v]=0;ah=u;ai=28;break}else if((ae|0)==27){b5(j|0,256,32576,(H=i,i=i+8|0,c[H>>2]=(a[303124]&1)!=0?31888:31480,H)|0)|0;i=H;ah=u;ai=27;break}else if((ae|0)==29){a[j]=0;ah=u;ai=29;break}else if((ae|0)==30){b5(j|0,256,53064,(H=i,i=i+8|0,c[H>>2]=c[M>>2],H)|0)|0;i=H;ah=u;ai=30;break}else{af=ae-31|0;aj=(af>>>0)/3|0;ak=(af>>>0)%3|0;if((ak|0)==0){af=d+4256+(aj*4148|0)|0;if((a[af]|0)==0){a[j]=78;a[w]=47;a[x]=65;a[v]=0;ah=u;ai=ae;break}else{hu(j,af,256);ah=u;ai=ae;break}}else if((ak|0)==1){af=c[d+4256+(aj*4148|0)+4136>>2]|0;if((af|0)==1){a[j]=76;a[w]=105;a[x]=110;a[v]=101;a[B]=97;a[C]=114;a[z]=0;ah=u;ai=ae;break}else if((af|0)==2){a[j]=78;a[w]=101;a[x]=97;a[v]=114;a[B]=101;a[C]=115;a[z]=116;a[A]=0;ah=u;ai=ae;break}else if((af|0)==0){a[j]=68;a[w]=111;a[x]=110;a[v]=39;a[B]=116;a[C]=32;a[z]=99;a[A]=97;a[I]=114;a[J]=101;a[L]=0;ah=u;ai=ae;break}else{ah=u;ai=ae;break}}else if((ak|0)==2){ak=~~+g[d+4256+(aj*4148|0)+4116>>2];if((ak|0)==0){a[j]=68;a[w]=111;a[x]=110;a[v]=39;a[B]=116;a[C]=32;a[z]=99;a[A]=97;a[I]=114;a[J]=101;a[L]=0;ah=u;ai=ae;break}else{b5(j|0,256,51952,(H=i,i=i+8|0,c[H>>2]=ak,H)|0)|0;i=H;ah=u;ai=ae;break}}else{ah=u;ai=ae;break}}}else{do{if(!((G|0)==88|(G|0)==71|(G|0)==57)){if(N){break}if(O){a[j]=0;ah=0;ai=ae;break L1090}if(ae>>>0>65535){ak=ae-65536|0;aj=c[(c[126128]|0)+4100>>2]|0;af=256;al=j;am=c[(c[c[aj+(ak<<4)+8>>2]>>2]|0)+(c[aj+(ak<<4)+12>>2]<<3)>>2]|0;while(1){ak=af-1|0;if((ak|0)==0){break}aj=a[am]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=ae;break L1090}else{af=ak;al=al+1|0;am=am+1|0}}a[al]=0;if((a[am]|0)==0){ah=u;ai=ae;break L1090}else{an=am}while(1){af=an+1|0;if((a[af]|0)==0){ah=u;ai=ae;break L1090}else{an=af}}}switch(ae|0){case 89:{b5(j|0,256,24592,(H=i,i=i+8|0,h[H>>3]=+g[92124],H)|0)|0;i=H;ah=u;ai=89;break L1090;break};case 90:{b5(j|0,256,24592,(H=i,i=i+8|0,h[H>>3]=+g[92125],H)|0)|0;i=H;ah=u;ai=90;break L1090;break};case 91:{b5(j|0,256,24328,(H=i,i=i+8|0,c[H>>2]=ac+1,H)|0)|0;i=H;ah=u;ai=91;break L1090;break};case 92:{am=c[363780+(ac<<2)>>2]|0;if(am>>>0>=8){a[j]=68;a[w]=105;a[x]=115;a[v]=97;a[B]=98;a[C]=108;a[z]=101;a[A]=100;a[I]=0;ah=u;ai=92;break L1090}al=363844+(am<<6)|0;if((a[al]|0)==0){b5(j|0,256,24016,(H=i,i=i+8|0,c[H>>2]=am,H)|0)|0;i=H;ah=u;ai=92;break L1090}else{ao=256;ap=j;aq=al}while(1){al=ao-1|0;if((al|0)==0){break}am=a[aq]|0;a[ap]=am;if(am<<24>>24==0){ah=u;ai=92;break L1090}else{ao=al;ap=ap+1|0;aq=aq+1|0}}a[ap]=0;if((a[aq]|0)==0){ah=u;ai=92;break L1090}else{ar=aq}while(1){al=ar+1|0;if((a[al]|0)==0){ah=u;ai=92;break L1090}else{ar=al}}break};case 93:{switch(c[405436+(ac<<2)>>2]|0){case 1:{as=256;at=j;au=23216;break};case 5:{as=256;at=j;au=22904;break};case 257:{as=256;at=j;au=22752;break};case 2:{as=256;at=j;au=22200;break};case 516:{as=256;at=j;au=21600;break};case 772:{as=256;at=j;au=21200;break};case 260:{as=256;at=j;au=20704;break};case 0:{as=256;at=j;au=23448;break};default:{as=256;at=j;au=20544}}while(1){al=as-1|0;if((al|0)==0){break}am=a[au]|0;a[at]=am;if(am<<24>>24==0){ah=u;ai=93;break L1090}else{as=al;at=at+1|0;au=au+1|0}}a[at]=0;if((a[au]|0)==0){ah=u;ai=93;break L1090}else{av=au}while(1){al=av+1|0;if((a[al]|0)==0){ah=u;ai=93;break L1090}else{av=al}}break};case 94:{al=c[364356+(ac<<2)>>2]|0;if((al|0)==2){a[j]=82;a[w]=105;a[x]=103;a[v]=104;a[B]=116;a[C]=32;a[z]=83;a[A]=116;a[I]=105;a[J]=99;a[L]=107;a[P]=0;ah=u;ai=94;break L1090}else if((al|0)==3){a[j]=68;a[w]=117;a[x]=97;a[v]=108;a[B]=32;a[C]=65;a[z]=110;a[A]=97;a[I]=108;a[J]=111;a[L]=103;a[P]=0;ah=u;ai=94;break L1090}else if((al|0)==1){a[j]=76;a[w]=101;a[x]=102;a[v]=116;a[B]=32;a[C]=83;a[z]=116;a[A]=105;a[I]=99;a[J]=107;a[L]=0;ah=u;ai=94;break L1090}else if((al|0)==0){a[j]=78;a[w]=111;a[x]=110;a[v]=101;a[B]=0;ah=u;ai=94;break L1090}else{ah=u;ai=94;break L1090}break};case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:case 108:case 109:case 110:{al=c[1552+(ae-95<<2)>>2]|0;a[l]=85;a[m]=110;a[Y]=107;a[Z]=110;a[_]=111;a[$]=119;a[aa]=110;a[ab]=0;am=327928+(ac*2240|0)+(al*40|0)+16|0;al=c[am+4>>2]|0;c[k>>2]=c[am>>2];c[k+4>>2]=al;al=c[(c[140914]|0)+20>>2]|0;if((al|0)==0){aw=256;ax=j;ay=l}else{f1[al&15](D,0,0,0,256);aw=256;ax=j;ay=l}while(1){al=aw-1|0;if((al|0)==0){break}am=a[ay]|0;a[ax]=am;if(am<<24>>24==0){ah=u;ai=ae;break L1090}else{aw=al;ax=ax+1|0;ay=ay+1|0}}a[ax]=0;if((a[ay]|0)==0){ah=u;ai=ae;break L1090}else{az=ay}while(1){al=az+1|0;if((a[al]|0)==0){ah=u;ai=ae;break L1090}else{az=al}}break};case 55:case 56:case 58:case 12:case 14:case 5:case 59:case 69:case 26:case 28:case 57:case 71:case 60:case 61:case 62:{a[j]=46;a[w]=46;a[x]=46;a[v]=0;ah=u;ai=ae;break L1090;break};case 1:{a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break L1090;break};case 0:{a[j]=40;a[w]=70;a[x]=73;a[v]=76;a[B]=69;a[C]=41;a[z]=0;ah=6;ai=0;break L1090;break};case 88:{al=cE(364400,47)|0;am=256;af=j;ak=(al|0)==0?364400:al+1|0;while(1){al=am-1|0;if((al|0)==0){break}aj=a[ak]|0;a[af]=aj;if(aj<<24>>24==0){ah=u;ai=88;break L1090}else{am=al;af=af+1|0;ak=ak+1|0}}a[af]=0;if((a[ak]|0)==0){ah=u;ai=88;break L1090}else{aA=ak}while(1){am=aA+1|0;if((a[am]|0)==0){ah=u;ai=88;break L1090}else{aA=am}}break};case 15:{ak=256;af=j;am=1320+(c[140611]<<5)|0;while(1){al=ak-1|0;if((al|0)==0){break}aj=a[am]|0;a[af]=aj;if(aj<<24>>24==0){ah=u;ai=15;break L1090}else{ak=al;af=af+1|0;am=am+1|0}}a[af]=0;if((a[am]|0)==0){ah=u;ai=15;break L1090}else{aB=am}while(1){ak=aB+1|0;if((a[ak]|0)==0){ah=u;ai=15;break L1090}else{aB=ak}}break};case 8:{am=562472;b5(j|0,256,((c[am>>2]&65536|0)!=0|(c[am+4>>2]&0|0)!=0?30720:30184)|0,(H=i,i=i+1|0,i=i+7>>3<<3,c[H>>2]=0,H)|0)|0;i=H;ah=u;ai=8;break L1090;break};case 7:{if((a[303124]&1)==0){a[j]=80;a[w]=111;a[x]=105;a[v]=110;a[B]=116;a[C]=32;a[z]=102;a[A]=105;a[I]=108;a[J]=116;a[L]=101;a[P]=114;a[Q]=105;a[R]=110;a[S]=103;a[T]=0;ah=u;ai=7;break L1090}else{a[j]=66;a[w]=105;a[x]=108;a[v]=105;a[B]=110;a[C]=101;a[z]=97;a[A]=114;a[I]=32;a[J]=102;a[L]=105;a[P]=108;a[Q]=116;a[R]=101;a[S]=114;a[T]=105;a[U]=110;a[V]=103;a[X]=0;ah=u;ai=7;break L1090}break};case 9:{b5(j|0,256,11016,(H=i,i=i+8|0,c[H>>2]=c[140612],H)|0)|0;i=H;ah=u;ai=9;break L1090;break};case 16:{am=256;af=j;ak=(a[303112]&1)!=0?30720:30184;while(1){al=am-1|0;if((al|0)==0){break}aj=a[ak]|0;a[af]=aj;if(aj<<24>>24==0){ah=u;ai=16;break L1090}else{am=al;af=af+1|0;ak=ak+1|0}}a[af]=0;if((a[ak]|0)==0){ah=u;ai=16;break L1090}else{aC=ak}while(1){am=aC+1|0;if((a[am]|0)==0){ah=u;ai=16;break L1090}else{aC=am}}break};case 17:{ak=256;af=j;am=(a[303113]&1)!=0?30720:30184;while(1){al=ak-1|0;if((al|0)==0){break}aj=a[am]|0;a[af]=aj;if(aj<<24>>24==0){ah=u;ai=17;break L1090}else{ak=al;af=af+1|0;am=am+1|0}}a[af]=0;if((a[am]|0)==0){ah=u;ai=17;break L1090}else{aD=am}while(1){ak=aD+1|0;if((a[ak]|0)==0){ah=u;ai=17;break L1090}else{aD=ak}}break};case 19:{am=256;af=j;ak=(a[303114]&1)!=0?30720:30184;while(1){al=am-1|0;if((al|0)==0){break}aj=a[ak]|0;a[af]=aj;if(aj<<24>>24==0){ah=u;ai=19;break L1090}else{am=al;af=af+1|0;ak=ak+1|0}}a[af]=0;if((a[ak]|0)==0){ah=u;ai=19;break L1090}else{aE=ak}while(1){am=aE+1|0;if((a[am]|0)==0){ah=u;ai=19;break L1090}else{aE=am}}break};case 20:{b5(j|0,256,53064,(H=i,i=i+8|0,c[H>>2]=c[75779],H)|0)|0;i=H;ah=u;ai=20;break L1090;break};case 21:{b5(j|0,256,27840,(H=i,i=i+8|0,h[H>>3]=+g[75772],H)|0)|0;i=H;ah=u;ai=21;break L1090;break};case 22:{b5(j|0,256,27840,(H=i,i=i+8|0,h[H>>3]=+g[75773],H)|0)|0;i=H;ah=u;ai=22;break L1090;break};case 23:{ak=256;af=j;am=(a[303126]&1)!=0?30720:30184;while(1){al=ak-1|0;if((al|0)==0){break}aj=a[am]|0;a[af]=aj;if(aj<<24>>24==0){ah=u;ai=23;break L1090}else{ak=al;af=af+1|0;am=am+1|0}}a[af]=0;if((a[am]|0)==0){ah=u;ai=23;break L1090}else{aF=am}while(1){ak=aF+1|0;if((a[ak]|0)==0){ah=u;ai=23;break L1090}else{aF=ak}}break};case 18:{b5(j|0,256,53064,(H=i,i=i+8|0,c[H>>2]=c[75780],H)|0)|0;i=H;ah=u;ai=18;break L1090;break};case 24:{do{if((a[311340]&1)==0){am=553784;af=c[am>>2]|0;ak=c[am+4>>2]|0;am=0;al=ak>>>0>am>>>0|ak>>>0==am>>>0&af>>>0>2048>>>0?2048:af;if(al>>>0<2){break}else{aG=0;aH=0;aI=0}do{af=537400+(aG<<3)|0;aI=yL(c[af>>2]|0,c[af+4>>2]|0,aI,aH)|0;aH=K;aG=aG+1|0;}while(aG>>>0<al>>>0);af=yT(aI,aH,al,0)|0;am=K;ak=0;aj=0;aJ=0;do{aK=537400+(aJ<<3)|0;aL=yM(c[aK>>2]|0,c[aK+4>>2]|0,af,am)|0;aK=K;aM=yV(aL,aK,aL,aK)|0;aj=yL(aM,K,aj,ak)|0;ak=K;aJ=aJ+1|0;}while(aJ>>>0<al>>>0);aN=+(af>>>0)+ +(am|0)*4294967296.0;aO=+W(+((+(aj>>>0)+ +(ak|0)*4294967296.0)/+((al-1|0)>>>0>>>0)))/aN*100.0;b5(j|0,256,27384,(H=i,i=i+24|0,h[H>>3]=1.0e6/aN,h[H+8>>3]=aO,c[H+16>>2]=al,H)|0)|0;i=H;ah=u;ai=24;break L1090}}while(0);a[j]=78;a[w]=47;a[x]=65;a[v]=0;ah=u;ai=24;break L1090;break};case 10:{aJ=256;aM=j;aK=(a[303133]&1)!=0?30720:30184;while(1){aL=aJ-1|0;if((aL|0)==0){break}aP=a[aK]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=10;break L1090}else{aJ=aL;aM=aM+1|0;aK=aK+1|0}}a[aM]=0;if((a[aK]|0)==0){ah=u;ai=10;break L1090}else{aQ=aK}while(1){aJ=aQ+1|0;if((a[aJ]|0)==0){ah=u;ai=10;break L1090}else{aQ=aJ}}break};case 11:{aK=256;aM=j;aJ=10304+((c[75784]|0)*68|0)|0;while(1){aL=aK-1|0;if((aL|0)==0){break}aP=a[aJ]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=11;break L1090}else{aK=aL;aM=aM+1|0;aJ=aJ+1|0}}a[aM]=0;if((a[aJ]|0)==0){ah=u;ai=11;break L1090}else{aR=aJ}while(1){aK=aR+1|0;if((a[aK]|0)==0){ah=u;ai=11;break L1090}else{aR=aK}}break};case 63:{aJ=256;aM=j;aK=(a[401276]&1)!=0?30720:30184;while(1){aL=aJ-1|0;if((aL|0)==0){break}aP=a[aK]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=63;break L1090}else{aJ=aL;aM=aM+1|0;aK=aK+1|0}}a[aM]=0;if((a[aK]|0)==0){ah=u;ai=63;break L1090}else{aS=aK}while(1){aJ=aS+1|0;if((a[aJ]|0)==0){ah=u;ai=63;break L1090}else{aS=aJ}}break};case 64:{b5(j|0,256,53064,(H=i,i=i+8|0,c[H>>2]=c[100321],H)|0)|0;i=H;ah=u;ai=64;break L1090;break};case 65:{aK=256;aM=j;aJ=(a[562486]&1)!=0?30720:30184;while(1){aL=aK-1|0;if((aL|0)==0){break}aP=a[aJ]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=65;break L1090}else{aK=aL;aM=aM+1|0;aJ=aJ+1|0}}a[aM]=0;if((a[aJ]|0)==0){ah=u;ai=65;break L1090}else{aT=aJ}while(1){aK=aT+1|0;if((a[aK]|0)==0){ah=u;ai=65;break L1090}else{aT=aK}}break};case 66:{aJ=256;aM=j;aK=(c[100325]|0)!=0?30720:30184;while(1){aL=aJ-1|0;if((aL|0)==0){break}aP=a[aK]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=66;break L1090}else{aJ=aL;aM=aM+1|0;aK=aK+1|0}}a[aM]=0;if((a[aK]|0)==0){ah=u;ai=66;break L1090}else{aU=aK}while(1){aJ=aU+1|0;if((a[aJ]|0)==0){ah=u;ai=66;break L1090}else{aU=aJ}}break};case 67:case 68:{b5(j|0,256,11016,(H=i,i=i+8|0,c[H>>2]=c[124924],H)|0)|0;i=H;ah=u;ai=ae;break L1090;break};case 81:{aK=256;aM=j;aJ=(a[504561]&1)!=0?30720:30184;while(1){aL=aK-1|0;if((aL|0)==0){break}aP=a[aJ]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=81;break L1090}else{aK=aL;aM=aM+1|0;aJ=aJ+1|0}}a[aM]=0;if((a[aJ]|0)==0){ah=u;ai=81;break L1090}else{aV=aJ}while(1){aK=aV+1|0;if((a[aK]|0)==0){ah=u;ai=81;break L1090}else{aV=aK}}break};case 82:{b5(j|0,256,26632,(H=i,i=i+8|0,h[H>>3]=+g[81955],H)|0)|0;i=H;ah=u;ai=82;break L1090;break};case 84:{aJ=562472;b5(j|0,256,((c[aJ>>2]&256|0)!=0|(c[aJ+4>>2]&0|0)!=0?30720:30184)|0,(H=i,i=i+1|0,i=i+7>>3<<3,c[H>>2]=0,H)|0)|0;i=H;ah=u;ai=84;break L1090;break};case 73:{aJ=256;aM=j;aK=(a[401313]|0)!=0?401313:26232;while(1){aL=aJ-1|0;if((aL|0)==0){break}aP=a[aK]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=73;break L1090}else{aJ=aL;aM=aM+1|0;aK=aK+1|0}}a[aM]=0;if((a[aK]|0)==0){ah=u;ai=73;break L1090}else{aW=aK}while(1){aJ=aW+1|0;if((a[aJ]|0)==0){ah=u;ai=73;break L1090}else{aW=aJ}}break};case 76:{aK=256;aM=j;aJ=(a[475114]|0)!=0?475114:25680;while(1){aL=aK-1|0;if((aL|0)==0){break}aP=a[aJ]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=76;break L1090}else{aK=aL;aM=aM+1|0;aJ=aJ+1|0}}a[aM]=0;if((a[aJ]|0)==0){ah=u;ai=76;break L1090}else{aX=aJ}while(1){aK=aX+1|0;if((a[aK]|0)==0){ah=u;ai=76;break L1090}else{aX=aK}}break};case 78:{aJ=256;aM=j;aK=(a[483306]|0)!=0?483306:26232;while(1){aL=aJ-1|0;if((aL|0)==0){break}aP=a[aK]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=78;break L1090}else{aJ=aL;aM=aM+1|0;aK=aK+1|0}}a[aM]=0;if((a[aK]|0)==0){ah=u;ai=78;break L1090}else{aY=aK}while(1){aJ=aY+1|0;if((a[aJ]|0)==0){ah=u;ai=78;break L1090}else{aY=aJ}}break};case 75:{aK=256;aM=j;aJ=(a[479210]|0)!=0?479210:25680;while(1){aL=aK-1|0;if((aL|0)==0){break}aP=a[aJ]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=75;break L1090}else{aK=aL;aM=aM+1|0;aJ=aJ+1|0}}a[aM]=0;if((a[aJ]|0)==0){ah=u;ai=75;break L1090}else{aZ=aJ}while(1){aK=aZ+1|0;if((a[aK]|0)==0){ah=u;ai=75;break L1090}else{aZ=aK}}break};case 74:{aJ=256;aM=j;aK=(a[311341]|0)!=0?311341:26232;while(1){aL=aJ-1|0;if((aL|0)==0){break}aP=a[aK]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=74;break L1090}else{aJ=aL;aM=aM+1|0;aK=aK+1|0}}a[aM]=0;if((a[aK]|0)==0){ah=u;ai=74;break L1090}else{a_=aK}while(1){aJ=a_+1|0;if((a[aJ]|0)==0){ah=u;ai=74;break L1090}else{a_=aJ}}break};case 79:{aK=256;aM=j;aJ=(a[397180]|0)!=0?397180:25680;while(1){aL=aK-1|0;if((aL|0)==0){break}aP=a[aJ]|0;a[aM]=aP;if(aP<<24>>24==0){ah=u;ai=79;break L1090}else{aK=aL;aM=aM+1|0;aJ=aJ+1|0}}a[aM]=0;if((a[aJ]|0)==0){ah=u;ai=79;break L1090}else{a$=aJ}while(1){aK=a$+1|0;if((a[aK]|0)==0){ah=u;ai=79;break L1090}else{a$=aK}}break};case 70:{aJ=gp[c[126108]&31]()|0;aM=gp[c[126106]&31]()|0;if(aM>>>0<aJ>>>0){aJ=aM+1|0;b5(j|0,256,53064,(H=i,i=i+8|0,c[H>>2]=aJ,H)|0)|0;i=H;ah=u;ai=70;break L1090}else{a[j]=78;a[w]=111;a[x]=32;a[v]=68;a[B]=105;a[C]=115;a[z]=107;a[A]=0;ah=u;ai=70;break L1090}break};default:{a[j]=0;ah=0;ai=ae;break L1090}}}}while(0);if((ae|0)==0){a[j]=40;a[w]=70;a[x]=73;a[v]=76;a[B]=69;a[C]=41;a[z]=0;ah=6;ai=0;break}else if((ae|0)==3){a[j]=0;ah=0;ai=3;break}else{a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break}}}while(0);ae=(n|0)==(c[q>>2]|0);ac=256;aJ=f;aM=ad;while(1){aK=ac-1|0;if((aK|0)==0){F=991;break}aL=a[aM]|0;a[aJ]=aL;if(aL<<24>>24==0){a0=64;a1=o;a2=j;break}else{ac=aK;aJ=aJ+1|0;aM=aM+1|0}}do{if((F|0)==991){F=0;a[aJ]=0;if((a[aM]|0)==0){a0=64;a1=o;a2=j;break}else{a3=aM}while(1){ac=a3+1|0;if((a[ac]|0)==0){a0=64;a1=o;a2=j;break}else{a3=ac}}}}while(0);while(1){aM=a0-1|0;if((aM|0)==0){F=995;break}aJ=a[a2]|0;a[a1]=aJ;if(aJ<<24>>24==0){break}else{a0=aM;a1=a1+1|0;a2=a2+1|0}}do{if((F|0)==995){F=0;a[a1]=0;if((a[a2]|0)==0){break}else{a4=a2}do{a4=a4+1|0;}while((a[a4]|0)!=0)}}while(0);if(ai>>>0<2){aM=-3-ah|0;jg(f,aM+48|0,((c[140560]|0)>>>0)/15|0,ad,ae);a5=aM}else{jg(o,ah,((c[140560]|0)>>>0)/15|0,j,ae);a5=-3-ah|0}aM=a5+48|0;b5(p|0,256,20024,(H=i,i=i+48|0,c[H>>2]=ae?62:32,c[H+8>>2]=aM,c[H+16>>2]=aM,c[H+24>>2]=f,c[H+32>>2]=ah,c[H+40>>2]=o,H)|0)|0;i=H;jm(d,15,s,p,ae);aM=n+1|0;if(aM>>>0<r>>>0){n=aM;s=s+11|0}else{break}}i=e;return}function jm(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=a[h]|0;if(j<<24>>24==0){return}k=e+4152|0;l=i?32639:-1;i=e+32|0;m=e+28|0;e=h;h=f;f=j;while(1){j=h+4|0;n=h+3|0;o=h+2|0;p=h+1|0;q=0;r=f;while(1){s=q*5|0;t=q+g|0;u=c[k>>2]|0;if((1<<(s&7)&(d[u+((s>>3)+((r&255)*7|0))|0]|0)|0)==0){v=r;w=u}else{u=(ag((c[i>>2]|0)>>>1,t)|0)+h|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;v=a[e]|0;w=c[k>>2]|0}u=s+1|0;if(((d[w+(((v&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){x=v;y=w}else{u=p+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;x=a[e]|0;y=c[k>>2]|0}u=s+2|0;if(((d[y+(((x&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){z=x;A=y}else{u=o+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;z=a[e]|0;A=c[k>>2]|0}u=s+3|0;if(((d[A+(((z&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){B=z;C=A}else{u=n+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;B=a[e]|0;C=c[k>>2]|0}u=s+4|0;if(((d[C+(((B&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)!=0){u=j+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l}u=q+1|0;if((u|0)>=10){break}q=u;r=a[e]|0}r=e+1|0;q=a[r]|0;if(q<<24>>24==0){break}else{e=r;h=h+6|0;f=q}}return}function jn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+16|0;f=e|0;g=a+4|0;h=c[g>>2]|0;L1390:do{if((h|0)==0){j=0}else{k=a|0;l=c[k>>2]|0;L1392:do{if((b|0)==0){m=0;while(1){do{if((c[l+(m*12|0)>>2]|0)==0){if((db(c[l+(m*12|0)+4>>2]|0,380796)|0)!=0){break}if((db(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L1392}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L1390}}}else{m=0;while(1){o=c[l+(m*12|0)>>2]|0;do{if((o|0)!=0){if((db(b|0,o|0)|0)!=0){break}if((db(c[l+(m*12|0)+4>>2]|0,380796)|0)!=0){break}if((db(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L1392}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L1390}}}}while(0);if((n|0)==0){i=e;return}m=f;o=l+(n*12|0)|0;c[m>>2]=c[o>>2];c[m+4>>2]=c[o+4>>2];c[m+8>>2]=c[o+8>>2];yI(l+12|0,l|0,n*12|0|0);o=c[k>>2]|0;c[o>>2]=c[m>>2];c[o+4>>2]=c[m+4>>2];c[o+8>>2]=c[m+8>>2];i=e;return}}while(0);n=a+8|0;f=c[n>>2]|0;if((j|0)==(f|0)){h=j-1|0;j=a|0;m=c[j>>2]|0;o=m+(h*12|0)|0;yt(c[o>>2]|0);yt(c[m+(h*12|0)+4>>2]|0);yt(c[m+(h*12|0)+8>>2]|0);yB(o|0,0,12);c[g>>2]=(c[g>>2]|0)-1;p=c[n>>2]|0;q=j}else{p=f;q=a|0}a=c[q>>2]|0;yI(a+12|0,a|0,(p*12|0)-12|0);if((b|0)==0){r=0}else{r=dW(b|0)|0}c[c[q>>2]>>2]=r;r=dW(380796)|0;c[(c[q>>2]|0)+4>>2]=r;r=dW(d|0)|0;c[(c[q>>2]|0)+8>>2]=r;c[g>>2]=(c[g>>2]|0)+1;i=e;return}function jo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;if((a|0)==0){i=b;return}d=a+12|0;e=c[d>>2]|0;do{if((e|0)!=0){f=dA(e|0,76e3)|0;if((f|0)==0){break}g=a+4|0;if((c[g>>2]|0)!=0){h=a|0;j=0;do{k=c[h>>2]|0;l=c[k+(j*12|0)>>2]|0;m=c[k+(j*12|0)+4>>2]|0;n=c[k+(j*12|0)+8>>2]|0;eS(f|0,37184,(k=i,i=i+24|0,c[k>>2]=(l|0)==0?564064:l,c[k+8>>2]=m,c[k+16>>2]=n,k)|0)|0;i=k;j=j+1|0;}while(j>>>0<(c[g>>2]|0)>>>0)}a_(f|0)|0}}while(0);yt(c[d>>2]|0);d=a+8|0;e=a|0;g=c[e>>2]|0;if((c[d>>2]|0)==0){o=g}else{j=0;h=g;while(1){g=h+(j*12|0)|0;yt(c[g>>2]|0);yt(c[h+(j*12|0)+4>>2]|0);yt(c[h+(j*12|0)+8>>2]|0);yB(g|0,0,12);g=j+1|0;k=c[e>>2]|0;if(g>>>0<(c[d>>2]|0)>>>0){j=g;h=k}else{o=k;break}}}yt(o);yt(a);i=b;return}function jp(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+72|0;h=f|0;j=f+8|0;k=f+40|0;l=b+4|0;m=c[l>>2]|0;if((m|0)==0){i=f;return}if((gp[c[m+16>>2]&31]()|0)==0){i=f;return}m=j|0;a[m]=0;n=c[l>>2]|0;do{if((n|0)==0){o=1086}else{f3[c[n+28>>2]&1023](1,j);p=c[l>>2]|0;if((p|0)==0){o=1086;break}q=gp[c[p+16>>2]&31]()|0;p=c[l>>2]|0;r=k|0;a[r]=0;if((p|0)==0){s=0;u=r;break}f3[c[p+28>>2]&1023](q,k);q=c[l>>2]|0;if((q|0)==0){s=0;u=r;break}do{if((gp[c[q+16>>2]&31]()|0)==1){if((a[m]&1)!=0){break}i=f;return}}while(0);q=c[l>>2]|0;if((q|0)==0){s=0;u=r;break}s=gp[c[q+16>>2]&31]()|0;u=r}}while(0);if((o|0)==1086){n=k|0;a[n]=0;s=0;u=n}n=s-1|0;k=b+1636|0;c[k>>2]=n;if((a[u]&1)==0){v=n}else{c[k>>2]=s;v=s}if((a[m]&1)==0){g[j+12>>2]=1.0;g[j+16>>2]=1.0;c[j+8>>2]=0;c[j+4>>2]=0;a[m]=1}j=b+1124|0;s=j;yE(j|0,m|0,32)|0;if((v|0)>1){v=1;while(1){m=v+1|0;j=s+(v<<5)|0;n=j|0;a[n]=0;u=c[l>>2]|0;if((u|0)==0){o=1101}else{f3[c[u+28>>2]&1023](m,j);if((a[n]&1)==0){o=1101}}if((o|0)==1101){o=0;g[s+(v<<5)+16>>2]=1.0;g[s+(v<<5)+12>>2]=1.0;c[s+(v<<5)+8>>2]=0;c[s+(v<<5)+4>>2]=0;a[n]=1}if((m|0)<(c[k>>2]|0)){v=m}else{break}}}jq(b,d,e,c[b+1728>>2]|0,c[b+1732>>2]|0);e=c[k>>2]|0;if((e|0)>0){d=b+740|0;v=0;while(1){m=(c[d+(v*24|0)>>2]|0)-1|0;n=m>>>1|m;m=n>>>2|n;n=m>>>4|m;m=n>>>8|n;n=(m>>>16|m)+1|0;c[d+(v*24|0)+16>>2]=n;m=(c[d+(v*24|0)+4>>2]|0)-1|0;j=m>>>1|m;m=j>>>2|j;j=m>>>4|m;m=j>>>8|j;j=(m>>>16|m)+1|0;c[d+(v*24|0)+20>>2]=j;if((a[405432]&1)!=0){m=c[140620]|0;u=(m|0)!=0?m:c[t>>2]|0;eS(u|0,43024,(w=i,i=i+24|0,c[w>>2]=v,c[w+8>>2]=n,c[w+16>>2]=j,w)|0)|0;i=w;j=c[140620]|0;n=(j|0)!=0?j:c[t>>2]|0;a7(n|0)|0}n=v+1|0;j=c[k>>2]|0;if((n|0)<(j|0)){v=n}else{x=j;break}}}else{x=e}e=b+676|0;v=e;d=e;bM(x|0,d|0);x=(a[303124]&1)!=0?9729:9728;if((c[k>>2]|0)>0){e=b+740|0;j=b+2584|0;n=0;do{a6(3553,c[v+(n<<2)>>2]|0);a[h]=0;u=c[l>>2]|0;do{if((u|0)==0){y=33071;z=x}else{m=n+2|0;if(gm[c[u+20>>2]&127](m,h)|0){A=(a[h]&1)!=0?9729:9728}else{A=x}q=c[l>>2]|0;if((q|0)==0){y=33071;z=A;break}p=f5[c[q+24>>2]&255](m)|0;if((p|0)==2){y=10497;z=A;break}else if((p|0)==3){y=33648;z=A;break}else if((p|0)==0|(p|0)==1){y=33071;z=A;break}else{y=0;z=A;break}}}while(0);fL(3553,10240,z|0);fL(3553,10241,z|0);fL(3553,10242,y|0);fL(3553,10243,y|0);do{if((a[s+(n<<5)|0]&1)==0){o=1129}else{if((a[s+(n<<5)+28|0]&1)==0){o=1129;break}do{if((a[j]&1)==0){u=bd(7939)|0;if((u|0)==0){B=0;break}B=(bJ(u|0,23416)|0)!=0}else{B=0}}while(0);if((a[405432]&1)!=0){u=c[140620]|0;r=(u|0)!=0?u:c[t>>2]|0;u=B?51896:49248;eS(r|0,54624,(w=i,i=i+16|0,c[w>>2]=23416,c[w+8>>2]=u,w)|0)|0;i=w;u=c[140620]|0;r=(u|0)!=0?u:c[t>>2]|0;a7(r|0)|0}if(!B){r=c[140620]|0;u=(r|0)!=0?r:c[t>>2]|0;be(23144,67,1,u|0)|0;u=c[140620]|0;r=(u|0)!=0?u:c[t>>2]|0;a7(r|0)|0}if((a[405432]&1)!=0){r=c[140620]|0;u=(r|0)!=0?r:c[t>>2]|0;eS(u|0,22856,(w=i,i=i+8|0,c[w>>2]=n,w)|0)|0;i=w;u=c[140620]|0;r=(u|0)!=0?u:c[t>>2]|0;a7(r|0)|0}eI(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5126,0)}}while(0);if((o|0)==1129){o=0;eI(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5121,0)}n=n+1|0;}while((n|0)<(c[k>>2]|0))}a6(3553,0);a6(3553,0);n=b+612|0;e=n;w=n;em(c[k>>2]|0,w|0);n=0;while(1){if((n|0)>=(c[k>>2]|0)){o=1135;break}cm(36160,c[e+(n<<2)>>2]|0);d_(36160,36064,3553,c[v+(n<<2)>>2]|0,0);if((cK(36160)|0)==36053){n=n+1|0}else{o=1134;break}}if((o|0)==1134){cs(c[k>>2]|0,w|0);w=c[140620]|0;n=(w|0)!=0?w:c[t>>2]|0;be(23704,94,1,n|0)|0;n=c[140620]|0;w=(n|0)!=0?n:c[t>>2]|0;a7(w|0)|0;br(c[k>>2]|0,d|0);d=c[140620]|0;k=(d|0)!=0?d:c[t>>2]|0;be(50336,78,1,k|0)|0;k=c[140620]|0;d=(k|0)!=0?k:c[t>>2]|0;a7(d|0)|0;i=f;return}else if((o|0)==1135){a[b+1640|0]=1;i=f;return}}function jq(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+8|0;j=h|0;k=c[a+1832>>2]|0;l=c[a+1836>>2]|0;c[j>>2]=0;et(3379,j|0);m=a+1636|0;if((c[m>>2]|0)<=0){i=h;return}n=a+1124|0;o=a+740|0;p=+(f>>>0>>>0);q=+(e>>>0>>>0);e=b;b=d;d=k;k=l;l=0;f=0;while(1){a=c[n+(f<<5)+4>>2]|0;if((a|0)==0){r=+g[n+(f<<5)+12>>2];c[o+(f*24|0)>>2]=~~(+(e>>>0>>>0)*r);c[o+(f*24|0)+8>>2]=~~(+(d>>>0>>>0)*r)}else if((a|0)==1){s=c[n+(f<<5)+20>>2]|0;c[o+(f*24|0)+8>>2]=s;c[o+(f*24|0)>>2]=s}else if((a|0)==2){a=~~(q*+g[n+(f<<5)+12>>2]);c[o+(f*24|0)+8>>2]=a;c[o+(f*24|0)>>2]=a}a=c[n+(f<<5)+8>>2]|0;if((a|0)==0){r=+g[n+(f<<5)+16>>2];c[o+(f*24|0)+4>>2]=~~(+(b>>>0>>>0)*r);c[o+(f*24|0)+12>>2]=~~(+(k>>>0>>>0)*r)}else if((a|0)==1){s=c[n+(f<<5)+24>>2]|0;c[o+(f*24|0)+12>>2]=s;c[o+(f*24|0)+4>>2]=s}else if((a|0)==2){a=~~(p*+g[n+(f<<5)+16>>2]);c[o+(f*24|0)+12>>2]=a;c[o+(f*24|0)+4>>2]=a}a=o+(f*24|0)|0;s=c[a>>2]|0;u=c[j>>2]|0;if(s>>>0>u>>>0){c[a>>2]=u;v=1;w=u}else{v=l;w=s}s=o+(f*24|0)+4|0;x=c[s>>2]|0;if(x>>>0>u>>>0){c[s>>2]=u;y=1;z=u}else{y=v;z=x}x=o+(f*24|0)+8|0;A=c[x>>2]|0;if(A>>>0>u>>>0){c[x>>2]=u;B=1;C=u}else{B=y;C=A}A=o+(f*24|0)+12|0;D=c[A>>2]|0;if(D>>>0>u>>>0){c[A>>2]=u;E=1161}else{if(B){E=1161}else{F=0;G=w;H=z;I=C;J=D}}if((E|0)==1161){E=0;D=c[140620]|0;K=(D|0)!=0?D:c[t>>2]|0;eS(K|0,22656,(K=i,i=i+16|0,c[K>>2]=u,c[K+8>>2]=u,K)|0)|0;i=K;K=c[140620]|0;u=(K|0)!=0?K:c[t>>2]|0;a7(u|0)|0;F=1;G=c[a>>2]|0;H=c[s>>2]|0;I=c[x>>2]|0;J=c[A>>2]|0}A=f+1|0;if((A|0)<(c[m>>2]|0)){e=G;b=H;d=I;k=J;l=F;f=A}else{break}}i=h;return}function jr(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+64|0;j=h|0;k=c[(c[b>>2]|0)+24>>2]|0;if((k|0)==0){l=+(d>>>0>>>0)/+(e>>>0>>>0)}else{l=+gn[k&7](d,e)}do{if((a[303133]&1)==0){if((a[b+1714|0]&1)==0){c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=d;c[b+1748>>2]=e;m=d;n=e;o=0;p=0;break}q=+g[124944];do{if((c[75784]|0)==7){k=c[140608]|0;r=c[140607]|0;s=k;t=(c[b+1732>>2]|0)-(c[140606]|0)-k|0;u=c[140605]|0}else{if(+V(+(l-q))<9999999747378752.0e-20){r=d;s=e;t=0;u=0;break}if(l>q){v=(q/l+-1.0)*.5+.5;w=+(d>>>0>>>0);k=~~+bZ(+(w*(.5-v)));r=~~+bZ(+(w*2.0*v));s=e;t=0;u=k;break}else{v=(l/q+-1.0)*.5+.5;w=+(e>>>0>>>0);k=~~+bZ(+(w*(.5-v)));r=d;s=~~+bZ(+(w*2.0*v));t=k;u=0;break}}}while(0);c[b+1736>>2]=u;c[b+1740>>2]=t;c[b+1744>>2]=r;c[b+1748>>2]=s;m=r;n=s;o=u;p=t}else{k=b+1736|0;x=(a[b+1714|0]&1)==0;if((c[75784]|0)==7){y=c[140607]|0;z=c[140608]|0;A=y;B=z;C=d-y|0;D=e-z|0}else{z=c[124935]|0;y=~~+bZ(+(+g[124944]*+(z>>>0>>>0)));do{if(y>>>0>d>>>0|z>>>0>e>>>0){E=0;F=0}else{if(x){E=(d>>>0)%(y>>>0)|0;F=(e>>>0)%(z>>>0)|0;break}else{G=(d>>>0)/(y>>>0)|0;H=(e>>>0)/(z>>>0)|0;I=G>>>0<H>>>0?G:H;H=d-(ag(I,y)|0)|0;E=H;F=e-(ag(I,z)|0)|0;break}}}while(0);A=d-E|0;B=e-F|0;C=E;D=F}c[b+1744>>2]=A;c[b+1748>>2]=B;z=(C|0)/2|0;c[k>>2]=z;y=(D|0)/2|0;c[b+1740>>2]=y;m=A;n=B;o=z;p=y}}while(0);fn(o|0,p|0,m|0,n|0);p=b+1936|0;yB(p|0,0,48);g[b+1996>>2]=1.0;g[p>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;if(f){l=+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0;q=+Y(+l);v=+Z(+l);yB(j|0,0,60);g[j+40>>2]=1.0;g[j+60>>2]=1.0;g[j>>2]=q;g[j+20>>2]=q;g[j+16>>2]=-0.0-v;g[j+4>>2]=v;jW(b+1872|0,j,p);J=b+1760|0;K=J;c[K>>2]=m;L=b+1764|0;M=L;c[M>>2]=n;i=h;return}else{j=b+1872|0;yE(j|0,p|0,64)|0;J=b+1760|0;K=J;c[K>>2]=m;L=b+1764|0;M=L;c[M>>2]=n;i=h;return}}function js(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+8|0;h=f|0;j=ys(2592)|0;if((j|0)==0){k=0;i=f;return k|0}if((c[j-4>>2]&3|0)!=0){yB(j|0,0,2592)}l=j;m=c[126116]|0;n=c[126117]|0;L1598:do{if((a[303056]|0)==0){do{if((bs(12448)|0)!=0){if(!(j7()|0)){break}o=j;c[o>>2]=8080;p=8080;q=o;break L1598}}while(0);c[j>>2]=0;r=1208}else{o=(db(42376,303056)|0)==0;s=o?8080:0;if(!o){o=c[140620]|0;u=(o|0)!=0?o:c[t>>2]|0;eS(u|0,23960,(v=i,i=i+8|0,c[v>>2]=303056,v)|0)|0;i=v;u=c[140620]|0;o=(u|0)!=0?u:c[t>>2]|0;a7(o|0)|0;r=1208;break}if(!(ga[c[s+8>>2]&127](1,m,n)|0)){o=c[140620]|0;u=(o|0)!=0?o:c[t>>2]|0;eS(u|0,24528,(v=i,i=i+16|0,c[v>>2]=24768,c[v+8>>2]=303056,v)|0)|0;i=v;u=c[140620]|0;o=(u|0)!=0?u:c[t>>2]|0;a7(o|0)|0;r=1208;break}if(gp[c[s>>2]&31]()|0){o=j;c[o>>2]=s;p=s;q=o;break}else{o=c[140620]|0;u=(o|0)!=0?o:c[t>>2]|0;o=c[s+68>>2]|0;eS(u|0,24272,(v=i,i=i+8|0,c[v>>2]=o,v)|0)|0;i=v;o=c[140620]|0;u=(o|0)!=0?o:c[t>>2]|0;a7(u|0)|0;r=1208;break}}}while(0);if((r|0)==1208){yt(j);k=0;i=f;return k|0}n=j+2476|0;m=b;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];c[n+12>>2]=c[m+12>>2];c[n+16>>2]=c[m+16>>2];if((a[405432]&1)==0){w=p}else{m=c[140620]|0;n=(m|0)!=0?m:c[t>>2]|0;m=c[p+68>>2]|0;eS(n|0,36384,(v=i,i=i+8|0,c[v>>2]=m,v)|0)|0;i=v;m=c[140620]|0;n=(m|0)!=0?m:c[t>>2]|0;a7(n|0)|0;w=c[q>>2]|0}n=j+1720|0;m=j+1724|0;f3[c[w+20>>2]&1023](n,m);if((a[405432]&1)!=0){w=c[140620]|0;p=(w|0)!=0?w:c[t>>2]|0;w=c[n>>2]|0;u=c[m>>2]|0;eS(p|0,35016,(v=i,i=i+16|0,c[v>>2]=w,c[v+8>>2]=u,v)|0)|0;i=v;u=c[140620]|0;w=(u|0)!=0?u:c[t>>2]|0;a7(w|0)|0}w=b+9|0;f2[c[(c[q>>2]|0)+12>>2]&1023]((a[w]&1)!=0?c[75779]|0:0);u=c[b>>2]|0;p=c[b+4>>2]|0;o=b+8|0;s=(a[o]&1)!=0;if(s&(u|0)==0&(p|0)==0){x=c[n>>2]|0;y=c[m>>2]|0}else{x=u;y=p}if(!(ga[c[(c[q>>2]|0)+16>>2]&127](x,y,s)|0)){yt(j);k=0;i=f;return k|0}ed()|0;s=bd(7936)|0;y=bd(7937)|0;if((a[405432]&1)!=0){x=c[140620]|0;p=(x|0)!=0?x:c[t>>2]|0;eS(p|0,33904,(v=i,i=i+16|0,c[v>>2]=s,c[v+8>>2]=y,v)|0)|0;i=v;y=c[140620]|0;s=(y|0)!=0?y:c[t>>2]|0;a7(s|0)|0}s=bd(7938)|0;if((a[405432]&1)!=0){y=c[140620]|0;p=(y|0)!=0?y:c[t>>2]|0;eS(p|0,33352,(v=i,i=i+8|0,c[v>>2]=s,v)|0)|0;i=v;s=c[140620]|0;p=(s|0)!=0?s:c[t>>2]|0;a7(p|0)|0}p=c[(c[q>>2]|0)+52>>2]|0;s=1616;y=41856;do{x=f5[p&255](y)|0;u=c[s+4>>2]|0;C=x;a[u]=C&255;C=C>>8;a[u+1|0]=C&255;C=C>>8;a[u+2|0]=C&255;C=C>>8;a[u+3|0]=C&255;s=s+8|0;y=c[s>>2]|0;}while((y|0)!=0);fh(770,771);a[563828]=0;y=j+2584|0;do{if((a[y]&1)==0){s=bd(7939)|0;if((s|0)==0){z=0;break}z=(bJ(s|0,26616)|0)!=0}else{z=0}}while(0);if((a[405432]&1)!=0){s=c[140620]|0;p=(s|0)!=0?s:c[t>>2]|0;s=z?51896:49248;eS(p|0,54624,(v=i,i=i+16|0,c[v>>2]=26616,c[v+8>>2]=s,v)|0)|0;i=v;s=c[140620]|0;p=(s|0)!=0?s:c[t>>2]|0;a7(p|0)|0}do{if(z){if((a[405432]&1)==0){break}p=c[140620]|0;s=(p|0)!=0?p:c[t>>2]|0;be(26176,52,1,s|0)|0;s=c[140620]|0;p=(s|0)!=0?s:c[t>>2]|0;a7(p|0)|0}else{a[563828]=1;p=c[140620]|0;s=(p|0)!=0?p:c[t>>2]|0;be(25560,117,1,s|0)|0;s=c[140620]|0;p=(s|0)!=0?s:c[t>>2]|0;a7(p|0)|0}}while(0);a[j+8|0]=a[w]&1;a[j+1713|0]=a[o]&1;o=j+1728|0;w=j+1732|0;f3[c[(c[q>>2]|0)+20>>2]&1023](o,w);if((a[405432]&1)!=0){z=c[140620]|0;p=(z|0)!=0?z:c[t>>2]|0;z=c[o>>2]|0;s=c[w>>2]|0;eS(p|0,32536,(v=i,i=i+16|0,c[v>>2]=z,c[v+8>>2]=s,v)|0)|0;i=v;s=c[140620]|0;z=(s|0)!=0?s:c[t>>2]|0;a7(z|0)|0}if((c[n>>2]|0)==0){if((c[m>>2]|0)!=0){r=1236}}else{r=1236}if((r|0)==1236){c[n>>2]=c[o>>2];c[m>>2]=c[w>>2]}m=j+2016|0;c[m>>2]=(a[504462]&1)!=0?168:136;n=j+48|0;c[n>>2]=4;z=(c[126111]|0)==2;s=j+1710|0;a[s]=z&1;if(z){c[n>>2]=1}z=j+2020|0;c[z>>2]=8;c[73722]=c[(c[q>>2]|0)+52>>2];p=c[126116]|0;u=c[126117]|0;a[294896]=a[y]&1;c[73720]=p;c[73718]=u;if((a[307236]&1)==0){A=0}else{A=(a[303140]|0)!=0?303140:0}u=i_(A,2)|0;do{if((u|0)==3){if((a[405432]&1)==0){break}p=c[140620]|0;y=(p|0)!=0?p:c[t>>2]|0;be(28592,41,1,y|0)|0;y=c[140620]|0;p=(y|0)!=0?y:c[t>>2]|0;a7(p|0)|0}else if((u|0)==2){if((a[405432]&1)!=0){p=c[140620]|0;y=(p|0)!=0?p:c[t>>2]|0;be(28216,44,1,y|0)|0;y=c[140620]|0;p=(y|0)!=0?y:c[t>>2]|0;a7(p|0)|0}p=j+4|0;c[p>>2]=7968;if(ke(A)|0){break}y=c[140620]|0;be(27024,73,1,((y|0)!=0?y:c[t>>2]|0)|0)|0;y=c[140620]|0;a7(((y|0)!=0?y:c[t>>2]|0)|0)|0;if(f5[c[c[p>>2]>>2]&255](0)|0){break}p=c[140620]|0;be(31840,47,1,((p|0)!=0?p:c[t>>2]|0)|0)|0;p=c[140620]|0;a7(((p|0)!=0?p:c[t>>2]|0)|0)|0;gs[c[(c[q>>2]|0)+4>>2]&63]();yt(j);k=0;i=f;return k|0}else{p=c[140620]|0;be(27744,89,1,((p|0)!=0?p:c[t>>2]|0)|0)|0;p=c[140620]|0;a7(((p|0)!=0?p:c[t>>2]|0)|0)|0}}while(0);A=j+4|0;u=c[A>>2]|0;if((u|0)!=0){p=(gp[c[u+40>>2]&31]()|0)+1|0;u=c[n>>2]|0;c[n>>2]=p>>>0>u>>>0?p:u}u=a[405432]|0;if((u&1)==0){B=u}else{u=c[140620]|0;p=(u|0)!=0?u:c[t>>2]|0;u=c[n>>2]|0;eS(p|0,21872,(v=i,i=i+8|0,c[v>>2]=u,v)|0)|0;i=v;u=c[140620]|0;p=(u|0)!=0?u:c[t>>2]|0;a7(p|0)|0;B=a[405432]|0}if((B&1)!=0){B=c[140620]|0;p=(B|0)!=0?B:c[t>>2]|0;B=c[A>>2]|0;if((B|0)==0){D=0}else{D=gp[c[B+16>>2]&31]()|0}eS(p|0,31440,(v=i,i=i+8|0,c[v>>2]=D,v)|0)|0;i=v;v=c[140620]|0;D=(v|0)!=0?v:c[t>>2]|0;a7(D|0)|0}D=c[b+12>>2]<<8;v=j+1832|0;c[v>>2]=D;p=j+1836|0;c[p>>2]=D;a[j+1714|0]=a[b+10|0]&1;D=c[A>>2]|0;if((D|0)!=0){f2[c[D+12>>2]&1023](0)}jr(j,c[o>>2]|0,c[w>>2]|0,1);D=c[A>>2]|0;if((D|0)!=0){f2[c[D+12>>2]&1023](1)}jr(j,c[o>>2]|0,c[w>>2]|0,1);a[h]=0;w=c[A>>2]|0;do{if((w|0)==0){r=1265}else{if(!(gm[c[w+20>>2]&127](1,h)|0)){r=1265;break}c[j+468>>2]=(a[h]&1)!=0?9729:9728}}while(0);if((r|0)==1265){c[j+468>>2]=(a[b+11|0]&1)!=0?9729:9728}r=c[A>>2]|0;do{if((r|0)==0){E=33071}else{A=f5[c[r+24>>2]&255](1)|0;if((A|0)==2){E=10497;break}else if((A|0)==3){E=33648;break}else if((A|0)==0|(A|0)==1){E=33071;break}else{E=0;break}}}while(0);c[j+2040>>2]=E;E=(a[b+16|0]&1)!=0;r=E?32993:6407;A=j+2028|0;c[A>>2]=r;h=j+2032|0;c[h>>2]=r;c[j+2036>>2]=E?5121:33635;c[j+2044>>2]=E?4:2;if(!((a[563828]&1)==0|E^1)){c[A>>2]=6408;c[h>>2]=6408}dI(2929);dI(2884);dI(3024);h=j+1840|0;yE(h|0,808,32)|0;c[j+2e3>>2]=c[m>>2];c[j+2008>>2]=h;c[j+2004>>2]=c[z>>2];c[j+2012>>2]=808;z=ag(c[p>>2]|0,c[v>>2]|0)|0;h=z<<2;m=z>>>0>65535;if(m){F=(z&1073741823|0)==(z|0)?h:-1}else{F=h}A=ys(F)|0;do{if((A|0)!=0){if((c[A-4>>2]&3|0)==0){break}yB(A|0,0,F|0)}}while(0);c[j+472>>2]=A;if(m){G=(z&1073741823|0)==(z|0)?h:-1}else{G=h}h=ys(G)|0;if((h|0)==0){c[j+476>>2]=0;gs[c[(c[q>>2]|0)+4>>2]&63]();yt(j);k=0;i=f;return k|0}if((c[h-4>>2]&3|0)!=0){yB(h|0,0,G|0)}c[j+476>>2]=h;jU(j,b);do{if((c[n>>2]|0)!=0){b=j+1768|0;h=j+1800|0;G=0;do{c[b+(G<<2)>>2]=c[v>>2];c[h+(G<<2)>>2]=c[p>>2];G=G+1|0;H=c[n>>2]|0;}while(G>>>0<H>>>0);if((H|0)==0){break}G=j+12|0;h=j+52|0;b=0;do{c[h+(b*52|0)>>2]=c[G>>2];g[h+(b*52|0)+4>>2]=+((c[v>>2]|0)>>>0>>>0);g[h+(b*52|0)+12>>2]=+((c[v>>2]|0)>>>0>>>0);g[h+(b*52|0)+8>>2]=+((c[p>>2]|0)>>>0>>>0);g[h+(b*52|0)+16>>2]=+((c[p>>2]|0)>>>0>>>0);z=h+(b*52|0)+20|0;yE(z|0,808,32)|0;b=b+1|0;}while(b>>>0<(c[n>>2]|0)>>>0)}}while(0);jp(j,c[v>>2]|0,c[p>>2]|0);do{if((a[s]&1)!=0){if(jV(l,c[v>>2]|0,c[p>>2]|0)|0){break}gs[c[(c[q>>2]|0)+4>>2]&63]();yt(j);k=0;i=f;return k|0}}while(0);if(!((d|0)==0|(e|0)==0)){f3[c[(c[q>>2]|0)+48>>2]&1023](d,e)}if((a[319540]&1)!=0){c[j+2052>>2]=jY(j,315437,+g[79884])|0?7888:0}switch(ed()|0){case 1280:{e=c[140620]|0;be(31024,39,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[140620]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;break};case 1281:{e=c[140620]|0;be(30672,40,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[140620]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;break};case 1282:{e=c[140620]|0;be(30136,44,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[140620]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;break};case 1285:{e=c[140620]|0;be(29416,40,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[140620]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;break};case 0:{k=j;i=f;return k|0};default:{e=c[140620]|0;be(28976,45,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[140620]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0}}gs[c[(c[q>>2]|0)+4>>2]&63]();yt(j);k=0;i=f;return k|0}function jt(b,d,e,f,h,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ab=0,ac=0.0,ad=0,ae=0.0,af=0.0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0;k=i;i=i+992|0;l=k|0;m=k+64|0;n=k+96|0;o=k+928|0;p=k+936|0;q=b+4|0;r=c[q>>2]|0;if((r|0)!=0){f2[c[r+12>>2]&1023](1)}r=b+1640|0;if((a[r]&1)!=0){jq(b,e,f,c[b+1760>>2]|0,c[b+1764>>2]|0);a6(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);cm(36160,c[b+612>>2]|0);s=c[b+740>>2]|0;u=c[b+744>>2]|0;v=c[(c[b>>2]|0)+24>>2]|0;if((v|0)!=0){+gn[v&7](s,u)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=s;c[b+1748>>2]=u;fn(0,0,s|0,u|0);u=b+1936|0;yB(u|0,0,48);g[b+1996>>2]=1.0;g[u>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;s=b+1872|0;yE(s|0,u|0,64)|0;c[b+2e3>>2]=168}u=b+1711|0;do{if((a[u]&1)!=0){a[u]=0;s=b;v=b+1728|0;w=b+1732|0;f3[c[(c[s>>2]|0)+36>>2]&1023](c[v>>2]|0,c[w>>2]|0);if((a[r]&1)==0){jr(b,c[v>>2]|0,c[w>>2]|0,1);break}w=b+1636|0;if((c[w>>2]|0)>0){v=b+740|0;x=v;y=b+612|0;z=y;A=b+676|0;B=0;while(1){C=c[x+(B*24|0)+8>>2]|0;D=x+(B*24|0)+16|0;E=c[x+(B*24|0)+12>>2]|0;F=x+(B*24|0)+20|0;if(C>>>0>(c[D>>2]|0)>>>0){G=1327}else{if(E>>>0>(c[F>>2]|0)>>>0){G=1327}}do{if((G|0)==1327){G=0;H=(C>>>0>E>>>0?C:E)-1|0;I=H>>>1|H;H=I>>>2|I;I=H>>>4|H;H=I>>>8|I;I=(H>>>16|H)+1|0;c[F>>2]=I;c[D>>2]=I;cm(36160,c[z+(B<<2)>>2]|0);I=A+(B<<2)|0;a6(3553,c[I>>2]|0);eI(3553,0,32993,c[D>>2]|0,c[F>>2]|0,0,32993,5121,0);d_(36160,36064,3553,c[I>>2]|0,0);if((cK(36160)|0)!=36053){I=c[140620]|0;H=(I|0)!=0?I:c[t>>2]|0;be(39376,50,1,H|0)|0;H=c[140620]|0;I=(H|0)!=0?H:c[t>>2]|0;a7(I|0)|0}if((a[405432]&1)==0){break}I=c[140620]|0;H=(I|0)!=0?I:c[t>>2]|0;I=c[D>>2]|0;J=c[F>>2]|0;eS(H|0,38088,(H=i,i=i+24|0,c[H>>2]=B,c[H+8>>2]=I,c[H+16>>2]=J,H)|0)|0;i=H;H=c[140620]|0;J=(H|0)!=0?H:c[t>>2]|0;a7(J|0)|0}}while(0);F=B+1|0;if((F|0)<(c[w>>2]|0)){B=F}else{K=y;L=v;break}}}else{K=b+612|0;L=b+740|0}a6(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);cm(36160,c[K>>2]|0);v=c[L>>2]|0;y=c[b+744>>2]|0;B=c[(c[s>>2]|0)+24>>2]|0;if((B|0)!=0){+gn[B&7](v,y)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=v;c[b+1748>>2]=y;fn(0,0,v|0,y|0);y=b+1936|0;yB(y|0,0,48);g[b+1996>>2]=1.0;g[y>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;v=b+1872|0;yE(v|0,y|0,64)|0;c[b+2e3>>2]=168}}while(0);L=b+44|0;K=c[L>>2]|0;L1792:do{if((d|0)==0){a6(3553,c[b+12+(K<<2)>>2]|0);M=b+1708|0}else{u=b+48|0;y=((K+1|0)>>>0)%((c[u>>2]|0)>>>0)|0;c[L>>2]=y;a6(3553,c[b+12+(y<<2)>>2]|0);y=b+1708|0;if((a[y]&1)!=0){M=y;break}v=c[L>>2]|0;B=b+1768|0;w=B+(v<<2)|0;if((c[w>>2]|0)==(e|0)){if((c[b+1800+(v<<2)>>2]|0)==(f|0)){G=1341}else{G=1339}}else{G=1339}do{if((G|0)==1339){A=b+472|0;if((c[A>>2]|0)==0){G=1341;break}c[w>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;fV(3317,(e<<2&4^4)+4|0);z=b+1832|0;x=b+1836|0;eK(3553,0,0,0,c[z>>2]|0,c[x>>2]|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[A>>2]|0);N=+(e>>>0>>>0)/+((c[z>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[x>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==1341){w=c[u>>2]|0;s=((v-1+w|0)>>>0)%(w>>>0)|0;if((c[B+(s<<2)>>2]|0)==(e|0)){if((c[b+1800+(s<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[b+2472|0]&1)!=0){c[o>>2]=0;B=f$[c[(c[b>>2]|0)+60>>2]&3](d,e,f,h,(c[b+2044>>2]|0)==4,c[L>>2]|0,o)|0;v=c[o>>2]|0;if((v|0)==0){u=c[140620]|0;s=(u|0)!=0?u:c[t>>2]|0;be(40392,55,1,s|0)|0;s=c[140620]|0;u=(s|0)!=0?s:c[t>>2]|0;a7(u|0)|0;M=y;break}if(!B){M=y;break}f3[c[141172]&1023](3553,v);M=y;break}v=b+2044|0;B=ag(c[v>>2]|0,e)|0;do{if((B&1|0)==0){if((B&2|0)!=0){P=2;break}P=(B&4^4)+4|0}else{P=1}}while(0);fV(3317,P|0);B=c[v>>2]|0;do{if((B|0)==4){if((a[563828]&1)==0){break}u=b+476|0;s=c[u>>2]|0;w=b+480|0;x=w;z=w;w=b+484|0;if((c[z>>2]|0)==(e|0)){if((c[w>>2]|0)!=(f|0)){G=1356}}else{G=1356}if((G|0)==1356){c[z>>2]=e;c[w>>2]=f;c[b+492>>2]=e;c[b+496>>2]=f;c[b+504>>2]=0;c[b+508>>2]=1;c[b+512>>2]=1;iG(x)|0}c[b+488>>2]=h;c[b+500>>2]=e<<2;iS(x,s,d);eK(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y;break L1792}}while(0);if(((h>>>0)/(B>>>0)|0|0)==(e|0)){eK(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,d|0);M=y;break}v=ag(B,e)|0;u=b+476|0;if((f|0)!=0){s=c[u>>2]|0;x=d;w=0;while(1){yE(s|0,x|0,v)|0;z=w+1|0;if(z>>>0<f>>>0){s=s+v|0;x=x+h|0;w=z}else{break}}}eK(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y}}while(0);if((a[M]&1)!=0){h=c[L>>2]|0;d=b+1768|0;P=d+(h<<2)|0;if((c[P>>2]|0)==(e|0)){if((c[b+1800+(h<<2)>>2]|0)==(f|0)){G=1370}else{G=1368}}else{G=1368}do{if((G|0)==1368){if((c[b+472>>2]|0)==0){G=1370;break}c[P>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;N=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==1370){P=c[b+48>>2]|0;o=((h-1+P|0)>>>0)%(P>>>0)|0;if((c[d+(o<<2)>>2]|0)==(e|0)){if((c[b+1800+(o<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[r]&1)==0){cm(36160,0);jr(b,c[b+1728>>2]|0,c[b+1732>>2]|0,1)}dI(2929);dI(2960);dI(2884);dI(3024);dI(3042);fh(770,771);aW(0.0,0.0,0.0,1.0)}d=p;yB(d|0,0,52);c[p>>2]=c[b+12+(c[L>>2]<<2)>>2];g[p+4>>2]=+(e>>>0>>>0);g[p+8>>2]=+(f>>>0>>>0);L=b+1832|0;g[p+12>>2]=+((c[L>>2]|0)>>>0>>>0);h=b+1836|0;g[p+16>>2]=+((c[h>>2]|0)>>>0>>>0);G=p+20|0;o=b+1840|0;yE(G|0,o|0,32)|0;dN(16384);if((a[303114]&1)!=0){gs[c[(c[b>>2]|0)+44>>2]&63]();dN(16384)}G=c[q>>2]|0;do{if((G|0)==0){P=b+2e3|0;K=b+1872|0;Q=P;R=P;S=K;T=K}else{f6[c[G+8>>2]&3](e,f,c[L>>2]|0,c[h>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[140560]|0,p,b+52|0,0,0);K=c[q>>2]|0;P=b+2e3|0;w=P;x=b+1872|0;v=x;if((K|0)==0){Q=P;R=w;S=x;T=v;break}s=c[K+32>>2]|0;f5[s&255](w)|0;s=c[q>>2]|0;if((s|0)==0){Q=P;R=w;S=x;T=v;break}K=c[s+36>>2]|0;f5[K&255](v)|0;Q=P;R=w;S=x;T=v}}while(0);dC(5,0,4);if((a[r]&1)!=0){r=m;yB(r|0,0,32);h=b+2008|0;c[h>>2]=m;L=b+1636|0;f=c[L>>2]|0;e=b+740|0;G=m+8|0;v=m+24|0;x=m+20|0;w=m+28|0;if((f|0)>1){m=b+676|0;P=b+612|0;K=b;s=b+1740|0;B=b+1736|0;z=b+1744|0;A=b+1748|0;F=b+1936|0;D=b+52|0;E=n|0;C=F;J=b+1956|0;H=b+1976|0;I=b+1996|0;U=b+1984|0;V=b+1988|0;W=b+1992|0;X=1;Y=0;while(1){Z=X-1|0;_=e+(Z*24|0)|0;N=+((c[_>>2]|0)>>>0>>>0);$=e+(Z*24|0)+16|0;O=+((c[$>>2]|0)>>>0>>>0);aa=N/O;ab=e+(Z*24|0)+4|0;ac=+((c[ab>>2]|0)>>>0>>>0);ad=e+(Z*24|0)+20|0;ae=+((c[ad>>2]|0)>>>0>>>0);af=ac/ae;g[G>>2]=aa;g[v>>2]=aa;g[x>>2]=af;g[w>>2]=af;ah=m+(Z<<2)|0;c[n+(Z*52|0)>>2]=c[ah>>2];g[n+(Z*52|0)+4>>2]=N;g[n+(Z*52|0)+8>>2]=ac;g[n+(Z*52|0)+12>>2]=O;g[n+(Z*52|0)+16>>2]=ae;ai=n+(Z*52|0)+20|0;yE(ai|0,r|0,32)|0;cm(36160,c[P+(X<<2)>>2]|0);ai=c[q>>2]|0;if((ai|0)!=0){f2[c[ai+12>>2]&1023](X+1|0)}a6(3553,c[ah>>2]|0);dN(16384);ah=c[e+(X*24|0)>>2]|0;ai=c[e+(X*24|0)+4>>2]|0;Z=c[(c[K>>2]|0)+24>>2]|0;if((Z|0)!=0){+gn[Z&7](ah,ai)}c[s>>2]=0;c[B>>2]=0;c[z>>2]=ah;c[A>>2]=ai;fn(0,0,ah|0,ai|0);yB(F|0,0,48);g[I>>2]=1.0;g[C>>2]=2.0;g[J>>2]=2.0;g[H>>2]=-1.0;g[U>>2]=-1.0;g[V>>2]=-1.0;g[W>>2]=-0.0;yE(S|0,F|0,64)|0;ai=c[q>>2]|0;do{if((ai|0)!=0){f6[c[ai+8>>2]&3](c[_>>2]|0,c[ab>>2]|0,c[$>>2]|0,c[ad>>2]|0,c[z>>2]|0,c[A>>2]|0,c[140560]|0,p,D,E,Y);ah=c[q>>2]|0;if((ah|0)==0){break}Z=c[ah+32>>2]|0;f5[Z&255](R)|0;Z=c[q>>2]|0;if((Z|0)==0){break}ah=c[Z+36>>2]|0;f5[ah&255](T)|0}}while(0);dC(5,0,4);ad=Y+1|0;$=X+1|0;ab=c[L>>2]|0;if(($|0)<(ab|0)){X=$;Y=ad}else{aj=ad;ak=ab;break}}}else{aj=0;ak=f}f=ak-1|0;ak=e+(f*24|0)|0;Y=e+(f*24|0)+16|0;ae=+((c[ak>>2]|0)>>>0>>>0)/+((c[Y>>2]|0)>>>0>>>0);X=e+(f*24|0)+4|0;E=e+(f*24|0)+20|0;O=+((c[X>>2]|0)>>>0>>>0)/+((c[E>>2]|0)>>>0>>>0);g[G>>2]=ae;g[v>>2]=ae;g[x>>2]=O;g[w>>2]=O;cm(36160,0);w=c[q>>2]|0;if((w|0)!=0){f2[c[w+12>>2]&1023]((c[L>>2]|0)+1|0)}a6(3553,c[b+676+((c[L>>2]|0)-1<<2)>>2]|0);dN(16384);jr(b,c[b+1728>>2]|0,c[b+1732>>2]|0,1);L=c[q>>2]|0;do{if((L|0)==0){c[Q>>2]=c[b+2016>>2]}else{f6[c[L+8>>2]&3](c[ak>>2]|0,c[X>>2]|0,c[Y>>2]|0,c[E>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[140560]|0,p,b+52|0,n|0,aj);w=c[q>>2]|0;c[Q>>2]=c[b+2016>>2];if((w|0)==0){break}x=c[w+32>>2]|0;f5[x&255](R)|0;x=c[q>>2]|0;if((x|0)==0){break}w=c[x+36>>2]|0;f5[w&255](T)|0}}while(0);dC(5,0,4);c[h>>2]=o}h=b+52|0;yI(b+104|0,h|0,((c[b+48>>2]|0)*52|0)-52|0);yE(h|0,d|0,52)|0;do{if((a[b+2576|0]&1)!=0){d=c[b+2572>>2]|0;if((d|0)==0){break}h=l|0;g[h>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2580>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;T=Q;c[T>>2]=136;aj=b+2008|0;c[aj>>2]=808;n=b+2004|0;c[n>>2]=h;a6(3553,d|0);d=c[q>>2]|0;do{if((d|0)!=0){f2[c[d+12>>2]&1023](15);h=c[q>>2]|0;p=b+1936|0;if((h|0)==0){break}E=c[h+32>>2]|0;f5[E&255](R)|0;E=c[q>>2]|0;if((E|0)==0){break}h=c[E+36>>2]|0;f5[h&255](p)|0}}while(0);e1(3042);if((a[b+2577|0]&1)==0){dC(5,0,4)}else{fn(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);dC(5,0,4);fn(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}dI(3042);c[T>>2]=c[b+2016>>2];c[aj>>2]=o;c[n>>2]=c[b+2020>>2]}}while(0);do{if((j|0)!=0){d=c[b+2052>>2]|0;if((d|0)==0){break}gr[c[d+8>>2]&127](b,j,0)}}while(0);if((a[b+2496|0]&1)!=0){a6(3553,c[b+2500>>2]|0);j=l|0;g[j>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2568>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;l=c[q>>2]|0;if((l|0)!=0){f2[c[l+12>>2]&1023](15)}e1(3042);l=Q;c[l>>2]=b+2536;Q=b+2008|0;c[Q>>2]=b+2504;d=b+2004|0;c[d>>2]=j;j=b+1936|0;p=c[q>>2]|0;do{if((p|0)!=0){h=c[p+32>>2]|0;f5[h&255](R)|0;h=c[q>>2]|0;if((h|0)==0){break}E=c[h+36>>2]|0;f5[E&255](j)|0}}while(0);if((a[b+2497|0]&1)==0){dC(5,0,4)}else{fn(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);dC(5,0,4);fn(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}dI(3042);c[l>>2]=c[b+2016>>2];c[Q>>2]=o;c[d>>2]=c[b+2020>>2]}d=b;gs[c[(c[d>>2]|0)+28>>2]&63]();if((a[M]&1)==0){al=c[d>>2]|0;am=al+44|0;an=c[am>>2]|0;gs[an&63]();ao=c[140560]|0;ap=ao+1|0;c[140560]=ap;i=k;return 1}M=c[q>>2]|0;if((M|0)!=0){f2[c[M+12>>2]&1023](0)}a6(3553,0);al=c[d>>2]|0;am=al+44|0;an=c[am>>2]|0;gs[an&63]();ao=c[140560]|0;ap=ao+1|0;c[140560]=ap;i=k;return 1}function ju(a,b){a=a|0;b=b|0;c[b>>2]=7944;return}function jv(a,b){a=a|0;b=b|0;c[b>>2]=7904;return}function jw(a){a=a|0;return c[a+1644+(((((c[a+44>>2]|0)+1|0)>>>0)%((c[a+48>>2]|0)>>>0)|0)<<2)>>2]|0}function jx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;if((a[405432]&1)!=0){f=c[140620]|0;g=(f|0)!=0?f:c[t>>2]|0;f=d?42472:41472;eS(g|0,43600,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;g=c[140620]|0;f=(g|0)!=0?g:c[t>>2]|0;a7(f|0)|0}f2[c[(c[b>>2]|0)+12>>2]&1023](d?0:c[75779]|0);i=e;return}function jy(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;f=d+8|0;f1[c[(c[b>>2]|0)+32>>2]&15](e,f,b+1728|0,b+1732|0,c[140560]|0);do{if((a[e]&1)==0){if((a[f]&1)==0){break}a[b+1711|0]=1}else{a[b+1712|0]=1}}while(0);i=d;return(a[b+1712|0]&1)==0|0}function jz(a){a=a|0;return gp[c[(c[a>>2]|0)+40>>2]&31]()|0}function jA(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0;f=i;i=i+8|0;h=f|0;j=b;if((d|0)==3){k=0;i=f;return k|0}l=b+4|0;m=c[l>>2]|0;if((m|0)!=0){gs[c[m+4>>2]&63]()}m=(d|0)==2;c[l>>2]=m?7968:0;if(!m){m=c[140620]|0;d=(m|0)!=0?m:c[t>>2]|0;eS(d|0,29752,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;d=c[140620]|0;m=(d|0)!=0?d:c[t>>2]|0;a7(m|0)|0;k=0;i=f;return k|0}m=b+1640|0;if((a[m]&1)!=0){d=b+1636|0;br(c[d>>2]|0,b+676|0);o=b+612|0;cs(c[d>>2]|0,o|0);a[m]=0;c[d>>2]=0;yB(o|0,0,128)}o=b+44|0;d=b+12|0;a6(3553,c[d+(c[o>>2]<<2)>>2]|0);if(!(f5[c[c[l>>2]>>2]&255](e)|0)){e=c[140620]|0;m=(e|0)!=0?e:c[t>>2]|0;be(25208,81,1,m|0)|0;m=c[140620]|0;e=(m|0)!=0?m:c[t>>2]|0;a7(e|0)|0;if(f5[c[c[l>>2]>>2]&255](0)|0){k=0;i=f;return k|0}c[l>>2]=0;k=0;i=f;return k|0}a[h]=0;e=c[l>>2]|0;if((e|0)==0){p=1457}else{if(!(gm[c[e+20>>2]&127](1,h)|0)){p=1457}}if((p|0)==1457){a[h]=a[303124]&1}e=c[l>>2]|0;do{if((e|0)==0){q=33071}else{m=f5[c[e+24>>2]&255](1)|0;if((m|0)==2){q=10497;break}else if((m|0)==3){q=33648;break}else if((m|0)==0|(m|0)==1){q=33071;break}else{q=0;break}}}while(0);e=a[h]&1;a[b+2487|0]=e;h=e<<24>>24!=0?9729:9728;e=b+468|0;m=b+2040|0;if((h|0)==(c[e>>2]|0)){if((q|0)!=(c[m>>2]|0)){p=1465}}else{p=1465}if((p|0)==1465){c[e>>2]=h;c[m>>2]=q;q=b+48|0;h=c[q>>2]|0;if((h|0)!=0){p=0;r=h;while(1){h=c[j+12+(p<<2)>>2]|0;if((h|0)==0){s=r}else{a6(3553,h|0);fL(3553,10242,c[m>>2]|0);fL(3553,10243,c[m>>2]|0);fL(3553,10240,c[e>>2]|0);fL(3553,10241,c[e>>2]|0);s=c[q>>2]|0}h=p+1|0;if(h>>>0<s>>>0){p=h;r=s}else{break}}}a6(3553,c[j+12+(c[o>>2]<<2)>>2]|0)}s=c[l>>2]|0;do{if((s|0)!=0){r=(gp[c[s+40>>2]&31]()|0)+1|0;p=b+48|0;q=c[p>>2]|0;if(r>>>0<=q>>>0){break}e=b+1708|0;if((a[e]&1)!=0){cs(q|0,b+1644|0)}if((a[b+1709|0]&1)!=0){b3(c[p>>2]|0,b+1676|0)}a[e]=0;e=d;br(c[p>>2]|0,e|0);c[p>>2]=r;if((a[405432]&1)!=0){q=c[140620]|0;m=(q|0)!=0?q:c[t>>2]|0;eS(m|0,21872,(n=i,i=i+8|0,c[n>>2]=r,n)|0)|0;i=n;r=c[140620]|0;m=(r|0)!=0?r:c[t>>2]|0;a7(m|0)|0}c[o>>2]=0;jU(b,b+2476|0);do{if((c[p>>2]|0)!=0){m=b+1832|0;r=b+1768|0;q=b+1836|0;h=b+1800|0;u=0;do{c[r+(u<<2)>>2]=c[m>>2];c[h+(u<<2)>>2]=c[q>>2];u=u+1|0;v=c[p>>2]|0;}while(u>>>0<v>>>0);if((v|0)==0){break}u=b+52|0;h=0;do{c[u+(h*52|0)>>2]=c[e>>2];g[u+(h*52|0)+4>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+12>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+8>>2]=+((c[q>>2]|0)>>>0>>>0);g[u+(h*52|0)+16>>2]=+((c[q>>2]|0)>>>0>>>0);r=u+(h*52|0)+20|0;yE(r|0,808,32)|0;h=h+1|0;}while(h>>>0<(c[p>>2]|0)>>>0)}}while(0);if((a[b+1710|0]&1)==0){break}p=c[b+1832>>2]|0;e=c[b+1836>>2]|0;jV(j,p,e)|0}}while(0);jp(b,c[b+1832>>2]|0,c[b+1836>>2]|0);j=c[l>>2]|0;if((j|0)!=0){f2[c[j+12>>2]&1023](0)}j=b+1728|0;v=b+1732|0;jr(b,c[j>>2]|0,c[v>>2]|0,1);o=c[l>>2]|0;if((o|0)!=0){f2[c[o+12>>2]&1023](1)}jr(b,c[j>>2]|0,c[v>>2]|0,1);k=1;i=f;return k|0}function jB(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[b+2052>>2]|0;if((d|0)!=0){f2[c[d+4>>2]&1023](b)}d=b+4|0;e=c[d>>2]|0;if((e|0)!=0){gs[c[e+4>>2]&63]()}c[d>>2]=0;d=b+48|0;br(c[d>>2]|0,b+12|0);e=b+2572|0;if((c[e>>2]|0)!=0){br(1,e|0)}e=b+2500|0;if((c[e>>2]|0)!=0){br(1,e|0)}e=b+544|0;yt(c[e>>2]|0);yt(c[b+556>>2]|0);yt(c[b+560>>2]|0);yt(c[b+572>>2]|0);yt(c[b+584>>2]|0);yt(c[b+576>>2]|0);yt(c[b+600>>2]|0);yB(e|0,0,64);e=b+1640|0;if((a[e]&1)!=0){f=b+1636|0;br(c[f>>2]|0,b+676|0);g=b+612|0;cs(c[f>>2]|0,g|0);a[e]=0;c[f>>2]=0;yB(g|0,0,128)}g=b+1708|0;if((a[g]&1)!=0){cs(c[d>>2]|0,b+1644|0)}if((a[b+1709|0]&1)==0){a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;gs[k&63]();l=b+472|0;m=l;n=c[m>>2]|0;yt(n);o=b+476|0;p=o;q=c[p>>2]|0;yt(q);yt(b);return}b3(c[d>>2]|0,b+1676|0);a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;gs[k&63]();l=b+472|0;m=l;n=c[m>>2]|0;yt(n);o=b+476|0;p=o;q=c[p>>2]|0;yt(q);yt(b);return}function jC(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=d;c[e>>2]=c[1966];c[e+4>>2]=c[1967];c[e+8>>2]=c[1968];c[e+12>>2]=c[1969];c[e+16>>2]=c[1970];a[d+9|0]=a[303112]&1;a[d+10|0]=0;a[d+11|0]=a[303124]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[75784]|0)==7){c[d>>2]=c[140607];c[d+4>>2]=c[140608]}e=js(d,0,0)|0;c[140916]=e;c[140964]=7904;c[e+2052>>2]=jY(e,315437,+g[79884])|0?7888:0;i=b;return}function jD(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=c[140916]|0;if((e|0)==0){i=b;return}c[140916]=0;jB(e);e=d;c[e>>2]=c[1966];c[e+4>>2]=c[1967];c[e+8>>2]=c[1968];c[e+12>>2]=c[1969];c[e+16>>2]=c[1970];a[d+9|0]=a[303112]&1;a[d+10|0]=0;a[d+11|0]=a[303124]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[75784]|0)==7){c[d>>2]=c[140607];c[d+4>>2]=c[140608]}e=js(d,0,0)|0;c[140916]=e;c[140964]=7904;c[e+2052>>2]=jY(e,315437,+g[79884])|0?7888:0;i=b;return}function jE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0.0,j=0.0,k=0.0;d=i;i=i+64|0;e=d|0;f=b*90|0;c[a+1716>>2]=f;b=a+1936|0;yB(b|0,0,48);g[a+1996>>2]=1.0;g[b>>2]=2.0;g[a+1956>>2]=2.0;g[a+1976>>2]=-1.0;g[a+1984>>2]=-1.0;g[a+1988>>2]=-1.0;g[a+1992>>2]=-0.0;h=+(f>>>0>>>0)*3.141592653589793/180.0;j=+Y(+h);k=+Z(+h);yB(e|0,0,60);g[e+40>>2]=1.0;g[e+60>>2]=1.0;g[e>>2]=j;g[e+20>>2]=j;g[e+16>>2]=-0.0-k;g[e+4>>2]=k;jW(a+1872|0,e,b);i=d;return}function jF(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+1736|0;e=b;c[e>>2]=c[d>>2];c[e+4>>2]=c[d+4>>2];c[e+8>>2]=c[d+8>>2];c[e+12>>2]=c[d+12>>2];c[e+16>>2]=c[d+16>>2];c[e+20>>2]=c[d+20>>2];c[b+16>>2]=c[a+1728>>2];d=a+1732|0;c[b+20>>2]=c[d>>2];a=b+4|0;c[a>>2]=(c[d>>2]|0)-((c[b+12>>2]|0)+(c[a>>2]|0));return}function jG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((a[b+1708|0]&1)==0){if((a[b+1640|0]&1)!=0){e=1528}}else{e=1528}if((e|0)==1528){cm(36160,0)}e=b+1736|0;f=b+1744|0;g=(c[f>>2]|0)*3|0;do{if((g&1|0)==0){if((g&2|0)!=0){h=2;break}h=(g&4^4)+4|0}else{h=1}}while(0);fV(3333,h|0);h=b+1748|0;el(c[e>>2]|0,c[b+1740>>2]|0,c[f>>2]|0,c[h>>2]|0,6407,5121,d|0);b=ag(c[h>>2]|0,c[f>>2]|0)|0;f=0;h=d;while(1){d=h+2|0;e=a[d]|0;a[d]=a[h]|0;a[h]=e;e=f+1|0;if(e>>>0>b>>>0){break}else{f=e;h=h+3|0}}return 1}function jH(a,b){a=a|0;b=b|0;return f5[c[(c[a>>2]|0)+52>>2]&255](b)|0}function jI(b){b=b|0;a[b+1711|0]=1;return}function jJ(b,c,d){b=b|0;c=c|0;d=d|0;a[b+2576|0]=c&1;a[b+2577|0]=d&1;return}function jK(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;g[a+2504>>2]=b;g[a+2508>>2]=c;f=b+d;g[a+2512>>2]=f;g[a+2516>>2]=c;g[a+2520>>2]=b;b=c+e;g[a+2524>>2]=b;g[a+2528>>2]=f;g[a+2532>>2]=b;return}function jL(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;f=1.0-c;g[a+2536>>2]=b;g[a+2540>>2]=f;c=b+d;g[a+2544>>2]=c;g[a+2548>>2]=f;g[a+2552>>2]=b;b=f-e;g[a+2556>>2]=b;g[a+2560>>2]=c;g[a+2564>>2]=b;return}function jM(b,c){b=b|0;c=c|0;a[b+2497|0]=c&1;return}function jN(a,b){a=a|0;b=+b;g[a+2568>>2]=b;return}function jO(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0;e=i;L2075:do{if((d|0)==5){f=c[124934]|0;h=c[124935]|0;if((f|0)==0|(h|0)==0){break}j=f>>>0<h>>>0?f:h;if(j>>>0>1){k=1;l=1;while(1){if(((f>>>0)%(k>>>0)|0|0)==0){m=((h>>>0)%(k>>>0)|0|0)==0?k:l}else{m=l}n=k+1|0;if(n>>>0<j>>>0){k=n;l=m}else{o=m;break}}}else{o=1}l=(f>>>0)/(o>>>0)|0;k=(h>>>0)/(o>>>0)|0;b5(10644,64,31304,(j=i,i=i+16|0,c[j>>2]=l,c[j+8>>2]=k,j)|0)|0;i=j;g[2677]=+(l>>>0>>>0)/+(k>>>0>>>0)}else if((d|0)==6){if((a[562484]&1)==0){break}p=+g[124938];if(p>0.0){g[2694]=p;break}else{g[2694]=+((c[124934]|0)>>>0>>>0)/+((c[124935]|0)>>>0>>>0);break}}else if((d|0)==4){p=+g[75782];if(p>=0.0){g[2660]=p;break}p=+g[124938];do{if(p>0.0){if((a[303132]&1)==0){break}g[2660]=p;break L2075}}while(0);g[2660]=+((c[124934]|0)>>>0>>>0)/+((c[124935]|0)>>>0>>>0)}}while(0);g[124944]=+g[10368+(d*68|0)>>2];a[b+1714|0]=1;a[b+1711|0]=1;i=e;return}function jP(b,d,e,f,h,i){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=+i;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=b+2572|0;k=c[j>>2]|0;if((k|0)==0){bM(1,j|0);a6(3553,c[j>>2]|0);fL(3553,10242,33071);fL(3553,10243,33071);fL(3553,10240,9729);fL(3553,10241,9729)}else{a6(3553,k|0)}g[b+2580>>2]=i;k=ag(e?4:2,f)|0;if((k&2|0)==0){l=(k&4^4)+4|0}else{l=2}fV(3317,l|0);if(e){e=(a[563828]&1)!=0?6408:32993;eI(3553,0,e|0,f|0,h|0,0,e|0,5121,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;a6(3553,s|0);return}else{eI(3553,0,6408,f|0,h|0,0,6408,32819,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;a6(3553,s|0);return}}function jQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+2052>>2]|0;if((e|0)==0){return}gr[c[e+8>>2]&127](a,b,d);return}function jR(a,b){a=a|0;b=b|0;var d=0;d=c[(c[a>>2]|0)+64>>2]|0;if((d|0)==0){return}f2[d&1023](b);return}function jS(b,d){b=b|0;d=d|0;var e=0;a[b+2496|0]=d&1;e=c[(c[b>>2]|0)+64>>2]|0;if((e|0)==0){return}if((a[b+1713|0]&1)==0){return}f2[e&1023](d);return}function jT(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0;h=b+2500|0;i=c[h>>2]|0;if((i|0)==0){bM(1,h|0);j=c[h>>2]|0}else{j=i}a6(3553,j|0);fL(3553,10242,33071);fL(3553,10243,33071);fL(3553,10240,9729);fL(3553,10241,9729);fV(3317,(e<<2&4^4)+4|0);j=(a[563828]&1)!=0?6408:32993;eI(3553,0,j|0,e|0,f|0,0,j|0,5121,d|0);g[b+2504>>2]=0.0;g[b+2508>>2]=0.0;g[b+2512>>2]=1.0;g[b+2516>>2]=0.0;g[b+2520>>2]=0.0;g[b+2524>>2]=1.0;g[b+2528>>2]=1.0;g[b+2532>>2]=1.0;g[b+2536>>2]=0.0;g[b+2540>>2]=1.0;g[b+2544>>2]=1.0;g[b+2548>>2]=1.0;g[b+2552>>2]=0.0;g[b+2556>>2]=0.0;g[b+2560>>2]=1.0;g[b+2564>>2]=0.0;return 1}function jU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0;e=i;f=b+1710|0;g=a[f]|0;if((g&1)==0&(c[141172]|0)!=0){h=(f5[c[(c[b>>2]|0)+56>>2]&255](d)|0)&1;j=h;k=a[f]|0}else{j=0;k=g}g=b+2472|0;a[g]=j;j=c[b+2028>>2]|0;f=c[b+2032>>2]|0;h=c[b+2036>>2]|0;do{if((k&1)==0){l=j;m=h;n=f}else{if((c[b+2044>>2]|0)!=4){l=j;m=h;n=f;break}d=b+2584|0;do{if((a[d]&1)==0){o=bd(7939)|0;if((o|0)==0){p=0;break}p=(bJ(o|0,47608)|0)!=0}else{p=0}}while(0);if((a[405432]&1)!=0){o=c[140620]|0;q=(o|0)!=0?o:c[t>>2]|0;o=p?51896:49248;eS(q|0,54624,(r=i,i=i+16|0,c[r>>2]=47608,c[r+8>>2]=o,r)|0)|0;i=r;o=c[140620]|0;q=(o|0)!=0?o:c[t>>2]|0;a7(q|0)|0}if(p){l=6408;m=5121;n=6408;break}do{if((a[d]&1)==0){q=bd(7939)|0;if((q|0)==0){s=0;break}s=(bJ(q|0,46520)|0)!=0}else{s=0}}while(0);if((a[405432]&1)!=0){d=c[140620]|0;q=(d|0)!=0?d:c[t>>2]|0;d=s?51896:49248;eS(q|0,54624,(r=i,i=i+16|0,c[r>>2]=46520,c[r+8>>2]=d,r)|0)|0;i=r;d=c[140620]|0;q=(d|0)!=0?d:c[t>>2]|0;a7(q|0)|0}if(s){l=6408;m=5121;n=6408;break}q=c[140620]|0;d=(q|0)!=0?q:c[t>>2]|0;be(45080,76,1,d|0)|0;d=c[140620]|0;q=(d|0)!=0?d:c[t>>2]|0;a7(q|0)|0;l=6407;m=33635;n=6407}}while(0);s=b+48|0;r=b+12|0;p=r;bM(c[s>>2]|0,r|0);if((c[s>>2]|0)==0){u=b+44|0;v=u;w=c[v>>2]|0;x=p+(w<<2)|0;y=c[x>>2]|0;a6(3553,y|0);i=e;return}r=b+2040|0;f=b+468|0;h=b+1832|0;j=b+1836|0;k=b+472|0;q=0;do{a6(3553,c[p+(q<<2)>>2]|0);fL(3553,10242,c[r>>2]|0);fL(3553,10243,c[r>>2]|0);fL(3553,10240,c[f>>2]|0);fL(3553,10241,c[f>>2]|0);if((a[g]&1)==0){eI(3553,0,l|0,c[h>>2]|0,c[j>>2]|0,0,n|0,m|0,c[k>>2]|0)}q=q+1|0;}while(q>>>0<(c[s>>2]|0)>>>0);u=b+44|0;v=u;w=c[v>>2]|0;x=p+(w<<2)|0;y=c[x>>2]|0;a6(3553,y|0);i=e;return}
function oY(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0;f=b+2292|0;g=b+2308|0;h=c[g>>2]|0;if((h|0)==0){i=b+2364|0;switch(c[i>>2]|0){case 2:{j=b+2422|0;k=b+2392|0;l=c[k>>2]|0;m=l+108|0;n=((a[j]&24)==16?3:1)|c[m>>2];c[m>>2]=n;do{if((a[l+116|0]|0)!=0){if((c[l+112>>2]&n|0)==0){break}m=c[l+104>>2]|0;c[l+32>>2]=m;c[l+100>>2]=8;c[l+80>>2]=8;c[l+68>>2]=8;o=c[l+64>>2]|0;p=(c[l+(o<<2)>>2]|0)>>>0<m>>>0?o:8;c[l+60>>2]=p;c[l+36>>2]=c[l+(p<<2)>>2]}}while(0);a[j]=a[b+2420|0]|0;j=b+2320|0;l=(70224<<(a[b+291|0]&1))+(c[j>>2]|0)|0;c[j>>2]=l;j=(c[b+2324>>2]|0)>>>0>l>>>0?2:3;c[b+2380>>2]=j;l=c[b+2376>>2]|0;n=(c[b+2312+(l<<2)>>2]|0)>>>0<(c[b+2312+(j<<2)>>2]|0)>>>0?l:j;c[b+2368>>2]=n;j=c[b+2372>>2]|0;l=(c[b+2312+(n<<2)>>2]|0)>>>0<(c[b+2312+(j<<2)>>2]|0)>>>0?n:j;c[i>>2]=l;j=c[b+2312+(l<<2)>>2]|0;c[b+2344>>2]=j;c[f>>2]=j;l=(c[b+2296>>2]|0)>>>0<=j>>>0|0;c[g>>2]=l;c[b+2300>>2]=c[b+2292+(l<<2)>>2];l=c[k>>2]|0;c[l+28>>2]=j;k=(c[l+24>>2]|0)>>>0<j>>>0?6:7;c[l+96>>2]=k;j=c[l+92>>2]|0;n=(c[l+(j<<2)>>2]|0)>>>0<(c[l+(k<<2)>>2]|0)>>>0?j:k;c[l+76>>2]=n;k=c[l+72>>2]|0;j=(c[l+(k<<2)>>2]|0)>>>0<(c[l+(n<<2)>>2]|0)>>>0?k:n;c[l+64>>2]=j;n=c[l+68>>2]|0;k=(c[l+(j<<2)>>2]|0)>>>0<(c[l+(n<<2)>>2]|0)>>>0?j:n;c[l+60>>2]=k;c[l+36>>2]=c[l+(k<<2)>>2];return};case 4:{k=b+2328|0;l=c[k>>2]|0;qC(b+1880|0,l);n=b+1732|0;yB(n|0,-128|0,144);j=b+292|0;p=0;do{o=8<<(a[(p>>>1)+(b+1960)|0]&1);m=cO((d[b+1880+p|0]|0)-17|0,o|0)|0;q=m;L3561:do{if(q>>>0<(o+143|0)>>>0){if(K){r=j;s=n}else{m=1-o+q|0;r=(m*10|0)+(b+292)|0;s=b+1732+m|0}m=(q>>>0<143?q:143)+(b+1732)|0;t=p&255;u=r;v=s;while(1){w=a[v]|0;x=w&127;if(x>>>0<10){a[v]=w+1&255;a[u+x|0]=t}x=v+1|0;if(x>>>0>m>>>0){break L3561}u=u+10|0;v=x}}}while(0);p=p+2|0;}while(p>>>0<80);c[c[b+1876>>2]>>2]=0;if((a[b+2012|0]|0)==-1){y=-1}else{y=(e[(c[b+2e3>>2]|0)+4>>1]|0)+l|0}c[k>>2]=y;k=(c[b+2332>>2]|0)>>>0>y>>>0?4:5;c[b+2384>>2]=k;y=c[b+2388>>2]|0;l=(c[b+2312+(k<<2)>>2]|0)>>>0<(c[b+2312+(y<<2)>>2]|0)>>>0?k:y;c[b+2372>>2]=l;y=c[b+2368>>2]|0;k=(c[b+2312+(y<<2)>>2]|0)>>>0<(c[b+2312+(l<<2)>>2]|0)>>>0?y:l;c[i>>2]=k;l=c[b+2312+(k<<2)>>2]|0;c[b+2344>>2]=l;c[f>>2]=l;k=(c[b+2296>>2]|0)>>>0<=l>>>0|0;c[g>>2]=k;c[b+2300>>2]=c[b+2292+(k<<2)>>2];k=c[b+2392>>2]|0;c[k+28>>2]=l;y=(c[k+24>>2]|0)>>>0<l>>>0?6:7;c[k+96>>2]=y;l=c[k+92>>2]|0;p=(c[k+(l<<2)>>2]|0)>>>0<(c[k+(y<<2)>>2]|0)>>>0?l:y;c[k+76>>2]=p;y=c[k+72>>2]|0;l=(c[k+(y<<2)>>2]|0)>>>0<(c[k+(p<<2)>>2]|0)>>>0?y:p;c[k+64>>2]=l;p=c[k+68>>2]|0;y=(c[k+(l<<2)>>2]|0)>>>0<(c[k+(p<<2)>>2]|0)>>>0?l:p;c[k+60>>2]=y;c[k+36>>2]=c[k+(y<<2)>>2];oU(b);return};case 0:{y=b+2392|0;k=c[y>>2]|0;p=k+108|0;l=c[p>>2]|2;c[p>>2]=l;do{if((a[k+116|0]|0)!=0){if((c[k+112>>2]&l|0)==0){break}p=c[k+104>>2]|0;c[k+32>>2]=p;c[k+100>>2]=8;c[k+80>>2]=8;c[k+68>>2]=8;s=c[k+64>>2]|0;r=(c[k+(s<<2)>>2]|0)>>>0<p>>>0?s:8;c[k+60>>2]=r;c[k+36>>2]=c[k+(r<<2)>>2]}}while(0);c[b+2312>>2]=-1;c[b+2376>>2]=1;k=c[b+2380>>2]|0;l=(c[b+2316>>2]|0)>>>0<(c[b+2312+(k<<2)>>2]|0)>>>0?1:k;c[b+2368>>2]=l;k=c[b+2372>>2]|0;r=(c[b+2312+(l<<2)>>2]|0)>>>0<(c[b+2312+(k<<2)>>2]|0)>>>0?l:k;c[i>>2]=r;k=c[b+2312+(r<<2)>>2]|0;c[b+2344>>2]=k;c[f>>2]=k;r=(c[b+2296>>2]|0)>>>0<=k>>>0|0;c[g>>2]=r;c[b+2300>>2]=c[b+2292+(r<<2)>>2];r=c[y>>2]|0;c[r+28>>2]=k;y=(c[r+24>>2]|0)>>>0<k>>>0?6:7;c[r+96>>2]=y;k=c[r+92>>2]|0;l=(c[r+(k<<2)>>2]|0)>>>0<(c[r+(y<<2)>>2]|0)>>>0?k:y;c[r+76>>2]=l;y=c[r+72>>2]|0;k=(c[r+(y<<2)>>2]|0)>>>0<(c[r+(l<<2)>>2]|0)>>>0?y:l;c[r+64>>2]=k;l=c[r+68>>2]|0;y=(c[r+(k<<2)>>2]|0)>>>0<(c[r+(l<<2)>>2]|0)>>>0?k:l;c[r+60>>2]=y;c[r+36>>2]=c[r+(y<<2)>>2];return};case 7:{y=a[b+290|0]|0;r=b+2420|0;l=a[r]|0;k=a[b+2404|0]|0;s=b+2396|0;p=a[s]|0;do{if(((p|l)&8)==0){z=0}else{if((p&64)!=0){if((a[b+2397|0]|0)==y<<24>>24){z=0;break}}z=2}}while(0);a[s]=l;a[b+2397|0]=k;k=b+2392|0;l=c[k>>2]|0;s=l+108|0;y=c[s>>2]|z;c[s>>2]=y;do{if((a[l+116|0]|0)!=0){if((c[l+112>>2]&y|0)==0){break}s=c[l+104>>2]|0;c[l+32>>2]=s;c[l+100>>2]=8;c[l+80>>2]=8;c[l+68>>2]=8;z=c[l+64>>2]|0;p=(c[l+(z<<2)>>2]|0)>>>0<s>>>0?z:8;c[l+60>>2]=p;c[l+36>>2]=c[l+(p<<2)>>2]}}while(0);if((a[r]&8)==0){A=-1}else{r=c[b+264>>2]|0;l=ga[c[(c[b+260>>2]|0)+4>>2]&127](b|0,166,-(c[b+272>>2]|0)|0)|0;y=a[b+291|0]&1;A=(l<<y)+r+(a[b+2111|0]&1)-y|0}c[b+2340>>2]=A;y=(c[b+2336>>2]|0)>>>0<A>>>0?6:7;c[b+2388>>2]=y;A=c[b+2384>>2]|0;r=(c[b+2312+(A<<2)>>2]|0)>>>0<(c[b+2312+(y<<2)>>2]|0)>>>0?A:y;c[b+2372>>2]=r;y=c[b+2368>>2]|0;A=(c[b+2312+(y<<2)>>2]|0)>>>0<(c[b+2312+(r<<2)>>2]|0)>>>0?y:r;c[i>>2]=A;r=c[b+2312+(A<<2)>>2]|0;c[b+2344>>2]=r;c[f>>2]=r;A=(c[b+2296>>2]|0)>>>0<=r>>>0|0;c[g>>2]=A;c[b+2300>>2]=c[b+2292+(A<<2)>>2];A=c[k>>2]|0;c[A+28>>2]=r;k=(c[A+24>>2]|0)>>>0<r>>>0?6:7;c[A+96>>2]=k;r=c[A+92>>2]|0;y=(c[A+(r<<2)>>2]|0)>>>0<(c[A+(k<<2)>>2]|0)>>>0?r:k;c[A+76>>2]=y;k=c[A+72>>2]|0;r=(c[A+(k<<2)>>2]|0)>>>0<(c[A+(y<<2)>>2]|0)>>>0?k:y;c[A+64>>2]=r;y=c[A+68>>2]|0;k=(c[A+(r<<2)>>2]|0)>>>0<(c[A+(y<<2)>>2]|0)>>>0?r:y;c[A+60>>2]=k;c[A+36>>2]=c[A+(k<<2)>>2];return};case 1:{a[b+2098|0]=a[b+2097|0]|0;oU(b);c[b+2316>>2]=-1;k=(c[b+2312>>2]|0)==-1|0;c[b+2376>>2]=k;A=c[b+2380>>2]|0;y=(c[b+2312+(k<<2)>>2]|0)>>>0<(c[b+2312+(A<<2)>>2]|0)>>>0?k:A;c[b+2368>>2]=y;A=c[b+2372>>2]|0;k=(c[b+2312+(y<<2)>>2]|0)>>>0<(c[b+2312+(A<<2)>>2]|0)>>>0?y:A;c[i>>2]=k;A=c[b+2312+(k<<2)>>2]|0;c[b+2344>>2]=A;c[f>>2]=A;k=(c[b+2296>>2]|0)>>>0<=A>>>0|0;c[g>>2]=k;c[b+2300>>2]=c[b+2292+(k<<2)>>2];k=c[b+2392>>2]|0;c[k+28>>2]=A;y=(c[k+24>>2]|0)>>>0<A>>>0?6:7;c[k+96>>2]=y;A=c[k+92>>2]|0;r=(c[k+(A<<2)>>2]|0)>>>0<(c[k+(y<<2)>>2]|0)>>>0?A:y;c[k+76>>2]=r;y=c[k+72>>2]|0;A=(c[k+(y<<2)>>2]|0)>>>0<(c[k+(r<<2)>>2]|0)>>>0?y:r;c[k+64>>2]=A;r=c[k+68>>2]|0;y=(c[k+(A<<2)>>2]|0)>>>0<(c[k+(r<<2)>>2]|0)>>>0?A:r;c[k+60>>2]=y;c[k+36>>2]=c[k+(y<<2)>>2];return};case 6:{y=b+2296|0;k=b+2336|0;r=c[k>>2]|0;A=a[b+290|0]|0;l=A&255;do{if(((c[y>>2]|0)-r|0)>>>0<8){if(A<<24>>24==-103){B=2874;break}C=l+1|0;B=2875}else{if(A<<24>>24==0){B=2874}else{C=l;B=2875}}}while(0);if((B|0)==2874){if((a[b+2421|0]&16)==0){C=0;B=2875}else{D=0;E=r}}L3608:do{if((B|0)==2875){do{if((a[b+2421|0]&64)!=0){l=a[b+2404|0]|0;if(l<<24>>24==0){if(C>>>0>1){break}else{D=C;E=r;break L3608}}else{if((C|0)==((l&255)+1|0)){D=C;E=r;break L3608}else{break}}}}while(0);l=c[b+2392>>2]|0;A=l+108|0;p=c[A>>2]|2;c[A>>2]=p;do{if((a[l+116|0]|0)!=0){if((c[l+112>>2]&p|0)==0){break}A=c[l+104>>2]|0;c[l+32>>2]=A;c[l+100>>2]=8;c[l+80>>2]=8;c[l+68>>2]=8;z=c[l+64>>2]|0;s=(c[l+(z<<2)>>2]|0)>>>0<A>>>0?z:8;c[l+60>>2]=s;c[l+36>>2]=c[l+(s<<2)>>2]}}while(0);D=C;E=c[k>>2]|0}}while(0);C=a[b+2420|0]|0;a[b+2421|0]=C;if((C&8)!=0){C=(70224<<(a[b+291|0]&1))+E|0;c[k>>2]=C;r=(c[b+2340>>2]|0)>>>0>C>>>0?6:7;c[b+2388>>2]=r;C=c[b+2384>>2]|0;B=(c[b+2312+(C<<2)>>2]|0)>>>0<(c[b+2312+(r<<2)>>2]|0)>>>0?C:r;c[b+2372>>2]=B;r=c[b+2368>>2]|0;C=(c[b+2312+(r<<2)>>2]|0)>>>0<(c[b+2312+(B<<2)>>2]|0)>>>0?r:B;c[i>>2]=C;B=c[b+2312+(C<<2)>>2]|0;c[b+2344>>2]=B;c[f>>2]=B;C=(c[y>>2]|0)>>>0<=B>>>0|0;c[g>>2]=C;c[b+2300>>2]=c[b+2292+(C<<2)>>2];C=c[b+2392>>2]|0;c[C+28>>2]=B;r=(c[C+24>>2]|0)>>>0<B>>>0?6:7;c[C+96>>2]=r;B=c[C+92>>2]|0;l=(c[C+(B<<2)>>2]|0)>>>0<(c[C+(r<<2)>>2]|0)>>>0?B:r;c[C+76>>2]=l;r=c[C+72>>2]|0;B=(c[C+(r<<2)>>2]|0)>>>0<(c[C+(l<<2)>>2]|0)>>>0?r:l;c[C+64>>2]=B;l=c[C+68>>2]|0;r=(c[C+(B<<2)>>2]|0)>>>0<(c[C+(l<<2)>>2]|0)>>>0?B:l;c[C+60>>2]=r;c[C+36>>2]=c[C+(r<<2)>>2];return}r=e[b+288>>1]|0;C=r+E|0;if((D|0)==0){F=C-4|0}else if((D|0)==143){F=(r*10|0)+4+C|0}else{F=C}c[k>>2]=F;k=(c[b+2340>>2]|0)>>>0>F>>>0?6:7;c[b+2388>>2]=k;F=c[b+2384>>2]|0;C=(c[b+2312+(F<<2)>>2]|0)>>>0<(c[b+2312+(k<<2)>>2]|0)>>>0?F:k;c[b+2372>>2]=C;k=c[b+2368>>2]|0;F=(c[b+2312+(k<<2)>>2]|0)>>>0<(c[b+2312+(C<<2)>>2]|0)>>>0?k:C;c[i>>2]=F;C=c[b+2312+(F<<2)>>2]|0;c[b+2344>>2]=C;c[f>>2]=C;F=(c[y>>2]|0)>>>0<=C>>>0|0;c[g>>2]=F;c[b+2300>>2]=c[b+2292+(F<<2)>>2];F=c[b+2392>>2]|0;c[F+28>>2]=C;y=(c[F+24>>2]|0)>>>0<C>>>0?6:7;c[F+96>>2]=y;C=c[F+92>>2]|0;k=(c[F+(C<<2)>>2]|0)>>>0<(c[F+(y<<2)>>2]|0)>>>0?C:y;c[F+76>>2]=k;y=c[F+72>>2]|0;C=(c[F+(y<<2)>>2]|0)>>>0<(c[F+(k<<2)>>2]|0)>>>0?y:k;c[F+64>>2]=C;k=c[F+68>>2]|0;y=(c[F+(C<<2)>>2]|0)>>>0<(c[F+(k<<2)>>2]|0)>>>0?C:k;c[F+60>>2]=y;c[F+36>>2]=c[F+(y<<2)>>2];return};case 3:{y=b+2400|0;F=b+284|0;k=b+2407|0;C=a[k]|0;r=a[b+2405|0]|0;do{if(((r|C)&64)==0){G=b+2406|0;H=y|0;I=0}else{D=y|0;if(((c[F>>2]|0)-(c[D>>2]|0)|0)>>>0<(e[b+288>>1]|0)>>>0){J=0}else{J=d[b+290|0]|0}E=b+2406|0;if((d[E]|0)!=(J|0)){G=E;H=D;I=0;break}l=C&255;if((J-1|0)>>>0<143){if((l&32|0)!=0){G=E;H=D;I=0;break}}else{if((l&16|0)!=0){G=E;H=D;I=0;break}}G=E;H=D;I=2}}while(0);J=a[b+2404|0]|0;a[G]=J;a[k]=r;k=J&255;G=c[H>>2]|0;if((r&64)!=0&(J&255)<154){if(J<<24>>24==0){L=69776}else{L=k*456|0}k=a[b+291|0]&1;J=(((153-(d[b+290|0]|0)|0)*456|0)+L<<k)+(c[F>>2]|0)|0;F=70224<<k;M=J-((J-G|0)>>>0>F>>>0?F:0)|0}else{M=-1}c[H>>2]=M;M=b+2392|0;H=c[M>>2]|0;F=H+108|0;G=c[F>>2]|I;c[F>>2]=G;do{if((a[H+116|0]|0)!=0){if((c[H+112>>2]&G|0)==0){break}F=c[H+104>>2]|0;c[H+32>>2]=F;c[H+100>>2]=8;c[H+80>>2]=8;c[H+68>>2]=8;I=c[H+64>>2]|0;J=(c[H+(I<<2)>>2]|0)>>>0<F>>>0?I:8;c[H+60>>2]=J;c[H+36>>2]=c[H+(J<<2)>>2]}}while(0);H=c[y>>2]|0;c[b+2324>>2]=H;y=(c[b+2320>>2]|0)>>>0<H>>>0?2:3;c[b+2380>>2]=y;H=c[b+2376>>2]|0;G=(c[b+2312+(H<<2)>>2]|0)>>>0<(c[b+2312+(y<<2)>>2]|0)>>>0?H:y;c[b+2368>>2]=G;y=c[b+2372>>2]|0;H=(c[b+2312+(G<<2)>>2]|0)>>>0<(c[b+2312+(y<<2)>>2]|0)>>>0?G:y;c[i>>2]=H;y=c[b+2312+(H<<2)>>2]|0;c[b+2344>>2]=y;c[f>>2]=y;H=(c[b+2296>>2]|0)>>>0<=y>>>0|0;c[g>>2]=H;c[b+2300>>2]=c[b+2292+(H<<2)>>2];H=c[M>>2]|0;c[H+28>>2]=y;M=(c[H+24>>2]|0)>>>0<y>>>0?6:7;c[H+96>>2]=M;y=c[H+92>>2]|0;G=(c[H+(y<<2)>>2]|0)>>>0<(c[H+(M<<2)>>2]|0)>>>0?y:M;c[H+76>>2]=G;M=c[H+72>>2]|0;y=(c[H+(M<<2)>>2]|0)>>>0<(c[H+(G<<2)>>2]|0)>>>0?M:G;c[H+64>>2]=y;G=c[H+68>>2]|0;M=(c[H+(y<<2)>>2]|0)>>>0<(c[H+(G<<2)>>2]|0)>>>0?y:G;c[H+60>>2]=M;c[H+36>>2]=c[H+(M<<2)>>2];return};case 5:{M=b+2392|0;H=c[M>>2]|0;c[H+20>>2]=0;c[H+92>>2]=5;G=c[H+96>>2]|0;y=(c[H+(G<<2)>>2]|0)!=0?5:G;c[H+76>>2]=y;G=c[H+72>>2]|0;J=(c[H+(G<<2)>>2]|0)>>>0<(c[H+(y<<2)>>2]|0)>>>0?G:y;c[H+64>>2]=J;y=c[H+68>>2]|0;G=(c[H+(J<<2)>>2]|0)>>>0<(c[H+(y<<2)>>2]|0)>>>0?J:y;c[H+60>>2]=G;c[H+36>>2]=c[H+(G<<2)>>2];G=c[b+264>>2]|0;H=ga[c[(c[b+260>>2]|0)+4>>2]&127](b|0,167,-(c[b+272>>2]|0)|0)|0;y=a[b+291|0]&1;J=(H<<y)+G|0;c[b+2412>>2]=J;G=(y^1)+J|0;c[b+2332>>2]=G;J=(c[b+2328>>2]|0)>>>0<G>>>0?4:5;c[b+2384>>2]=J;G=c[b+2388>>2]|0;y=(c[b+2312+(J<<2)>>2]|0)>>>0<(c[b+2312+(G<<2)>>2]|0)>>>0?J:G;c[b+2372>>2]=y;G=c[b+2368>>2]|0;J=(c[b+2312+(G<<2)>>2]|0)>>>0<(c[b+2312+(y<<2)>>2]|0)>>>0?G:y;c[i>>2]=J;i=c[b+2312+(J<<2)>>2]|0;c[b+2344>>2]=i;c[f>>2]=i;J=(c[b+2296>>2]|0)>>>0<=i>>>0|0;c[g>>2]=J;c[b+2300>>2]=c[b+2292+(J<<2)>>2];J=c[M>>2]|0;c[J+28>>2]=i;M=(c[J+24>>2]|0)>>>0<i>>>0?6:7;c[J+96>>2]=M;i=c[J+92>>2]|0;y=(c[J+(i<<2)>>2]|0)>>>0<(c[J+(M<<2)>>2]|0)>>>0?i:M;c[J+76>>2]=y;M=c[J+72>>2]|0;i=(c[J+(M<<2)>>2]|0)>>>0<(c[J+(y<<2)>>2]|0)>>>0?M:y;c[J+64>>2]=i;y=c[J+68>>2]|0;M=(c[J+(i<<2)>>2]|0)>>>0<(c[J+(y<<2)>>2]|0)>>>0?i:y;c[J+60>>2]=M;c[J+36>>2]=c[J+(M<<2)>>2];return};default:{return}}}else if((h|0)==1){h=b+290|0;M=(a[h]|0)+1&255;a[h]=M<<24>>24==-102?0:M;M=b+284|0;h=(e[b+288>>1]|0)+(c[M>>2]|0)|0;c[M>>2]=h;c[b+2296>>2]=h;M=(c[f>>2]|0)>>>0>=h>>>0|0;c[g>>2]=M;c[b+2300>>2]=c[b+2292+(M<<2)>>2];return}else{return}}function oZ(a){a=a|0;return}function o_(a){a=a|0;return}function o$(a){a=a|0;return}function o0(a){a=a|0;return}function o1(a){a=a|0;return}function o2(a){a=a|0;var b=0;b=(c[a>>2]|0)>>>0>=(c[a+4>>2]|0)>>>0|0;c[a+16>>2]=b;c[a+8>>2]=c[a+(b<<2)>>2];return}function o3(a){a=a|0;var b=0,d=0,e=0;b=(c[a+16>>2]|0)>>>0<(c[a+20>>2]|0)>>>0?4:5;c[a+72>>2]=b;d=c[a+76>>2]|0;e=(c[a+(b<<2)>>2]|0)>>>0<(c[a+(d<<2)>>2]|0)>>>0?b:d;c[a+60>>2]=e;d=c[a+56>>2]|0;b=(c[a+(d<<2)>>2]|0)>>>0<(c[a+(e<<2)>>2]|0)>>>0?d:e;c[a+52>>2]=b;c[a+32>>2]=c[a+(b<<2)>>2];return}function o4(a){a=a|0;var b=0,d=0,e=0;b=(c[a+24>>2]|0)>>>0<(c[a+28>>2]|0)>>>0?6:7;c[a+76>>2]=b;d=c[a+72>>2]|0;e=(c[a+(d<<2)>>2]|0)>>>0<(c[a+(b<<2)>>2]|0)>>>0?d:b;c[a+60>>2]=e;b=c[a+56>>2]|0;d=(c[a+(b<<2)>>2]|0)>>>0<(c[a+(e<<2)>>2]|0)>>>0?b:e;c[a+52>>2]=d;c[a+32>>2]=c[a+(d<<2)>>2];return}function o5(a){a=a|0;var b=0,d=0,e=0;b=(c[a+8>>2]|0)>>>0<(c[a+12>>2]|0)>>>0?2:3;c[a+68>>2]=b;d=c[a+64>>2]|0;e=(c[a+(d<<2)>>2]|0)>>>0<(c[a+(b<<2)>>2]|0)>>>0?d:b;c[a+56>>2]=e;b=c[a+60>>2]|0;d=(c[a+(e<<2)>>2]|0)>>>0<(c[a+(b<<2)>>2]|0)>>>0?e:b;c[a+52>>2]=d;c[a+32>>2]=c[a+(d<<2)>>2];return}function o6(a){a=a|0;var b=0,d=0,e=0;b=(c[a>>2]|0)>>>0>=(c[a+4>>2]|0)>>>0|0;c[a+64>>2]=b;d=c[a+68>>2]|0;e=(c[a+(b<<2)>>2]|0)>>>0<(c[a+(d<<2)>>2]|0)>>>0?b:d;c[a+56>>2]=e;d=c[a+60>>2]|0;b=(c[a+(e<<2)>>2]|0)>>>0<(c[a+(d<<2)>>2]|0)>>>0?e:d;c[a+52>>2]=b;c[a+32>>2]=c[a+(b<<2)>>2];return}function o7(a,b){a=a|0;b=b|0;b=a+4|0;a=c[b>>2]|0;if((a|0)==-1){return}c[b>>2]=a^-2147483648;return}function o8(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=c[b+4>>2]|0;do{if((c[g+104>>2]|0)!=0){if((a[g+113|0]&1)==0){break}if((a[g+73|0]|0)==0){break}h=c[b+8>>2]|0;i=h+8|0;j=c[i>>2]|0;if(j>>>0>f>>>0){k=j;l=a[h+14|0]|0}else{m=e[h+12>>1]|0;n=(((f-j|0)>>>0)/(m>>>0)|0)+1|0;o=(ag(n,m)|0)+j|0;c[i>>2]=o;i=h+14|0;j=(d[i]|0)+n&7;a[i]=j;k=o;l=j}j=d[h+15|0]|0;o=l&255;a[h+16|0]=(d[72384+j|0]&1<<o|0)!=0|0;a[h+17|0]=1;if((k|0)==-1){c[h+4>>2]=-1;return}else{c[h+4>>2]=(ag(d[56824+(j<<3|o)|0]|0,e[h+12>>1]|0)|0)+k;return}}}while(0);k=c[b+8>>2]|0;a[k+17|0]=0;c[k+4>>2]=-1;return}function o9(b){b=b|0;var d=0;a[c[b+4>>2]|0]=0;d=c[b+8>>2]|0;a[d+17|0]=0;c[d+4>>2]=-1;return}function pa(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=c[b+4>>2]|0;do{if((c[g+84>>2]|0)!=0){if((a[g+93|0]&1)==0){break}if((a[g+73|0]|0)==0){break}h=c[b+8>>2]|0;i=h+8|0;j=c[i>>2]|0;if(j>>>0>f>>>0){k=j;l=a[h+14|0]|0}else{m=e[h+12>>1]|0;n=(((f-j|0)>>>0)/(m>>>0)|0)+1|0;o=(ag(n,m)|0)+j|0;c[i>>2]=o;i=h+14|0;j=(d[i]|0)+n&7;a[i]=j;k=o;l=j}j=d[h+15|0]|0;o=l&255;a[h+16|0]=(d[72384+j|0]&1<<o|0)!=0|0;a[h+17|0]=1;if((k|0)==-1){c[h+4>>2]=-1;return}else{c[h+4>>2]=(ag(d[56824+(j<<3|o)|0]|0,e[h+12>>1]|0)|0)+k;return}}}while(0);k=c[b+8>>2]|0;a[k+17|0]=0;c[k+4>>2]=-1;return}function pb(b){b=b|0;a[c[b+4>>2]|0]=0;c[c[b+8>>2]>>2]=-1;return}function pc(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d+8|0;h=c[g>>2]|0;if(h>>>0>f>>>0){return}i=a[d+14|0]|0;j=i&255;k=j&7;l=(k|0)==0;m=(l?1:k)<<(l?2:3)+(j>>>4);j=(((f-h|0)>>>0)/(m>>>0)|0)+1|0;c[g>>2]=(ag(m,j)|0)+h;if(!((a[d+15|0]&1)!=0&(i&255)<224)){return}if((i&8)==0){i=d+12|0;h=b[i>>1]|0;if(j>>>0>15){m=j;g=h;do{g=(g&65535)>>>1^g;m=m-15|0;}while(m>>>0>15);b[i>>1]=g;n=m;o=g}else{n=j;o=h}h=o&65535;b[i>>1]=((h>>>1^h)<<15-n&32767|h>>>(n>>>0))&65535;return}else{n=d+12|0;d=e[n>>1]|0;if(j>>>0>6){h=j;i=d;do{o=(i<<1^i)&126;i=o|i>>>6&897|o<<8;h=h-6|0;}while(h>>>0>6);b[n>>1]=i&65535;p=h;q=i}else{p=j;q=d}d=(q>>>1^q)<<7-p&127;b[n>>1]=(d|(128>>>(p>>>0))+65407&q>>>(p>>>0)|d<<8)&65535;return}}function pd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((a[b+33|0]&64)==0){e=fp(0)|0;f=(e|0)<0?-1:0;g=e}else{e=b+24|0;f=c[e+4>>2]|0;g=c[e>>2]|0}e=b+16|0;b=c[e>>2]|0;h=c[e+4>>2]|0;i=yM(g,f,b,h)|0;f=yX(i,K,60,0)|0;i=K;g=yM(b,h,d,0)|0;d=yL(g,K,f,i)|0;c[e>>2]=d;c[e+4>>2]=K;return}function pe(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((a[b+33|0]&64)==0){e=fp(0)|0;f=(e|0)<0?-1:0;g=e}else{e=b+24|0;f=c[e+4>>2]|0;g=c[e>>2]|0}e=b+16|0;b=c[e>>2]|0;h=c[e+4>>2]|0;i=yM(g,f,b,h)|0;f=yW(i,K,60,0)|0;i=yX(f,K,60,0)|0;f=yV(i,K,60,0)|0;i=K;g=yM(b,h,d*60|0,0)|0;d=yL(g,K,f,i)|0;c[e>>2]=d;c[e+4>>2]=K;return}function pf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((a[b+33|0]&64)==0){e=fp(0)|0;f=(e|0)<0?-1:0;g=e}else{e=b+24|0;f=c[e+4>>2]|0;g=c[e>>2]|0}e=b+16|0;b=c[e>>2]|0;h=c[e+4>>2]|0;i=yM(g,f,b,h)|0;f=yW(i,K,3600,0)|0;i=yX(f,K,24,0)|0;f=yV(i,K,3600,0)|0;i=K;g=yM(b,h,d*3600|0,0)|0;d=yL(g,K,f,i)|0;c[e>>2]=d;c[e+4>>2]=K;return}function pg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((a[b+33|0]&64)==0){e=fp(0)|0;f=(e|0)<0?-1:0;g=e}else{e=b+24|0;f=c[e+4>>2]|0;g=c[e>>2]|0}e=b+16|0;b=c[e>>2]|0;h=c[e+4>>2]|0;i=yM(g,f,b,h)|0;f=yW(i,K,86400,0)|0;i=yV(f&255,K&0,86400,0)|0;f=K;g=yM(b,h,d*86400|0,0)|0;d=yL(g,K,i,f)|0;c[e>>2]=d;c[e+4>>2]=K;return}function ph(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b+33|0;f=a[e]|0;if((f&64)==0){g=fp(0)|0;h=(g|0)<0?-1:0;i=g;j=a[e]|0}else{e=b+24|0;h=c[e+4>>2]|0;i=c[e>>2]|0;j=f}f=b+16|0;e=c[f>>2]|0;g=c[f+4>>2]|0;k=yM(i,h,e,g)|0;h=yW(k,K,86400,0)|0;k=yV(h&256,K&0,86400,0)|0;h=K;i=yM(e,g,(d<<8&256)*86400|0,0)|0;g=yL(i,K,k,h)|0;c[f>>2]=g;c[f+4>>2]=K;if(((j&255^d)&64|0)==0){return}j=fp(0)|0;g=j;h=(j|0)<0?-1:0;j=b+24|0;if((d&64|0)==0){d=yM(g,h,c[j>>2]|0,c[j+4>>2]|0)|0;b=yL(d,K,c[f>>2]|0,c[f+4>>2]|0)|0;c[f>>2]=b;c[f+4>>2]=K;return}else{c[j>>2]=g;c[j+4>>2]=h;return}}function pi(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+18|0;h=a[g]|0;i=h&255;j=i>>>4&7;if((j|0)==0){k=f+4|0;c[k>>2]=(c[k>>2]|0)+131072;return}k=f+16|0;l=e[k>>1]|0;m=l>>>((i&7)>>>0);if((i&8|0)==0){n=m+l|0}else{a[f+19|0]=1;n=l-m|0}do{if((n&2048|0)==0){if((h&7)==0){break}b[k>>1]=n&65535;m=c[f+12>>2]|0;l=c[f+4>>2]|0;i=m+8|0;o=c[i>>2]|0;if(o>>>0>l>>>0){p=o;q=m+12|0}else{r=m+12|0;s=e[r>>1]|0;t=(((l-o|0)>>>0)/(s>>>0)|0)+1|0;l=(ag(t,s)|0)+o|0;c[i>>2]=l;i=m+14|0;a[i]=(d[i]|0)+t&7;p=l;q=r}r=2048-n<<1;b[q>>1]=r&65535;if((a[m+17|0]&1)==0|(p|0)==-1){c[m+4>>2]=-1}else{c[m+4>>2]=(ag(d[56824+((d[m+15|0]|0)<<3|(d[m+14|0]|0))|0]|0,r&65534)|0)+p}r=e[k>>1]|0;m=d[g]|0;l=r>>>((m&7)>>>0);if((m&8|0)==0){u=l+r|0}else{a[f+19|0]=1;u=r-l|0}if((u&2048|0)==0){break}l=c[f+8>>2]|0;f2[c[(c[l>>2]|0)+8>>2]&1023](l)}else{l=c[f+8>>2]|0;f2[c[(c[l>>2]|0)+8>>2]&1023](l)}}while(0);u=f+4|0;c[u>>2]=(c[u>>2]|0)+(j<<14);return}function pj(a){a=a|0;if((a|0)==0){return}yt(a);return}function pk(a){a=a|0;if((a|0)==0){return}yt(a);return}function pl(a){a=a|0;if((a|0)==0){return}yt(a);return}function pm(a){a=a|0;if((a|0)==0){return}yt(a);return}function pn(a){a=a|0;if((a|0)==0){return}yt(a);return}function po(a){a=a|0;return}function pp(a){a=a|0;return}function pq(a){a=a|0;return}function pr(a){a=a|0;return}function ps(a){a=a|0;return}function pt(a){a=a|0;return}function pu(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;f=a[d+14|0]|0;do{if((f&255)<224){g=d+12|0;h=e[g>>1]|0;i=h>>>1;j=(i^h)&1;h=j<<14|i;b[g>>1]=h&65535;if((f&8)==0){break}b[g>>1]=(h&32703|j<<6)&65535}}while(0);j=f&255;f=j&7;h=(f|0)==0;g=d+4|0;i=(c[g>>2]|0)+((h?1:f)<<(h?2:3)+(j>>>4))|0;c[g>>2]=i;c[d+8>>2]=i;return}function pv(d){d=d|0;var e=0;a[c[d+4>>2]|0]=0;e=c[d+8>>2]|0;c[e+4>>2]=-1;a[e+15|0]=0;b[e+12>>1]=255;return}function pw(b){b=b|0;var d=0,f=0,g=0,h=0,i=0;d=e[b+12>>1]|0;f=a[b+15|0]|0;g=d<<(f&255);if(f<<24>>24==3){h=g-(d<<1)|0}else{h=g}g=b+16|0;f=a[g]&1;a[g]=f^1;if(f<<24>>24==0){i=h}else{i=(d<<3)-h|0}h=b+4|0;c[h>>2]=(c[h>>2]|0)+i;return}function px(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=f+12|0;j=e[i>>1]|0;k=f+8|0;l=c[k>>2]|0;if(l>>>0>h>>>0){m=l}else{n=(((h-l|0)>>>0)/(j>>>0)|0)+1|0;o=(ag(n,j)|0)+l|0;c[k>>2]=o;l=f+14|0;a[l]=(d[l]|0)+n&7;m=o}o=2048-(-(j>>>1)&255|g<<8&1792)<<1;b[i>>1]=o&65535;i=(a[f+17|0]&1)==0;if(i|(m|0)==-1){c[f+4>>2]=-1}else{c[f+4>>2]=(ag(d[56824+((d[f+15|0]|0)<<3|(d[f+14|0]|0))|0]|0,o)|0)+m}if((g&128|0)==0){return}g=o+(h&-2)|0;c[k>>2]=g;if(i|(g|0)==-1){c[f+4>>2]=-1;return}else{c[f+4>>2]=(ag(d[56824+((d[f+15|0]|0)<<3|(d[f+14|0]|0))|0]|0,o)|0)+g;return}}function py(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=b+8|0;h=c[g>>2]|0;if((h|0)==-1){return}if(h>>>0>f>>>0){i=h}else{j=e[b+12>>1]|0;k=(((f-h|0)>>>0)/(j>>>0)|0)+1|0;f=(ag(k,j)|0)+h|0;c[g>>2]=f;h=b+14|0;a[h]=(d[h]|0)+k&7;i=f}c[g>>2]=i^-2147483648;i=b+4|0;b=c[i>>2]|0;if((b|0)==-1){return}c[i>>2]=b^-2147483648;return}function pz(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((e&64|0)!=0&f>>>0<154){if((f|0)==0){i=69776}else{i=f*456|0}j=a[g+7|0]&1;k=(((153-(d[g+6|0]|0)|0)*456|0)+i<<j)+(c[g>>2]|0)|0;i=70224<<j;l=k-((k-h|0)>>>0>i>>>0?i:0)|0}else{l=-1}i=e&255;a[b+5|0]=i;k=f&255;a[b+4|0]=k;f=b|0;j=c[f>>2]|0;m=l>>>0<j>>>0?l:j;c[f>>2]=m;f=m-h|0;if((a[b+8|0]&1)==0){if(!(f>>>0<5&(l|0)==(m|0))){a[b+6|0]=k}do{if(f>>>0>4){n=3108}else{if((a[b+6|0]|0)!=0){n=3108;break}o=a[b+7|0]|0}}while(0);if((n|0)==3108){a[b+7|0]=i;o=i}a[b+7|0]=(o&64|e&191)&255;return}else{do{if(f>>>0>8){n=3100}else{if((l|0)==(m|0)){break}if(f>>>0>(4-((a[g+7|0]&1)<<2)|0)>>>0){n=3100}}}while(0);if((n|0)==3100){a[b+6|0]=k}if(f>>>0<=(4-((a[g+7|0]&1)<<2)|0)>>>0){return}a[b+7|0]=i;return}}function pA(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=a[b+6|0]|0;h=g&255;if((a[b+7|0]&64)!=0&(g&255)<154){if(g<<24>>24==0){i=69776}else{i=h*456|0}h=a[e+7|0]&1;g=(((153-(d[e+6|0]|0)|0)*456|0)+i<<h)+(c[e>>2]|0)|0;i=70224<<h;j=g-((g-f|0)>>>0>i>>>0?i:0)|0}else{j=-1}i=a[b+4|0]|0;if(!((a[b+5|0]&64)!=0&(i&255)<154)){k=-1;l=k>>>0<j>>>0;m=l?k:j;n=b|0;c[n>>2]=m;return}if(i<<24>>24==0){o=69776}else{o=(i&255)*456|0}i=a[e+7|0]&1;g=(((153-(d[e+6|0]|0)|0)*456|0)+o<<i)+(c[e>>2]|0)|0;e=70224<<i;k=g-((g-f|0)>>>0>e>>>0?e:0)|0;l=k>>>0<j>>>0;m=l?k:j;n=b|0;c[n>>2]=m;return}function pB(a,b){a=a|0;b=b|0;pc(a,b);b=a+8|0;c[b>>2]=c[b>>2]^-2147483648;b=a+4|0;a=c[b>>2]|0;if((a|0)==-1){return}c[b>>2]=a^-2147483648;return}function pC(a){a=a|0;if((a|0)==0){return}yt(a);return}function pD(a){a=a|0;if((a|0)==0){return}yt(a);return}function pE(b,d){b=b|0;d=d|0;var e=0,f=0;e=c[b+4>>2]|0;do{if((c[e+80>>2]|0)!=0){if((a[e+89|0]&1)==0){break}if((a[e+53|0]|0)==0){break}f=c[b+8>>2]|0;pc(f,d);c[f+4>>2]=c[f+8>>2];return}}while(0);c[(c[b+8>>2]|0)+4>>2]=-1;return}function pF(a){a=a|0;if((a|0)==0){return}yt(a);return}function pG(a){a=a|0;if((a|0)==0){return}yt(a);return}function pH(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=d[b+12|0]|0;f=e&7;if((f|0)==0){g=b+4|0;c[g>>2]=(c[g>>2]|0)+262144;return}g=b+13|0;h=(e>>>2&2)-1+(d[g]|0)|0;if(h>>>0>=16){c[b+4>>2]=-1;return}a[g]=h&255;if((h&254)>>>0<2){h=c[b+8>>2]|0;g=b+4|0;f3[c[(c[h>>2]|0)+8>>2]&1023](h,c[g>>2]|0);i=g}else{i=b+4|0}c[i>>2]=(c[i>>2]|0)+(f<<15);return}function pI(a){a=a|0;if((a|0)==0){return}yt(a);return}function pJ(a){a=a|0;var d=0;c[a+4>>2]=-1;b[a+12>>1]=0;d=c[a+8>>2]|0;f2[c[(c[d>>2]|0)+8>>2]&1023](d);return}function pK(a){a=a|0;if((a|0)==0){return}yt(a);return}function pL(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=b+2094|0;h=d[g]|0;i=h^e;j=e&128;do{if((i&j|0)==0){if((i&32|0)==0){break}k=b+2100|0;l=a[k]|0;if((e&32|0)!=0){if(l<<24>>24!=1){break}a[k]=3;m=b+2102|0;a[m]=(a[m]|0)+1&255;break}if(l<<24>>24!=2){if((a[b+2109|0]|0)!=-88){break}}a[k]=l&-3}else{c[b+264>>2]=f;c[b+268>>2]=0;a[b+290|0]=0;l=a[b+291|0]&1;c[b+284>>2]=(456<<l)+f;yB(b+1880|0,0,120);c[b+2008>>2]=(80<<(a[(c[b+2e3>>2]|0)+7|0]&1))+f;a[b+2012|0]=80;if((e&32|0)==0){n=0}else{n=(a[b+2097|0]|0)==0|0}a[b+2112|0]=n;a[b+2100|0]=0;c[b+260>>2]=83976;c[b+272>>2]=-83-(-l&3)}}while(0);if((i&4|0)==0){o=e&255;a[g]=o;return}if((h&j|0)!=0){qC(b+1880|0,f);f=c[b+2e3>>2]|0;j=a[f+7|0]&1;h=459-(((c[f>>2]|0)-(c[b+2008>>2]|0)|0)>>>(j>>>0))-(-j&3)|0;j=h>>>0>455?h-456|0:h;a[b+2012|0]=j>>>0>80?80:j&255}a[b+2013|0]=e>>>2&1;o=e&255;a[g]=o;return}function pM(b){b=b|0;var e=0,f=0,g=0;e=a[b+2094|0]|0;if((e&32)==0){f=0}else{f=((d[b+290|0]|0)+1|0)==(d[b+2097|0]|0|0)|0}g=b+2112|0;a[g]=a[g]&1|f;f=b+272|0;g=(c[f>>2]|0)-83-(a[b+2111|0]&1|2)|0;c[f>>2]=g;if((g|0)<=-1){c[b+260>>2]=83976;return}a[b+2109|0]=0;g=b+2100|0;if(((e&255)>>>5&1&(d[g]|0)|0)==0){a[g]=0}else{a[g]=2;a[b+2101|0]=a[b+2096|0]&7|8;g=b+2102|0;a[g]=(a[g]|0)+1&255}c[b+260>>2]=83960;pT(b);return}function pN(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0;f=(d[b+290|0]|0)+1|0;g=a[b+2094|0]|0;if((g&32)==0){h=0}else{h=(f|0)==(d[b+2097|0]|0|0)|0}i=a[b+2096|0]&7;return pO(b,0,8-i|0,f,0,(h|a[b+2112|0]&1|0)!=0,((g&255)>>>5&a[b+2100|0])<<1&2,i>>>0>5?5:i,c,e+86+i|0)|0}function pO(b,c,e,f,g,h,i,j,k,l){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;L4006:do{if((i&1)==0){m=i}else{do{if((c|0)>=167){if((a[b+2111|0]&1)!=0){break}m=(a[b+2094|0]&32)==0?i&-3:i;break L4006}}while(0);n=i&2;o=a[b+2094|0]|0;if(n<<24>>24==0){m=(o&32)==0?0:n;break}p=pP(b,c,e,f,g,h,(o&255)>>>4&2,0,k,l)|0;return p|0}}while(0);if((c|0)>(k|0)){p=pQ(b,m&255,k)|0;return p|0}i=k-c|0;o=i+l|0;l=a[b+2099|0]|0;n=l&255;q=a[b+2094|0]|0;do{if((n-c|0)>>>0<i>>>0){if((q&32)==0){r=255;s=o;break}if(!h){if((d[b+2098|0]|0|0)!=(f|0)){r=255;s=o;break}}if((m&2)!=0){r=255;s=o;break}t=(a[b+2111|0]&1)==0&l<<24>>24==-90;r=t?255:n;s=t?o:o+6|0}else{r=255;s=o}}while(0);if((a[b+2111|0]&1|q&2|0)==0){p=s;return p|0}q=b+1732+f|0;o=a[q]|0;do{if(o<<24>>24<0){n=o&127;a[q]=n;l=f*10|0;m=b+292+l|0;h=(n&255)+l|0;i=b+292+h|0;if((l|0)>=(h|0)){u=n;v=l;break}t=l|1;if((t|0)>=(h|0)){u=n;v=l;break}n=b+292+t|0;do{t=a[n]|0;L4037:do{if((n|0)==(m|0)){w=m}else{h=(t&255)+1+(b+1880)|0;x=n;while(1){y=x-1|0;z=a[y]|0;if((d[h]|0)>=(d[(z&255)+1+(b+1880)|0]|0)){w=x;break L4037}a[x]=z;if((y|0)==(m|0)){w=m;break}else{x=y}}}}while(0);a[w]=t;n=n+1|0;}while(n>>>0<i>>>0);u=a[q]|0;v=l}else{u=o;v=f*10|0}}while(0);f=u&127;u=f+v+(b+292)|0;o=v+g+(b+292)|0;if((f|0)<=(g|0)){p=s;return p|0}f=d[(d[o]|0)+1+(b+1880)|0]|0;q=e&7;e=c-q&-8;w=f+(j-c)|0;if((w|0)>4|f>>>0>r>>>0){A=o;B=s}else{A=g+1+v+(b+292)|0;B=s+11-w|0}if((r|0)<(k|0)){L4053:do{if(A>>>0<u>>>0){w=0;s=e;v=A;while(1){g=d[(d[v]|0)+1+(b+1880)|0]|0;if(g>>>0>r>>>0){C=w;D=v;break L4053}o=g-q|0;g=o&7;f=o&-8;o=(g>>>0>4|(f|0)==(s|0)?6:11-g|0)+w|0;g=v+1|0;if(g>>>0<u>>>0){w=o;s=f;v=g}else{C=o;D=g;break}}}else{C=0;D=A}}while(0);E=1;F=r+1|0;G=D;H=C+B|0}else{E=e;F=q;G=A;H=B}L4059:do{if(G>>>0<u>>>0){B=0;A=E;q=G;while(1){e=d[(d[q]|0)+1+(b+1880)|0]|0;if(e>>>0>k>>>0){I=B;break L4059}C=e-F|0;e=C&7;D=C&-8;C=(e>>>0>4|(D|0)==(A|0)?6:11-e|0)+B|0;e=q+1|0;if(e>>>0<u>>>0){B=C;A=D;q=e}else{I=C;break}}}else{I=0}}while(0);p=I+H|0;return p|0}function pP(b,c,e,f,g,h,i,j,k,l){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c|0)>(k|0)){m=pQ(b,i,k)|0;return m|0}n=6-j|0;j=d[b+2094|0]|0;do{if((j&32|0)==0){o=a[b+2111|0]&1;if(o<<24>>24==0){p=n;q=c;break}r=k+1|0;s=((r|0)<(e|0)?r:e)-c|0;r=(s|0)<(n|0)?s:n;if((o&255|j&2|0)==0){t=r+c|0}else{o=d[b+2028+(g<<2)|0]|0;s=r+c|0;if(o>>>0<s>>>0){p=n;q=o;break}else{t=s}}p=r;q=t}else{p=n;q=c}}while(0);c=p+l|0;if((q|0)>(k|0)){m=c-1|0;return m|0}else{m=pO(b,q,(q|0)<160?q+8|0:168,f,g,h,i&255,0,k,c)|0;return m|0}return 0}function pQ(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;do{if((a[b+2099|0]|0)==-90){if((a[b+2111|0]&1)!=0){g=e;break}if((d[b+2109|0]|0)>=167){g=e;break}if((a[b+2112|0]&1)==0){if((a[b+2098|0]|0)!=(a[b+290|0]|0)){g=e;break}h=a[b+2094|0]|0;if((h&32)==0){g=e;break}else{i=h}}else{i=a[b+2094|0]|0}g=(i&255)>>>4&2|1}else{g=e}}while(0);e=a[b+291|0]&1;i=c[b+284>>2]|0;if(e<<24>>24==0){j=i-6-(a[b+2111|0]&1)|0}else{j=i-8|0}i=a[b+290|0]|0;if(i<<24>>24==-113){h=a[b+2111|0]&1;k=e&255;l=a[b+2094|0]|0;if((l&32)==0){m=0}else{m=(a[b+2097|0]|0)==0}n=a[b+2096|0]&7;o=pO(b,0,8-n|0,0,0,m,((l&255)>>>5&g)<<1&2,n>>>0>5?5:n,f,((j-(c[b+264>>2]|0)+((h|4566)<<k)|0)>>>(k>>>0))+84+n-h|0)|0;return o|0}h=(j-(c[b+264>>2]|0)|0)>>>((e&255)>>>0);e=a[b+2094|0]|0;j=e&32;do{if((a[b+2112|0]&1)==0){if(j<<24>>24==0){p=0;q=0;r=(i&255)+1|0;break}else{s=i<<24>>24==(a[b+2097|0]|0)|0;t=3291;break}}else{s=1;t=3291}}while(0);do{if((t|0)==3291){n=(i&255)+1|0;if(j<<24>>24==0){p=0;q=s;r=n;break}p=(n|0)==(d[b+2097|0]|0)|0;q=s;r=n}}while(0);s=a[b+2096|0]&7;o=pO(b,0,8-s|0,r,0,(p|q|0)!=0,((e&255)>>>5&g)<<1&2,s>>>0>5?5:s,f,h+90+s|0)|0;return o|0}function pR(b){b=b|0;var d=0,e=0;if((a[b+2094|0]&32)==0){d=0}else{d=(a[b+290|0]|0)==(a[b+2097|0]|0)|0}e=b+2112|0;a[e]=a[e]&1|d;d=b+272|0;e=(c[d>>2]|0)-4|0;c[d>>2]=e;if((e|0)>-1){pM(b);return}else{c[b+260>>2]=84280;return}}function pS(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=a[b+2100|0]|0;g=a[b+2094|0]|0;h=g&32;do{if((a[b+2112|0]&1)==0){i=a[b+290|0]|0;if(h<<24>>24==0){j=0;k=0;l=(i&255)+1|0;break}else{m=i<<24>>24==(a[b+2097|0]|0)|0;n=i;o=3310;break}}else{m=1;n=a[b+290|0]|0;o=3310}}while(0);do{if((o|0)==3310){i=(n&255)+1|0;if(h<<24>>24==0){j=0;k=m;l=i;break}j=(i|0)==(d[b+2097|0]|0)|0;k=m;l=i}}while(0);m=a[b+2096|0]&7;return pO(b,0,8-m|0,l,0,(j|k|0)!=0,((g&255)>>>5&f)<<1&2,m>>>0>5?5:m,c,e+90+m|0)|0}function pT(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=f+2109|0;h=f+2096|0;i=f+272|0;j=f+2100|0;k=f+2094|0;l=f+2095|0;m=f+290|0;n=f+256|0;o=f+2104|0;p=f+2106|0;q=f+2102|0;r=f+2101|0;s=f+2103|0;t=f+280|0;u=a[g]|0;while(1){if((u&255)>=80){break}v=u&7;w=d[h]|0;if((v|0)==(w&7|0)){break}do{if((v|0)==0){x=d[k]|0;if((a[j]&2)==0){y=x<<7&1024|w>>>3|(d[m]|0)+(d[l]|0)<<2&992;z=c[n>>2]|0;a[o]=a[z+(y|6144)|0]|0;a[p]=a[z+(y|14336)|0]|0;break}else{y=(d[q]|0)<<2&992|x<<4&1024|(d[r]|0)>>>3;x=c[n>>2]|0;a[o]=a[x+(y|6144)|0]|0;a[p]=a[x+(y|14336)|0]|0;break}}else if((v|0)==4){if((a[j]&2)==0){A=(d[m]|0)+(d[l]|0)|0}else{A=d[q]|0}y=d[p]|0;x=d[o]|0;z=y<<3&256;c[t>>2]=((e[82936+((d[(c[n>>2]|0)+(x<<4|(A^-(y>>>6&1))<<1&14|(y<<10&8192|4096)-(((d[k]|0)<<8|x<<5)&4096)|1)|0]|0|z)<<1)>>1]|0)<<1)+(e[82936+((d[s]|0|z)<<1)>>1]|0)}else if((v|0)==2){if((a[j]&2)==0){B=(d[m]|0)+(d[l]|0)|0}else{B=d[q]|0}z=d[p]|0;x=d[o]|0;a[s]=a[(c[n>>2]|0)+((B^-(z>>>6&1))<<1&14|x<<4|(z<<10&8192|4096)-(((d[k]|0)<<8|x<<5)&4096))|0]|0}}while(0);v=u+1&255;a[g]=v;w=(c[i>>2]|0)-1|0;c[i>>2]=w;if((w|0)<0){C=3346;break}else{u=v}}if((C|0)==3346){return}C=a[m]|0;m=C&255;u=f+1732+m|0;k=a[u]|0;B=k&127;do{if(k<<24>>24<0){n=k&127;a[u]=n;s=m*10|0;o=f+292+s|0;p=(n&255)+s|0;n=f+292+p|0;if((s|0)>=(p|0)){D=s;break}q=s|1;if((q|0)>=(p|0)){D=s;break}p=f+292+q|0;while(1){q=a[p]|0;L4166:do{if((p|0)==(o|0)){E=o}else{l=(q&255)+1+(f+1880)|0;j=p;while(1){A=j-1|0;t=a[A]|0;if((d[l]|0)>=(d[(t&255)+1+(f+1880)|0]|0)){E=j;break L4166}a[j]=t;if((A|0)==(o|0)){E=o;break}else{j=A}}}}while(0);a[E]=q;j=p+1|0;if(j>>>0<n>>>0){p=j}else{D=s;break}}}else{D=m*10|0}}while(0);if((B|0)!=0){m=C+16&255;C=0;do{E=a[C+D+(f+292)|0]|0;u=E&255;k=a[f+1880+u|0]|0;a[f+2028+(C<<2)|0]=a[u+1+(f+1880)|0]|0;a[f+2028+(C<<2)+2|0]=m-k&255;a[f+2028+(C<<2)+1|0]=E<<1;b[f+2072+(C<<1)>>1]=0;C=C+1|0;}while(C>>>0<B>>>0)}a[f+2028+(B<<2)|0]=-1;a[f+2107|0]=0;a[g]=0;g=a[h]|0;a[f+2110|0]=8-(g&7)&255;h=c[72336+((g&7)<<2)>>2]|0;g=(c[i>>2]|0)-(a[f+2111|0]&1^1)|0;c[i>>2]=g;if((g|0)>-1){f2[c[h>>2]&1023](f);return}else{c[f+260>>2]=h;return}}function pU(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0;f=d[b+2109|0]|0;g=d[b+2096|0]|0;h=g-f&7;i=80-f|0;f=g&7;return pO(b,0,8-f|0,d[b+290|0]|0,0,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,f>>>0>5?5:f,c,e+1-(a[b+2111|0]&1)+(i>>>0<h>>>0?i:h)|0)|0}function pV(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=b+2110|0;f=a[e]|0;g=b+260|0;c[g>>2]=83992;h=b+2100|0;i=b+2107|0;j=b+2109|0;k=b+2094|0;l=b+2111|0;m=b+272|0;n=a[j]|0;while(1){o=a[h]|0;if((o&1)==0){p=o}else{if((n&255)<167){q=3354}else{if((a[l]&1)==0){r=0;s=o}else{q=3354}}if((q|0)==3354){q=0;t=o&2;a[h]=t;r=t<<24>>24!=0;s=t}if((a[k]&32)==0){t=s&-3;a[h]=t;u=t}else{u=s}if(r){q=3358;break}else{p=u}}v=a[i]|0;w=v&255;if((a[b+2028+(w<<2)|0]|0)==n<<24>>24){x=a[k]|0;y=x&2;z=a[l]&1;if((z&255|y|0)==0){A=v}else{q=3361;break}do{A=A+1&255;}while((a[b+2028+((A&255)<<2)|0]|0)==n<<24>>24);a[i]=A}pZ(b);t=a[j]|0;if(t<<24>>24==f<<24>>24){q=3397;break}o=c[m>>2]|0;c[m>>2]=o-1;if((o|0)>0){n=t}else{q=3426;break}}if((q|0)==3361){a[b+2108|0]=v;v=b+2028+(w<<2)+1|0;A=c[b+2004>>2]|0;a[b+2104|0]=a[A+((d[v]|0)+2)|0]|0;k=c[m>>2]|0;c[m>>2]=k-1;if((k|0)<=0){c[g>>2]=84248;return}do{if((p&1)!=0){if((n&255)>166&z<<24>>24==0){B=0;C=p}else{k=p&2;a[h]=k;B=k<<24>>24!=0;C=k}if((x&32)==0){a[h]=C&-3}if(!B){break}pX(b);return}}while(0);a[b+2028+(w<<2)+3|0]=a[A+((d[v]|0)+3)|0]|0;v=a[i]|0;do{if((a[b+2028+((v&255)<<2)|0]|0)==n<<24>>24){if((a[l]&1|y|0)==0){D=v}else{break}do{D=D+1&255;}while((a[b+2028+((D&255)<<2)|0]|0)==n<<24>>24);a[i]=D;pZ(b)}else{pZ(b)}}while(0);D=a[j]|0;if(D<<24>>24!=(a[e]|0)){e=c[m>>2]|0;c[m>>2]=e-1;if((e|0)>0){p0(b);return}else{c[g>>2]=84232;return}}if((D&255)<168){D=c[m>>2]|0;c[m>>2]=D-1;if((D|0)>0){qr(b);return}else{c[g>>2]=84072;return}}D=c[b+264>>2]|0;e=a[b+291|0]&1;j=e&255;c[b+268>>2]=D-(c[m>>2]<<j);i=c[b+284>>2]|0;if(e<<24>>24==0){E=i-6-(a[l]&1)|0}else{E=i-8|0}i=(a[b+290|0]|0)==-113;if(i){F=((a[l]&1|4566)<<j)+E|0}else{F=E}if(D>>>0<F>>>0){G=-(F-D>>j)|0}else{G=D-F>>j}j=i?84312:84296;c[m>>2]=G;if((G|0)>-1){f2[c[j>>2]&1023](b);return}else{c[g>>2]=j;return}}else if((q|0)==3397){if((f&255)<168){f=c[m>>2]|0;c[m>>2]=f-1;if((f|0)>0){qr(b);return}else{c[g>>2]=84072;return}}f=c[b+264>>2]|0;j=a[b+291|0]&1;G=j&255;c[b+268>>2]=f-(c[m>>2]<<G);i=c[b+284>>2]|0;if(j<<24>>24==0){H=i-6-(a[l]&1)|0}else{H=i-8|0}i=(a[b+290|0]|0)==-113;if(i){I=((a[l]&1|4566)<<G)+H|0}else{I=H}if(f>>>0<I>>>0){J=-(I-f>>G)|0}else{J=f-I>>G}G=i?84312:84296;c[m>>2]=J;if((J|0)>-1){f2[c[G>>2]&1023](b);return}else{c[g>>2]=G;return}}else if((q|0)==3426){return}else if((q|0)==3358){pX(b);return}}function pW(b,c,e){b=b|0;c=c|0;e=e|0;return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,5,c,e)|0}function pX(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=b+2109|0;f=a[e]|0;g=b+2110|0;if(f<<24>>24==(a[g]|0)){c[b+276>>2]=c[b+280>>2];a[b+2105|0]=a[b+2106|0]|0;a[g]=(f&255)<160?f+8&255:-88}a[b+2101|0]=8-f&255;h=b+2100|0;i=b+2094|0;j=a[i]|0;k=j&255;if((a[h]&2)==0){l=(d[b+290|0]|0)+(d[b+2095|0]|0)<<2&992|k<<7&1024;m=c[b+256>>2]|0;a[b+2104|0]=a[m+(l|6144)|0]|0;a[b+2106|0]=a[m+(l|14336)|0]|0}else{l=d[b+2102|0]<<2&992|k<<4&1024;m=c[b+256>>2]|0;a[b+2104|0]=a[m+(l|6144)|0]|0;a[b+2106|0]=a[m+(l|14336)|0]|0}do{if((j&32)==0){l=b+2111|0;m=a[l]&1;if(m<<24>>24==0){n=f;break}o=b+2107|0;p=a[o]|0;do{if((a[b+2028+((p&255)<<2)|0]|0)==f<<24>>24){if((m&255|k&2|0)==0){q=p}else{break}do{q=q+1&255;}while((a[b+2028+((q&255)<<2)|0]|0)==f<<24>>24);a[o]=q;pZ(b)}else{pZ(b)}}while(0);o=a[e]|0;if(o<<24>>24!=(a[g]|0)){n=o;break}if((o&255)<168){o=b+272|0;p=c[o>>2]|0;c[o>>2]=p-1;if((p|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}p=c[b+264>>2]|0;o=b+272|0;m=a[b+291|0]&1;r=m&255;c[b+268>>2]=p-(c[o>>2]<<r);s=c[b+284>>2]|0;if(m<<24>>24==0){t=s-6-(a[l]&1)|0}else{t=s-8|0}s=(a[b+290|0]|0)==-113;if(s){u=((a[l]&1|4566)<<r)+t|0}else{u=t}if(p>>>0<u>>>0){v=-(u-p>>r)|0}else{v=p-u>>r}r=s?84312:84296;c[o>>2]=v;if((v|0)>-1){f2[c[r>>2]&1023](b);return}else{c[b+260>>2]=r;return}}else{n=f}}while(0);f=b+272|0;v=c[f>>2]|0;u=v-1|0;c[f>>2]=u;if((v|0)<=0){c[b+260>>2]=84152;return}v=a[i]|0;do{if((v&32)==0){t=b+2111|0;q=a[t]&1;if(q<<24>>24==0){w=u;x=n;break}k=b+2107|0;j=a[k]|0;do{if((a[b+2028+((j&255)<<2)|0]|0)==n<<24>>24){if((q&255|v&2|0)==0){y=j}else{break}do{y=y+1&255;}while((a[b+2028+((y&255)<<2)|0]|0)==n<<24>>24);a[k]=y;pZ(b)}else{pZ(b)}}while(0);k=a[e]|0;if(k<<24>>24!=(a[g]|0)){w=c[f>>2]|0;x=k;break}if((k&255)<168){k=c[f>>2]|0;c[f>>2]=k-1;if((k|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}k=c[b+264>>2]|0;j=a[b+291|0]&1;q=j&255;c[b+268>>2]=k-(c[f>>2]<<q);l=c[b+284>>2]|0;if(j<<24>>24==0){z=l-6-(a[t]&1)|0}else{z=l-8|0}l=(a[b+290|0]|0)==-113;if(l){A=((a[t]&1|4566)<<q)+z|0}else{A=z}if(k>>>0<A>>>0){B=-(A-k>>q)|0}else{B=k-A>>q}q=l?84312:84296;c[f>>2]=B;if((B|0)>-1){f2[c[q>>2]&1023](b);return}else{c[b+260>>2]=q;return}}else{w=u;x=n}}while(0);n=w-1|0;c[f>>2]=n;if((w|0)<=0){c[b+260>>2]=84136;return}if((a[h]&2)==0){C=(d[b+290|0]|0)+(d[b+2095|0]|0)|0}else{C=d[b+2102|0]|0}h=d[b+2106|0]|0;w=d[b+2104|0]|0;u=a[i]|0;B=u&255;a[b+2103|0]=a[(c[b+256>>2]|0)+((C^-(h>>>6&1))<<1&14|w<<4|(h<<10&8192|4096)-((B<<8|w<<5)&4096))|0]|0;do{if((u&32)==0){w=b+2111|0;h=a[w]&1;if(h<<24>>24==0){D=n;E=x;break}C=b+2107|0;A=a[C]|0;do{if((a[b+2028+((A&255)<<2)|0]|0)==x<<24>>24){if((h&255|B&2|0)==0){F=A}else{break}do{F=F+1&255;}while((a[b+2028+((F&255)<<2)|0]|0)==x<<24>>24);a[C]=F;pZ(b)}else{pZ(b)}}while(0);C=a[e]|0;if(C<<24>>24!=(a[g]|0)){D=c[f>>2]|0;E=C;break}if((C&255)<168){C=c[f>>2]|0;c[f>>2]=C-1;if((C|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}C=c[b+264>>2]|0;A=a[b+291|0]&1;h=A&255;c[b+268>>2]=C-(c[f>>2]<<h);t=c[b+284>>2]|0;if(A<<24>>24==0){G=t-6-(a[w]&1)|0}else{G=t-8|0}t=(a[b+290|0]|0)==-113;if(t){H=((a[w]&1|4566)<<h)+G|0}else{H=G}if(C>>>0<H>>>0){I=-(H-C>>h)|0}else{I=C-H>>h}h=t?84312:84296;c[f>>2]=I;if((I|0)>-1){f2[c[h>>2]&1023](b);return}else{c[b+260>>2]=h;return}}else{D=n;E=x}}while(0);x=D-1|0;c[f>>2]=x;if((D|0)<=0){c[b+260>>2]=84120;return}D=a[i]|0;do{if((D&32)==0){i=b+2111|0;n=a[i]&1;if(n<<24>>24==0){J=x;break}I=b+2107|0;H=a[I]|0;do{if((a[b+2028+((H&255)<<2)|0]|0)==E<<24>>24){if((n&255|D&2|0)==0){K=H}else{break}do{K=K+1&255;}while((a[b+2028+((K&255)<<2)|0]|0)==E<<24>>24);a[I]=K;pZ(b)}else{pZ(b)}}while(0);I=a[e]|0;if(I<<24>>24!=(a[g]|0)){J=c[f>>2]|0;break}if((I&255)<168){I=c[f>>2]|0;c[f>>2]=I-1;if((I|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}I=c[b+264>>2]|0;H=a[b+291|0]&1;n=H&255;c[b+268>>2]=I-(c[f>>2]<<n);w=c[b+284>>2]|0;if(H<<24>>24==0){L=w-6-(a[i]&1)|0}else{L=w-8|0}w=(a[b+290|0]|0)==-113;if(w){M=((a[i]&1|4566)<<n)+L|0}else{M=L}if(I>>>0<M>>>0){N=-(M-I>>n)|0}else{N=I-M>>n}n=w?84312:84296;c[f>>2]=N;if((N|0)>-1){f2[c[n>>2]&1023](b);return}else{c[b+260>>2]=n;return}}else{J=x}}while(0);c[f>>2]=J-1;if((J|0)>0){qe(b);return}else{c[b+260>>2]=84104;return}}function pY(b){b=b|0;var e=0,f=0;a[b+2104|0]=a[(c[b+2004>>2]|0)+((d[b+2028+((d[b+2108|0]|0)<<2)+1|0]|0)+2)|0]|0;e=b+272|0;f=c[e>>2]|0;c[e>>2]=f-1;if((f|0)>0){p_(b);return}else{c[b+260>>2]=84248;return}}function pZ(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=e+2109|0;g=a[f]|0;h=g&255;i=e+276|0;j=c[i>>2]|0;k=c[e+2020>>2]|0;L4476:do{if((a[e+2099|0]|0)==g<<24>>24){if((a[e+2112|0]&1)==0){if((a[e+2098|0]|0)!=(a[e+290|0]|0)){break}if(!((a[e+2094|0]&32)!=0&(g&255)<167)){break}}else{if((g&255)>=167){break}}l=e+2100|0;m=a[l]|0;n=m<<24>>24==0;do{if(n){if((a[e+2094|0]&32)==0){break}a[l]=3;o=e+2102|0;a[o]=(a[o]|0)+1&255;break L4476}}while(0);if((a[e+2111|0]&1)!=0){break}if(!(n|g<<24>>24==-90)){break}a[l]=m|1}}while(0);o=e+2094|0;p=a[e+2111|0]&1;q=p<<24>>24==0;r=j&3&-(p&255|a[o]&1);p=e+2105|0;s=c[e+((r|d[p]<<2&28)<<2)>>2]|0;t=a[e+2107|0]|0;u=(t&255)-1|0;do{if(t<<24>>24==0){v=s;w=h-8|0}else{x=h-8|0;if((d[e+2028+(u<<2)|0]|0)<=(x|0)){v=s;w=x;break}if(q){y=0;z=0;A=u;while(1){B=e+2072+(A<<1)|0;C=b[B>>1]|0;D=C&3;if((D|0)==0){E=y;F=z}else{E=d[e+2028+(A<<2)+3|0]|0;F=D}b[B>>1]=(C&65535)>>>2;C=A-1|0;if((A|0)<=0){break}if((d[e+2028+(C<<2)|0]|0)>(x|0)){y=E;z=F;A=C}else{break}}if((F|0)==0){v=s;w=x;break}if((a[o]&2)==0){v=s;w=x;break}if(!((E&128|0)==0|(r|0)==0)){v=s;w=x;break}v=c[e+128+((E>>>2&4)+F<<2)>>2]|0;w=x;break}else{G=255;H=0;I=0;J=u}while(1){A=e+2072+(J<<1)|0;z=b[A>>1]|0;y=z&3;do{if((y|0)==0){K=G;L=H;M=I}else{m=d[e+2028+(J<<2)+1|0]|0;if(m>>>0>=G>>>0){K=G;L=H;M=I;break}K=m;L=d[e+2028+(J<<2)+3|0]|0;M=y}}while(0);b[A>>1]=(z&65535)>>>2;y=J-1|0;if((J|0)<=0){break}if((d[e+2028+(y<<2)|0]|0)>(x|0)){G=K;H=L;I=M;J=y}else{break}}if((M|0)==0){v=s;w=x;break}y=d[o]|0;if((y&2|0)==0){v=s;w=x;break}if(!(((d[p]|L)&128|0)==0|(r|0)==0)){if((y&1|0)!=0){v=s;w=x;break}}v=c[e+128+((L<<2&28)+M<<2)>>2]|0;w=x}}while(0);if((w|0)<=-1){N=g+1&255;a[f]=N;O=j>>>2;c[i>>2]=O;return}c[k+(w<<2)>>2]=v;N=g+1&255;a[f]=N;O=j>>>2;c[i>>2]=O;return}function p_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=b+2100|0;f=a[e]|0;g=b+2109|0;h=a[g]|0;do{if((f&1)!=0){if((h&255)<167){i=3610}else{if((a[b+2111|0]&1)==0){j=0;k=f}else{i=3610}}if((i|0)==3610){l=f&2;a[e]=l;j=l<<24>>24!=0;k=l}if((a[b+2094|0]&32)==0){a[e]=k&-3}if(!j){break}pX(b);return}}while(0);j=d[b+2108|0]|0;a[b+2028+(j<<2)+3|0]=a[(c[b+2004>>2]|0)+((d[b+2028+(j<<2)+1|0]|0)+3)|0]|0;j=b+2107|0;k=a[j]|0;do{if((a[b+2028+((k&255)<<2)|0]|0)==h<<24>>24){if((a[b+2111|0]&1|a[b+2094|0]&2|0)==0){m=k}else{break}do{m=m+1&255;}while((a[b+2028+((m&255)<<2)|0]|0)==h<<24>>24);a[j]=m;pZ(b)}else{pZ(b)}}while(0);m=a[g]|0;if(m<<24>>24!=(a[b+2110|0]|0)){g=b+272|0;j=c[g>>2]|0;c[g>>2]=j-1;if((j|0)>0){p0(b);return}else{c[b+260>>2]=84232;return}}if((m&255)<168){m=b+272|0;j=c[m>>2]|0;c[m>>2]=j-1;if((j|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}j=c[b+264>>2]|0;m=b+272|0;g=a[b+291|0]&1;h=g&255;c[b+268>>2]=j-(c[m>>2]<<h);k=c[b+284>>2]|0;if(g<<24>>24==0){n=k-6-(a[b+2111|0]&1)|0}else{n=k-8|0}k=(a[b+290|0]|0)==-113;if(k){o=((a[b+2111|0]&1|4566)<<h)+n|0}else{o=n}if(j>>>0<o>>>0){p=-(o-j>>h)|0}else{p=j-o>>h}h=k?84312:84296;c[m>>2]=p;if((p|0)>-1){f2[c[h>>2]&1023](b);return}else{c[b+260>>2]=h;return}}function p$(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=d[b+2107|0]|0;if((a[b+2111|0]&1|a[b+2094|0]&2|0)==0){g=f;h=e}else{g=f+1|0;h=e+5|0}return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,g,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,5,c,h)|0}function p0(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=b+2100|0;f=a[e]|0;do{if((f&1)==0){g=a[b+2094|0]|0}else{if((d[b+2109|0]|0)<167){h=3654}else{if((a[b+2111|0]&1)==0){i=0;j=f}else{h=3654}}if((h|0)==3654){k=f&2;a[e]=k;i=k<<24>>24!=0;j=k}k=a[b+2094|0]|0;if((k&32)==0){a[e]=j&-3}if(!i){g=k;break}pX(b);return}}while(0);i=d[b+2108|0]|0;j=d[b+2028+(i<<2)+3|0]|0;f=d[b+2028+(i<<2)+2|0]|0;i=((j&64|0)!=0?f^15:f)<<1;f=b+2111|0;k=a[f]&1;l=d[b+2104|0]<<4;if((g&4)==0){m=i&494|l}else{m=l&4064|i}a[b+2103|0]=a[(c[b+256>>2]|0)+(m+(k<<13&j<<10))|0]|0;j=b+2107|0;m=a[j]|0;i=a[b+2028+((m&255)<<2)|0]|0;l=b+2109|0;do{if(i<<24>>24==(a[l]|0)){if((k|g&2|0)==0){n=m}else{break}do{n=n+1&255;}while((a[b+2028+((n&255)<<2)|0]|0)==i<<24>>24);a[j]=n;pZ(b)}else{pZ(b)}}while(0);n=a[l]|0;i=b+2110|0;if(n<<24>>24==(a[i]|0)){if((n&255)<168){m=b+272|0;g=c[m>>2]|0;c[m>>2]=g-1;if((g|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}g=c[b+264>>2]|0;m=b+272|0;k=a[b+291|0]&1;o=k&255;c[b+268>>2]=g-(c[m>>2]<<o);p=c[b+284>>2]|0;if(k<<24>>24==0){q=p-6-(a[f]&1)|0}else{q=p-8|0}p=(a[b+290|0]|0)==-113;if(p){r=((a[f]&1|4566)<<o)+q|0}else{r=q}if(g>>>0<r>>>0){s=-(r-g>>o)|0}else{s=g-r>>o}o=p?84312:84296;c[m>>2]=s;if((s|0)>-1){f2[c[o>>2]&1023](b);return}else{c[b+260>>2]=o;return}}o=b+272|0;s=c[o>>2]|0;c[o>>2]=s-1;if((s|0)<=0){c[b+260>>2]=84216;return}s=a[e]|0;do{if((s&1)!=0){if((n&255)<167){h=3687}else{if((a[f]&1)==0){t=0;u=s}else{h=3687}}if((h|0)==3687){m=s&2;a[e]=m;t=m<<24>>24!=0;u=m}if((a[b+2094|0]&32)==0){a[e]=u&-3}if(!t){break}pX(b);return}}while(0);t=a[j]|0;do{if((a[b+2028+((t&255)<<2)|0]|0)==n<<24>>24){if((a[f]&1|a[b+2094|0]&2|0)==0){v=t}else{break}do{v=v+1&255;}while((a[b+2028+((v&255)<<2)|0]|0)==n<<24>>24);a[j]=v;pZ(b)}else{pZ(b)}}while(0);v=a[l]|0;if(v<<24>>24!=(a[i]|0)){i=c[o>>2]|0;c[o>>2]=i-1;if((i|0)>0){p4(b);return}else{c[b+260>>2]=84200;return}}if((v&255)<168){v=c[o>>2]|0;c[o>>2]=v-1;if((v|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}v=c[b+264>>2]|0;i=a[b+291|0]&1;l=i&255;c[b+268>>2]=v-(c[o>>2]<<l);j=c[b+284>>2]|0;if(i<<24>>24==0){w=j-6-(a[f]&1)|0}else{w=j-8|0}j=(a[b+290|0]|0)==-113;if(j){x=((a[f]&1|4566)<<l)+w|0}else{x=w}if(v>>>0<x>>>0){y=-(x-v>>l)|0}else{y=v-x>>l}l=j?84312:84296;c[o>>2]=y;if((y|0)>-1){f2[c[l>>2]&1023](b);return}else{c[b+260>>2]=l;return}}function p1(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=d[b+2107|0]|0;if((a[b+2111|0]&1|a[b+2094|0]&2|0)==0){g=f;h=e}else{g=f+1|0;h=e+4|0}return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,g,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,5,c,h)|0}function p2(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b+2100|0;e=a[d]|0;f=b+2109|0;g=a[f]|0;do{if((e&1)!=0){if((g&255)<167){h=3737}else{if((a[b+2111|0]&1)==0){i=0;j=e}else{h=3737}}if((h|0)==3737){k=e&2;a[d]=k;i=k<<24>>24!=0;j=k}if((a[b+2094|0]&32)==0){a[d]=j&-3}if(!i){break}pX(b);return}}while(0);i=b+2107|0;j=a[i]|0;do{if((a[b+2028+((j&255)<<2)|0]|0)==g<<24>>24){if((a[b+2111|0]&1|a[b+2094|0]&2|0)==0){l=j}else{break}do{l=l+1&255;}while((a[b+2028+((l&255)<<2)|0]|0)==g<<24>>24);a[i]=l;pZ(b)}else{pZ(b)}}while(0);l=a[f]|0;if(l<<24>>24!=(a[b+2110|0]|0)){f=b+272|0;i=c[f>>2]|0;c[f>>2]=i-1;if((i|0)>0){p4(b);return}else{c[b+260>>2]=84200;return}}if((l&255)<168){l=b+272|0;i=c[l>>2]|0;c[l>>2]=i-1;if((i|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}i=c[b+264>>2]|0;l=b+272|0;f=a[b+291|0]&1;g=f&255;c[b+268>>2]=i-(c[l>>2]<<g);j=c[b+284>>2]|0;if(f<<24>>24==0){m=j-6-(a[b+2111|0]&1)|0}else{m=j-8|0}j=(a[b+290|0]|0)==-113;if(j){n=((a[b+2111|0]&1|4566)<<g)+m|0}else{n=m}if(i>>>0<n>>>0){o=-(n-i>>g)|0}else{o=i-n>>g}g=j?84312:84296;c[l>>2]=o;if((o|0)>-1){f2[c[g>>2]&1023](b);return}else{c[b+260>>2]=g;return}}function p3(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=d[b+2107|0]|0;if((a[b+2111|0]&1|a[b+2094|0]&2|0)==0){g=f;h=e}else{g=f+1|0;h=e+3|0}return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,g,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,5,c,h)|0}function p4(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=b+2100|0;f=a[e]|0;do{if((f&1)==0){g=a[b+2094|0]|0}else{if((d[b+2109|0]|0)<167){h=3781}else{if((a[b+2111|0]&1)==0){i=0;j=f}else{h=3781}}if((h|0)==3781){k=f&2;a[e]=k;i=k<<24>>24!=0;j=k}k=a[b+2094|0]|0;if((k&32)==0){a[e]=j&-3}if(!i){g=k;break}pX(b);return}}while(0);i=d[b+2108|0]|0;j=d[b+2028+(i<<2)+3|0]|0;e=d[b+2028+(i<<2)+2|0]|0;i=((j&64|0)!=0?e^15:e)<<1;e=b+2111|0;f=a[e]&1;h=b+2104|0;k=d[h]<<4;if((g&4)==0){l=i&494|k}else{l=k&4064|i}a[h]=a[(c[b+256>>2]|0)+(l+(f<<13&j<<10|1))|0]|0;j=b+2107|0;l=a[j]|0;h=a[b+2028+((l&255)<<2)|0]|0;i=b+2109|0;do{if(h<<24>>24==(a[i]|0)){if((f|g&2|0)==0){m=l}else{break}do{m=m+1&255;}while((a[b+2028+((m&255)<<2)|0]|0)==h<<24>>24);a[j]=m;pZ(b)}else{pZ(b)}}while(0);m=a[i]|0;if(m<<24>>24!=(a[b+2110|0]|0)){i=b+272|0;j=c[i>>2]|0;c[i>>2]=j-1;if((j|0)>0){p6(b);return}else{c[b+260>>2]=84184;return}}if((m&255)<168){m=b+272|0;j=c[m>>2]|0;c[m>>2]=j-1;if((j|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}j=c[b+264>>2]|0;m=b+272|0;i=a[b+291|0]&1;h=i&255;c[b+268>>2]=j-(c[m>>2]<<h);l=c[b+284>>2]|0;if(i<<24>>24==0){n=l-6-(a[e]&1)|0}else{n=l-8|0}l=(a[b+290|0]|0)==-113;if(l){o=((a[e]&1|4566)<<h)+n|0}else{o=n}if(j>>>0<o>>>0){p=-(o-j>>h)|0}else{p=j-o>>h}h=l?84312:84296;c[m>>2]=p;if((p|0)>-1){f2[c[h>>2]&1023](b);return}else{c[b+260>>2]=h;return}}function p5(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=d[b+2107|0]|0;if((a[b+2111|0]&1|a[b+2094|0]&2|0)==0){g=f;h=e}else{g=f+1|0;h=e+2|0}return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,g,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,5,c,h)|0}function p6(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=e+2100|0;g=a[f]|0;h=e+2109|0;i=a[h]|0;do{if((g&1)!=0){if((i&255)<167){j=3827}else{if((a[e+2111|0]&1)==0){k=0;l=g}else{j=3827}}if((j|0)==3827){m=g&2;a[f]=m;k=m<<24>>24!=0;l=m}if((a[e+2094|0]&32)==0){a[f]=l&-3}if(!k){break}pX(e);return}}while(0);k=e+2107|0;l=a[k]|0;do{if((a[e+2028+((l&255)<<2)|0]|0)==i<<24>>24){if((a[e+2111|0]&1|a[e+2094|0]&2|0)==0){n=l}else{break}do{n=n+1&255;}while((a[e+2028+((n&255)<<2)|0]|0)==i<<24>>24);a[k]=n;pZ(e)}else{pZ(e)}}while(0);n=a[e+2108|0]|0;i=n&255;l=a[k]|0;if(n<<24>>24==l<<24>>24){a[k]=n+1&255;o=i}else{n=(l&255)-1|0;l=e+2028+(i<<2)|0;i=e+2028+(n<<2)|0;C=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[i]=C&255;C=C>>8;a[i+1|0]=C&255;C=C>>8;a[i+2|0]=C&255;C=C>>8;a[i+3|0]=C&255;o=n}n=d[e+2028+(o<<2)+3|0]<<3&256;b[e+2072+(o<<1)>>1]=(b[82936+((d[e+2104|0]|n)<<1)>>1]<<1)+(b[82936+((n|d[e+2103|0])<<1)>>1]|0)&65535;n=a[h]|0;a[e+2028+(o<<2)|0]=n;if(n<<24>>24!=(a[e+2110|0]|0)){o=e+260|0;c[o>>2]=83992;h=e+272|0;i=c[h>>2]|0;c[h>>2]=i-1;if((i|0)>0){pV(e);return}else{c[o>>2]=83992;return}}if((n&255)<168){n=e+272|0;o=c[n>>2]|0;c[n>>2]=o-1;if((o|0)>0){qr(e);return}else{c[e+260>>2]=84072;return}}o=c[e+264>>2]|0;n=e+272|0;i=a[e+291|0]&1;h=i&255;c[e+268>>2]=o-(c[n>>2]<<h);l=c[e+284>>2]|0;if(i<<24>>24==0){p=l-6-(a[e+2111|0]&1)|0}else{p=l-8|0}l=(a[e+290|0]|0)==-113;if(l){q=((a[e+2111|0]&1|4566)<<h)+p|0}else{q=p}if(o>>>0<q>>>0){r=-(q-o>>h)|0}else{r=o-q>>h}h=l?84312:84296;c[n>>2]=r;if((r|0)>-1){f2[c[h>>2]&1023](e);return}else{c[e+260>>2]=h;return}}function p7(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=d[b+2107|0]|0;if((a[b+2111|0]&1|a[b+2094|0]&2|0)==0){g=f;h=e}else{g=f+1|0;h=e+1|0}return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,g,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,5,c,h)|0}function p8(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=b+2094|0;f=a[e]|0;do{if((f&32)==0){g=b+2111|0;h=a[g]&1;if(h<<24>>24==0){break}i=b+2107|0;j=a[i]|0;k=a[b+2028+((j&255)<<2)|0]|0;l=b+2109|0;do{if(k<<24>>24==(a[l]|0)){if((h&255|f&2|0)==0){m=j}else{break}do{m=m+1&255;}while((a[b+2028+((m&255)<<2)|0]|0)==k<<24>>24);a[i]=m;pZ(b)}else{pZ(b)}}while(0);i=a[l]|0;if(i<<24>>24!=(a[b+2110|0]|0)){break}if((i&255)<168){i=b+272|0;k=c[i>>2]|0;c[i>>2]=k-1;if((k|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}k=c[b+264>>2]|0;i=b+272|0;j=a[b+291|0]&1;h=j&255;c[b+268>>2]=k-(c[i>>2]<<h);n=c[b+284>>2]|0;if(j<<24>>24==0){o=n-6-(a[g]&1)|0}else{o=n-8|0}n=(a[b+290|0]|0)==-113;if(n){p=((a[g]&1|4566)<<h)+o|0}else{p=o}if(k>>>0<p>>>0){q=-(p-k>>h)|0}else{q=k-p>>h}h=n?84312:84296;c[i>>2]=q;if((q|0)>-1){f2[c[h>>2]&1023](b);return}else{c[b+260>>2]=h;return}}}while(0);q=b+272|0;p=c[q>>2]|0;o=p-1|0;c[q>>2]=o;if((p|0)<=0){c[b+260>>2]=84136;return}if((a[b+2100|0]&2)==0){r=(d[b+290|0]|0)+(d[b+2095|0]|0)|0}else{r=d[b+2102|0]|0}p=d[b+2106|0]|0;m=d[b+2104|0]|0;f=a[e]|0;h=f&255;a[b+2103|0]=a[(c[b+256>>2]|0)+((r^-(p>>>6&1))<<1&14|m<<4|(p<<10&8192|4096)-((h<<8|m<<5)&4096))|0]|0;do{if((f&32)==0){m=b+2111|0;p=a[m]&1;if(p<<24>>24==0){s=o;break}r=b+2107|0;i=a[r]|0;n=a[b+2028+((i&255)<<2)|0]|0;k=b+2109|0;do{if(n<<24>>24==(a[k]|0)){if((p&255|h&2|0)==0){t=i}else{break}do{t=t+1&255;}while((a[b+2028+((t&255)<<2)|0]|0)==n<<24>>24);a[r]=t;pZ(b)}else{pZ(b)}}while(0);r=a[k]|0;if(r<<24>>24!=(a[b+2110|0]|0)){s=c[q>>2]|0;break}if((r&255)<168){r=c[q>>2]|0;c[q>>2]=r-1;if((r|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}r=c[b+264>>2]|0;n=a[b+291|0]&1;i=n&255;c[b+268>>2]=r-(c[q>>2]<<i);p=c[b+284>>2]|0;if(n<<24>>24==0){u=p-6-(a[m]&1)|0}else{u=p-8|0}p=(a[b+290|0]|0)==-113;if(p){v=((a[m]&1|4566)<<i)+u|0}else{v=u}if(r>>>0<v>>>0){w=-(v-r>>i)|0}else{w=r-v>>i}i=p?84312:84296;c[q>>2]=w;if((w|0)>-1){f2[c[i>>2]&1023](b);return}else{c[b+260>>2]=i;return}}else{s=o}}while(0);o=s-1|0;c[q>>2]=o;if((s|0)<=0){c[b+260>>2]=84120;return}s=a[e]|0;do{if((s&32)==0){e=b+2111|0;w=a[e]&1;if(w<<24>>24==0){x=o;break}v=b+2107|0;u=a[v]|0;t=a[b+2028+((u&255)<<2)|0]|0;h=b+2109|0;do{if(t<<24>>24==(a[h]|0)){if((w&255|s&2|0)==0){y=u}else{break}do{y=y+1&255;}while((a[b+2028+((y&255)<<2)|0]|0)==t<<24>>24);a[v]=y;pZ(b)}else{pZ(b)}}while(0);v=a[h]|0;if(v<<24>>24!=(a[b+2110|0]|0)){x=c[q>>2]|0;break}if((v&255)<168){v=c[q>>2]|0;c[q>>2]=v-1;if((v|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}v=c[b+264>>2]|0;t=a[b+291|0]&1;u=t&255;c[b+268>>2]=v-(c[q>>2]<<u);w=c[b+284>>2]|0;if(t<<24>>24==0){z=w-6-(a[e]&1)|0}else{z=w-8|0}w=(a[b+290|0]|0)==-113;if(w){A=((a[e]&1|4566)<<u)+z|0}else{A=z}if(v>>>0<A>>>0){B=-(A-v>>u)|0}else{B=v-A>>u}u=w?84312:84296;c[q>>2]=B;if((B|0)>-1){f2[c[u>>2]&1023](b);return}else{c[b+260>>2]=u;return}}else{x=o}}while(0);c[q>>2]=x-1;if((x|0)>0){qe(b);return}else{c[b+260>>2]=84104;return}}function p9(b,c,e){b=b|0;c=c|0;e=e|0;return pP(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,d[b+2100|0]|0,1,c,e)|0}function qa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[b+2100|0]&2)==0){e=(d[b+290|0]|0)+(d[b+2095|0]|0)|0}else{e=d[b+2102|0]|0}f=d[b+2106|0]|0;g=d[b+2104|0]|0;h=b+2094|0;i=a[h]|0;j=i&255;a[b+2103|0]=a[(c[b+256>>2]|0)+((e^-(f>>>6&1))<<1&14|g<<4|(f<<10&8192|4096)-((j<<8|g<<5)&4096))|0]|0;do{if((i&32)==0){g=b+2111|0;f=a[g]&1;if(f<<24>>24==0){break}e=b+2107|0;k=a[e]|0;l=a[b+2028+((k&255)<<2)|0]|0;m=b+2109|0;do{if(l<<24>>24==(a[m]|0)){if((f&255|j&2|0)==0){n=k}else{break}do{n=n+1&255;}while((a[b+2028+((n&255)<<2)|0]|0)==l<<24>>24);a[e]=n;pZ(b)}else{pZ(b)}}while(0);e=a[m]|0;if(e<<24>>24!=(a[b+2110|0]|0)){break}if((e&255)<168){e=b+272|0;l=c[e>>2]|0;c[e>>2]=l-1;if((l|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}l=c[b+264>>2]|0;e=b+272|0;k=a[b+291|0]&1;f=k&255;c[b+268>>2]=l-(c[e>>2]<<f);o=c[b+284>>2]|0;if(k<<24>>24==0){p=o-6-(a[g]&1)|0}else{p=o-8|0}o=(a[b+290|0]|0)==-113;if(o){q=((a[g]&1|4566)<<f)+p|0}else{q=p}if(l>>>0<q>>>0){r=-(q-l>>f)|0}else{r=l-q>>f}f=o?84312:84296;c[e>>2]=r;if((r|0)>-1){f2[c[f>>2]&1023](b);return}else{c[b+260>>2]=f;return}}}while(0);r=b+272|0;q=c[r>>2]|0;p=q-1|0;c[r>>2]=p;if((q|0)<=0){c[b+260>>2]=84120;return}q=a[h]|0;do{if((q&32)==0){h=b+2111|0;n=a[h]&1;if(n<<24>>24==0){s=p;break}j=b+2107|0;i=a[j]|0;f=a[b+2028+((i&255)<<2)|0]|0;e=b+2109|0;do{if(f<<24>>24==(a[e]|0)){if((n&255|q&2|0)==0){t=i}else{break}do{t=t+1&255;}while((a[b+2028+((t&255)<<2)|0]|0)==f<<24>>24);a[j]=t;pZ(b)}else{pZ(b)}}while(0);j=a[e]|0;if(j<<24>>24!=(a[b+2110|0]|0)){s=c[r>>2]|0;break}if((j&255)<168){j=c[r>>2]|0;c[r>>2]=j-1;if((j|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}j=c[b+264>>2]|0;f=a[b+291|0]&1;i=f&255;c[b+268>>2]=j-(c[r>>2]<<i);n=c[b+284>>2]|0;if(f<<24>>24==0){u=n-6-(a[h]&1)|0}else{u=n-8|0}n=(a[b+290|0]|0)==-113;if(n){v=((a[h]&1|4566)<<i)+u|0}else{v=u}if(j>>>0<v>>>0){w=-(v-j>>i)|0}else{w=j-v>>i}i=n?84312:84296;c[r>>2]=w;if((w|0)>-1){f2[c[i>>2]&1023](b);return}else{c[b+260>>2]=i;return}}else{s=p}}while(0);c[r>>2]=s-1;if((s|0)>0){qe(b);return}else{c[b+260>>2]=84104;return}}function qb(b,c,e){b=b|0;c=c|0;e=e|0;return pP(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,d[b+2100|0]|0,2,c,e)|0}function qc(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a[b+2094|0]|0;do{if((d&32)==0){e=b+2111|0;f=a[e]&1;if(f<<24>>24==0){break}g=b+2107|0;h=a[g]|0;i=a[b+2028+((h&255)<<2)|0]|0;j=b+2109|0;do{if(i<<24>>24==(a[j]|0)){if((f&255|d&2|0)==0){k=h}else{break}do{k=k+1&255;}while((a[b+2028+((k&255)<<2)|0]|0)==i<<24>>24);a[g]=k;pZ(b)}else{pZ(b)}}while(0);g=a[j]|0;if(g<<24>>24!=(a[b+2110|0]|0)){break}if((g&255)<168){g=b+272|0;i=c[g>>2]|0;c[g>>2]=i-1;if((i|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}i=c[b+264>>2]|0;g=b+272|0;h=a[b+291|0]&1;f=h&255;c[b+268>>2]=i-(c[g>>2]<<f);l=c[b+284>>2]|0;if(h<<24>>24==0){m=l-6-(a[e]&1)|0}else{m=l-8|0}l=(a[b+290|0]|0)==-113;if(l){n=((a[e]&1|4566)<<f)+m|0}else{n=m}if(i>>>0<n>>>0){o=-(n-i>>f)|0}else{o=i-n>>f}f=l?84312:84296;c[g>>2]=o;if((o|0)>-1){f2[c[f>>2]&1023](b);return}else{c[b+260>>2]=f;return}}}while(0);o=b+272|0;n=c[o>>2]|0;c[o>>2]=n-1;if((n|0)>0){qe(b);return}else{c[b+260>>2]=84104;return}}function qd(b,c,e){b=b|0;c=c|0;e=e|0;return pP(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,d[b+2100|0]|0,3,c,e)|0}function qe(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[b+2100|0]&2)==0){f=(d[b+290|0]|0)+(d[b+2095|0]|0)|0}else{f=d[b+2102|0]|0}g=d[b+2106|0]|0;h=d[b+2104|0]|0;i=b+2094|0;j=a[i]|0;k=j&255;l=g<<3&256;c[b+280>>2]=(e[82936+((d[(c[b+256>>2]|0)+(h<<4|(f^-(g>>>6&1))<<1&14|(g<<10&8192|4096)-((k<<8|h<<5)&4096)|1)|0]|l)<<1)>>1]<<1)+(e[82936+((d[b+2103|0]|l)<<1)>>1]|0);do{if((j&32)==0){l=b+2111|0;h=a[l]&1;if(h<<24>>24==0){break}g=b+2107|0;f=a[g]|0;m=a[b+2028+((f&255)<<2)|0]|0;n=b+2109|0;do{if(m<<24>>24==(a[n]|0)){if((h&255|k&2|0)==0){o=f}else{break}do{o=o+1&255;}while((a[b+2028+((o&255)<<2)|0]|0)==m<<24>>24);a[g]=o;pZ(b)}else{pZ(b)}}while(0);g=a[n]|0;if(g<<24>>24!=(a[b+2110|0]|0)){break}if((g&255)<168){g=b+272|0;m=c[g>>2]|0;c[g>>2]=m-1;if((m|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}m=c[b+264>>2]|0;g=b+272|0;f=a[b+291|0]&1;h=f&255;c[b+268>>2]=m-(c[g>>2]<<h);p=c[b+284>>2]|0;if(f<<24>>24==0){q=p-6-(a[l]&1)|0}else{q=p-8|0}p=(a[b+290|0]|0)==-113;if(p){r=((a[l]&1|4566)<<h)+q|0}else{r=q}if(m>>>0<r>>>0){s=-(r-m>>h)|0}else{s=m-r>>h}h=p?84312:84296;c[g>>2]=s;if((s|0)>-1){f2[c[h>>2]&1023](b);return}else{c[b+260>>2]=h;return}}}while(0);s=b+272|0;r=c[s>>2]|0;q=r-1|0;c[s>>2]=q;if((r|0)<=0){c[b+260>>2]=84088;return}r=a[i]|0;do{if((r&32)==0){i=b+2111|0;o=a[i]&1;if(o<<24>>24==0){t=q;break}k=b+2107|0;j=a[k]|0;h=a[b+2028+((j&255)<<2)|0]|0;g=b+2109|0;do{if(h<<24>>24==(a[g]|0)){if((o&255|r&2|0)==0){u=j}else{break}do{u=u+1&255;}while((a[b+2028+((u&255)<<2)|0]|0)==h<<24>>24);a[k]=u;pZ(b)}else{pZ(b)}}while(0);k=a[g]|0;if(k<<24>>24!=(a[b+2110|0]|0)){t=c[s>>2]|0;break}if((k&255)<168){k=c[s>>2]|0;c[s>>2]=k-1;if((k|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}k=c[b+264>>2]|0;h=a[b+291|0]&1;j=h&255;c[b+268>>2]=k-(c[s>>2]<<j);o=c[b+284>>2]|0;if(h<<24>>24==0){v=o-6-(a[i]&1)|0}else{v=o-8|0}o=(a[b+290|0]|0)==-113;if(o){w=((a[i]&1|4566)<<j)+v|0}else{w=v}if(k>>>0<w>>>0){x=-(w-k>>j)|0}else{x=k-w>>j}j=o?84312:84296;c[s>>2]=x;if((x|0)>-1){f2[c[j>>2]&1023](b);return}else{c[b+260>>2]=j;return}}else{t=q}}while(0);c[s>>2]=t-1;if((t|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}function qf(b,c,e){b=b|0;c=c|0;e=e|0;return pP(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,d[b+2100|0]|0,4,c,e)|0}function qg(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a[b+2094|0]|0;do{if((d&32)==0){e=b+2111|0;f=a[e]&1;if(f<<24>>24==0){break}g=b+2107|0;h=a[g]|0;i=a[b+2028+((h&255)<<2)|0]|0;j=b+2109|0;do{if(i<<24>>24==(a[j]|0)){if((f&255|d&2|0)==0){k=h}else{break}do{k=k+1&255;}while((a[b+2028+((k&255)<<2)|0]|0)==i<<24>>24);a[g]=k;pZ(b)}else{pZ(b)}}while(0);g=a[j]|0;if(g<<24>>24!=(a[b+2110|0]|0)){break}if((g&255)<168){g=b+272|0;i=c[g>>2]|0;c[g>>2]=i-1;if((i|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}i=c[b+264>>2]|0;g=b+272|0;h=a[b+291|0]&1;f=h&255;c[b+268>>2]=i-(c[g>>2]<<f);l=c[b+284>>2]|0;if(h<<24>>24==0){m=l-6-(a[e]&1)|0}else{m=l-8|0}l=(a[b+290|0]|0)==-113;if(l){n=((a[e]&1|4566)<<f)+m|0}else{n=m}if(i>>>0<n>>>0){o=-(n-i>>f)|0}else{o=i-n>>f}f=l?84312:84296;c[g>>2]=o;if((o|0)>-1){f2[c[f>>2]&1023](b);return}else{c[b+260>>2]=f;return}}}while(0);o=b+272|0;n=c[o>>2]|0;c[o>>2]=n-1;if((n|0)>0){qr(b);return}else{c[b+260>>2]=84072;return}}function qh(b,c,e){b=b|0;c=c|0;e=e|0;return pP(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,d[b+2100|0]|0,5,c,e)|0}function qi(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=b+2100|0;g=a[f]|0;do{if((g&1)==0){h=g}else{if((d[b+2109|0]|0)<167){i=4176}else{if((a[b+2111|0]&1)==0){j=0;k=g}else{i=4176}}if((i|0)==4176){l=g&2;a[f]=l;j=l<<24>>24!=0;k=l}if((a[b+2094|0]&32)==0){l=k&-3;a[f]=l;m=l}else{m=k}if(!j){h=m;break}pX(b);return}}while(0);if((h&2)==0){n=(d[b+290|0]|0)+(d[b+2095|0]|0)|0}else{n=d[b+2102|0]|0}h=d[b+2106|0]|0;m=d[b+2104|0]|0;j=d[b+2094|0]|0;k=h<<3&256;c[b+280>>2]=(e[82936+((d[(c[b+256>>2]|0)+(m<<4|(n^-(h>>>6&1))<<1&14|(h<<10&8192|4096)-((j<<8|m<<5)&4096)|1)|0]|k)<<1)>>1]<<1)+(e[82936+((d[b+2103|0]|k)<<1)>>1]|0);k=b+2107|0;m=a[k]|0;h=a[b+2028+((m&255)<<2)|0]|0;n=b+2109|0;do{if(h<<24>>24==(a[n]|0)){if((a[b+2111|0]&1|j&2|0)==0){o=m}else{break}do{o=o+1&255;}while((a[b+2028+((o&255)<<2)|0]|0)==h<<24>>24);a[k]=o;pZ(b)}else{pZ(b)}}while(0);if((a[n]|0)!=-88){n=b+272|0;o=c[n>>2]|0;c[n>>2]=o-1;if((o|0)>0){pV(b);return}else{c[b+260>>2]=83992;return}}o=c[b+264>>2]|0;n=b+272|0;k=a[b+291|0]&1;h=k&255;c[b+268>>2]=o-(c[n>>2]<<h);m=c[b+284>>2]|0;if(k<<24>>24==0){p=m-6-(a[b+2111|0]&1)|0}else{p=m-8|0}m=(a[b+290|0]|0)==-113;if(m){q=((a[b+2111|0]&1|4566)<<h)+p|0}else{q=p}if(o>>>0<q>>>0){r=-(q-o>>h)|0}else{r=o-q>>h}h=m?84312:84296;c[n>>2]=r;if((r|0)>-1){f2[c[h>>2]&1023](b);return}else{c[b+260>>2]=h;return}}function qj(b,c,e){b=b|0;c=c|0;e=e|0;return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,4,c,e)|0}function qk(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0;c=b+2100|0;e=a[c]|0;do{if((e&1)!=0){if((d[b+2109|0]|0)<167){f=4214}else{if((a[b+2111|0]&1)==0){g=0;h=e}else{f=4214}}if((f|0)==4214){i=e&2;a[c]=i;g=i<<24>>24!=0;h=i}if((a[b+2094|0]&32)==0){a[c]=h&-3}if(!g){break}pX(b);return}}while(0);qm(84008,b);return}function ql(b,c,e){b=b|0;c=c|0;e=e|0;return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,3,c,e)|0}function qm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=d+2107|0;f=a[e]|0;g=a[d+2028+((f&255)<<2)|0]|0;h=d+2109|0;do{if(g<<24>>24==(a[h]|0)){if((a[d+2111|0]&1|a[d+2094|0]&2|0)==0){i=f}else{break}do{i=i+1&255;}while((a[d+2028+((i&255)<<2)|0]|0)==g<<24>>24);a[e]=i;pZ(d)}else{pZ(d)}}while(0);if((a[h]|0)!=-88){h=d+272|0;i=c[h>>2]|0;c[h>>2]=i-1;if((i|0)>0){f2[c[b>>2]&1023](d);return}else{c[d+260>>2]=b;return}}b=c[d+264>>2]|0;i=d+272|0;h=a[d+291|0]&1;e=h&255;c[d+268>>2]=b-(c[i>>2]<<e);g=c[d+284>>2]|0;if(h<<24>>24==0){j=g-6-(a[d+2111|0]&1)|0}else{j=g-8|0}g=(a[d+290|0]|0)==-113;if(g){k=((a[d+2111|0]&1|4566)<<e)+j|0}else{k=j}if(b>>>0<k>>>0){l=-(k-b>>e)|0}else{l=b-k>>e}e=g?84312:84296;c[i>>2]=l;if((l|0)>-1){f2[c[e>>2]&1023](d);return}else{c[d+260>>2]=e;return}}function qn(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b+2100|0;f=a[e]|0;do{if((f&1)==0){g=f}else{if((d[b+2109|0]|0)<167){h=4252}else{if((a[b+2111|0]&1)==0){i=0;j=f}else{h=4252}}if((h|0)==4252){k=f&2;a[e]=k;i=k<<24>>24!=0;j=k}if((a[b+2094|0]&32)==0){k=j&-3;a[e]=k;l=k}else{l=j}if(!i){g=l;break}pX(b);return}}while(0);if((g&2)==0){m=(d[b+290|0]|0)+(d[b+2095|0]|0)|0}else{m=d[b+2102|0]|0}g=d[b+2106|0]|0;l=d[b+2104|0]|0;a[b+2103|0]=a[(c[b+256>>2]|0)+((m^-(g>>>6&1))<<1&14|l<<4|(g<<10&8192|4096)-(((d[b+2094|0]|0)<<8|l<<5)&4096))|0]|0;qm(84024,b);return}function qo(b,c,e){b=b|0;c=c|0;e=e|0;return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,2,c,e)|0}function qp(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0;c=b+2100|0;e=a[c]|0;do{if((e&1)!=0){if((d[b+2109|0]|0)<167){f=4268}else{if((a[b+2111|0]&1)==0){g=0;h=e}else{f=4268}}if((f|0)==4268){i=e&2;a[c]=i;g=i<<24>>24!=0;h=i}if((a[b+2094|0]&32)==0){a[c]=h&-3}if(!g){break}pX(b);return}}while(0);qm(84040,b);return}function qq(b,c,e){b=b|0;c=c|0;e=e|0;return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,1,c,e)|0}function qr(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+64|0;f=e|0;g=b+2100|0;h=a[g]|0;j=b+2109|0;k=a[j]|0;do{if((h&1)==0){l=h}else{if((k&255)<167){m=4281}else{if((a[b+2111|0]&1)==0){n=0;o=h}else{m=4281}}if((m|0)==4281){p=h&2;a[g]=p;n=p<<24>>24!=0;o=p}if((a[b+2094|0]&32)==0){p=o&-3;a[g]=p;q=p}else{q=o}if(!n){l=q;break}pX(b);i=e;return}}while(0);q=k&255;n=a[b+2099|0]|0;o=(n&255)<(k&255)|(n&255)>167?161:(n&255)-7|0;do{if((q|0)<(o|0)){n=c[b+2020>>2]|0;h=d[b+2094|0]|0;if((l&2)==0){m=(d[b+290|0]|0)+(d[b+2095|0]|0)|0;p=b+2111|0;r=m<<2&992|h<<7&1024;s=q+1+(d[b+2096|0]|0)-(a[p]&1)|0;t=m;u=p}else{p=d[b+2102|0]|0;r=p<<2&992|h<<4&1024;s=(d[b+2101|0]|0)+q|0;t=p;u=b+2111|0}p=(c[b+256>>2]|0)+(r|6144)|0;h=s>>3;m=t&7;if((k&255)<8){v=(o|0)<8?o:8;w=f+(8-q<<2)|0;if((a[u]&1)==0){qu(b,v,w,p,m,h)}else{qt(b,v,w,p,m,h)}v=a[j]|0;x=v&255;if((v&255)>8){y=n;z=w;w=(x<<2)-32|0;yE(y|0,z|0,w)|0;if((x|0)>=(o|0)){break}}else{if(!((v&255)>7&(x|0)<(o|0))){break}}A=(x-q>>3)+h|0}else{A=h}if((a[u]&1)==0){qu(b,o,n,p,m,A);break}else{qt(b,o,n,p,m,A);break}}}while(0);A=a[j]|0;if(A<<24>>24!=-88){c[b+276>>2]=c[b+280>>2];j=b+2106|0;a[b+2105|0]=a[j]|0;a[b+2110|0]=(A&255)<160?A+8&255:-88;o=d[b+2094|0]|0;if((a[g]&2)==0){g=(d[b+290|0]|0)+(d[b+2095|0]|0)<<2&992|(((A&255)+1+(d[b+2096|0]|0)-(a[b+2111|0]&1)|0)>>>3|o<<7)&1055;u=c[b+256>>2]|0;a[b+2104|0]=a[u+(g|6144)|0]|0;B=u+(g|14336)|0}else{g=d[b+2102|0]<<2&992|o<<4&1024|((d[b+2101|0]|0)+(A&255)|0)>>>3&31;A=c[b+256>>2]|0;a[b+2104|0]=a[A+(g|6144)|0]|0;B=A+(g|14336)|0}a[j]=a[B]|0;qm(84056,b);i=e;return}B=b+272|0;j=(c[B>>2]|0)+1|0;c[B>>2]=j;g=c[b+264>>2]|0;A=a[b+291|0]&1;o=A&255;c[b+268>>2]=g-(j<<o);j=c[b+284>>2]|0;if(A<<24>>24==0){C=j-6-(a[b+2111|0]&1)|0}else{C=j-8|0}j=(a[b+290|0]|0)==-113;if(j){D=((a[b+2111|0]&1|4566)<<o)+C|0}else{D=C}if(g>>>0<D>>>0){E=-(D-g>>o)|0}else{E=g-D>>o}o=j?84312:84296;c[B>>2]=E;if((E|0)>-1){f2[c[o>>2]&1023](b);i=e;return}else{c[b+260>>2]=o;i=e;return}}function qs(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0;f=a[b+2109|0]|0;g=f&255;return pO(b,g,(f&255)<160?g+8|0:168,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,0,c,e)|0}function qt(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;m=i;i=i+8|0;n=m|0;o=n;p=f+2109|0;q=f+2094|0;r=(d[q]|0)<<3&128^128;s=f+256|0;t=c[s>>2]|0;u=r<<5;v=f+272|0;w=f+2107|0;x=f+2004|0;y=f+280|0;z=f+2106|0;A=k^7;B=g+7|0;C=l;l=d[p]|0;L5463:while(1){D=d[w]|0;E=d[f+2028+(D<<2)|0]|0;F=l+8|0;L5465:do{if((E|0)<(F|0)){G=l-E|0;H=(c[v>>2]|0)+((G+11|0)<6?-14:-19-G|0)|0;G=D;while(1){I=G+1|0;if((d[f+2028+(I<<2)|0]|0|0)<(F|0)){H=H-6|0;G=I}else{break}}if((H|0)<0){J=l&255;K=4388;break L5463}c[v>>2]=H;G=D;do{I=d[f+2028+(G<<2)+1|0]|0;L=c[x>>2]|0;M=(d[L+(I+2)|0]|0)<<4;N=a[L+(I+3)|0]|0;I=N&255;L=d[f+2028+(G<<2)+2|0]|0;O=((I&64|0)!=0?L^15:L)<<1;L=I<<10&8192;if((a[q]&4)==0){P=O&494|M;Q=c[s>>2]|0;R=P;S=Q;T=Q+(P|L)|0}else{P=O|M&4064;M=c[s>>2]|0;R=P;S=M;T=M+(P|L)|0}P=I<<3&256;b[f+2072+(G<<1)>>1]=(b[82936+((d[S+(R+(L|1))|0]|0|P)<<1)>>1]<<1)+(b[82936+((d[T]|0|P)<<1)>>1]|0)&65535;a[f+2028+(G<<2)+3|0]=N;G=G+1|0;}while((d[f+2028+(G<<2)|0]|0|0)<(F|0));a[w]=G&255;U=G;V=l-8|0;K=4342}else{H=D-1|0;do{if((H|0)>=0){N=l-8|0;if((d[f+2028+(H<<2)|0]|0|0)<=(N|0)){break}P=(c[v>>2]|0)-8|0;if((P|0)<0){J=l&255;K=4389;break L5463}c[v>>2]=P;U=D;V=N;K=4342;break L5465}}while(0);H=c[v>>2]|0;if(H>>>0<=7){J=l&255;K=4387;break L5463}G=((B|0)<(E|0)?B:E)-l>>3;N=H>>>3;P=N>>>0<G>>>0?N:G;L=c[y>>2]|0;I=d[z]|0;M=P<<3;c[v>>2]=H-M;H=~G;G=~N;N=H>>>0>G>>>0;O=C;Q=P;P=L;L=I;I=h+(l-8<<2)|0;while(1){W=L<<2&28;c[I>>2]=c[f+((W|P&3)<<2)>>2];c[I+4>>2]=c[f+((P>>>2&3|W)<<2)>>2];c[I+8>>2]=c[f+((P>>>4&3|W)<<2)>>2];c[I+12>>2]=c[f+((P>>>6&3|W)<<2)>>2];c[I+16>>2]=c[f+((P>>>8&3|W)<<2)>>2];c[I+20>>2]=c[f+((P>>>10&3|W)<<2)>>2];c[I+24>>2]=c[f+((P>>>12&3|W)<<2)>>2];c[I+28>>2]=c[f+(W+(P>>>14)<<2)>>2];W=O&31;X=d[j+W|0]|0;Y=a[j+(W|8192)|0]|0;W=Y&255;Z=(X<<4|u|W<<10&8192)-((X&r)<<5)+(((W&64|0)!=0?A:k)<<1)|0;X=W<<3&256;_=((e[82936+((X|(d[t+(Z|1)|0]|0))<<1)>>1]|0)<<1)+(e[82936+((X|(d[t+Z|0]|0))<<1)>>1]|0)|0;Z=Q-1|0;if((Z|0)==0){break}else{O=O+1|0;Q=Z;P=_;L=W;I=I+32|0}}$=C-1-(N?H:G)|0;aa=M+l|0;ab=Y;ac=_}}while(0);if((K|0)==4342){K=0;E=c[y>>2]|0;D=a[z]|0;I=(D&255)<<2&28;c[h+(V<<2)>>2]=c[f+((I|E&3)<<2)>>2];c[h+(l-7<<2)>>2]=c[f+((I|E>>>2&3)<<2)>>2];c[h+(l-6<<2)>>2]=c[f+((I|E>>>4&3)<<2)>>2];c[h+(l-5<<2)>>2]=c[f+((I|E>>>6&3)<<2)>>2];c[h+(l-4<<2)>>2]=c[f+((I|E>>>8&3)<<2)>>2];c[h+(l-3<<2)>>2]=c[f+((I|E>>>10&3)<<2)>>2];c[h+(l-2<<2)>>2]=c[f+((I|E>>>12&3)<<2)>>2];c[h+(l-1<<2)>>2]=c[f+(I+(E>>>14)<<2)>>2];L=U-1|0;P=a[q]|0;L5490:do{if((P&2)==0){Q=L;O=a[f+2028+(L<<2)|0]|0;while(1){W=(O&255)-l|0;Z=f+2072+(Q<<1)|0;b[Z>>1]=(e[Z>>1]|0)>>>(((((W|0)>-1?-W|0:W)<<1)+16|0)>>>0)&65535;W=Q-1|0;if((Q|0)<=0){break L5490}Z=a[f+2028+(W<<2)|0]|0;if((Z&255|0)>(V|0)){Q=W;O=Z}else{break}}}else{c[n>>2]=-1;c[n+4>>2]=-1;O=(P&255)<<7;Q=L;M=a[f+2028+(L<<2)|0]|0;while(1){G=(M&255)-l|0;H=(G|0)<0;N=H?G:-G|0;Z=N+8|0;W=H?0:G;G=a[f+2028+(Q<<2)+1|0]|0;H=a[f+2028+(Q<<2)+3|0]|0;X=f+2072+(Q<<1)|0;ad=e[X>>1]|0;ae=(H&255)<<2&28;if(((H|D)&255&O|0)==0){L5500:do{switch(N|0){case-7:{K=4370;break};case-5:{K=4364;break};case 0:{H=ad>>>14;if((H|0)==0){K=4352;break L5500}af=W+7|0;ag=o+af|0;if((G&255)>=(d[ag]|0)){K=4352;break L5500}a[ag]=G;c[h+(af+V<<2)>>2]=c[f+128+((ae|H)<<2)>>2];K=4352;break};case-4:{K=4361;break};case-2:{K=4355;break};case-1:{K=4352;break};case-3:{K=4358;break};case-6:{K=4367;break};default:{}}}while(0);do{if((K|0)==4352){K=0;N=ad>>>12&3;if((N|0)==0){K=4355;break}H=W+6|0;af=o+H|0;if((G&255)>=(d[af]|0)){K=4355;break}a[af]=G;c[h+(H+V<<2)>>2]=c[f+128+((N|ae)<<2)>>2];K=4355}}while(0);do{if((K|0)==4355){K=0;N=ad>>>10&3;if((N|0)==0){K=4358;break}H=W+5|0;af=o+H|0;if((G&255)>=(d[af]|0)){K=4358;break}a[af]=G;c[h+(H+V<<2)>>2]=c[f+128+((N|ae)<<2)>>2];K=4358}}while(0);do{if((K|0)==4358){K=0;N=ad>>>8&3;if((N|0)==0){K=4361;break}H=W+4|0;af=o+H|0;if((G&255)>=(d[af]|0)){K=4361;break}a[af]=G;c[h+(H+V<<2)>>2]=c[f+128+((N|ae)<<2)>>2];K=4361}}while(0);do{if((K|0)==4361){K=0;N=ad>>>6&3;if((N|0)==0){K=4364;break}H=W+3|0;af=o+H|0;if((G&255)>=(d[af]|0)){K=4364;break}a[af]=G;c[h+(H+V<<2)>>2]=c[f+128+((N|ae)<<2)>>2];K=4364}}while(0);do{if((K|0)==4364){K=0;N=ad>>>4&3;if((N|0)==0){K=4367;break}H=W+2|0;af=o+H|0;if((G&255)>=(d[af]|0)){K=4367;break}a[af]=G;c[h+(H+V<<2)>>2]=c[f+128+((N|ae)<<2)>>2];K=4367}}while(0);do{if((K|0)==4367){K=0;N=ad>>>2&3;if((N|0)==0){K=4370;break}H=W+1|0;af=o+H|0;if((G&255)>=(d[af]|0)){K=4370;break}a[af]=G;c[h+(H+V<<2)>>2]=c[f+128+((N|ae)<<2)>>2];K=4370}}while(0);do{if((K|0)==4370){K=0;N=ad&3;if((N|0)==0){break}H=o+W|0;if((G&255)>=(d[H]|0)){break}a[H]=G;c[h+(W+V<<2)>>2]=c[f+128+((ae|N)<<2)>>2]}}while(0);ah=ad>>>(Z<<1>>>0)}else{N=E>>>(W<<1>>>0);H=ad;af=W;ag=Z;while(1){ai=H&3;do{if((ai|0)!=0){aj=o+af|0;if((G&255)>=(d[aj]|0)){break}a[aj]=G;aj=N&3;if((aj|0)==0){ak=f+128+((ai|ae)<<2)|0}else{ak=f+((aj|I)<<2)|0}c[h+(af+V<<2)>>2]=c[ak>>2]}}while(0);ai=H>>>2;aj=ag-1|0;if((aj|0)==0){ah=ai;break}else{N=N>>>2;H=ai;af=af+1|0;ag=aj}}}b[X>>1]=ah&65535;ag=Q-1|0;if((Q|0)<=0){break L5490}af=a[f+2028+(ag<<2)|0]|0;if((af&255|0)>(V|0)){Q=ag;M=af}else{break}}}}while(0);I=C&31;E=d[j+I|0]|0;D=a[j+(I|8192)|0]|0;I=D&255;L=(E<<4|u|I<<10&8192)-((E&r)<<5)+(((I&64|0)!=0?A:k)<<1)|0;E=I<<3&256;$=C+1|0;aa=F;ab=D;ac=((e[82936+((E|(d[t+(L|1)|0]|0))<<1)>>1]|0)<<1)+(e[82936+((E|(d[t+L|0]|0))<<1)>>1]|0)|0}c[y>>2]=ac;a[z]=ab;if((aa|0)<(g|0)){C=$;l=aa}else{J=aa&255;K=4390;break}}if((K|0)==4387){a[p]=J;i=m;return}else if((K|0)==4388){a[p]=J;i=m;return}else if((K|0)==4389){a[p]=J;i=m;return}else if((K|0)==4390){a[p]=J;i=m;return}}function qu(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0;l=f+2094|0;m=d[l]|0;n=m<<3&128^128;o=f+256|0;p=c[o>>2]|0;q=(n<<5)+(j<<1)|0;j=-(m&1)&3;m=f+2109|0;r=f+272|0;s=f+2107|0;t=f+2004|0;u=f+280|0;v=g+7|0;w=k;k=d[m]|0;L5554:while(1){x=d[s]|0;y=d[f+2028+(x<<2)|0]|0;z=k+8|0;L5556:do{if((y|0)<(z|0)){A=(c[r>>2]|0)-8|0;B=a[l]|0;L5558:do{if((B&2)==0){if((A|0)<0){C=k&255;D=4452;break L5554}c[r>>2]=A;E=x;while(1){F=E+1|0;if((d[f+2028+(F<<2)|0]|0|0)<(z|0)){E=F}else{G=F;break}}}else{E=k-y+11|0;F=A-((E|0)<6?6:E)|0;E=x;while(1){H=E+1|0;if((d[f+2028+(H<<2)|0]|0|0)<(z|0)){F=F-6|0;E=H}else{break}}if((F|0)<0){C=k&255;D=4453;break L5554}c[r>>2]=F;E=x;H=B;while(1){I=d[f+2028+(E<<2)+1|0]|0;J=c[t>>2]|0;K=(d[J+(I+2)|0]|0)<<4;L=a[J+(I+3)|0]|0;I=L&255;J=d[f+2028+(E<<2)+2|0]|0;M=((I&64|0)!=0?J^15:J)<<1;if((H&4)==0){J=M&494|K;N=c[o>>2]|0;O=J;P=N;Q=N+J|0}else{J=M|K&4064;K=c[o>>2]|0;O=J;P=K;Q=K+J|0}J=I<<3&256;b[f+2072+(E<<1)>>1]=(b[82936+((d[P+(O+1)|0]|0|J)<<1)>>1]<<1)+(b[82936+((d[Q]|0|J)<<1)>>1]|0)&65535;a[f+2028+(E<<2)+3|0]=L;L=E+1|0;if((d[f+2028+(L<<2)|0]|0|0)>=(z|0)){G=L;break L5558}E=L;H=a[l]|0}}}while(0);a[s]=G&255;R=G;S=k-8|0;D=4415}else{B=x-1|0;do{if((B|0)>=0){A=k-8|0;if((d[f+2028+(B<<2)|0]|0|0)<=(A|0)){break}H=(c[r>>2]|0)-8|0;if((H|0)<0){C=k&255;D=4449;break L5554}c[r>>2]=H;R=x;S=A;D=4415;break L5556}}while(0);B=c[r>>2]|0;if(B>>>0<=7){C=k&255;D=4450;break L5554}A=((v|0)<(y|0)?v:y)-k>>3;H=B>>>3;E=H>>>0<A>>>0?H:A;F=c[u>>2]|0;L=E<<3;c[r>>2]=B-L;B=~A;A=~H;H=B>>>0>A>>>0;J=w;I=E;E=F;F=h+(k-8<<2)|0;while(1){c[F>>2]=c[f+((E&j)<<2)>>2];c[F+4>>2]=c[f+((E>>>2&j)<<2)>>2];c[F+8>>2]=c[f+((E>>>4&j)<<2)>>2];c[F+12>>2]=c[f+((E>>>6&j)<<2)>>2];c[F+16>>2]=c[f+((E>>>8&j)<<2)>>2];c[F+20>>2]=c[f+((E>>>10&j)<<2)>>2];c[F+24>>2]=c[f+((E>>>12&j)<<2)>>2];c[F+28>>2]=c[f+((E>>>14&j)<<2)>>2];K=d[i+(J&31)|0]|0;M=(K<<4)+q-((K&n)<<5)|0;T=((e[82936+((d[p+(M|1)|0]|0)<<1)>>1]|0)<<1)+(e[82936+((d[p+M|0]|0)<<1)>>1]|0)|0;M=I-1|0;if((M|0)==0){break}else{J=J+1|0;I=M;E=T;F=F+32|0}}U=w-1-(H?B:A)|0;V=L+k|0;W=T}}while(0);if((D|0)==4415){D=0;y=c[u>>2]|0;c[h+(S<<2)>>2]=c[f+((y&j)<<2)>>2];x=k-7|0;c[h+(x<<2)>>2]=c[f+((y>>>2&j)<<2)>>2];F=k-6|0;c[h+(F<<2)>>2]=c[f+((y>>>4&j)<<2)>>2];E=k-5|0;c[h+(E<<2)>>2]=c[f+((y>>>6&j)<<2)>>2];I=k-4|0;c[h+(I<<2)>>2]=c[f+((y>>>8&j)<<2)>>2];J=k-3|0;c[h+(J<<2)>>2]=c[f+((y>>>10&j)<<2)>>2];M=k-2|0;c[h+(M<<2)>>2]=c[f+((y>>>12&j)<<2)>>2];K=k-1|0;c[h+(K<<2)>>2]=c[f+((y>>>14&j)<<2)>>2];N=R-1|0;X=a[f+2028+(N<<2)|0]|0;L5588:do{if((a[l]&2)==0){Y=N;Z=X;while(1){_=(Z&255)-k|0;$=f+2072+(Y<<1)|0;b[$>>1]=(e[$>>1]|0)>>>(((((_|0)>-1?-_|0:_)<<1)+16|0)>>>0)&65535;_=Y-1|0;if((Y|0)<=0){break L5588}$=a[f+2028+(_<<2)|0]|0;if(($&255|0)>(S|0)){Y=_;Z=$}else{break}}}else{Z=N;Y=X;while(1){L=(Y&255)-k|0;A=(L|0)<0;B=A?L:-L|0;H=B+8|0;$=A?0:L;L=d[f+2028+(Z<<2)+3|0]|0;A=f+2072+(Z<<1)|0;_=e[A>>1]|0;aa=L>>>2&4;if((L&128|0)==0){L5606:do{switch(B|0){case-6:{D=4432;break};case-5:{D=4430;break};case-3:{D=4426;break};case-1:{D=4422;break};case-4:{D=4428;break};case-2:{D=4424;break};case-7:{D=4434;break};case 0:{L=_>>>14;if((L|0)==0){D=4422;break L5606}c[h+($+K<<2)>>2]=c[f+128+((aa|L)<<2)>>2];D=4422;break};default:{}}}while(0);do{if((D|0)==4422){D=0;B=_>>>12&3;if((B|0)==0){D=4424;break}c[h+($+M<<2)>>2]=c[f+128+((B|aa)<<2)>>2];D=4424}}while(0);do{if((D|0)==4424){D=0;B=_>>>10&3;if((B|0)==0){D=4426;break}c[h+($+J<<2)>>2]=c[f+128+((B|aa)<<2)>>2];D=4426}}while(0);do{if((D|0)==4426){D=0;B=_>>>8&3;if((B|0)==0){D=4428;break}c[h+($+I<<2)>>2]=c[f+128+((B|aa)<<2)>>2];D=4428}}while(0);do{if((D|0)==4428){D=0;B=_>>>6&3;if((B|0)==0){D=4430;break}c[h+($+E<<2)>>2]=c[f+128+((B|aa)<<2)>>2];D=4430}}while(0);do{if((D|0)==4430){D=0;B=_>>>4&3;if((B|0)==0){D=4432;break}c[h+($+F<<2)>>2]=c[f+128+((B|aa)<<2)>>2];D=4432}}while(0);do{if((D|0)==4432){D=0;B=_>>>2&3;if((B|0)==0){D=4434;break}c[h+($+x<<2)>>2]=c[f+128+((B|aa)<<2)>>2];D=4434}}while(0);do{if((D|0)==4434){D=0;B=_&3;if((B|0)==0){break}c[h+($+S<<2)>>2]=c[f+128+((aa|B)<<2)>>2]}}while(0);ab=_>>>(H<<1>>>0)}else{B=y>>>($<<1>>>0);L=_;ac=$;ad=H;while(1){ae=L&3;if((ae|0)!=0){af=B&j;if((af|0)==0){ag=f+128+((ae|aa)<<2)|0}else{ag=f+(af<<2)|0}c[h+(ac+S<<2)>>2]=c[ag>>2]}af=L>>>2;ae=ad-1|0;if((ae|0)==0){ab=af;break}else{B=B>>>2;L=af;ac=ac+1|0;ad=ae}}}b[A>>1]=ab&65535;ad=Z-1|0;if((Z|0)<=0){break L5588}ac=a[f+2028+(ad<<2)|0]|0;if((ac&255|0)>(S|0)){Z=ad;Y=ac}else{break}}}}while(0);y=d[i+(w&31)|0]|0;x=(y<<4)+q-((y&n)<<5)|0;U=w+1|0;V=z;W=((e[82936+((d[p+(x|1)|0]|0)<<1)>>1]|0)<<1)+(e[82936+((d[p+x|0]|0)<<1)>>1]|0)|0}c[u>>2]=W;if((V|0)<(g|0)){w=U;k=V}else{C=V&255;D=4451;break}}if((D|0)==4449){a[m]=C;return}else if((D|0)==4450){a[m]=C;return}else if((D|0)==4451){a[m]=C;return}else if((D|0)==4452){a[m]=C;return}else if((D|0)==4453){a[m]=C;return}}function qv(b){b=b|0;var e=0;a[b+2109|0]=0;e=b+2100|0;if((a[e]&1&(d[b+2094|0]|0)>>>5|0)==0){a[e]=0}else{a[e]=2;a[b+2101|0]=a[b+2096|0]&7|8;e=b+2102|0;a[e]=(a[e]|0)+1&255}c[b+260>>2]=83960;pT(b);return}function qw(b,e,f){b=b|0;e=e|0;f=f|0;var g=0;g=a[b+2096|0]&7;return pO(b,0,8-g|0,(((c[b+284>>2]|0)-(c[b+264>>2]|0)|0)>>>0<16)+(d[b+290|0]|0)|0,0,(a[b+2112|0]&1)!=0,((d[b+2094|0]|0)>>>5&a[b+2100|0])<<1&2,g>>>0>5?5:g,e,f+1+g-(a[b+2111|0]&1)|0)|0}function qx(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=a[b+2109|0]|0;g=a[b+2110|0]|0;if(f<<24>>24==g<<24>>24){h=f&255;i=(f&255)<160?h+8|0:168;j=h}else{i=g&255;j=f&255}return pP(b,j,i,d[b+290|0]|0,d[b+2107|0]|0,(a[b+2112|0]&1)!=0,d[b+2100|0]|0,0,c,e)|0}function qy(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=d[b+2107|0]|0;if((a[b+2111|0]&1|a[b+2094|0]&2|0)==0){g=f;h=e}else{g=f+1|0;h=e+6|0}return pO(b,d[b+2109|0]|0,d[b+2110|0]|0,d[b+290|0]|0,g,(a[b+2112|0]&1)!=0,a[b+2100|0]|0,5,c,h)|0}function qz(b){b=b|0;var e=0,f=0,g=0,h=0;e=a[b+2094|0]|0;if((e&32)==0){f=0}else{f=(a[b+2097|0]|0)==0|0}a[b+2112|0]=f;f=b+2102|0;a[f]=-1;g=b+272|0;h=(c[g>>2]|0)-83|0;c[g>>2]=h;if((h|0)<=-1){c[b+260>>2]=83976;return}a[b+2109|0]=0;h=b+2100|0;if(((e&255)>>>5&1&d[h]|0)==0){a[h]=0}else{a[h]=2;a[b+2101|0]=a[b+2096|0]&7|8;a[f]=0}c[b+260>>2]=83960;pT(b);return}function qA(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=a[b+2094|0]|0;if((e&32)==0){f=0}else{f=(a[b+2097|0]|0)==0}g=a[b+2096|0]&7;return pO(b,0,8-g|0,0,0,f,((e&255)>>>5&a[b+2100|0])<<1&2,g>>>0>5?5:g,c,d+84+g-(a[b+2111|0]&1)|0)|0}function qB(a){a=a|0;return}function qC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+128|0;f=c[e>>2]|0;if(f>>>0>=d>>>0){return}g=b+132|0;h=a[g]|0;do{if(h<<24>>24!=-1){i=c[b+120>>2]|0;j=c[i>>2]|0;k=a[i+7|0]&1;i=-k&3;l=459-((j-f|0)>>>(k>>>0))-i|0;m=l>>>0>455?l-456|0:l;l=m>>>0>80?80:m;if((d-f|0)>>>(k>>>0)>>>0<456){n=459-((j-d|0)>>>(k>>>0))-i|0;i=n>>>0>455?n-456|0:n;o=(i>>>0>80?80:i)-l+(i>>>0<m>>>0?80:0)|0}else{o=80}m=h&255;i=(m>>>0<=l>>>0?80:0)+(m-l)|0;if(i>>>0>o>>>0){p=o}else{a[g]=-1;p=i}if((p|0)==0){break}i=b+134|0;m=b+124|0;n=b+133|0;k=l;l=p;while(1){j=l-1|0;if((k&1|0)==0){q=(k|0)==80?0:k;if((a[i]&1)!=0){a[(q>>>1)+(b+80)|0]=a[n]&1}r=q<<1;a[b+q|0]=a[(c[m>>2]|0)+r|0]|0;a[b+(q+1)|0]=a[(c[m>>2]|0)+(r|1)|0]|0;s=q}else{q=(k>>>1)+(b+80)|0;a[q]=a[n]&1|a[q]&1&a[i];s=k}if((j|0)==0){break}else{k=s+1|0;l=j}}}}while(0);c[e>>2]=d;return}function qD(b){b=b|0;c[b>>2]=26728;c[b+4>>2]=34200;a[b+12|0]=0;a[b+13|0]=0;c[b+8>>2]=28696;return}function qE(a){a=a|0;var b=0;b=a;c[b>>2]=c[18098];c[b+4>>2]=c[18099];c[b+8>>2]=c[18100];c[b+12>>2]=c[18101];c[b+16>>2]=c[18102];b=a+24|0;c[b>>2]=c[185306];c[b+4>>2]=c[185307];c[b+8>>2]=c[185308];c[b+12>>2]=c[185309];return}function qF(){var a=0,b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0,F=0,G=0.0,H=0,J=0.0,L=0,M=0,N=0.0,O=0,P=0,Q=0,R=0,S=0,T=0;a=i;i=i+16|0;b=a|0;d=a+8|0;c[(c[185312]|0)+16900>>2]=741216;while(1){e=ys(48)|0;if((e|0)!=0){break}f=(I=c[185320]|0,c[185320]=I+0,I);if((f|0)==0){g=4509;break}gs[f&63]()}if((g|0)==4509){f=ff(4)|0;c[f>>2]=72440;dr(f|0,79056,316)}f=e;c[e>>2]=75872;j=e+12|0;k=j;l=j;c[k>>2]=l;j=e+16|0;c[j>>2]=l;m=e+20|0;yB(m|0,0,24);c[e+4>>2]=2097152;c[e+8>>2]=32e3;c[e+36>>2]=0;c[e+28>>2]=0;c[e+32>>2]=0;n=e+40|0;c[n>>2]=0;o=e+24|0;c[o>>2]=0;if((l|0)!=(l|0)){p=l;do{q=c[p+8>>2]|0;if((q|0)!=0){f2[c[(c[q>>2]|0)+20>>2]&1023](q)}p=c[p+4>>2]|0;}while((p|0)!=(l|0))}p=m;do{if((c[p>>2]|0)!=0){m=c[j>>2]|0;q=(c[k>>2]|0)+4|0;r=m|0;c[(c[r>>2]|0)+4>>2]=c[q>>2];c[c[q>>2]>>2]=c[r>>2];c[p>>2]=0;if((m|0)==(l|0)){break}else{s=m}while(1){m=c[s+4>>2]|0;if((s|0)!=0){yt(s)}if((m|0)==(l|0)){break}else{s=m}}}}while(0);c[n>>2]=4128;t=65.536;L5724:while(1){n=~~(t/4.199999809265137);s=(n|0)>23?23:n;while(1){u=ys(68)|0;if((u|0)!=0){break}n=(I=c[185320]|0,c[185320]=I+0,I);if((n|0)==0){g=4530;break L5724}gs[n&63]()}c[u>>2]=75832;yB(u+4|0,0,24);c[u+28>>2]=s;c[u+32>>2]=s;yB(u+36|0,0,24);c[u+60>>2]=s;c[u+64>>2]=s;while(1){v=ys(12)|0;if((v|0)!=0){break}n=(I=c[185320]|0,c[185320]=I+0,I);if((n|0)==0){g=4541;break L5724}gs[n&63]()}n=v;j=v+8|0;if((j|0)!=0){c[j>>2]=u}c[(c[k>>2]|0)+4>>2]=n;c[v>>2]=c[k>>2];c[k>>2]=n;c[v+4>>2]=l;c[p>>2]=(c[p>>2]|0)+1;w=t/+(s|0);if(w<8.399999618530273){g=4547;break}else{t=w}}if((g|0)==4541){v=ff(4)|0;c[v>>2]=72440;dr(v|0,79056,316)}else if((g|0)==4530){v=ff(4)|0;c[v>>2]=72440;dr(v|0,79056,316)}else if((g|0)==4547){t=w*32.0;x=w;y=x*2.0;v=~~(t/((+W(+(y*.20000000298023224))+2.0)*.5)+.5);z=t/+(v|0);A=z;B=A*2.0;C=x*A/(B+-2.0)+A/.20000000298023224;if(C<x/.20000000298023224){u=~~(t/((+W(+(y*(2.0-2.0/((+W(+((+W(+(y*(2.0-2.0/((+W(+((+W(+(y*(2.0-2.0/((+W(+((+W(+(y*(2.0-2.0/((+W(+((+W(+(y*(2.0-2.0/((+W(+((+W(+(y*(2.0-2.0/((+W(+((+W(+(y*(2.0-2.0/((+W(+((+W(+(y*(2.0-2.0/((+W(+(B*.20000000298023224))+2.0)*.5))))+2.0)*.5*2.0*.20000000298023224))+2.0)*.5))))+2.0)*.5*2.0*.20000000298023224))+2.0)*.5))))+2.0)*.5*2.0*.20000000298023224))+2.0)*.5))))+2.0)*.5*2.0*.20000000298023224))+2.0)*.5))))+2.0)*.5*2.0*.20000000298023224))+2.0)*.5))))+2.0)*.5*2.0*.20000000298023224))+2.0)*.5))))+2.0)*.5*2.0*.20000000298023224))+2.0)*.5))))+2.0)*.5)+.5);B=t/+(u|0);t=B*32.0;y=B;A=y*2.0;n=~~(t/((+W(+(A*.20000000298023224))+2.0)*.5)+.5);D=t/+(n|0);t=D;if(x*y/(A+-2.0)+(y*t/(t*2.0+-2.0)+t/.20000000298023224)<C){while(1){E=ys(52)|0;if((E|0)!=0){break}j=(I=c[185320]|0,c[185320]=I+0,I);if((j|0)==0){g=4556;break}gs[j&63]()}if((g|0)==4556){j=ff(4)|0;c[j>>2]=72440;dr(j|0,79056,316)}j=~~+af(+(2.7149999141693115/((B+-1.0)/w)));c[E>>2]=75912;yB(E+4|0,0,48);rE(E,u,j,.5/w+1.2000000476837158/+(j|0));while(1){F=ys(12)|0;if((F|0)!=0){break}j=(I=c[185320]|0,c[185320]=I+0,I);if((j|0)==0){g=4567;break}gs[j&63]()}if((g|0)==4567){j=ff(4)|0;c[j>>2]=72440;dr(j|0,79056,316)}j=F;u=F+8|0;if((u|0)!=0){c[u>>2]=E}c[(c[k>>2]|0)+4>>2]=j;c[F>>2]=c[k>>2];c[k>>2]=j;c[F+4>>2]=l;c[p>>2]=(c[p>>2]|0)+1;G=B;H=n;J=D}else{G=w;H=v;J=z}while(1){L=ys(52)|0;if((L|0)!=0){break}v=(I=c[185320]|0,c[185320]=I+0,I);if((v|0)==0){g=4581;break}gs[v&63]()}if((g|0)==4581){v=ff(4)|0;c[v>>2]=72440;dr(v|0,79056,316)}v=~~+af(+(2.7149999141693115/((J+-1.0)/G)));c[L>>2]=75912;yB(L+4|0,0,48);rE(L,H,v,.5/G+1.2000000476837158/+(v|0));while(1){M=ys(12)|0;if((M|0)!=0){break}v=(I=c[185320]|0,c[185320]=I+0,I);if((v|0)==0){g=4592;break}gs[v&63]()}if((g|0)==4592){v=ff(4)|0;c[v>>2]=72440;dr(v|0,79056,316)}v=M;H=M+8|0;if((H|0)!=0){c[H>>2]=L}c[(c[k>>2]|0)+4>>2]=v;c[M>>2]=c[k>>2];c[k>>2]=v;c[M+4>>2]=l;c[p>>2]=(c[p>>2]|0)+1;N=J}else{N=w}while(1){O=ys(52)|0;if((O|0)!=0){break}M=(I=c[185320]|0,c[185320]=I+0,I);if((M|0)==0){g=4606;break}gs[M&63]()}if((g|0)==4606){M=ff(4)|0;c[M>>2]=72440;dr(M|0,79056,316)}M=~~(N*2048.0+.5);v=~~+af(+(2.7149999141693115/(.10000000149011612/N)));c[O>>2]=75952;L=O+4|0;w=.4000000059604645/N+1.2000000476837158/+(v|0);yB(L|0,0,48);H=v<<11;n=O+44|0;do{if((H|0)==0){P=0}else{F=cg(H|0,2)|0;j=K?-1:F;F=(j|0)==0?1:j;while(1){Q=ys(F)|0;if((Q|0)!=0){g=4621;break}j=(I=c[185320]|0,c[185320]=I+0,I);if((j|0)==0){break}gs[j&63]()}if((g|0)==4621){P=Q;break}F=ff(4)|0;c[F>>2]=72440;dr(F|0,79056,316)}}while(0);c[n>>2]=P;c[O+48>>2]=H;rp(P,2048,v,w,6);P=(v|0)==0;H=cg(v|0,2)|0;Q=K;F=v<<1;s=(F|0)>0;j=F>>1;F=-j|0;E=(((F|0)>-1?F:2147483647)+j<<1)+2|0;c[L>>2]=c[n>>2];c[O+16>>2]=M;c[O+20>>2]=0;L=O+8|0;j=c[L>>2]|0;if((j|0)!=0){yt(j)}do{if(P){c[L>>2]=0;c[O+12>>2]=0}else{j=Q?-1:H;F=(j|0)==0?1:j;while(1){R=ys(F)|0;if((R|0)!=0){g=4641;break}j=(I=c[185320]|0,c[185320]=I+0,I);if((j|0)==0){g=4639;break}gs[j&63]()}if((g|0)==4641){c[L>>2]=R;c[O+12>>2]=v;if(!s){break}yB(R|0,0,E|0);break}else if((g|0)==4639){F=ff(4)|0;c[F>>2]=72440;dr(F|0,79056,316)}}}while(0);c[O+24>>2]=c[n>>2];c[O+36>>2]=M;c[O+40>>2]=0;M=O+28|0;n=c[M>>2]|0;if((n|0)!=0){yt(n)}do{if(P){c[M>>2]=0;c[O+32>>2]=0}else{n=Q?-1:H;R=(n|0)==0?1:n;while(1){S=ys(R)|0;if((S|0)!=0){g=4661;break}n=(I=c[185320]|0,c[185320]=I+0,I);if((n|0)==0){g=4659;break}gs[n&63]()}if((g|0)==4659){R=ff(4)|0;c[R>>2]=72440;dr(R|0,79056,316)}else if((g|0)==4661){c[M>>2]=S;c[O+32>>2]=v;if(!s){break}yB(S|0,0,E|0);break}}}while(0);E=O;c[o>>2]=E;while(1){T=ys(12)|0;if((T|0)!=0){break}o=(I=c[185320]|0,c[185320]=I+0,I);if((o|0)==0){g=4676;break}gs[o&63]()}if((g|0)==4676){g=ff(4)|0;c[g>>2]=72440;dr(g|0,79056,316)}g=T;o=T+8|0;if((o|0)!=0){c[o>>2]=E}c[(c[k>>2]|0)+4>>2]=g;c[T>>2]=c[k>>2];c[k>>2]=g;c[T+4>>2]=l;c[p>>2]=(c[p>>2]|0)+1;rn(f);f=e;c[185296]=f;if((c[185322]|0)==0){i=a;return}h[92653]=59.72750056960583;gr[c[(c[e>>2]|0)+4>>2]&127](f,b,d);h[92654]=+((c[b>>2]|0)>>>0>>>0)*2097152.0/+((c[d>>2]|0)>>>0>>>0);i=a;return}}function qG(a){a=a|0;c[185298]=a;return}function qH(a){a=a|0;c[185310]=a;return}function qI(a){a=a|0;return}function qJ(a){a=a|0;c[185318]=a;return}function qK(a){a=a|0;c[185316]=a;return}function qL(a,b){a=a|0;b=b|0;return}function qM(){return}function qN(a,b,c){a=a|0;b=b|0;c=c|0;return}function qO(){var a=0;a=c[185296]|0;if((a|0)==0){return}f2[c[(c[a>>2]|0)+20>>2]&1023](a);return}function qP(a){a=a|0;c[185322]=a;gm[a&127](16,72416)|0;return}function qQ(){return kG()|0}function qR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+344|0;g=f|0;h=f+8|0;j=c[185314]|0;if((j|0)==0){k=kG()|0;c[185314]=k;l=k}else{l=j}if((l|0)!=(e|0)){m=0;i=f;return m|0}yB(h+20|0,0,24);yB(h+96|0,0,32);e=h+256|0;c[e>>2]=0;l=h+260|0;c[l>>2]=0;j=c[185312]|0;c[h+20>>2]=j+512;c[h+24>>2]=16384;c[h+44>>2]=j;c[h+48>>2]=512;k=c[j+17180>>2]|0;n=j+17172|0;o=(c[n>>2]|0)-k|0;c[h+28>>2]=k;c[h+32>>2]=o;o=c[n>>2]|0;n=(c[j+17184>>2]|0)-o|0;c[h+36>>2]=o;c[h+40>>2]=n;c[h+96>>2]=j+19432;c[h+100>>2]=64;c[h+104>>2]=j+19496;c[h+108>>2]=64;c[h+112>>2]=j+19148;c[h+116>>2]=80;c[h+120>>2]=j+19228;c[h+124>>2]=40;c[e>>2]=j+19904;c[l>>2]=16;ky(j|0,h);j=g|0;c[j>>2]=b;l=g+4|0;c[l>>2]=0;do{if((b|0)==0){c[l>>2]=2;p=4707}else{e=b;C=256;a[e]=C&255;C=C>>8;a[e+1|0]=C&255;e=b+2|0;c[j>>2]=e;c[l>>2]=2;if((e|0)==0){p=4707;break}n=b+3|0;c[j>>2]=n;a[e]=0;c[l>>2]=3;if((n|0)==0){p=4709;break}e=b+4|0;c[j>>2]=e;a[n]=0;c[l>>2]=4;if((e|0)==0){q=0;break}n=b+5|0;c[j>>2]=n;a[e]=0;q=n}}while(0);if((p|0)==4707){c[l>>2]=3;p=4709}if((p|0)==4709){c[l>>2]=4;q=0}c[l>>2]=5;p=c[185292]|0;if((p|0)==(c[185293]|0)){m=1;i=f;return m|0}else{r=p;s=q}while(1){q=d[r+12|0]|0;if((s|0)!=0){p=c[r>>2]|0;yE(s|0,p|0,q)|0;c[j>>2]=(c[j>>2]|0)+q}c[l>>2]=(c[l>>2]|0)+q;f3[c[r+4>>2]&1023](g,h);q=r+16|0;if((q|0)==(c[185293]|0)){m=1;break}r=q;s=c[j>>2]|0}i=f;return m|0}function qS(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[185312]|0;L5897:do{switch(d[(c[a+17164>>2]|0)+327|0]|0|0){case 3:case 6:case 9:case 15:case 16:case 19:case 27:case 30:{b=c[a+17172>>2]|0;e=c[a+17180>>2]|0;if((b|0)==(e|0)){break L5897}f=b-e|0;while(1){g=ys(f)|0;if((g|0)!=0){break}e=(I=c[185320]|0,c[185320]=I+0,I);if((e|0)==0){h=4733;break}gs[e&63]()}if((h|0)==4733){f=ff(4)|0;c[f>>2]=72440;dr(f|0,79056,316)}f=c[185312]|0;e=d[(c[f+17164>>2]|0)+327|0]|0;switch(e|0){case 3:case 6:case 9:case 15:case 16:case 19:case 27:case 30:{i=c[f+17180>>2]|0;break};default:{i=0}}switch(e|0){case 3:case 6:case 9:case 15:case 16:case 19:case 27:case 30:{j=(c[f+17172>>2]|0)-(c[f+17180>>2]|0)|0;break};default:{j=0}}yE(g|0,i|0,j)|0;kF();f=c[185312]|0;e=d[(c[f+17164>>2]|0)+327|0]|0;switch(e|0){case 3:case 6:case 9:case 15:case 16:case 19:case 27:case 30:{k=c[f+17180>>2]|0;break};default:{k=0}}switch(e|0){case 3:case 6:case 9:case 15:case 16:case 19:case 27:case 30:{l=(c[f+17172>>2]|0)-(c[f+17180>>2]|0)|0;break};default:{l=0}}yE(k|0,g|0,l)|0;yt(g);return};default:{}}}while(0);kF();return}function qT(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;g=i;i=i+344|0;h=g|0;j=g+8|0;k=c[185314]|0;if((k|0)==0){l=kG()|0;c[185314]=l;m=l}else{m=k}if((m|0)!=(f|0)){n=0;i=g;return n|0}yB(j+20|0,0,24);yB(j+96|0,0,32);f=j+256|0;c[f>>2]=0;m=j+260|0;c[m>>2]=0;k=c[185312]|0;c[j+20>>2]=k+512;c[j+24>>2]=16384;c[j+44>>2]=k;c[j+48>>2]=512;l=c[k+17180>>2]|0;o=k+17172|0;p=(c[o>>2]|0)-l|0;c[j+28>>2]=l;c[j+32>>2]=p;p=c[o>>2]|0;o=(c[k+17184>>2]|0)-p|0;c[j+36>>2]=p;c[j+40>>2]=o;c[j+96>>2]=k+19432;c[j+100>>2]=64;c[j+104>>2]=k+19496;c[j+108>>2]=64;c[j+112>>2]=k+19148;c[j+116>>2]=80;c[j+120>>2]=k+19228;c[j+124>>2]=40;c[f>>2]=k+19904;c[m>>2]=16;m=h|0;k=h+4|0;c[m>>2]=e+1;f=a[e]|0;c[k>>2]=1;if(f<<24>>24!=0){n=1;i=g;return n|0}f=((d[e+3|0]|d[e+2|0]<<8)<<8|d[e+4|0])+5|0;o=e+f|0;c[m>>2]=o;c[k>>2]=f;f=a[741180]|0;L5933:do{if(f<<24>>24==0){q=0}else{e=f&255;while(1){p=ys(e)|0;if((p|0)!=0){q=p;break L5933}p=(I=c[185320]|0,c[185320]=I+0,I);if((p|0)==0){break}gs[p&63]()}e=ff(4)|0;c[e>>2]=72440;dr(e|0,79056,316);return 0}}while(0);f=c[185292]|0;L5942:do{if((f|0)!=(c[185293]|0)){e=f;p=o;while(1){l=e|0;r=e+16|0;s=r;t=p;while(1){do{if((a[741180]|0)==1){c[m>>2]=t+1;u=q}else{v=(a[t]|0)==0;c[m>>2]=t+1;if(v){u=q;break}else{w=t;x=q}while(1){v=x+1|0;a[x]=a[w]|0;c[k>>2]=(c[k>>2]|0)+1;y=c[m>>2]|0;z=(a[y]|0)==0;c[m>>2]=y+1;if(z){u=v;break}else{w=y;x=v}}}}while(0);c[k>>2]=(c[k>>2]|0)+1;a[u]=0;if((db(q|0,c[l>>2]|0)|0)==0){A=e;B=r;break}v=c[185293]|0;y=v-s>>4;z=r;L5954:while(1){C=y;while(1){if((C|0)==0){break L5954}D=(C|0)/2|0;if((db(c[z+(D<<4)>>2]|0,q|0)|0)<0){break}else{C=D}}y=C-1-D|0;z=z+(D+1<<4)|0}if((z|0)!=(v|0)){if((db(q|0,c[z>>2]|0)|0)==0){A=z;B=e;break}}y=c[m>>2]|0;E=y+1|0;c[m>>2]=E;F=a[y]|0;G=c[k>>2]|0;c[k>>2]=G+1;H=y+2|0;c[m>>2]=H;J=a[E]|0;c[k>>2]=G+2;c[m>>2]=y+3;E=(J&255|(F&255)<<8)<<8|d[H];t=y+(E+3)|0;c[m>>2]=t;c[k>>2]=G+3+E;if((e|0)==(v|0)){break L5942}}f3[c[A+8>>2]&1023](h,j);if((B|0)==(c[185293]|0)){break L5942}e=B;p=c[m>>2]|0}}}while(0);m=j|0;c[m>>2]=c[m>>2]&2147483647;B=j+316|0;c[B>>2]=c[B>>2]&2147483647;if((q|0)!=0){yt(q)}q=c[185312]|0;kL(q|0,j);c[q+20112>>2]=c[m>>2];b[q+20116>>1]=b[j+4>>1]|0;b[q+20118>>1]=b[j+6>>1]|0;a[q+20136|0]=a[j+8|0]|0;a[q+20137|0]=a[j+9|0]|0;a[q+20138|0]=a[j+10|0]|0;a[q+20139|0]=a[j+11|0]|0;a[q+20140|0]=a[j+12|0]|0;m=d[j+13|0]|0;c[q+20128>>2]=m&128^128;B=m<<4;c[q+20124>>2]=B&1536;c[q+20132>>2]=B&256;a[q+20141|0]=a[j+14|0]|0;a[q+20142|0]=a[j+15|0]|0;a[q+20143|0]=a[j+16|0]&1;n=1;i=g;return n|0}function qU(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,dc=0,dd=0,de=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,ds=0,dt=0,du=0,dv=0,dx=0,dy=0,dz=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dK=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0;f=i;i=i+1584|0;g=f|0;h=f+16|0;j=f+32|0;k=f+40|0;l=f+48|0;m=f+56|0;n=f+64|0;o=f+80|0;p=f+96|0;q=f+432|0;r=f+768|0;s=f+784|0;u=f+792|0;v=f+800|0;w=f+816|0;x=f+832|0;y=f+848|0;z=f+864|0;A=f+880|0;B=f+896|0;D=f+1088|0;E=f+1104|0;F=f+1120|0;G=f+1136|0;H=f+1152|0;J=f+1168|0;K=f+1184|0;L=f+1200|0;M=f+1216|0;N=f+1232|0;O=f+1376|0;P=f+1392|0;Q=f+1408|0;R=f+1424|0;S=f+1440|0;T=f+1456|0;U=f+1472|0;V=f+1488|0;W=f+1504|0;X=f+1520|0;Y=f+1536|0;Z=f+1552|0;_=f+1568|0;$=f+1576|0;a[_]=0;gm[c[185322]&127](3,_)|0;if((a[_]&1)==0){_=c[t>>2]|0;be(16368,32,1,_|0)|0;aa=0;i=f;return aa|0}c[$>>2]=1;if(!(gm[c[185322]&127](10,$)|0)){$=c[t>>2]|0;be(13928,39,1,$|0)|0;aa=0;i=f;return aa|0}$=e+4|0;_=c[$>>2]|0;ab=c[e+8>>2]|0;ac=c[185312]|0;L9:do{if((ab|0)==0){ad=0}else{while(1){ae=ys(ab)|0;if((ae|0)!=0){ad=ae;break L9}ae=(I=c[185320]|0,c[185320]=I+0,I);if((ae|0)==0){break}gs[ae&63]()}ae=ff(4)|0;c[ae>>2]=72440;dr(ae|0,79056,316);return 0}}while(0);yE(ad|0,_|0,ab)|0;_=p|0;ae=ab>>>0<336?ab:336;yE(_|0,ad|0,ae)|0;ae=a[p+327|0]|0;_=ae&255;switch(_|0){case 0:{dJ(40848)|0;af=47;break};case 1:{dJ(49824)|0;af=47;break};case 2:{dJ(36776)|0;af=47;break};case 3:{dJ(29504)|0;af=47;break};case 5:{dJ(24864)|0;af=47;break};case 6:{dJ(21664)|0;af=47;break};case 8:{dJ(19288)|0;af=47;break};case 9:{dJ(16912)|0;af=47;break};case 11:{dJ(14568)|0;ag=1;break};case 12:{dJ(14568)|0;ag=1;break};case 13:{dJ(14568)|0;ag=1;break};case 15:{dJ(12432)|0;af=47;break};case 16:{dJ(54288)|0;af=47;break};case 17:{dJ(51600)|0;af=47;break};case 18:{dJ(49168)|0;af=47;break};case 19:{dJ(47528)|0;af=47;break};case 21:{dJ(46448)|0;ag=1;break};case 22:{dJ(46448)|0;ag=1;break};case 23:{dJ(46448)|0;ag=1;break};case 25:{dJ(45024)|0;af=47;break};case 26:{dJ(43536)|0;af=47;break};case 27:{dJ(42400)|0;af=47;break};case 28:{dJ(41336)|0;af=47;break};case 29:{dJ(40312)|0;af=47;break};case 30:{dJ(39288)|0;af=47;break};case 252:{dJ(38008)|0;ag=1;break};case 253:{dJ(36328)|0;ag=1;break};case 254:{dJ(34960)|0;ag=1;break};case 255:{dJ(33848)|0;ag=1;break};default:{dJ(33272)|0;ag=1}}do{if((af|0)==47){L50:do{switch(d[p+329|0]|0){case 0:{if((ae&255)<31){ah=(_-5|0)>>>0<2|0;break L50}else{dL(31e3,94,55216,30624);return 0}break};case 3:{ah=4;break};case 4:{ah=16;break};case 5:{ah=16;break};case 1:case 2:{ah=1;break};default:{ah=16}}}while(0);ai=(d[p+323|0]|0)>>>7;aj=(ai|0)!=0;dw(32488,(ak=i,i=i+8|0,c[ak>>2]=ai,ak)|0)|0;i=ak;dw(31800,(ak=i,i=i+8|0,c[ak>>2]=ah,ak)|0)|0;i=ak;ai=ab>>>14;al=ai-1|0;am=al>>>1|al;al=am>>>2|am;am=al>>>4|al;al=(am>>>8|am)+1|0;dw(31416,(ak=i,i=i+8|0,c[ak>>2]=ai,ak)|0)|0;i=ak;am=ac+17160|0;an=c[am>>2]|0;if((an|0)!=0){yt(an)}an=(al<<14)+16384|0;ao=an+(ah<<13)|0;ap=ao+(aj?32768:8192)|0;aj=ap+16384|0;aq=(aj|0)==0?1:aj;while(1){ar=ys(aq)|0;if((ar|0)!=0){af=72;break}aj=(I=c[185320]|0,c[185320]=I+0,I);if((aj|0)==0){break}gs[aj&63]()}if((af|0)==72){c[am>>2]=ar;aq=ar+16384|0;aj=ac+17164|0;c[aj>>2]=aq;c[ac+17180>>2]=ar+an;c[ac+17172>>2]=ar+ao;as=ar+ap|0;c[ac+17184>>2]=as;c[ac+17188>>2]=ar+(ap+8192);yB(as|0,-1|0,8192);c[ac+17200>>2]=5;c[ac+17032>>2]=aq;c[ac+17036>>2]=aq;c[ac+17040>>2]=aq;c[ac+17044>>2]=aq;as=ar+(ao-49152)|0;c[ac+17144>>2]=as;c[ac+17080>>2]=as;at=ar+(ao-57344)|0;c[ac+17152>>2]=at;c[ac+17088>>2]=at;c[ac+17168>>2]=aq;c[ac+17048>>2]=aq;c[ac+17052>>2]=aq;c[ac+17056>>2]=aq;c[ac+17060>>2]=aq;aq=ar+(ap-40960)|0;c[ac+17192>>2]=aq;at=ar+(ap-32768)|0;c[ac+17196>>2]=at;c[ac+17072>>2]=aq;c[ac+17076>>2]=aq;c[ac+17136>>2]=at;c[ac+17140>>2]=at;c[ac+17176>>2]=ar+(ao|4096);c[ac+17148>>2]=as;c[ac+17084>>2]=as;as=ab&-16384;yI(c[aj>>2]|0,ad|0,(ab>>>0<as>>>0?ab:as)|0);yB((c[aj>>2]|0)+as|0,-1|0,al-ai<<14|0);ag=0;break}as=ff(4)|0;c[as>>2]=72440;dr(as|0,79056,316);return 0}}while(0);if((ad|0)!=0){yt(ad)}if(ag){aa=0;i=f;return aa|0}ag=((c[ac+17184>>2]|0)-(c[ac+17172>>2]|0)|0)==32768|0;a[ac+19731|0]=ag;a[ac+19847|0]=ag;a[ac+19975|0]=ag;a[ac+19947|0]=ag;a[ac+20015|0]=ag;a[ac+19379|0]=ag;c[ac+19272>>2]=ac;a[ac+19282|0]=ag;ad=ac+19281|0;a[ad]=0;c[ac+19276>>2]=0;a[ac+19280|0]=-1;ab=ac+19228|0;C=0;a[ab]=C&255;C=C>>8;a[ab+1|0]=C&255;C=C>>8;a[ab+2|0]=C&255;C=C>>8;a[ab+3|0]=C&255;ab=ac+19232|0;a[ab]=0;ar=34;ah=ab;ab=0;while(1){p=ah+1|0;a[p]=ab;if((ar|0)<=0){break}ar=ar-1|0;ah=p;ab=a[ad]&1}ad=ac+17268|0;ab=0;ah=80;while(1){ar=ah-1|0;a[ac+19148+ab|0]=a[ac+(ab<<1&-4|ab&1)|0]|0;if((ar|0)==0){break}else{ab=ab+1|0;ah=ar}}yB(ac+19e3|0,-128|0,144);a[ac+19676|0]=ag;oO(ad);ad=c[185312]|0;yB(q+20|0,0,24);yB(q+96|0,0,32);ag=q+256|0;c[ag>>2]=0;ac=q+260|0;c[ac>>2]=0;c[q+20>>2]=ad+512;c[q+24>>2]=16384;c[q+44>>2]=ad;c[q+48>>2]=512;ah=c[ad+17180>>2]|0;ab=ad+17172|0;ar=(c[ab>>2]|0)-ah|0;c[q+28>>2]=ah;c[q+32>>2]=ar;ar=c[ab>>2]|0;ab=(c[ad+17184>>2]|0)-ar|0;c[q+36>>2]=ar;c[q+40>>2]=ab;c[q+96>>2]=ad+19432;c[q+100>>2]=64;c[q+104>>2]=ad+19496;c[q+108>>2]=64;c[q+112>>2]=ad+19148;c[q+116>>2]=80;c[q+120>>2]=ad+19228;c[q+124>>2]=40;c[ag>>2]=ad+19904;c[ac>>2]=16;ac=(a[ad+19379|0]&1)!=0;a[ad+20148|0]=0;kH(q,ac,0);kL(ad|0,q);c[ad+20112>>2]=c[q>>2];b[ad+20116>>1]=b[q+4>>1]|0;b[ad+20118>>1]=b[q+6>>1]|0;a[ad+20136|0]=a[q+8|0]|0;a[ad+20137|0]=a[q+9|0]|0;a[ad+20138|0]=a[q+10|0]|0;a[ad+20139|0]=a[q+11|0]|0;a[ad+20140|0]=a[q+12|0]|0;ac=d[q+13|0]|0;c[ad+20128>>2]=ac&128^128;ag=ac<<4;c[ad+20124>>2]=ag&1536;c[ad+20132>>2]=ag&256;a[ad+20141|0]=a[q+14|0]|0;a[ad+20142|0]=a[q+15|0]|0;a[ad+20143|0]=a[q+16|0]&1;c[ad+20144>>2]=1;q=ad+19684|0;ad=c[q>>2]|0;if((ad|0)!=0){f2[c[(c[ad>>2]|0)+4>>2]&1023](ad)}c[q>>2]=0;q=c[e>>2]|0;sr(741200,(q|0)==0?564064:q);yK(278200,(c[$>>2]|0)+308|0,16)|0;eS(c[t>>2]|0,53928,(ak=i,i=i+8|0,c[ak>>2]=278200,ak)|0)|0;i=ak;q$();$=v;q=w;e=x;ad=y;ag=z;ac=A;ab=B;ar=D;ah=E;p=F;_=G;ae=H;as=J;aj=K;at=L;aq=M;au=N;av=O;aw=P;ax=Q;ay=R;az=S;aA=T;aB=U;aC=V;aD=W;aE=X;aF=Y;aG=Z;c[s>>2]=0;c[u>>2]=0;gm[c[185322]&127](9,u)|0;aH=c[u>>2]|0;if((aH|0)==0){u=c[t>>2]|0;be(50960,77,1,u|0)|0;aa=1;i=f;return aa|0}u=yA(aH|0)|0;if((u|0)==-1){su();return 0}do{if(u>>>0<11){aI=u<<1&255;aJ=v;a[$]=aI;aK=aJ+1|0;aL=aI;aM=aJ}else{aJ=u+16&-16;aI=(aJ|0)==0?1:aJ;while(1){aN=ys(aI)|0;if((aN|0)!=0){af=100;break}aO=(I=c[185320]|0,c[185320]=I+0,I);if((aO|0)==0){break}gs[aO&63]()}if((af|0)==100){c[v+8>>2]=aN;aI=aJ|1;c[v>>2]=aI;c[v+4>>2]=u;aK=aN;aL=aI&255;aM=v;break}aI=ff(4)|0;c[aI>>2]=72440;dr(aI|0,79056,316);return 0}}while(0);yE(aK|0,aH|0,u)|0;a[aK+u|0]=0;yB(ad|0,0,12);u=aL&255;if((u&1|0)==0){aP=u>>>1}else{aP=c[v+4>>2]|0}if((aL&1)==0){aQ=aM+1|0}else{aQ=c[v+8>>2]|0}aL=aP+10|0;if((aL|0)==-1){su();return 0}do{if(aL>>>0<11){a[ad]=aP<<1&255;aR=y+1|0}else{u=aP+26&-16;aK=(u|0)==0?1:u;while(1){aS=ys(aK)|0;if((aS|0)!=0){af=122;break}aH=(I=c[185320]|0,c[185320]=I+0,I);if((aH|0)==0){break}gs[aH&63]()}if((af|0)==122){c[y+8>>2]=aS;c[y>>2]=u|1;c[y+4>>2]=aP;aR=aS;break}aK=ff(4)|0;c[aK>>2]=72440;dr(aK|0,79056,316);return 0}}while(0);yE(aR|0,aQ|0,aP)|0;a[aR+aP|0]=0;sw(y,48632,10);if((a[741200]&1)==0){c[ac>>2]=c[185300];c[ac+4>>2]=c[185301];c[ac+8>>2]=c[185302];aT=a[ac]|0}else{aP=c[185302]|0;aR=c[185301]|0;if((aR|0)==-1){su();return 0}do{if(aR>>>0<11){aQ=aR<<1&255;a[ac]=aQ;aU=A+1|0;aV=aQ}else{aQ=aR+16&-16;aS=(aQ|0)==0?1:aQ;while(1){aW=ys(aS)|0;if((aW|0)!=0){af=140;break}aL=(I=c[185320]|0,c[185320]=I+0,I);if((aL|0)==0){break}gs[aL&63]()}if((af|0)==140){c[A+8>>2]=aW;aS=aQ|1;c[A>>2]=aS;c[A+4>>2]=aR;aU=aW;aV=aS&255;break}aS=ff(4)|0;c[aS>>2]=72440;dr(aS|0,79056,316);return 0}}while(0);yE(aU|0,aP|0,aR)|0;a[aU+aR|0]=0;aT=aV}aV=A;aR=aT&255;aU=(aR&1|0)==0;if(aU){aX=aR>>>1}else{aX=c[A+4>>2]|0}aP=(aT&1)==0;if(aP){aY=aV+1|0}else{aY=c[A+8>>2]|0}aW=aY+aX|0;while(1){if((aW|0)==(aY|0)){aZ=aT;break}a_=aW-1|0;if((df(44960,d[a_]|0,2)|0)==0){aW=a_}else{af=151;break}}do{if((af|0)==151){aW=a_-aY|0;if((aW|0)==-1){aZ=aT;break}aX=aW+1|0;if(aU){a$=aR>>>1}else{a$=c[A+4>>2]|0}if((aX|0)==0){aZ=aT;break}if(aP){a0=aV+1|0}else{a0=c[A+8>>2]|0}aW=a$>>>0<aX>>>0?a$:aX;aX=a$-aW|0;if((a$|0)==(aW|0)){a1=aT}else{yI(a0|0,a0+aW|0,aX|0);a1=a[ac]|0}if((a1&1)==0){a[ac]=aX<<1&255}else{c[A+4>>2]=aX}a[a0+aX|0]=0;aZ=a[ac]|0}}while(0);a0=aZ&255;a1=(a0&1|0)==0;if(a1){a2=a0>>>1}else{a2=c[A+4>>2]|0}L184:do{if((a2|0)==0){a3=aZ}else{aT=(aZ&1)==0;if(aT){a4=aV+1|0}else{a4=c[A+8>>2]|0}a$=a4+a2|0;do{if((a$|0)==(a4|0)){a3=aZ;break L184}a$=a$-1|0;}while((a[a$]|0)!=46);aQ=a$-a4|0;if((aQ|0)==-1){a3=aZ;break}if(a1){a5=a0>>>1}else{a5=c[A+4>>2]|0}if(a5>>>0<aQ>>>0){sv();return 0}if(aT){a[ac]=aQ<<1&255;a6=aV+1|0}else{aP=c[A+8>>2]|0;c[A+4>>2]=aQ;a6=aP}a[a6+aQ|0]=0;a3=a[ac]|0}}while(0);if((a3&1)==0){c[ag>>2]=c[ac>>2];c[ag+4>>2]=c[ac+4>>2];c[ag+8>>2]=c[ac+8>>2]}else{a3=c[A+8>>2]|0;a6=c[A+4>>2]|0;if((a6|0)==-1){su();return 0}do{if(a6>>>0<11){a[ag]=a6<<1&255;a7=z+1|0}else{aV=a6+16&-16;a5=(aV|0)==0?1:aV;while(1){a8=ys(a5)|0;if((a8|0)!=0){af=202;break}a0=(I=c[185320]|0,c[185320]=I+0,I);if((a0|0)==0){break}gs[a0&63]()}if((af|0)==202){c[z+8>>2]=a8;c[z>>2]=aV|1;c[z+4>>2]=a6;a7=a8;break}a5=ff(4)|0;c[a5>>2]=72440;dr(a5|0,79056,316);return 0}}while(0);yE(a7|0,a3|0,a6)|0;a[a7+a6|0]=0}yB(e|0,0,12);a6=a[ad]|0;a7=a6&255;if((a7&1|0)==0){a9=a7>>>1}else{a9=c[y+4>>2]|0}a7=z;a3=a[ag]|0;a8=a3&255;if((a8&1|0)==0){ba=a8>>>1}else{ba=c[z+4>>2]|0}if((a6&1)==0){bb=y+1|0}else{bb=c[y+8>>2]|0}a6=ba+a9|0;if((a6|0)==-1){su();return 0}do{if(a6>>>0<11){a[e]=a9<<1&255;bc=x+1|0}else{a8=a6+16&-16;a5=(a8|0)==0?1:a8;while(1){bd=ys(a5)|0;if((bd|0)!=0){af=228;break}aT=(I=c[185320]|0,c[185320]=I+0,I);if((aT|0)==0){break}gs[aT&63]()}if((af|0)==228){c[x+8>>2]=bd;c[x>>2]=a8|1;c[x+4>>2]=a9;bc=bd;break}a5=ff(4)|0;c[a5>>2]=72440;dr(a5|0,79056,316);return 0}}while(0);yE(bc|0,bb|0,a9)|0;a[bc+a9|0]=0;if((a3&1)==0){bf=a7+1|0}else{bf=c[z+8>>2]|0}sw(x,bf,ba);yB(q|0,0,12);ba=a[e]|0;bf=ba&255;if((bf&1|0)==0){bg=bf>>>1}else{bg=c[x+4>>2]|0}if((ba&1)==0){bh=x+1|0}else{bh=c[x+8>>2]|0}ba=bg+4|0;if((ba|0)==-1){su();return 0}do{if(ba>>>0<11){a[q]=bg<<1&255;bi=w+1|0}else{bf=bg+20&-16;a7=(bf|0)==0?1:bf;while(1){bj=ys(a7)|0;if((bj|0)!=0){af=253;break}a3=(I=c[185320]|0,c[185320]=I+0,I);if((a3|0)==0){break}gs[a3&63]()}if((af|0)==253){c[w+8>>2]=bj;c[w>>2]=bf|1;c[w+4>>2]=bg;bi=bj;break}a7=ff(4)|0;c[a7>>2]=72440;dr(a7|0,79056,316);return 0}}while(0);yE(bi|0,bh|0,bg)|0;a[bi+bg|0]=0;sw(w,47304,4);do{if((a[e]&1)!=0){bg=c[x+8>>2]|0;if((bg|0)==0){break}yt(bg)}}while(0);do{if((a[ag]&1)!=0){x=c[z+8>>2]|0;if((x|0)==0){break}yt(x)}}while(0);do{if((a[ac]&1)!=0){z=c[A+8>>2]|0;if((z|0)==0){break}yt(z)}}while(0);do{if((a[ad]&1)!=0){A=c[y+8>>2]|0;if((A|0)==0){break}yt(A)}}while(0);y=w;if((a[q]&1)==0){bk=y+1|0}else{bk=c[w+8>>2]|0}ad=B+108|0;A=B|0;ac=B+108|0;z=B+8|0;ag=B;c[A>>2]=80684;c[ad>>2]=80704;c[B+4>>2]=0;c[B+132>>2]=z;c[B+124>>2]=0;c[B+128>>2]=0;c[B+112>>2]=4098;c[B+120>>2]=0;c[B+116>>2]=6;x=B+140|0;yB(x|0,0,40);e=B+136|0;bg=ac|0;bi=c[(wC()|0)>>2]|0;c[e>>2]=bi;bh=bi+4|0;I=c[bh>>2]|0,c[bh>>2]=I+1,I;c[B+180>>2]=0;c[B+184>>2]=-1;c[A>>2]=74516;c[bg>>2]=74536;bh=z|0;c[bh>>2]=74440;bi=B+12|0;bj=c[(wC()|0)>>2]|0;c[bi>>2]=bj;ba=bj+4|0;I=c[ba>>2]|0,c[ba>>2]=I+1,I;yB(B+16|0,0,24);c[bh>>2]=74752;c[B+40>>2]=0;c[B+44>>2]=0;c[B+48>>2]=0;bh=B+76|0;yB(B+60|0,0,47);ba=c[bi>>2]|0;bj=ba+4|0;I=c[bj>>2]|0,c[bj>>2]=I+1,I;if((c[185094]|0)!=-1){c[o>>2]=740376;c[o+4>>2]=210;c[o+8>>2]=0;st(740376,o)}o=(c[185095]|0)-1|0;a7=c[ba+8>>2]|0;if((c[ba+12>>2]|0)-a7>>2>>>0>o>>>0){bl=(c[a7+(o<<2)>>2]|0)!=0}else{bl=0}if(((I=c[bj>>2]|0,c[bj>>2]=I+ -1,I)|0)==0){f2[c[(c[ba>>2]|0)+8>>2]&1023](ba|0)}if(bl){bl=B+106|0;ba=c[bi>>2]|0;bi=ba+4|0;I=c[bi>>2]|0,c[bi>>2]=I+1,I;if((c[185094]|0)!=-1){c[n>>2]=740376;c[n+4>>2]=210;c[n+8>>2]=0;st(740376,n)}n=(c[185095]|0)-1|0;bj=c[ba+8>>2]|0;if((c[ba+12>>2]|0)-bj>>2>>>0<=n>>>0){bm=ff(4)|0;bn=bm;c[bn>>2]=72472;dr(bm|0,79072,408);return 0}o=c[bj+(n<<2)>>2]|0;if((o|0)==0){bm=ff(4)|0;bn=bm;c[bn>>2]=72472;dr(bm|0,79072,408);return 0}c[bh>>2]=o;if(((I=c[bi>>2]|0,c[bi>>2]=I+ -1,I)|0)==0){f2[c[(c[ba>>2]|0)+8>>2]&1023](ba|0)}ba=c[bh>>2]|0;a[bl]=(f5[c[(c[ba>>2]|0)+28>>2]&255](ba)|0)&1}ga[c[(c[z>>2]|0)+12>>2]&127](z,0,4096)|0;ba=B+72|0;do{if((c[ba>>2]|0)==0){bl=dA(bk|0,11144)|0;c[ba>>2]=bl;if((bl|0)==0){af=291;break}c[B+96>>2]=8;af=465}else{af=291}}while(0);do{if((af|0)==291){bk=c[(c[ag>>2]|0)-12>>2]|0;sM(ab+bk|0,c[ab+(bk+16)>>2]|4);if((c[ba>>2]|0)!=0){af=465;break}yB(p|0,0,12);bk=a[$]|0;bl=bk&255;bh=(bl&1|0)==0;if(bh){bo=bl>>>1}else{bo=c[v+4>>2]|0}bi=(bk&1)==0;if(bi){bp=aM+1|0}else{bp=c[v+8>>2]|0}bk=bo+10|0;if((bk|0)==-1){su();return 0}do{if(bk>>>0<11){a[p]=bo<<1&255;bq=F+1|0}else{o=bo+26&-16;bm=(o|0)==0?1:o;while(1){br=ys(bm)|0;if((br|0)!=0){af=313;break}bn=(I=c[185320]|0,c[185320]=I+0,I);if((bn|0)==0){break}gs[bn&63]()}if((af|0)==313){c[F+8>>2]=br;c[F>>2]=o|1;c[F+4>>2]=bo;bq=br;break}bm=ff(4)|0;c[bm>>2]=72440;dr(bm|0,79056,316);return 0}}while(0);yE(bq|0,bp|0,bo)|0;a[bq+bo|0]=0;sw(F,48632,10);bk=yA(278200)|0;if((bk|0)==-1){su();return 0}do{if(bk>>>0<11){bf=bk<<1&255;a[_]=bf;bs=G+1|0;bt=bf}else{bf=bk+16&-16;bm=(bf|0)==0?1:bf;while(1){bu=ys(bm)|0;if((bu|0)!=0){af=329;break}bn=(I=c[185320]|0,c[185320]=I+0,I);if((bn|0)==0){break}gs[bn&63]()}if((af|0)==329){c[G+8>>2]=bu;bm=bf|1;c[G>>2]=bm;c[G+4>>2]=bk;bs=bu;bt=bm&255;break}bm=ff(4)|0;c[bm>>2]=72440;dr(bm|0,79056,316);return 0}}while(0);yE(bs|0,278200,bk)|0;a[bs+bk|0]=0;yB(ah|0,0,12);bm=a[p]|0;o=bm&255;if((o&1|0)==0){bv=o>>>1}else{bv=c[F+4>>2]|0}o=G;bn=bt&255;if((bn&1|0)==0){bw=bn>>>1}else{bw=c[G+4>>2]|0}if((bm&1)==0){bx=F+1|0}else{bx=c[F+8>>2]|0}bm=bw+bv|0;if((bm|0)==-1){su();return 0}do{if(bm>>>0<11){a[ah]=bv<<1&255;by=E+1|0}else{bn=bm+16&-16;n=(bn|0)==0?1:bn;while(1){bz=ys(n)|0;if((bz|0)!=0){af=354;break}bj=(I=c[185320]|0,c[185320]=I+0,I);if((bj|0)==0){break}gs[bj&63]()}if((af|0)==354){c[E+8>>2]=bz;c[E>>2]=bn|1;c[E+4>>2]=bv;by=bz;break}n=ff(4)|0;c[n>>2]=72440;dr(n|0,79056,316);return 0}}while(0);yE(by|0,bx|0,bv)|0;a[by+bv|0]=0;if((bt&1)==0){bA=o+1|0}else{bA=c[G+8>>2]|0}sw(E,bA,bw);yB(ar|0,0,12);bm=a[ah]|0;bk=bm&255;if((bk&1|0)==0){bB=bk>>>1}else{bB=c[E+4>>2]|0}if((bm&1)==0){bC=E+1|0}else{bC=c[E+8>>2]|0}bm=bB+4|0;if((bm|0)==-1){su();return 0}do{if(bm>>>0<11){a[ar]=bB<<1&255;bD=D+1|0}else{bk=bB+20&-16;n=(bk|0)==0?1:bk;while(1){bE=ys(n)|0;if((bE|0)!=0){af=379;break}bf=(I=c[185320]|0,c[185320]=I+0,I);if((bf|0)==0){break}gs[bf&63]()}if((af|0)==379){c[D+8>>2]=bE;c[D>>2]=bk|1;c[D+4>>2]=bB;bD=bE;break}n=ff(4)|0;c[n>>2]=72440;dr(n|0,79056,316);return 0}}while(0);yE(bD|0,bC|0,bB)|0;a[bD+bB|0]=0;sw(D,47304,4);sq(w,D);do{if((a[ar]&1)!=0){bm=c[D+8>>2]|0;if((bm|0)==0){break}yt(bm)}}while(0);do{if((a[ah]&1)!=0){bm=c[E+8>>2]|0;if((bm|0)==0){break}yt(bm)}}while(0);do{if((a[_]&1)!=0){bm=c[G+8>>2]|0;if((bm|0)==0){break}yt(bm)}}while(0);do{if((a[p]&1)!=0){bm=c[F+8>>2]|0;if((bm|0)==0){break}yt(bm)}}while(0);if((a[q]&1)==0){bF=y+1|0}else{bF=c[w+8>>2]|0}do{if((c[ba>>2]|0)==0){bm=dA(bF|0,11144)|0;c[ba>>2]=bm;if((bm|0)==0){af=398;break}c[B+96>>2]=8;sM(ab+(c[(c[ag>>2]|0)-12>>2]|0)|0,0)}else{af=398}}while(0);if((af|0)==398){bm=c[(c[ag>>2]|0)-12>>2]|0;sM(ab+bm|0,c[ab+(bm+16)>>2]|4)}if((c[ba>>2]|0)==0){bG=81968;bH=109}else{af=465;break}L450:while(1){bm=bH;while(1){if((bm|0)==0){break L450}bI=(bm|0)/2|0;if((db(c[bG+(bI<<3)>>2]|0,278200)|0)<0){break}else{bm=bI}}bG=bG+(bI+1<<3)|0;bH=bm-1-bI|0}do{if(bG>>>0<82840>>>0){if((db(c[bG>>2]|0,278200)|0)!=0){af=407;break}if((c[bG+4>>2]|0)==0){af=407}}else{af=407}}while(0);L460:do{if((af|0)==407){yB(as|0,0,12);if(bh){bJ=bl>>>1}else{bJ=c[v+4>>2]|0}if(bi){bK=aM+1|0}else{bK=c[v+8>>2]|0}bk=bJ+10|0;if((bk|0)==-1){su();return 0}do{if(bk>>>0<11){o=J;a[as]=bJ<<1&255;bL=o+1|0;bM=o}else{o=bJ+26&-16;n=(o|0)==0?1:o;while(1){bN=ys(n)|0;if((bN|0)!=0){af=428;break}bn=(I=c[185320]|0,c[185320]=I+0,I);if((bn|0)==0){break}gs[bn&63]()}if((af|0)==428){c[J+8>>2]=bN;c[J>>2]=o|1;c[J+4>>2]=bJ;bL=bN;bM=J;break}n=ff(4)|0;c[n>>2]=72440;dr(n|0,79056,316);return 0}}while(0);yE(bL|0,bK|0,bJ)|0;a[bL+bJ|0]=0;sw(J,48632,10);yB(ae|0,0,12);bk=a[as]|0;bm=bk&255;if((bm&1|0)==0){bO=bm>>>1}else{bO=c[J+4>>2]|0}if((bk&1)==0){bP=bM+1|0}else{bP=c[J+8>>2]|0}if((bO|0)==-12){su();return 0}do{if(bO>>>0>4294967284){a[ae]=bO<<1&255;bQ=H+1|0}else{bk=bO+27&-16;bm=(bk|0)==0?1:bk;while(1){bR=ys(bm)|0;if((bR|0)!=0){af=450;break}n=(I=c[185320]|0,c[185320]=I+0,I);if((n|0)==0){break}gs[n&63]()}if((af|0)==450){c[H+8>>2]=bR;c[H>>2]=bk|1;c[H+4>>2]=bO;bQ=bR;break}bm=ff(4)|0;c[bm>>2]=72440;dr(bm|0,79056,316);return 0}}while(0);yE(bQ|0,bP|0,bO)|0;a[bQ+bO|0]=0;sw(H,46128,11);sq(w,H);do{if((a[ae]&1)!=0){bm=c[H+8>>2]|0;if((bm|0)==0){break}yt(bm)}}while(0);do{if((a[as]&1)!=0){bm=c[J+8>>2]|0;if((bm|0)==0){break}yt(bm)}}while(0);if((a[q]&1)==0){bS=y+1|0}else{bS=c[w+8>>2]|0}do{if((c[ba>>2]|0)==0){bm=dA(bS|0,11144)|0;c[ba>>2]=bm;if((bm|0)==0){break}c[B+96>>2]=8;sM(ab+(c[(c[ag>>2]|0)-12>>2]|0)|0,0);break L460}}while(0);bm=c[(c[ag>>2]|0)-12>>2]|0;sM(ab+bm|0,c[ab+(bm+16)>>2]|4)}}while(0);if((c[ba>>2]|0)!=0){af=465}}}while(0);do{if((af|0)==465){yB(aj|0,0,12);ba=K+1|0;bS=y+1|0;J=w+8|0;as=N+64|0;H=N|0;ae=N+64|0;bO=ae|0;bQ=N+8|0;bP=N+12|0;bR=N;bM=N+4|0;bJ=bP;bL=bP|0;bP=N+60|0;bK=N+44|0;bN=K+8|0;aM=N+136|0;bG=N+140|0;bI=N+44|0;bH=r;bF=L+1|0;F=M+1|0;p=N+88|0;G=N+80|0;_=N+84|0;E=N+68|0;ah=N+76|0;D=N+72|0;ar=N+96|0;bB=ar;bD=N+92|0;bC=N+16|0;bE=N+20|0;bw=bE;bA=O+1|0;bt=P+1|0;bv=Q+1|0;by=R+1|0;bx=S+1|0;bz=T+1|0;bs=U+1|0;bu=V+1|0;bo=W+1|0;bq=X+1|0;bp=Y+1|0;br=Z+1|0;bi=Z+8|0;bl=Z+4|0;bh=K+4|0;bm=Z|0;o=Y+8|0;n=Y+4|0;bn=Y|0;bf=X+8|0;bj=X+4|0;a7=X|0;a8=W+8|0;a3=W+4|0;a9=W|0;bc=V+8|0;bb=V+4|0;bd=V|0;a6=U+8|0;a5=U+4|0;aV=U|0;aT=T+8|0;a$=T+4|0;a0=T|0;a1=S+8|0;aZ=S+4|0;a4=S|0;a2=R+8|0;aQ=R+4|0;aP=R|0;aR=Q+8|0;aU=Q+4|0;aY=Q|0;a_=P+8|0;aX=P+4|0;aW=P|0;aS=O+8|0;u=O+4|0;aL=O|0;aK=bK;aJ=ae|0;ae=N+104|0;aH=N+100|0;aN=N+112|0;aI=N+124|0;ai=M+8|0;al=N+52|0;ao=M|0;ap=M+4|0;an=L+8|0;am=L+4|0;aO=L|0;bT=r|0;bU=r+4|0;bV=r+8|0;bW=K|0;bX=N+56|0;bY=g;bZ=g|0;b_=g+4|0;b$=g+8|0;b0=h;b1=j|0;b2=k|0;b3=h|0;b4=h+4|0;b5=h+8|0;b6=bK;b7=b6+1|0;b8=N+36|0;b9=N+32|0;ca=N+40|0;cb=N+48|0;cc=bK|0;cd=N+24|0;ce=N+28|0;cf=1;L527:while(1){cg=c[ab+((c[(c[ag>>2]|0)-12>>2]|0)+28)>>2]|0;ch=cg+4|0;I=c[ch>>2]|0,c[ch>>2]=I+1,I;if((c[185170]|0)!=-1){c[bT>>2]=740680;c[bU>>2]=210;c[bV>>2]=0;st(740680,bH)}ci=(c[185171]|0)-1|0;cj=c[cg+8>>2]|0;if((c[cg+12>>2]|0)-cj>>2>>>0<=ci>>>0){af=1082;break}ck=c[cj+(ci<<2)>>2]|0;if((ck|0)==0){af=1083;break}ci=gm[c[(c[ck>>2]|0)+28>>2]&127](ck,10)|0;if(((I=c[ch>>2]|0,c[ch>>2]=I+ -1,I)|0)==0){f2[c[(c[cg>>2]|0)+8>>2]&1023](cg)}cg=c[(c[ag>>2]|0)-12>>2]|0;ch=c[ab+(cg+16)>>2]|0;do{if((ch|0)==0){ck=c[ab+(cg+72)>>2]|0;if((ck|0)==0){cl=cg}else{tm(ck);cl=c[(c[ag>>2]|0)-12>>2]|0}if((c[ab+(cl+16)>>2]|0)!=0){break}if((a[aj]&1)==0){a[ba]=0;a[aj]=0;cm=0}else{a[c[bN>>2]|0]=0;c[bh>>2]=0;cm=0}while(1){ck=c[ab+((c[(c[ag>>2]|0)-12>>2]|0)+24)>>2]|0;cj=ck+12|0;cn=c[cj>>2]|0;if((cn|0)==(c[ck+16>>2]|0)){co=f5[c[(c[ck>>2]|0)+40>>2]&255](ck)|0;if((co|0)==-1){cp=2;cq=cm;break}else{cr=co&255}}else{c[cj>>2]=cn+1;cr=a[cn]|0}cn=cm+1|0;if(cr<<24>>24==ci<<24>>24){cp=0;cq=cn;break}cj=a[aj]|0;if((cj&1)==0){cs=(cj&255)>>>1;ct=10}else{cs=c[bh>>2]|0;ct=(c[bW>>2]&-2)-1|0}if((cs|0)==(ct|0)){sA(K,ct,1,ct,ct,0);cu=a[aj]|0}else{cu=cj}if((cu&1)==0){a[aj]=(cs<<1)+2&255;cv=ba;cw=cs+1|0}else{cj=c[bN>>2]|0;co=cs+1|0;c[bh>>2]=co;cv=cj;cw=co}a[cv+cs|0]=cr;a[cv+cw|0]=0;if((a[aj]&1)==0){cm=cn;continue}if((c[bh>>2]|0)==-2){cp=4;cq=cn;break}else{cm=cn}}bk=c[(c[ag>>2]|0)-12>>2]|0;sM(ab+bk|0,c[ab+(bk+16)>>2]|((cq|0)==0?cp|4:cp))}else{sM(ab+cg|0,ch|4)}}while(0);ch=a[aj]|0;cx=(ch&1)==0;if((c[ab+((c[(c[ag>>2]|0)-12>>2]|0)+16)>>2]&5|0)!=0){af=497;break}cg=c[bN>>2]|0;ci=cx?ba:cg;bk=a[ci]|0;L569:do{if(!((bk<<24>>24|0)==91|(bk<<24>>24|0)==59|(bk<<24>>24|0)==10)){cn=ch&255;co=c[bh>>2]|0;cj=(cn&1|0)==0?cn>>>1:co;L571:do{if((cj|0)!=0){cn=ci+cj|0;ck=ci;if((cj|0)<1){break}else{cy=ci;cz=bk}while(1){if(cz<<24>>24==61){break}cA=cy+1|0;if((cA|0)==(cn|0)){break L571}cy=cA;cz=a[cA]|0}if((cy|0)==(cn|0)){break}if((cy-ck|0)==-1){break}if(cx){c[at>>2]=c[aj>>2];c[at+4>>2]=c[aj+4>>2];c[at+8>>2]=c[aj+8>>2];cB=a[at]|0}else{if((co|0)==-1){af=513;break L527}if(co>>>0<11){cA=co<<1&255;a[at]=cA;cC=bF;cD=cA}else{cA=co+16&-16;cE=(cA|0)==0?1:cA;while(1){cF=ys(cE)|0;if((cF|0)!=0){break}cG=(I=c[185320]|0,c[185320]=I+0,I);if((cG|0)==0){af=524;break L527}gs[cG&63]()}c[an>>2]=cF;cE=cA|1;c[aO>>2]=cE;c[am>>2]=co;cC=cF;cD=cE&255}yE(cC|0,cg|0,co)|0;a[cC+co|0]=0;cB=cD}while(1){cH=ys(16)|0;if((cH|0)!=0){break}cE=(I=c[185320]|0,c[185320]=I+0,I);if((cE|0)==0){af=537;break L527}gs[cE&63]()}yE(cH|0,42120,14)|0;a[cH+14|0]=0;cA=cB&255;cE=(cA&1|0)==0?cA>>>1:c[am>>2]|0;cA=cE>>>0<14;ck=(cB&1)==0;cn=c[an>>2]|0;cG=(yJ((ck?bF:cn)|0,cH|0,(cA?cE:14)|0)|0)!=0|cA;yt(cH);if(!(ck|(cn|0)==0)){yt(cn)}if(!cG){break L569}cG=a[aj]|0;cn=cG&255;ck=(cn&1|0)==0?cn>>>1:c[bh>>2]|0;L603:do{if((ck|0)==0){cI=0}else{cn=(cG&1)==0?ba:c[bN>>2]|0;cA=cn+ck|0;cE=cn;if((ck|0)<1){cI=0;break}else{cJ=cn}while(1){if((a[cJ]|0)==61){break}cn=cJ+1|0;if((cn|0)==(cA|0)){cI=0;break L603}else{cJ=cn}}if((cJ|0)==(cA|0)){cI=0;break}cI=1-cE+cJ|0}}while(0);if(ck>>>0<cI>>>0){af=550;break L527}cn=((cG&1)==0?ba:c[bN>>2]|0)+cI|0;cK=ck-cI|0;if((cK|0)==-1){af=552;break L527}if(cK>>>0<11){a[aq]=cK<<1&255;cL=F}else{cM=cK+16&-16;cN=(cM|0)==0?1:cM;while(1){cO=ys(cN)|0;if((cO|0)!=0){break}cP=(I=c[185320]|0,c[185320]=I+0,I);if((cP|0)==0){af=563;break L527}gs[cP&63]()}c[ai>>2]=cO;c[ao>>2]=cM|1;c[ap>>2]=cK;cL=cO}yE(cL|0,cn|0,cK)|0;a[cL+cK|0]=0;c[bQ>>2]=74136;c[H>>2]=80644;c[as>>2]=80664;c[bM>>2]=0;c[p>>2]=bJ;c[G>>2]=0;c[_>>2]=0;c[E>>2]=4098;c[ah>>2]=0;c[D>>2]=6;yB(bB|0,0,40);cN=c[(wC()|0)>>2]|0;c[bD>>2]=cN;ck=cN+4|0;I=c[ck>>2]|0,c[ck>>2]=I+1,I;c[aM>>2]=0;c[bG>>2]=-1;c[H>>2]=74116;c[bO>>2]=74156;c[bQ>>2]=74136;c[bL>>2]=74440;ck=c[(wC()|0)>>2]|0;c[bC>>2]=ck;cN=ck+4|0;I=c[cN>>2]|0,c[cN>>2]=I+1,I;yB(bw|0,0,24);c[bL>>2]=74296;yB(bI|0,0,16);c[bP>>2]=24;sq(bK,M);c[bX>>2]=0;cN=c[bP>>2]|0;if((cN&8|0)!=0){ck=a[aK]|0;cG=(ck&1)==0;cP=ck&255;ck=(cG?b7:c[al>>2]|0)+((cP&1|0)==0?cP>>>1:c[cb>>2]|0)|0;c[bX>>2]=ck;cP=cG?b7:c[al>>2]|0;c[bE>>2]=cP;c[cd>>2]=cP;c[ce>>2]=ck}do{if((cN&16|0)!=0){ck=a[aK]|0;cP=ck&255;cG=(cP&1|0)==0?cP>>>1:c[cb>>2]|0;if((ck&1)==0){c[bX>>2]=b6+1+cG;cQ=10;cR=ck}else{c[bX>>2]=(c[al>>2]|0)+cG;ck=c[cc>>2]|0;cQ=(ck&-2)-1|0;cR=ck&255}ck=cR&255;cP=(ck&1|0)==0?ck>>>1:c[cb>>2]|0;do{if(cP>>>0<cQ>>>0){ss(bK,cQ-cP|0)}else{if((cR&1)==0){a[b6+1+cQ|0]=0;a[aK]=cQ<<1&255;break}else{a[(c[al>>2]|0)+cQ|0]=0;c[cb>>2]=cQ;break}}}while(0);cP=a[aK]|0;cE=(cP&1)==0?b7:c[al>>2]|0;cA=cP&255;cP=cE+((cA&1|0)==0?cA>>>1:c[cb>>2]|0)|0;c[b8>>2]=cE;c[b9>>2]=cE;c[ca>>2]=cP;if((c[bP>>2]&3|0)==0){break}c[b8>>2]=cE+cG}}while(0);cN=c[(c[bR>>2]|0)-12>>2]|0;cK=c[au+(cN+16)>>2]|0;do{if((cK|0)==0){cn=c[au+(cN+72)>>2]|0;if((cn|0)==0){cS=cN}else{tm(cn);cS=c[(c[bR>>2]|0)-12>>2]|0}L648:do{if((c[au+(cS+4)>>2]&4096|0)!=0){cn=c[au+(cS+28)>>2]|0;cM=cn+4|0;I=c[cM>>2]|0,c[cM>>2]=I+1,I;if((c[185170]|0)!=-1){c[bZ>>2]=740680;c[b_>>2]=210;c[b$>>2]=0;st(740680,bY)}cE=(c[185171]|0)-1|0;cP=c[cn+8>>2]|0;if((c[cn+12>>2]|0)-cP>>2>>>0<=cE>>>0){af=593;break L527}cA=c[cP+(cE<<2)>>2]|0;if((cA|0)==0){af=593;break L527}if(((I=c[cM>>2]|0,c[cM>>2]=I+ -1,I)|0)==0){f2[c[(c[cn>>2]|0)+8>>2]&1023](cn|0)}cn=c[au+((c[(c[bR>>2]|0)-12>>2]|0)+24)>>2]|0;cM=cA+8|0;L658:do{if((cn|0)!=0){cA=cn;while(1){cE=c[cA+12>>2]|0;if((cE|0)==(c[cA+16>>2]|0)){cT=f5[c[(c[cA>>2]|0)+36>>2]&255](cA)|0}else{cT=d[cE]|0}cU=(cT|0)==-1?0:cA;if((cU|0)==0){break L658}cV=cU+12|0;cE=c[cV>>2]|0;cW=cU+16|0;if((cE|0)==(c[cW>>2]|0)){cX=(f5[c[(c[cU>>2]|0)+36>>2]&255](cU)|0)&255}else{cX=a[cE]|0}if(cX<<24>>24<=-1){break}if((b[(c[cM>>2]|0)+(cX<<24>>24<<1)>>1]&8192)==0){break}cE=c[cV>>2]|0;if((cE|0)==(c[cW>>2]|0)){cP=c[(c[cU>>2]|0)+40>>2]|0;f5[cP&255](cU)|0;cA=cU;continue}else{c[cV>>2]=cE+1;cA=cU;continue}}if((c[cV>>2]|0)!=(c[cW>>2]|0)){break L648}if((f5[c[(c[cU>>2]|0)+36>>2]&255](cU)|0)!=-1){break L648}}}while(0);cM=c[(c[bR>>2]|0)-12>>2]|0;sM(au+cM|0,c[au+(cM+16)>>2]|6)}}while(0);if((c[au+((c[(c[bR>>2]|0)-12>>2]|0)+16)>>2]|0)!=0){break}c[l>>2]=0;cG=c[au+((c[(c[bR>>2]|0)-12>>2]|0)+28)>>2]|0;cM=cG+4|0;I=c[cM>>2]|0,c[cM>>2]=I+1,I;if((c[185086]|0)!=-1){c[b3>>2]=740344;c[b4>>2]=210;c[b5>>2]=0;st(740344,b0)}cn=(c[185087]|0)-1|0;cA=c[cG+8>>2]|0;if((c[cG+12>>2]|0)-cA>>2>>>0<=cn>>>0){af=624;break L527}cE=c[cA+(cn<<2)>>2]|0;if((cE|0)==0){af=624;break L527}cn=c[(c[bR>>2]|0)-12>>2]|0;cA=c[(c[cE>>2]|0)+28>>2]|0;c[b1>>2]=c[au+(cn+24)>>2];c[b2>>2]=0;gi[cA&127](m,cE,j,k,au+cn|0,l,s);if(((I=c[cM>>2]|0,c[cM>>2]=I+ -1,I)|0)==0){f2[c[(c[cG>>2]|0)+8>>2]&1023](cG|0)}cG=c[(c[bR>>2]|0)-12>>2]|0;sM(au+cG|0,c[au+(cG+16)>>2]|c[l>>2])}else{sM(au+cN|0,cK|4)}}while(0);do{if((c[au+((c[(c[bR>>2]|0)-12>>2]|0)+16)>>2]&5|0)==0){if((a[aj]&1)==0){c[av>>2]=c[aj>>2];c[av+4>>2]=c[aj+4>>2];c[av+8>>2]=c[aj+8>>2];cY=a[av]|0}else{cK=c[bN>>2]|0;cN=c[bh>>2]|0;if((cN|0)==-1){af=647;break L527}if(cN>>>0<11){cG=cN<<1&255;a[av]=cG;cZ=bA;c_=cG}else{cG=cN+16&-16;cM=(cG|0)==0?1:cG;while(1){c$=ys(cM)|0;if((c$|0)!=0){break}cn=(I=c[185320]|0,c[185320]=I+0,I);if((cn|0)==0){af=658;break L527}gs[cn&63]()}c[aS>>2]=c$;cM=cG|1;c[aL>>2]=cM;c[u>>2]=cN;cZ=c$;c_=cM&255}yE(cZ|0,cK|0,cN)|0;a[cZ+cN|0]=0;cY=c_}while(1){c0=ys(16)|0;if((c0|0)!=0){break}cM=(I=c[185320]|0,c[185320]=I+0,I);if((cM|0)==0){af=671;break L527}gs[cM&63]()}yE(c0|0,40016,12)|0;a[c0+12|0]=0;cN=cY&255;cK=(cN&1|0)==0?cN>>>1:c[u>>2]|0;cN=cK>>>0<12;cG=(cY&1)==0;cM=c[aS>>2]|0;cn=(yJ((cG?bA:cM)|0,c0|0,(cN?cK:12)|0)|0)!=0|cN;yt(c0);if(!(cG|(cM|0)==0)){yt(cM)}if(!cn){cn=c[185312]|0;c[cn+19384>>2]=c[s>>2];oO(cn+17268|0);break}if((a[aj]&1)==0){c[aw>>2]=c[aj>>2];c[aw+4>>2]=c[aj+4>>2];c[aw+8>>2]=c[aj+8>>2];c1=a[aw]|0}else{cn=c[bN>>2]|0;cM=c[bh>>2]|0;if((cM|0)==-1){af=681;break L527}if(cM>>>0<11){cG=cM<<1&255;a[aw]=cG;c2=bt;c3=cG}else{cG=cM+16&-16;cN=(cG|0)==0?1:cG;while(1){c4=ys(cN)|0;if((c4|0)!=0){break}cK=(I=c[185320]|0,c[185320]=I+0,I);if((cK|0)==0){af=692;break L527}gs[cK&63]()}c[a_>>2]=c4;cN=cG|1;c[aW>>2]=cN;c[aX>>2]=cM;c2=c4;c3=cN&255}yE(c2|0,cn|0,cM)|0;a[c2+cM|0]=0;c1=c3}while(1){c5=ys(16)|0;if((c5|0)!=0){break}cN=(I=c[185320]|0,c[185320]=I+0,I);if((cN|0)==0){af=705;break L527}gs[cN&63]()}yE(c5|0,39032,12)|0;a[c5+12|0]=0;cM=c1&255;cn=(cM&1|0)==0?cM>>>1:c[aX>>2]|0;cM=cn>>>0<12;cG=(c1&1)==0;cN=c[a_>>2]|0;cK=(yJ((cG?bt:cN)|0,c5|0,(cM?cn:12)|0)|0)!=0|cM;yt(c5);if(!(cG|(cN|0)==0)){yt(cN)}if(!cK){cK=c[185312]|0;c[cK+19388>>2]=c[s>>2];oO(cK+17268|0);break}if((a[aj]&1)==0){c[ax>>2]=c[aj>>2];c[ax+4>>2]=c[aj+4>>2];c[ax+8>>2]=c[aj+8>>2];c6=a[ax]|0}else{cK=c[bN>>2]|0;cN=c[bh>>2]|0;if((cN|0)==-1){af=715;break L527}if(cN>>>0<11){cG=cN<<1&255;a[ax]=cG;c7=bv;c8=cG}else{cG=cN+16&-16;cM=(cG|0)==0?1:cG;while(1){c9=ys(cM)|0;if((c9|0)!=0){break}cn=(I=c[185320]|0,c[185320]=I+0,I);if((cn|0)==0){af=726;break L527}gs[cn&63]()}c[aR>>2]=c9;cM=cG|1;c[aY>>2]=cM;c[aU>>2]=cN;c7=c9;c8=cM&255}yE(c7|0,cK|0,cN)|0;a[c7+cN|0]=0;c6=c8}while(1){da=ys(16)|0;if((da|0)!=0){break}cM=(I=c[185320]|0,c[185320]=I+0,I);if((cM|0)==0){af=739;break L527}gs[cM&63]()}yE(da|0,37704,12)|0;a[da+12|0]=0;cN=c6&255;cK=(cN&1|0)==0?cN>>>1:c[aU>>2]|0;cN=cK>>>0<12;cG=(c6&1)==0;cM=c[aR>>2]|0;cn=(yJ((cG?bv:cM)|0,da|0,(cN?cK:12)|0)|0)!=0|cN;yt(da);if(!(cG|(cM|0)==0)){yt(cM)}if(!cn){cn=c[185312]|0;c[cn+19392>>2]=c[s>>2];oO(cn+17268|0);break}if((a[aj]&1)==0){c[ay>>2]=c[aj>>2];c[ay+4>>2]=c[aj+4>>2];c[ay+8>>2]=c[aj+8>>2];dc=a[ay]|0}else{cn=c[bN>>2]|0;cM=c[bh>>2]|0;if((cM|0)==-1){af=749;break L527}if(cM>>>0<11){cG=cM<<1&255;a[ay]=cG;dd=by;de=cG}else{cG=cM+16&-16;cN=(cG|0)==0?1:cG;while(1){dg=ys(cN)|0;if((dg|0)!=0){break}cK=(I=c[185320]|0,c[185320]=I+0,I);if((cK|0)==0){af=760;break L527}gs[cK&63]()}c[a2>>2]=dg;cN=cG|1;c[aP>>2]=cN;c[aQ>>2]=cM;dd=dg;de=cN&255}yE(dd|0,cn|0,cM)|0;a[dd+cM|0]=0;dc=de}while(1){dh=ys(16)|0;if((dh|0)!=0){break}cN=(I=c[185320]|0,c[185320]=I+0,I);if((cN|0)==0){af=773;break L527}gs[cN&63]()}yE(dh|0,35880,12)|0;a[dh+12|0]=0;cM=dc&255;cn=(cM&1|0)==0?cM>>>1:c[aQ>>2]|0;cM=cn>>>0<12;cG=(dc&1)==0;cN=c[a2>>2]|0;cK=(yJ((cG?by:cN)|0,dh|0,(cM?cn:12)|0)|0)!=0|cM;yt(dh);if(!(cG|(cN|0)==0)){yt(cN)}if(!cK){cK=c[185312]|0;c[cK+19396>>2]=c[s>>2];oO(cK+17268|0);break}if((a[aj]&1)==0){c[az>>2]=c[aj>>2];c[az+4>>2]=c[aj+4>>2];c[az+8>>2]=c[aj+8>>2];di=a[az]|0}else{cK=c[bN>>2]|0;cN=c[bh>>2]|0;if((cN|0)==-1){af=783;break L527}if(cN>>>0<11){cG=cN<<1&255;a[az]=cG;dj=bx;dk=cG}else{cG=cN+16&-16;cM=(cG|0)==0?1:cG;while(1){dl=ys(cM)|0;if((dl|0)!=0){break}cn=(I=c[185320]|0,c[185320]=I+0,I);if((cn|0)==0){af=794;break L527}gs[cn&63]()}c[a1>>2]=dl;cM=cG|1;c[a4>>2]=cM;c[aZ>>2]=cN;dj=dl;dk=cM&255}yE(dj|0,cK|0,cN)|0;a[dj+cN|0]=0;di=dk}while(1){dm=ys(16)|0;if((dm|0)!=0){break}cM=(I=c[185320]|0,c[185320]=I+0,I);if((cM|0)==0){af=807;break L527}gs[cM&63]()}yE(dm|0,34608,12)|0;a[dm+12|0]=0;cN=di&255;cK=(cN&1|0)==0?cN>>>1:c[aZ>>2]|0;cN=cK>>>0<12;cG=(di&1)==0;cM=c[a1>>2]|0;cn=(yJ((cG?bx:cM)|0,dm|0,(cN?cK:12)|0)|0)!=0|cN;yt(dm);if(!(cG|(cM|0)==0)){yt(cM)}if(!cn){cn=c[185312]|0;c[cn+19400>>2]=c[s>>2];oO(cn+17268|0);break}if((a[aj]&1)==0){c[aA>>2]=c[aj>>2];c[aA+4>>2]=c[aj+4>>2];c[aA+8>>2]=c[aj+8>>2];dn=a[aA]|0}else{cn=c[bN>>2]|0;cM=c[bh>>2]|0;if((cM|0)==-1){af=817;break L527}if(cM>>>0<11){cG=cM<<1&255;a[aA]=cG;dp=bz;dq=cG}else{cG=cM+16&-16;cN=(cG|0)==0?1:cG;while(1){ds=ys(cN)|0;if((ds|0)!=0){break}cK=(I=c[185320]|0,c[185320]=I+0,I);if((cK|0)==0){af=828;break L527}gs[cK&63]()}c[aT>>2]=ds;cN=cG|1;c[a0>>2]=cN;c[a$>>2]=cM;dp=ds;dq=cN&255}yE(dp|0,cn|0,cM)|0;a[dp+cM|0]=0;dn=dq}while(1){dt=ys(16)|0;if((dt|0)!=0){break}cN=(I=c[185320]|0,c[185320]=I+0,I);if((cN|0)==0){af=841;break L527}gs[cN&63]()}yE(dt|0,33648,12)|0;a[dt+12|0]=0;cM=dn&255;cn=(cM&1|0)==0?cM>>>1:c[a$>>2]|0;cM=cn>>>0<12;cG=(dn&1)==0;cN=c[aT>>2]|0;cK=(yJ((cG?bz:cN)|0,dt|0,(cM?cn:12)|0)|0)!=0|cM;yt(dt);if(!(cG|(cN|0)==0)){yt(cN)}if(!cK){cK=c[185312]|0;c[cK+19404>>2]=c[s>>2];oO(cK+17268|0);break}if((a[aj]&1)==0){c[aB>>2]=c[aj>>2];c[aB+4>>2]=c[aj+4>>2];c[aB+8>>2]=c[aj+8>>2];du=a[aB]|0}else{cK=c[bN>>2]|0;cN=c[bh>>2]|0;if((cN|0)==-1){af=851;break L527}if(cN>>>0<11){cG=cN<<1&255;a[aB]=cG;dv=bs;dx=cG}else{cG=cN+16&-16;cM=(cG|0)==0?1:cG;while(1){dy=ys(cM)|0;if((dy|0)!=0){break}cn=(I=c[185320]|0,c[185320]=I+0,I);if((cn|0)==0){af=862;break L527}gs[cn&63]()}c[a6>>2]=dy;cM=cG|1;c[aV>>2]=cM;c[a5>>2]=cN;dv=dy;dx=cM&255}yE(dv|0,cK|0,cN)|0;a[dv+cN|0]=0;du=dx}while(1){dz=ys(16)|0;if((dz|0)!=0){break}cM=(I=c[185320]|0,c[185320]=I+0,I);if((cM|0)==0){af=875;break L527}gs[cM&63]()}yE(dz|0,33008,12)|0;a[dz+12|0]=0;cN=du&255;cK=(cN&1|0)==0?cN>>>1:c[a5>>2]|0;cN=cK>>>0<12;cG=(du&1)==0;cM=c[a6>>2]|0;cn=(yJ((cG?bs:cM)|0,dz|0,(cN?cK:12)|0)|0)!=0|cN;yt(dz);if(!(cG|(cM|0)==0)){yt(cM)}if(!cn){cn=c[185312]|0;c[cn+19408>>2]=c[s>>2];oO(cn+17268|0);break}if((a[aj]&1)==0){c[aC>>2]=c[aj>>2];c[aC+4>>2]=c[aj+4>>2];c[aC+8>>2]=c[aj+8>>2];dB=a[aC]|0}else{cn=c[bN>>2]|0;cM=c[bh>>2]|0;if((cM|0)==-1){af=885;break L527}if(cM>>>0<11){cG=cM<<1&255;a[aC]=cG;dC=bu;dD=cG}else{cG=cM+16&-16;cN=(cG|0)==0?1:cG;while(1){dE=ys(cN)|0;if((dE|0)!=0){break}cK=(I=c[185320]|0,c[185320]=I+0,I);if((cK|0)==0){af=896;break L527}gs[cK&63]()}c[bc>>2]=dE;cN=cG|1;c[bd>>2]=cN;c[bb>>2]=cM;dC=dE;dD=cN&255}yE(dC|0,cn|0,cM)|0;a[dC+cM|0]=0;dB=dD}while(1){dF=ys(16)|0;if((dF|0)!=0){break}cN=(I=c[185320]|0,c[185320]=I+0,I);if((cN|0)==0){af=909;break L527}gs[cN&63]()}yE(dF|0,32080,12)|0;a[dF+12|0]=0;cM=dB&255;cn=(cM&1|0)==0?cM>>>1:c[bb>>2]|0;cM=cn>>>0<12;cG=(dB&1)==0;cN=c[bc>>2]|0;cK=(yJ((cG?bu:cN)|0,dF|0,(cM?cn:12)|0)|0)!=0|cM;yt(dF);if(!(cG|(cN|0)==0)){yt(cN)}if(!cK){cK=c[185312]|0;c[cK+19412>>2]=c[s>>2];oO(cK+17268|0);break}if((a[aj]&1)==0){c[aD>>2]=c[aj>>2];c[aD+4>>2]=c[aj+4>>2];c[aD+8>>2]=c[aj+8>>2];dG=a[aD]|0}else{cK=c[bN>>2]|0;cN=c[bh>>2]|0;if((cN|0)==-1){af=919;break L527}if(cN>>>0<11){cG=cN<<1&255;a[aD]=cG;dH=bo;dI=cG}else{cG=cN+16&-16;cM=(cG|0)==0?1:cG;while(1){dK=ys(cM)|0;if((dK|0)!=0){break}cn=(I=c[185320]|0,c[185320]=I+0,I);if((cn|0)==0){af=930;break L527}gs[cn&63]()}c[a8>>2]=dK;cM=cG|1;c[a9>>2]=cM;c[a3>>2]=cN;dH=dK;dI=cM&255}yE(dH|0,cK|0,cN)|0;a[dH+cN|0]=0;dG=dI}while(1){dM=ys(16)|0;if((dM|0)!=0){break}cM=(I=c[185320]|0,c[185320]=I+0,I);if((cM|0)==0){af=943;break L527}gs[cM&63]()}yE(dM|0,31672,12)|0;a[dM+12|0]=0;cN=dG&255;cK=(cN&1|0)==0?cN>>>1:c[a3>>2]|0;cN=cK>>>0<12;cG=(dG&1)==0;cM=c[a8>>2]|0;cn=(yJ((cG?bo:cM)|0,dM|0,(cN?cK:12)|0)|0)!=0|cN;yt(dM);if(!(cG|(cM|0)==0)){yt(cM)}if(!cn){cn=c[185312]|0;c[cn+19416>>2]=c[s>>2];oO(cn+17268|0);break}if((a[aj]&1)==0){c[aE>>2]=c[aj>>2];c[aE+4>>2]=c[aj+4>>2];c[aE+8>>2]=c[aj+8>>2];dN=a[aE]|0}else{cn=c[bN>>2]|0;cM=c[bh>>2]|0;if((cM|0)==-1){af=953;break L527}if(cM>>>0<11){cG=cM<<1&255;a[aE]=cG;dO=bq;dP=cG}else{cG=cM+16&-16;cN=(cG|0)==0?1:cG;while(1){dQ=ys(cN)|0;if((dQ|0)!=0){break}cK=(I=c[185320]|0,c[185320]=I+0,I);if((cK|0)==0){af=964;break L527}gs[cK&63]()}c[bf>>2]=dQ;cN=cG|1;c[a7>>2]=cN;c[bj>>2]=cM;dO=dQ;dP=cN&255}yE(dO|0,cn|0,cM)|0;a[dO+cM|0]=0;dN=dP}while(1){dR=ys(16)|0;if((dR|0)!=0){break}cN=(I=c[185320]|0,c[185320]=I+0,I);if((cN|0)==0){af=977;break L527}gs[cN&63]()}yE(dR|0,31288,12)|0;a[dR+12|0]=0;cM=dN&255;cn=(cM&1|0)==0?cM>>>1:c[bj>>2]|0;cM=cn>>>0<12;cG=(dN&1)==0;cN=c[bf>>2]|0;cK=(yJ((cG?bq:cN)|0,dR|0,(cM?cn:12)|0)|0)!=0|cM;yt(dR);if(!(cG|(cN|0)==0)){yt(cN)}if(!cK){cK=c[185312]|0;c[cK+19420>>2]=c[s>>2];oO(cK+17268|0);break}if((a[aj]&1)==0){c[aF>>2]=c[aj>>2];c[aF+4>>2]=c[aj+4>>2];c[aF+8>>2]=c[aj+8>>2];dS=a[aF]|0}else{cK=c[bN>>2]|0;cN=c[bh>>2]|0;if((cN|0)==-1){af=987;break L527}if(cN>>>0<11){cG=cN<<1&255;a[aF]=cG;dT=bp;dU=cG}else{cG=cN+16&-16;cM=(cG|0)==0?1:cG;while(1){dV=ys(cM)|0;if((dV|0)!=0){break}cn=(I=c[185320]|0,c[185320]=I+0,I);if((cn|0)==0){af=998;break L527}gs[cn&63]()}c[o>>2]=dV;cM=cG|1;c[bn>>2]=cM;c[n>>2]=cN;dT=dV;dU=cM&255}yE(dT|0,cK|0,cN)|0;a[dT+cN|0]=0;dS=dU}while(1){dW=ys(16)|0;if((dW|0)!=0){break}cM=(I=c[185320]|0,c[185320]=I+0,I);if((cM|0)==0){af=1011;break L527}gs[cM&63]()}yE(dW|0,30928,12)|0;a[dW+12|0]=0;cN=dS&255;cK=(cN&1|0)==0?cN>>>1:c[n>>2]|0;cN=cK>>>0<12;cG=(dS&1)==0;cM=c[o>>2]|0;cn=(yJ((cG?bp:cM)|0,dW|0,(cN?cK:12)|0)|0)!=0|cN;yt(dW);if(!(cG|(cM|0)==0)){yt(cM)}if(!cn){cn=c[185312]|0;c[cn+19424>>2]=c[s>>2];oO(cn+17268|0);break}if((a[aj]&1)==0){c[aG>>2]=c[aj>>2];c[aG+4>>2]=c[aj+4>>2];c[aG+8>>2]=c[aj+8>>2];dX=a[aG]|0}else{cn=c[bN>>2]|0;cM=c[bh>>2]|0;if((cM|0)==-1){af=1021;break L527}if(cM>>>0<11){cG=cM<<1&255;a[aG]=cG;dY=br;dZ=cG}else{cG=cM+16&-16;cN=(cG|0)==0?1:cG;while(1){d_=ys(cN)|0;if((d_|0)!=0){break}cK=(I=c[185320]|0,c[185320]=I+0,I);if((cK|0)==0){af=1032;break L527}gs[cK&63]()}c[bi>>2]=d_;cN=cG|1;c[bm>>2]=cN;c[bl>>2]=cM;dY=d_;dZ=cN&255}yE(dY|0,cn|0,cM)|0;a[dY+cM|0]=0;dX=dZ}while(1){d$=ys(16)|0;if((d$|0)!=0){break}cN=(I=c[185320]|0,c[185320]=I+0,I);if((cN|0)==0){af=1045;break L527}gs[cN&63]()}yE(d$|0,30496,12)|0;a[d$+12|0]=0;cM=dX&255;cn=(cM&1|0)==0?cM>>>1:c[bl>>2]|0;cM=cn>>>0<12;cG=(dX&1)==0;cN=c[bi>>2]|0;cK=(yJ((cG?br:cN)|0,d$|0,(cM?cn:12)|0)|0)!=0|cM;yt(d$);if(!(cG|(cN|0)==0)){yt(cN)}if(cK){cK=c[t>>2]|0;cN=(a[q]&1)==0?bS:c[J>>2]|0;eS(cK|0,43248,(ak=i,i=i+16|0,c[ak>>2]=cN,c[ak+8>>2]=cf,ak)|0)|0;i=ak;break}else{cN=c[185312]|0;c[cN+19428>>2]=c[s>>2];oO(cN+17268|0);break}}else{eS(c[t>>2]|0,41024,(ak=i,i=i+16|0,c[ak>>2]=(a[q]&1)==0?bS:c[J>>2]|0,c[ak+8>>2]=cf,ak)|0)|0;i=ak}}while(0);c[H>>2]=74116;c[as>>2]=74156;c[bQ>>2]=74136;c[bL>>2]=74296;do{if((a[aK]&1)!=0){cN=c[al>>2]|0;if((cN|0)==0){break}yt(cN)}}while(0);c[bL>>2]=74440;cN=c[bC>>2]|0;cK=cN+4|0;if(((I=c[cK>>2]|0,c[cK>>2]=I+ -1,I)|0)==0){f2[c[(c[cN>>2]|0)+8>>2]&1023](cN|0)}c[bO>>2]=73224;cN=c[ae>>2]|0;if((cN|0)!=0){cK=cN;do{cK=cK-1|0;gr[c[(c[ar>>2]|0)+(cK<<2)>>2]&127](0,aJ,c[(c[aH>>2]|0)+(cK<<2)>>2]|0);}while((cK|0)!=0)}cK=c[bD>>2]|0;cN=cK+4|0;if(((I=c[cN>>2]|0,c[cN>>2]=I+ -1,I)|0)==0){f2[c[(c[cK>>2]|0)+8>>2]&1023](cK)}yt(c[ar>>2]|0);yt(c[aH>>2]|0);yt(c[aN>>2]|0);yt(c[aI>>2]|0);if((a[aq]&1)==0){break L569}cK=c[ai>>2]|0;if((cK|0)==0){break L569}yt(cK);break L569}}while(0);co=c[t>>2]|0;cj=(a[q]&1)==0?bS:c[J>>2]|0;eS(co|0,43248,(ak=i,i=i+16|0,c[ak>>2]=cj,c[ak+8>>2]=cf,ak)|0)|0;i=ak}}while(0);cf=cf+1|0}if((af|0)==497){if(cx){break}cf=c[bN>>2]|0;if((cf|0)==0){break}yt(cf);break}else if((af|0)==513){su();return 0}else if((af|0)==524){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==537){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==550){sv();return 0}else if((af|0)==552){su();return 0}else if((af|0)==563){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==593){cf=ff(4)|0;c[cf>>2]=72472;dr(cf|0,79072,408);return 0}else if((af|0)==624){cf=ff(4)|0;c[cf>>2]=72472;dr(cf|0,79072,408);return 0}else if((af|0)==647){su();return 0}else if((af|0)==658){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==671){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==681){su();return 0}else if((af|0)==692){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==705){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==715){su();return 0}else if((af|0)==726){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==739){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==749){su();return 0}else if((af|0)==760){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==773){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==783){su();return 0}else if((af|0)==794){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==807){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==817){su();return 0}else if((af|0)==828){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==841){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==851){su();return 0}else if((af|0)==862){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==875){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==885){su();return 0}else if((af|0)==896){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==909){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==919){su();return 0}else if((af|0)==930){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==943){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==953){su();return 0}else if((af|0)==964){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==977){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==987){su();return 0}else if((af|0)==998){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==1011){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==1021){su();return 0}else if((af|0)==1032){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==1045){cf=ff(4)|0;c[cf>>2]=72440;dr(cf|0,79056,316);return 0}else if((af|0)==1082){d0=ff(4)|0;d1=d0;c[d1>>2]=72472;dr(d0|0,79072,408);return 0}else if((af|0)==1083){d0=ff(4)|0;d1=d0;c[d1>>2]=72472;dr(d0|0,79072,408);return 0}}}while(0);c[A>>2]=74516;c[ad>>2]=74536;kY(z);z=ac|0;c[bg>>2]=73224;bg=c[B+148>>2]|0;ac=B+144|0;if((bg|0)!=0){ad=bg;do{ad=ad-1|0;gr[c[(c[x>>2]|0)+(ad<<2)>>2]&127](0,z,c[(c[ac>>2]|0)+(ad<<2)>>2]|0);}while((ad|0)!=0)}ad=c[e>>2]|0;e=ad+4|0;if(((I=c[e>>2]|0,c[e>>2]=I+ -1,I)|0)==0){f2[c[(c[ad>>2]|0)+8>>2]&1023](ad)}yt(c[x>>2]|0);yt(c[ac>>2]|0);yt(c[B+156>>2]|0);yt(c[B+168>>2]|0);do{if((a[q]&1)!=0){B=c[w+8>>2]|0;if((B|0)==0){break}yt(B)}}while(0);if((a[$]&1)==0){aa=1;i=f;return aa|0}$=c[v+8>>2]|0;if(($|0)==0){aa=1;i=f;return aa|0}yt($);aa=1;i=f;return aa|0}function qV(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function qW(){return}function qX(){return 0}function qY(){return 1}function qZ(a){a=a|0;var b=0,e=0;if((a|0)==0){b=c[185312]|0;switch(d[(c[b+17164>>2]|0)+327|0]|0|0){case 3:case 6:case 9:case 15:case 16:case 19:case 27:case 30:{break};default:{e=0;return e|0}}e=c[b+17180>>2]|0;return e|0}else if((a|0)==1){a=c[185312]|0;if(((d[(c[a+17164>>2]|0)+327|0]|0)-15|0)>>>0>=2){e=0;return e|0}e=a+17224|0;return e|0}else{e=0;return e|0}return 0}function q_(a){a=a|0;var b=0,e=0;if((a|0)==0){b=c[185312]|0;switch(d[(c[b+17164>>2]|0)+327|0]|0|0){case 3:case 6:case 9:case 15:case 16:case 19:case 27:case 30:{break};default:{e=0;return e|0}}e=(c[b+17172>>2]|0)-(c[b+17180>>2]|0)|0;return e|0}else if((a|0)==1){e=((d[(c[(c[185312]|0)+17164>>2]|0)+327|0]|0)-15|0)>>>0<2?8:0;return e|0}else{e=0;return e|0}return 0}function q$(){var b=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+8|0;d=b|0;c[d>>2]=0;c[d+4>>2]=0;c[d>>2]=24400;if(!(gm[c[185322]&127](15,d)|0)){i=b;return}f=c[d+4>>2]|0;if((f|0)==0){i=b;return}d=c[185312]|0;if((a[d+19379|0]&1)!=0){i=b;return}L1153:do{if((db(f|0,44832)|0)==0){a[84336]=0;g=82840;h=12;j=1137}else{if((db(f|0,44544)|0)==0){a[84336]=1;k=81968;l=109}else{if(a[84336]|0){k=81968;l=109}else{g=82840;h=12;j=1137;break}}L1159:while(1){m=l;while(1){if((m|0)==0){break L1159}n=(m|0)/2|0;if((db(c[k+(n<<3)>>2]|0,278200)|0)<0){break}else{m=n}}k=k+(n+1<<3)|0;l=m-1-n|0}do{if(k>>>0<82840>>>0){if((db(c[k>>2]|0,278200)|0)!=0){o=82840;p=12;break}q=c[k+4>>2]|0;if((q|0)==0){o=82840;p=12}else{r=q;break L1153}}else{o=82840;p=12}}while(0);L1169:while(1){q=p;while(1){if((q|0)==0){break L1169}s=(q|0)/2|0;if((db(c[o+(s<<3)>>2]|0,44408)|0)<0){break}else{q=s}}o=o+(s+1<<3)|0;p=q-1-s|0}if(o>>>0>=82936>>>0){r=0;break}if((db(c[o>>2]|0,44408)|0)!=0){r=0;break}r=c[o+4>>2]|0}}while(0);do{if((j|0)==1137){L1179:while(1){j=0;o=h;while(1){if((o|0)==0){break L1179}t=(o|0)/2|0;if((db(c[g+(t<<3)>>2]|0,44288)|0)<0){break}else{o=t}}g=g+(t+1<<3)|0;h=o-1-t|0;j=1137}if(g>>>0>=82936>>>0){r=0;break}if((db(c[g>>2]|0,44288)|0)!=0){r=0;break}r=c[g+4>>2]|0}}while(0);g=0;j=d;while(1){d=g<<2;t=e[r+(d<<1)>>1]|0;h=t>>>10&31;q=t>>>5&31;s=t&31;t=q<<1;c[j+19384+(d<<2)>>2]=(t+(s*11|0)+(h*3|0)|0)>>>1|(q*3|0)+s<<9|(t+s+(h*13|0)|0)>>>1<<16;oO(j+17268|0);h=c[185312]|0;s=d|1;t=e[r+(s<<1)>>1]|0;q=t>>>10&31;p=t>>>5&31;k=t&31;t=p<<1;c[h+19384+(s<<2)>>2]=(t+(k*11|0)+(q*3|0)|0)>>>1|(p*3|0)+k<<9|(t+k+(q*13|0)|0)>>>1<<16;oO(h+17268|0);h=c[185312]|0;q=d|2;k=e[r+(q<<1)>>1]|0;t=k>>>10&31;p=k>>>5&31;s=k&31;k=p<<1;c[h+19384+(q<<2)>>2]=(k+(s*11|0)+(t*3|0)|0)>>>1|(p*3|0)+s<<9|(k+s+(t*13|0)|0)>>>1<<16;oO(h+17268|0);h=c[185312]|0;t=d|3;d=e[r+(t<<1)>>1]|0;s=d>>>10&31;k=d>>>5&31;p=d&31;d=k<<1;c[h+19384+(t<<2)>>2]=(d+(p*11|0)+(s*3|0)|0)>>>1|(k*3|0)+p<<9|(d+p+(s*13|0)|0)>>>1<<16;oO(h+17268|0);h=g+1|0;if(h>>>0>=3){break}g=h;j=c[185312]|0}i=b;return}function q0(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+16|0;e=d|0;f=d+8|0;gs[c[185318]&63]();g=yW(c[184964]|0,c[184965]|0,35112,0)|0;h=K;j=c[184967]|0;if(j>>>0<h>>>0|j>>>0==h>>>0&(c[184966]|0)>>>0<g>>>0){gu[c[185298]&127](0,160,144,512);g=yL(c[184966]|0,c[184967]|0,1,0)|0;c[184966]=g;c[184967]=K;i=d;return}c[e>>2]=2064;g=(kA(e)|0)==-1;h=c[e>>2]|0;if(g){g=h;while(1){do{if((g|0)!=0){j=c[185296]|0;k=(gq[c[(c[j>>2]|0)+12>>2]&31](j,567632,723344,g)|0)<<1;if((k|0)==0){break}else{l=0}do{f3[c[185310]&1023](b[567632+(l<<1)>>1]|0,b[567632+((l|1)<<1)>>1]|0);l=l+2|0;}while(l>>>0<k>>>0)}}while(0);k=yL(c[184964]|0,c[184965]|0,g,0)|0;c[184964]=k;c[184965]=K;c[e>>2]=2064;k=(kA(e)|0)==-1;j=c[e>>2]|0;if(k){g=j}else{m=j;break}}}else{m=h}h=yL(c[184964]|0,c[184965]|0,m,0)|0;c[184964]=h;c[184965]=K;do{if((m|0)!=0){h=c[185296]|0;g=(gq[c[(c[h>>2]|0)+12>>2]&31](h,567632,723344,m)|0)<<1;if((g|0)==0){break}else{n=0}do{f3[c[185310]&1023](b[567632+(n<<1)>>1]|0,b[567632+((n|1)<<1)>>1]|0);n=n+2|0;}while(n>>>0<g>>>0)}}while(0);gu[c[185298]&127](575888,160,144,1024);n=yL(c[184966]|0,c[184967]|0,1,0)|0;c[184966]=n;c[184967]=K;a[f]=0;if(!(gm[c[185322]&127](17,f)|0)){i=d;return}if((a[f]&1)==0){i=d;return}q$();i=d;return}function q1(b){b=b|0;var d=0,e=0,f=0;c[b>>2]=74116;c[b+64>>2]=74156;c[b+8>>2]=74136;d=b+12|0;c[d>>2]=74296;do{if((a[b+44|0]&1)!=0){e=c[b+52>>2]|0;if((e|0)==0){break}yt(e)}}while(0);c[d>>2]=74440;d=c[b+16>>2]|0;e=d+4|0;if(((I=c[e>>2]|0,c[e>>2]=I+ -1,I)|0)!=0){f=b+64|0;sN(f);return}f2[c[(c[d>>2]|0)+8>>2]&1023](d|0);f=b+64|0;sN(f);return}function q2(b){b=b|0;var d=0,e=0,f=0,g=0;d=b-144+136|0;c[d>>2]=74116;b=d+64|0;c[b>>2]=74156;c[d+8>>2]=74136;e=d+12|0;c[e>>2]=74296;do{if((a[d+44|0]&1)!=0){f=c[d+52>>2]|0;if((f|0)==0){break}yt(f)}}while(0);c[e>>2]=74440;e=c[d+16>>2]|0;d=e+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){g=b;sN(g);return}f2[c[(c[e>>2]|0)+8>>2]&1023](e);g=b;sN(g);return}function q3(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b;e=c[(c[b>>2]|0)-12>>2]|0;c[d+e>>2]=74116;b=d+(e+64)|0;c[b>>2]=74156;c[d+(e+8)>>2]=74136;f=d+(e+12)|0;c[f>>2]=74296;do{if((a[d+(e+44)|0]&1)!=0){g=c[d+(e+52)>>2]|0;if((g|0)==0){break}yt(g)}}while(0);c[f>>2]=74440;f=c[d+(e+16)>>2]|0;e=f+4|0;if(((I=c[e>>2]|0,c[e>>2]=I+ -1,I)|0)!=0){h=b;sN(h);return}f2[c[(c[f>>2]|0)+8>>2]&1023](f|0);h=b;sN(h);return}function q4(b){b=b|0;var d=0,e=0;c[b>>2]=74116;c[b+64>>2]=74156;c[b+8>>2]=74136;d=b+12|0;c[d>>2]=74296;do{if((a[b+44|0]&1)!=0){e=c[b+52>>2]|0;if((e|0)==0){break}yt(e)}}while(0);c[d>>2]=74440;d=c[b+16>>2]|0;e=d+4|0;if(((I=c[e>>2]|0,c[e>>2]=I+ -1,I)|0)==0){f2[c[(c[d>>2]|0)+8>>2]&1023](d|0)}sN(b+64|0);if((b|0)==0){return}yt(b);return}function q5(b){b=b|0;var d=0,e=0,f=0;d=b-144+136|0;c[d>>2]=74116;b=d+64|0;c[b>>2]=74156;c[d+8>>2]=74136;e=d+12|0;c[e>>2]=74296;do{if((a[d+44|0]&1)!=0){f=c[d+52>>2]|0;if((f|0)==0){break}yt(f)}}while(0);c[e>>2]=74440;e=c[d+16>>2]|0;f=e+4|0;if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f2[c[(c[e>>2]|0)+8>>2]&1023](e)}sN(b);if((d|0)==0){return}yt(d);return}function q6(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b;e=c[(c[b>>2]|0)-12>>2]|0;b=d+e|0;c[b>>2]=74116;f=d+(e+64)|0;c[f>>2]=74156;c[d+(e+8)>>2]=74136;g=d+(e+12)|0;c[g>>2]=74296;do{if((a[d+(e+44)|0]&1)!=0){h=c[d+(e+52)>>2]|0;if((h|0)==0){break}yt(h)}}while(0);c[g>>2]=74440;g=c[d+(e+16)>>2]|0;e=g+4|0;if(((I=c[e>>2]|0,c[e>>2]=I+ -1,I)|0)==0){f2[c[(c[g>>2]|0)+8>>2]&1023](g|0)}sN(f);if((b|0)==0){return}yt(b);return}function q7(b){b=b|0;var d=0,e=0;d=b|0;c[d>>2]=74296;do{if((a[b+32|0]&1)!=0){e=c[b+40>>2]|0;if((e|0)==0){break}yt(e)}}while(0);c[d>>2]=74440;d=c[b+4>>2]|0;b=d+4|0;if(((I=c[b>>2]|0,c[b>>2]=I+ -1,I)|0)!=0){return}f2[c[(c[d>>2]|0)+8>>2]&1023](d|0);return}function q8(b){b=b|0;var d=0,e=0;d=b|0;c[d>>2]=74296;do{if((a[b+32|0]&1)!=0){e=c[b+40>>2]|0;if((e|0)==0){break}yt(e)}}while(0);c[d>>2]=74440;d=c[b+4>>2]|0;e=d+4|0;if(((I=c[e>>2]|0,c[e>>2]=I+ -1,I)|0)==0){f2[c[(c[d>>2]|0)+8>>2]&1023](d|0)}if((b|0)==0){return}yt(b);return}function q9(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=d+44|0;j=c[i>>2]|0;k=d+24|0;l=c[k>>2]|0;if(j>>>0<l>>>0){c[i>>2]=l;m=l}else{m=j}j=h&24;do{if((j|0)==24){if((g|0)==0){n=0;o=0;break}else if((g|0)==2){p=1252;break}else if((g|0)!=1){p=1256;break}i=b;c[i>>2]=0;c[i+4>>2]=0;i=b+8|0;c[i>>2]=-1;c[i+4>>2]=-1;return}else if((j|0)==0){i=b;c[i>>2]=0;c[i+4>>2]=0;i=b+8|0;c[i>>2]=-1;c[i+4>>2]=-1;return}else{if((g|0)==0){n=0;o=0;break}else if((g|0)==2){p=1252;break}else if((g|0)!=1){p=1256;break}if((h&8|0)==0){i=l-(c[d+20>>2]|0)|0;n=(i|0)<0?-1:0;o=i;break}else{i=(c[d+12>>2]|0)-(c[d+8>>2]|0)|0;n=(i|0)<0?-1:0;o=i;break}}}while(0);if((p|0)==1256){g=b;c[g>>2]=0;c[g+4>>2]=0;g=b+8|0;c[g>>2]=-1;c[g+4>>2]=-1;return}if((p|0)==1252){p=d+32|0;if((a[p]&1)==0){q=p+1|0}else{q=c[d+40>>2]|0}p=m-q|0;n=(p|0)<0?-1:0;o=p}p=yL(o,n,e,f)|0;f=K;e=0;do{if(!((f|0)<(e|0)|(f|0)==(e|0)&p>>>0<0>>>0)){n=d+32|0;if((a[n]&1)==0){r=n+1|0}else{r=c[d+40>>2]|0}n=m-r|0;o=(n|0)<0?-1:0;if((o|0)<(f|0)|(o|0)==(f|0)&n>>>0<p>>>0){break}n=h&8;do{if(!((p|0)==0&(f|0)==0)){do{if((n|0)!=0){if((c[d+12>>2]|0)!=0){break}o=b;c[o>>2]=0;c[o+4>>2]=0;o=b+8|0;c[o>>2]=-1;c[o+4>>2]=-1;return}}while(0);if(!((h&16|0)!=0&(l|0)==0)){break}o=b;c[o>>2]=0;c[o+4>>2]=0;o=b+8|0;c[o>>2]=-1;c[o+4>>2]=-1;return}}while(0);if((n|0)!=0){c[d+12>>2]=(c[d+8>>2]|0)+p;c[d+16>>2]=m}if((h&16|0)!=0){c[k>>2]=(c[d+20>>2]|0)+p}o=b;c[o>>2]=0;c[o+4>>2]=0;o=b+8|0;c[o>>2]=p;c[o+4>>2]=f;return}}while(0);f=b;c[f>>2]=0;c[f+4>>2]=0;f=b+8|0;c[f>>2]=-1;c[f+4>>2]=-1;return}function ra(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;b=a+44|0;e=c[b>>2]|0;f=c[a+24>>2]|0;if(e>>>0<f>>>0){c[b>>2]=f;g=f}else{g=e}if((c[a+48>>2]&8|0)==0){h=-1;return h|0}e=a+16|0;f=c[e>>2]|0;b=c[a+12>>2]|0;if(f>>>0<g>>>0){c[e>>2]=g;i=g}else{i=f}if(b>>>0>=i>>>0){h=-1;return h|0}h=d[b]|0;return h|0}function rb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b+44|0;f=c[e>>2]|0;g=c[b+24>>2]|0;if(f>>>0<g>>>0){c[e>>2]=g;h=g}else{h=f}f=b+8|0;g=c[f>>2]|0;e=b+12|0;i=c[e>>2]|0;if(g>>>0>=i>>>0){j=-1;return j|0}if((d|0)==-1){c[f>>2]=g;c[e>>2]=i-1;c[b+16>>2]=h;j=0;return j|0}k=i-1|0;do{if((c[b+48>>2]&16|0)==0){if((d<<24>>24|0)==(a[k]|0)){break}else{j=-1}return j|0}}while(0);c[f>>2]=g;c[e>>2]=k;c[b+16>>2]=h;a[k]=d&255;j=d;return j|0}function rc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=d;d=i;i=i+16|0;c[d>>2]=c[g>>2];c[d+4>>2]=c[g+4>>2];c[d+8>>2]=c[g+8>>2];c[d+12>>2]=c[g+12>>2];g=d+8|0;ge[c[(c[b>>2]|0)+16>>2]&63](a,b,c[g>>2]|0,c[g+4>>2]|0,0,e);i=f;return}function rd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;if((d|0)==-1){e=0;return e|0}f=b|0;g=b+12|0;h=b+8|0;i=(c[g>>2]|0)-(c[h>>2]|0)|0;j=b+24|0;k=c[j>>2]|0;l=b+28|0;m=c[l>>2]|0;if((k|0)==(m|0)){n=b+48|0;if((c[n>>2]&16|0)==0){e=-1;return e|0}o=b+20|0;p=c[o>>2]|0;q=k-p|0;r=b+44|0;s=(c[r>>2]|0)-p|0;p=b+32|0;t=p;u=p;v=a[u]|0;if((v&1)==0){w=(v&255)>>>1;x=10}else{w=c[b+36>>2]|0;x=(c[p>>2]&-2)-1|0}if((w|0)==(x|0)){sA(p,x,1,x,x,0);y=a[u]|0}else{y=v}if((y&1)==0){a[u]=(w<<1)+2&255;z=t+1|0;A=w+1|0}else{y=c[b+40>>2]|0;v=w+1|0;c[b+36>>2]=v;z=y;A=v}a[z+w|0]=0;a[z+A|0]=0;A=a[u]|0;if((A&1)==0){B=10;C=A}else{A=c[p>>2]|0;B=(A&-2)-1|0;C=A&255}A=C&255;if((A&1|0)==0){D=A>>>1}else{D=c[b+36>>2]|0}do{if(D>>>0<B>>>0){ss(p,B-D|0)}else{if((C&1)==0){a[t+1+B|0]=0;a[u]=B<<1&255;break}else{a[(c[b+40>>2]|0)+B|0]=0;c[b+36>>2]=B;break}}}while(0);B=a[u]|0;if((B&1)==0){E=t+1|0}else{E=c[b+40>>2]|0}t=B&255;if((t&1|0)==0){F=t>>>1}else{F=c[b+36>>2]|0}t=E+F|0;c[o>>2]=E;c[l>>2]=t;l=E+q|0;c[j>>2]=l;q=E+s|0;c[r>>2]=q;G=l;H=t;I=q;J=n}else{G=k;H=m;I=c[b+44>>2]|0;J=b+48|0}m=G+1|0;k=m>>>0<I>>>0?I:m;c[b+44>>2]=k;if((c[J>>2]&8|0)!=0){J=b+32|0;if((a[J]&1)==0){K=J+1|0}else{K=c[b+40>>2]|0}c[h>>2]=K;c[g>>2]=K+i;c[b+16>>2]=k}if((G|0)==(H|0)){e=gm[c[(c[b>>2]|0)+52>>2]&127](f,d&255)|0;return e|0}else{c[j>>2]=m;a[G]=d&255;e=d&255;return e|0}return 0}function re(a){a=a|0;if((a|0)==0){return}yt(a);return}function rf(a){a=a|0;var b=0;a=(gq[c[185316]&31](0,1,0,8)|0)<<16>>16!=0|0;b=((gq[c[185316]&31](0,1,0,0)|0)<<16>>16==0?0:2)|a;a=b|((gq[c[185316]&31](0,1,0,2)|0)<<16>>16==0?0:4);b=a|((gq[c[185316]&31](0,1,0,3)|0)<<16>>16==0?0:8);a=b|((gq[c[185316]&31](0,1,0,7)|0)<<16>>16==0?0:16);b=a|((gq[c[185316]&31](0,1,0,6)|0)<<16>>16==0?0:32);a=b|((gq[c[185316]&31](0,1,0,4)|0)<<16>>16==0?0:64);return a|((gq[c[185316]&31](0,1,0,5)|0)<<16>>16==0?0:128)|0}function rg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;while(1){d=ys(20152)|0;if((d|0)!=0){break}e=(I=c[185320]|0,c[185320]=I+0,I);if((e|0)==0){f=1363;break}gs[e&63]()}if((f|0)==1363){e=ff(4)|0;c[e>>2]=72440;dr(e|0,79056,316)}e=d;g=d;h=d+20118|0;i=h;j=d+20116|0;k=j;l=d+512|0;c[d+16896>>2]=l;c[d+16900>>2]=0;c[d+16904>>2]=0;m=d+16912|0;n=d+16996|0;yB(d+16908|0,-1|0,40);c[n>>2]=1;o=d+17e3|0;c[o>>2]=3;c[d+17004>>2]=5;c[d+17008>>2]=7;c[d+17012>>2]=8;p=5;q=6;while(1){s=p+1>>1;t=q-s|0;if((s|0)>0){u=0;do{v=u<<1;w=v+q|0;x=c[g+16972+(w<<2)>>2]|0;if((v|1|0)==(p|0)){f=1371}else{v=c[g+16972+(w+1<<2)>>2]|0;if((c[g+16912+(x<<2)>>2]|0)>>>0<(c[g+16912+(v<<2)>>2]|0)>>>0){f=1371}else{y=v}}if((f|0)==1371){f=0;y=x}c[g+16972+(u+t<<2)>>2]=y;u=u+1|0;}while((u|0)<(s|0))}if((q|0)==(s|0)){break}else{p=s;q=t}}q=d+16972|0;p=d+16948|0;c[p>>2]=c[g+16912+(c[q>>2]<<2)>>2];c[d+16968>>2]=6;c[d+16964>>2]=266;c[d+16960>>2]=16;c[d+16956>>2]=442;c[d+16952>>2]=34;yB(d+17016|0,0,13);c[d+17160>>2]=0;yB(d+17180|0,0,20);c[d+17200>>2]=5;yB(d+17032|0,0,128);yB(d+17164|0,0,16);c[d+17208>>2]=0;y=d+17212|0;c[y>>2]=0;c[y+4>>2]=0;yB(d+17224|0,0,16);a[d+17240|0]=5;yB(d+17241|0,0,7);b[d+17248>>1]=1;a[d+17250|0]=0;a[d+17251|0]=0;a[d+17252|0]=0;c[d+17256>>2]=0;c[d+17260>>2]=-1;a[d+17264|0]=0;a[d+17265|0]=0;a[d+17266|0]=0;y=d+17268|0;u=d+19680|0;c[d+17524>>2]=l;c[d+17528>>2]=84312;c[d+17532>>2]=0;c[d+17536>>2]=0;c[d+17540>>2]=-4396;l=d+17552|0;yB(d+17544|0,0,16);b[d+17556>>1]=456;a[d+17558|0]=0;c[l>>2]=456;c[d+19144>>2]=u;c[d+19268>>2]=l;l=d+19272|0;x=d+19282|0;c[l>>2]=d;a[x]=0;v=d+19281|0;a[v]=0;w=d+19276|0;c[w>>2]=0;z=d+19280|0;a[z]=-1;A=d+19228|0;C=0;a[A]=C&255;C=C>>8;a[A+1|0]=C&255;C=C>>8;a[A+2|0]=C&255;C=C>>8;a[A+3|0]=C&255;B=d+19232|0;a[B]=0;D=34;E=B;B=0;while(1){F=E+1|0;a[F]=B;if((D|0)<=0){G=0;H=80;break}D=D-1|0;E=F;B=a[v]&1}while(1){B=H-1|0;a[y+1880+G|0]=a[d+(G<<1&-4|G&1)|0]|0;if((B|0)==0){break}else{G=G+1|0;H=B}}H=d+19e3|0;yB(H|0,-128|0,144);G=d+19284|0;c[G>>2]=0;B=d+19288|0;c[B>>2]=566992;E=d+19292|0;c[E>>2]=0;yB(d+19362|0,0,14);a[d+19376|0]=-1;yB(d+19296|0,0,66);D=d+19377|0;C=0;a[D]=C&255;C=C>>8;a[D+1|0]=C&255;C=C>>8;a[D+2|0]=C&255;C=C>>8;a[D+3|0]=C&255;c[d+19560>>2]=-1;c[d+19564>>2]=-1;c[d+19576>>2]=1;c[d+19568>>2]=-1;c[d+19572>>2]=164;yB(d+19580|0,-1|0,32);c[d+19644>>2]=1;c[d+19648>>2]=3;c[d+19652>>2]=5;c[d+19656>>2]=7;D=4;F=3;while(1){J=D+1>>1;K=F-J|0;if((J|0)>0){L=0;do{M=L<<1;N=M+F|0;O=c[y+2364+(N<<2)>>2]|0;if((M|1|0)==(D|0)){f=1382}else{M=c[y+2364+(N+1<<2)>>2]|0;if((c[y+2312+(O<<2)>>2]|0)>>>0<(c[y+2312+(M<<2)>>2]|0)>>>0){f=1382}else{P=M}}if((f|0)==1382){f=0;P=O}c[y+2364+(L+K<<2)>>2]=P;L=L+1|0;}while((L|0)<(J|0))}if((F|0)==(J|0)){break}else{D=J;F=K}}c[d+19612>>2]=c[y+2312+(c[d+19632>>2]<<2)>>2];c[d+19628>>2]=356;c[d+19624>>2]=340;c[d+19620>>2]=520;c[d+19616>>2]=428;c[d+19660>>2]=m;a[d+19664|0]=0;a[d+19665|0]=0;c[d+19668>>2]=-1;yB(d+19672|0,0,5);yB(d+19432|0,0,128);yB(u|0,0,11);c[d+19384>>2]=16777215;c[d+19388>>2]=11184810;c[d+19392>>2]=5592405;c[d+19396>>2]=0;c[d+19400>>2]=16777215;c[d+19404>>2]=11184810;c[d+19408>>2]=5592405;c[d+19412>>2]=0;c[d+19416>>2]=16777215;c[d+19420>>2]=11184810;c[d+19424>>2]=5592405;c[d+19428>>2]=0;a[d+19379|0]=0;c[l>>2]=d;a[x]=0;a[v]=0;c[w>>2]=0;a[z]=-1;C=0;a[A]=C&255;C=C>>8;a[A+1|0]=C&255;C=C>>8;a[A+2|0]=C&255;C=C>>8;a[A+3|0]=C&255;A=35;z=d+19231|0;w=0;while(1){x=z+1|0;a[x]=w;if((A|0)<=0){Q=0;R=80;break}A=A-1|0;z=x;w=a[v]&1}while(1){v=R-1|0;a[y+1880+Q|0]=a[d+(Q<<1&-4|Q&1)|0]|0;if((v|0)==0){break}else{Q=Q+1|0;R=v}}yB(H|0,-128|0,144);a[d+19676|0]=0;oO(y);c[G>>2]=0;c[E>>2]=160;c[B>>2]=566992;B=d+19692|0;E=d+19732|0;G=E;c[B>>2]=75624;c[d+19696>>2]=B;c[d+19700>>2]=G;y=d+19704|0;c[d+19708>>2]=d+19805;c[y>>2]=75656;c[d+19712>>2]=G;H=y;c[d+19716>>2]=75688;c[d+19724>>2]=H;a[d+19730|0]=63;a[d+19731|0]=0;b[d+19728>>1]=64;c[d+19720>>2]=-1;c[d+19736>>2]=-1;c[E>>2]=75400;c[d+19740>>2]=-1;b[d+19744>>1]=4096;a[d+19746|0]=0;a[d+19747|0]=0;a[d+19748|0]=0;a[d+19749|0]=1;c[d+19756>>2]=-1;c[d+19752>>2]=75720;c[d+19760>>2]=B;a[d+19764|0]=0;a[d+19765|0]=0;B=d+19768|0;c[d+19772>>2]=-1;c[B>>2]=75528;c[d+19776>>2]=H;c[d+19780>>2]=G;G=d+19784|0;C=0;b[G>>1]=C&65535;b[G+2>>1]=C>>16;yB(d+19792|0,0,14);c[d+19788>>2]=B;B=d+19808|0;G=d+19848|0;H=G;c[B>>2]=75592;c[d+19812>>2]=B;c[d+19816>>2]=H;E=d+19820|0;c[d+19824>>2]=d+19901;c[E>>2]=75656;c[d+19828>>2]=H;c[d+19832>>2]=75688;c[d+19840>>2]=E;a[d+19846|0]=63;a[d+19847|0]=0;b[d+19844>>1]=64;c[d+19836>>2]=-1;c[d+19852>>2]=-1;c[G>>2]=75400;c[d+19856>>2]=-1;b[d+19860>>1]=4096;a[d+19862|0]=0;a[d+19863|0]=0;a[d+19864|0]=0;a[d+19865|0]=1;G=d+19868|0;c[d+19872>>2]=-1;c[G>>2]=75720;c[d+19876>>2]=B;a[d+19880|0]=0;a[d+19881|0]=0;yB(d+19888|0,0,14);c[d+19884>>2]=G;G=d+19920|0;B=d+19974|0;E=d+19960|0;c[d+19924>>2]=B;c[G>>2]=75496;c[d+19928>>2]=E;c[d+19932>>2]=75688;c[d+19940>>2]=G;a[d+19946|0]=-1;a[d+19947|0]=0;b[d+19944>>1]=256;c[d+19936>>2]=-1;c[d+19948>>2]=0;c[d+19952>>2]=0;c[d+19956>>2]=0;c[E>>2]=-1;E=d+19964|0;c[E>>2]=0;c[E+4>>2]=0;a[d+19972|0]=4;a[d+19973|0]=0;a[B]=0;a[d+19975|0]=0;B=d+19976|0;E=d+20032|0;G=E;c[B>>2]=75560;c[d+19980>>2]=B;c[d+19984>>2]=G;H=d+19988|0;c[d+19992>>2]=d+20065;c[H>>2]=75464;c[d+19996>>2]=G;c[d+2e4>>2]=75688;c[d+20008>>2]=H;a[d+20014|0]=63;a[d+20015|0]=0;b[d+20012>>1]=64;c[d+20004>>2]=-1;H=d+20016|0;c[d+20020>>2]=-1;c[H>>2]=75720;c[d+20024>>2]=B;a[d+20028|0]=0;a[d+20029|0]=0;c[d+20036>>2]=-1;c[E>>2]=75432;c[d+20040>>2]=-1;b[d+20044>>1]=255;a[d+20046|0]=0;a[d+20047|0]=0;yB(d+20052|0,0,14);c[d+20048>>2]=H;c[d+20068>>2]=0;c[d+20072>>2]=0;c[d+20076>>2]=0;c[d+20080>>2]=32768;c[d+20084>>2]=0;a[d+20088|0]=0;H=d+20092|0;c[H>>2]=h;c[H+4>>2]=j;b[d+20100>>1]=0;b[d+20102>>1]=0;a[d+20104|0]=-2;a[d+20105|0]=0;c[d+16920>>2]=65664;j=(c[d+16924>>2]|0)>>>0>65664?2:3;c[o>>2]=j;o=c[n>>2]|0;H=g+16912+(j<<2)|0;h=(c[g+16912+(o<<2)>>2]|0)>>>0<(c[H>>2]|0)>>>0?o:j;o=d+16984|0;c[o>>2]=h;E=c[d+16988>>2]|0;B=g+16912+(E<<2)|0;G=(c[g+16912+(h<<2)>>2]|0)>>>0<(c[B>>2]|0)>>>0?h:E;h=d+16976|0;c[h>>2]=G;y=c[d+16980>>2]|0;R=g+16912+(y<<2)|0;Q=(c[g+16912+(G<<2)>>2]|0)>>>0<(c[R>>2]|0)>>>0?G:y;c[q>>2]=Q;c[p>>2]=c[g+16912+(Q<<2)>>2];c[d+16916>>2]=0;c[n>>2]=1;n=(c[H>>2]|0)!=0?1:j;c[o>>2]=n;o=(c[g+16912+(n<<2)>>2]|0)>>>0<(c[B>>2]|0)>>>0?n:E;c[h>>2]=o;h=(c[g+16912+(o<<2)>>2]|0)>>>0<(c[R>>2]|0)>>>0?o:y;c[q>>2]=h;c[p>>2]=c[g+16912+(h<<2)>>2];c[d+20112>>2]=0;b[k>>1]=256;b[i>>1]=-2;c[d+20120>>2]=15;c[d+20124>>2]=15;c[d+20128>>2]=0;c[d+20132>>2]=256;a[d+20136|0]=1;a[d+20137|0]=0;a[d+20138|0]=19;a[d+20139|0]=0;a[d+20140|0]=-40;a[d+20141|0]=1;a[d+20142|0]=77;a[d+20143|0]=0;c[d+20144>>2]=1;a[d+20148|0]=0;c[185312]=e;ep(172,741248,r|0)|0;c[185304]=75800;yB(741200,0,12);ep(534,741200,r|0)|0;return}function rh(a,b){a=a|0;b=b|0;return c[a+44>>2]|0}function ri(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0.0;e=i;i=i+16|0;f=e|0;g=e+8|0;gr[c[(c[a>>2]|0)+4>>2]&127](a,f,g);h=c[a+24>>2]|0;j=c[h>>2]|0;k=c[j+12>>2]|0;l=+(b|0)*+((c[f>>2]|0)>>>0>>>0);f=c[g>>2]|0;g=~~(l/(+(d|0)*+(((f>>>0)/((f5[c[j+8>>2]&255](h)|0)>>>0)|0)>>>0>>>0))+.5);f3[k&1023](h,g);rn(a);c[a+4>>2]=b;c[a+8>>2]=d;i=e;return}function rj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;c[b>>2]=1;c[d>>2]=1;e=c[a+16>>2]|0;f=a+12|0;if((e|0)==(f|0)){return}else{g=e}do{e=g+8|0;a=c[e>>2]|0;h=f5[c[(c[a>>2]|0)+4>>2]&255](a)|0;c[b>>2]=ag(c[b>>2]|0,h)|0;h=c[e>>2]|0;e=f5[c[(c[h>>2]|0)+8>>2]&255](h)|0;c[d>>2]=ag(c[d>>2]|0,e)|0;g=c[g+4>>2]|0;}while((g|0)!=(f|0));return}function rk(a){a=a|0;rm(a);return}function rl(a){a=a|0;rm(a);if((a|0)==0){return}yt(a);return}function rm(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[a>>2]=75872;c[a+36>>2]=0;b=a+28|0;d=c[b>>2]|0;if((d|0)!=0){yt(d)}c[b>>2]=0;c[a+32>>2]=0;c[a+40>>2]=0;c[a+24>>2]=0;d=a+12|0;e=a+16|0;f=c[e>>2]|0;g=d;if((f|0)!=(g|0)){h=f;do{f=c[h+8>>2]|0;if((f|0)!=0){f2[c[(c[f>>2]|0)+20>>2]&1023](f)}h=c[h+4>>2]|0;}while((h|0)!=(g|0))}h=a+20|0;do{if((c[h>>2]|0)!=0){f=c[e>>2]|0;i=(c[d>>2]|0)+4|0;j=f|0;c[(c[j>>2]|0)+4>>2]=c[i>>2];c[c[i>>2]>>2]=c[j>>2];c[h>>2]=0;if((f|0)==(g|0)){break}else{k=f}while(1){f=c[k+4>>2]|0;if((k|0)!=0){yt(k)}if((f|0)==(g|0)){break}else{k=f}}}}while(0);k=c[b>>2]|0;if((k|0)!=0){yt(k)}k=a+12|0;if((c[h>>2]|0)==0){return}a=c[e>>2]|0;e=k;b=(c[k>>2]|0)+4|0;k=a|0;c[(c[k>>2]|0)+4>>2]=c[b>>2];c[c[b>>2]>>2]=c[k>>2];c[h>>2]=0;if((a|0)==(e|0)){return}else{l=a}while(1){a=c[l+4>>2]|0;if((l|0)!=0){yt(l)}if((a|0)==(e|0)){break}else{l=a}}return}function rn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+8|0;d=b|0;e=d;c[d>>2]=0;c[d+4>>2]=0;f=c[a+40>>2]|0;g=c[a+16>>2]|0;h=a+12|0;if((g|0)==(h|0)){j=1;k=f;l=1429}else{m=f;f=-1;n=g;do{g=n+8|0;o=c[g>>2]|0;p=(ag(f5[c[(c[o>>2]|0)+4>>2]&255](o)|0,m)|0)-1|0;o=c[g>>2]|0;m=((p>>>0)/((f5[c[(c[o>>2]|0)+8>>2]&255](o)|0)>>>0)|0)+1|0;f=f+1|0;q=f&1;o=e+(q<<2)|0;p=c[o>>2]|0;if(m>>>0>p>>>0){c[o>>2]=m;r=m}else{r=p}n=c[n+4>>2]|0;}while((n|0)!=(h|0));if(m>>>0<r>>>0){s=m}else{j=q;k=m;l=1429}}if((l|0)==1429){c[e+(j<<2)>>2]=0;s=k}k=a+28|0;j=a+32|0;m=c[d>>2]|0;d=c[e+4>>2]|0;e=d+m<<1;if((c[j>>2]|0)>>>0<e>>>0){q=k|0;r=c[q>>2]|0;if((r|0)!=0){yt(r)}do{if((e|0)==0){t=0}else{r=cg(e|0,2)|0;h=K?-1:r;r=(h|0)==0?1:h;while(1){u=ys(r)|0;if((u|0)!=0){l=1449;break}h=(I=c[185320]|0,c[185320]=I+0,I);if((h|0)==0){break}gs[h&63]()}if((l|0)==1449){t=u;break}r=ff(4)|0;c[r>>2]=72440;dr(r|0,79056,316)}}while(0);c[q>>2]=t;c[j>>2]=e}if((d|0)==0){v=0;w=a+36|0;c[w>>2]=v;x=a+44|0;c[x>>2]=s;i=b;return}v=(c[k>>2]|0)+(m<<1<<1)|0;w=a+36|0;c[w>>2]=v;x=a+44|0;c[x>>2]=s;i=b;return}function ro(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[a+40>>2]|0)>>>0<e>>>0){dL(24784,97,55288,46408);return 0}f=c[a+28>>2]|0;g=c[a+36>>2]|0;h=(f|0)==(g|0)?b:f;f=(g|0)==0?b:g;g=c[a+16>>2]|0;i=a+12|0;if((g|0)==(i|0)){j=e;return j|0}else{k=e;l=d;m=g}while(1){g=m+4|0;if((c[g>>2]|0)==(i|0)){n=b}else{n=(l|0)==(h|0)?f:h}d=c[m+8>>2]|0;e=gq[c[c[d>>2]>>2]&31](d,n,l,k)|0;d=c[g>>2]|0;if((d|0)==(i|0)){j=e;break}else{k=e;l=n;m=d}}return j|0}function rp(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=+f;g=g|0;var i=0.0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0,D=0.0,E=0.0,F=0,G=0,H=0,J=0,L=0,M=0,N=0,O=0;i=f/+(d>>>0>>>0);j=ag(e,d)|0;k=j-1|0;l=(k|0)/2|0;m=l+1|0;do{if((m|0)==0){n=0}else{o=cg(m|0,8)|0;p=K?-1:o;o=(p|0)==0?1:p;while(1){q=ys(o)|0;if((q|0)!=0){r=1481;break}p=(I=c[185320]|0,c[185320]=I+0,I);if((p|0)==0){break}gs[p&63]()}if((r|0)==1481){n=q;break}o=ff(4)|0;c[o>>2]=72440;dr(o|0,79056,316)}}while(0);if((d|0)!=0){f=i*3.141592653589793;q=0;r=n;while(1){if((q|0)<(m|0)){o=q;p=r;while(1){s=o<<1;if((s|0)==(k|0)){t=f}else{i=+(s-k|0);t=+Z(+(f*i))/i}s=p+8|0;h[p>>3]=t*+gn[g&7](o,k);u=o+d|0;if((u|0)<(m|0)){o=u;p=s}else{v=s;break}}}else{v=r}p=q+1|0;if(p>>>0<d>>>0){q=p;r=v}else{break}}v=(d+1|0)>>>1;if((v|0)==0){w=0.0}else{t=0.0;r=n;q=n+(l<<3)|0;l=0;while(1){k=(l|0)<(m|0);if(k){f=0.0;i=0.0;g=r;p=l;while(1){x=+h[g>>3];y=f+x;z=i+ +V(+x);o=p+d|0;if((o|0)<(m|0)){f=y;i=z;g=g+8|0;p=o}else{A=y;B=z;C=o;break}}}else{A=0.0;B=0.0;C=l}if((C|0)<(j|0)){i=A;f=B;p=q;g=C;while(1){z=+h[p>>3];y=i+z;x=f+ +V(+z);o=g+d|0;if((o|0)<(j|0)){i=y;f=x;p=p-8|0;g=o}else{D=y;E=x;break}}}else{D=A;E=B}f=1.0/D;if(k){g=r;p=l;while(1){o=g+8|0;h[g>>3]=f*+h[g>>3];s=p+d|0;if((s|0)<(m|0)){g=o;p=s}else{F=o;G=s;break}}}else{F=r;G=l}if(F>>>0<q>>>0&(G|0)<(j|0)){p=q;g=G;while(1){k=p-8|0;h[p>>3]=f*+h[p>>3];s=g+d|0;if((s|0)<(j|0)){p=k;g=s}else{H=k;break}}}else{H=q}i=E*f;x=i>t?i:t;g=l+1|0;if(g>>>0<v>>>0){t=x;r=F;q=H;l=g}else{w=x;break}}}t=(65536.0- +(e>>>0>>>0)*.5)/w;l=e-1|0;H=n;q=0;while(1){F=q+1|0;do{if((q|0)<(m|0)){r=l+(ag((F|0)==(d|0)?0:F,e)|0)|0;v=a+(r<<1)|0;r=a+((ag(((d-q|0)>>>0)%(d>>>0)|0,e)|0)<<1)|0;j=H+8|0;G=~~+U(+(t*+h[H>>3]+.5));b[r>>1]=G;b[v>>1]=G;G=q+d|0;if((G|0)<(m|0)){J=v;L=r;M=j;N=G}else{O=j;break}while(1){j=J-2|0;G=L+2|0;r=M+8|0;v=~~+U(+(t*+h[M>>3]+.5));b[G>>1]=v;b[j>>1]=v;v=N+d|0;if((v|0)<(m|0)){J=j;L=G;M=r;N=v}else{O=r;break}}}else{O=H}}while(0);if(F>>>0<d>>>0){H=O;q=F}else{break}}}if((n|0)==0){return}yt(n);return}function rq(a,b){a=a|0;b=b|0;return}function rr(a){a=a|0;return 2048}function rs(a){a=a|0;return 32}function rt(a){a=a|0;return c[a+16>>2]|0}function ru(a,b){a=a|0;b=b|0;c[a+16>>2]=b;c[a+36>>2]=b;return}function rv(a){a=a|0;return c[a+16>>2]|0}function rw(a,b){a=a|0;b=b|0;c[a+16>>2]=b;c[a+36>>2]=b;return}function rx(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=a|0;h=c[g>>2]|0;if((h|0)==0|(f|0)==0){i=0;return i|0}j=a+4|0;k=c[a+8>>2]|0;l=(k<<11)-1|0;m=f<<11;n=a+16|0;o=c[n>>2]|0;p=l>>>0<m>>>0?l:m;L1651:do{if(o>>>0<p>>>0){l=j|0;q=a+12|0;r=o;s=d;t=h;while(1){u=ag(r+1&2047,k)|0;v=t+(u<<1)|0;w=r>>>11;x=w+1|0;y=(w^2147483647)+k<<1>>1;if((y|0)==0){z=x;A=0;B=e;C=v}else{w=v;v=(c[l>>2]|0)+(x<<1)|0;D=0;E=y;while(1){F=E-1|0;G=(ag(b[v>>1]|0,b[w>>1]|0)|0)+D|0;if((F|0)==0){break}else{w=w+2|0;v=v+2|0;D=G;E=F}}z=x;A=G;B=e;C=t+(y+u<<1)|0}while(1){H=(ag(b[B>>1]|0,b[C>>1]|0)|0)+A|0;E=z-1|0;if((E|0)==0){break}else{z=E;A=H;B=B+4|0;C=C+2|0}}b[s>>1]=(H+32768|0)>>>16&65535;u=s+4|0;y=(c[q>>2]|0)+r|0;if(y>>>0>=p>>>0){I=y;J=u;break L1651}r=y;s=u;t=c[g>>2]|0}}else{I=o;J=d}}while(0);L1665:do{if(I>>>0<m>>>0){d=1-k|0;o=a+12|0;p=I;H=J;while(1){C=c[g>>2]|0;B=k;A=0;z=e+(d+(p>>>11)<<1<<1)|0;G=C+((ag(p+1&2047,k)|0)<<1)|0;while(1){K=(ag(b[z>>1]|0,b[G>>1]|0)|0)+A|0;C=B-1|0;if((C|0)==0){break}else{B=C;A=K;z=z+4|0;G=G+2|0}}b[H>>1]=(K+32768|0)>>>16&65535;G=c[o>>2]|0;z=G+p|0;if(z>>>0>=m>>>0){L=z;M=G;break L1665}p=z;H=H+4|0}}else{L=I;M=c[a+12>>2]|0}}while(0);a=((L-(c[n>>2]|0)|0)>>>0)/(M>>>0)|0;c[n>>2]=L-m;m=f&2097151;f=c[j>>2]|0;if(m>>>0<k>>>0){j=k-m|0;yI(f|0,f+(m<<1)|0,j<<1|0);N=m;O=e;P=f+(j<<1)|0}else{N=k;O=e+(m-k<<1<<1)|0;P=f}while(1){b[P>>1]=b[O>>1]|0;f=N-1|0;if((f|0)==0){i=a;break}else{N=f;O=O+4|0;P=P+2|0}}return i|0}function ry(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=a|0;h=c[g>>2]|0;if((h|0)==0|(f|0)==0){i=0;return i|0}j=a+4|0;k=c[a+8>>2]|0;l=(k<<5)-1|0;m=f<<5;n=a+16|0;o=c[n>>2]|0;p=l>>>0<m>>>0?l:m;L1684:do{if(o>>>0<p>>>0){l=j|0;q=a+12|0;r=o;s=d;t=h;while(1){u=ag(r+1&31,k)|0;v=t+(u<<1)|0;w=r>>>5;x=w+1|0;y=(w^2147483647)+k<<1>>1;if((y|0)==0){z=x;A=0;B=e;C=v}else{w=v;v=(c[l>>2]|0)+(x<<1)|0;D=0;E=y;while(1){F=E-1|0;G=(ag(b[v>>1]|0,b[w>>1]|0)|0)+D|0;if((F|0)==0){break}else{w=w+2|0;v=v+2|0;D=G;E=F}}z=x;A=G;B=e;C=t+(y+u<<1)|0}while(1){H=(ag(b[B>>1]|0,b[C>>1]|0)|0)+A|0;E=z-1|0;if((E|0)==0){break}else{z=E;A=H;B=B+4|0;C=C+2|0}}b[s>>1]=(H+32768|0)>>>16&65535;u=s+4|0;y=(c[q>>2]|0)+r|0;if(y>>>0>=p>>>0){I=y;J=u;break L1684}r=y;s=u;t=c[g>>2]|0}}else{I=o;J=d}}while(0);L1698:do{if(I>>>0<m>>>0){d=1-k|0;o=a+12|0;p=I;H=J;while(1){C=c[g>>2]|0;B=k;A=0;z=e+(d+(p>>>5)<<1<<1)|0;G=C+((ag(p+1&31,k)|0)<<1)|0;while(1){K=(ag(b[z>>1]|0,b[G>>1]|0)|0)+A|0;C=B-1|0;if((C|0)==0){break}else{B=C;A=K;z=z+4|0;G=G+2|0}}b[H>>1]=(K+32768|0)>>>16&65535;G=c[o>>2]|0;z=G+p|0;if(z>>>0>=m>>>0){L=z;M=G;break L1698}p=z;H=H+4|0}}else{L=I;M=c[a+12>>2]|0}}while(0);a=((L-(c[n>>2]|0)|0)>>>0)/(M>>>0)|0;c[n>>2]=L-m;m=f&134217727;f=c[j>>2]|0;if(m>>>0<k>>>0){j=k-m|0;yI(f|0,f+(m<<1)|0,j<<1|0);N=m;O=e;P=f+(j<<1)|0}else{N=k;O=e+(m-k<<1<<1)|0;P=f}while(1){b[P>>1]=b[O>>1]|0;f=N-1|0;if((f|0)==0){i=a;break}else{N=f;O=O+4|0;P=P+2|0}}return i|0}function rz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;rx(a+4|0,b,c,d)|0;return rx(a+24|0,b+2|0,c+2|0,d)|0}function rA(a){a=a|0;var b=0;c[a>>2]=75952;b=c[a+44>>2]|0;if((b|0)!=0){yt(b)}b=c[a+28>>2]|0;if((b|0)!=0){yt(b)}b=c[a+8>>2]|0;if((b|0)==0){return}yt(b);return}function rB(a){a=a|0;var b=0;c[a>>2]=75952;b=c[a+44>>2]|0;if((b|0)!=0){yt(b)}b=c[a+28>>2]|0;if((b|0)!=0){yt(b)}b=c[a+8>>2]|0;if((b|0)!=0){yt(b)}if((a|0)==0){return}yt(a);return}function rC(b,c){b=b|0;c=c|0;var d=0.0,e=0.0,f=0.0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0;do{if((a[741496]|0)==0){if((cR(741496)|0)==0){break}h[9047]=.051458913433319785}}while(0);d=+(b<<1|0)/+(c|0)+-1.0;e=+W(+(1.0-d*d))*4.62;d=e*e*.25;e=d*d*.25;f=d/9.0*e;g=d*.0625*f;i=d/25.0*g;j=d/36.0*i;k=d/49.0*j;l=d*.015625*k;m=d/81.0*l;n=d/100.0*m;o=d/121.0*n;p=d/144.0*o;q=d/169.0*p;r=d/196.0*q;s=d/225.0*r;return+(+h[9047]*(d+1.0+e+f+g+i+j+k+l+m+n+o+p+q+r+s+d*.00390625*s))}function rD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ry(a+4|0,b,c,d)|0;return ry(a+24|0,b+2|0,c+2|0,d)|0}function rE(a,b,d,e){a=a|0;b=b|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d<<5;g=a+44|0;h=c[g>>2]|0;if((h|0)!=0){yt(h)}do{if((f|0)==0){i=0}else{h=cg(f|0,2)|0;j=K?-1:h;h=(j|0)==0?1:j;while(1){k=ys(h)|0;if((k|0)!=0){l=1607;break}j=(I=c[185320]|0,c[185320]=I+0,I);if((j|0)==0){break}gs[j&63]()}if((l|0)==1607){i=k;break}h=ff(4)|0;c[h>>2]=72440;dr(h|0,79056,316)}}while(0);c[g>>2]=i;c[a+48>>2]=f;rp(i,32,d,e,2);i=(d|0)==0;f=cg(d|0,2)|0;k=K;h=d<<1;j=(h|0)>0;m=h>>1;h=-m|0;n=(((h|0)>-1?h:2147483647)+m<<1)+2|0;c[a+4>>2]=c[g>>2];c[a+16>>2]=b;c[a+20>>2]=0;m=a+8|0;h=c[m>>2]|0;if((h|0)!=0){yt(h)}do{if(i){c[m>>2]=0;c[a+12>>2]=0}else{h=k?-1:f;o=(h|0)==0?1:h;while(1){p=ys(o)|0;if((p|0)!=0){l=1627;break}h=(I=c[185320]|0,c[185320]=I+0,I);if((h|0)==0){l=1621;break}gs[h&63]()}if((l|0)==1627){c[m>>2]=p;c[a+12>>2]=d;if(!j){break}yB(p|0,0,n|0);break}else if((l|0)==1621){o=ff(4)|0;c[o>>2]=72440;dr(o|0,79056,316)}}}while(0);c[a+24>>2]=c[g>>2];c[a+36>>2]=b;c[a+40>>2]=0;b=a+28|0;g=c[b>>2]|0;if((g|0)!=0){yt(g)}if(i){c[b>>2]=0;c[a+32>>2]=0;return}i=k?-1:f;f=(i|0)==0?1:i;while(1){q=ys(f)|0;if((q|0)!=0){break}i=(I=c[185320]|0,c[185320]=I+0,I);if((i|0)==0){l=1641;break}gs[i&63]()}if((l|0)==1641){l=ff(4)|0;c[l>>2]=72440;dr(l|0,79056,316)}c[b>>2]=q;c[a+32>>2]=d;if(!j){return}yB(q|0,0,n|0);return}function rF(a){a=a|0;return 1}function rG(a){a=a|0;return}function rH(a){a=a|0;return c[a+28>>2]|0}function rI(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=a+24|0;h=c[g>>2]|0;i=a+28|0;j=c[i>>2]|0;k=((h+f-j|0)>>>0)/(h>>>0)|0;l=65536/((ag(ag(h,h)|0,h)|0)>>>0)|0;h=a|0;m=c[h>>2]|0;n=a+4|0;o=c[n>>2]|0;p=a+8|0;q=c[p>>2]|0;if(j>>>0>f>>>0){r=e;s=q;t=o;u=m;v=j}else{w=a+20|0;x=a+16|0;y=a+12|0;a=d;d=e;z=k;A=j;j=q;q=o;o=m;while(1){m=d;B=A;C=j;D=q;E=o;while(1){F=(b[m>>1]|0)+E|0;G=F+D|0;H=G+C|0;I=B-1|0;if((I|0)==0){break}else{m=m+4|0;B=I;C=H;D=G;E=F}}J=d+(A<<1<<1)|0;E=H-(c[w>>2]|0)|0;c[w>>2]=H;D=E-(c[x>>2]|0)|0;c[x>>2]=E;b[a>>1]=((ag(D-(c[y>>2]|0)|0,l)|0)+32768|0)>>>16&65535;c[y>>2]=D;K=c[g>>2]|0;D=z-1|0;if((D|0)==0){break}else{a=a+4|0;d=J;z=D;A=K;j=H;q=G;o=F}}c[i>>2]=K;r=J;s=H;t=G;u=F;v=K}K=e+(f<<1<<1)-r>>1>>>1;c[i>>2]=v-K;if((K|0)==0){L=u;M=t;N=s;c[h>>2]=L;c[n>>2]=M;c[p>>2]=N;return k|0}else{O=u;P=t;Q=s;R=r;S=K}while(1){K=S-1|0;r=(b[R>>1]|0)+O|0;s=r+P|0;t=s+Q|0;if((K|0)==0){L=r;M=s;N=t;break}else{O=r;P=s;Q=t;R=R+4|0;S=K}}c[h>>2]=L;c[n>>2]=M;c[p>>2]=N;return k|0}function rJ(a){a=a|0;var b=0;c[a>>2]=75912;b=c[a+44>>2]|0;if((b|0)!=0){yt(b)}b=c[a+28>>2]|0;if((b|0)!=0){yt(b)}b=c[a+8>>2]|0;if((b|0)==0){return}yt(b);return}function rK(a){a=a|0;var b=0;c[a>>2]=75912;b=c[a+44>>2]|0;if((b|0)!=0){yt(b)}b=c[a+28>>2]|0;if((b|0)!=0){yt(b)}b=c[a+8>>2]|0;if((b|0)!=0){yt(b)}if((a|0)==0){return}yt(a);return}function rL(b,c){b=b|0;c=c|0;var d=0.0,e=0.0,f=0.0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0;do{if((a[741488]|0)==0){if((cR(741488)|0)==0){break}h[9046]=.051458913433319785}}while(0);d=+(b<<1|0)/+(c|0)+-1.0;e=+W(+(1.0-d*d))*4.62;d=e*e*.25;e=d*d*.25;f=d/9.0*e;g=d*.0625*f;i=d/25.0*g;j=d/36.0*i;k=d/49.0*j;l=d*.015625*k;m=d/81.0*l;n=d/100.0*m;o=d/121.0*n;p=d/144.0*o;q=d/169.0*p;r=d/196.0*q;s=d/225.0*r;return+(+h[9046]*(d+1.0+e+f+g+i+j+k+l+m+n+o+p+q+r+s+d*.00390625*s))}function rM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;rI(a+4|0,b,c,d)|0;return rI(a+36|0,b+2|0,c+2|0,d)|0}function rN(a){a=a|0;if((a|0)==0){return}yt(a);return}function rO(a){a=a|0;var b=0;c[a>>2]=74368;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);return}function rP(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=74368;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;yt(e);return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);e=a;yt(e);return}function rQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a+36|0;g=a+40|0;h=d|0;j=d+8|0;k=d;d=a+32|0;while(1){a=c[f>>2]|0;l=f9[c[(c[a>>2]|0)+20>>2]&31](a,c[g>>2]|0,h,j,e)|0;a=(c[e>>2]|0)-k|0;if((be(h|0,1,a|0,c[d>>2]|0)|0)!=(a|0)){m=-1;n=1714;break}if((l|0)==2){m=-1;n=1713;break}else if((l|0)!=1){n=1711;break}}if((n|0)==1714){i=b;return m|0}else if((n|0)==1713){i=b;return m|0}else if((n|0)==1711){m=((a7(c[d>>2]|0)|0)!=0)<<31>>31;i=b;return m|0}return 0}function rR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=(d|0)==-1;L1869:do{if(!k){c[g>>2]=d;if((a[b+44|0]&1)!=0){if((be(g|0,4,1,c[b+32>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}m=f|0;c[h>>2]=m;n=g+4|0;o=b+36|0;p=b+40|0;q=f+8|0;r=f;s=b+32|0;t=g;while(1){u=c[o>>2]|0;v=gt[c[(c[u>>2]|0)+12>>2]&31](u,c[p>>2]|0,t,n,j,m,q,h)|0;if((c[j>>2]|0)==(t|0)){l=-1;w=1731;break}if((v|0)==3){w=1722;break}u=(v|0)==1;if(v>>>0>=2){l=-1;w=1730;break}v=(c[h>>2]|0)-r|0;if((be(m|0,1,v|0,c[s>>2]|0)|0)!=(v|0)){l=-1;w=1729;break}if(u){t=u?c[j>>2]|0:t}else{break L1869}}if((w|0)==1722){if((be(t|0,1,1,c[s>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}else if((w|0)==1729){i=e;return l|0}else if((w|0)==1730){i=e;return l|0}else if((w|0)==1731){i=e;return l|0}}}while(0);l=k?0:d;i=e;return l|0}function rS(a){a=a|0;var b=0;c[a>>2]=74368;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);return}function rT(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=74368;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;yt(e);return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);e=a;yt(e);return}function rU(a){a=a|0;return rX(a,0)|0}function rV(a){a=a|0;return rX(a,1)|0}function rW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=b+52|0;l=(a[k]&1)!=0;if((d|0)==-1){if(l){m=-1;i=e;return m|0}n=c[b+48>>2]|0;a[k]=(n|0)!=-1|0;m=n;i=e;return m|0}n=b+48|0;L1909:do{if(l){c[h>>2]=c[n>>2];o=c[b+36>>2]|0;p=f|0;q=gt[c[(c[o>>2]|0)+12>>2]&31](o,c[b+40>>2]|0,h,h+4|0,j,p,f+8|0,g)|0;if((q|0)==2|(q|0)==1){m=-1;i=e;return m|0}else if((q|0)==3){a[p]=c[n>>2]&255;c[g>>2]=f+1}q=b+32|0;while(1){o=c[g>>2]|0;if(o>>>0<=p>>>0){break L1909}r=o-1|0;c[g>>2]=r;if((eB(a[r]|0,c[q>>2]|0)|0)==-1){m=-1;break}}i=e;return m|0}}while(0);c[n>>2]=d;a[k]=1;m=d;i=e;return m|0}function rX(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=b+52|0;if((a[k]&1)!=0){l=b+48|0;m=c[l>>2]|0;if(!d){n=m;i=e;return n|0}c[l>>2]=-1;a[k]=0;n=m;i=e;return n|0}m=c[b+44>>2]|0;k=(m|0)>1?m:1;L1929:do{if((k|0)>0){m=b+32|0;l=0;while(1){o=b7(c[m>>2]|0)|0;if((o|0)==-1){n=-1;break}a[f+l|0]=o&255;l=l+1|0;if((l|0)>=(k|0)){break L1929}}i=e;return n|0}}while(0);L1936:do{if((a[b+53|0]&1)==0){l=b+40|0;m=b+36|0;o=f|0;p=g+4|0;q=b+32|0;r=k;while(1){s=c[l>>2]|0;t=s;u=c[t>>2]|0;v=c[t+4>>2]|0;t=c[m>>2]|0;w=f+r|0;x=gt[c[(c[t>>2]|0)+16>>2]&31](t,s,o,w,h,g,p,j)|0;if((x|0)==3){y=1775;break}else if((x|0)==2){n=-1;y=1786;break}else if((x|0)!=1){z=r;break L1936}x=c[l>>2]|0;c[x>>2]=u;c[x+4>>2]=v;if((r|0)==8){n=-1;y=1787;break}v=b7(c[q>>2]|0)|0;if((v|0)==-1){n=-1;y=1788;break}a[w]=v&255;r=r+1|0}if((y|0)==1775){c[g>>2]=a[o]|0;z=r;break}else if((y|0)==1786){i=e;return n|0}else if((y|0)==1787){i=e;return n|0}else if((y|0)==1788){i=e;return n|0}}else{c[g>>2]=a[f|0]|0;z=k}}while(0);if(d){d=c[g>>2]|0;c[b+48>>2]=d;n=d;i=e;return n|0}d=b+32|0;b=z;while(1){if((b|0)<=0){break}z=b-1|0;if((eB(a[f+z|0]|0,c[d>>2]|0)|0)==-1){n=-1;y=1784;break}else{b=z}}if((y|0)==1784){i=e;return n|0}n=c[g>>2]|0;i=e;return n|0}function rY(a){a=a|0;var b=0;c[a>>2]=74440;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);return}function rZ(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=74440;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;yt(e);return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);e=a;yt(e);return}function r_(a){a=a|0;tm(740776);tm(740864);tn(740408);tn(740496);return}function r$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;f5[c[(c[b>>2]|0)+24>>2]&255](b)|0;g=c[d>>2]|0;if((c[185092]|0)!=-1){c[f>>2]=740368;c[f+4>>2]=210;c[f+8>>2]=0;st(740368,f)}f=(c[185093]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=ff(4)|0;j=h;c[j>>2]=72472;dr(h|0,79072,408)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=ff(4)|0;j=h;c[j>>2]=72472;dr(h|0,79072,408)}else{h=g;c[b+36>>2]=h;a[b+44|0]=(f5[c[(c[g>>2]|0)+28>>2]&255](h)|0)&1;i=e;return}}function r0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;g=c[d>>2]|0;if((c[185092]|0)!=-1){c[f>>2]=740368;c[f+4>>2]=210;c[f+8>>2]=0;st(740368,f)}f=(c[185093]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=ff(4)|0;j=h;c[j>>2]=72472;dr(h|0,79072,408)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=ff(4)|0;j=h;c[j>>2]=72472;dr(h|0,79072,408)}h=g;j=b+36|0;c[j>>2]=h;f=b+44|0;c[f>>2]=f5[c[(c[g>>2]|0)+24>>2]&255](h)|0;h=c[j>>2]|0;a[b+53|0]=(f5[c[(c[h>>2]|0)+28>>2]&255](h)|0)&1;if((c[f>>2]|0)>8){v6(12064)}else{i=e;return}}function r1(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a+36|0;g=a+40|0;h=d|0;j=d+8|0;k=d;d=a+32|0;while(1){a=c[f>>2]|0;l=f9[c[(c[a>>2]|0)+20>>2]&31](a,c[g>>2]|0,h,j,e)|0;a=(c[e>>2]|0)-k|0;if((be(h|0,1,a|0,c[d>>2]|0)|0)!=(a|0)){m=-1;n=1834;break}if((l|0)==2){m=-1;n=1832;break}else if((l|0)!=1){n=1830;break}}if((n|0)==1834){i=b;return m|0}else if((n|0)==1832){i=b;return m|0}else if((n|0)==1830){m=((a7(c[d>>2]|0)|0)!=0)<<31>>31;i=b;return m|0}return 0}function r2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=(d|0)==-1;L2009:do{if(!k){a[g]=d&255;if((a[b+44|0]&1)!=0){if((be(g|0,1,1,c[b+32>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}m=f|0;c[h>>2]=m;n=g+1|0;o=b+36|0;p=b+40|0;q=f+8|0;r=f;s=b+32|0;t=g;while(1){u=c[o>>2]|0;v=gt[c[(c[u>>2]|0)+12>>2]&31](u,c[p>>2]|0,t,n,j,m,q,h)|0;if((c[j>>2]|0)==(t|0)){l=-1;w=1851;break}if((v|0)==3){w=1841;break}u=(v|0)==1;if(v>>>0>=2){l=-1;w=1852;break}v=(c[h>>2]|0)-r|0;if((be(m|0,1,v|0,c[s>>2]|0)|0)!=(v|0)){l=-1;w=1848;break}if(u){t=u?c[j>>2]|0:t}else{break L2009}}if((w|0)==1841){if((be(t|0,1,1,c[s>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}else if((w|0)==1848){i=e;return l|0}else if((w|0)==1852){i=e;return l|0}else if((w|0)==1851){i=e;return l|0}}}while(0);l=k?0:d;i=e;return l|0}function r3(a){a=a|0;var b=0;c[a>>2]=74440;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);return}function r4(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=74440;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;yt(e);return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);e=a;yt(e);return}function r5(a){a=a|0;return r8(a,0)|0}function r6(a){a=a|0;return r8(a,1)|0}function r7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=b+52|0;l=(a[k]&1)!=0;if((d|0)==-1){if(l){m=-1;i=e;return m|0}n=c[b+48>>2]|0;a[k]=(n|0)!=-1|0;m=n;i=e;return m|0}n=b+48|0;L2049:do{if(l){a[h]=c[n>>2]&255;o=c[b+36>>2]|0;p=f|0;q=gt[c[(c[o>>2]|0)+12>>2]&31](o,c[b+40>>2]|0,h,h+1|0,j,p,f+8|0,g)|0;if((q|0)==3){a[p]=c[n>>2]&255;c[g>>2]=f+1}else if((q|0)==2|(q|0)==1){m=-1;i=e;return m|0}q=b+32|0;while(1){o=c[g>>2]|0;if(o>>>0<=p>>>0){break L2049}r=o-1|0;c[g>>2]=r;if((eB(a[r]|0,c[q>>2]|0)|0)==-1){m=-1;break}}i=e;return m|0}}while(0);c[n>>2]=d;a[k]=1;m=d;i=e;return m|0}function r8(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+32|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=b+52|0;if((a[l]&1)!=0){m=b+48|0;n=c[m>>2]|0;if(!e){o=n;i=f;return o|0}c[m>>2]=-1;a[l]=0;o=n;i=f;return o|0}n=c[b+44>>2]|0;l=(n|0)>1?n:1;L2069:do{if((l|0)>0){n=b+32|0;m=0;while(1){p=b7(c[n>>2]|0)|0;if((p|0)==-1){o=-1;break}a[g+m|0]=p&255;m=m+1|0;if((m|0)>=(l|0)){break L2069}}i=f;return o|0}}while(0);L2076:do{if((a[b+53|0]&1)==0){m=b+40|0;n=b+36|0;p=g|0;q=h+1|0;r=b+32|0;s=l;while(1){t=c[m>>2]|0;u=t;v=c[u>>2]|0;w=c[u+4>>2]|0;u=c[n>>2]|0;x=g+s|0;y=gt[c[(c[u>>2]|0)+16>>2]&31](u,t,p,x,j,h,q,k)|0;if((y|0)==2){o=-1;z=1904;break}else if((y|0)==3){z=1894;break}else if((y|0)!=1){A=s;break L2076}y=c[m>>2]|0;c[y>>2]=v;c[y+4>>2]=w;if((s|0)==8){o=-1;z=1909;break}w=b7(c[r>>2]|0)|0;if((w|0)==-1){o=-1;z=1906;break}a[x]=w&255;s=s+1|0}if((z|0)==1904){i=f;return o|0}else if((z|0)==1906){i=f;return o|0}else if((z|0)==1909){i=f;return o|0}else if((z|0)==1894){a[h]=a[p]|0;A=s;break}}else{a[h]=a[g|0]|0;A=l}}while(0);do{if(e){l=a[h]|0;c[b+48>>2]=l&255;B=l}else{l=b+32|0;k=A;while(1){if((k|0)<=0){z=1901;break}j=k-1|0;if((eB(d[g+j|0]|0|0,c[l>>2]|0)|0)==-1){o=-1;z=1910;break}else{k=j}}if((z|0)==1910){i=f;return o|0}else if((z|0)==1901){B=a[h]|0;break}}}while(0);o=B&255;i=f;return o|0}function r9(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;f5[c[(c[b>>2]|0)+24>>2]&255](b)|0;g=c[d>>2]|0;if((c[185094]|0)!=-1){c[f>>2]=740376;c[f+4>>2]=210;c[f+8>>2]=0;st(740376,f)}f=(c[185095]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=ff(4)|0;j=h;c[j>>2]=72472;dr(h|0,79072,408)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=ff(4)|0;j=h;c[j>>2]=72472;dr(h|0,79072,408)}else{h=g;c[b+36>>2]=h;a[b+44|0]=(f5[c[(c[g>>2]|0)+28>>2]&255](h)|0)&1;i=e;return}}function sa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;g=c[d>>2]|0;if((c[185094]|0)!=-1){c[f>>2]=740376;c[f+4>>2]=210;c[f+8>>2]=0;st(740376,f)}f=(c[185095]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=ff(4)|0;j=h;c[j>>2]=72472;dr(h|0,79072,408)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=ff(4)|0;j=h;c[j>>2]=72472;dr(h|0,79072,408)}h=g;j=b+36|0;c[j>>2]=h;f=b+44|0;c[f>>2]=f5[c[(c[g>>2]|0)+24>>2]&255](h)|0;h=c[j>>2]|0;a[b+53|0]=(f5[c[(c[h>>2]|0)+28>>2]&255](h)|0)&1;if((c[f>>2]|0)>8){v6(12064)}else{i=e;return}}function sb(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+96|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=c[s>>2]|0;c[185030]=74440;l=c[(wC()|0)>>2]|0;c[185031]=l;m=l+4|0;I=c[m>>2]|0,c[m>>2]=I+1,I;yB(740128,0,24);c[185030]=75328;c[185038]=k;c[185040]=740176;c[185042]=-1;a[740172]=0;k=c[185031]|0;m=k+4|0;I=c[m>>2]|0,c[m>>2]=I+1,I;if((c[185094]|0)!=-1){c[e>>2]=740376;c[e+4>>2]=210;c[e+8>>2]=0;st(740376,e)}e=(c[185095]|0)-1|0;l=c[k+8>>2]|0;do{if((c[k+12>>2]|0)-l>>2>>>0>e>>>0){n=c[l+(e<<2)>>2]|0;if((n|0)==0){break}o=n;c[185039]=o;c[185041]=f5[c[(c[n>>2]|0)+24>>2]&255](o)|0;o=c[185039]|0;a[740173]=(f5[c[(c[o>>2]|0)+28>>2]&255](o)|0)&1;if((c[185041]|0)>8){o=ff(8)|0;c[o>>2]=72504;n=o+4|0;p=n;do{if((n|0)!=0){while(1){u=ys(50)|0;if((u|0)!=0){v=1950;break}w=(I=c[185320]|0,c[185320]=I+0,I);if((w|0)==0){break}gs[w&63]()}if((v|0)==1950){c[u+4>>2]=37;c[u>>2]=37;w=u+12|0;c[p>>2]=w;c[u+8>>2]=0;yE(w|0,12064,38)|0;break}w=ff(4)|0;c[w>>2]=72440;dr(w|0,79056,316)}}while(0);dr(o|0,79088,154)}if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)==0){f2[c[(c[k>>2]|0)+8>>2]&1023](k|0)}c[185260]=74708;c[185262]=74728;c[185261]=0;c[185268]=740120;c[185266]=0;c[185267]=0;c[185263]=4098;c[185265]=0;c[185264]=6;yB(741080,0,40);p=c[(wC()|0)>>2]|0;c[185269]=p;n=p+4|0;I=c[n>>2]|0,c[n>>2]=I+1,I;c[185280]=0;c[185281]=-1;n=c[q>>2]|0;c[185006]=74440;p=c[(wC()|0)>>2]|0;c[185007]=p;w=p+4|0;I=c[w>>2]|0,c[w>>2]=I+1,I;yB(740032,0,24);c[185006]=74928;c[185014]=n;n=c[185007]|0;w=n+4|0;I=c[w>>2]|0,c[w>>2]=I+1,I;if((c[185094]|0)!=-1){c[j>>2]=740376;c[j+4>>2]=210;c[j+8>>2]=0;st(740376,j)}p=(c[185095]|0)-1|0;x=c[n+8>>2]|0;do{if((c[n+12>>2]|0)-x>>2>>>0>p>>>0){y=c[x+(p<<2)>>2]|0;if((y|0)==0){break}z=y;if(((I=c[w>>2]|0,c[w>>2]=I+ -1,I)|0)==0){f2[c[(c[n>>2]|0)+8>>2]&1023](n|0)}c[185015]=z;c[185016]=740184;a[740068]=(f5[c[(c[y>>2]|0)+28>>2]&255](z)|0)&1;c[185194]=74612;c[185195]=74632;c[185201]=740024;c[185199]=0;c[185200]=0;c[185196]=4098;c[185198]=0;c[185197]=6;yB(740812,0,40);z=c[(wC()|0)>>2]|0;c[185202]=z;y=z+4|0;I=c[y>>2]|0,c[y>>2]=I+1,I;c[185213]=0;c[185214]=-1;y=c[t>>2]|0;c[185018]=74440;z=c[(wC()|0)>>2]|0;c[185019]=z;A=z+4|0;I=c[A>>2]|0,c[A>>2]=I+1,I;yB(740080,0,24);c[185018]=74928;c[185026]=y;y=c[185019]|0;A=y+4|0;I=c[A>>2]|0,c[A>>2]=I+1,I;if((c[185094]|0)!=-1){c[h>>2]=740376;c[h+4>>2]=210;c[h+8>>2]=0;st(740376,h)}z=(c[185095]|0)-1|0;B=c[y+8>>2]|0;do{if((c[y+12>>2]|0)-B>>2>>>0>z>>>0){C=c[B+(z<<2)>>2]|0;if((C|0)==0){break}D=C;if(((I=c[A>>2]|0,c[A>>2]=I+ -1,I)|0)==0){f2[c[(c[y>>2]|0)+8>>2]&1023](y|0)}c[185027]=D;c[185028]=740192;a[740116]=(f5[c[(c[C>>2]|0)+28>>2]&255](D)|0)&1;c[185238]=74612;c[185239]=74632;c[185245]=740072;c[185243]=0;c[185244]=0;c[185240]=4098;c[185242]=0;c[185241]=6;yB(740988,0,40);D=c[(wC()|0)>>2]|0;c[185246]=D;C=D+4|0;I=c[C>>2]|0,c[C>>2]=I+1,I;c[185257]=0;c[185258]=-1;C=c[(c[(c[185238]|0)-12>>2]|0)+740976>>2]|0;c[185216]=74612;c[185217]=74632;c[185223]=C;c[185221]=(C|0)==0;c[185222]=0;c[185218]=4098;c[185220]=0;c[185219]=6;yB(740900,0,40);C=c[(wC()|0)>>2]|0;c[185224]=C;D=C+4|0;I=c[D>>2]|0,c[D>>2]=I+1,I;c[185235]=0;c[185236]=-1;c[(c[(c[185260]|0)-12>>2]|0)+741112>>2]=740776;D=(c[(c[185238]|0)-12>>2]|0)+740956|0;c[D>>2]=c[D>>2]|8192;c[(c[(c[185238]|0)-12>>2]|0)+741024>>2]=740776;D=c[s>>2]|0;c[184992]=74368;C=c[(wC()|0)>>2]|0;c[184993]=C;E=C+4|0;I=c[E>>2]|0,c[E>>2]=I+1,I;yB(739976,0,24);c[184992]=75256;c[185e3]=D;c[185002]=740200;c[185004]=-1;a[740020]=0;D=c[184993]|0;E=D+4|0;I=c[E>>2]|0,c[E>>2]=I+1,I;if((c[185092]|0)!=-1){c[d>>2]=740368;c[d+4>>2]=210;c[d+8>>2]=0;st(740368,d)}C=(c[185093]|0)-1|0;F=c[D+8>>2]|0;do{if((c[D+12>>2]|0)-F>>2>>>0>C>>>0){G=c[F+(C<<2)>>2]|0;if((G|0)==0){break}H=G;c[185001]=H;c[185003]=f5[c[(c[G>>2]|0)+24>>2]&255](H)|0;H=c[185001]|0;a[740021]=(f5[c[(c[H>>2]|0)+28>>2]&255](H)|0)&1;if((c[185003]|0)>8){H=ff(8)|0;c[H>>2]=72504;G=H+4|0;J=G;do{if((G|0)!=0){while(1){K=ys(50)|0;if((K|0)!=0){v=2025;break}L=(I=c[185320]|0,c[185320]=I+0,I);if((L|0)==0){break}gs[L&63]()}if((v|0)==2025){c[K+4>>2]=37;c[K>>2]=37;L=K+12|0;c[J>>2]=L;c[K+8>>2]=0;yE(L|0,12064,38)|0;break}L=ff(4)|0;c[L>>2]=72440;dr(L|0,79056,316)}}while(0);dr(H|0,79088,154)}if(((I=c[E>>2]|0,c[E>>2]=I+ -1,I)|0)==0){f2[c[(c[D>>2]|0)+8>>2]&1023](D|0)}c[185172]=74660;c[185174]=74680;c[185173]=0;c[185180]=739968;c[185178]=0;c[185179]=0;c[185175]=4098;c[185177]=0;c[185176]=6;yB(740728,0,40);J=c[(wC()|0)>>2]|0;c[185181]=J;G=J+4|0;I=c[G>>2]|0,c[G>>2]=I+1,I;c[185192]=0;c[185193]=-1;G=c[q>>2]|0;c[184968]=74368;J=c[(wC()|0)>>2]|0;c[184969]=J;L=J+4|0;I=c[L>>2]|0,c[L>>2]=I+1,I;yB(739880,0,24);c[184968]=74856;c[184976]=G;G=c[184969]|0;L=G+4|0;I=c[L>>2]|0,c[L>>2]=I+1,I;if((c[185092]|0)!=-1){c[g>>2]=740368;c[g+4>>2]=210;c[g+8>>2]=0;st(740368,g)}J=(c[185093]|0)-1|0;M=c[G+8>>2]|0;do{if((c[G+12>>2]|0)-M>>2>>>0>J>>>0){N=c[M+(J<<2)>>2]|0;if((N|0)==0){break}O=N;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f2[c[(c[G>>2]|0)+8>>2]&1023](G|0)}c[184977]=O;c[184978]=740208;a[739916]=(f5[c[(c[N>>2]|0)+28>>2]&255](O)|0)&1;c[185102]=74564;c[185103]=74584;c[185109]=739872;c[185107]=0;c[185108]=0;c[185104]=4098;c[185106]=0;c[185105]=6;yB(740444,0,40);O=c[(wC()|0)>>2]|0;c[185110]=O;N=O+4|0;I=c[N>>2]|0,c[N>>2]=I+1,I;c[185121]=0;c[185122]=-1;N=c[t>>2]|0;c[184980]=74368;O=c[(wC()|0)>>2]|0;c[184981]=O;P=O+4|0;I=c[P>>2]|0,c[P>>2]=I+1,I;yB(739928,0,24);c[184980]=74856;c[184988]=N;N=c[184981]|0;P=N+4|0;I=c[P>>2]|0,c[P>>2]=I+1,I;if((c[185092]|0)!=-1){c[f>>2]=740368;c[f+4>>2]=210;c[f+8>>2]=0;st(740368,f)}O=(c[185093]|0)-1|0;Q=c[N+8>>2]|0;do{if((c[N+12>>2]|0)-Q>>2>>>0>O>>>0){R=c[Q+(O<<2)>>2]|0;if((R|0)==0){break}S=R;if(((I=c[P>>2]|0,c[P>>2]=I+ -1,I)|0)==0){f2[c[(c[N>>2]|0)+8>>2]&1023](N|0)}c[184989]=S;c[184990]=740216;a[739964]=(f5[c[(c[R>>2]|0)+28>>2]&255](S)|0)&1;c[185146]=74564;c[185147]=74584;c[185153]=739920;c[185151]=0;c[185152]=0;c[185148]=4098;c[185150]=0;c[185149]=6;yB(740620,0,40);S=c[(wC()|0)>>2]|0;c[185154]=S;R=S+4|0;I=c[R>>2]|0,c[R>>2]=I+1,I;c[185165]=0;c[185166]=-1;R=c[(c[(c[185146]|0)-12>>2]|0)+740608>>2]|0;c[185124]=74564;c[185125]=74584;c[185131]=R;c[185129]=(R|0)==0;c[185130]=0;c[185126]=4098;c[185128]=0;c[185127]=6;yB(740532,0,40);R=c[(wC()|0)>>2]|0;c[185132]=R;S=R+4|0;I=c[S>>2]|0,c[S>>2]=I+1,I;c[185143]=0;c[185144]=-1;c[(c[(c[185172]|0)-12>>2]|0)+740760>>2]=740408;S=(c[(c[185146]|0)-12>>2]|0)+740588|0;c[S>>2]=c[S>>2]|8192;c[(c[(c[185146]|0)-12>>2]|0)+740656>>2]=740408;ep(308,741128,r|0)|0;i=b;return}}while(0);N=ff(4)|0;c[N>>2]=72472;dr(N|0,79072,408)}}while(0);G=ff(4)|0;c[G>>2]=72472;dr(G|0,79072,408)}}while(0);D=ff(4)|0;c[D>>2]=72472;dr(D|0,79072,408)}}while(0);y=ff(4)|0;c[y>>2]=72472;dr(y|0,79072,408)}}while(0);n=ff(4)|0;c[n>>2]=72472;dr(n|0,79072,408)}}while(0);b=ff(4)|0;c[b>>2]=72472;dr(b|0,79072,408)}function sc(a){a=a|0;return c[a+4>>2]|0}function sd(a){a=a|0;return c[a+4>>2]|0}function se(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=d;c[a+4>>2]=b;return}function sf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((c[b+4>>2]|0)!=(a|0)){e=0;return e|0}e=(c[b>>2]|0)==(d|0);return e|0}function sg(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=72600;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){yt(e)}if((a|0)!=0){break}return}}while(0);yt(a);return}function sh(a){a=a|0;var b=0;c[a>>2]=72600;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}yt(a);return}function si(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=72504;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){yt(e)}if((a|0)!=0){break}return}}while(0);yt(a);return}function sj(a){a=a|0;var b=0;c[a>>2]=72504;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}yt(a);return}function sk(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=72600;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){yt(e)}if((a|0)!=0){break}return}}while(0);yt(a);return}function sl(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=72600;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){yt(e)}if((a|0)!=0){break}return}}while(0);yt(a);return}function sm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=e|0;gr[c[(c[a>>2]|0)+12>>2]&127](f,a,b);if((c[f+4>>2]|0)!=(c[d+4>>2]|0)){g=0;i=e;return g|0}g=(c[f>>2]|0)==(c[d>>2]|0);i=e;return g|0}function sn(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=72504;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){yt(e)}if((a|0)!=0){break}return}}while(0);yt(a);return}function so(a){a=a|0;var b=0;c[a>>2]=72504;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}yt(a);return}function sp(b){b=b|0;var d=0;if((a[b]&1)==0){return}d=c[b+8>>2]|0;if((d|0)==0){return}yt(d);return}function sq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((b|0)==(d|0)){return}e=a[d]|0;if((e&1)==0){f=d+1|0}else{f=c[d+8>>2]|0}g=e&255;if((g&1|0)==0){h=g>>>1}else{h=c[d+4>>2]|0}d=b;g=b;e=a[g]|0;if((e&1)==0){i=10;j=e}else{e=c[b>>2]|0;i=(e&-2)-1|0;j=e&255}if(i>>>0<h>>>0){e=j&255;if((e&1|0)==0){k=e>>>1}else{k=c[b+4>>2]|0}sz(b,i,h-i|0,k,0,k,h,f);return}if((j&1)==0){l=d+1|0}else{l=c[b+8>>2]|0}yI(l|0,f|0,h|0);a[l+h|0]=0;if((a[g]&1)==0){a[g]=h<<1&255;return}else{c[b+4>>2]=h;return}}function sr(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=yA(d|0)|0;f=b;g=b;h=a[g]|0;if((h&1)==0){i=10;j=h}else{h=c[b>>2]|0;i=(h&-2)-1|0;j=h&255}if(i>>>0<e>>>0){h=j&255;if((h&1|0)==0){k=h>>>1}else{k=c[b+4>>2]|0}sz(b,i,e-i|0,k,0,k,e,d);return}if((j&1)==0){l=f+1|0}else{l=c[b+8>>2]|0}yI(l|0,d|0,e|0);a[l+e|0]=0;if((a[g]&1)==0){a[g]=e<<1&255;return}else{c[b+4>>2]=e;return}}function ss(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)==0){return}e=b;f=a[e]|0;if((f&1)==0){g=10;h=f}else{f=c[b>>2]|0;g=(f&-2)-1|0;h=f&255}f=h&255;if((f&1|0)==0){i=f>>>1}else{i=c[b+4>>2]|0}if((g-i|0)>>>0<d>>>0){sA(b,g,d-g+i|0,i,i,0);j=a[e]|0}else{j=h}if((j&1)==0){k=b+1|0}else{k=c[b+8>>2]|0}yB(k+i|0,0,d|0);j=i+d|0;if((a[e]&1)==0){a[e]=j<<1&255}else{c[b+4>>2]=j}a[k+j|0]=0;return}function st(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d;if((c[a>>2]|0)==1){do{bR(80720,80712)|0;}while((c[a>>2]|0)==1)}if((c[a>>2]|0)!=0){e;return}c[a>>2]=1;f;f=b+4|0;e=(c[b>>2]|0)+(c[f+4>>2]|0)|0;b=c[f>>2]|0;if((b&1|0)==0){g=b}else{g=c[(c[e>>2]|0)+(b-1)>>2]|0}f2[g&1023](e);h;c[a>>2]=-1;i;d9(80720)|0;return}function su(){var a=0,b=0,d=0,e=0,f=0,g=0;a=ff(8)|0;c[a>>2]=72600;b=a+4|0;d=b;if((b|0)==0){e=a;c[e>>2]=72568;dr(a|0,79120,202)}while(1){f=ys(25)|0;if((f|0)!=0){g=2260;break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){g=2254;break}gs[b&63]()}if((g|0)==2254){b=ff(4)|0;c[b>>2]=72440;dr(b|0,79056,316)}else if((g|0)==2260){c[f+4>>2]=12;c[f>>2]=12;g=f+12|0;c[d>>2]=g;c[f+8>>2]=0;yE(g|0,15696,13)|0;e=a;c[e>>2]=72568;dr(a|0,79120,202)}}function sv(){var a=0,b=0,d=0,e=0,f=0,g=0;a=ff(8)|0;c[a>>2]=72600;b=a+4|0;d=b;if((b|0)==0){e=a;c[e>>2]=72536;dr(a|0,79104,202)}while(1){f=ys(25)|0;if((f|0)!=0){g=2281;break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){g=2275;break}gs[b&63]()}if((g|0)==2275){b=ff(4)|0;c[b>>2]=72440;dr(b|0,79056,316)}else if((g|0)==2281){c[f+4>>2]=12;c[f>>2]=12;g=f+12|0;c[d>>2]=g;c[f+8>>2]=0;yE(g|0,15696,13)|0;e=a;c[e>>2]=72536;dr(a|0,79104,202)}}function sw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b;g=a[f]|0;if((g&1)==0){h=10;i=g}else{g=c[b>>2]|0;h=(g&-2)-1|0;i=g&255}g=i&255;if((g&1|0)==0){j=g>>>1}else{j=c[b+4>>2]|0}if((h-j|0)>>>0<e>>>0){sz(b,h,e-h+j|0,j,j,0,e,d);return}if((e|0)==0){return}if((i&1)==0){k=b+1|0}else{k=c[b+8>>2]|0}i=k+j|0;yE(i|0,d|0,e)|0;d=j+e|0;if((a[f]&1)==0){a[f]=d<<1&255}else{c[b+4>>2]=d}a[k+d|0]=0;return}function sx(b){b=b|0;var d=0;if((a[b]&1)==0){return}d=c[b+8>>2]|0;if((d|0)==0){return}yt(d);return}function sy(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=b;e=b;f=a[e]|0;if((f&1)==0){g=10;h=f}else{f=c[b>>2]|0;g=(f&-2)-1|0;h=f&255}f=h&255;i=(f&1|0)==0;if(i){j=f>>>1}else{j=c[b+4>>2]|0}if(j>>>0<11){k=11}else{k=j+16&-16}l=k-1|0;if((l|0)==(g|0)){return}if((l|0)==10){m=d+1|0;n=c[b+8>>2]|0;o=1;p=0}else{q=(k|0)==0?1:k;L2489:do{if(l>>>0>g>>>0){while(1){r=ys(q)|0;if((r|0)!=0){s=r;break L2489}r=(I=c[185320]|0,c[185320]=I+0,I);if((r|0)==0){break}gs[r&63]()}r=ff(4)|0;c[r>>2]=72440;dr(r|0,79056,316)}else{while(1){r=ys(q)|0;if((r|0)!=0){s=r;break L2489}r=(I=c[185320]|0,c[185320]=I+0,I);if((r|0)==0){break}gs[r&63]()}r=ff(4)|0;c[r>>2]=72440;dr(r|0,79056,316)}}while(0);q=h&1;if(q<<24>>24==0){t=d+1|0}else{t=c[b+8>>2]|0}m=s;n=t;o=q<<24>>24!=0;p=1}if(i){u=f>>>1}else{u=c[b+4>>2]|0}f=u+1|0;yE(m|0,n|0,f)|0;if(!(o^1|(n|0)==0)){yt(n)}if(p){c[b>>2]=k|1;c[b+4>>2]=j;c[b+8>>2]=m;return}else{a[e]=j<<1&255;return}}function sz(b,d,e,f,g,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((-3-d|0)>>>0<e>>>0){su()}if((a[b]&1)==0){k=b+1|0}else{k=c[b+8>>2]|0}do{if(d>>>0<2147483631){l=e+d|0;m=d<<1;n=l>>>0<m>>>0?m:l;if(n>>>0<11){o=11;break}o=n+16&-16}else{o=-2}}while(0);e=(o|0)==0?1:o;while(1){p=ys(e)|0;if((p|0)!=0){break}n=(I=c[185320]|0,c[185320]=I+0,I);if((n|0)==0){q=2378;break}gs[n&63]()}if((q|0)==2378){q=ff(4)|0;c[q>>2]=72440;dr(q|0,79056,316)}if((g|0)!=0){yE(p|0,k|0,g)|0}if((i|0)!=0){q=p+g|0;yE(q|0,j|0,i)|0}j=f-h|0;if((j|0)!=(g|0)){f=j-g|0;q=p+(i+g)|0;e=k+(h+g)|0;yE(q|0,e|0,f)|0}if((d|0)==10|(k|0)==0){r=b+8|0;c[r>>2]=p;s=o|1;t=b|0;c[t>>2]=s;u=j+i|0;v=b+4|0;c[v>>2]=u;w=p+u|0;a[w]=0;return}yt(k);r=b+8|0;c[r>>2]=p;s=o|1;t=b|0;c[t>>2]=s;u=j+i|0;v=b+4|0;c[v>>2]=u;w=p+u|0;a[w]=0;return}function sA(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((-3-d|0)>>>0<e>>>0){su()}if((a[b]&1)==0){i=b+1|0}else{i=c[b+8>>2]|0}do{if(d>>>0<2147483631){j=e+d|0;k=d<<1;l=j>>>0<k>>>0?k:j;if(l>>>0<11){m=11;break}m=l+16&-16}else{m=-2}}while(0);e=(m|0)==0?1:m;while(1){n=ys(e)|0;if((n|0)!=0){break}l=(I=c[185320]|0,c[185320]=I+0,I);if((l|0)==0){o=2408;break}gs[l&63]()}if((o|0)==2408){o=ff(4)|0;c[o>>2]=72440;dr(o|0,79056,316)}if((g|0)!=0){yE(n|0,i|0,g)|0}if((f|0)!=(g|0)){o=f-g|0;f=n+(h+g)|0;h=i+g|0;yE(f|0,h|0,o)|0}if((d|0)==10|(i|0)==0){p=b+8|0;c[p>>2]=n;q=m|1;r=b|0;c[r>>2]=q;return}yt(i);p=b+8|0;c[p>>2]=n;q=m|1;r=b|0;c[r>>2]=q;return}function sB(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b;g=a[f]|0;if((g&1)==0){h=1;i=g}else{g=c[b>>2]|0;h=(g&-2)-1|0;i=g&255}if(h>>>0>=e>>>0){if((i&1)==0){j=b+4|0}else{j=c[b+8>>2]|0}g=(e|0)==0;do{if(j-d>>2>>>0<e>>>0){if(g){break}else{k=e}do{k=k-1|0;c[j+(k<<2)>>2]=c[d+(k<<2)>>2];}while((k|0)!=0)}else{if(g){break}else{l=d;m=e;n=j}while(1){o=m-1|0;c[n>>2]=c[l>>2];if((o|0)==0){break}else{l=l+4|0;m=o;n=n+4|0}}}}while(0);c[j+(e<<2)>>2]=0;if((a[f]&1)==0){a[f]=e<<1&255;return}else{c[b+4>>2]=e;return}}if((1073741821-h|0)>>>0<(e-h|0)>>>0){su()}if((i&1)==0){p=b+4|0}else{p=c[b+8>>2]|0}do{if(h>>>0<536870895){i=h<<1;f=i>>>0>e>>>0?i:e;if(f>>>0<2){q=2;break}q=f+4&-4}else{q=1073741822}}while(0);f=q<<2;i=(f|0)==0?1:f;while(1){r=ys(i)|0;if((r|0)!=0){break}f=(I=c[185320]|0,c[185320]=I+0,I);if((f|0)==0){s=2450;break}gs[f&63]()}if((s|0)==2450){s=ff(4)|0;c[s>>2]=72440;dr(s|0,79056,316)}s=r;if((e|0)!=0){r=d;d=e;i=s;while(1){f=d-1|0;c[i>>2]=c[r>>2];if((f|0)==0){break}else{r=r+4|0;d=f;i=i+4|0}}}if(!((h|0)==1|(p|0)==0)){yt(p)}c[b+8>>2]=s;c[b>>2]=q|1;c[b+4>>2]=e;c[s+(e<<2)>>2]=0;return}function sC(a,b){a=a|0;b=b|0;return}function sD(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function sE(a){a=a|0;return 0}function sF(a){a=a|0;return 0}function sG(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=a;c[g>>2]=0;c[g+4>>2]=0;g=a+8|0;c[g>>2]=-1;c[g+4>>2]=-1;return}function sH(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=i;b=d;d=i;i=i+16|0;c[d>>2]=c[b>>2];c[d+4>>2]=c[b+4>>2];c[d+8>>2]=c[b+8>>2];c[d+12>>2]=c[b+12>>2];b=a;c[b>>2]=0;c[b+4>>2]=0;b=a+8|0;c[b>>2]=-1;c[b+4>>2]=-1;i=e;return}function sI(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=74440;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;yt(e);return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);e=a;yt(e);return}function sJ(a){a=a|0;var b=0;c[a>>2]=74440;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);return}function sK(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b;e=a[d]|0;if((e&1)==0){f=1;g=e}else{e=c[b>>2]|0;f=(e&-2)-1|0;g=e&255}e=g&255;h=(e&1|0)==0;if(h){i=e>>>1}else{i=c[b+4>>2]|0}if(i>>>0<2){j=2}else{j=i+4&-4}k=j-1|0;if((k|0)==(f|0)){return}if((k|0)==1){l=b+4|0;m=c[b+8>>2]|0;n=1;o=0}else{p=j<<2;q=(p|0)==0?1:p;L2667:do{if(k>>>0>f>>>0){while(1){p=ys(q)|0;if((p|0)!=0){r=p;break L2667}p=(I=c[185320]|0,c[185320]=I+0,I);if((p|0)==0){break}gs[p&63]()}p=ff(4)|0;c[p>>2]=72440;dr(p|0,79056,316)}else{while(1){p=ys(q)|0;if((p|0)!=0){r=p;break L2667}p=(I=c[185320]|0,c[185320]=I+0,I);if((p|0)==0){break}gs[p&63]()}p=ff(4)|0;c[p>>2]=72440;dr(p|0,79056,316)}}while(0);q=g&1;if(q<<24>>24==0){s=b+4|0}else{s=c[b+8>>2]|0}l=r;m=s;n=q<<24>>24!=0;o=1}q=l;if(h){t=e>>>1}else{t=c[b+4>>2]|0}e=t+1|0;if((e|0)!=0){t=m;h=e;e=q;while(1){l=h-1|0;c[e>>2]=c[t>>2];if((l|0)==0){break}else{t=t+4|0;h=l;e=e+4|0}}}if(!(n^1|(m|0)==0)){yt(m)}if(o){c[b>>2]=j|1;c[b+4>>2]=i;c[b+8>>2]=q;return}else{a[d]=i<<1&255;return}}function sL(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((1073741821-d|0)>>>0<e>>>0){su()}if((a[b]&1)==0){j=b+4|0}else{j=c[b+8>>2]|0}do{if(d>>>0<536870895){k=e+d|0;l=d<<1;m=k>>>0<l>>>0?l:k;if(m>>>0<2){n=2;break}n=m+4&-4}else{n=1073741822}}while(0);e=n<<2;m=(e|0)==0?1:e;while(1){o=ys(m)|0;if((o|0)!=0){break}e=(I=c[185320]|0,c[185320]=I+0,I);if((e|0)==0){p=2545;break}gs[e&63]()}if((p|0)==2545){p=ff(4)|0;c[p>>2]=72440;dr(p|0,79056,316)}p=o;if((g|0)!=0){o=j;m=g;e=p;while(1){k=m-1|0;c[e>>2]=c[o>>2];if((k|0)==0){break}else{o=o+4|0;m=k;e=e+4|0}}}e=f-h|0;if((e|0)!=(g|0)){f=j+(h+g<<2)|0;h=e-g|0;e=p+(i+g<<2)|0;while(1){g=h-1|0;c[e>>2]=c[f>>2];if((g|0)==0){break}else{f=f+4|0;h=g;e=e+4|0}}}if((d|0)==1|(j|0)==0){q=b+8|0;c[q>>2]=p;r=n|1;s=b|0;c[s>>2]=r;return}yt(j);q=b+8|0;c[q>>2]=p;r=n|1;s=b|0;c[s>>2]=r;return}function sM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+48|0;g=f|0;h=f+16|0;j=f+32|0;k=(c[b+24>>2]|0)==0;if(k){c[b+16>>2]=e|1}else{c[b+16>>2]=e}if((c[b+20>>2]&(k&1|e)|0)==0){i=f;return}f=ff(16)|0;do{if((a[741368]|0)==0){if((cR(741368)|0)==0){break}c[141572]=74064}}while(0);e=h;k=j;while(1){l=ys(16)|0;if((l|0)!=0){break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){m=2574;break}gs[b&63]()}if((m|0)==2574){b=ff(4)|0;c[b>>2]=72440;dr(b|0,79056,316)}b=j+8|0;c[b>>2]=l;c[j>>2]=17;n=j+4|0;c[n>>2]=15;yE(l|0,37800,15)|0;a[l+15|0]=0;l=g;o=d[k]|0;if((((o&1|0)==0?o>>>1:c[n>>2]|0)|0)!=0){sw(j,49704,2)}gr[c[(c[141572]|0)+24>>2]&127](g,566288,1);n=a[l]|0;if((n&1)==0){p=g+1|0}else{p=c[g+8>>2]|0}o=n&255;if((o&1|0)==0){q=o>>>1}else{q=c[g+4>>2]|0}sw(j,p,q);do{if((a[l]&1)!=0){q=c[g+8>>2]|0;if((q|0)==0){break}yt(q)}}while(0);c[e>>2]=c[k>>2];c[e+4>>2]=c[k+4>>2];c[e+8>>2]=c[k+8>>2];yB(k|0,0,12);g=f;c[g>>2]=72504;l=f+4|0;q=l;p=a[e]&1;do{if((l|0)==0){r=p}else{if(p<<24>>24==0){s=h+1|0}else{s=c[h+8>>2]|0}e=yA(s|0)|0;j=e+13|0;o=(j|0)==0?1:j;while(1){t=ys(o)|0;if((t|0)!=0){m=2607;break}j=(I=c[185320]|0,c[185320]=I+0,I);if((j|0)==0){break}gs[j&63]()}if((m|0)==2607){o=e+1|0;c[t+4>>2]=e;c[t>>2]=e;j=t+12|0;c[q>>2]=j;c[t+8>>2]=0;yE(j|0,s|0,o)|0;r=p;break}o=ff(4)|0;c[o>>2]=72440;dr(o|0,79056,316)}}while(0);do{if(r<<24>>24!=0){p=c[h+8>>2]|0;if((p|0)==0){break}yt(p)}}while(0);do{if((a[k]&1)!=0){h=c[b>>2]|0;if((h|0)==0){break}yt(h)}}while(0);c[g>>2]=74824;b=f+8|0;k=yN(566288,0,32)|0;h=K;c[b>>2]=k&0|1;c[b+4>>2]=h|0;c[g>>2]=73248;dr(f|0,79664,46)}function sN(a){a=a|0;var b=0,d=0,e=0,f=0;c[a>>2]=73224;b=c[a+40>>2]|0;d=a+32|0;e=a+36|0;if((b|0)!=0){f=b;do{f=f-1|0;gr[c[(c[d>>2]|0)+(f<<2)>>2]&127](0,a,c[(c[e>>2]|0)+(f<<2)>>2]|0);}while((f|0)!=0)}f=c[a+28>>2]|0;b=f+4|0;if(((I=c[b>>2]|0,c[b>>2]=I+ -1,I)|0)==0){f2[c[(c[f>>2]|0)+8>>2]&1023](f)}yt(c[d>>2]|0);yt(c[e>>2]|0);yt(c[a+48>>2]|0);yt(c[a+60>>2]|0);return}function sO(a){a=a|0;return-1|0}function sP(a,b){a=a|0;b=b|0;return-1|0}function sQ(a,b){a=a|0;b=b|0;return-1|0}function sR(a,b){a=a|0;b=b|0;return}function sS(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function sT(a){a=a|0;return 0}function sU(a){a=a|0;return 0}function sV(a){a=a|0;return-1|0}function sW(a,b){a=a|0;b=b|0;return-1|0}function sX(a,b){a=a|0;b=b|0;return-1|0}function sY(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=a;c[g>>2]=0;c[g+4>>2]=0;g=a+8|0;c[g>>2]=-1;c[g+4>>2]=-1;return}function sZ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=i;b=d;d=i;i=i+16|0;c[d>>2]=c[b>>2];c[d+4>>2]=c[b+4>>2];c[d+8>>2]=c[b+8>>2];c[d+12>>2]=c[b+12>>2];b=a;c[b>>2]=0;c[b+4>>2]=0;b=a+8|0;c[b>>2]=-1;c[b+4>>2]=-1;i=e;return}function s_(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;if((e|0)<=0){g=0;return g|0}h=b+12|0;i=b+16|0;j=d;d=0;while(1){k=c[h>>2]|0;if(k>>>0<(c[i>>2]|0)>>>0){c[h>>2]=k+1;l=a[k]|0}else{k=f5[c[(c[f>>2]|0)+40>>2]&255](b)|0;if((k|0)==-1){g=d;m=2660;break}l=k&255}a[j]=l;k=d+1|0;if((k|0)<(e|0)){j=j+1|0;d=k}else{g=k;m=2659;break}}if((m|0)==2659){return g|0}else if((m|0)==2660){return g|0}return 0}function s$(a){a=a|0;var b=0,e=0;if((f5[c[(c[a>>2]|0)+36>>2]&255](a)|0)==-1){b=-1;return b|0}e=a+12|0;a=c[e>>2]|0;c[e>>2]=a+1;b=d[a]|0;return b|0}function s0(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;if((f|0)<=0){h=0;return h|0}i=b+24|0;j=b+28|0;k=0;l=e;while(1){e=c[i>>2]|0;if(e>>>0<(c[j>>2]|0)>>>0){m=a[l]|0;c[i>>2]=e+1;a[e]=m}else{if((gm[c[(c[g>>2]|0)+52>>2]&127](b,d[l]|0)|0)==-1){h=k;n=2674;break}}m=k+1|0;if((m|0)<(f|0)){k=m;l=l+1|0}else{h=m;n=2675;break}}if((n|0)==2674){return h|0}else if((n|0)==2675){return h|0}return 0}function s1(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=74368;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;yt(e);return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);e=a;yt(e);return}function s2(a){a=a|0;var b=0;c[a>>2]=74368;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f2[c[(c[b>>2]|0)+8>>2]&1023](b|0);return}function s3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a;if((d|0)<=0){f=0;return f|0}g=a+12|0;h=a+16|0;i=b;b=0;while(1){j=c[g>>2]|0;if(j>>>0<(c[h>>2]|0)>>>0){c[g>>2]=j+4;k=c[j>>2]|0}else{j=f5[c[(c[e>>2]|0)+40>>2]&255](a)|0;if((j|0)==-1){f=b;l=2695;break}else{k=j}}c[i>>2]=k;j=b+1|0;if((j|0)<(d|0)){i=i+4|0;b=j}else{f=j;l=2696;break}}if((l|0)==2696){return f|0}else if((l|0)==2695){return f|0}return 0}function s4(a){a=a|0;var b=0,d=0;if((f5[c[(c[a>>2]|0)+36>>2]&255](a)|0)==-1){b=-1;return b|0}d=a+12|0;a=c[d>>2]|0;c[d>>2]=a+4;b=c[a>>2]|0;return b|0}function s5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a;if((d|0)<=0){f=0;return f|0}g=a+24|0;h=a+28|0;i=0;j=b;while(1){b=c[g>>2]|0;if(b>>>0<(c[h>>2]|0)>>>0){k=c[j>>2]|0;c[g>>2]=b+4;c[b>>2]=k}else{if((gm[c[(c[e>>2]|0)+52>>2]&127](a,c[j>>2]|0)|0)==-1){f=i;l=2711;break}}k=i+1|0;if((k|0)<(d|0)){i=k;j=j+4|0}else{f=k;l=2709;break}}if((l|0)==2709){return f|0}else if((l|0)==2711){return f|0}return 0}function s6(a){a=a|0;sN(a+8|0);if((a|0)==0){return}yt(a);return}function s7(a){a=a|0;sN(a+8|0);return}function s8(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;sN(b+(d+8)|0);if((a|0)==0){return}yt(a);return}function s9(a){a=a|0;sN(a+((c[(c[a>>2]|0)-12>>2]|0)+8)|0);return}function ta(a){a=a|0;sN(a+8|0);if((a|0)==0){return}yt(a);return}function tb(a){a=a|0;sN(a+8|0);return}function tc(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;sN(b+(d+8)|0);if((a|0)==0){return}yt(a);return}function td(a){a=a|0;sN(a+((c[(c[a>>2]|0)-12>>2]|0)+8)|0);return}function te(a){a=a|0;sN(a+4|0);if((a|0)==0){return}yt(a);return}function tf(a){a=a|0;sN(a+4|0);return}function tg(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;sN(b+(d+4)|0);if((a|0)==0){return}yt(a);return}function th(a){a=a|0;sN(a+((c[(c[a>>2]|0)-12>>2]|0)+4)|0);return}function ti(a){a=a|0;sN(a+4|0);if((a|0)==0){return}yt(a);return}function tj(a){a=a|0;sN(a+4|0);return}function tk(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;sN(b+(d+4)|0);if((a|0)==0){return}yt(a);return}function tl(a){a=a|0;sN(a+((c[(c[a>>2]|0)-12>>2]|0)+4)|0);return}function tm(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=b;g=c[(c[f>>2]|0)-12>>2]|0;h=b;if((c[h+(g+24)>>2]|0)==0){i=d;return}j=e|0;a[j]=0;c[e+4>>2]=b;do{if((c[h+(g+16)>>2]|0)==0){b=c[h+(g+72)>>2]|0;if((b|0)==0){k=g}else{tm(b);k=c[(c[f>>2]|0)-12>>2]|0}a[j]=1;b=c[h+(k+24)>>2]|0;if((f5[c[(c[b>>2]|0)+24>>2]&255](b)|0)!=-1){break}b=c[(c[f>>2]|0)-12>>2]|0;sM(h+b|0,c[h+(b+16)>>2]|1)}}while(0);to(e);i=d;return}function tn(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=b;g=c[(c[f>>2]|0)-12>>2]|0;h=b;if((c[h+(g+24)>>2]|0)==0){i=d;return}j=e|0;a[j]=0;c[e+4>>2]=b;do{if((c[h+(g+16)>>2]|0)==0){b=c[h+(g+72)>>2]|0;if((b|0)==0){k=g}else{tn(b);k=c[(c[f>>2]|0)-12>>2]|0}a[j]=1;b=c[h+(k+24)>>2]|0;if((f5[c[(c[b>>2]|0)+24>>2]&255](b)|0)!=-1){break}b=c[(c[f>>2]|0)-12>>2]|0;sM(h+b|0,c[h+(b+16)>>2]|1)}}while(0);tG(e);i=d;return}function to(a){a=a|0;var b=0,d=0,e=0;b=a+4|0;a=c[b>>2]|0;d=c[(c[a>>2]|0)-12>>2]|0;e=a;if((c[e+(d+24)>>2]|0)==0){return}if((c[e+(d+16)>>2]|0)!=0){return}if((c[e+(d+4)>>2]&8192|0)==0){return}if(c4()|0){return}d=c[b>>2]|0;e=c[d+((c[(c[d>>2]|0)-12>>2]|0)+24)>>2]|0;if((f5[c[(c[e>>2]|0)+24>>2]&255](e)|0)!=-1){return}e=c[b>>2]|0;b=c[(c[e>>2]|0)-12>>2]|0;d=e;sM(d+b|0,c[d+(b+16)>>2]|1);return}function tp(a){a=a|0;return 47456|0}function tq(a){a=a|0;return}function tr(a){a=a|0;return}function ts(a){a=a|0;return}function tt(a){a=a|0;return}function tu(a){a=a|0;return}function tv(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;L2991:do{if((e|0)==(f|0)){g=c}else{b=c;h=e;while(1){if((b|0)==(d|0)){i=-1;j=2832;break}k=a[b]|0;l=a[h]|0;if(k<<24>>24<l<<24>>24){i=-1;j=2831;break}if(l<<24>>24<k<<24>>24){i=1;j=2833;break}k=b+1|0;l=h+1|0;if((l|0)==(f|0)){g=k;break L2991}else{b=k;h=l}}if((j|0)==2832){return i|0}else if((j|0)==2833){return i|0}else if((j|0)==2831){return i|0}}}while(0);i=(g|0)!=(d|0)|0;return i|0}function tw(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((c|0)==(d|0)){e=0;return e|0}else{f=c;g=0}while(1){c=(a[f]|0)+(g<<4)|0;b=c&-268435456;h=(b>>>24|b)^c;c=f+1|0;if((c|0)==(d|0)){e=h;break}else{f=c;g=h}}return e|0}function tx(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;L3010:do{if((e|0)==(f|0)){g=b}else{a=b;h=e;while(1){if((a|0)==(d|0)){i=-1;j=2850;break}k=c[a>>2]|0;l=c[h>>2]|0;if((k|0)<(l|0)){i=-1;j=2849;break}if((l|0)<(k|0)){i=1;j=2848;break}k=a+4|0;l=h+4|0;if((l|0)==(f|0)){g=k;break L3010}else{a=k;h=l}}if((j|0)==2850){return i|0}else if((j|0)==2848){return i|0}else if((j|0)==2849){return i|0}}}while(0);i=(g|0)!=(d|0)|0;return i|0}function ty(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b|0)==(d|0)){e=0;return e|0}else{f=b;g=0}while(1){b=(c[f>>2]|0)+(g<<4)|0;a=b&-268435456;h=(a>>>24|a)^b;b=f+4|0;if((b|0)==(d|0)){e=h;break}else{f=b;g=h}}return e|0}function tz(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=72504;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){yt(e)}if((a|0)!=0){break}return}}while(0);yt(a);return}function tA(a){a=a|0;var b=0;c[a>>2]=72504;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}yt(a);return}function tB(a){a=a|0;sN(a);if((a|0)==0){return}yt(a);return}function tC(a){a=a|0;if((a|0)==0){return}yt(a);return}function tD(a){a=a|0;if((a|0)==0){return}yt(a);return}function tE(a){a=a|0;if((a|0)==0){return}yt(a);return}function tF(a){a=a|0;if((a|0)==0){return}yt(a);return}function tG(a){a=a|0;var b=0,d=0,e=0;b=a+4|0;a=c[b>>2]|0;d=c[(c[a>>2]|0)-12>>2]|0;e=a;if((c[e+(d+24)>>2]|0)==0){return}if((c[e+(d+16)>>2]|0)!=0){return}if((c[e+(d+4)>>2]&8192|0)==0){return}if(c4()|0){return}d=c[b>>2]|0;e=c[d+((c[(c[d>>2]|0)-12>>2]|0)+24)>>2]|0;if((f5[c[(c[e>>2]|0)+24>>2]&255](e)|0)!=-1){return}e=c[b>>2]|0;b=c[(c[e>>2]|0)-12>>2]|0;d=e;sM(d+b|0,c[d+(b+16)>>2]|1);return}function tH(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==1){while(1){f=ys(48)|0;if((f|0)!=0){g=2940;break}d=(I=c[185320]|0,c[185320]=I+0,I);if((d|0)==0){g=2937;break}gs[d&63]()}if((g|0)==2940){c[b+8>>2]=f;c[b>>2]=49;c[b+4>>2]=35;yE(f|0,51112,35)|0;a[f+35|0]=0;return}else if((g|0)==2937){f=ff(4)|0;c[f>>2]=72440;dr(f|0,79056,316)}}f=es(e|0)|0;e=yA(f|0)|0;if((e|0)==-1){su()}do{if(e>>>0<11){a[b]=e<<1&255;h=b+1|0}else{d=e+16&-16;i=(d|0)==0?1:d;while(1){j=ys(i)|0;if((j|0)!=0){g=2928;break}k=(I=c[185320]|0,c[185320]=I+0,I);if((k|0)==0){break}gs[k&63]()}if((g|0)==2928){c[b+8>>2]=j;c[b>>2]=d|1;c[b+4>>2]=e;h=j;break}i=ff(4)|0;c[i>>2]=72440;dr(i|0,79056,316)}}while(0);yE(h|0,f|0,e)|0;a[h+e|0]=0;return}function tI(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=e;g=f-d|0;if((g|0)==-1){su()}do{if(g>>>0<11){a[b]=g<<1&255;h=b+1|0}else{i=g+16&-16;j=(i|0)==0?1:i;while(1){k=ys(j)|0;if((k|0)!=0){l=2959;break}m=(I=c[185320]|0,c[185320]=I+0,I);if((m|0)==0){break}gs[m&63]()}if((l|0)==2959){c[b+8>>2]=k;c[b>>2]=i|1;c[b+4>>2]=g;h=k;break}j=ff(4)|0;c[j>>2]=72440;dr(j|0,79056,316)}}while(0);if((e|0)==(f|0)){n=h;a[n]=0;return}k=-d|0;d=h;g=e;while(1){a[d]=a[g]|0;e=g+1|0;if((e|0)==(f|0)){break}else{d=d+1|0;g=e}}n=h+(f+k)|0;a[n]=0;return}function tJ(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=e;g=f-d|0;h=g>>2;if(h>>>0>1073741822){su()}do{if(h>>>0<2){a[b]=g>>>1&255;i=b+4|0}else{j=h+4&-4;k=j<<2;l=(k|0)==0?1:k;while(1){m=ys(l)|0;if((m|0)!=0){n=2982;break}k=(I=c[185320]|0,c[185320]=I+0,I);if((k|0)==0){break}gs[k&63]()}if((n|0)==2982){l=m;c[b+8>>2]=l;c[b>>2]=j|1;c[b+4>>2]=h;i=l;break}l=ff(4)|0;c[l>>2]=72440;dr(l|0,79056,316)}}while(0);if((e|0)==(f|0)){o=i;c[o>>2]=0;return}h=f-4+(-d|0)|0;d=i;b=e;while(1){c[d>>2]=c[b>>2];e=b+4|0;if((e|0)==(f|0)){break}else{d=d+4|0;b=e}}o=i+((h>>>2)+1<<2)|0;c[o>>2]=0;return}function tK(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+88|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=k|0;m=k+16|0;n=k+32|0;o=k+40|0;p=k+48|0;q=k+56|0;r=k+64|0;if((c[g+4>>2]&1|0)==0){c[n>>2]=-1;s=c[(c[d>>2]|0)+16>>2]|0;t=e|0;c[p>>2]=c[t>>2];c[q>>2]=c[f>>2];gi[s&127](o,d,p,q,g,h,n);q=c[o>>2]|0;c[t>>2]=q;t=c[n>>2]|0;if((t|0)==0){a[j]=0}else if((t|0)==1){a[j]=1}else{a[j]=1;c[h>>2]=4}c[b>>2]=q;i=k;return}q=g+28|0;g=c[q>>2]|0;t=g+4|0;I=c[t>>2]|0,c[t>>2]=I+1,I;if((c[185170]|0)!=-1){c[m>>2]=740680;c[m+4>>2]=210;c[m+8>>2]=0;st(740680,m)}m=(c[185171]|0)-1|0;n=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-n>>2>>>0>m>>>0){o=c[n+(m<<2)>>2]|0;if((o|0)==0){break}p=o;if(((I=c[t>>2]|0,c[t>>2]=I+ -1,I)|0)==0){f2[c[(c[g>>2]|0)+8>>2]&1023](g)}o=c[q>>2]|0;d=o+4|0;I=c[d>>2]|0,c[d>>2]=I+1,I;if((c[185074]|0)!=-1){c[l>>2]=740296;c[l+4>>2]=210;c[l+8>>2]=0;st(740296,l)}s=(c[185075]|0)-1|0;u=c[o+8>>2]|0;do{if((c[o+12>>2]|0)-u>>2>>>0>s>>>0){v=c[u+(s<<2)>>2]|0;if((v|0)==0){break}w=v;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)==0){f2[c[(c[o>>2]|0)+8>>2]&1023](o)}x=r|0;y=v;f3[c[(c[y>>2]|0)+24>>2]&1023](x,w);v=r+12|0;f3[c[(c[y>>2]|0)+28>>2]&1023](v,w);a[j]=(tL(e,c[f>>2]|0,x,r+24|0,p,h,1)|0)==(x|0)|0;c[b>>2]=c[e>>2];do{if((a[v]&1)!=0){x=c[r+20>>2]|0;if((x|0)==0){break}yt(x)}}while(0);if((a[r]&1)==0){i=k;return}v=c[r+8>>2]|0;if((v|0)==0){i=k;return}yt(v);i=k;return}}while(0);p=ff(4)|0;c[p>>2]=72472;dr(p|0,79072,408)}}while(0);k=ff(4)|0;c[k>>2]=72472;dr(k|0,79072,408)}function tL(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;l=i;i=i+104|0;m=(g-f|0)/12|0;n=l|0;do{if(m>>>0>100){o=ys(m)|0;if((o|0)!=0){p=o;q=o;break}o=ff(4)|0;c[o>>2]=72440;dr(o|0,79056,316);return 0}else{p=n;q=0}}while(0);n=(f|0)==(g|0);if(n){r=m;s=0}else{o=m;m=0;t=p;u=f;while(1){v=d[u]|0;if((v&1|0)==0){w=v>>>1}else{w=c[u+4>>2]|0}if((w|0)==0){a[t]=2;x=m+1|0;y=o-1|0}else{a[t]=1;x=m;y=o}v=u+12|0;if((v|0)==(g|0)){r=y;s=x;break}else{o=y;m=x;t=t+1|0;u=v}}}u=b|0;b=h;t=0;x=s;s=r;r=e;L3226:while(1){e=(s|0)!=0;m=t;y=r;while(1){o=c[u>>2]|0;do{if((o|0)==0){z=0}else{if((c[o+12>>2]|0)!=(c[o+16>>2]|0)){z=o;break}if((f5[c[(c[o>>2]|0)+36>>2]&255](o)|0)==-1){c[u>>2]=0;z=0;break}else{z=c[u>>2]|0;break}}}while(0);o=(z|0)==0;if((y|0)==0){A=z;B=0}else{if((c[y+12>>2]|0)==(c[y+16>>2]|0)){C=(f5[c[(c[y>>2]|0)+36>>2]&255](y)|0)==-1?0:y}else{C=y}A=c[u>>2]|0;B=C}D=(B|0)==0;if(!((o^D)&e)){break L3226}o=c[A+12>>2]|0;if((o|0)==(c[A+16>>2]|0)){E=(f5[c[(c[A>>2]|0)+36>>2]&255](A)|0)&255}else{E=a[o]|0}if(k){F=E}else{F=gm[c[(c[b>>2]|0)+12>>2]&127](h,E)|0}G=m+1|0;if(n){m=G;y=B}else{break}}L3255:do{if(k){y=s;e=x;o=p;w=0;v=f;while(1){do{if((a[o]|0)==1){H=a[v]|0;if((H&1)==0){I=v+1|0}else{I=c[v+8>>2]|0}if(F<<24>>24!=(a[I+m|0]|0)){a[o]=0;J=w;K=e;L=y-1|0;break}M=H&255;if((M&1|0)==0){N=M>>>1}else{N=c[v+4>>2]|0}if((N|0)!=(G|0)){J=1;K=e;L=y;break}a[o]=2;J=1;K=e+1|0;L=y-1|0}else{J=w;K=e;L=y}}while(0);M=v+12|0;if((M|0)==(g|0)){O=L;P=K;Q=J;break L3255}y=L;e=K;o=o+1|0;w=J;v=M}}else{v=s;w=x;o=p;e=0;y=f;while(1){do{if((a[o]|0)==1){M=y;if((a[M]&1)==0){R=y+1|0}else{R=c[y+8>>2]|0}if(F<<24>>24!=(gm[c[(c[b>>2]|0)+12>>2]&127](h,a[R+m|0]|0)|0)<<24>>24){a[o]=0;S=e;T=w;U=v-1|0;break}H=d[M]|0;if((H&1|0)==0){V=H>>>1}else{V=c[y+4>>2]|0}if((V|0)!=(G|0)){S=1;T=w;U=v;break}a[o]=2;S=1;T=w+1|0;U=v-1|0}else{S=e;T=w;U=v}}while(0);H=y+12|0;if((H|0)==(g|0)){O=U;P=T;Q=S;break L3255}v=U;w=T;o=o+1|0;e=S;y=H}}}while(0);if(!Q){t=G;x=P;s=O;r=B;continue}m=c[u>>2]|0;y=m+12|0;e=c[y>>2]|0;if((e|0)==(c[m+16>>2]|0)){o=c[(c[m>>2]|0)+40>>2]|0;f5[o&255](m)|0}else{c[y>>2]=e+1}if((O+P|0)>>>0<2){t=G;x=P;s=O;r=B;continue}else{W=P;X=p;Y=f}while(1){do{if((a[X]|0)==2){e=d[Y]|0;if((e&1|0)==0){Z=e>>>1}else{Z=c[Y+4>>2]|0}if((Z|0)==(G|0)){_=W;break}a[X]=0;_=W-1|0}else{_=W}}while(0);e=Y+12|0;if((e|0)==(g|0)){t=G;x=_;s=O;r=B;continue L3226}else{W=_;X=X+1|0;Y=e}}}do{if((A|0)==0){$=0}else{if((c[A+12>>2]|0)!=(c[A+16>>2]|0)){$=A;break}if((f5[c[(c[A>>2]|0)+36>>2]&255](A)|0)==-1){c[u>>2]=0;$=0;break}else{$=c[u>>2]|0;break}}}while(0);u=($|0)==0;do{if(D){aa=3134}else{if((c[B+12>>2]|0)!=(c[B+16>>2]|0)){if(u){break}else{aa=3136;break}}if((f5[c[(c[B>>2]|0)+36>>2]&255](B)|0)==-1){aa=3134;break}if(!u){aa=3136}}}while(0);if((aa|0)==3134){if(u){aa=3136}}if((aa|0)==3136){c[j>>2]=c[j>>2]|2}L3330:do{if(n){aa=3141}else{u=f;B=p;while(1){if((a[B]|0)==2){ab=u;break L3330}D=u+12|0;if((D|0)==(g|0)){aa=3141;break L3330}u=D;B=B+1|0}}}while(0);if((aa|0)==3141){c[j>>2]=c[j>>2]|4;ab=g}if((q|0)==0){i=l;return ab|0}yt(q);i=l;return ab|0}function tM(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0;n=c[g>>2]|0;o=(n|0)==(f|0);do{if(o){p=(a[m+24|0]|0)==b<<24>>24;if(!p){if((a[m+25|0]|0)!=b<<24>>24){break}}c[g>>2]=f+1;a[f]=p?43:45;c[h>>2]=0;q=0;return q|0}}while(0);p=d[j]|0;if((p&1|0)==0){r=p>>>1}else{r=c[j+4>>2]|0}if((r|0)!=0&b<<24>>24==i<<24>>24){i=c[l>>2]|0;if((i-k|0)>=160){q=0;return q|0}k=c[h>>2]|0;c[l>>2]=i+4;c[i>>2]=k;c[h>>2]=0;q=0;return q|0}k=m+26|0;i=m;while(1){if((i|0)==(k|0)){s=k;break}if((a[i]|0)==b<<24>>24){s=i;break}else{i=i+1|0}}i=s-m|0;if((i|0)>23){q=-1;return q|0}do{if((e|0)==8|(e|0)==10){if((i|0)<(e|0)){break}else{q=-1}return q|0}else if((e|0)==16){if((i|0)<22){break}if(o){q=-1;return q|0}if((n-f|0)>=3){q=-1;return q|0}if((a[n-1|0]|0)!=48){q=-1;return q|0}c[h>>2]=0;m=a[80728+i|0]|0;s=c[g>>2]|0;c[g>>2]=s+1;a[s]=m;q=0;return q|0}}while(0);f=a[80728+i|0]|0;c[g>>2]=n+1;a[n]=f;c[h>>2]=(c[h>>2]|0)+1;q=0;return q|0}function tN(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+72|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+32|0;n=e+40|0;o=e+56|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==64){v=8}else if((u|0)==0){v=0}else{v=10}u=l|0;tP(n,c[h+28>>2]|0,u,m);yB(p|0,0,12);h=o;ss(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=a[m]|0;m=o+8|0;C=w;w=c[z>>2]|0;L3396:while(1){do{if((w|0)==0){D=0}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){D=w;break}if((f5[c[(c[w>>2]|0)+36>>2]&255](w)|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;F=c[f>>2]|0;do{if((F|0)==0){G=3201}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L3396}}if((f5[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[f>>2]=0;G=3201;break}else{if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L3396}}}}while(0);if((G|0)==3201){G=0;if(E){J=C;K=0;L=1;M=0;N=1;break}else{H=0;I=1}}F=(c[q>>2]|0)-C|0;O=a[p]|0;P=O&255;if((F|0)==(((P&1|0)==0?P>>>1:c[A>>2]|0)|0)){P=F<<1;do{if(F>>>0<P>>>0){ss(o,F)}else{if((O&1)==0){a[h+1+P|0]=0;a[p]=F<<2&255;break}else{a[(c[m>>2]|0)+P|0]=0;c[A>>2]=P;break}}}while(0);P=a[p]|0;if((P&1)==0){Q=10;R=P}else{P=c[g>>2]|0;Q=(P&-2)-1|0;R=P&255}P=R&255;O=(P&1|0)==0?P>>>1:c[A>>2]|0;do{if(O>>>0<Q>>>0){ss(o,Q-O|0)}else{if((R&1)==0){a[h+1+Q|0]=0;a[p]=Q<<1&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[A>>2]=Q;break}}}while(0);if((a[p]&1)==0){S=x}else{S=c[y>>2]|0}c[q>>2]=S+F;T=S}else{T=C}O=D+12|0;P=c[O>>2]|0;U=D+16|0;if((P|0)==(c[U>>2]|0)){V=(f5[c[(c[D>>2]|0)+36>>2]&255](D)|0)&255}else{V=a[P]|0}if((tM(V,v,T,q,t,B,n,l,s,u)|0)!=0){J=T;K=H;L=I;M=D;N=E;break}P=c[O>>2]|0;if((P|0)==(c[U>>2]|0)){U=c[(c[D>>2]|0)+40>>2]|0;f5[U&255](D)|0;C=T;w=D;continue}else{c[O>>2]=P+1;C=T;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){W=w>>>1}else{W=c[n+4>>2]|0}do{if((W|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}T=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=T}}while(0);c[k>>2]=tO(J,c[q>>2]|0,j,v)|0;tQ(n,l,c[s>>2]|0,j);do{if(N){X=0}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){X=M;break}if((f5[c[(c[M>>2]|0)+36>>2]&255](M)|0)!=-1){X=M;break}c[z>>2]=0;X=0}}while(0);z=(X|0)==0;L3464:do{if(L){G=3253}else{do{if((c[K+12>>2]|0)==(c[K+16>>2]|0)){if((f5[c[(c[K>>2]|0)+36>>2]&255](K)|0)!=-1){break}c[f>>2]=0;G=3253;break L3464}}while(0);if(!(z^(K|0)==0)){G=3255}}}while(0);if((G|0)==3253){if(z){G=3255}}if((G|0)==3255){c[j>>2]=c[j>>2]|2}c[b>>2]=X;do{if((a[p]&1)!=0){X=c[m>>2]|0;if((X|0)==0){break}yt(X)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}yt(D);i=e;return}function tO(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}k=c[(er()|0)>>2]|0;c[(er()|0)>>2]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=eV(b|0,h|0,f|0,c[141570]|0)|0;f=K;b=c[(er()|0)>>2]|0;if((b|0)==0){c[(er()|0)>>2]=k}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=-1;h=0;if((b|0)==34|((f|0)<(d|0)|(f|0)==(d|0)&l>>>0<-2147483648>>>0)|((f|0)>(h|0)|(f|0)==(h|0)&l>>>0>2147483647>>>0)){c[e>>2]=4;e=0;j=(f|0)>(e|0)|(f|0)==(e|0)&l>>>0>0>>>0?2147483647:-2147483648;i=g;return j|0}else{j=l;i=g;return j|0}return 0}function tP(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=d+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;if((c[185170]|0)!=-1){c[j>>2]=740680;c[j+4>>2]=210;c[j+8>>2]=0;st(740680,j)}j=(c[185171]|0)-1|0;l=d+12|0;m=d+8|0;n=c[m>>2]|0;do{if((c[l>>2]|0)-n>>2>>>0>j>>>0){o=c[n+(j<<2)>>2]|0;if((o|0)==0){break}p=o;q=c[(c[o>>2]|0)+32>>2]|0;gq[q&31](p,80728,80754,e)|0;if((c[185074]|0)!=-1){c[h>>2]=740296;c[h+4>>2]=210;c[h+8>>2]=0;st(740296,h)}p=(c[185075]|0)-1|0;q=c[m>>2]|0;do{if((c[l>>2]|0)-q>>2>>>0>p>>>0){o=c[q+(p<<2)>>2]|0;if((o|0)==0){break}r=o;a[f]=f5[c[(c[o>>2]|0)+16>>2]&255](r)|0;f3[c[(c[o>>2]|0)+20>>2]&1023](b,r);if(((I=c[k>>2]|0,c[k>>2]=I+ -1,I)|0)!=0){i=g;return}f2[c[(c[d>>2]|0)+8>>2]&1023](d);i=g;return}}while(0);p=ff(4)|0;c[p>>2]=72472;dr(p|0,79072,408)}}while(0);g=ff(4)|0;c[g>>2]=72472;dr(g|0,79072,408)}function tQ(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=b;h=b;i=a[h]|0;j=i&255;if((j&1|0)==0){k=j>>>1}else{k=c[b+4>>2]|0}if((k|0)==0){return}do{if((d|0)==(e|0)){l=i}else{k=e-4|0;if(k>>>0>d>>>0){m=d;n=k}else{l=i;break}do{k=c[m>>2]|0;c[m>>2]=c[n>>2];c[n>>2]=k;m=m+4|0;n=n-4|0;}while(m>>>0<n>>>0);l=a[h]|0}}while(0);if((l&1)==0){o=g+1|0}else{o=c[b+8>>2]|0}g=l&255;if((g&1|0)==0){p=g>>>1}else{p=c[b+4>>2]|0}b=e-4|0;e=a[o]|0;g=e<<24>>24;l=e<<24>>24<1|e<<24>>24==127;L3555:do{if(b>>>0>d>>>0){e=o+p|0;h=o;n=d;m=g;i=l;while(1){if(!i){if((m|0)!=(c[n>>2]|0)){break}}k=(e-h|0)>1?h+1|0:h;j=n+4|0;q=a[k]|0;r=q<<24>>24;s=q<<24>>24<1|q<<24>>24==127;if(j>>>0<b>>>0){h=k;n=j;m=r;i=s}else{t=r;u=s;break L3555}}c[f>>2]=4;return}else{t=g;u=l}}while(0);if(u){return}u=c[b>>2]|0;if(!(t>>>0<u>>>0|(u|0)==0)){return}c[f>>2]=4;return}function tR(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+72|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+32|0;n=e+40|0;o=e+56|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==0){v=0}else if((u|0)==8){v=16}else if((u|0)==64){v=8}else{v=10}u=l|0;tP(n,c[h+28>>2]|0,u,m);yB(p|0,0,12);h=o;ss(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=a[m]|0;m=o+8|0;C=w;w=c[z>>2]|0;L3583:while(1){do{if((w|0)==0){D=0}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){D=w;break}if((f5[c[(c[w>>2]|0)+36>>2]&255](w)|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;F=c[f>>2]|0;do{if((F|0)==0){G=3357}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){if(E){H=F;I=0;break}else{J=C;L=F;M=0;N=D;O=0;break L3583}}if((f5[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[f>>2]=0;G=3357;break}else{if(E){H=F;I=0;break}else{J=C;L=F;M=0;N=D;O=0;break L3583}}}}while(0);if((G|0)==3357){G=0;if(E){J=C;L=0;M=1;N=0;O=1;break}else{H=0;I=1}}F=(c[q>>2]|0)-C|0;P=a[p]|0;Q=P&255;if((F|0)==(((Q&1|0)==0?Q>>>1:c[A>>2]|0)|0)){Q=F<<1;do{if(F>>>0<Q>>>0){ss(o,F)}else{if((P&1)==0){a[h+1+Q|0]=0;a[p]=F<<2&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[A>>2]=Q;break}}}while(0);Q=a[p]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[g>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[A>>2]|0;do{if(P>>>0<R>>>0){ss(o,R-P|0)}else{if((S&1)==0){a[h+1+R|0]=0;a[p]=R<<1&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[A>>2]=R;break}}}while(0);if((a[p]&1)==0){T=x}else{T=c[y>>2]|0}c[q>>2]=T+F;U=T}else{U=C}P=D+12|0;Q=c[P>>2]|0;V=D+16|0;if((Q|0)==(c[V>>2]|0)){W=(f5[c[(c[D>>2]|0)+36>>2]&255](D)|0)&255}else{W=a[Q]|0}if((tM(W,v,U,q,t,B,n,l,s,u)|0)!=0){J=U;L=H;M=I;N=D;O=E;break}Q=c[P>>2]|0;if((Q|0)==(c[V>>2]|0)){V=c[(c[D>>2]|0)+40>>2]|0;f5[V&255](D)|0;C=U;w=D;continue}else{c[P>>2]=Q+1;C=U;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){X=w>>>1}else{X=c[n+4>>2]|0}do{if((X|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}U=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=U}}while(0);t=tS(J,c[q>>2]|0,j,v)|0;c[k>>2]=t;c[k+4>>2]=K;tQ(n,l,c[s>>2]|0,j);do{if(O){Y=0}else{if((c[N+12>>2]|0)!=(c[N+16>>2]|0)){Y=N;break}if((f5[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){Y=N;break}c[z>>2]=0;Y=0}}while(0);z=(Y|0)==0;L3651:do{if(M){G=3409}else{do{if((c[L+12>>2]|0)==(c[L+16>>2]|0)){if((f5[c[(c[L>>2]|0)+36>>2]&255](L)|0)!=-1){break}c[f>>2]=0;G=3409;break L3651}}while(0);if(!(z^(L|0)==0)){G=3411}}}while(0);if((G|0)==3409){if(z){G=3411}}if((G|0)==3411){c[j>>2]=c[j>>2]|2}c[b>>2]=Y;do{if((a[p]&1)!=0){Y=c[m>>2]|0;if((Y|0)==0){break}yt(Y)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}yt(D);i=e;return}function tS(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;k=0;i=g;return(K=j,k)|0}l=c[(er()|0)>>2]|0;c[(er()|0)>>2]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);m=eV(b|0,h|0,f|0,c[141570]|0)|0;f=K;b=c[(er()|0)>>2]|0;if((b|0)==0){c[(er()|0)>>2]=l}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;k=0;i=g;return(K=j,k)|0}if((b|0)!=34){j=f;k=m;i=g;return(K=j,k)|0}c[e>>2]=4;e=0;b=(f|0)>(e|0)|(f|0)==(e|0)&m>>>0>0>>>0;j=b?2147483647:-2147483648;k=b?-1:0;i=g;return(K=j,k)|0}function tT(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;i=i+72|0;m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7>>3<<3;c[h>>2]=c[m>>2];m=f|0;n=f+32|0;o=f+40|0;p=f+56|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=c[j+4>>2]&74;if((v|0)==64){w=8}else if((v|0)==8){w=16}else if((v|0)==0){w=0}else{w=10}v=m|0;tP(o,c[j+28>>2]|0,v,n);yB(q|0,0,12);j=p;ss(p,10);if((a[q]&1)==0){m=j+1|0;x=m;y=m;z=p+8|0}else{m=p+8|0;x=c[m>>2]|0;y=j+1|0;z=m}c[r>>2]=x;m=s|0;c[t>>2]=m;c[u>>2]=0;A=g|0;g=h|0;h=p|0;B=p+4|0;C=a[n]|0;n=p+8|0;D=x;x=c[A>>2]|0;L3706:while(1){do{if((x|0)==0){E=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){E=x;break}if((f5[c[(c[x>>2]|0)+36>>2]&255](x)|0)!=-1){E=x;break}c[A>>2]=0;E=0}}while(0);F=(E|0)==0;G=c[g>>2]|0;do{if((G|0)==0){H=3460}else{if((c[G+12>>2]|0)!=(c[G+16>>2]|0)){if(F){I=G;J=0;break}else{K=D;L=G;M=0;N=E;O=0;break L3706}}if((f5[c[(c[G>>2]|0)+36>>2]&255](G)|0)==-1){c[g>>2]=0;H=3460;break}else{if(F){I=G;J=0;break}else{K=D;L=G;M=0;N=E;O=0;break L3706}}}}while(0);if((H|0)==3460){H=0;if(F){K=D;L=0;M=1;N=0;O=1;break}else{I=0;J=1}}G=(c[r>>2]|0)-D|0;P=a[q]|0;Q=P&255;if((G|0)==(((Q&1|0)==0?Q>>>1:c[B>>2]|0)|0)){Q=G<<1;do{if(G>>>0<Q>>>0){ss(p,G)}else{if((P&1)==0){a[j+1+Q|0]=0;a[q]=G<<2&255;break}else{a[(c[n>>2]|0)+Q|0]=0;c[B>>2]=Q;break}}}while(0);Q=a[q]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[h>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[B>>2]|0;do{if(P>>>0<R>>>0){ss(p,R-P|0)}else{if((S&1)==0){a[j+1+R|0]=0;a[q]=R<<1&255;break}else{a[(c[n>>2]|0)+R|0]=0;c[B>>2]=R;break}}}while(0);if((a[q]&1)==0){T=y}else{T=c[z>>2]|0}c[r>>2]=T+G;U=T}else{U=D}P=E+12|0;Q=c[P>>2]|0;V=E+16|0;if((Q|0)==(c[V>>2]|0)){W=(f5[c[(c[E>>2]|0)+36>>2]&255](E)|0)&255}else{W=a[Q]|0}if((tM(W,w,U,r,u,C,o,m,t,v)|0)!=0){K=U;L=I;M=J;N=E;O=F;break}Q=c[P>>2]|0;if((Q|0)==(c[V>>2]|0)){V=c[(c[E>>2]|0)+40>>2]|0;f5[V&255](E)|0;D=U;x=E;continue}else{c[P>>2]=Q+1;D=U;x=E;continue}}E=o;x=d[E]|0;if((x&1|0)==0){X=x>>>1}else{X=c[o+4>>2]|0}do{if((X|0)!=0){x=c[t>>2]|0;if((x-s|0)>=160){break}U=c[u>>2]|0;c[t>>2]=x+4;c[x>>2]=U}}while(0);b[l>>1]=tU(K,c[r>>2]|0,k,w)|0;tQ(o,m,c[t>>2]|0,k);do{if(O){Y=0}else{if((c[N+12>>2]|0)!=(c[N+16>>2]|0)){Y=N;break}if((f5[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){Y=N;break}c[A>>2]=0;Y=0}}while(0);A=(Y|0)==0;L3774:do{if(M){H=3512}else{do{if((c[L+12>>2]|0)==(c[L+16>>2]|0)){if((f5[c[(c[L>>2]|0)+36>>2]&255](L)|0)!=-1){break}c[g>>2]=0;H=3512;break L3774}}while(0);if(!(A^(L|0)==0)){H=3514}}}while(0);if((H|0)==3512){if(A){H=3514}}if((H|0)==3514){c[k>>2]=c[k>>2]|2}c[e>>2]=Y;do{if((a[q]&1)!=0){Y=c[n>>2]|0;if((Y|0)==0){break}yt(Y)}}while(0);if((a[E]&1)==0){i=f;return}E=c[o+8>>2]|0;if((E|0)==0){i=f;return}yt(E);i=f;return}function tU(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}if((a[b]|0)==45){c[e>>2]=4;j=0;i=g;return j|0}k=c[(er()|0)>>2]|0;c[(er()|0)>>2]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=a5(b|0,h|0,f|0,c[141570]|0)|0;f=K;b=c[(er()|0)>>2]|0;if((b|0)==0){c[(er()|0)>>2]=k}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=0;if((b|0)==34|(f>>>0>d>>>0|f>>>0==d>>>0&l>>>0>65535>>>0)){c[e>>2]=4;j=-1;i=g;return j|0}else{j=l&65535;i=g;return j|0}return 0}function tV(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+72|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+32|0;n=e+40|0;o=e+56|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==64){v=8}else if((u|0)==0){v=0}else if((u|0)==8){v=16}else{v=10}u=l|0;tP(n,c[h+28>>2]|0,u,m);yB(p|0,0,12);h=o;ss(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=a[m]|0;m=o+8|0;C=w;w=c[z>>2]|0;L3834:while(1){do{if((w|0)==0){D=0}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){D=w;break}if((f5[c[(c[w>>2]|0)+36>>2]&255](w)|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;F=c[f>>2]|0;do{if((F|0)==0){G=3567}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L3834}}if((f5[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[f>>2]=0;G=3567;break}else{if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L3834}}}}while(0);if((G|0)==3567){G=0;if(E){J=C;K=0;L=1;M=0;N=1;break}else{H=0;I=1}}F=(c[q>>2]|0)-C|0;O=a[p]|0;P=O&255;if((F|0)==(((P&1|0)==0?P>>>1:c[A>>2]|0)|0)){P=F<<1;do{if(F>>>0<P>>>0){ss(o,F)}else{if((O&1)==0){a[h+1+P|0]=0;a[p]=F<<2&255;break}else{a[(c[m>>2]|0)+P|0]=0;c[A>>2]=P;break}}}while(0);P=a[p]|0;if((P&1)==0){Q=10;R=P}else{P=c[g>>2]|0;Q=(P&-2)-1|0;R=P&255}P=R&255;O=(P&1|0)==0?P>>>1:c[A>>2]|0;do{if(O>>>0<Q>>>0){ss(o,Q-O|0)}else{if((R&1)==0){a[h+1+Q|0]=0;a[p]=Q<<1&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[A>>2]=Q;break}}}while(0);if((a[p]&1)==0){S=x}else{S=c[y>>2]|0}c[q>>2]=S+F;T=S}else{T=C}O=D+12|0;P=c[O>>2]|0;U=D+16|0;if((P|0)==(c[U>>2]|0)){V=(f5[c[(c[D>>2]|0)+36>>2]&255](D)|0)&255}else{V=a[P]|0}if((tM(V,v,T,q,t,B,n,l,s,u)|0)!=0){J=T;K=H;L=I;M=D;N=E;break}P=c[O>>2]|0;if((P|0)==(c[U>>2]|0)){U=c[(c[D>>2]|0)+40>>2]|0;f5[U&255](D)|0;C=T;w=D;continue}else{c[O>>2]=P+1;C=T;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){W=w>>>1}else{W=c[n+4>>2]|0}do{if((W|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}T=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=T}}while(0);c[k>>2]=tW(J,c[q>>2]|0,j,v)|0;tQ(n,l,c[s>>2]|0,j);do{if(N){X=0}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){X=M;break}if((f5[c[(c[M>>2]|0)+36>>2]&255](M)|0)!=-1){X=M;break}c[z>>2]=0;X=0}}while(0);z=(X|0)==0;L3902:do{if(L){G=3619}else{do{if((c[K+12>>2]|0)==(c[K+16>>2]|0)){if((f5[c[(c[K>>2]|0)+36>>2]&255](K)|0)!=-1){break}c[f>>2]=0;G=3619;break L3902}}while(0);if(!(z^(K|0)==0)){G=3621}}}while(0);if((G|0)==3619){if(z){G=3621}}if((G|0)==3621){c[j>>2]=c[j>>2]|2}c[b>>2]=X;do{if((a[p]&1)!=0){X=c[m>>2]|0;if((X|0)==0){break}yt(X)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}yt(D);i=e;return}function tW(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}if((a[b]|0)==45){c[e>>2]=4;j=0;i=g;return j|0}k=c[(er()|0)>>2]|0;c[(er()|0)>>2]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=a5(b|0,h|0,f|0,c[141570]|0)|0;f=K;b=c[(er()|0)>>2]|0;if((b|0)==0){c[(er()|0)>>2]=k}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=0;if((b|0)==34|(f>>>0>d>>>0|f>>>0==d>>>0&l>>>0>-1>>>0)){c[e>>2]=4;j=-1;i=g;return j|0}else{j=l;i=g;return j|0}return 0}
function kL(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;h=i;i=i+40|0;j=h|0;k=f+19692|0;l=g+316|0;m=c[g+192>>2]|0;n=c[l>>2]|0;o=f+19772|0;c[o>>2]=m>>>0<n>>>0?n:m;b[f+19784>>1]=b[g+196>>1]|0;a[f+19786|0]=a[g+198|0]|0;a[f+19787|0]=a[g+199|0]&1;m=g+44|0;n=d[(c[m>>2]|0)+273|0]|0;p=g+224|0;q=d[p]|0;r=c[l>>2]|0;s=c[g+200>>2]|0;t=s>>>0<r>>>0?r:s;c[f+19740>>2]=t;s=a[g+205|0]&7;a[f+19746|0]=s;r=n>>>6;a[f+19747|0]=r&255;n=s&255;a[f+19748|0]=(1<<n&d[72384+r|0]|0)!=0|0;s=2048-(d[g+204|0]|q<<8&1792)<<1;b[f+19744>>1]=s&65535;a[f+19749|0]=1;if((t|0)==-1){c[f+19736>>2]=-1}else{c[f+19736>>2]=(ag(d[56824+(n|r<<3)|0]|0,s)|0)+t}t=a[(c[m>>2]|0)+274|0]|0;s=c[l>>2]|0;r=c[g+208>>2]|0;n=f+19756|0;c[n>>2]=r>>>0<s>>>0?s:r;a[f+19765|0]=a[g+212|0]|0;a[f+19764|0]=t;t=c[l>>2]|0;r=c[g+216>>2]|0;s=f+19720|0;c[s>>2]=r>>>0<t>>>0?t:r;b[f+19728>>1]=b[g+220>>1]|0;r=c[l>>2]|0;c[f+19792>>2]=r;a[f+19804|0]=a[p]|0;a[f+19805|0]=a[g+225|0]&1;p=f+19808|0;t=d[(c[m>>2]|0)+278|0]|0;q=g+252|0;u=d[q]|0;v=c[l>>2]|0;w=c[g+228>>2]|0;x=w>>>0<v>>>0?v:w;c[f+19856>>2]=x;w=a[g+233|0]&7;a[f+19862|0]=w;v=t>>>6;a[f+19863|0]=v&255;t=w&255;a[f+19864|0]=(1<<t&d[72384+v|0]|0)!=0|0;w=2048-(d[g+232|0]|u<<8&1792)<<1;b[f+19860>>1]=w&65535;a[f+19865|0]=1;if((x|0)==-1){c[f+19852>>2]=-1}else{c[f+19852>>2]=(ag(d[56824+(t|v<<3)|0]|0,w)|0)+x}x=a[(c[m>>2]|0)+279|0]|0;w=c[l>>2]|0;v=c[g+236>>2]|0;t=f+19872|0;c[t>>2]=v>>>0<w>>>0?w:v;a[f+19881|0]=a[g+240|0]|0;a[f+19880|0]=x;x=c[l>>2]|0;v=c[g+244>>2]|0;w=f+19836|0;c[w>>2]=v>>>0<x>>>0?x:v;b[f+19844>>1]=b[g+248>>1]|0;v=f+19888|0;c[v>>2]=c[l>>2];a[f+19900|0]=a[q]|0;a[f+19901|0]=a[g+253|0]&1;q=c[l>>2]|0;x=c[g+264>>2]|0;c[f+19936>>2]=x>>>0<q>>>0?q:x;b[f+19944>>1]=b[g+268>>1]|0;c[f+19948>>2]=c[l>>2];x=c[g+272>>2]|0;q=c[l>>2]|0;c[f+19960>>2]=x>>>0<q>>>0?q:x;c[f+19964>>2]=c[g+276>>2];a[f+19969|0]=a[g+280|0]|0;a[f+19970|0]=a[g+281|0]|0;a[f+19971|0]=a[g+282|0]&31;a[f+19973|0]=a[g+283|0]|0;a[f+19974|0]=a[g+284|0]&1;a[f+19968|0]=a[(c[m>>2]|0)+282|0]&-128;x=((d[(c[m>>2]|0)+284|0]|0)>>>5&3)+255|0;a[f+19972|0]=(x&252)>>>0>3?4:x&255;x=f+19976|0;q=c[g+288>>2]|0;u=c[l>>2]|0;y=q>>>0<u>>>0?u:q;c[f+20040>>2]=y;c[f+20036>>2]=y;b[f+20044>>1]=b[g+292>>1]|0;y=g+313|0;a[f+20047|0]=a[y]&1;a[f+20046|0]=a[(c[m>>2]|0)+290|0]|0;q=a[(c[m>>2]|0)+289|0]|0;u=c[l>>2]|0;z=c[g+296>>2]|0;A=f+20020|0;c[A>>2]=z>>>0<u>>>0?u:z;a[f+20029|0]=a[g+300|0]|0;a[f+20028|0]=q;q=c[l>>2]|0;z=c[g+304>>2]|0;u=f+20004|0;c[u>>2]=z>>>0<q>>>0?q:z;b[f+20012>>1]=b[g+308>>1]|0;z=f+20052|0;c[z>>2]=c[l>>2];a[f+20064|0]=a[g+312|0]|0;a[f+20065|0]=a[y]&1;y=g|0;c[f+20072>>2]=c[y>>2];l=d[(c[m>>2]|0)+292|0]|0;c[f+20076>>2]=((l<<16&458752|l>>>4&7)<<6)+4194368;l=d[(c[m>>2]|0)+293|0]|0;q=l<<16|l>>>4;c[f+19796>>2]=(q&65537)*65535|0;f3[c[(c[k>>2]|0)+8>>2]&1023](k|0,r);r=f+19768|0;k=f+19788|0;c[k>>2]=r;if((c[n>>2]|0)>>>0<(c[o>>2]|0)>>>0){o=f+19752|0;c[k>>2]=o;B=o}else{B=r}if((c[s>>2]|0)>>>0<(c[B+4>>2]|0)>>>0){c[k>>2]=f+19716}c[f+19892>>2]=(q>>>1&65537)*65535|0;f3[c[(c[p>>2]|0)+8>>2]&1023](p|0,c[v>>2]|0);v=f+19884|0;c[v>>2]=f+19868;if((c[w>>2]|0)>>>0<(c[t>>2]|0)>>>0){c[v>>2]=f+19832}c[f+19952>>2]=(q>>>2&65537)*65535|0;c[f+20056>>2]=(q>>>3&65537)*65535|0;f3[c[(c[x>>2]|0)+8>>2]&1023](x|0,c[z>>2]|0);z=f+20048|0;c[z>>2]=f+20016;if((c[u>>2]|0)>>>0<(c[A>>2]|0)>>>0){c[z>>2]=f+2e4}a[f+20088|0]=(d[(c[m>>2]|0)+294|0]|0)>>>7;z=f+17268|0;A=g+87|0;if((d[A]|0)<160){C=c[f+17184>>2]|0}else{C=f|0}u=a[(c[m>>2]|0)+321|0]|0;x=f+19688|0;a[x]=u;a[f+19689|0]=u;a[f+19690|0]=u;switch(d[g+181|0]|0){case 130:{D=84040;break};case 131:{D=84024;break};case 132:{D=84008;break};case 133:{D=83992;break};case 136:{D=84264;break};case 137:{D=84248;break};case 129:{D=84056;break};case 149:{D=84088;break};case 138:{D=84232;break};case 145:{D=84152;break};case 141:{D=84184;break};case 128:{D=84072;break};case 140:{D=84200;break};case 139:{D=84216;break};case 146:{D=84136;break};case 148:{D=84104;break};case 147:{D=84120;break};case 144:{D=84168;break};default:{D=0}}u=g+128|0;q=c[u>>2]|0;v=q>>>0>70223?70223:q;q=f+19379|0;t=(d[(c[m>>2]|0)+333|0]|0)>>>7&d[q];w=v-(-t&3)|0;p=(w|0)<0?w+70224|0:w;w=f+17532|0;c[w>>2]=c[y>>2];k=f+19362|0;a[k]=a[(c[m>>2]|0)+320|0]|0;B=f+17559|0;a[B]=t&255;s=f+17556|0;b[s>>1]=456<<t&65535;r=c[u>>2]|0;o=r>>>0>70223?70223:r;r=c[y>>2]|0;n=(o>>>0)/456|0;l=f+17558|0;a[l]=n&255;c[f+17552>>2]=(456-o+((n&255)*456|0)<<t)+r;c[f+19272>>2]=C;a[f+19281|0]=(d[(c[m>>2]|0)+320|0]|0)>>>2&1;C=c[g+132>>2]|0;r=f+19276|0;c[r>>2]=C;qC(f+19148|0,C);C=c[f+19268>>2]|0;t=a[C+7|0]&1;n=459-(((c[C>>2]|0)-(c[r>>2]|0)|0)>>>(t>>>0))-(-t&3)|0;t=n>>>0>455?n-456|0:n;a[f+19280|0]=t>>>0>80?80:t&255;t=f+19e3|0;yB(t|0,-128|0,144);n=f+17560|0;r=0;do{C=8<<(a[(r>>>1)+(f+19228)|0]&1);o=cO((d[f+19148+r|0]|0)-17|0,C|0)|0;E=o;L5877:do{if(E>>>0<(C+143|0)>>>0){if(K){F=n;G=t}else{o=1-C+E|0;F=(o*10|0)+(f+17560)|0;G=f+19e3+o|0}o=(E>>>0<143?E:143)+(f+19e3)|0;H=r&255;I=F;J=G;while(1){L=a[J]|0;M=L&127;if(M>>>0<10){a[J]=L+1&255;a[I+M|0]=H}M=J+1|0;if(M>>>0>o>>>0){break L5877}I=I+10|0;J=M}}}while(0);r=r+2|0;}while(r>>>0<80);r=(p>>>0)%456|0;c[c[f+19144>>2]>>2]=0;a[f+19370|0]=a[g+174|0]|0;a[f+19363|0]=a[(c[m>>2]|0)+322|0]|0;a[f+19364|0]=a[(c[m>>2]|0)+323|0]|0;a[f+19365|0]=a[(c[m>>2]|0)+330|0]|0;G=g+186|0;a[f+19366|0]=a[G]|0;a[f+19367|0]=a[(c[m>>2]|0)+331|0]|0;F=g+175|0;t=a[F]|0;n=(t&255)>168?-88:t;t=f+19377|0;a[t]=n;E=n&-8|a[g+176|0]&7;C=E&255;J=(E&255)<=(n&255)?C+8|0:C;a[f+19378|0]=J>>>0>168?-88:J&255;a[f+19371|0]=a[g+177|0]|0;a[f+19372|0]=a[g+178|0]|0;c[f+17544>>2]=e[g+140>>1]|0;c[f+17548>>2]=e[g+142>>1]|0;a[f+19373|0]=a[g+179|0]|0;a[f+19374|0]=a[g+180|0]|0;a[f+19369|0]=a[g+188|0]|0;a[f+19380|0]=a[g+189|0]&1;a[f+19368|0]=a[g+187|0]&3;J=f+17536|0;c[J>>2]=(c[w>>2]|0)-(e[g+136>>1]|0);C=c[u>>2]|0;do{if(C>>>0<65664){if((d[F]|0)>=168){break}u=(C>>>0)/456|0;n=f+19e3+u|0;E=a[n]|0;I=E&127;do{if(E<<24>>24<0){o=E&127;a[n]=o;H=u*10|0;M=f+17560+H|0;L=(o&255)+H|0;o=f+17560+L|0;if((H|0)>=(L|0)){N=H;break}O=H|1;if((O|0)>=(L|0)){N=H;break}L=f+17560+O|0;while(1){O=a[L]|0;L5900:do{if((L|0)==(M|0)){P=M}else{Q=(O&255)+1+(f+19148)|0;R=L;while(1){S=R-1|0;T=a[S]|0;if((d[Q]|0)>=(d[(T&255)+1+(f+19148)|0]|0)){P=R;break L5900}a[R]=T;if((S|0)==(M|0)){P=M;break}else{R=S}}}}while(0);a[P]=O;R=L+1|0;if(R>>>0<o>>>0){L=R}else{N=H;break}}}else{N=u*10|0}}while(0);if((I|0)!=0){n=u+16|0;E=0;do{H=a[E+N+(f+17560)|0]|0;L=H&255;o=d[f+19148+L|0]|0;a[f+19296+(E<<2)|0]=a[L+1+(f+19148)|0]|0;a[f+19296+(E<<2)+2|0]=n-o&255;a[f+19296+(E<<2)+1|0]=H<<1;a[f+19296+(E<<2)+3|0]=a[g+144+E|0]|0;b[f+19340+(E<<1)>>1]=d[g+164+E|0]<<8|d[g+154+E|0];E=E+1|0;}while(E>>>0<I>>>0)}a[f+19296+(I<<2)|0]=-1;E=d[g+182|0]|0;n=f+19375|0;u=(I>>>0<E>>>0?I:E)&255;while(1){a[n]=u;if((d[f+19296+((u&255)<<2)|0]|0)<(d[F]|0)){u=u+1&255}else{break}}n=a[g+183|0]|0;a[f+19376|0]=(n&255)<(u&255)?n:u}}while(0);do{if((D|0)!=0&(v|0)<65664){F=a[t]|0;if((F&255)>=168){U=4496;break}N=174-(F&255)|0;F=a[f+19375|0]|0;L5919:do{if((F&255)<10){P=N;C=F&255;while(1){if((d[f+19296+(C<<2)|0]|0)>=168){V=P;break L5919}n=P+11|0;I=C+1|0;if(I>>>0<10){P=n;C=I}else{V=n;break}}}else{V=N}}while(0);if((V+r|0)>=(450-(a[q]&1)|0)){U=4496;break}c[f+17528>>2]=D;c[f+17540>>2]=-1;W=D;X=-1}else{U=4496}}while(0);do{if((U|0)==4496){if((p|0)>=65371){D=p-70224|0;c[f+17540>>2]=D;c[f+17528>>2]=84312;W=84312;X=D;break}c[j>>2]=83976;c[j+4>>2]=83;c[j+8>>2]=83960;c[j+12>>2]=163;c[j+16>>2]=84296;D=a[q]&1;V=450-D|0;c[j+20>>2]=V;c[j+24>>2]=84280;v=454-D|0;c[j+28>>2]=v;c[j+32>>2]=83976;c[j+36>>2]=539;do{if(V>>>0>r>>>0){if(r>>>0>=163){Y=2;break}Y=r>>>0>82|0}else{Y=v>>>0>r>>>0?3:4}}while(0);v=r-(c[j+(Y<<3)+4>>2]|0)|0;V=f+17540|0;c[V>>2]=v;D=c[j+(Y<<3)>>2]|0;c[f+17528>>2]=D;if((D|0)!=83960){W=D;X=v;break}a[t]=r+174&255;c[V>>2]=-1;W=83960;X=-1}}while(0);r=f+19668|0;a[f+19672|0]=a[(c[m>>2]|0)+325|0]|0;t=a[(c[m>>2]|0)+321|0]|0;a[f+19673|0]=t;a[f+19674|0]=a[g+184|0]|0;a[f+19675|0]=t;a[f+19665|0]=a[g+185|0]|0;a[f+19664|0]=a[(c[m>>2]|0)+321|0]|0;if((a[k]|0)>-1){k=f+19580|0;t=f+19612|0;Y=f+19560|0;j=f+19564|0;p=f+19576|0;V=f+19568|0;v=f+19660|0;D=0;do{c[f+19580+(D<<2)>>2]=-1;f2[c[f+19616+(D>>1<<2)>>2]&1023](k);N=c[t>>2]|0;c[Y>>2]=N;F=(c[j>>2]|0)>>>0<=N>>>0|0;c[p>>2]=F;c[V>>2]=c[f+19560+(F<<2)>>2];F=c[v>>2]|0;c[F+28>>2]=N;u=(c[F+24>>2]|0)>>>0<N>>>0?6:7;c[F+96>>2]=u;N=c[F+92>>2]|0;C=(c[F+(N<<2)>>2]|0)>>>0<(c[F+(u<<2)>>2]|0)>>>0?N:u;c[F+76>>2]=C;u=c[F+72>>2]|0;N=(c[F+(u<<2)>>2]|0)>>>0<(c[F+(C<<2)>>2]|0)>>>0?u:C;c[F+64>>2]=N;C=c[F+68>>2]|0;u=(c[F+(N<<2)>>2]|0)>>>0<(c[F+(C<<2)>>2]|0)>>>0?N:C;c[F+60>>2]=u;c[F+36>>2]=c[F+(u<<2)>>2];D=D+1|0;}while((D|0)<8)}else{D=c[w>>2]|0;v=ga[c[W+4>>2]&127](z|0,167,-X|0)|0;X=f+19680|0;c[X>>2]=(v<<(a[B]&1))+D;D=f+17552|0;pA(r,D,c[w>>2]|0);if((a[g+190|0]&1)==0){Z=-1}else{Z=(c[w>>2]|0)+1|0}v=f+19580|0;c[v>>2]=Z;W=f+19584|0;V=(c[W>>2]|0)>>>0<=Z>>>0|0;Z=f+19644|0;c[Z>>2]=V;p=f+19648|0;j=c[p>>2]|0;Y=(c[f+19580+(V<<2)>>2]|0)>>>0<(c[f+19580+(j<<2)>>2]|0)>>>0?V:j;j=f+19636|0;c[j>>2]=Y;V=f+19640|0;t=c[V>>2]|0;k=(c[f+19580+(Y<<2)>>2]|0)>>>0<(c[f+19580+(t<<2)>>2]|0)>>>0?Y:t;t=f+19632|0;c[t>>2]=k;Y=c[f+19580+(k<<2)>>2]|0;k=f+19612|0;c[k>>2]=Y;u=f+19560|0;c[u>>2]=Y;F=f+19564|0;C=(c[F>>2]|0)>>>0<=Y>>>0|0;N=f+19576|0;c[N>>2]=C;P=f+19568|0;c[P>>2]=c[f+19560+(C<<2)>>2];C=f+19660|0;n=c[C>>2]|0;c[n+28>>2]=Y;I=(c[n+24>>2]|0)>>>0<Y>>>0?6:7;c[n+96>>2]=I;Y=c[n+92>>2]|0;E=(c[n+(Y<<2)>>2]|0)>>>0<(c[n+(I<<2)>>2]|0)>>>0?Y:I;c[n+76>>2]=E;I=c[n+72>>2]|0;Y=(c[n+(I<<2)>>2]|0)>>>0<(c[n+(E<<2)>>2]|0)>>>0?I:E;c[n+64>>2]=Y;E=c[n+68>>2]|0;I=(c[n+(Y<<2)>>2]|0)>>>0<(c[n+(E<<2)>>2]|0)>>>0?Y:E;c[n+60>>2]=I;c[n+36>>2]=c[n+(I<<2)>>2];if((a[G]|0)==(a[(c[m>>2]|0)+330|0]|0)){_=-1}else{_=(c[w>>2]|0)+1|0}c[W>>2]=_;W=(c[v>>2]|0)>>>0>=_>>>0|0;c[Z>>2]=W;_=c[p>>2]|0;v=(c[f+19580+(W<<2)>>2]|0)>>>0<(c[f+19580+(_<<2)>>2]|0)>>>0?W:_;c[j>>2]=v;_=c[V>>2]|0;W=(c[f+19580+(v<<2)>>2]|0)>>>0<(c[f+19580+(_<<2)>>2]|0)>>>0?v:_;c[t>>2]=W;_=c[f+19580+(W<<2)>>2]|0;c[k>>2]=_;c[u>>2]=_;W=(c[F>>2]|0)>>>0<=_>>>0|0;c[N>>2]=W;c[P>>2]=c[f+19560+(W<<2)>>2];W=c[C>>2]|0;c[W+28>>2]=_;v=(c[W+24>>2]|0)>>>0<_>>>0?6:7;c[W+96>>2]=v;_=c[W+92>>2]|0;G=(c[W+(_<<2)>>2]|0)>>>0<(c[W+(v<<2)>>2]|0)>>>0?_:v;c[W+76>>2]=G;v=c[W+72>>2]|0;_=(c[W+(v<<2)>>2]|0)>>>0<(c[W+(G<<2)>>2]|0)>>>0?v:G;c[W+64>>2]=_;G=c[W+68>>2]|0;v=(c[W+(_<<2)>>2]|0)>>>0<(c[W+(G<<2)>>2]|0)>>>0?_:G;c[W+60>>2]=v;c[W+36>>2]=c[W+(v<<2)>>2];v=D|0;D=c[v>>2]|0;c[F>>2]=D;W=(c[u>>2]|0)>>>0>=D>>>0|0;c[N>>2]=W;c[P>>2]=c[f+19560+(W<<2)>>2];W=(80<<(a[B]&1))+D|0;G=e[s>>1]|0;_=W-((W-(c[w>>2]|0)|0)>>>0>G>>>0?G:0)|0;G=f+19596|0;c[G>>2]=_;W=f+19600|0;I=(c[W>>2]|0)>>>0>_>>>0?4:5;_=f+19652|0;c[_>>2]=I;n=f+19656|0;E=c[n>>2]|0;Y=(c[f+19580+(I<<2)>>2]|0)>>>0<(c[f+19580+(E<<2)>>2]|0)>>>0?I:E;c[V>>2]=Y;E=c[j>>2]|0;I=(c[f+19580+(E<<2)>>2]|0)>>>0<(c[f+19580+(Y<<2)>>2]|0)>>>0?E:Y;c[t>>2]=I;Y=c[f+19580+(I<<2)>>2]|0;c[k>>2]=Y;c[u>>2]=Y;I=D>>>0<=Y>>>0|0;c[N>>2]=I;c[P>>2]=c[f+19560+(I<<2)>>2];I=c[C>>2]|0;c[I+28>>2]=Y;D=(c[I+24>>2]|0)>>>0<Y>>>0?6:7;c[I+96>>2]=D;Y=c[I+92>>2]|0;E=(c[I+(Y<<2)>>2]|0)>>>0<(c[I+(D<<2)>>2]|0)>>>0?Y:D;c[I+76>>2]=E;D=c[I+72>>2]|0;Y=(c[I+(D<<2)>>2]|0)>>>0<(c[I+(E<<2)>>2]|0)>>>0?D:E;c[I+64>>2]=Y;E=c[I+68>>2]|0;D=(c[I+(Y<<2)>>2]|0)>>>0<(c[I+(E<<2)>>2]|0)>>>0?Y:E;c[I+60>>2]=D;c[I+36>>2]=c[I+(D<<2)>>2];D=c[r>>2]|0;r=f+19592|0;c[r>>2]=D;I=f+19588|0;E=(c[I>>2]|0)>>>0<D>>>0?2:3;c[p>>2]=E;D=c[Z>>2]|0;Y=(c[f+19580+(D<<2)>>2]|0)>>>0<(c[f+19580+(E<<2)>>2]|0)>>>0?D:E;c[j>>2]=Y;E=c[V>>2]|0;D=(c[f+19580+(Y<<2)>>2]|0)>>>0<(c[f+19580+(E<<2)>>2]|0)>>>0?Y:E;c[t>>2]=D;E=c[f+19580+(D<<2)>>2]|0;c[k>>2]=E;c[u>>2]=E;D=(c[F>>2]|0)>>>0<=E>>>0|0;c[N>>2]=D;c[P>>2]=c[f+19560+(D<<2)>>2];D=c[C>>2]|0;c[D+28>>2]=E;Y=(c[D+24>>2]|0)>>>0<E>>>0?6:7;c[D+96>>2]=Y;E=c[D+92>>2]|0;H=(c[D+(E<<2)>>2]|0)>>>0<(c[D+(Y<<2)>>2]|0)>>>0?E:Y;c[D+76>>2]=H;Y=c[D+72>>2]|0;E=(c[D+(Y<<2)>>2]|0)>>>0<(c[D+(H<<2)>>2]|0)>>>0?Y:H;c[D+64>>2]=E;H=c[D+68>>2]|0;Y=(c[D+(E<<2)>>2]|0)>>>0<(c[D+(H<<2)>>2]|0)>>>0?E:H;c[D+60>>2]=Y;c[D+36>>2]=c[D+(Y<<2)>>2];Y=a[B]&1;D=(((153-(d[l]|0)|0)*456|0)+65664<<Y)+(c[v>>2]|0)|0;H=70224<<Y;Y=D-((D-(c[w>>2]|0)|0)>>>0>H>>>0?H:0)|0;c[I>>2]=Y;I=(c[r>>2]|0)>>>0>Y>>>0?2:3;c[p>>2]=I;p=c[Z>>2]|0;Z=(c[f+19580+(p<<2)>>2]|0)>>>0<(c[f+19580+(I<<2)>>2]|0)>>>0?p:I;c[j>>2]=Z;I=c[V>>2]|0;p=(c[f+19580+(Z<<2)>>2]|0)>>>0<(c[f+19580+(I<<2)>>2]|0)>>>0?Z:I;c[t>>2]=p;I=c[f+19580+(p<<2)>>2]|0;c[k>>2]=I;c[u>>2]=I;p=(c[F>>2]|0)>>>0<=I>>>0|0;c[N>>2]=p;c[P>>2]=c[f+19560+(p<<2)>>2];p=c[C>>2]|0;c[p+28>>2]=I;Z=(c[p+24>>2]|0)>>>0<I>>>0?6:7;c[p+96>>2]=Z;I=c[p+92>>2]|0;Y=(c[p+(I<<2)>>2]|0)>>>0<(c[p+(Z<<2)>>2]|0)>>>0?I:Z;c[p+76>>2]=Y;Z=c[p+72>>2]|0;I=(c[p+(Z<<2)>>2]|0)>>>0<(c[p+(Y<<2)>>2]|0)>>>0?Z:Y;c[p+64>>2]=I;Y=c[p+68>>2]|0;Z=(c[p+(I<<2)>>2]|0)>>>0<(c[p+(Y<<2)>>2]|0)>>>0?I:Y;c[p+60>>2]=Z;c[p+36>>2]=c[p+(Z<<2)>>2];Z=d[x]|0;p=c[w>>2]|0;if((Z&32|0)==0){$=-1}else{Y=(c[v>>2]|0)-p|0;v=a[l]|0;do{if((v&255)>142){U=4514}else{l=Y>>>0<5;if(v<<24>>24==-114&l){U=4514;break}if((Z&8|0)!=0){U=4514;break}if(l){aa=(e[s>>1]|0)+Y|0}else{aa=Y}ab=aa-4|0}}while(0);if((U|0)==4514){ab=(ag(e[s>>1]|0,153-(v&255)|0)|0)+Y|0}$=ab+p|0}p=f+19604|0;c[p>>2]=$;ab=f+19608|0;Y=(c[ab>>2]|0)>>>0>$>>>0?6:7;c[n>>2]=Y;$=c[_>>2]|0;v=(c[f+19580+($<<2)>>2]|0)>>>0<(c[f+19580+(Y<<2)>>2]|0)>>>0?$:Y;c[V>>2]=v;Y=c[j>>2]|0;$=(c[f+19580+(Y<<2)>>2]|0)>>>0<(c[f+19580+(v<<2)>>2]|0)>>>0?Y:v;c[t>>2]=$;v=c[f+19580+($<<2)>>2]|0;c[k>>2]=v;c[u>>2]=v;$=(c[F>>2]|0)>>>0<=v>>>0|0;c[N>>2]=$;c[P>>2]=c[f+19560+($<<2)>>2];$=c[C>>2]|0;c[$+28>>2]=v;Y=(c[$+24>>2]|0)>>>0<v>>>0?6:7;c[$+96>>2]=Y;v=c[$+92>>2]|0;s=(c[$+(v<<2)>>2]|0)>>>0<(c[$+(Y<<2)>>2]|0)>>>0?v:Y;c[$+76>>2]=s;Y=c[$+72>>2]|0;v=(c[$+(Y<<2)>>2]|0)>>>0<(c[$+(s<<2)>>2]|0)>>>0?Y:s;c[$+64>>2]=v;s=c[$+68>>2]|0;Y=(c[$+(v<<2)>>2]|0)>>>0<(c[$+(s<<2)>>2]|0)>>>0?v:s;c[$+60>>2]=Y;c[$+36>>2]=c[$+(Y<<2)>>2];if((a[x]&8)==0){ac=-1}else{ac=(e[g+138>>1]|0)+(c[w>>2]|0)|0}c[ab>>2]=ac;ab=(c[p>>2]|0)>>>0<ac>>>0?6:7;c[n>>2]=ab;ac=c[_>>2]|0;p=(c[f+19580+(ac<<2)>>2]|0)>>>0<(c[f+19580+(ab<<2)>>2]|0)>>>0?ac:ab;c[V>>2]=p;ab=c[j>>2]|0;ac=(c[f+19580+(ab<<2)>>2]|0)>>>0<(c[f+19580+(p<<2)>>2]|0)>>>0?ab:p;c[t>>2]=ac;p=c[f+19580+(ac<<2)>>2]|0;c[k>>2]=p;c[u>>2]=p;ac=(c[F>>2]|0)>>>0<=p>>>0|0;c[N>>2]=ac;c[P>>2]=c[f+19560+(ac<<2)>>2];ac=c[C>>2]|0;c[ac+28>>2]=p;ab=(c[ac+24>>2]|0)>>>0<p>>>0?6:7;c[ac+96>>2]=ab;p=c[ac+92>>2]|0;x=(c[ac+(p<<2)>>2]|0)>>>0<(c[ac+(ab<<2)>>2]|0)>>>0?p:ab;c[ac+76>>2]=x;ab=c[ac+72>>2]|0;p=(c[ac+(ab<<2)>>2]|0)>>>0<(c[ac+(x<<2)>>2]|0)>>>0?ab:x;c[ac+64>>2]=p;x=c[ac+68>>2]|0;ab=(c[ac+(p<<2)>>2]|0)>>>0<(c[ac+(x<<2)>>2]|0)>>>0?p:x;c[ac+60>>2]=ab;c[ac+36>>2]=c[ac+(ab<<2)>>2];do{if((a[g+92|0]&1)==0){ad=-1}else{ab=a[B]&1;ac=(c[J>>2]|0)+1-ab|0;if(ac>>>0>(c[w>>2]|0)>>>0){ad=ac;break}ad=(c[X>>2]|0)+(ab^1)|0}}while(0);c[W>>2]=ad;W=(c[G>>2]|0)>>>0<ad>>>0?4:5;c[_>>2]=W;_=c[n>>2]|0;n=(c[f+19580+(W<<2)>>2]|0)>>>0<(c[f+19580+(_<<2)>>2]|0)>>>0?W:_;c[V>>2]=n;V=c[j>>2]|0;j=(c[f+19580+(V<<2)>>2]|0)>>>0<(c[f+19580+(n<<2)>>2]|0)>>>0?V:n;c[t>>2]=j;t=c[f+19580+(j<<2)>>2]|0;c[k>>2]=t;c[u>>2]=t;u=(c[F>>2]|0)>>>0<=t>>>0|0;c[N>>2]=u;c[P>>2]=c[f+19560+(u<<2)>>2];u=c[C>>2]|0;c[u+28>>2]=t;C=(c[u+24>>2]|0)>>>0<t>>>0?6:7;c[u+96>>2]=C;t=c[u+92>>2]|0;P=(c[u+(t<<2)>>2]|0)>>>0<(c[u+(C<<2)>>2]|0)>>>0?t:C;c[u+76>>2]=P;C=c[u+72>>2]|0;t=(c[u+(C<<2)>>2]|0)>>>0<(c[u+(P<<2)>>2]|0)>>>0?C:P;c[u+64>>2]=t;P=c[u+68>>2]|0;C=(c[u+(t<<2)>>2]|0)>>>0<(c[u+(P<<2)>>2]|0)>>>0?t:P;c[u+60>>2]=C;c[u+36>>2]=c[u+(C<<2)>>2]}oO(z);z=c[g+56>>2]|0;c[f+17256>>2]=z;C=c[g+60>>2]|0;c[f+17260>>2]=C;u=a[(c[m>>2]|0)+261|0]|0;a[f+17264|0]=u;a[f+17265|0]=a[(c[m>>2]|0)+262|0]|0;P=a[(c[m>>2]|0)+263|0]|0;a[f+17266|0]=P;do{if((P&4)==0){ae=-1}else{if((C|0)!=-1){if(C>>>0>(c[y>>2]|0)>>>0){ae=C;break}}ae=z+3+(256-(u&255)<<d[84328+(P&3)|0])|0}}while(0);c[f+16936>>2]=ae;P=(c[f+16940>>2]|0)>>>0>ae>>>0?6:7;c[f+17008>>2]=P;ae=c[f+17004>>2]|0;u=(c[f+16912+(ae<<2)>>2]|0)>>>0<(c[f+16912+(P<<2)>>2]|0)>>>0?ae:P;c[f+16988>>2]=u;ae=c[f+16984>>2]|0;z=(c[f+16912+(ae<<2)>>2]|0)>>>0<(c[f+16912+(u<<2)>>2]|0)>>>0?ae:u;c[f+16976>>2]=z;ae=c[f+16980>>2]|0;C=(c[f+16912+(z<<2)>>2]|0)>>>0<(c[f+16912+(ae<<2)>>2]|0)>>>0?z:ae;c[f+16972>>2]=C;c[f+16948>>2]=c[f+16912+(C<<2)>>2];C=f+17032|0;ae=f+17208|0;t=c[f+17164>>2]|0;N=t+327|0;F=g+90|0;if(((d[N]|0)-15|0)>>>0<2){af=(a[F]&1)!=0}else{af=0}a[f+17246|0]=af&1;k=f+17224|0;c[k>>2]=c[g+320>>2];c[k+4>>2]=0;k=f+17232|0;c[k>>2]=c[g+324>>2];c[k+4>>2]=0;k=a[g+328|0]|0;a[f+17240|0]=k;j=f+17241|0;a[j]=a[g+329|0]|0;n=f+17242|0;a[n]=a[g+330|0]|0;V=f+17243|0;a[V]=a[g+331|0]|0;_=f+17244|0;a[_]=a[g+332|0]|0;W=f+17245|0;a[W]=a[g+333|0]|0;a[f+17247|0]=a[g+334|0]&1;L5979:do{if((k&255)>4|af^1){c[ae>>2]=0;ad=f+17212|0;c[ad>>2]=0;c[ad+4>>2]=0;ah=0}else{switch(k&255|0){case 1:{c[ae>>2]=_;ad=f+17212|0;c[ad>>2]=150;c[ad+4>>2]=0;ah=_;break L5979;break};case 2:{c[ae>>2]=V;ad=f+17212|0;c[ad>>2]=402;c[ad+4>>2]=0;ah=V;break L5979;break};case 0:{c[ae>>2]=W;ad=f+17212|0;c[ad>>2]=648;c[ad+4>>2]=0;ah=W;break L5979;break};case 3:{c[ae>>2]=n;ad=f+17212|0;c[ad>>2]=82;c[ad+4>>2]=0;ah=n;break L5979;break};case 4:{c[ae>>2]=j;ad=f+17212|0;c[ad>>2]=300;c[ad+4>>2]=0;ah=j;break L5979;break};default:{ah=c[ae>>2]|0;break L5979}}}}while(0);ae=c[f+17180>>2]|0;j=ae;n=((j-t|0)/16384|0)+65535&e[g+80>>1];W=n&65535;b[f+17248>>1]=W;V=c[f+17172>>2]|0;_=V;k=((_-j|0)/8192|0)+255&d[g+86|0];a[f+17250|0]=k&255;j=a[F]&1;a[f+17251|0]=j;a[f+17252|0]=a[g+91|0]&1;F=c[f+17184>>2]|0;af=F-40960|0;ad=f+17192|0;c[ad>>2]=af;G=(c[f+17188>>2]|0)-40960|0;X=f+17196|0;c[X>>2]=G;do{if(j<<24>>24==0){ai=af;aj=G;ak=V}else{if((ah|0)!=0){c[X>>2]=0;c[ad>>2]=0;ai=0;aj=0;ak=V;break}if((ae|0)==(V|0)){ai=af;aj=G;ak=ae;break}w=ae+((k<<13)-40960)|0;c[X>>2]=w;c[ad>>2]=w;ai=w;aj=w;ak=V}}while(0);ad=f+17072|0;c[ad>>2]=ai;X=f+17076|0;c[X>>2]=ai;k=f+17136|0;c[k>>2]=aj;ae=f+17140|0;c[ae>>2]=aj;G=C;af=F;F=(af-ak|0)==32768;ak=f+17200|0;ah=c[ak>>2]|0;do{if(F){if((ah|0)==0|(ah|0)==1|(ah|0)==4){yB(G|0,0,32);c[ad>>2]=0;c[X>>2]=0;c[k>>2]=0;c[ae>>2]=0;break}else if((ah|0)==3){c[f+17080>>2]=0;c[f+17084>>2]=0;c[f+17088>>2]=0;c[f+17144>>2]=0;c[f+17148>>2]=0;c[f+17152>>2]=0;break}else{break}}else{if(!((ah|0)==0|(ah|0)==1|(ah|0)==3|(ah|0)==4)){break}yB(G|0,0,32);yB(ad|0,0,20);yB(k|0,0,20)}}while(0);j=a[N]|0;if((j&255)>=31){dL(31e3,94,55216,30624)}N=d[55896+(j&255)|0]|0;if((N|0)==1){if((n&31|0)==0){U=4557}else{al=n}}else if((N|0)==4){if(W<<16>>16==0){U=4557}else{al=n}}else{al=n}if((U|0)==4557){al=n+1|0}n=t+((al<<14)-16384)|0;c[f+17168>>2]=n;al=f+17048|0;c[al>>2]=n;U=f+17052|0;c[U>>2]=n;W=f+17056|0;c[W>>2]=n;N=f+17060|0;c[N>>2]=n;do{if(F){if((ah|0)==0|(ah|0)==1|(ah|0)==4){yB(G|0,0,32);c[ad>>2]=0;c[X>>2]=0;c[k>>2]=0;c[ae>>2]=0;break}else if((ah|0)==3){c[f+17080>>2]=0;c[f+17084>>2]=0;c[f+17088>>2]=0;c[f+17144>>2]=0;c[f+17148>>2]=0;c[f+17152>>2]=0;break}else{break}}else{if(!((ah|0)==0|(ah|0)==1|(ah|0)==3|(ah|0)==4)){break}yB(G|0,0,32);yB(ad|0,0,20);yB(k|0,0,20)}}while(0);ah=c[g+72>>2]|0;c[f+17016>>2]=ah;F=d[(c[m>>2]|0)+271|0]|0;c[f+17020>>2]=F;j=a[(c[m>>2]|0)+511|0]&31;c[f+17024>>2]=j;m=a[g+89|0]<<1&2|a[g+88|0]&1;a[f+17028|0]=m;if(m<<24>>24==0){am=-1}else{am=(j&F|0)==0?-1:ah}c[f+16944>>2]=am;c[f+17012>>2]=8;c[f+16992>>2]=8;c[f+16980>>2]=8;ah=f+16976|0;F=(c[f+16912+(z<<2)>>2]|0)>>>0<am>>>0?z:8;z=f+16972|0;c[z>>2]=F;j=f+16948|0;c[j>>2]=c[f+16912+(F<<2)>>2];c[f+16904>>2]=c[g+52>>2];F=c[g+64>>2]|0;c[f+16924>>2]=F;m=f+16920|0;w=(c[m>>2]|0)>>>0<F>>>0?2:3;J=f+17e3|0;c[J>>2]=w;B=f+16996|0;ab=c[B>>2]|0;ac=f+16912+(w<<2)|0;x=(c[f+16912+(ab<<2)>>2]|0)>>>0<(c[ac>>2]|0)>>>0?ab:w;ab=f+16984|0;c[ab>>2]=x;p=f+16988|0;Y=f+16912+(u<<2)|0;$=(c[f+16912+(x<<2)>>2]|0)>>>0<(c[Y>>2]|0)>>>0?x:u;c[ah>>2]=$;x=(c[f+16912+($<<2)>>2]|0)>>>0<am>>>0?$:8;c[z>>2]=x;c[j>>2]=c[f+16912+(x<<2)>>2];x=c[g+76>>2]|0;c[f+16912>>2]=x;$=(c[f+16916>>2]|0)>>>0<=x>>>0|0;c[B>>2]=$;B=f+16912+($<<2)|0;x=(c[B>>2]|0)>>>0<(c[ac>>2]|0)>>>0?$:w;c[ab>>2]=x;w=f+16912+(x<<2)|0;ac=(c[w>>2]|0)>>>0<(c[Y>>2]|0)>>>0?x:u;c[ah>>2]=ac;Y=(c[f+16912+(ac<<2)>>2]|0)>>>0<am>>>0?ac:8;c[z>>2]=Y;c[j>>2]=c[f+16912+(Y<<2)>>2];Y=c[g+68>>2]|0;c[f+16908>>2]=Y;b[f+20100>>1]=b[g+82>>1]|0;b[f+20102>>1]=b[g+84>>1]|0;g=a[A]|0;a[f+20104|0]=g;A=a[q]|0;c[f+16896>>2]=((a[f+335|0]&1&A&255)<<13)+(f+512);q=C|0;c[q>>2]=t;C=f+17036|0;c[C>>2]=t;ac=f+17040|0;c[ac>>2]=t;s=f+17044|0;c[s>>2]=t;c[al>>2]=n;c[U>>2]=n;c[W>>2]=n;c[N>>2]=n;c[ad>>2]=ai;c[X>>2]=ai;c[k>>2]=aj;c[ae>>2]=aj;v=V-49152|0;aa=f+17144|0;c[aa>>2]=v;Z=f+17080|0;c[Z>>2]=v;l=f+17176|0;I=(c[l>>2]|0)-53248|0;r=f+17148|0;c[r>>2]=I;H=f+17084|0;c[H>>2]=I;I=V-57344|0;D=f+17152|0;c[D>>2]=I;E=f+17088|0;c[E>>2]=I;c[ak>>2]=5;o=A&1;A=o<<24>>24==0;if(A){an=4096}else{L=a[f+368|0]&7;an=(L|0)==0?4096:L<<12}c[l>>2]=V+an;l=V+(an-53248)|0;c[r>>2]=l;c[H>>2]=l;an=(af-_|0)==32768;if((Y|0)==-1){ao=u}else{u=a[f+326|0]|0;do{if((u&255)<160){_=u<<24>>24>-1;af=f+17032|0;c[af>>2]=t;c[C>>2]=t;c[ac>>2]=t;c[s>>2]=t;c[al>>2]=n;c[U>>2]=n;c[W>>2]=n;c[N>>2]=n;c[ad>>2]=ai;c[X>>2]=ai;c[k>>2]=aj;c[ae>>2]=aj;c[aa>>2]=v;c[Z>>2]=v;c[r>>2]=l;c[H>>2]=l;c[D>>2]=I;c[E>>2]=I;c[ak>>2]=_?0:2;V=af;if(an){if(!_){break}yB(V|0,0,32);c[ad>>2]=0;c[X>>2]=0;c[k>>2]=0;c[ae>>2]=0;break}else{if(!_){break}yB(V|0,0,32);yB(ad|0,0,20);yB(k|0,0,20);break}}else{if((u&255)>>>0>=(254-(-(o&255)&30)|0)>>>0){c[ad>>2]=ai;c[X>>2]=ai;c[k>>2]=aj;c[ae>>2]=aj;c[aa>>2]=v;c[Z>>2]=v;c[r>>2]=l;c[H>>2]=l;c[D>>2]=I;c[E>>2]=I;c[ak>>2]=4;yB(G|0,0,32);if(an){c[ad>>2]=0;c[X>>2]=0;c[k>>2]=0;c[ae>>2]=0;break}else{yB(ad|0,0,20);yB(k|0,0,20);break}}V=(u&255)<192;c[q>>2]=t;c[C>>2]=t;c[ac>>2]=t;c[s>>2]=t;c[al>>2]=n;c[U>>2]=n;c[W>>2]=n;c[N>>2]=n;c[ad>>2]=ai;c[X>>2]=ai;c[k>>2]=aj;c[ae>>2]=aj;c[aa>>2]=v;c[Z>>2]=v;c[r>>2]=l;c[H>>2]=l;c[D>>2]=I;c[E>>2]=I;c[ak>>2]=V?1:3;if(!an){yB(G|0,0,32);yB(ad|0,0,20);yB(k|0,0,20);break}if(V){yB(G|0,0,32);c[ad>>2]=0;c[X>>2]=0;c[k>>2]=0;c[ae>>2]=0;break}else{c[Z>>2]=0;c[H>>2]=0;c[E>>2]=0;c[aa>>2]=0;c[r>>2]=0;c[D>>2]=0;break}}}while(0);D=(((g&255)<160?160:256)-(g&255)<<2)+Y|0;c[f+16928>>2]=D;Y=(c[f+16932>>2]|0)>>>0>D>>>0?4:5;c[f+17004>>2]=Y;D=(c[f+16912+(Y<<2)>>2]|0)>>>0<(c[f+16912+(P<<2)>>2]|0)>>>0?Y:P;c[p>>2]=D;p=(c[w>>2]|0)>>>0<(c[f+16912+(D<<2)>>2]|0)>>>0?x:D;c[ah>>2]=p;x=(c[f+16912+(p<<2)>>2]|0)>>>0<am>>>0?p:8;c[z>>2]=x;c[j>>2]=c[f+16912+(x<<2)>>2];ao=D}D=c[((a[f+320|0]|0)<0?f+19588|0:y)>>2]|0;c[m>>2]=D;m=F>>>0>D>>>0?2:3;c[J>>2]=m;J=(c[B>>2]|0)>>>0<(c[f+16912+(m<<2)>>2]|0)>>>0?$:m;c[ab>>2]=J;ab=(c[f+16912+(J<<2)>>2]|0)>>>0<(c[f+16912+(ao<<2)>>2]|0)>>>0?J:ao;c[ah>>2]=ab;ah=(c[f+16912+(ab<<2)>>2]|0)>>>0<am>>>0?ab:8;c[z>>2]=ah;c[j>>2]=c[f+16912+(ah<<2)>>2];a[f+20105|0]=0;if(!A){i=h;return}yB(f+8704|0,0,8192);i=h;return}function kM(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b+16924|0;do{if((c[e>>2]|0)>>>0<=d>>>0){c[e>>2]=-1;f=(c[b+16920>>2]|0)!=-1?2:3;c[b+17e3>>2]=f;g=c[b+16996>>2]|0;h=(c[b+16912+(g<<2)>>2]|0)>>>0<(c[b+16912+(f<<2)>>2]|0)>>>0?g:f;c[b+16984>>2]=h;f=c[b+16988>>2]|0;g=(c[b+16912+(h<<2)>>2]|0)>>>0<(c[b+16912+(f<<2)>>2]|0)>>>0?h:f;c[b+16976>>2]=g;f=b+16912+(g<<2)|0;h=b+16980|0;i=c[h>>2]|0;j=(c[f>>2]|0)>>>0<(c[b+16912+(i<<2)>>2]|0)>>>0?g:i;i=b+16972|0;c[i>>2]=j;k=b+16948|0;c[k>>2]=c[b+16912+(j<<2)>>2];a[b+257|0]=-1;j=b+258|0;a[j]=a[j]&127;j=b+17020|0;l=c[j>>2]|8;c[j>>2]=l;if((a[b+17028|0]|0)==0){break}if((c[b+17024>>2]&l|0)==0){break}l=c[b+17016>>2]|0;c[b+16944>>2]=l;c[b+17012>>2]=8;c[b+16992>>2]=8;c[h>>2]=8;h=(c[f>>2]|0)>>>0<l>>>0?g:8;c[i>>2]=h;c[k>>2]=c[b+16912+(h<<2)>>2]}}while(0);e=b+16936|0;if((c[e>>2]|0)>>>0>d>>>0){m=b+17268|0;oQ(m,d);return}h=b+16912|0;k=b+17256|0;do{oN(k,h);}while((c[e>>2]|0)>>>0<=d>>>0);m=b+17268|0;oQ(m,d);return}function kN(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;h=f+16908|0;if((c[h>>2]|0)!=-1){kO(f,g)}i=f+16912|0;j=f+16972|0;switch(c[j>>2]|0){case 1:{k=f+16916|0;c[k>>2]=-2;l=i|0;m=c[l>>2]|0;n=m>>>0>4294967293|0;o=f+16996|0;c[o>>2]=n;p=f+17e3|0;q=c[p>>2]|0;r=(c[f+16912+(n<<2)>>2]|0)>>>0<(c[f+16912+(q<<2)>>2]|0)>>>0?n:q;n=f+16984|0;c[n>>2]=r;s=f+16988|0;t=c[s>>2]|0;u=(c[f+16912+(r<<2)>>2]|0)>>>0<(c[f+16912+(t<<2)>>2]|0)>>>0?r:t;r=f+16976|0;c[r>>2]=u;v=f+16980|0;w=c[v>>2]|0;x=(c[f+16912+(u<<2)>>2]|0)>>>0<(c[f+16912+(w<<2)>>2]|0)>>>0?u:w;c[j>>2]=x;u=c[f+16912+(x<<2)>>2]|0;x=f+16948|0;c[x>>2]=u;if(u>>>0>g>>>0){y=g;z=m;A=q;B=t;C=w}else{w=g;do{w=kN(f,w)|0;if(w>>>0<(c[x>>2]|0)>>>0){break}}while((c[k>>2]|0)!=-1);y=w;z=c[l>>2]|0;A=c[p>>2]|0;B=c[s>>2]|0;C=c[v>>2]|0}c[k>>2]=-1;k=(z|0)==-1|0;c[o>>2]=k;o=(c[f+16912+(k<<2)>>2]|0)>>>0<(c[f+16912+(A<<2)>>2]|0)>>>0?k:A;c[n>>2]=o;n=(c[f+16912+(o<<2)>>2]|0)>>>0<(c[f+16912+(B<<2)>>2]|0)>>>0?o:B;c[r>>2]=n;r=(c[f+16912+(n<<2)>>2]|0)>>>0<(c[f+16912+(C<<2)>>2]|0)>>>0?n:C;c[j>>2]=r;c[x>>2]=c[f+16912+(r<<2)>>2];D=y;return D|0};case 2:{y=f+16920|0;r=c[y>>2]|0;x=(d[f+320|0]|0)>>>7;C=f+20105|0;n=a[C]&1;do{if((n|x)<<24>>24==0){E=g;F=(70224<<(a[f+17559|0]&1))+r|0;G=f+16924|0;H=f+17e3|0;I=f+16996|0;J=f+16984|0;K=f+16988|0;L=f+16976|0;M=f+16980|0;N=f+16948|0}else{B=n<<24>>24==0;o=f+17268|0;do{if((a[f+19362|0]|0)<=-1){A=f+19568|0;k=c[A>>2]|0;z=f+17532|0;v=f+17559|0;s=f+17540|0;if(k>>>0<=g>>>0){p=o|0;l=f+19284|0;w=f+19288|0;t=f+17528|0;q=f+17558|0;m=f+19292|0;u=k;do{k=c[z>>2]|0;O=a[v]&1;P=(u-k|0)>>>(O>>>0);c[z>>2]=(P<<O)+k;k=P+(c[s>>2]|0)|0;c[s>>2]=k;if((k|0)>-1){k=c[l>>2]|0;if((k|0)==0){Q=566992}else{Q=k+((ag(c[m>>2]|0,d[q]|0)|0)<<2)|0}c[w>>2]=Q;f2[c[c[t>>2]>>2]&1023](p)}oY(o);u=c[A>>2]|0;}while(u>>>0<=g>>>0)}u=c[z>>2]|0;A=a[v]&1;p=(g-u|0)>>>(A>>>0);c[z>>2]=(p<<A)+u;u=p+(c[s>>2]|0)|0;c[s>>2]=u;if((u|0)<=-1){break}u=c[f+19284>>2]|0;if((u|0)==0){R=566992}else{R=u+((ag(c[f+19292>>2]|0,d[f+17558|0]|0)|0)<<2)|0}c[f+19288>>2]=R;f2[c[c[f+17528>>2]>>2]&1023](o|0)}}while(0);o=f+19284|0;do{if(B){S=4633}else{u=c[o>>2]|0;if((u|0)==0){break}if((a[f+19379|0]&1)==0){T=c[f+19384>>2]|0}else{T=16316664}p=c[f+19292>>2]|0;A=u;u=143;while(1){t=160;w=A;while(1){c[w>>2]=T;q=t-1|0;if((q|0)>0){t=q;w=w+4|0}else{break}}if((u|0)==0){S=4633;break}else{A=A+(p<<2)|0;u=u-1|0}}}}while(0);do{if((S|0)==4633){if((c[o>>2]|0)==0){break}B=f+19684|0;u=c[B>>2]|0;if((u|0)==0){break}p=f5[c[(c[u>>2]|0)+8>>2]&255](u)|0;if((p|0)==0){u=c[B>>2]|0;if((u|0)!=0){f2[c[(c[u>>2]|0)+4>>2]&1023](u)}c[B>>2]=0;break}u=c[o>>2]|0;A=c[B>>2]|0;B=c[f+19292>>2]|0;s=ag(B,c[A+12>>2]|0)|0;z=u+(s+(c[A+8>>2]|0)<<2)|0;s=c[A+4>>2]|0;if((s|0)==0){u=c[A+16>>2]|0;v=c[A+20>>2]|0;if((v|0)==0|(u|0)==0){break}else{U=p;V=z;W=v}while(1){v=U;w=V;t=u;while(1){q=t-1|0;m=c[v>>2]|0;if((m|0)!=-1){l=c[w>>2]|0;c[w>>2]=(l+(m*7|0)-((l&460551)+((m&460551)*7|0)&460551)|0)>>>3}if((q|0)==0){break}else{v=v+4|0;w=w+4|0;t=q}}t=W-1|0;if((t|0)==0){break}else{U=U+(u<<2)|0;V=V+(B<<2)|0;W=t}}}else if((s|0)==1){u=c[A+16>>2]|0;t=c[A+20>>2]|0;if((t|0)==0|(u|0)==0){break}else{X=p;Y=z;Z=t}while(1){t=X;w=Y;v=u;while(1){q=v-1|0;m=c[t>>2]|0;if((m|0)!=-1){l=c[w>>2]|0;c[w>>2]=(l+(m*3|0)-((l&197379)+((m&197379)*3|0)&197379)|0)>>>2}if((q|0)==0){break}else{t=t+4|0;w=w+4|0;v=q}}v=Z-1|0;if((v|0)==0){break}else{X=X+(u<<2)|0;Y=Y+(B<<2)|0;Z=v}}}else{break}}}while(0);c[y>>2]=-1;o=f+16924|0;B=f+17e3|0;c[B>>2]=3;u=f+16996|0;z=c[u>>2]|0;p=c[o>>2]|0;A=(c[f+16912+(z<<2)>>2]|0)>>>0<p>>>0?z:3;z=f+16984|0;c[z>>2]=A;s=f+16988|0;v=c[s>>2]|0;w=f+16912+(v<<2)|0;t=(c[f+16912+(A<<2)>>2]|0)>>>0<(c[w>>2]|0)>>>0?A:v;A=f+16976|0;c[A>>2]=t;q=f+16980|0;m=c[q>>2]|0;l=f+16912+(m<<2)|0;k=(c[f+16912+(t<<2)>>2]|0)>>>0<(c[l>>2]|0)>>>0?t:m;c[j>>2]=k;t=f+16948|0;c[t>>2]=c[f+16912+(k<<2)>>2];c[f+16916>>2]=-1;k=(c[i>>2]|0)==-1|0;c[u>>2]=k;P=(c[f+16912+(k<<2)>>2]|0)>>>0<p>>>0?k:3;c[z>>2]=P;k=(c[f+16912+(P<<2)>>2]|0)>>>0<(c[w>>2]|0)>>>0?P:v;c[A>>2]=k;v=(c[f+16912+(k<<2)>>2]|0)>>>0<(c[l>>2]|0)>>>0?k:m;c[j>>2]=v;m=c[f+16912+(v<<2)>>2]|0;c[t>>2]=m;if(m>>>0>g>>>0){E=g;F=r;G=o;H=B;I=u;J=z;K=s;L=A;M=q;N=t;break}else{_=g}while(1){m=kN(f,_)|0;if(m>>>0<(c[t>>2]|0)>>>0){E=m;F=r;G=o;H=B;I=u;J=z;K=s;L=A;M=q;N=t;break}else{_=m}}}}while(0);a[C]=x^1;c[y>>2]=F;y=(c[G>>2]|0)>>>0>F>>>0?2:3;c[H>>2]=y;H=c[I>>2]|0;I=(c[f+16912+(H<<2)>>2]|0)>>>0<(c[f+16912+(y<<2)>>2]|0)>>>0?H:y;c[J>>2]=I;J=c[K>>2]|0;K=(c[f+16912+(I<<2)>>2]|0)>>>0<(c[f+16912+(J<<2)>>2]|0)>>>0?I:J;c[L>>2]=K;L=c[M>>2]|0;M=(c[f+16912+(K<<2)>>2]|0)>>>0<(c[f+16912+(L<<2)>>2]|0)>>>0?K:L;c[j>>2]=M;c[N>>2]=c[f+16912+(M<<2)>>2];D=E;return D|0};case 3:{E=f+16924|0;if((c[E>>2]|0)>>>0>g>>>0){D=g;return D|0}c[E>>2]=-1;E=(c[f+16920>>2]|0)!=-1?2:3;c[f+17e3>>2]=E;M=c[f+16996>>2]|0;N=(c[f+16912+(M<<2)>>2]|0)>>>0<(c[f+16912+(E<<2)>>2]|0)>>>0?M:E;c[f+16984>>2]=N;E=c[f+16988>>2]|0;M=(c[f+16912+(N<<2)>>2]|0)>>>0<(c[f+16912+(E<<2)>>2]|0)>>>0?N:E;c[f+16976>>2]=M;E=f+16912+(M<<2)|0;N=f+16980|0;L=c[N>>2]|0;K=(c[E>>2]|0)>>>0<(c[f+16912+(L<<2)>>2]|0)>>>0?M:L;c[j>>2]=K;L=f+16948|0;c[L>>2]=c[f+16912+(K<<2)>>2];a[f+257|0]=-1;K=f+258|0;a[K]=a[K]&127;K=f+17020|0;J=c[K>>2]|8;c[K>>2]=J;if((a[f+17028|0]|0)==0){D=g;return D|0}if((c[f+17024>>2]&J|0)==0){D=g;return D|0}J=c[f+17016>>2]|0;c[f+16944>>2]=J;c[f+17012>>2]=8;c[f+16992>>2]=8;c[N>>2]=8;N=(c[E>>2]|0)>>>0<J>>>0?M:8;c[j>>2]=N;c[L>>2]=c[f+16912+(N<<2)>>2];D=g;return D|0};case 4:{N=f+16928|0;if((c[h>>2]|0)==-1){$=-1}else{$=(c[N>>2]|0)+640|0}c[N>>2]=$;N=(c[f+16932>>2]|0)>>>0>$>>>0?4:5;c[f+17004>>2]=N;$=c[f+17008>>2]|0;L=(c[f+16912+(N<<2)>>2]|0)>>>0<(c[f+16912+($<<2)>>2]|0)>>>0?N:$;c[f+16988>>2]=L;$=c[f+16984>>2]|0;N=(c[f+16912+($<<2)>>2]|0)>>>0<(c[f+16912+(L<<2)>>2]|0)>>>0?$:L;c[f+16976>>2]=N;L=c[f+16980>>2]|0;$=(c[f+16912+(N<<2)>>2]|0)>>>0<(c[f+16912+(L<<2)>>2]|0)>>>0?N:L;c[j>>2]=$;c[f+16948>>2]=c[f+16912+($<<2)>>2];D=g;return D|0};case 5:{$=a[f+17559|0]&1;L=f+20100|0;N=b[L>>1]|0;M=N&65535;J=f+20102|0;E=b[J>>1]|0;K=E&65535;I=f+341|0;y=a[I]|0;H=((y&255)<<4&2032)+16|0;F=f+16932|0;G=(c[F>>2]|0)==0?16:H;c[F>>2]=-1;F=(c[f+16928>>2]|0)!=-1?4:5;c[f+17004>>2]=F;x=c[f+17008>>2]|0;C=(c[f+16912+(F<<2)>>2]|0)>>>0<(c[f+16912+(x<<2)>>2]|0)>>>0?F:x;c[f+16988>>2]=C;x=c[f+16984>>2]|0;F=(c[f+16912+(x<<2)>>2]|0)>>>0<(c[f+16912+(C<<2)>>2]|0)>>>0?x:C;c[f+16976>>2]=F;C=c[f+16980>>2]|0;x=(c[f+16912+(F<<2)>>2]|0)>>>0<(c[f+16912+(C<<2)>>2]|0)>>>0?F:C;c[j>>2]=x;c[f+16948>>2]=c[f+16912+(x<<2)>>2];if((G+K&65536|0)==0){aa=G;ab=y}else{G=y|-128;a[I]=G;aa=65536-K|0;ab=G}G=H-aa|0;H=(a[f+320|0]|0)<0;y=c[h>>2]|0;c[h>>2]=-1;if((aa|0)==0){ac=y;ad=E;ae=N;af=g;ah=ab}else{ab=2<<($&255);$=f+20104|0;N=f+17268|0;E=f+17184|0;x=f|0;C=f+17164|0;F=f+17032|0;_=f+17036|0;r=f+17040|0;Z=f+17044|0;Y=f+17168|0;X=f+17048|0;W=f+17052|0;V=f+17056|0;U=f+17060|0;S=f+17192|0;T=f+17072|0;R=f+17076|0;Q=f+17196|0;n=f+17136|0;t=f+17140|0;q=f+17172|0;A=f+17144|0;s=f+17080|0;z=f+17176|0;u=f+17148|0;B=f+17084|0;o=f+17152|0;m=f+17088|0;v=f+17200|0;k=y;y=K;l=M;P=g;w=aa;while(1){p=w-1|0;O=l+1|0;ai=l&65535;do{if((l&57344|0)==32768|ai>>>0>65023){aj=255}else{ak=c[f+17032+(ai>>>12<<2)>>2]|0;if((ak|0)==0){aj=kQ(f,ai,P)|0;break}else{aj=d[ak+ai|0]|0;break}}}while(0);ai=P+ab|0;do{if((ai-3|0)>>>0>k>>>0){ak=(d[$]|0)+1|0;a[$]=ak&255;al=k+4|0;am=ak&255;if(am>>>0>=160){if((am|0)!=160){an=al;break}a[$]=-2;ak=c[C>>2]|0;c[F>>2]=ak;c[_>>2]=ak;c[r>>2]=ak;c[Z>>2]=ak;ak=c[Y>>2]|0;c[X>>2]=ak;c[W>>2]=ak;c[V>>2]=ak;c[U>>2]=ak;ak=c[S>>2]|0;c[T>>2]=ak;c[R>>2]=ak;ak=c[Q>>2]|0;c[n>>2]=ak;c[t>>2]=ak;ak=c[q>>2]|0;ao=ak-49152|0;c[A>>2]=ao;c[s>>2]=ao;ao=(c[z>>2]|0)-53248|0;c[u>>2]=ao;c[B>>2]=ao;ao=ak-57344|0;c[o>>2]=ao;c[m>>2]=ao;c[v>>2]=5;oV(N,x,k+3|0);an=-1;break}if((am|0)==0){oV(N,c[E>>2]|0,k+3|0)}a[f+(l&255)|0]=aj&255;an=al}else{an=k}}while(0);kP(f,y&8191|32768,aj,ai);if((p|0)==0){break}else{k=an;y=y+1|0;l=O;P=ai;w=p}}w=(ag(aa,ab)|0)+g|0;ac=an;ad=aa+K&65535;ae=aa+M&65535;af=w;ah=a[I]|0}c[h>>2]=ac;h=af+4|0;b[L>>1]=ae;b[J>>1]=ad;ad=ah&128|(H?(G>>>4)+255|0:255);a[I]=ad&255;if((ad&128|0)==0){D=h;return D|0}if((c[f+19600>>2]|0)==-1){D=h;return D|0}if((ac|0)!=-1){kO(f,h)}oR(f+17268|0,h);D=h;return D|0};case 0:{h=f+17028|0;ac=a[h]&-3;a[h]=ac;if(ac<<24>>24==0){c[f+16944>>2]=-1;c[f+17012>>2]=8;c[f+16992>>2]=8;c[f+16980>>2]=8;ac=f+16976|0;h=c[ac>>2]|0;ad=(c[f+16912+(h<<2)>>2]|0)!=-1?h:8;c[j>>2]=ad;h=f+16948|0;c[h>>2]=c[f+16912+(ad<<2)>>2];ap=8;aq=ac;ar=h}else{ap=c[f+16980>>2]|0;aq=f+16976|0;ar=f+16948|0}c[i>>2]=-1;c[f+16996>>2]=1;h=c[f+17e3>>2]|0;ac=(c[f+16916>>2]|0)>>>0<(c[f+16912+(h<<2)>>2]|0)>>>0?1:h;c[f+16984>>2]=ac;h=c[f+16988>>2]|0;ad=(c[f+16912+(ac<<2)>>2]|0)>>>0<(c[f+16912+(h<<2)>>2]|0)>>>0?ac:h;c[aq>>2]=ad;aq=(c[f+16912+(ad<<2)>>2]|0)>>>0<(c[f+16912+(ap<<2)>>2]|0)>>>0?ad:ap;c[j>>2]=aq;c[ar>>2]=c[f+16912+(aq<<2)>>2];D=g;return D|0};case 6:{oN(f+17256|0,i);D=g;return D|0};case 7:{oQ(f+17268|0,g);D=g;return D|0};case 8:{aq=f+17028|0;ar=a[aq]|0;if((ar&2)==0){as=g;at=ar}else{ap=(a[f+19379|0]&1)!=0?g+4|0:g;ad=ar&-3;a[aq]=ad;if(ad<<24>>24==0){c[f+16944>>2]=-1;c[f+17012>>2]=8;c[f+16992>>2]=8;c[f+16980>>2]=8;ar=f+16976|0;h=c[ar>>2]|0;ac=(c[f+16912+(h<<2)>>2]|0)!=-1?h:8;c[j>>2]=ac;h=f+16948|0;c[h>>2]=c[f+16912+(ac<<2)>>2];au=8;av=ar;aw=h}else{au=c[f+16980>>2]|0;av=f+16976|0;aw=f+16948|0}c[i>>2]=-1;c[f+16996>>2]=1;i=c[f+17e3>>2]|0;h=(c[f+16916>>2]|0)>>>0<(c[f+16912+(i<<2)>>2]|0)>>>0?1:i;c[f+16984>>2]=h;i=c[f+16988>>2]|0;ar=(c[f+16912+(h<<2)>>2]|0)>>>0<(c[f+16912+(i<<2)>>2]|0)>>>0?h:i;c[av>>2]=ar;av=(c[f+16912+(ar<<2)>>2]|0)>>>0<(c[f+16912+(au<<2)>>2]|0)>>>0?ar:au;c[j>>2]=av;c[aw>>2]=c[f+16912+(av<<2)>>2];as=ap;at=ad}if((at&1)==0){D=as;return D|0}ad=f+17020|0;ap=c[ad>>2]|0;av=c[f+17024>>2]&ap;aw=av&-av;if(aw>>>0<8){ax=d[56856+(aw-1)|0]|0}else{ax=aw+80&65535}c[ad>>2]=ap^aw;aw=at&-2;a[aq]=aw;if(aw<<24>>24==0){c[f+16944>>2]=-1;c[f+17012>>2]=8;c[f+16992>>2]=8;c[f+16980>>2]=8;aw=c[f+16976>>2]|0;aq=(c[f+16912+(aw<<2)>>2]|0)!=-1?aw:8;c[j>>2]=aq;c[f+16948>>2]=c[f+16912+(aq<<2)>>2]}aq=f+20092|0;j=c[aq>>2]|0;b[j>>1]=(b[j>>1]|0)-1&65535;j=e[c[aq>>2]>>1]|0;aw=f+20096|0;at=(e[c[aw>>2]>>1]|0)>>>8;ap=c[f+17096+(j>>>12<<2)>>2]|0;if((ap|0)==0){kP(f,j,at,as+8|0)}else{a[ap+j|0]=at&255}at=c[aq>>2]|0;b[at>>1]=(b[at>>1]|0)-1&65535;at=e[c[aq>>2]>>1]|0;aq=b[c[aw>>2]>>1]|0;j=c[f+17096+(at>>>12<<2)>>2]|0;if((j|0)==0){kP(f,at,aq&255,as+12|0)}else{a[j+at|0]=aq&255}b[c[aw>>2]>>1]=ax;D=as+20|0;return D|0};default:{D=g;return D|0}}return 0}function kO(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b+17200|0;g=c[f>>2]|0;do{if((g|0)==2){h=(c[b+16896>>2]|0)+(d[b+326|0]<<8&7936)|0}else if((g|0)==3){i=d[b+326|0]|0;h=(c[b+17172+((i>>>4&1)<<2)>>2]|0)+(i<<8&3840)|0}else if((g|0)==0){i=d[b+326|0]|0;h=(c[b+17164+(i>>>6<<2)>>2]|0)+(i<<8)|0}else if((g|0)==1){i=c[b+17192>>2]|0;if((i|0)==0){h=0;break}h=i+(d[b+326|0]<<8)|0}else{if((a[b+326|0]|0)==-1){if((a[b+19379|0]&1)==0){h=566832;break}}h=c[b+17184>>2]|0}}while(0);g=b+16908|0;i=c[g>>2]|0;j=(e-i|0)>>>2;e=j-1|0;if((j|0)==0){return}j=b+20104|0;k=b+17268|0;l=b+17184|0;m=b+17208|0;L6253:do{if((h|0)==0){n=e;o=i;while(1){p=(a[j]|0)+1&255;a[j]=p;c[g>>2]=o+4;if((p&255)<160){if(p<<24>>24==0){oV(k,c[l>>2]|0,o+3|0);q=a[j]|0}else{q=p}a[b+(q&255)|0]=a[c[m>>2]|0]|0}else{if(p<<24>>24==-96){r=o;break L6253}}if((n|0)==0){break}n=n-1|0;o=c[g>>2]|0}return}else{o=e;n=i;while(1){p=(a[j]|0)+1&255;a[j]=p;c[g>>2]=n+4;if((p&255)<160){if(p<<24>>24==0){oV(k,c[l>>2]|0,n+3|0);s=a[j]|0}else{s=p}t=s&255;a[b+t|0]=a[h+t|0]|0}else{if(p<<24>>24==-96){r=n;break L6253}}if((o|0)==0){break}o=o-1|0;n=c[g>>2]|0}return}}while(0);a[j]=-2;j=c[b+17164>>2]|0;c[b+17032>>2]=j;c[b+17036>>2]=j;c[b+17040>>2]=j;c[b+17044>>2]=j;j=c[b+17168>>2]|0;c[b+17048>>2]=j;c[b+17052>>2]=j;c[b+17056>>2]=j;c[b+17060>>2]=j;j=c[b+17192>>2]|0;c[b+17072>>2]=j;c[b+17076>>2]=j;j=c[b+17196>>2]|0;c[b+17136>>2]=j;c[b+17140>>2]=j;j=c[b+17172>>2]|0;h=j-49152|0;c[b+17144>>2]=h;c[b+17080>>2]=h;h=(c[b+17176>>2]|0)-53248|0;c[b+17148>>2]=h;c[b+17084>>2]=h;h=j-57344|0;c[b+17152>>2]=h;c[b+17088>>2]=h;c[f>>2]=5;oV(k,b|0,r+3|0);c[g>>2]=-1;return}function kP(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;do{if((c[f+16908>>2]|0)!=-1){kO(f,i);j=c[f+17200>>2]|0;k=(a[f+19379|0]&1)!=0?55848:55800;if((e[k+(j<<3)>>1]|0)>>>0<=g>>>0){break}if((g-(e[k+(j<<3)+2>>1]|0)|0)>>>0<(e[k+(j<<3)+4>>1]|0)>>>0){break}j=a[f+20104|0]|0;if((j&255)>=160){break}a[f+(j&255)|0]=h&255;return}}while(0);if(g>>>0>=65024){if((g-65408|0)>>>0<=126){a[f+(g-65024)|0]=h&255;return}if(g>>>0>=65280){kR(f,g,h,i);return}j=f+17268|0;k=f+19362|0;do{if((a[k]|0)<=-1){if((c[f+19276>>2]|0)>>>0>i>>>0){break}l=f+19568|0;m=c[l>>2]|0;do{if(m>>>0>i>>>0){n=f+17559|0;o=f+17558|0}else{p=f+17532|0;q=f+17559|0;r=f+17540|0;s=j|0;t=f+19284|0;u=f+19288|0;v=f+17528|0;w=f+17558|0;x=f+19292|0;y=m;do{z=c[p>>2]|0;A=a[q]&1;B=(y-z|0)>>>(A>>>0);c[p>>2]=(B<<A)+z;z=B+(c[r>>2]|0)|0;c[r>>2]=z;if((z|0)>-1){z=c[t>>2]|0;if((z|0)==0){C=566992}else{C=z+((ag(c[x>>2]|0,d[w]|0)|0)<<2)|0}c[u>>2]=C;f2[c[c[v>>2]>>2]&1023](s)}oY(j);y=c[l>>2]|0;}while(y>>>0<=i>>>0);y=c[p>>2]|0;z=a[q]&1;B=(i-y|0)>>>(z>>>0);c[p>>2]=(B<<z)+y;y=B+(c[r>>2]|0)|0;c[r>>2]=y;if((y|0)<=-1){n=q;o=w;break}y=c[t>>2]|0;if((y|0)==0){D=566992}else{D=y+((ag(c[x>>2]|0,d[w]|0)|0)<<2)|0}c[u>>2]=D;f2[c[c[v>>2]>>2]&1023](s);n=q;o=w}}while(0);m=f+17552|0;y=c[m>>2]|0;B=a[n]|0;z=B&1;A=a[f+19379|0]&1;E=a[o]|0;if((459-((y-i|0)>>>(z>>>0))+A-(z<<1)|0)>>>0>455){if((E&255)>142&E<<24>>24!=-103){break}return}if((E&255)>143){break}E=i+2+z-A|0;A=f+19680|0;z=c[A>>2]|0;if(z>>>0>i>>>0){F=z;G=y}else{do{if((a[k]|0)>-1){H=f+17532|0;I=f+17540|0}else{y=c[l>>2]|0;z=f+17532|0;J=f+17540|0;if(y>>>0>i>>>0){L=B}else{M=j|0;N=f+19284|0;O=f+19288|0;P=f+17528|0;Q=f+19292|0;R=y;y=B;while(1){S=c[z>>2]|0;T=y&1;U=(R-S|0)>>>(T>>>0);c[z>>2]=(U<<T)+S;S=U+(c[J>>2]|0)|0;c[J>>2]=S;if((S|0)>-1){S=c[N>>2]|0;if((S|0)==0){V=566992}else{V=S+((ag(c[Q>>2]|0,d[o]|0)|0)<<2)|0}c[O>>2]=V;f2[c[c[P>>2]>>2]&1023](M)}oY(j);S=c[l>>2]|0;U=a[n]|0;if(S>>>0>i>>>0){L=U;break}else{R=S;y=U}}}y=c[z>>2]|0;R=L&1;M=(i-y|0)>>>(R>>>0);c[z>>2]=(M<<R)+y;y=M+(c[J>>2]|0)|0;c[J>>2]=y;if((y|0)<=-1){H=z;I=J;break}y=c[f+19284>>2]|0;if((y|0)==0){W=566992}else{W=y+((ag(c[f+19292>>2]|0,d[o]|0)|0)<<2)|0}c[f+19288>>2]=W;f2[c[c[f+17528>>2]>>2]&1023](j|0);H=z;I=J}}while(0);l=c[H>>2]|0;B=ga[c[(c[f+17528>>2]|0)+4>>2]&127](j|0,167,-(c[I>>2]|0)|0)|0;y=(B<<(a[n]&1))+l|0;c[A>>2]=y;F=y;G=c[m>>2]|0}if(E>>>0>=(F>>>0<G>>>0?F:c[f+17536>>2]|0)>>>0){break}return}}while(0);if((d[f+20104|0]|0)<=159){return}do{if(g>>>0>=65184){if((a[f+19379|0]&1)!=0){break}return}}while(0);if((a[k]|0)<=-1){k=f+19568|0;F=c[k>>2]|0;G=f+17532|0;n=f+17559|0;I=f+17540|0;if(F>>>0<=i>>>0){H=j|0;W=f+19284|0;o=f+19288|0;L=f+17528|0;V=f+17558|0;D=f+19292|0;C=F;do{F=c[G>>2]|0;y=a[n]&1;l=(C-F|0)>>>(y>>>0);c[G>>2]=(l<<y)+F;F=l+(c[I>>2]|0)|0;c[I>>2]=F;if((F|0)>-1){F=c[W>>2]|0;if((F|0)==0){X=566992}else{X=F+((ag(c[D>>2]|0,d[V]|0)|0)<<2)|0}c[o>>2]=X;f2[c[c[L>>2]>>2]&1023](H)}oY(j);C=c[k>>2]|0;}while(C>>>0<=i>>>0)}C=c[G>>2]|0;H=a[n]&1;L=(i-C|0)>>>(H>>>0);c[G>>2]=(L<<H)+C;C=L+(c[I>>2]|0)|0;c[I>>2]=C;if((C|0)>-1){C=c[f+19284>>2]|0;if((C|0)==0){Y=566992}else{Y=C+((ag(c[f+19292>>2]|0,d[f+17558|0]|0)|0)<<2)|0}c[f+19288>>2]=Y;f2[c[c[f+17528>>2]>>2]&1023](j|0)}qC(f+19148|0,i);j=c[f+19268>>2]|0;Y=a[j+7|0]&1;C=459-(((c[j>>2]|0)-(c[f+19276>>2]|0)|0)>>>(Y>>>0))-(-Y&3)|0;Y=C>>>0>455?C-456|0:C;a[f+19280|0]=Y>>>0>80?80:Y&255;Y=(80<<(a[n]&1))+(c[f+17552>>2]|0)|0;n=e[f+17556>>1]|0;C=Y-((Y-i|0)>>>0>n>>>0?n:0)|0;c[f+19596>>2]=C;n=(c[f+19600>>2]|0)>>>0>C>>>0?4:5;c[f+19652>>2]=n;C=c[f+19656>>2]|0;Y=(c[f+19580+(n<<2)>>2]|0)>>>0<(c[f+19580+(C<<2)>>2]|0)>>>0?n:C;c[f+19640>>2]=Y;C=c[f+19636>>2]|0;n=(c[f+19580+(C<<2)>>2]|0)>>>0<(c[f+19580+(Y<<2)>>2]|0)>>>0?C:Y;c[f+19632>>2]=n;Y=c[f+19580+(n<<2)>>2]|0;c[f+19612>>2]=Y;c[f+19560>>2]=Y;n=(c[f+19564>>2]|0)>>>0<=Y>>>0|0;c[f+19576>>2]=n;c[k>>2]=c[f+19560+(n<<2)>>2];n=c[f+19660>>2]|0;c[n+28>>2]=Y;k=(c[n+24>>2]|0)>>>0<Y>>>0?6:7;c[n+96>>2]=k;Y=c[n+92>>2]|0;C=(c[n+(Y<<2)>>2]|0)>>>0<(c[n+(k<<2)>>2]|0)>>>0?Y:k;c[n+76>>2]=C;k=c[n+72>>2]|0;Y=(c[n+(k<<2)>>2]|0)>>>0<(c[n+(C<<2)>>2]|0)>>>0?k:C;c[n+64>>2]=Y;C=c[n+68>>2]|0;k=(c[n+(Y<<2)>>2]|0)>>>0<(c[n+(C<<2)>>2]|0)>>>0?Y:C;c[n+60>>2]=k;c[n+36>>2]=c[n+(k<<2)>>2]}a[f+(g-65024)|0]=h&255;return}if(g>>>0>=40960){if(g>>>0>=49152){a[(c[f+17172+((g>>>12&1)<<2)>>2]|0)+(g&4095)|0]=h&255;return}k=c[f+17196>>2]|0;if((k|0)!=0){a[k+g|0]=h&255;return}k=f+17208|0;n=f+17212|0;C=k+(c[n+4>>2]|0)|0;Y=c[n>>2]|0;if((Y&1|0)==0){Z=Y}else{Z=c[(c[C>>2]|0)+(Y-1)>>2]|0}f3[Z&1023](C,h);a[c[k>>2]|0]=h&255;return}if(g>>>0>=32768){k=f+17268|0;if(!(oS(k,i)|0)){return}oQ(k,i);a[(c[f+16896>>2]|0)+(g-32768)|0]=h&255;return}i=f+17032|0;k=f+17164|0;C=c[k>>2]|0;Z=C+327|0;Y=a[Z]|0;if((Y&255)>=31){dL(31e3,94,55216,30624)}n=Y&255;Y=d[55896+n|0]|0;L122:do{switch(g>>>12&7|0){case 0:case 1:{do{if((n-5|0)>>>0<2){if((g&256|0)==0){break}return}}while(0);E=(h&15|0)==10;m=E&1;a[f+17251|0]=m;L128:do{if(((d[Z]|0)-15|0)>>>0<2){A=f+17208|0;a[f+17246|0]=m;do{if(E){j=a[f+17240|0]|0;if((j&255)>4){break}switch(j&255|0){case 0:{c[A>>2]=f+17245;j=f+17212|0;c[j>>2]=648;c[j+4>>2]=0;break L128;break};case 1:{c[A>>2]=f+17244;j=f+17212|0;c[j>>2]=150;c[j+4>>2]=0;break L128;break};case 2:{c[A>>2]=f+17243;j=f+17212|0;c[j>>2]=402;c[j+4>>2]=0;break L128;break};case 3:{c[A>>2]=f+17242;j=f+17212|0;c[j>>2]=82;c[j+4>>2]=0;break L128;break};case 4:{c[A>>2]=f+17241;j=f+17212|0;c[j>>2]=300;c[j+4>>2]=0;break L128;break};default:{break L128}}}}while(0);c[A>>2]=0;J=f+17212|0;c[J>>2]=0;c[J+4>>2]=0}}while(0);m=c[f+17208>>2]|0;J=d[f+17250|0]|0;z=c[f+17184>>2]|0;j=z-40960|0;I=f+17192|0;c[I>>2]=j;L=(c[f+17188>>2]|0)-40960|0;H=f+17196|0;c[H>>2]=L;do{if(E){if((m|0)!=0){c[H>>2]=0;c[I>>2]=0;_=0;$=0;break}G=c[f+17180>>2]|0;if((G|0)==(c[f+17172>>2]|0)){_=j;$=L;break}X=G+((J<<13)-40960)|0;c[H>>2]=X;c[I>>2]=X;_=X;$=X}else{_=j;$=L}}while(0);L=f+17072|0;c[L>>2]=_;j=f+17076|0;c[j>>2]=_;I=f+17136|0;c[I>>2]=$;H=f+17140|0;c[H>>2]=$;J=i;m=c[f+17200>>2]|0;if((z-(c[f+17172>>2]|0)|0)!=32768){if(!((m|0)==0|(m|0)==1|(m|0)==3|(m|0)==4)){return}yB(J|0,0,32);yB(L|0,0,20);yB(I|0,0,20);return}if((m|0)==0|(m|0)==1|(m|0)==4){yB(J|0,0,32);c[L>>2]=0;c[j>>2]=0;c[I>>2]=0;c[H>>2]=0;return}else if((m|0)==3){c[f+17080>>2]=0;c[f+17084>>2]=0;c[f+17088>>2]=0;c[f+17144>>2]=0;c[f+17148>>2]=0;c[f+17152>>2]=0;return}else{return}break};case 2:{if((Y|0)==1){aa=43;break L122}else if((Y|0)==2){aa=47;break L122}else if((Y|0)==3){aa=49;break L122}else if((Y|0)!=4){return}m=f+17248|0;H=(((c[f+17180>>2]|0)-C|0)/16384|0)+65535&(b[m>>1]&256|h);b[m>>1]=H&65535;m=H&65535;H=C+((((m|0)==0)+m<<14)-16384)|0;c[f+17168>>2]=H;c[f+17048>>2]=H;c[f+17052>>2]=H;c[f+17056>>2]=H;c[f+17060>>2]=H;H=i;m=c[f+17200>>2]|0;if(((c[f+17184>>2]|0)-(c[f+17172>>2]|0)|0)!=32768){if(!((m|0)==0|(m|0)==1|(m|0)==3|(m|0)==4)){return}yB(H|0,0,32);yB(f+17072|0,0,20);yB(f+17136|0,0,20);return}if((m|0)==0|(m|0)==1|(m|0)==4){yB(H|0,0,32);c[f+17072>>2]=0;c[f+17076>>2]=0;c[f+17136>>2]=0;c[f+17140>>2]=0;return}else if((m|0)==3){c[f+17080>>2]=0;c[f+17084>>2]=0;c[f+17088>>2]=0;c[f+17144>>2]=0;c[f+17148>>2]=0;c[f+17152>>2]=0;return}else{return}break};case 3:{if((Y|0)==1){aa=43;break L122}else if((Y|0)==2){aa=47;break L122}else if((Y|0)==3){aa=49;break L122}else if((Y|0)==4){m=f+17248|0;H=(((c[f+17180>>2]|0)-C|0)/16384|0)+511&(b[m>>1]&255|h<<8&256);b[m>>1]=H&65535;ab=H;aa=53;break L122}else{return}break};case 4:case 5:{do{if((Y|0)==1){H=h&3;if((a[f+17252|0]&1)!=0){m=H&255;a[f+17250|0]=m;ac=m;break}m=f+17248|0;I=(((c[f+17180>>2]|0)-C|0)/16384|0)+127&(b[m>>1]&31|H<<5);b[m>>1]=I&65535;m=C+((((I&31|0)==0)+I<<14)-16384)|0;c[f+17168>>2]=m;c[f+17048>>2]=m;c[f+17052>>2]=m;c[f+17056>>2]=m;c[f+17060>>2]=m;m=i;I=c[f+17200>>2]|0;if(((c[f+17184>>2]|0)-(c[f+17172>>2]|0)|0)!=32768){if(!((I|0)==0|(I|0)==1|(I|0)==3|(I|0)==4)){return}yB(m|0,0,32);yB(f+17072|0,0,20);yB(f+17136|0,0,20);return}if((I|0)==0|(I|0)==1|(I|0)==4){yB(m|0,0,32);c[f+17072>>2]=0;c[f+17076>>2]=0;c[f+17136>>2]=0;c[f+17140>>2]=0;return}else if((I|0)==3){c[f+17080>>2]=0;c[f+17084>>2]=0;c[f+17088>>2]=0;c[f+17144>>2]=0;c[f+17148>>2]=0;c[f+17152>>2]=0;return}else{return}}else if((Y|0)==3){L202:do{if((n-15|0)>>>0<2){I=f+17208|0;m=(h&15)+248|0;H=m&255;a[f+17240|0]=H;if((a[f+17246|0]&1)==0|(H&255)>4){c[I>>2]=0;H=f+17212|0;c[H>>2]=0;c[H+4>>2]=0;break}switch(m&255|0){case 0:{c[I>>2]=f+17245;m=f+17212|0;c[m>>2]=648;c[m+4>>2]=0;break L202;break};case 1:{c[I>>2]=f+17244;m=f+17212|0;c[m>>2]=150;c[m+4>>2]=0;break L202;break};case 2:{c[I>>2]=f+17243;m=f+17212|0;c[m>>2]=402;c[m+4>>2]=0;break L202;break};case 3:{c[I>>2]=f+17242;m=f+17212|0;c[m>>2]=82;c[m+4>>2]=0;break L202;break};case 4:{c[I>>2]=f+17241;I=f+17212|0;c[I>>2]=300;c[I+4>>2]=0;break L202;break};default:{break L202}}}}while(0);A=h&3;a[f+17250|0]=A;ac=A}else if((Y|0)==4){A=h&15;a[f+17250|0]=A;ac=A}else{return}}while(0);z=c[f+17172>>2]|0;A=c[f+17180>>2]|0;I=z;m=((I-A|0)/8192|0)+255&(ac&255);a[f+17250|0]=m&255;H=(a[f+17251|0]&1)==0;j=c[f+17208>>2]|0;L=c[f+17184>>2]|0;J=L-40960|0;E=f+17192|0;c[E>>2]=J;X=(c[f+17188>>2]|0)-40960|0;G=f+17196|0;c[G>>2]=X;do{if(H){ad=J;ae=X}else{if((j|0)!=0){c[G>>2]=0;c[E>>2]=0;ad=0;ae=0;break}if((A|0)==(z|0)){ad=J;ae=X;break}o=A+((m<<13)-40960)|0;c[G>>2]=o;c[E>>2]=o;ad=o;ae=o}}while(0);E=f+17072|0;c[E>>2]=ad;G=f+17076|0;c[G>>2]=ad;m=f+17136|0;c[m>>2]=ae;A=f+17140|0;c[A>>2]=ae;X=i;J=c[f+17200>>2]|0;if((L-I|0)!=32768){if(!((J|0)==0|(J|0)==1|(J|0)==3|(J|0)==4)){return}yB(X|0,0,32);yB(E|0,0,20);yB(m|0,0,20);return}if((J|0)==0|(J|0)==1|(J|0)==4){yB(X|0,0,32);c[E>>2]=0;c[G>>2]=0;c[m>>2]=0;c[A>>2]=0;return}else if((J|0)==3){c[f+17080>>2]=0;c[f+17084>>2]=0;c[f+17088>>2]=0;c[f+17144>>2]=0;c[f+17148>>2]=0;c[f+17152>>2]=0;return}else{return}break};case 6:case 7:{if((Y|0)==1){a[f+17252|0]=h&1;return}else if((Y|0)==3){J=f+17247|0;if((a[J]&1)==0&(h|0)==1){A=f+17241|0;m=a[A]|0;if((m&64)==0){G=fp(0)|0;af=(G|0)<0?-1:0;ah=G;ai=a[A]|0}else{G=f+17232|0;af=c[G+4>>2]|0;ah=c[G>>2]|0;ai=m}m=f+17224|0;G=c[m>>2]|0;E=c[m+4>>2]|0;X=yM(ah,af,G,E)|0;z=K;j=0;if(z>>>0>j>>>0|z>>>0==j>>>0&X>>>0>44150400>>>0){j=z;H=X;o=E;E=G;G=ai;do{E=yL(E,o,44150400,0)|0;o=K;H=yL(H,j,-44150400,-1)|0;j=K;G=G|-128;V=0;}while(j>>>0>V>>>0|j>>>0==V>>>0&H>>>0>44150400>>>0);c[m>>2]=E;c[m+4>>2]=o;a[A]=G;aj=j;ak=H;al=G}else{aj=z;ak=X;al=ai}I=yW(ak,aj,86400,0)|0;a[f+17242|0]=I&255;a[A]=((I>>>8|K<<24)&1|al&-2&255)&255;I=yX(ak,aj,86400,0)|0;L=K;V=yW(I,L,3600,0)|0;a[f+17243|0]=V&255;V=yX(I,L,3600,0)|0;L=K;I=yW(V,L,60,0)|0;a[f+17244|0]=I&255;I=yX(V,L,60,0)|0;a[f+17245|0]=I&255}a[J]=(h|0)!=0|0;return}else{return}break};default:{return}}}while(0);do{if((aa|0)==43){if((a[f+17252|0]&1)==0){aj=f+17248|0;am=(b[aj>>1]&96|h&31)&65535;an=aj}else{am=h&31;an=f+17248|0}b[an>>1]=am;ao=am;ap=f+17248|0;aa=51}else if((aa|0)==47){if((g&256|0)==0){return}else{aj=h&15;ak=f+17248|0;b[ak>>1]=aj;ao=aj;ap=ak;aa=51;break}}else if((aa|0)==49){ak=h&127&(((c[f+17180>>2]|0)-C|0)/16384|0)+127;b[f+17248>>1]=ak&65535;aq=ak}}while(0);do{if((aa|0)==51){h=(((c[f+17180>>2]|0)-C|0)/16384|0)+65535&(ao&65535);b[ap>>1]=h&65535;if((Y|0)==4){ab=h;aa=53;break}else if((Y|0)!=1){aq=h;break}if((h&31|0)==0){ar=h;aa=54}else{aq=h}}}while(0);if((aa|0)==53){if((ab|0)==0){ar=0;aa=54}else{aq=ab}}if((aa|0)==54){aq=ar+1|0}ar=(c[k>>2]|0)+((aq<<14)-16384)|0;c[f+17168>>2]=ar;c[f+17048>>2]=ar;c[f+17052>>2]=ar;c[f+17056>>2]=ar;c[f+17060>>2]=ar;ar=i;i=c[f+17200>>2]|0;if(((c[f+17184>>2]|0)-(c[f+17172>>2]|0)|0)!=32768){if(!((i|0)==0|(i|0)==1|(i|0)==3|(i|0)==4)){return}yB(ar|0,0,32);yB(f+17072|0,0,20);yB(f+17136|0,0,20);return}if((i|0)==0|(i|0)==1|(i|0)==4){yB(ar|0,0,32);c[f+17072>>2]=0;c[f+17076>>2]=0;c[f+17136>>2]=0;c[f+17140>>2]=0;return}else if((i|0)==3){c[f+17080>>2]=0;c[f+17084>>2]=0;c[f+17088>>2]=0;c[f+17144>>2]=0;c[f+17148>>2]=0;c[f+17152>>2]=0;return}else{return}}function kQ(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;do{if(f>>>0<65408){do{if((c[b+16908>>2]|0)!=-1){kO(b,g);h=c[b+17200>>2]|0;i=(a[b+19379|0]&1)!=0?55848:55800;if((e[i+(h<<3)>>1]|0)>>>0<=f>>>0){break}if((f-(e[i+(h<<3)+2>>1]|0)|0)>>>0<(e[i+(h<<3)+4>>1]|0)>>>0){break}h=a[b+20104|0]|0;if((h&255)>=160){break}j=d[b+(h&255)|0]|0;return j|0}}while(0);if(f>>>0<49152){if(f>>>0<32768){j=d[(c[b+17164+(f>>>14<<2)>>2]|0)+f|0]|0;return j|0}if(f>>>0<40960){if(!(oS(b+17268|0,g)|0)){j=255;return j|0}j=d[(c[b+16896>>2]|0)+(f-32768)|0]|0;return j|0}h=c[b+17192>>2]|0;if((h|0)==0){j=d[c[b+17208>>2]|0]|0;return j|0}else{j=d[h+f|0]|0;return j|0}}if(f>>>0<65024){j=d[(c[b+17172+((f>>>12&1)<<2)>>2]|0)+(f&4095)|0]|0;return j|0}if(f>>>0>65279){j=kK(b,f,g)|0;return j|0}h=b+17268|0;i=b+19362|0;do{if((a[i]|0)<=-1){if((c[b+19276>>2]|0)>>>0>g>>>0){break}k=b+19568|0;l=c[k>>2]|0;do{if(l>>>0>g>>>0){m=b+17559|0;n=b+17558|0}else{o=b+17532|0;p=b+17559|0;q=b+17540|0;r=h|0;s=b+19284|0;t=b+19288|0;u=b+17528|0;v=b+17558|0;w=b+19292|0;x=l;do{y=c[o>>2]|0;z=a[p]&1;A=(x-y|0)>>>(z>>>0);c[o>>2]=(A<<z)+y;y=A+(c[q>>2]|0)|0;c[q>>2]=y;if((y|0)>-1){y=c[s>>2]|0;if((y|0)==0){B=566992}else{B=y+((ag(c[w>>2]|0,d[v]|0)|0)<<2)|0}c[t>>2]=B;f2[c[c[u>>2]>>2]&1023](r)}oY(h);x=c[k>>2]|0;}while(x>>>0<=g>>>0);x=c[o>>2]|0;y=a[p]&1;A=(g-x|0)>>>(y>>>0);c[o>>2]=(A<<y)+x;x=A+(c[q>>2]|0)|0;c[q>>2]=x;if((x|0)<=-1){m=p;n=v;break}x=c[s>>2]|0;if((x|0)==0){C=566992}else{C=x+((ag(c[w>>2]|0,d[v]|0)|0)<<2)|0}c[t>>2]=C;f2[c[c[u>>2]>>2]&1023](r);m=p;n=v}}while(0);l=b+17552|0;x=c[l>>2]|0;A=a[m]|0;y=A&1;z=a[n]|0;if((460-((x-g|0)>>>(y>>>0))-(-y&3)|0)>>>0>455){if((z&255)>142&z<<24>>24!=-103){break}else{j=255}return j|0}if((z&255)>143){break}z=g+2+y-(a[b+19379|0]&1)|0;y=b+19680|0;D=c[y>>2]|0;if(D>>>0>g>>>0){E=D;F=x}else{do{if((a[i]|0)>-1){G=b+17532|0;H=b+17540|0}else{x=c[k>>2]|0;D=b+17532|0;I=b+17540|0;if(x>>>0>g>>>0){J=A}else{K=h|0;L=b+19284|0;M=b+19288|0;N=b+17528|0;O=b+19292|0;P=x;x=A;while(1){Q=c[D>>2]|0;R=x&1;S=(P-Q|0)>>>(R>>>0);c[D>>2]=(S<<R)+Q;Q=S+(c[I>>2]|0)|0;c[I>>2]=Q;if((Q|0)>-1){Q=c[L>>2]|0;if((Q|0)==0){T=566992}else{T=Q+((ag(c[O>>2]|0,d[n]|0)|0)<<2)|0}c[M>>2]=T;f2[c[c[N>>2]>>2]&1023](K)}oY(h);Q=c[k>>2]|0;S=a[m]|0;if(Q>>>0>g>>>0){J=S;break}else{P=Q;x=S}}}x=c[D>>2]|0;P=J&1;K=(g-x|0)>>>(P>>>0);c[D>>2]=(K<<P)+x;x=K+(c[I>>2]|0)|0;c[I>>2]=x;if((x|0)<=-1){G=D;H=I;break}x=c[b+19284>>2]|0;if((x|0)==0){U=566992}else{U=x+((ag(c[b+19292>>2]|0,d[n]|0)|0)<<2)|0}c[b+19288>>2]=U;f2[c[c[b+17528>>2]>>2]&1023](h|0);G=D;H=I}}while(0);k=c[G>>2]|0;A=ga[c[(c[b+17528>>2]|0)+4>>2]&127](h|0,167,-(c[H>>2]|0)|0)|0;x=(A<<(a[m]&1))+k|0;c[y>>2]=x;E=x;F=c[l>>2]|0}if(z>>>0<(E>>>0<F>>>0?E:c[b+17536>>2]|0)>>>0){j=255}else{break}return j|0}}while(0);if((d[b+20104|0]|0)<160){j=255}else{break}return j|0}}while(0);j=d[b+(f-65024)|0]|0;return j|0}function kR(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0;j=f+16908|0;if((c[j>>2]|0)!=-1){kO(f,i)}L382:do{switch(g&255|0){case 0:{k=(a[f+256|0]&207|h&240)&255;break};case 1:{l=f+16924|0;do{if((c[l>>2]|0)>>>0<=i>>>0){c[l>>2]=-1;m=(c[f+16920>>2]|0)!=-1?2:3;c[f+17e3>>2]=m;n=c[f+16996>>2]|0;o=(c[f+16912+(n<<2)>>2]|0)>>>0<(c[f+16912+(m<<2)>>2]|0)>>>0?n:m;c[f+16984>>2]=o;m=c[f+16988>>2]|0;n=(c[f+16912+(o<<2)>>2]|0)>>>0<(c[f+16912+(m<<2)>>2]|0)>>>0?o:m;c[f+16976>>2]=n;m=f+16912+(n<<2)|0;o=f+16980|0;p=c[o>>2]|0;q=(c[m>>2]|0)>>>0<(c[f+16912+(p<<2)>>2]|0)>>>0?n:p;p=f+16972|0;c[p>>2]=q;r=f+16948|0;c[r>>2]=c[f+16912+(q<<2)>>2];a[f+257|0]=-1;q=f+258|0;a[q]=a[q]&127;q=f+17020|0;s=c[q>>2]|8;c[q>>2]=s;if((a[f+17028|0]|0)==0){break}if((c[f+17024>>2]&s|0)==0){break}s=c[f+17016>>2]|0;c[f+16944>>2]=s;c[f+17012>>2]=8;c[f+16992>>2]=8;c[o>>2]=8;o=(c[m>>2]|0)>>>0<s>>>0?n:8;c[p>>2]=o;c[r>>2]=c[f+16912+(o<<2)>>2]}}while(0);k=h&255;break};case 2:{l=f+16924|0;do{if((c[l>>2]|0)>>>0<=i>>>0){c[l>>2]=-1;o=(c[f+16920>>2]|0)!=-1?2:3;c[f+17e3>>2]=o;r=c[f+16996>>2]|0;p=(c[f+16912+(r<<2)>>2]|0)>>>0<(c[f+16912+(o<<2)>>2]|0)>>>0?r:o;c[f+16984>>2]=p;o=c[f+16988>>2]|0;r=(c[f+16912+(p<<2)>>2]|0)>>>0<(c[f+16912+(o<<2)>>2]|0)>>>0?p:o;c[f+16976>>2]=r;o=f+16912+(r<<2)|0;p=f+16980|0;n=c[p>>2]|0;s=(c[o>>2]|0)>>>0<(c[f+16912+(n<<2)>>2]|0)>>>0?r:n;n=f+16972|0;c[n>>2]=s;m=f+16948|0;c[m>>2]=c[f+16912+(s<<2)>>2];a[f+257|0]=-1;s=f+258|0;a[s]=a[s]&127;s=f+17020|0;q=c[s>>2]|8;c[s>>2]=q;if((a[f+17028|0]|0)==0){break}if((c[f+17024>>2]&q|0)==0){break}q=c[f+17016>>2]|0;c[f+16944>>2]=q;c[f+17012>>2]=8;c[f+16992>>2]=8;c[p>>2]=8;p=(c[o>>2]|0)>>>0<q>>>0?r:8;c[n>>2]=p;c[m>>2]=c[f+16912+(p<<2)>>2]}}while(0);p=(a[f+19379|0]&1)<<1;if((h&129|0)==129){m=((p&h|0)!=0?128:4096)+i|0;c[l>>2]=m;n=(c[f+16920>>2]|0)>>>0<m>>>0?2:3;c[f+17e3>>2]=n;m=c[f+16996>>2]|0;r=(c[f+16912+(m<<2)>>2]|0)>>>0<(c[f+16912+(n<<2)>>2]|0)>>>0?m:n;c[f+16984>>2]=r;n=c[f+16988>>2]|0;m=(c[f+16912+(r<<2)>>2]|0)>>>0<(c[f+16912+(n<<2)>>2]|0)>>>0?r:n;c[f+16976>>2]=m;n=c[f+16980>>2]|0;r=(c[f+16912+(m<<2)>>2]|0)>>>0<(c[f+16912+(n<<2)>>2]|0)>>>0?m:n;c[f+16972>>2]=r;c[f+16948>>2]=c[f+16912+(r<<2)>>2]}k=(126-p|h)&255;break};case 4:{a[f+260|0]=0;c[f+16904>>2]=i;return};case 5:{p=a[f+17266|0]|0;if((p&4)==0){t=f+17264|0}else{r=f+16936|0;n=c[r>>2]|0;if(n>>>0>i>>>0){u=84328+(p&3)|0}else{m=f+17265|0;q=f+16940|0;o=f+17008|0;s=f+17004|0;v=f+16988|0;w=f+16984|0;x=f+16976|0;y=f+16980|0;z=f+16972|0;A=f+16948|0;B=f+17020|0;D=f+17024|0;E=f+17016|0;F=f+16944|0;G=f+17012|0;H=f+16992|0;I=(a[f+17028|0]|0)==0;J=c[B>>2]|0;K=n;while(1){n=J|4;c[B>>2]=n;do{if(!I){if((c[D>>2]&n|0)==0){break}L=c[E>>2]|0;c[F>>2]=L;c[G>>2]=8;c[H>>2]=8;c[y>>2]=8;M=c[x>>2]|0;N=(c[f+16912+(M<<2)>>2]|0)>>>0<L>>>0?M:8;c[z>>2]=N;c[A>>2]=c[f+16912+(N<<2)>>2]}}while(0);N=84328+(p&3)|0;M=(256-(d[m]|0)<<d[N])+K|0;c[r>>2]=M;L=(c[q>>2]|0)>>>0>M>>>0?6:7;c[o>>2]=L;O=c[s>>2]|0;P=(c[f+16912+(O<<2)>>2]|0)>>>0<(c[f+16912+(L<<2)>>2]|0)>>>0?O:L;c[v>>2]=P;L=c[w>>2]|0;O=(c[f+16912+(L<<2)>>2]|0)>>>0<(c[f+16912+(P<<2)>>2]|0)>>>0?L:P;c[x>>2]=O;P=c[y>>2]|0;L=(c[f+16912+(O<<2)>>2]|0)>>>0<(c[f+16912+(P<<2)>>2]|0)>>>0?O:P;c[z>>2]=L;c[A>>2]=c[f+16912+(L<<2)>>2];if(M>>>0>i>>>0){u=N;break}else{J=n;K=M}}}K=f+17256|0;J=c[K>>2]|0;A=d[u]|0;z=(i-J|0)>>>(A>>>0);y=(z<<A)+J|0;c[K>>2]=y;K=f+17260|0;J=c[K>>2]|0;if(J>>>0>i>>>0){Q=a[f+17264|0]|0;R=J}else{if((J+4|0)>>>0>i>>>0){S=J}else{c[K>>2]=-1;S=-1}J=a[f+17265|0]|0;a[f+17264|0]=J;Q=J;R=S}J=f+17264|0;x=(Q&255)+z|0;if(x>>>0>256){z=d[f+17265|0]|-256;w=x;while(1){v=w+z|0;if(v>>>0>256){w=v}else{T=v;break}}}else{T=x}w=T&255;do{if((T|0)==256){z=y+3|0;c[K>>2]=z;if(z>>>0>i>>>0){U=0;V=z;break}if((y+7|0)>>>0>i>>>0){W=z}else{c[K>>2]=-1;W=-1}U=a[f+17265|0]|0;V=W}else{U=w;V=R}}while(0);a[J]=U;if((V-i|0)>>>0<4){c[K>>2]=-1}w=(256-h<<A)+3+y|0;c[r>>2]=w;x=(c[f+16940>>2]|0)>>>0>w>>>0?6:7;c[f+17008>>2]=x;w=c[f+17004>>2]|0;z=(c[f+16912+(w<<2)>>2]|0)>>>0<(c[f+16912+(x<<2)>>2]|0)>>>0?w:x;c[f+16988>>2]=z;x=c[f+16984>>2]|0;w=(c[f+16912+(x<<2)>>2]|0)>>>0<(c[f+16912+(z<<2)>>2]|0)>>>0?x:z;c[f+16976>>2]=w;z=c[f+16980>>2]|0;x=(c[f+16912+(w<<2)>>2]|0)>>>0<(c[f+16912+(z<<2)>>2]|0)>>>0?w:z;c[f+16972>>2]=x;c[f+16948>>2]=c[f+16912+(x<<2)>>2];t=J}x=h&255;a[t]=x;k=x;break};case 6:{x=a[f+17266|0]|0;if((x&4)!=0){z=f+16936|0;w=c[z>>2]|0;if(w>>>0>i>>>0){X=84328+(x&3)|0}else{v=f+17265|0;s=f+16940|0;o=f+17008|0;q=f+17004|0;m=f+16988|0;p=f+16984|0;H=f+16976|0;G=f+16980|0;F=f+16972|0;E=f+16948|0;D=f+17020|0;I=f+17024|0;B=f+17016|0;l=f+16944|0;M=f+17012|0;N=f+16992|0;L=(a[f+17028|0]|0)==0;P=c[D>>2]|0;O=w;while(1){w=P|4;c[D>>2]=w;do{if(!L){if((c[I>>2]&w|0)==0){break}Y=c[B>>2]|0;c[l>>2]=Y;c[M>>2]=8;c[N>>2]=8;c[G>>2]=8;Z=c[H>>2]|0;_=(c[f+16912+(Z<<2)>>2]|0)>>>0<Y>>>0?Z:8;c[F>>2]=_;c[E>>2]=c[f+16912+(_<<2)>>2]}}while(0);n=84328+(x&3)|0;_=(256-(d[v]|0)<<d[n])+O|0;c[z>>2]=_;Z=(c[s>>2]|0)>>>0>_>>>0?6:7;c[o>>2]=Z;Y=c[q>>2]|0;$=(c[f+16912+(Y<<2)>>2]|0)>>>0<(c[f+16912+(Z<<2)>>2]|0)>>>0?Y:Z;c[m>>2]=$;Z=c[p>>2]|0;Y=(c[f+16912+(Z<<2)>>2]|0)>>>0<(c[f+16912+($<<2)>>2]|0)>>>0?Z:$;c[H>>2]=Y;$=c[G>>2]|0;Z=(c[f+16912+(Y<<2)>>2]|0)>>>0<(c[f+16912+($<<2)>>2]|0)>>>0?Y:$;c[F>>2]=Z;c[E>>2]=c[f+16912+(Z<<2)>>2];if(_>>>0>i>>>0){X=n;break}else{P=w;O=_}}}O=f+17256|0;P=c[O>>2]|0;E=d[X]|0;F=(i-P|0)>>>(E>>>0);G=(F<<E)+P|0;c[O>>2]=G;O=f+17260|0;P=c[O>>2]|0;if(P>>>0>i>>>0){aa=a[f+17264|0]|0}else{if((P+4|0)>>>0<=i>>>0){c[O>>2]=-1}P=a[f+17265|0]|0;a[f+17264|0]=P;aa=P}P=f+17264|0;E=(aa&255)+F|0;if(E>>>0>256){F=d[f+17265|0]|-256;H=E;while(1){p=H+F|0;if(p>>>0>256){H=p}else{ab=p;break}}}else{ab=E}H=ab&255;do{if((ab|0)==256){F=G+3|0;c[O>>2]=F;if(F>>>0>i>>>0){ac=0;break}if((G+7|0)>>>0<=i>>>0){c[O>>2]=-1}ac=a[f+17265|0]|0}else{ac=H}}while(0);a[P]=ac}H=h&255;a[f+17265|0]=H;k=H;break};case 7:{H=h|248;O=f+17256|0;G=f+17266|0;E=a[G]|0;F=E&255;if((F|0)!=(H|0)){p=f+16936|0;m=c[p>>2]|0;if((E&4)==0){ad=m}else{if(m>>>0>i>>>0){ae=84328+(F&3)|0}else{E=f+17265|0;q=f+16940|0;o=f+17008|0;s=f+17004|0;z=f+16988|0;v=f+16984|0;x=f+16976|0;N=f+16980|0;M=f+16972|0;l=f+16948|0;B=f+17020|0;I=f+17024|0;L=f+17016|0;D=f+16944|0;J=f+17012|0;r=f+16992|0;y=(a[f+17028|0]|0)==0;A=c[B>>2]|0;K=m;while(1){_=A|4;c[B>>2]=_;do{if(!y){if((c[I>>2]&_|0)==0){break}n=c[L>>2]|0;c[D>>2]=n;c[J>>2]=8;c[r>>2]=8;c[N>>2]=8;Z=c[x>>2]|0;$=(c[f+16912+(Z<<2)>>2]|0)>>>0<n>>>0?Z:8;c[M>>2]=$;c[l>>2]=c[f+16912+($<<2)>>2]}}while(0);w=84328+(F&3)|0;$=(256-(d[E]|0)<<d[w])+K|0;c[p>>2]=$;Z=(c[q>>2]|0)>>>0>$>>>0?6:7;c[o>>2]=Z;n=c[s>>2]|0;Y=(c[f+16912+(n<<2)>>2]|0)>>>0<(c[f+16912+(Z<<2)>>2]|0)>>>0?n:Z;c[z>>2]=Y;Z=c[v>>2]|0;n=(c[f+16912+(Z<<2)>>2]|0)>>>0<(c[f+16912+(Y<<2)>>2]|0)>>>0?Z:Y;c[x>>2]=n;Y=c[N>>2]|0;Z=(c[f+16912+(n<<2)>>2]|0)>>>0<(c[f+16912+(Y<<2)>>2]|0)>>>0?n:Y;c[M>>2]=Z;c[l>>2]=c[f+16912+(Z<<2)>>2];if($>>>0>i>>>0){ae=w;break}else{A=_;K=$}}}K=O|0;A=c[K>>2]|0;l=d[ae]|0;M=(i-A|0)>>>(l>>>0);N=(M<<l)+A|0;c[K>>2]=N;A=f+17260|0;x=c[A>>2]|0;if(x>>>0>i>>>0){af=a[f+17264|0]|0;ah=x}else{if((x+4|0)>>>0>i>>>0){ai=x}else{c[A>>2]=-1;ai=-1}x=a[f+17265|0]|0;a[f+17264|0]=x;af=x;ah=ai}x=f+17264|0;v=(af&255)+M|0;if(v>>>0>256){M=d[f+17265|0]|-256;z=v;while(1){s=z+M|0;if(s>>>0>256){z=s}else{aj=s;break}}}else{aj=v}z=aj&255;do{if((aj|0)==256){M=N+3|0;c[A>>2]=M;if(M>>>0>i>>>0){ak=0;al=M;break}if((N+7|0)>>>0>i>>>0){am=M}else{c[A>>2]=-1;am=-1}ak=a[f+17265|0]|0;al=am}else{ak=z;al=ah}}while(0);a[x]=ak;z=-1<<l-1;v=z-3|0;M=v+N|0;c[K>>2]=M;s=v+al|0;c[A>>2]=s;do{if((m-3+z|0)>>>0<=i>>>0){v=f+17020|0;o=c[v>>2]|4;c[v>>2]=o;if((a[f+17028|0]|0)==0){break}if((c[f+17024>>2]&o|0)==0){break}o=c[f+17016>>2]|0;c[f+16944>>2]=o;c[f+17012>>2]=8;c[f+16992>>2]=8;c[f+16980>>2]=8;v=c[f+16976>>2]|0;q=(c[f+16912+(v<<2)>>2]|0)>>>0<o>>>0?v:8;c[f+16972>>2]=q;c[f+16948>>2]=c[f+16912+(q<<2)>>2]}}while(0);z=(i-M|0)>>>(l>>>0);m=(z<<l)+M|0;c[K>>2]=m;if(s>>>0>i>>>0){an=ak}else{if((s+4|0)>>>0<=i>>>0){c[A>>2]=-1}N=a[f+17265|0]|0;a[x]=N;an=N}N=(an&255)+z|0;if(N>>>0>256){z=d[f+17265|0]|-256;q=N;while(1){v=q+z|0;if(v>>>0>256){q=v}else{ao=v;break}}}else{ao=N}q=ao&255;do{if((ao|0)==256){z=m+3|0;c[A>>2]=z;if(z>>>0>i>>>0){ap=0;break}if((m+7|0)>>>0<=i>>>0){c[A>>2]=-1}ap=a[f+17265|0]|0}else{ap=q}}while(0);a[x]=ap;c[A>>2]=-1;ad=-1}if((h&4|0)==0){aq=ad}else{q=d[84328+(h&3)|0]|0;m=i>>>(q>>>0)<<q;c[O>>2]=m;aq=m+3+(256-(d[f+17264|0]|0)<<q)|0}c[p>>2]=aq;q=(c[f+16940>>2]|0)>>>0>aq>>>0?6:7;c[f+17008>>2]=q;m=c[f+17004>>2]|0;N=(c[f+16912+(m<<2)>>2]|0)>>>0<(c[f+16912+(q<<2)>>2]|0)>>>0?m:q;c[f+16988>>2]=N;q=c[f+16984>>2]|0;m=(c[f+16912+(q<<2)>>2]|0)>>>0<(c[f+16912+(N<<2)>>2]|0)>>>0?q:N;c[f+16976>>2]=m;N=c[f+16980>>2]|0;q=(c[f+16912+(m<<2)>>2]|0)>>>0<(c[f+16912+(N<<2)>>2]|0)>>>0?m:N;c[f+16972>>2]=q;c[f+16948>>2]=c[f+16912+(q<<2)>>2]}q=H&255;a[G]=q;k=q;break};case 15:{kM(f,i);q=h|224;c[f+17020>>2]=q;if((a[f+17028|0]|0)==0){return}if((c[f+17024>>2]&q|0)==0){ar=-1}else{ar=c[f+17016>>2]|0}c[f+16944>>2]=ar;c[f+17012>>2]=8;c[f+16992>>2]=8;c[f+16980>>2]=8;q=c[f+16976>>2]|0;N=(c[f+16912+(q<<2)>>2]|0)>>>0<ar>>>0?q:8;c[f+16972>>2]=N;c[f+16948>>2]=c[f+16912+(N<<2)>>2];return};case 16:{if((a[f+20088|0]&1)==0){return}kS(f+19692|0,i,a[f+17559|0]&1);do{if((a[f+19787|0]&1)!=0){if((h&8|0)!=0){break}N=c[f+19776>>2]|0;f2[c[(c[N>>2]|0)+8>>2]&1023](N)}}while(0);a[f+19786|0]=h&255;G=f+19768|0;H=f+19788|0;c[H>>2]=G;if((c[f+19756>>2]|0)>>>0<(c[f+19772>>2]|0)>>>0){p=f+19752|0;c[H>>2]=p;as=p}else{as=G}if((c[f+19720>>2]|0)>>>0<(c[as+4>>2]|0)>>>0){c[H>>2]=f+19716}k=(h|128)&255;break};case 17:{H=f+19692|0;do{if((a[f+20088|0]&1)==0){if((a[f+19379|0]&1)==0){at=h&63;break}else{return}}else{at=h}}while(0);kS(H,i,a[f+17559|0]&1);G=a[f+19804|0]|0;p=c[f+19792>>2]|0;O=(d[f+19730|0]&(at^65535))+1|0;b[f+19728>>1]=O&65535;if((G&64)==0){au=-1}else{au=(O<<13&536862720)+p&-8192}c[f+19720>>2]=au;O=f+19740|0;G=c[O>>2]|0;if(G>>>0>p>>>0){av=G;aw=a[f+19746|0]|0}else{A=e[f+19744>>1]|0;x=(((p-G|0)>>>0)/(A>>>0)|0)+1|0;p=(ag(x,A)|0)+G|0;c[O>>2]=p;O=f+19746|0;G=(d[O]|0)+x&7;a[O]=G;av=p;aw=G}G=at>>>6;a[f+19747|0]=G&255;p=aw&255;a[f+19748|0]=(d[72384+(G&255)|0]&1<<p|0)!=0|0;if((a[f+19749|0]&1)==0|(av|0)==-1){c[f+19736>>2]=-1}else{c[f+19736>>2]=(ag(d[56824+(p|G<<3&2040)|0]|0,e[f+19744>>1]|0)|0)+av}G=f+19768|0;p=f+19788|0;c[p>>2]=G;if((c[f+19756>>2]|0)>>>0<(c[f+19772>>2]|0)>>>0){O=f+19752|0;c[p>>2]=O;ax=O}else{ax=G}if(au>>>0<(c[ax+4>>2]|0)>>>0){c[p>>2]=f+19716}k=(at|63)&255;break};case 18:{p=f+19692|0;if((a[f+20088|0]&1)==0){return}kS(p,i,a[f+17559|0]&1);G=f+19764|0;O=a[G]|0;do{if((O&7)==0){if((c[f+19756>>2]|0)==-1){ay=424;break}x=f+19765|0;A=(a[x]|0)+1&255;a[x]=A;az=A}else{ay=424}}while(0);do{if((ay|0)==424){H=f+19765|0;A=a[H]|0;if((O&8)!=0){az=A;break}x=A+2&255;a[H]=x;az=x}}while(0);x=f+19765|0;if(((O&255^h)&8|0)==0){aA=az}else{H=16-az&255;a[x]=H;aA=H}a[x]=aA&15;x=h&255;a[G]=x;if((h&248|0)==0){H=f+19704|0;f2[c[(c[H>>2]|0)+8>>2]&1023](H)}else{f3[c[(c[p>>2]|0)+8>>2]&1023](p|0,c[f+19792>>2]|0)}H=f+19768|0;A=f+19788|0;c[A>>2]=H;if((c[f+19756>>2]|0)>>>0<(c[f+19772>>2]|0)>>>0){N=f+19752|0;c[A>>2]=N;aB=N}else{aB=H}if((c[f+19720>>2]|0)>>>0>=(c[aB+4>>2]|0)>>>0){k=x;break L382}c[A>>2]=f+19716;k=x;break};case 19:{if((a[f+20088|0]&1)==0){return}kS(f+19692|0,i,a[f+17559|0]&1);x=c[f+19792>>2]|0;A=f+19744|0;H=e[A>>1]|0;N=f+19740|0;q=c[N>>2]|0;if(q>>>0>x>>>0){aC=q}else{m=(((x-q|0)>>>0)/(H>>>0)|0)+1|0;x=(ag(m,H)|0)+q|0;c[N>>2]=x;N=f+19746|0;a[N]=(d[N]|0)+m&7;aC=x}x=2048-(-(H>>>1)&1792|h)<<1;b[A>>1]=x&65535;if((a[f+19749|0]&1)==0|(aC|0)==-1){c[f+19736>>2]=-1}else{c[f+19736>>2]=(ag(d[56824+(d[f+19747|0]<<3|d[f+19746|0])|0]|0,x&65534)|0)+aC}x=f+19768|0;A=f+19788|0;c[A>>2]=x;if((c[f+19756>>2]|0)>>>0<(c[f+19772>>2]|0)>>>0){H=f+19752|0;c[A>>2]=H;aD=H}else{aD=x}if((c[f+19720>>2]|0)>>>0>=(c[aD+4>>2]|0)>>>0){return}c[A>>2]=f+19716;return};case 20:{A=f+19692|0;if((a[f+20088|0]&1)==0){return}kS(A,i,a[f+17559|0]&1);x=f+19804|0;H=a[x]|0;m=f+19792|0;N=c[m>>2]|0;q=f+19720|0;z=c[q>>2]|0;if((z|0)!=-1){b[f+19728>>1]=(z>>>13)-(N>>>13)&65535}z=(h&64|0)!=0;do{if(z){s=N>>>12&1^1;if((H&64)!=0){aE=s;break}K=f+19728|0;M=b[K>>1]|0;if(M<<16>>16==0){aE=s;break}l=(M&65535)-s&65535;b[K>>1]=l;if(l<<16>>16!=0){aE=s;break}l=c[f+19724>>2]|0;f2[c[(c[l>>2]|0)+8>>2]&1023](l);aE=s}else{aE=0}}while(0);H=(h&128|0)==0;do{if(!H){p=f+19728|0;if((b[p>>1]|0)!=0){break}b[p>>1]=1-aE+(d[f+19730|0]|0)&65535}}while(0);do{if(z){p=b[f+19728>>1]|0;if(p<<16>>16==0){aF=-1;break}aF=((p&65535)<<13)+N&-8192}else{aF=-1}}while(0);c[q>>2]=aF;a[x]=h&255;px(f+19732|0,h,c[m>>2]|0);if(H){aG=f+19756|0}else{a[x]=a[x]&127;N=c[m>>2]|0;z=a[f+19764|0]|0;p=z&7;G=f+19756|0;c[G>>2]=N-(N+28672&32767)+(((p|0)==0?8:p)+((N&28672|0)==0)<<15);a[f+19765|0]=(z&255)>>>4;a[f+19805|0]=(z&255)>7|0;z=f+19787|0;a[z]=0;p=2048-((e[(c[f+19780>>2]|0)+12>>1]|0)>>>1)&65535;b[f+19784>>1]=p;O=d[f+19786|0]|0;s=O>>>4&7;l=O&7;if((s|l|0)==0){c[f+19772>>2]=-1}else{c[f+19772>>2]=((s|0)!=0?s<<14:131072)+N&-16384}do{if((l|0)==0){aH=N}else{s=p&65535;K=s>>>(l>>>0);if((O&8|0)==0){aI=K+s|0}else{a[z]=1;aI=s-K|0}if((aI&2048|0)==0){aH=N;break}K=c[f+19776>>2]|0;f2[c[(c[K>>2]|0)+8>>2]&1023](K);aH=c[m>>2]|0}}while(0);f3[c[(c[A>>2]|0)+8>>2]&1023](A|0,aH);aG=G}m=f+19768|0;N=f+19788|0;c[N>>2]=m;if((c[aG>>2]|0)>>>0<(c[f+19772>>2]|0)>>>0){z=f+19752|0;c[N>>2]=z;aJ=z}else{aJ=m}if((c[q>>2]|0)>>>0<(c[aJ+4>>2]|0)>>>0){c[N>>2]=f+19716}k=(h|191)&255;break};case 22:{N=f+19692|0;do{if((a[f+20088|0]&1)==0){if((a[f+19379|0]&1)==0){aK=h&63;break}else{return}}else{aK=h}}while(0);kS(N,i,a[f+17559|0]&1);q=a[f+19900|0]|0;G=c[f+19888>>2]|0;A=(d[f+19846|0]&(aK^65535))+1|0;b[f+19844>>1]=A&65535;if((q&64)==0){aL=-1}else{aL=(A<<13&536862720)+G&-8192}c[f+19836>>2]=aL;A=f+19856|0;q=c[A>>2]|0;if(q>>>0>G>>>0){aM=q;aN=a[f+19862|0]|0}else{m=e[f+19860>>1]|0;z=(((G-q|0)>>>0)/(m>>>0)|0)+1|0;G=(ag(z,m)|0)+q|0;c[A>>2]=G;A=f+19862|0;q=(d[A]|0)+z&7;a[A]=q;aM=G;aN=q}q=aK>>>6;a[f+19863|0]=q&255;G=aN&255;a[f+19864|0]=(d[72384+(q&255)|0]&1<<G|0)!=0|0;if((a[f+19865|0]&1)==0|(aM|0)==-1){c[f+19852>>2]=-1}else{c[f+19852>>2]=(ag(d[56824+(G|q<<3&2040)|0]|0,e[f+19860>>1]|0)|0)+aM}q=f+19884|0;c[q>>2]=f+19868;if(aL>>>0<(c[f+19872>>2]|0)>>>0){c[q>>2]=f+19832}k=(aK|63)&255;break};case 23:{if((a[f+20088|0]&1)==0){return}kS(f+19692|0,i,a[f+17559|0]&1);q=f+19808|0;G=f+19880|0;A=a[G]|0;do{if((A&7)==0){if((c[f+19872>>2]|0)==-1){ay=494;break}z=f+19881|0;m=(a[z]|0)+1&255;a[z]=m;aO=m}else{ay=494}}while(0);do{if((ay|0)==494){N=f+19881|0;m=a[N]|0;if((A&8)!=0){aO=m;break}z=m+2&255;a[N]=z;aO=z}}while(0);z=f+19881|0;if(((A&255^h)&8|0)==0){aP=aO}else{N=16-aO&255;a[z]=N;aP=N}a[z]=aP&15;z=h&255;a[G]=z;if((h&248|0)==0){N=f+19820|0;f2[c[(c[N>>2]|0)+8>>2]&1023](N)}else{f3[c[(c[q>>2]|0)+8>>2]&1023](q|0,c[f+19888>>2]|0)}N=f+19884|0;c[N>>2]=f+19868;if((c[f+19836>>2]|0)>>>0>=(c[f+19872>>2]|0)>>>0){k=z;break L382}c[N>>2]=f+19832;k=z;break};case 24:{if((a[f+20088|0]&1)==0){return}kS(f+19692|0,i,a[f+17559|0]&1);z=c[f+19888>>2]|0;N=f+19860|0;m=e[N>>1]|0;O=f+19856|0;l=c[O>>2]|0;if(l>>>0>z>>>0){aQ=l}else{p=(((z-l|0)>>>0)/(m>>>0)|0)+1|0;z=(ag(p,m)|0)+l|0;c[O>>2]=z;O=f+19862|0;a[O]=(d[O]|0)+p&7;aQ=z}z=2048-(-(m>>>1)&1792|h)<<1;b[N>>1]=z&65535;if((a[f+19865|0]&1)==0|(aQ|0)==-1){c[f+19852>>2]=-1}else{c[f+19852>>2]=(ag(d[56824+(d[f+19863|0]<<3|d[f+19862|0])|0]|0,z&65534)|0)+aQ}z=f+19884|0;c[z>>2]=f+19868;if((c[f+19836>>2]|0)>>>0>=(c[f+19872>>2]|0)>>>0){return}c[z>>2]=f+19832;return};case 25:{if((a[f+20088|0]&1)==0){return}kS(f+19692|0,i,a[f+17559|0]&1);z=f+19808|0;N=f+19900|0;m=a[N]|0;p=f+19888|0;O=c[p>>2]|0;l=f+19836|0;x=c[l>>2]|0;if((x|0)!=-1){b[f+19844>>1]=(x>>>13)-(O>>>13)&65535}x=(h&64|0)!=0;do{if(x){H=O>>>12&1^1;if((m&64)!=0){aR=H;break}K=f+19844|0;s=b[K>>1]|0;if(s<<16>>16==0){aR=H;break}M=(s&65535)-H&65535;b[K>>1]=M;if(M<<16>>16!=0){aR=H;break}M=c[f+19840>>2]|0;f2[c[(c[M>>2]|0)+8>>2]&1023](M);aR=H}else{aR=0}}while(0);m=(h&128|0)==0;do{if(!m){q=f+19844|0;if((b[q>>1]|0)!=0){break}b[q>>1]=1-aR+(d[f+19846|0]|0)&65535}}while(0);do{if(x){q=b[f+19844>>1]|0;if(q<<16>>16==0){aS=-1;break}aS=((q&65535)<<13)+O&-8192}else{aS=-1}}while(0);c[l>>2]=aS;O=h&255;a[N]=O;if(m){aT=f+19872|0}else{a[N]=O&127;O=c[p>>2]|0;x=a[f+19880|0]|0;q=x&7;G=f+19872|0;c[G>>2]=O-(O+28672&32767)+(((q|0)==0?8:q)+((O&28672|0)==0)<<15);a[f+19881|0]=(x&255)>>>4;a[f+19901|0]=(x&255)>7|0;f3[c[(c[z>>2]|0)+8>>2]&1023](z|0,O);aT=G}px(f+19848|0,h,c[p>>2]|0);G=f+19884|0;c[G>>2]=f+19868;if((c[l>>2]|0)>>>0<(c[aT>>2]|0)>>>0){c[G>>2]=f+19832}k=(h|191)&255;break};case 26:{if((a[f+20088|0]&1)==0){return}kS(f+19692|0,i,a[f+17559|0]&1);G=h&128;a[f+19968|0]=G&255;if((G|0)==0){G=f+19920|0;f2[c[(c[G>>2]|0)+8>>2]&1023](G)}k=(h|127)&255;break};case 27:{G=f+19692|0;do{if((a[f+20088|0]&1)==0){if((a[f+19379|0]&1)==0){break}return}}while(0);kS(G,i,a[f+17559|0]&1);l=a[f+19970|0]|0;p=c[f+19948>>2]|0;z=(d[f+19946|0]&(h^65535))+1|0;b[f+19944>>1]=z&65535;if((l&64)==0){aU=-1}else{aU=(z<<13&536862720)+p&-8192}c[f+19936>>2]=aU;return};case 28:{if((a[f+20088|0]&1)==0){return}else{kS(f+19692|0,i,a[f+17559|0]&1);p=(h>>>5&3)+255|0;a[f+19972|0]=(p&252)>>>0>3?4:p&255;k=(h|159)&255;break L382}break};case 29:{if((a[f+20088|0]&1)==0){return}kS(f+19692|0,i,a[f+17559|0]&1);a[f+19969|0]=h&255;return};case 30:{if((a[f+20088|0]&1)==0){return}kS(f+19692|0,i,a[f+17559|0]&1);p=f+19904|0;z=f+19970|0;l=a[z]|0;N=f+19948|0;m=c[N>>2]|0;O=f+19936|0;x=c[O>>2]|0;if((x|0)!=-1){b[f+19944>>1]=(x>>>13)-(m>>>13)&65535}x=(h&64|0)!=0;do{if(x){q=m>>>12&1^1;if((l&64)!=0){aV=q;break}A=f+19944|0;H=b[A>>1]|0;if(H<<16>>16==0){aV=q;break}M=(H&65535)-q&65535;b[A>>1]=M;if(M<<16>>16!=0){aV=q;break}M=c[f+19940>>2]|0;f2[c[(c[M>>2]|0)+8>>2]&1023](M);aV=q}else{aV=0}}while(0);do{if((h&128|0)!=0){l=f+19944|0;if((b[l>>1]|0)!=0){break}b[l>>1]=1-aV+(d[f+19946|0]|0)&65535}}while(0);do{if(x){l=b[f+19944>>1]|0;if(l<<16>>16==0){aW=-1;break}aW=((l&65535)<<13)+m&-8192}else{aW=-1}}while(0);c[O>>2]=aW;a[z]=h&127;if((d[f+19968|0]&h|0)!=0){do{if((a[f+19975|0]&1)==0){m=f+19960|0;x=c[N>>2]|0;if((c[m>>2]|0)!=(x+1|0)){aX=x;aY=m;break}l=((d[f+19971|0]|0)+1|0)>>>1;G=l&15;if(G>>>0<4){a[p|0]=a[f+19904+G|0]|0;aX=x;aY=m;break}else{G=(l&12)+(f+19904)|0;l=p;C=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;a[l]=C&255;C=C>>8;a[l+1|0]=C&255;C=C>>8;a[l+2|0]=C&255;C=C>>8;a[l+3|0]=C&255;aX=x;aY=m;break}}else{aX=c[N>>2]|0;aY=f+19960|0}}while(0);a[f+19974|0]=1;a[f+19971|0]=0;N=aX+2051-(d[f+19969|0]|h<<8&1792)|0;c[aY>>2]=N;c[f+19964>>2]=N}k=(h|191)&255;break};case 32:{N=f+19692|0;do{if((a[f+20088|0]&1)==0){if((a[f+19379|0]&1)==0){break}return}}while(0);kS(N,i,a[f+17559|0]&1);p=a[f+20064|0]|0;z=c[f+20052>>2]|0;O=(d[f+20014|0]&(h^65535))+1|0;b[f+20012>>1]=O&65535;if((p&64)==0){aZ=-1}else{aZ=(O<<13&536862720)+z&-8192}c[f+20004>>2]=aZ;z=f+20048|0;c[z>>2]=f+20016;if(aZ>>>0>=(c[f+20020>>2]|0)>>>0){return}c[z>>2]=f+2e4;return};case 33:{if((a[f+20088|0]&1)==0){return}kS(f+19692|0,i,a[f+17559|0]&1);z=f+19976|0;O=f+20028|0;p=a[O]|0;do{if((p&7)==0){if((c[f+20020>>2]|0)==-1){ay=577;break}m=f+20029|0;x=(a[m]|0)+1&255;a[m]=x;a_=x}else{ay=577}}while(0);do{if((ay|0)==577){N=f+20029|0;x=a[N]|0;if((p&8)!=0){a_=x;break}m=x+2&255;a[N]=m;a_=m}}while(0);m=f+20029|0;if(((p&255^h)&8|0)==0){a$=a_}else{N=16-a_&255;a[m]=N;a$=N}a[m]=a$&15;m=h&255;a[O]=m;if((h&248|0)==0){N=f+19988|0;f2[c[(c[N>>2]|0)+8>>2]&1023](N)}else{f3[c[(c[z>>2]|0)+8>>2]&1023](z|0,c[f+20052>>2]|0)}N=f+20048|0;c[N>>2]=f+20016;if((c[f+20004>>2]|0)>>>0>=(c[f+20020>>2]|0)>>>0){k=m;break L382}c[N>>2]=f+2e4;k=m;break};case 34:{if((a[f+20088|0]&1)==0){return}else{kS(f+19692|0,i,a[f+17559|0]&1);pc(f+20032|0,c[f+20052>>2]|0);m=h&255;a[f+20046|0]=m;k=m;break L382}break};case 35:{if((a[f+20088|0]&1)==0){return}kS(f+19692|0,i,a[f+17559|0]&1);m=f+19976|0;N=f+20064|0;x=a[N]|0;l=f+20052|0;G=c[l>>2]|0;q=f+20004|0;M=c[q>>2]|0;if((M|0)!=-1){b[f+20012>>1]=(M>>>13)-(G>>>13)&65535}M=(h&64|0)!=0;do{if(M){A=G>>>12&1^1;if((x&64)!=0){a0=A;break}H=f+20012|0;K=b[H>>1]|0;if(K<<16>>16==0){a0=A;break}s=(K&65535)-A&65535;b[H>>1]=s;if(s<<16>>16!=0){a0=A;break}s=c[f+20008>>2]|0;f2[c[(c[s>>2]|0)+8>>2]&1023](s);a0=A}else{a0=0}}while(0);x=(h&128|0)==0;do{if(!x){z=f+20012|0;if((b[z>>1]|0)!=0){break}b[z>>1]=1-a0+(d[f+20014|0]|0)&65535}}while(0);do{if(M){z=b[f+20012>>1]|0;if(z<<16>>16==0){a1=-1;break}a1=((z&65535)<<13)+G&-8192}else{a1=-1}}while(0);c[q>>2]=a1;G=h&255;a[N]=G;if(x){a2=a1;a3=f+20020|0}else{a[N]=G&127;G=c[l>>2]|0;M=a[f+20028|0]|0;z=M&7;O=f+20020|0;c[O>>2]=G-(G+28672&32767)+(((z|0)==0?8:z)+((G&28672|0)==0)<<15);a[f+20029|0]=(M&255)>>>4;z=(M&255)<8;a[f+20065|0]=z&1^1;if(z){a4=G}else{z=f+20036|0;c[z>>2]=-1;M=f+20047|0;a[M]=0;b[f+20044>>1]=255;pc(f+20032|0,G);a[M]=1;M=f+20040|0;G=(c[M>>2]|0)+4|0;c[M>>2]=G;c[z>>2]=G;a4=c[l>>2]|0}f3[c[(c[m>>2]|0)+8>>2]&1023](m|0,a4);a2=c[q>>2]|0;a3=O}O=f+20048|0;c[O>>2]=f+20016;if(a2>>>0<(c[a3>>2]|0)>>>0){c[O>>2]=f+2e4}k=(h|191)&255;break};case 36:{if((a[f+20088|0]&1)==0){return}else{kS(f+19692|0,i,a[f+17559|0]&1);c[f+20076>>2]=((h<<16&458752|h>>>4&7)<<6)+4194368;k=h&255;break L382}break};case 37:{O=f+19692|0;if((a[f+20088|0]&1)==0){return}kS(O,i,a[f+17559|0]&1);G=(h<<16)+(h>>>4)|0;c[f+19796>>2]=(G&65537)*65535|0;f3[c[(c[O>>2]|0)+8>>2]&1023](O|0,c[f+19792>>2]|0);O=f+19768|0;z=f+19788|0;c[z>>2]=O;if((c[f+19756>>2]|0)>>>0<(c[f+19772>>2]|0)>>>0){M=f+19752|0;c[z>>2]=M;a5=M}else{a5=O}if((c[f+19720>>2]|0)>>>0<(c[a5+4>>2]|0)>>>0){c[z>>2]=f+19716}z=f+19808|0;c[f+19892>>2]=(G>>>1&65537)*65535|0;f3[c[(c[z>>2]|0)+8>>2]&1023](z|0,c[f+19888>>2]|0);z=f+19884|0;c[z>>2]=f+19868;if((c[f+19836>>2]|0)>>>0<(c[f+19872>>2]|0)>>>0){c[z>>2]=f+19832}c[f+19952>>2]=(G>>>2&65537)*65535|0;z=f+19976|0;c[f+20056>>2]=(G>>>3&65537)*65535|0;f3[c[(c[z>>2]|0)+8>>2]&1023](z|0,c[f+20052>>2]|0);z=f+20048|0;c[z>>2]=f+20016;if((c[f+20004>>2]|0)>>>0<(c[f+20020>>2]|0)>>>0){c[z>>2]=f+2e4}k=h&255;break};case 38:{z=f+294|0;do{if(((d[z]^h)&128|0)==0){a6=h&128}else{kS(f+19692|0,i,a[f+17559|0]&1);G=h&128;if((G|0)==0){O=65296;do{kR(f,O,0,i);O=O+1|0;}while(O>>>0<65318);a[f+20088|0]=0;a6=0;break}O=f+19792|0;c[O>>2]=c[O>>2]&4095|4096;a[f+19746|0]=0;a[f+19748|0]=((d[f+19747|0]|0)-1|0)>>>0<2|0;c[f+19740>>2]=-1;c[f+19736>>2]=-1;c[f+19756>>2]=-1;c[f+19772>>2]=-1;O=f+19788|0;c[O>>2]=f+19768;if((c[f+19720>>2]|0)!=-1){c[O>>2]=f+19716}O=f+19888|0;c[O>>2]=c[O>>2]&4095|4096;a[f+19862|0]=0;a[f+19864|0]=((d[f+19863|0]|0)-1|0)>>>0<2|0;c[f+19856>>2]=-1;c[f+19852>>2]=-1;c[f+19872>>2]=-1;O=f+19884|0;c[O>>2]=f+19868;if((c[f+19836>>2]|0)!=-1){c[O>>2]=f+19832}O=f+19948|0;c[O>>2]=c[O>>2]&4095|4096;a[f+19973|0]=0;O=f+20052|0;_=c[O>>2]&4095|4096;c[O>>2]=_;a[f+20046|0]=0;c[f+20036>>2]=-1;a[f+20047|0]=0;b[f+20044>>1]=255;c[f+20040>>2]=_+4;c[f+20020>>2]=-1;_=f+20048|0;c[_>>2]=f+20016;if((c[f+20004>>2]|0)!=-1){c[_>>2]=f+2e4}a[f+20088|0]=1;a6=G}}while(0);k=(a[z]&127|a6)&255;break};case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:case 58:case 59:case 60:case 61:case 62:case 63:{kS(f+19692|0,i,a[f+17559|0]&1);if((a[f+19974|0]&1)==0){a7=g&15}else{do{if((a[f+19975|0]&1)==0){if((c[f+19948>>2]|0)==(c[f+19964>>2]|0)){break}k=h&255;break L382}}while(0);a7=(d[f+19971|0]|0)>>>1}z=h&255;a[f+19904+a7|0]=z;k=z;break};case 64:{z=f+320|0;q=d[z]|0;if((q|0)==(h|0)){return}m=f+17268|0;do{if(((q^h)&128|0)==0){oW(m,h,i)}else{l=oX(m,d[f+325|0]|0,i)|0;N=c[f+19600>>2]|0;oW(m,h,i);a[f+324|0]=0;x=f+321|0;_=a[x]&-8;a[x]=_;if((h&128|0)==0){a[x]=(_&255|l&4)&255;l=(1824<<(a[f+17559|0]&1))+i|0;c[f+16920>>2]=l;_=(c[f+16924>>2]|0)>>>0>l>>>0?2:3;c[f+17e3>>2]=_;l=c[f+16996>>2]|0;x=(c[f+16912+(l<<2)>>2]|0)>>>0<(c[f+16912+(_<<2)>>2]|0)>>>0?l:_;c[f+16984>>2]=x;_=f+16912+(x<<2)|0;l=f+16988|0;O=c[l>>2]|0;M=(c[_>>2]|0)>>>0<(c[f+16912+(O<<2)>>2]|0)>>>0?x:O;O=f+16976|0;c[O>>2]=M;p=c[f+16980>>2]|0;A=f+16912+(p<<2)|0;s=(c[f+16912+(M<<2)>>2]|0)>>>0<(c[A>>2]|0)>>>0?M:p;M=f+16972|0;c[M>>2]=s;H=f+16948|0;c[H>>2]=c[f+16912+(s<<2)>>2];if((N|0)==-1){break}c[f+16932>>2]=0;c[f+17004>>2]=5;N=c[f+17008>>2]|0;s=(c[f+16912+(N<<2)>>2]|0)!=0?5:N;c[l>>2]=s;l=(c[_>>2]|0)>>>0<(c[f+16912+(s<<2)>>2]|0)>>>0?x:s;c[O>>2]=l;O=(c[f+16912+(l<<2)>>2]|0)>>>0<(c[A>>2]|0)>>>0?l:p;c[M>>2]=O;c[H>>2]=c[f+16912+(O<<2)>>2];break}if((a[f+20105|0]&1)==0){a8=70224<<(a[f+17559|0]&1)}else{a8=0}O=a8+(c[f+19588>>2]|0)|0;c[f+16920>>2]=O;H=(c[f+16924>>2]|0)>>>0>O>>>0?2:3;c[f+17e3>>2]=H;O=c[f+16996>>2]|0;M=(c[f+16912+(O<<2)>>2]|0)>>>0<(c[f+16912+(H<<2)>>2]|0)>>>0?O:H;c[f+16984>>2]=M;H=c[f+16988>>2]|0;O=(c[f+16912+(M<<2)>>2]|0)>>>0<(c[f+16912+(H<<2)>>2]|0)>>>0?M:H;c[f+16976>>2]=O;H=c[f+16980>>2]|0;M=(c[f+16912+(O<<2)>>2]|0)>>>0<(c[f+16912+(H<<2)>>2]|0)>>>0?O:H;c[f+16972>>2]=M;c[f+16948>>2]=c[f+16912+(M<<2)>>2]}}while(0);a[z]=h&255;return};case 65:{m=f+17268|0;q=f+19560|0;M=f+19568|0;H=c[M>>2]|0;O=f+19362|0;do{if(H>>>0<=i>>>0){if((a[O]|0)>-1){break}p=f+17532|0;l=f+17559|0;A=f+17540|0;s=m|0;x=f+19284|0;_=f+19288|0;N=f+17528|0;K=f+17558|0;v=f+19292|0;o=H;do{E=c[p>>2]|0;F=a[l]&1;r=(o-E|0)>>>(F>>>0);c[p>>2]=(r<<F)+E;E=r+(c[A>>2]|0)|0;c[A>>2]=E;if((E|0)>-1){E=c[x>>2]|0;if((E|0)==0){a9=566992}else{a9=E+((ag(c[v>>2]|0,d[K]|0)|0)<<2)|0}c[_>>2]=a9;f2[c[c[N>>2]>>2]&1023](s)}oY(m);o=c[M>>2]|0;}while(o>>>0<=i>>>0);o=c[p>>2]|0;G=a[l]&1;E=(i-o|0)>>>(G>>>0);c[p>>2]=(E<<G)+o;o=E+(c[A>>2]|0)|0;c[A>>2]=o;if((o|0)<=-1){break}o=c[x>>2]|0;if((o|0)==0){ba=566992}else{ba=o+((ag(c[v>>2]|0,d[K]|0)|0)<<2)|0}c[_>>2]=ba;f2[c[c[N>>2]>>2]&1023](s)}}while(0);H=f+19688|0;z=d[H]|0;o=h&255;a[H]=o;E=f+19668|0;G=f+17552|0;r=f+19672|0;pz(E,h,d[r]|0,G,i);if((a[O]|0)>-1){bb=f+19604|0;bc=f+19379|0}else{F=f+19379|0;J=G|0;G=c[J>>2]|0;D=G-i|0;L=f+17558|0;I=a[L]|0;y=I<<24>>24==-103;L952:do{if((a[F]&1)==0){if(((y&D>>>0<453?0:I&255)|0)==(d[r]|0)){if((z&64|0)!=0){break}if((I&255)>=144){if((z&16|0)!=0){break}}B=c[f+19660>>2]|0;P=B+108|0;$=c[P>>2]|2;c[P>>2]=$;if((a[B+116|0]|0)==0){break}if((c[B+112>>2]&$|0)==0){break}$=c[B+104>>2]|0;c[B+32>>2]=$;c[B+100>>2]=8;c[B+80>>2]=8;c[B+68>>2]=8;P=c[B+64>>2]|0;w=(c[B+(P<<2)>>2]|0)>>>0<$>>>0?P:8;c[B+60>>2]=w;c[B+36>>2]=c[B+(w<<2)>>2];break}if((I&255)>143){if((z&16|0)!=0){break}w=c[f+19660>>2]|0;B=w+108|0;P=c[B>>2]|2;c[B>>2]=P;if((a[w+116|0]|0)==0){break}if((c[w+112>>2]&P|0)==0){break}P=c[w+104>>2]|0;c[w+32>>2]=P;c[w+100>>2]=8;c[w+80>>2]=8;c[w+68>>2]=8;B=c[w+64>>2]|0;$=(c[w+(B<<2)>>2]|0)>>>0<P>>>0?B:8;c[w+60>>2]=$;c[w+36>>2]=c[w+($<<2)>>2];break}$=i+1|0;w=f+19680|0;B=c[w>>2]|0;if(B>>>0>i>>>0){bd=B;be=G}else{B=c[M>>2]|0;P=f+17532|0;Z=f+17559|0;Y=f+17540|0;n=m|0;if(B>>>0>i>>>0){bf=n}else{bg=f+19284|0;bh=f+19288|0;bi=f+17528|0;bj=f+19292|0;bk=B;while(1){B=c[P>>2]|0;bl=a[Z]&1;bm=(bk-B|0)>>>(bl>>>0);c[P>>2]=(bm<<bl)+B;B=bm+(c[Y>>2]|0)|0;c[Y>>2]=B;if((B|0)>-1){B=c[bg>>2]|0;if((B|0)==0){bn=566992}else{bn=B+((ag(c[bj>>2]|0,d[L]|0)|0)<<2)|0}c[bh>>2]=bn;f2[c[c[bi>>2]>>2]&1023](n)}oY(m);B=c[M>>2]|0;if(B>>>0>i>>>0){bf=n;break}else{bk=B}}}bk=c[P>>2]|0;n=a[Z]&1;bi=(i-bk|0)>>>(n>>>0);bh=(bi<<n)+bk|0;c[P>>2]=bh;bk=bi+(c[Y>>2]|0)|0;c[Y>>2]=bk;if((bk|0)>-1){bi=c[f+19284>>2]|0;if((bi|0)==0){bo=566992}else{bo=bi+((ag(c[f+19292>>2]|0,d[L]|0)|0)<<2)|0}c[f+19288>>2]=bo;bi=f+17528|0;f2[c[c[bi>>2]>>2]&1023](bf);bp=c[P>>2]|0;bq=c[Y>>2]|0;br=bi}else{bp=bh;bq=bk;br=f+17528|0}bk=ga[c[(c[br>>2]|0)+4>>2]&127](bf,167,-bq|0)|0;bh=(bk<<(a[Z]&1))+bp|0;c[w>>2]=bh;bd=bh;be=c[f+17552>>2]|0}if($>>>0<(bd>>>0<be>>>0?bd:c[f+17536>>2]|0)>>>0){break}if((z&8|0)!=0){break}bh=c[f+19660>>2]|0;bk=bh+108|0;bi=c[bk>>2]|2;c[bk>>2]=bi;if((a[bh+116|0]|0)==0){break}if((c[bh+112>>2]&bi|0)==0){break}bi=c[bh+104>>2]|0;c[bh+32>>2]=bi;c[bh+100>>2]=8;c[bh+80>>2]=8;c[bh+68>>2]=8;bk=c[bh+64>>2]|0;n=(c[bh+(bk<<2)>>2]|0)>>>0<bi>>>0?bk:8;c[bh+60>>2]=n;c[bh+36>>2]=c[bh+(n<<2)>>2]}else{if(y){if(D>>>0>((444<<(a[f+17559|0]&1))+8|0)>>>0){ay=699}else{bs=0}}else{ay=699}if((ay|0)==699){bs=I&255}do{if((bs|0)==(d[r]|0)){if(D>>>0<=(4-((a[f+17559|0]&1)<<2)|0)>>>0){bt=0;break}n=z&64;bh=(n|0)!=0;if(((h&64)-n|0)!=64){bt=bh;break}if((I&255)>=144){if((z&16|0)!=0){bt=bh;break}}bh=c[f+19660>>2]|0;n=bh+108|0;bk=c[n>>2]|2;c[n>>2]=bk;if((a[bh+116|0]|0)==0){break L952}if((c[bh+112>>2]&bk|0)==0){break L952}bk=c[bh+104>>2]|0;c[bh+32>>2]=bk;c[bh+100>>2]=8;c[bh+80>>2]=8;c[bh+68>>2]=8;n=c[bh+64>>2]|0;bi=(c[bh+(n<<2)>>2]|0)>>>0<bk>>>0?n:8;c[bh+60>>2]=bi;c[bh+36>>2]=c[bh+(bi<<2)>>2];break L952}else{bt=0}}while(0);$=(I&255)>143;do{if($){if(((h&16)-(z&16)|0)!=16){break}if((I&255)<153){if(bt){break}}else{if(D>>>0<=(4-((a[f+17559|0]&1)<<2)|0)>>>0|bt){break}}w=c[f+19660>>2]|0;Z=w+108|0;Y=c[Z>>2]|2;c[Z>>2]=Y;if((a[w+116|0]|0)==0){break L952}if((c[w+112>>2]&Y|0)==0){break L952}Y=c[w+104>>2]|0;c[w+32>>2]=Y;c[w+100>>2]=8;c[w+80>>2]=8;c[w+68>>2]=8;Z=c[w+64>>2]|0;P=(c[w+(Z<<2)>>2]|0)>>>0<Y>>>0?Z:8;c[w+60>>2]=P;c[w+36>>2]=c[w+(P<<2)>>2];break L952}}while(0);do{if(((h&8)-(z&8)|0)==8){if(!(D>>>0>4&(($|bt)^1))){break}P=f+17559|0;w=a[P]|0;Z=((w&1)<<1)+i|0;Y=f+19680|0;bi=c[Y>>2]|0;if(bi>>>0>i>>>0){bu=bi;bv=G}else{bi=c[M>>2]|0;bh=f+17532|0;n=f+17540|0;bk=m|0;if(bi>>>0>i>>>0){bw=w;bx=bk}else{bj=f+19284|0;bg=f+19288|0;s=f+17528|0;N=f+19292|0;_=bi;bi=w;while(1){w=c[bh>>2]|0;K=bi&1;v=(_-w|0)>>>(K>>>0);c[bh>>2]=(v<<K)+w;w=v+(c[n>>2]|0)|0;c[n>>2]=w;if((w|0)>-1){w=c[bj>>2]|0;if((w|0)==0){by=566992}else{by=w+((ag(c[N>>2]|0,d[L]|0)|0)<<2)|0}c[bg>>2]=by;f2[c[c[s>>2]>>2]&1023](bk)}oY(m);w=c[M>>2]|0;v=a[P]|0;if(w>>>0>i>>>0){bw=v;bx=bk;break}else{_=w;bi=v}}}bi=c[bh>>2]|0;_=bw&1;bk=(i-bi|0)>>>(_>>>0);s=(bk<<_)+bi|0;c[bh>>2]=s;bi=bk+(c[n>>2]|0)|0;c[n>>2]=bi;if((bi|0)>-1){bk=c[f+19284>>2]|0;if((bk|0)==0){bz=566992}else{bz=bk+((ag(c[f+19292>>2]|0,d[L]|0)|0)<<2)|0}c[f+19288>>2]=bz;bk=f+17528|0;f2[c[c[bk>>2]>>2]&1023](bx);bA=c[bh>>2]|0;bB=c[n>>2]|0;bC=bk}else{bA=s;bB=bi;bC=f+17528|0}bi=ga[c[(c[bC>>2]|0)+4>>2]&127](bx,167,-bB|0)|0;s=(bi<<(a[P]&1))+bA|0;c[Y>>2]=s;bu=s;bv=c[f+17552>>2]|0}if(Z>>>0<(bu>>>0<bv>>>0?bu:c[f+17536>>2]|0)>>>0){break}s=c[f+19660>>2]|0;bi=s+108|0;bk=c[bi>>2]|2;c[bi>>2]=bk;if((a[s+116|0]|0)==0){break L952}if((c[s+112>>2]&bk|0)==0){break L952}bk=c[s+104>>2]|0;c[s+32>>2]=bk;c[s+100>>2]=8;c[s+80>>2]=8;c[s+68>>2]=8;bi=c[s+64>>2]|0;_=(c[s+(bi<<2)>>2]|0)>>>0<bk>>>0?bi:8;c[s+60>>2]=_;c[s+36>>2]=c[s+(_<<2)>>2];break L952}}while(0);if((h&40|0)!=32){break}if((z&32|0)!=0){break}if(D>>>0<5){if((d[L]|0)>=143){ay=740}}else{ay=740}if((ay|0)==740){if((D|0)!=912){break}if((d[L]|0)>=144){break}}$=c[f+19660>>2]|0;_=$+108|0;s=c[_>>2]|2;c[_>>2]=s;if((a[$+116|0]|0)==0){break}if((c[$+112>>2]&s|0)==0){break}s=c[$+104>>2]|0;c[$+32>>2]=s;c[$+100>>2]=8;c[$+80>>2]=8;c[$+68>>2]=8;_=c[$+64>>2]|0;bi=(c[$+(_<<2)>>2]|0)>>>0<s>>>0?_:8;c[$+60>>2]=bi;c[$+36>>2]=c[$+(bi<<2)>>2]}}while(0);D=(h&8|0)==0;do{if(!D){z=f+19608|0;if((c[z>>2]|0)!=-1){break}do{if((a[O]|0)>-1){bD=f+17532|0;bE=f+17540|0;bF=f+17559|0}else{G=c[M>>2]|0;I=f+17532|0;r=f+17559|0;y=f+17540|0;if(G>>>0<=i>>>0){bi=m|0;$=f+19284|0;_=f+19288|0;s=f+17528|0;bk=f+19292|0;bg=G;do{G=c[I>>2]|0;N=a[r]&1;bj=(bg-G|0)>>>(N>>>0);c[I>>2]=(bj<<N)+G;G=bj+(c[y>>2]|0)|0;c[y>>2]=G;if((G|0)>-1){G=c[$>>2]|0;if((G|0)==0){bG=566992}else{bG=G+((ag(c[bk>>2]|0,d[L]|0)|0)<<2)|0}c[_>>2]=bG;f2[c[c[s>>2]>>2]&1023](bi)}oY(m);bg=c[M>>2]|0;}while(bg>>>0<=i>>>0)}bg=c[I>>2]|0;bi=a[r]&1;s=(i-bg|0)>>>(bi>>>0);c[I>>2]=(s<<bi)+bg;bg=s+(c[y>>2]|0)|0;c[y>>2]=bg;if((bg|0)<=-1){bD=I;bE=y;bF=r;break}bg=c[f+19284>>2]|0;if((bg|0)==0){bH=566992}else{bH=bg+((ag(c[f+19292>>2]|0,d[L]|0)|0)<<2)|0}c[f+19288>>2]=bH;f2[c[c[f+17528>>2]>>2]&1023](m|0);bD=I;bE=y;bF=r}}while(0);bg=c[bD>>2]|0;s=ga[c[(c[f+17528>>2]|0)+4>>2]&127](m|0,166,-(c[bE>>2]|0)|0)|0;bi=a[bF]&1;_=(s<<bi)+bg+(a[F]&1)-bi|0;c[z>>2]=_;bi=(c[f+19604>>2]|0)>>>0<_>>>0?6:7;c[f+19656>>2]=bi;_=c[f+19652>>2]|0;bg=(c[f+19580+(_<<2)>>2]|0)>>>0<(c[f+19580+(bi<<2)>>2]|0)>>>0?_:bi;c[f+19640>>2]=bg;bi=c[f+19636>>2]|0;_=(c[f+19580+(bi<<2)>>2]|0)>>>0<(c[f+19580+(bg<<2)>>2]|0)>>>0?bi:bg;c[f+19632>>2]=_;bg=c[f+19580+(_<<2)>>2]|0;c[f+19612>>2]=bg;c[q>>2]=bg;_=(c[f+19564>>2]|0)>>>0<=bg>>>0|0;c[f+19576>>2]=_;c[M>>2]=c[f+19560+(_<<2)>>2];_=c[f+19660>>2]|0;c[_+28>>2]=bg;bi=(c[_+24>>2]|0)>>>0<bg>>>0?6:7;c[_+96>>2]=bi;bg=c[_+92>>2]|0;s=(c[_+(bg<<2)>>2]|0)>>>0<(c[_+(bi<<2)>>2]|0)>>>0?bg:bi;c[_+76>>2]=s;bi=c[_+72>>2]|0;bg=(c[_+(bi<<2)>>2]|0)>>>0<(c[_+(s<<2)>>2]|0)>>>0?bi:s;c[_+64>>2]=bg;s=c[_+68>>2]|0;bi=(c[_+(bg<<2)>>2]|0)>>>0<(c[_+(s<<2)>>2]|0)>>>0?bg:s;c[_+60>>2]=bi;c[_+36>>2]=c[_+(bi<<2)>>2]}}while(0);if((h&32|0)==0){bI=-1}else{m=(c[J>>2]|0)-i|0;O=a[L]|0;do{if((O&255)>142){ay=764}else{bi=m>>>0<5;if(O<<24>>24==-114&bi|D^1){ay=764;break}if(bi){bJ=(e[f+17556>>1]|0)+m|0}else{bJ=m}bK=bJ-4|0}}while(0);if((ay|0)==764){bK=(ag(e[f+17556>>1]|0,153-(O&255)|0)|0)+m|0}bI=bK+i|0}D=f+19604|0;c[D>>2]=bI;L=(c[f+19608>>2]|0)>>>0>bI>>>0?6:7;c[f+19656>>2]=L;J=c[f+19652>>2]|0;bi=(c[f+19580+(J<<2)>>2]|0)>>>0<(c[f+19580+(L<<2)>>2]|0)>>>0?J:L;L=f+19640|0;c[L>>2]=bi;J=f+19636|0;_=c[J>>2]|0;s=(c[f+19580+(_<<2)>>2]|0)>>>0<(c[f+19580+(bi<<2)>>2]|0)>>>0?_:bi;bi=f+19632|0;c[bi>>2]=s;_=c[f+19580+(s<<2)>>2]|0;s=f+19612|0;c[s>>2]=_;bg=q|0;c[bg>>2]=_;bk=f+19564|0;$=(c[bk>>2]|0)>>>0<=_>>>0|0;Z=f+19576|0;c[Z>>2]=$;c[M>>2]=c[f+19560+($<<2)>>2];$=f+19660|0;Y=c[$>>2]|0;c[Y+28>>2]=_;P=(c[Y+24>>2]|0)>>>0<_>>>0?6:7;c[Y+96>>2]=P;_=c[Y+92>>2]|0;n=(c[Y+(_<<2)>>2]|0)>>>0<(c[Y+(P<<2)>>2]|0)>>>0?_:P;c[Y+76>>2]=n;P=c[Y+72>>2]|0;_=(c[Y+(P<<2)>>2]|0)>>>0<(c[Y+(n<<2)>>2]|0)>>>0?P:n;c[Y+64>>2]=_;n=c[Y+68>>2]|0;P=(c[Y+(_<<2)>>2]|0)>>>0<(c[Y+(n<<2)>>2]|0)>>>0?_:n;c[Y+60>>2]=P;c[Y+36>>2]=c[Y+(P<<2)>>2];P=c[E>>2]|0;c[f+19592>>2]=P;Y=(c[f+19588>>2]|0)>>>0<P>>>0?2:3;c[f+19648>>2]=Y;P=c[f+19644>>2]|0;n=(c[f+19580+(P<<2)>>2]|0)>>>0<(c[f+19580+(Y<<2)>>2]|0)>>>0?P:Y;c[J>>2]=n;J=c[L>>2]|0;L=(c[f+19580+(n<<2)>>2]|0)>>>0<(c[f+19580+(J<<2)>>2]|0)>>>0?n:J;c[bi>>2]=L;bi=c[f+19580+(L<<2)>>2]|0;c[s>>2]=bi;c[bg>>2]=bi;bg=(c[bk>>2]|0)>>>0<=bi>>>0|0;c[Z>>2]=bg;c[M>>2]=c[f+19560+(bg<<2)>>2];bg=c[$>>2]|0;c[bg+28>>2]=bi;$=(c[bg+24>>2]|0)>>>0<bi>>>0?6:7;c[bg+96>>2]=$;bi=c[bg+92>>2]|0;Z=(c[bg+(bi<<2)>>2]|0)>>>0<(c[bg+($<<2)>>2]|0)>>>0?bi:$;c[bg+76>>2]=Z;$=c[bg+72>>2]|0;bi=(c[bg+($<<2)>>2]|0)>>>0<(c[bg+(Z<<2)>>2]|0)>>>0?$:Z;c[bg+64>>2]=bi;Z=c[bg+68>>2]|0;$=(c[bg+(bi<<2)>>2]|0)>>>0<(c[bg+(Z<<2)>>2]|0)>>>0?bi:Z;c[bg+60>>2]=$;c[bg+36>>2]=c[bg+($<<2)>>2];bb=D;bc=F}D=a[bc]&1;$=D-(a[f+17559|0]&1)<<2;bg=f+19689|0;if(((c[bb>>2]|0)-i|0)>>>0>$>>>0){bL=o}else{bL=a[H]&-17|a[bg]&16}a[bg]=bL;bg=f+19690|0;if(((c[f+19588>>2]|0)-i|0)>>>0>$>>>0){bM=o}else{bM=a[H]&-9|a[bg]&8}a[bg]=bM;if(((c[f+19608>>2]|0)-i|0)>>>0>D<<1>>>0){a[f+19664|0]=o}k=(a[f+321|0]&135|h&120)&255;break};case 66:{D=f+17268|0;bg=f+17559|0;$=a[bg]|0;Z=(a[f+19379|0]&1)+i+($&1)|0;do{if((a[f+19362|0]|0)<=-1){bi=f+19568|0;bk=c[bi>>2]|0;s=f+17532|0;L=f+17540|0;if(bk>>>0>Z>>>0){bN=$}else{J=D|0;n=f+19284|0;Y=f+19288|0;P=f+17528|0;_=f+17558|0;bh=f+19292|0;G=bk;bk=$;while(1){bj=c[s>>2]|0;N=bk&1;v=(G-bj|0)>>>(N>>>0);c[s>>2]=(v<<N)+bj;bj=v+(c[L>>2]|0)|0;c[L>>2]=bj;if((bj|0)>-1){bj=c[n>>2]|0;if((bj|0)==0){bO=566992}else{bO=bj+((ag(c[bh>>2]|0,d[_]|0)|0)<<2)|0}c[Y>>2]=bO;f2[c[c[P>>2]>>2]&1023](J)}oY(D);bj=c[bi>>2]|0;v=a[bg]|0;if(bj>>>0>Z>>>0){bN=v;break}else{G=bj;bk=v}}}bk=c[s>>2]|0;G=bN&1;bi=(Z-bk|0)>>>(G>>>0);c[s>>2]=(bi<<G)+bk;bk=bi+(c[L>>2]|0)|0;c[L>>2]=bk;if((bk|0)<=-1){break}bk=c[f+19284>>2]|0;if((bk|0)==0){bP=566992}else{bP=bk+((ag(c[f+19292>>2]|0,d[f+17558|0]|0)|0)<<2)|0}c[f+19288>>2]=bP;f2[c[c[f+17528>>2]>>2]&1023](D|0)}}while(0);D=h&255;a[f+19363|0]=D;k=D;break};case 67:{D=f+17268|0;Z=f+17559|0;bg=a[Z]|0;$=(a[f+19379|0]&1)+i+(bg&1)|0;do{if((a[f+19362|0]|0)<=-1){o=f+19568|0;H=c[o>>2]|0;F=f+17532|0;M=f+17540|0;if(H>>>0>$>>>0){bQ=bg}else{E=D|0;q=f+19284|0;m=f+19288|0;O=f+17528|0;bk=f+17558|0;bi=f+19292|0;G=H;H=bg;while(1){J=c[F>>2]|0;P=H&1;Y=(G-J|0)>>>(P>>>0);c[F>>2]=(Y<<P)+J;J=Y+(c[M>>2]|0)|0;c[M>>2]=J;if((J|0)>-1){J=c[q>>2]|0;if((J|0)==0){bR=566992}else{bR=J+((ag(c[bi>>2]|0,d[bk]|0)|0)<<2)|0}c[m>>2]=bR;f2[c[c[O>>2]>>2]&1023](E)}oY(D);J=c[o>>2]|0;Y=a[Z]|0;if(J>>>0>$>>>0){bQ=Y;break}else{G=J;H=Y}}}H=c[F>>2]|0;G=bQ&1;o=($-H|0)>>>(G>>>0);c[F>>2]=(o<<G)+H;H=o+(c[M>>2]|0)|0;c[M>>2]=H;if((H|0)<=-1){break}H=c[f+19284>>2]|0;if((H|0)==0){bS=566992}else{bS=H+((ag(c[f+19292>>2]|0,d[f+17558|0]|0)|0)<<2)|0}c[f+19288>>2]=bS;f2[c[c[f+17528>>2]>>2]&1023](D|0)}}while(0);$=h&255;a[f+19364|0]=$;oU(D);k=$;break};case 69:{$=f+17268|0;Z=f+19668|0;L1143:do{if((d[f+19672|0]|0)!=(h|0)){bg=f+19568|0;H=c[bg>>2]|0;do{if(H>>>0<=i>>>0){if((a[f+19362|0]|0)>-1){break}o=f+17532|0;G=f+17559|0;E=f+17540|0;O=$|0;m=f+19284|0;bk=f+19288|0;bi=f+17528|0;q=f+17558|0;L=f+19292|0;s=H;do{Y=c[o>>2]|0;J=a[G]&1;P=(s-Y|0)>>>(J>>>0);c[o>>2]=(P<<J)+Y;Y=P+(c[E>>2]|0)|0;c[E>>2]=Y;if((Y|0)>-1){Y=c[m>>2]|0;if((Y|0)==0){bT=566992}else{bT=Y+((ag(c[L>>2]|0,d[q]|0)|0)<<2)|0}c[bk>>2]=bT;f2[c[c[bi>>2]>>2]&1023](O)}oY($);s=c[bg>>2]|0;}while(s>>>0<=i>>>0);s=c[o>>2]|0;r=a[G]&1;y=(i-s|0)>>>(r>>>0);c[o>>2]=(y<<r)+s;s=y+(c[E>>2]|0)|0;c[E>>2]=s;if((s|0)<=-1){break}s=c[m>>2]|0;if((s|0)==0){bU=566992}else{bU=s+((ag(c[L>>2]|0,d[q]|0)|0)<<2)|0}c[bk>>2]=bU;f2[c[c[bi>>2]>>2]&1023](O)}}while(0);H=f+17559|0;M=f+19379|0;if(((c[f+19608>>2]|0)-i|0)>>>0>((-(a[M]&1)&5)+(a[H]&1^1)|0)>>>0){a[f+19665|0]=h&255}F=f+17552|0;pz(Z,d[f+19673|0]|0,h,F,i);if((a[f+19362|0]|0)>-1){break}s=c[Z>>2]|0;c[f+19592>>2]=s;y=(c[f+19588>>2]|0)>>>0<s>>>0?2:3;s=f+19648|0;c[s>>2]=y;r=f+19644|0;I=c[r>>2]|0;Y=(c[f+19580+(I<<2)>>2]|0)>>>0<(c[f+19580+(y<<2)>>2]|0)>>>0?I:y;y=f+19636|0;c[y>>2]=Y;I=f+19640|0;P=c[I>>2]|0;J=(c[f+19580+(Y<<2)>>2]|0)>>>0<(c[f+19580+(P<<2)>>2]|0)>>>0?Y:P;P=f+19632|0;c[P>>2]=J;Y=c[f+19580+(J<<2)>>2]|0;J=f+19612|0;c[J>>2]=Y;_=f+19560|0;c[_>>2]=Y;bh=f+19564|0;n=(c[bh>>2]|0)>>>0<=Y>>>0|0;z=f+19576|0;c[z>>2]=n;c[bg>>2]=c[f+19560+(n<<2)>>2];n=f+19660|0;v=c[n>>2]|0;c[v+28>>2]=Y;bj=(c[v+24>>2]|0)>>>0<Y>>>0?6:7;c[v+96>>2]=bj;Y=c[v+92>>2]|0;N=(c[v+(Y<<2)>>2]|0)>>>0<(c[v+(bj<<2)>>2]|0)>>>0?Y:bj;c[v+76>>2]=N;bj=c[v+72>>2]|0;Y=(c[v+(bj<<2)>>2]|0)>>>0<(c[v+(N<<2)>>2]|0)>>>0?bj:N;c[v+64>>2]=Y;N=c[v+68>>2]|0;bj=(c[v+(Y<<2)>>2]|0)>>>0<(c[v+(N<<2)>>2]|0)>>>0?Y:N;c[v+60>>2]=bj;c[v+36>>2]=c[v+(bj<<2)>>2];bj=(c[F>>2]|0)-i|0;F=a[f+19688|0]|0;if(!((F&64)!=0&h>>>0<154)){break}v=a[f+17558|0]|0;do{if((v&255)>=144){if((F&16)==0){break}if(!(v<<24>>24==-103&bj>>>0<5)){break L1143}}}while(0);F=v&255;N=(a[M]&1)==0;do{if(N){if(bj>>>0<5){bV=255;break}bV=v<<24>>24==-103&bj>>>0<453?0:F}else{Y=a[H]&1;if(bj>>>0<=4>>>(Y>>>0)>>>0){bV=(v&255)<153?F+1|0:0;break}if(bj>>>0<9){bV=255;break}if(v<<24>>24!=-103){bV=F;break}bV=bj>>>0>((448<<Y)+8|0)>>>0?F:0}}while(0);if((bV|0)!=(h|0)){break}do{if(!N){if((a[H]&1)!=0){break}F=i+5|0;c[f+19580>>2]=F;bj=(c[f+19584>>2]|0)>>>0<=F>>>0|0;c[r>>2]=bj;F=c[s>>2]|0;v=(c[f+19580+(bj<<2)>>2]|0)>>>0<(c[f+19580+(F<<2)>>2]|0)>>>0?bj:F;c[y>>2]=v;F=c[I>>2]|0;bj=(c[f+19580+(v<<2)>>2]|0)>>>0<(c[f+19580+(F<<2)>>2]|0)>>>0?v:F;c[P>>2]=bj;F=c[f+19580+(bj<<2)>>2]|0;c[J>>2]=F;c[_>>2]=F;bj=(c[bh>>2]|0)>>>0<=F>>>0|0;c[z>>2]=bj;c[bg>>2]=c[f+19560+(bj<<2)>>2];bj=c[n>>2]|0;c[bj+28>>2]=F;v=(c[bj+24>>2]|0)>>>0<F>>>0?6:7;c[bj+96>>2]=v;F=c[bj+92>>2]|0;M=(c[bj+(F<<2)>>2]|0)>>>0<(c[bj+(v<<2)>>2]|0)>>>0?F:v;c[bj+76>>2]=M;v=c[bj+72>>2]|0;F=(c[bj+(v<<2)>>2]|0)>>>0<(c[bj+(M<<2)>>2]|0)>>>0?v:M;c[bj+64>>2]=F;M=c[bj+68>>2]|0;v=(c[bj+(F<<2)>>2]|0)>>>0<(c[bj+(M<<2)>>2]|0)>>>0?F:M;c[bj+60>>2]=v;c[bj+36>>2]=c[bj+(v<<2)>>2];break L1143}}while(0);bg=c[n>>2]|0;z=bg+108|0;bh=c[z>>2]|2;c[z>>2]=bh;if((a[bg+116|0]|0)==0){break}if((c[bg+112>>2]&bh|0)==0){break}bh=c[bg+104>>2]|0;c[bg+32>>2]=bh;c[bg+100>>2]=8;c[bg+80>>2]=8;c[bg+68>>2]=8;z=c[bg+64>>2]|0;_=(c[bg+(z<<2)>>2]|0)>>>0<bh>>>0?z:8;c[bg+60>>2]=_;c[bg+36>>2]=c[bg+(_<<2)>>2]}}while(0);k=h&255;break};case 70:{if((c[j>>2]|0)!=-1){a[f+20104|0]=-2;Z=c[f+17164>>2]|0;c[f+17032>>2]=Z;c[f+17036>>2]=Z;c[f+17040>>2]=Z;c[f+17044>>2]=Z;Z=c[f+17168>>2]|0;c[f+17048>>2]=Z;c[f+17052>>2]=Z;c[f+17056>>2]=Z;c[f+17060>>2]=Z;Z=c[f+17192>>2]|0;c[f+17072>>2]=Z;c[f+17076>>2]=Z;Z=c[f+17196>>2]|0;c[f+17136>>2]=Z;c[f+17140>>2]=Z;Z=c[f+17172>>2]|0;$=Z-49152|0;c[f+17144>>2]=$;c[f+17080>>2]=$;$=(c[f+17176>>2]|0)-53248|0;c[f+17148>>2]=$;c[f+17084>>2]=$;$=Z-57344|0;c[f+17152>>2]=$;c[f+17088>>2]=$;c[f+17200>>2]=5;oV(f+17268|0,f|0,i)}c[j>>2]=i;$=i+8|0;c[f+16928>>2]=$;Z=(c[f+16932>>2]|0)>>>0>$>>>0?4:5;c[f+17004>>2]=Z;$=c[f+17008>>2]|0;D=(c[f+16912+(Z<<2)>>2]|0)>>>0<(c[f+16912+($<<2)>>2]|0)>>>0?Z:$;c[f+16988>>2]=D;$=c[f+16984>>2]|0;Z=(c[f+16912+($<<2)>>2]|0)>>>0<(c[f+16912+(D<<2)>>2]|0)>>>0?$:D;c[f+16976>>2]=Z;D=c[f+16980>>2]|0;$=(c[f+16912+(Z<<2)>>2]|0)>>>0<(c[f+16912+(D<<2)>>2]|0)>>>0?Z:D;c[f+16972>>2]=$;c[f+16948>>2]=c[f+16912+($<<2)>>2];$=h&255;a[f+326|0]=$;if(($&255)<160){D=$<<24>>24>-1;Z=f+17032|0;_=c[f+17164>>2]|0;c[Z>>2]=_;c[f+17036>>2]=_;c[f+17040>>2]=_;c[f+17044>>2]=_;_=c[f+17168>>2]|0;c[f+17048>>2]=_;c[f+17052>>2]=_;c[f+17056>>2]=_;c[f+17060>>2]=_;_=c[f+17192>>2]|0;bg=f+17072|0;c[bg>>2]=_;z=f+17076|0;c[z>>2]=_;_=c[f+17196>>2]|0;bh=f+17136|0;c[bh>>2]=_;J=f+17140|0;c[J>>2]=_;_=c[f+17172>>2]|0;P=_-49152|0;c[f+17144>>2]=P;c[f+17080>>2]=P;P=(c[f+17176>>2]|0)-53248|0;c[f+17148>>2]=P;c[f+17084>>2]=P;P=_-57344|0;c[f+17152>>2]=P;c[f+17088>>2]=P;c[f+17200>>2]=D?0:2;P=Z;if(((c[f+17184>>2]|0)-_|0)==32768){if(!D){return}yB(P|0,0,32);c[bg>>2]=0;c[z>>2]=0;c[bh>>2]=0;c[J>>2]=0;return}else{if(!D){return}yB(P|0,0,32);yB(bg|0,0,20);yB(bh|0,0,20);return}}bh=f+17032|0;if((h&255)>>>0>=(254-(-(a[f+19379|0]&1)&30)|0)>>>0){bg=c[f+17192>>2]|0;P=f+17072|0;c[P>>2]=bg;D=f+17076|0;c[D>>2]=bg;bg=c[f+17196>>2]|0;J=f+17136|0;c[J>>2]=bg;z=f+17140|0;c[z>>2]=bg;bg=c[f+17172>>2]|0;_=bg-49152|0;c[f+17144>>2]=_;c[f+17080>>2]=_;_=(c[f+17176>>2]|0)-53248|0;c[f+17148>>2]=_;c[f+17084>>2]=_;_=bg-57344|0;c[f+17152>>2]=_;c[f+17088>>2]=_;c[f+17200>>2]=4;_=((c[f+17184>>2]|0)-bg|0)==32768;yB(bh|0,0,32);if(_){c[P>>2]=0;c[D>>2]=0;c[J>>2]=0;c[z>>2]=0;return}else{yB(P|0,0,20);yB(J|0,0,20);return}}J=($&255)<192;$=c[f+17164>>2]|0;c[bh>>2]=$;c[f+17036>>2]=$;c[f+17040>>2]=$;c[f+17044>>2]=$;$=c[f+17168>>2]|0;c[f+17048>>2]=$;c[f+17052>>2]=$;c[f+17056>>2]=$;c[f+17060>>2]=$;$=c[f+17192>>2]|0;P=f+17072|0;c[P>>2]=$;z=f+17076|0;c[z>>2]=$;$=c[f+17196>>2]|0;D=f+17136|0;c[D>>2]=$;_=f+17140|0;c[_>>2]=$;$=c[f+17172>>2]|0;bg=$-49152|0;Z=f+17144|0;c[Z>>2]=bg;I=f+17080|0;c[I>>2]=bg;bg=(c[f+17176>>2]|0)-53248|0;y=f+17148|0;c[y>>2]=bg;s=f+17084|0;c[s>>2]=bg;bg=$-57344|0;r=f+17152|0;c[r>>2]=bg;H=f+17088|0;c[H>>2]=bg;c[f+17200>>2]=J?1:3;bg=bh;if(((c[f+17184>>2]|0)-$|0)!=32768){yB(bg|0,0,32);yB(P|0,0,20);yB(D|0,0,20);return}if(J){yB(bg|0,0,32);c[P>>2]=0;c[z>>2]=0;c[D>>2]=0;c[_>>2]=0;return}else{c[I>>2]=0;c[s>>2]=0;c[H>>2]=0;c[Z>>2]=0;c[y>>2]=0;c[r>>2]=0;return}break};case 71:{r=h&255;if((a[f+19379|0]&1)!=0){k=r;break L382}y=f+17268|0;oQ(y,i);a[f+19432|0]=r;c[y>>2]=c[f+19384+((h&3)<<2)>>2];c[f+17272>>2]=c[f+19384+((h>>>2&3)<<2)>>2];c[f+17276>>2]=c[f+19384+((h>>>4&3)<<2)>>2];c[f+17280>>2]=c[f+19384+((h>>>6&3)<<2)>>2];k=r;break};case 72:{r=h&255;if((a[f+19379|0]&1)!=0){k=r;break L382}oQ(f+17268|0,i);a[f+19496|0]=r;c[f+17396>>2]=c[f+19384+((h&3|4)<<2)>>2];c[f+17400>>2]=c[f+19384+((h>>>2&3|4)<<2)>>2];c[f+17404>>2]=c[f+19384+((h>>>4&3|4)<<2)>>2];c[f+17408>>2]=c[f+19384+((h>>>6&3|4)<<2)>>2];k=r;break};case 73:{r=h&255;if((a[f+19379|0]&1)!=0){k=r;break L382}oQ(f+17268|0,i);a[f+19497|0]=r;c[f+17412>>2]=c[f+19384+((h&3|8)<<2)>>2];c[f+17416>>2]=c[f+19384+((h>>>2&3|8)<<2)>>2];c[f+17420>>2]=c[f+19384+((h>>>4&3|8)<<2)>>2];c[f+17424>>2]=c[f+19384+((h>>>6&3|8)<<2)>>2];k=r;break};case 74:{r=f+17268|0;y=i+1|0;Z=f+19362|0;do{if((a[Z]|0)<=-1){H=f+19568|0;s=c[H>>2]|0;I=f+17532|0;_=f+17559|0;D=f+17540|0;if(s>>>0<=y>>>0){z=r|0;P=f+19284|0;bg=f+19288|0;J=f+17528|0;$=f+17558|0;bh=f+19292|0;N=s;do{s=c[I>>2]|0;v=a[_]&1;bj=(N-s|0)>>>(v>>>0);c[I>>2]=(bj<<v)+s;s=bj+(c[D>>2]|0)|0;c[D>>2]=s;if((s|0)>-1){s=c[P>>2]|0;if((s|0)==0){bW=566992}else{bW=s+((ag(c[bh>>2]|0,d[$]|0)|0)<<2)|0}c[bg>>2]=bW;f2[c[c[J>>2]>>2]&1023](z)}oY(r);N=c[H>>2]|0;}while(N>>>0<=y>>>0)}N=c[I>>2]|0;H=a[_]&1;z=(y-N|0)>>>(H>>>0);c[I>>2]=(z<<H)+N;N=z+(c[D>>2]|0)|0;c[D>>2]=N;if((N|0)<=-1){break}N=c[f+19284>>2]|0;if((N|0)==0){bX=566992}else{bX=N+((ag(c[f+19292>>2]|0,d[f+17558|0]|0)|0)<<2)|0}c[f+19288>>2]=bX;f2[c[c[f+17528>>2]>>2]&1023](r|0)}}while(0);y=h&255;N=f+19365|0;a[N]=y;z=a[Z]|0;do{if((a[f+19379|0]&1)==0){H=i+2|0;if(z<<24>>24>-1){bY=y;break}J=f+19568|0;bg=c[J>>2]|0;$=f+17532|0;bh=f+17559|0;P=f+17540|0;if(bg>>>0<=H>>>0){n=r|0;s=f+19284|0;bj=f+19288|0;v=f+17528|0;M=f+17558|0;F=f+19292|0;Y=bg;do{bg=c[$>>2]|0;w=a[bh]&1;K=(Y-bg|0)>>>(w>>>0);c[$>>2]=(K<<w)+bg;bg=K+(c[P>>2]|0)|0;c[P>>2]=bg;if((bg|0)>-1){bg=c[s>>2]|0;if((bg|0)==0){bZ=566992}else{bZ=bg+((ag(c[F>>2]|0,d[M]|0)|0)<<2)|0}c[bj>>2]=bZ;f2[c[c[v>>2]>>2]&1023](n)}oY(r);Y=c[J>>2]|0;}while(Y>>>0<=H>>>0)}Y=c[$>>2]|0;J=a[bh]&1;n=(H-Y|0)>>>(J>>>0);c[$>>2]=(n<<J)+Y;Y=n+(c[P>>2]|0)|0;c[P>>2]=Y;if((Y|0)>-1){Y=c[f+19284>>2]|0;if((Y|0)==0){b_=566992}else{b_=Y+((ag(c[f+19292>>2]|0,d[f+17558|0]|0)|0)<<2)|0}c[f+19288>>2]=b_;f2[c[c[f+17528>>2]>>2]&1023](r|0)}bY=a[N]|0}else{if(z<<24>>24>-1){bY=y;break}Y=i+5|0;c[f+19584>>2]=Y;n=(c[f+19580>>2]|0)>>>0>=Y>>>0|0;c[f+19644>>2]=n;Y=c[f+19648>>2]|0;J=(c[f+19580+(n<<2)>>2]|0)>>>0<(c[f+19580+(Y<<2)>>2]|0)>>>0?n:Y;c[f+19636>>2]=J;Y=c[f+19640>>2]|0;n=(c[f+19580+(J<<2)>>2]|0)>>>0<(c[f+19580+(Y<<2)>>2]|0)>>>0?J:Y;c[f+19632>>2]=n;Y=c[f+19580+(n<<2)>>2]|0;c[f+19612>>2]=Y;c[f+19560>>2]=Y;n=(c[f+19564>>2]|0)>>>0<=Y>>>0|0;c[f+19576>>2]=n;c[f+19568>>2]=c[f+19560+(n<<2)>>2];n=c[f+19660>>2]|0;c[n+28>>2]=Y;J=(c[n+24>>2]|0)>>>0<Y>>>0?6:7;c[n+96>>2]=J;Y=c[n+92>>2]|0;v=(c[n+(Y<<2)>>2]|0)>>>0<(c[n+(J<<2)>>2]|0)>>>0?Y:J;c[n+76>>2]=v;J=c[n+72>>2]|0;Y=(c[n+(J<<2)>>2]|0)>>>0<(c[n+(v<<2)>>2]|0)>>>0?J:v;c[n+64>>2]=Y;v=c[n+68>>2]|0;J=(c[n+(Y<<2)>>2]|0)>>>0<(c[n+(v<<2)>>2]|0)>>>0?Y:v;c[n+60>>2]=J;c[n+36>>2]=c[n+(J<<2)>>2];k=y;break L382}}while(0);a[f+19366|0]=bY;oU(r);k=y;break};case 75:{z=f+17268|0;N=f+17559|0;Z=a[N]|0;J=i+1+(Z&1)|0;do{if((a[f+19362|0]|0)<=-1){n=f+19568|0;v=c[n>>2]|0;Y=f+17532|0;bj=f+17540|0;if(v>>>0>J>>>0){b$=Z}else{M=z|0;F=f+19284|0;s=f+19288|0;D=f+17528|0;I=f+17558|0;_=f+19292|0;bg=v;v=Z;while(1){K=c[Y>>2]|0;w=v&1;x=(bg-K|0)>>>(w>>>0);c[Y>>2]=(x<<w)+K;K=x+(c[bj>>2]|0)|0;c[bj>>2]=K;if((K|0)>-1){K=c[F>>2]|0;if((K|0)==0){b0=566992}else{b0=K+((ag(c[_>>2]|0,d[I]|0)|0)<<2)|0}c[s>>2]=b0;f2[c[c[D>>2]>>2]&1023](M)}oY(z);K=c[n>>2]|0;x=a[N]|0;if(K>>>0>J>>>0){b$=x;break}else{bg=K;v=x}}}v=c[Y>>2]|0;bg=b$&1;n=(J-v|0)>>>(bg>>>0);c[Y>>2]=(n<<bg)+v;v=n+(c[bj>>2]|0)|0;c[bj>>2]=v;if((v|0)<=-1){break}v=c[f+19284>>2]|0;if((v|0)==0){b1=566992}else{b1=v+((ag(c[f+19292>>2]|0,d[f+17558|0]|0)|0)<<2)|0}c[f+19288>>2]=b1;f2[c[c[f+17528>>2]>>2]&1023](z|0)}}while(0);J=h&255;a[f+19367|0]=J;oU(z);k=J;break};case 77:{J=f+333|0;a[J]=(d[J]|h&1)&255;return};case 79:{if((a[f+19379|0]&1)==0){return}c[f+16896>>2]=(h<<13&8192)+(f+512);a[f+335|0]=(h|254)&255;return};case 81:{J=f+20100|0;b[J>>1]=(b[J>>1]&255|h<<8)&65535;return};case 82:{J=f+20100|0;b[J>>1]=(b[J>>1]&65280|h&240)&65535;return};case 83:{J=f+20102|0;b[J>>1]=(b[J>>1]&255|h<<8)&65535;return};case 84:{J=f+20102|0;b[J>>1]=(b[J>>1]&65280|h&240)&65535;return};case 85:{if((a[f+19379|0]&1)==0){return}J=h&255;N=f+341|0;a[N]=J&127;Z=f+17268|0;y=f+19600|0;r=(h&128|0)!=0;if((c[y>>2]|0)!=-1){if(r){return}a[N]=J|-128;oR(Z,i);return}if(!r){c[f+16932>>2]=1;r=(c[f+16928>>2]|0)==0?4:5;c[f+17004>>2]=r;J=c[f+17008>>2]|0;N=(c[f+16912+(r<<2)>>2]|0)>>>0<(c[f+16912+(J<<2)>>2]|0)>>>0?r:J;c[f+16988>>2]=N;J=c[f+16984>>2]|0;r=(c[f+16912+(J<<2)>>2]|0)>>>0<(c[f+16912+(N<<2)>>2]|0)>>>0?J:N;c[f+16976>>2]=r;N=c[f+16980>>2]|0;J=(c[f+16912+(r<<2)>>2]|0)>>>0<(c[f+16912+(N<<2)>>2]|0)>>>0?r:N;c[f+16972>>2]=J;c[f+16948>>2]=c[f+16912+(J<<2)>>2];return}if((a[f+320|0]|0)>=0){c[f+16932>>2]=0;c[f+17004>>2]=5;J=c[f+17008>>2]|0;N=(c[f+16912+(J<<2)>>2]|0)!=0?5:J;c[f+16988>>2]=N;J=c[f+16984>>2]|0;r=(c[f+16912+(J<<2)>>2]|0)>>>0<(c[f+16912+(N<<2)>>2]|0)>>>0?J:N;c[f+16976>>2]=r;N=c[f+16980>>2]|0;J=(c[f+16912+(r<<2)>>2]|0)>>>0<(c[f+16912+(N<<2)>>2]|0)>>>0?r:N;c[f+16972>>2]=J;c[f+16948>>2]=c[f+16912+(J<<2)>>2];return}J=f+19680|0;do{if((c[J>>2]|0)>>>0>i>>>0){N=f+19568|0;r=c[N>>2]|0;if(r>>>0>i>>>0){break}if((a[f+19362|0]|0)>-1){break}v=f+17532|0;n=f+17559|0;bg=f+17540|0;M=Z|0;D=f+19284|0;s=f+19288|0;I=f+17528|0;_=f+17558|0;F=f+19292|0;P=r;do{r=c[v>>2]|0;$=a[n]&1;H=(P-r|0)>>>($>>>0);c[v>>2]=(H<<$)+r;r=H+(c[bg>>2]|0)|0;c[bg>>2]=r;if((r|0)>-1){r=c[D>>2]|0;if((r|0)==0){b2=566992}else{b2=r+((ag(c[F>>2]|0,d[_]|0)|0)<<2)|0}c[s>>2]=b2;f2[c[c[I>>2]>>2]&1023](M)}oY(Z);P=c[N>>2]|0;}while(P>>>0<=i>>>0);P=c[v>>2]|0;N=a[n]&1;bj=(i-P|0)>>>(N>>>0);c[v>>2]=(bj<<N)+P;P=bj+(c[bg>>2]|0)|0;c[bg>>2]=P;if((P|0)<=-1){break}P=c[D>>2]|0;if((P|0)==0){b3=566992}else{b3=P+((ag(c[F>>2]|0,d[_]|0)|0)<<2)|0}c[s>>2]=b3;f2[c[c[I>>2]>>2]&1023](M)}else{do{if((a[f+19362|0]|0)>-1){b4=f+17532|0;b5=f+17540|0;b6=f+17559|0}else{P=f+19568|0;bj=c[P>>2]|0;N=f+17532|0;Y=f+17559|0;r=f+17540|0;if(bj>>>0<=i>>>0){H=Z|0;$=f+19284|0;bh=f+19288|0;x=f+17528|0;K=f+17558|0;w=f+19292|0;A=bj;do{bj=c[N>>2]|0;p=a[Y]&1;l=(A-bj|0)>>>(p>>>0);c[N>>2]=(l<<p)+bj;bj=l+(c[r>>2]|0)|0;c[r>>2]=bj;if((bj|0)>-1){bj=c[$>>2]|0;if((bj|0)==0){b7=566992}else{b7=bj+((ag(c[w>>2]|0,d[K]|0)|0)<<2)|0}c[bh>>2]=b7;f2[c[c[x>>2]>>2]&1023](H)}oY(Z);A=c[P>>2]|0;}while(A>>>0<=i>>>0)}A=c[N>>2]|0;P=a[Y]&1;H=(i-A|0)>>>(P>>>0);c[N>>2]=(H<<P)+A;A=H+(c[r>>2]|0)|0;c[r>>2]=A;if((A|0)<=-1){b4=N;b5=r;b6=Y;break}A=c[f+19284>>2]|0;if((A|0)==0){b8=566992}else{b8=A+((ag(c[f+19292>>2]|0,d[f+17558|0]|0)|0)<<2)|0}c[f+19288>>2]=b8;f2[c[c[f+17528>>2]>>2]&1023](Z|0);b4=N;b5=r;b6=Y}}while(0);M=c[b4>>2]|0;I=ga[c[(c[f+17528>>2]|0)+4>>2]&127](Z|0,167,-(c[b5>>2]|0)|0)|0;c[J>>2]=(I<<(a[b6]&1))+M}}while(0);Z=c[f+17552>>2]|0;z=f+17536|0;M=c[z>>2]|0;I=c[J>>2]|0;s=I>>>0<Z>>>0?I:M;do{if((d[f+17558|0]|0)<144){if((Z-i|0)>>>0<=4){b9=M;break}if((s+1-(a[f+17559|0]&1)|0)>>>0>i>>>0){b9=M;break}I=c[f+19660>>2]|0;c[I+20>>2]=0;c[I+92>>2]=5;_=c[I+96>>2]|0;F=(c[I+(_<<2)>>2]|0)!=0?5:_;c[I+76>>2]=F;_=c[I+72>>2]|0;D=(c[I+(_<<2)>>2]|0)>>>0<(c[I+(F<<2)>>2]|0)>>>0?_:F;c[I+64>>2]=D;F=c[I+68>>2]|0;_=(c[I+(D<<2)>>2]|0)>>>0<(c[I+(F<<2)>>2]|0)>>>0?D:F;c[I+60>>2]=_;c[I+36>>2]=c[I+(_<<2)>>2];b9=c[z>>2]|0}else{b9=M}}while(0);M=a[f+17559|0]&1;z=b9+1-M|0;if(z>>>0>i>>>0){ca=z}else{ca=(c[J>>2]|0)+(M^1)|0}c[y>>2]=ca;M=(c[f+19596>>2]|0)>>>0<ca>>>0?4:5;c[f+19652>>2]=M;z=c[f+19656>>2]|0;s=(c[f+19580+(M<<2)>>2]|0)>>>0<(c[f+19580+(z<<2)>>2]|0)>>>0?M:z;c[f+19640>>2]=s;z=c[f+19636>>2]|0;M=(c[f+19580+(z<<2)>>2]|0)>>>0<(c[f+19580+(s<<2)>>2]|0)>>>0?z:s;c[f+19632>>2]=M;s=c[f+19580+(M<<2)>>2]|0;c[f+19612>>2]=s;c[f+19560>>2]=s;M=(c[f+19564>>2]|0)>>>0<=s>>>0|0;c[f+19576>>2]=M;c[f+19568>>2]=c[f+19560+(M<<2)>>2];M=c[f+19660>>2]|0;c[M+28>>2]=s;z=(c[M+24>>2]|0)>>>0<s>>>0?6:7;c[M+96>>2]=z;s=c[M+92>>2]|0;Z=(c[M+(s<<2)>>2]|0)>>>0<(c[M+(z<<2)>>2]|0)>>>0?s:z;c[M+76>>2]=Z;z=c[M+72>>2]|0;s=(c[M+(z<<2)>>2]|0)>>>0<(c[M+(Z<<2)>>2]|0)>>>0?z:Z;c[M+64>>2]=s;Z=c[M+68>>2]|0;z=(c[M+(s<<2)>>2]|0)>>>0<(c[M+(Z<<2)>>2]|0)>>>0?s:Z;c[M+60>>2]=z;c[M+36>>2]=c[M+(z<<2)>>2];return};case 86:{if((a[f+19379|0]&1)==0){return}a[f+342|0]=(h|62)&255;return};case 104:{if((a[f+19379|0]&1)==0){return}a[f+360|0]=(h|64)&255;return};case 105:{if((a[f+19379|0]&1)==0){return}z=f+360|0;M=a[z]|0;Z=M&63;s=f+19432+Z|0;if((d[s]|0)==(h|0)){cb=M}else{_=f+17268|0;if(oT(_,i)|0){do{if((a[f+19362|0]|0)<=-1){I=f+19568|0;F=c[I>>2]|0;D=f+17532|0;bg=f+17559|0;v=f+17540|0;if(F>>>0<=i>>>0){n=_|0;A=f+19284|0;H=f+19288|0;P=f+17528|0;x=f+17558|0;bh=f+19292|0;K=F;do{F=c[D>>2]|0;w=a[bg]&1;$=(K-F|0)>>>(w>>>0);c[D>>2]=($<<w)+F;F=$+(c[v>>2]|0)|0;c[v>>2]=F;if((F|0)>-1){F=c[A>>2]|0;if((F|0)==0){cc=566992}else{cc=F+((ag(c[bh>>2]|0,d[x]|0)|0)<<2)|0}c[H>>2]=cc;f2[c[c[P>>2]>>2]&1023](n)}oY(_);K=c[I>>2]|0;}while(K>>>0<=i>>>0)}K=c[D>>2]|0;I=a[bg]&1;n=(i-K|0)>>>(I>>>0);c[D>>2]=(n<<I)+K;K=n+(c[v>>2]|0)|0;c[v>>2]=K;if((K|0)<=-1){break}K=c[f+19284>>2]|0;if((K|0)==0){cd=566992}else{cd=K+((ag(c[f+19292>>2]|0,d[f+17558|0]|0)|0)<<2)|0}c[f+19288>>2]=cd;f2[c[c[f+17528>>2]>>2]&1023](_|0)}}while(0);a[s]=h&255;_=Z>>>1;y=_<<1;J=d[f+19432+y|0]|0;K=d[(y|1)+(f+19432)|0]|0;y=J&31;n=(K<<8|J)>>>5&31;J=K>>>2&31;K=n<<1;c[f+17268+(_<<2)>>2]=((J*11|0)+(y*3|0)+K|0)>>>1|(n*3|0)+J<<9|(J+(y*13|0)+K|0)>>>1<<16}cb=a[z]|0}a[z]=((cb&255)>>>7)+M&63|cb&-64;return};case 106:{if((a[f+19379|0]&1)==0){return}a[f+362|0]=(h|64)&255;return};case 107:{if((a[f+19379|0]&1)==0){return}K=f+362|0;y=a[K]|0;J=y&63;n=f+19496+J|0;if((d[n]|0)==(h|0)){ce=y}else{_=f+17268|0;if(oT(_,i)|0){do{if((a[f+19362|0]|0)<=-1){I=f+19568|0;P=c[I>>2]|0;H=f+17532|0;x=f+17559|0;bh=f+17540|0;if(P>>>0<=i>>>0){A=_|0;F=f+19284|0;$=f+19288|0;w=f+17528|0;O=f+17558|0;bi=f+19292|0;bk=P;do{P=c[H>>2]|0;q=a[x]&1;L=(bk-P|0)>>>(q>>>0);c[H>>2]=(L<<q)+P;P=L+(c[bh>>2]|0)|0;c[bh>>2]=P;if((P|0)>-1){P=c[F>>2]|0;if((P|0)==0){cf=566992}else{cf=P+((ag(c[bi>>2]|0,d[O]|0)|0)<<2)|0}c[$>>2]=cf;f2[c[c[w>>2]>>2]&1023](A)}oY(_);bk=c[I>>2]|0;}while(bk>>>0<=i>>>0)}bk=c[H>>2]|0;I=a[x]&1;A=(i-bk|0)>>>(I>>>0);c[H>>2]=(A<<I)+bk;bk=A+(c[bh>>2]|0)|0;c[bh>>2]=bk;if((bk|0)<=-1){break}bk=c[f+19284>>2]|0;if((bk|0)==0){cg=566992}else{cg=bk+((ag(c[f+19292>>2]|0,d[f+17558|0]|0)|0)<<2)|0}c[f+19288>>2]=cg;f2[c[c[f+17528>>2]>>2]&1023](_|0)}}while(0);a[n]=h&255;_=J>>>1;M=_<<1;z=d[f+19496+M|0]|0;Z=d[(M|1)+(f+19496)|0]|0;M=z&31;s=(Z<<8|z)>>>5&31;z=Z>>>2&31;Z=s<<1;c[f+17396+(_<<2)>>2]=((z*11|0)+(M*3|0)+Z|0)>>>1|(s*3|0)+z<<9|(z+(M*13|0)+Z|0)>>>1<<16}ce=a[K]|0}a[K]=((ce&255)>>>7)+y&63|ce&-64;return};case 108:{if((a[f+19379|0]&1)==0){return}a[f+364|0]=(h|254)&255;return};case 112:{if((a[f+19379|0]&1)==0){return}Z=h&7;M=c[f+17172>>2]|0;z=(Z|0)==0?4096:Z<<12;c[f+17176>>2]=M+z;Z=M+(z-53248)|0;z=f+17148|0;c[z>>2]=Z;s=f+17084|0;c[s>>2]=Z;Z=f+17032|0;_=c[f+17200>>2]|0;do{if(((c[f+17184>>2]|0)-M|0)==32768){if((_|0)==0|(_|0)==1|(_|0)==4){yB(Z|0,0,32);c[f+17072>>2]=0;c[f+17076>>2]=0;c[f+17136>>2]=0;c[f+17140>>2]=0;break}else if((_|0)==3){c[f+17080>>2]=0;c[s>>2]=0;c[f+17088>>2]=0;c[f+17144>>2]=0;c[z>>2]=0;c[f+17152>>2]=0;break}else{break}}else{if(!((_|0)==0|(_|0)==1|(_|0)==3|(_|0)==4)){break}yB(Z|0,0,32);yB(f+17072|0,0,20);yB(f+17136|0,0,20)}}while(0);a[f+368|0]=(h|248)&255;return};case 114:case 115:case 116:{if((a[f+19379|0]&1)!=0){k=h&255;break L382}return};case 117:{if((a[f+19379|0]&1)==0){return}a[f+373|0]=(h|143)&255;return};case 255:{Z=h&31;c[f+17024>>2]=Z;if((a[f+17028|0]|0)!=0){if((c[f+17020>>2]&Z|0)==0){ch=-1}else{ch=c[f+17016>>2]|0}c[f+16944>>2]=ch;c[f+17012>>2]=8;c[f+16992>>2]=8;c[f+16980>>2]=8;Z=c[f+16976>>2]|0;_=(c[f+16912+(Z<<2)>>2]|0)>>>0<ch>>>0?Z:8;c[f+16972>>2]=_;c[f+16948>>2]=c[f+16912+(_<<2)>>2]}k=h&255;break};default:{return}}}while(0);a[f+(g-65024)|0]=k;return}function kS(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;i=f+380|0;j=c[i>>2]|0;k=h+1|0;h=(g-j|0)>>>(k>>>0);c[i>>2]=(h<<k)+j;if((h|0)==0){l=f+392|0;m=c[l>>2]|0;n=m+h|0;c[l>>2]=n;return}j=f+392|0;k=(c[f+376>>2]|0)+(c[j>>2]<<2)|0;yB(k|0,0,h<<2|0);i=f+384|0;g=f+60|0;if((d[f+72|0]|0)>7){o=c[f+104>>2]&c[i>>2]}else{o=0}p=o*-15|0;q=f+100|0;r=(c[q>>2]|0)+h|0;s=f+113|0;t=f+96|0;u=f+56|0;v=f+44|0;w=f+108|0;x=f+76|0;y=f+64|0;z=f+80|0;A=f+60|0;B=f+28|0;C=f+24|0;D=f+73|0;E=f+52|0;F=f+55|0;G=k;while(1){if((a[s]&1)==0){H=p}else{H=ag((d[D]<<1)-15|0,o)|0}I=c[(c[t>>2]|0)+4>>2]|0;J=I>>>0<r>>>0?I:r;I=(a[u]&1)!=0?H:p;if((c[v>>2]|0)>>>0>J>>>0){K=G;L=I;M=c[q>>2]|0}else{N=G;O=I;I=c[w>>2]|0;while(1){c[N>>2]=O-I;c[w>>2]=O;P=c[v>>2]|0;Q=N+(P-(c[q>>2]|0)<<2)|0;c[q>>2]=P;R=e[E>>1]|0;S=a[F]|0;T=R<<(S&255);if(S<<24>>24==3){U=T-(R<<1)|0}else{U=T}T=a[u]&1;S=T<<24>>24==0;a[u]=T^1;if(S){V=U}else{V=(R<<3)-U|0}R=P+V|0;c[v>>2]=R;T=S?H:p;if(R>>>0>J>>>0){K=Q;L=T;M=P;break}else{N=Q;I=O;O=T}}}if(M>>>0<J>>>0){c[K>>2]=L-(c[w>>2]|0);c[w>>2]=L;O=K+(J-(c[q>>2]|0)<<2)|0;c[q>>2]=J;W=O;X=J}else{W=K;X=M}O=c[t>>2]|0;if((c[O+4>>2]|0)!=(J|0)){break}f2[c[(c[O>>2]|0)+8>>2]&1023](O);c[t>>2]=x;if((c[y>>2]|0)>>>0<(c[z>>2]|0)>>>0){c[t>>2]=A;Y=A}else{Y=x}if((c[B>>2]|0)>>>0>=(c[Y+4>>2]|0)>>>0){G=W;continue}c[t>>2]=C;G=W}if((X|0)<0){W=f+48|0;G=c[W>>2]|0;do{if((G|0)!=-1){if(G>>>0>X>>>0){Z=G}else{t=e[E>>1]|0;Y=(((X-G|0)>>>0)/(t>>>0)|0)+1|0;B=(ag(Y,t)|0)+G|0;c[W>>2]=B;t=f+54|0;a[t]=(d[t]|0)+Y&7;Z=B}c[W>>2]=Z^-2147483648;B=c[v>>2]|0;if((B|0)==-1){break}c[v>>2]=B^-2147483648}}while(0);f3[c[(c[C>>2]|0)+12>>2]&1023](C,X);f3[c[(c[g>>2]|0)+12>>2]&1023](g|0,c[q>>2]|0);f3[c[(c[x>>2]|0)+12>>2]&1023](x,c[q>>2]|0);c[q>>2]=c[q>>2]^-2147483648}q=f+176|0;if((d[f+188|0]|0)>7){_=c[f+200>>2]&c[i>>2]}else{_=0}x=_*-15|0;g=f+196|0;X=(c[g>>2]|0)+h|0;C=f+209|0;v=f+192|0;Z=f+172|0;W=f+160|0;G=f+204|0;E=f+176|0;B=f+144|0;Y=f+180|0;t=f+140|0;A=f+189|0;z=f+168|0;y=f+171|0;M=k;while(1){if((a[C]&1)==0){$=x}else{$=ag((d[A]<<1)-15|0,_)|0}K=c[(c[v>>2]|0)+4>>2]|0;L=K>>>0<X>>>0?K:X;K=(a[Z]&1)!=0?$:x;if((c[W>>2]|0)>>>0>L>>>0){aa=M;ab=K;ac=c[g>>2]|0}else{w=M;p=K;K=c[G>>2]|0;while(1){c[w>>2]=p-K+(c[w>>2]|0);c[G>>2]=p;H=c[W>>2]|0;V=w+(H-(c[g>>2]|0)<<2)|0;c[g>>2]=H;U=e[z>>1]|0;u=a[y]|0;F=U<<(u&255);if(u<<24>>24==3){ad=F-(U<<1)|0}else{ad=F}F=a[Z]&1;u=F<<24>>24==0;a[Z]=F^1;if(u){ae=ad}else{ae=(U<<3)-ad|0}U=H+ae|0;c[W>>2]=U;F=u?$:x;if(U>>>0>L>>>0){aa=V;ab=F;ac=H;break}else{w=V;K=p;p=F}}}if(ac>>>0<L>>>0){c[aa>>2]=ab-(c[G>>2]|0)+(c[aa>>2]|0);c[G>>2]=ab;p=aa+(L-(c[g>>2]|0)<<2)|0;c[g>>2]=L;af=p;ah=L}else{af=aa;ah=ac}p=c[v>>2]|0;if((c[p+4>>2]|0)!=(L|0)){break}f2[c[(c[p>>2]|0)+8>>2]&1023](p);c[v>>2]=E;if((c[B>>2]|0)>>>0>=(c[Y>>2]|0)>>>0){M=af;continue}c[v>>2]=t;M=af}if((ah|0)<0){af=f+164|0;M=c[af>>2]|0;do{if((M|0)!=-1){if(M>>>0>ah>>>0){ai=M}else{v=e[z>>1]|0;Y=(((ah-M|0)>>>0)/(v>>>0)|0)+1|0;B=(ag(Y,v)|0)+M|0;c[af>>2]=B;v=f+170|0;a[v]=(d[v]|0)+Y&7;ai=B}c[af>>2]=ai^-2147483648;B=c[W>>2]|0;if((B|0)==-1){break}c[W>>2]=B^-2147483648}}while(0);f3[c[(c[t>>2]|0)+12>>2]&1023](t,ah);f3[c[(c[q>>2]|0)+12>>2]&1023](q|0,c[g>>2]|0);c[g>>2]=c[g>>2]^-2147483648}L1560:do{if((a[f+276|0]|0)==0){aj=1158}else{g=c[f+260>>2]&c[i>>2];if((g|0)==0){aj=1158;break}q=f+280|0;if((a[q]|0)==4){ah=g*-15|0;t=f+264|0;c[k>>2]=ah-(c[t>>2]|0)+(c[k>>2]|0);c[t>>2]=ah;aj=1158;break}ah=f+256|0;t=(c[ah>>2]|0)+h|0;W=f+244|0;ai=f+282|0;af=f+281|0;M=f+279|0;z=f+268|0;B=f+264|0;Y=f+272|0;v=f+277|0;E=f+278|0;ac=f+252|0;aa=f+248|0;ab=k;while(1){G=c[W>>2]|0;x=G>>>0<t>>>0?G:t;if((a[ai]&1)==0){ak=-15}else{ak=(((d[af]|0)>>>((d[M]<<2&4^4)>>>0)&15)>>>((d[q]|0)>>>0)<<1)-15|0}G=ag(ak,g)|0;if((c[z>>2]|0)>>>0>x>>>0){al=ab;am=G;an=c[ah>>2]|0}else{$=ab;ae=G;G=c[B>>2]|0;while(1){c[$>>2]=ae-G+(c[$>>2]|0);c[B>>2]=ae;ad=c[z>>2]|0;Z=$+(ad-(c[ah>>2]|0)<<2)|0;c[ah>>2]=ad;c[Y>>2]=ad;y=ad+2048-(d[E]<<8&1792|d[v])|0;c[z>>2]=y;X=(a[M]|0)+1&31;a[M]=X;_=X&255;X=a[(_>>>1)+(f+212)|0]|0;a[af]=X;A=ag((((X&255)>>>((_<<2&4^4)>>>0)&15)>>>((d[q]|0)>>>0)<<1)-15|0,g)|0;if(y>>>0>x>>>0){al=Z;am=A;an=ad;break}else{$=Z;G=ae;ae=A}}}if(an>>>0<x>>>0){c[al>>2]=am-(c[B>>2]|0)+(c[al>>2]|0);c[B>>2]=am;ae=al+(x-(c[ah>>2]|0)<<2)|0;c[ah>>2]=x;ao=ae;ap=x}else{ao=al;ap=an}if((c[W>>2]|0)!=(x|0)){aq=ap;break L1560}c[W>>2]=-1;b[ac>>1]=0;ae=c[aa>>2]|0;f2[c[(c[ae>>2]|0)+8>>2]&1023](ae);ab=ao}}}while(0);do{if((aj|0)==1158){ao=f+256|0;ap=(c[ao>>2]|0)+h|0;c[ao>>2]=ap;an=f+244|0;al=c[an>>2]|0;am=f+268|0;ak=c[am>>2]|0;if(al>>>0>ap>>>0){ar=ap;as=ak}else{ap=f+277|0;ab=f+278|0;aa=f+272|0;ac=f+279|0;W=f+281|0;ah=f+252|0;B=f+248|0;g=al;al=ak;while(1){if(al>>>0<=g>>>0){ak=2048-(d[ab]<<8&1792|d[ap])|0;q=((g-al|0)>>>0)/(ak>>>0)|0;af=(ag(ak,q)|0)+al|0;c[aa>>2]=af;c[am>>2]=af+ak;ak=q+1+(d[ac]|0)&31;a[ac]=ak;a[W]=a[((ak&255)>>>1)+(f+212)|0]|0}c[an>>2]=-1;b[ah>>1]=0;ak=c[B>>2]|0;f2[c[(c[ak>>2]|0)+8>>2]&1023](ak);ak=c[an>>2]|0;q=c[ao>>2]|0;af=c[am>>2]|0;if(ak>>>0>q>>>0){ar=q;as=af;break}else{g=ak;al=af}}}if(as>>>0>ar>>>0){aq=ar;break}al=2048-(d[f+278|0]<<8&1792|d[f+277|0])|0;g=((ar-as|0)>>>0)/(al>>>0)|0;ao=(ag(al,g)|0)+as|0;c[f+272>>2]=ao;c[am>>2]=ao+al;al=f+279|0;ao=g+1+(d[al]|0)&31;a[al]=ao;a[f+281|0]=a[((ao&255)>>>1)+(f+212)|0]|0;aq=ar}}while(0);ar=f+256|0;if((aq|0)<0){as=f+240|0;f3[c[(c[as>>2]|0)+12>>2]&1023](as,aq);aq=f+268|0;as=c[aq>>2]|0;if((as|0)!=-1){c[aq>>2]=as^-2147483648}as=f+272|0;c[as>>2]=c[as>>2]^-2147483648;c[ar>>2]=c[ar>>2]^-2147483648}ar=f+324|0;if((d[f+336|0]|0)>7){at=c[f+364>>2]&c[i>>2]}else{at=0}i=f+360|0;as=(c[i>>2]|0)+h|0;aq=f+337|0;aj=f+356|0;ao=f+352|0;al=f+344|0;g=f+368|0;an=f+324|0;B=f+312|0;ah=f+328|0;W=f+308|0;ac=f+354|0;aa=f+348|0;ap=k;k=c[aj>>2]|0;while(1){ab=(d[aq]<<1)-15|0;af=c[k+4>>2]|0;ak=af>>>0<as>>>0?af:as;af=ag((b[ao>>1]&1)==0?ab:-15,at)|0;if((c[al>>2]|0)>>>0>ak>>>0){au=ap;av=af;aw=c[i>>2]|0}else{q=ap;M=af;af=c[g>>2]|0;while(1){c[q>>2]=M-af+(c[q>>2]|0);c[g>>2]=M;z=c[al>>2]|0;v=q+(z-(c[i>>2]|0)<<2)|0;c[i>>2]=z;E=a[ac]|0;Y=b[ao>>1]|0;do{if((E&255)<224){ai=Y&65535;t=ai>>>1;L=(t^ai)&1;ai=L<<14|t;t=ai&65535;b[ao>>1]=t;if((E&8)==0){ax=t;break}t=(ai&32703|L<<6)&65535;b[ao>>1]=t;ax=t}else{ax=Y}}while(0);Y=E&255;x=Y&7;t=(x|0)==0;L=((t?1:x)<<(t?2:3)+(Y>>>4))+z|0;c[al>>2]=L;c[aa>>2]=L;Y=ag((ax&1)==0?ab:-15,at)|0;if(L>>>0>ak>>>0){au=v;av=Y;aw=z;break}else{q=v;af=M;M=Y}}}if(aw>>>0<ak>>>0){c[au>>2]=av-(c[g>>2]|0)+(c[au>>2]|0);c[g>>2]=av;M=au+(ak-(c[i>>2]|0)<<2)|0;c[i>>2]=ak;ay=M;az=ak}else{ay=au;az=aw}M=c[aj>>2]|0;if((c[M+4>>2]|0)!=(ak|0)){break}f2[c[(c[M>>2]|0)+8>>2]&1023](M);c[aj>>2]=an;if((c[B>>2]|0)>>>0>=(c[ah>>2]|0)>>>0){ap=ay;k=an;continue}c[aj>>2]=W;ap=ay;k=W}if((az|0)>=0){l=j;m=c[l>>2]|0;n=m+h|0;c[l>>2]=n;return}f3[c[(c[W>>2]|0)+12>>2]&1023](W,az);pc(f+340|0,c[i>>2]|0);c[aa>>2]=c[aa>>2]^-2147483648;aa=c[al>>2]|0;if((aa|0)!=-1){c[al>>2]=aa^-2147483648}f3[c[(c[ar>>2]|0)+12>>2]&1023](ar|0,c[i>>2]|0);c[i>>2]=c[i>>2]^-2147483648;l=j;m=c[l>>2]|0;n=m+h|0;c[l>>2]=n;return}function kT(a){a=a|0;c[a>>2]=74516;c[a+108>>2]=74536;kY(a+8|0);sN(a+108|0);return}function kU(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;c[b+d>>2]=74516;a=b+(d+108)|0;c[a>>2]=74536;kY(b+(d+8)|0);sN(a);return}function kV(a){a=a|0;c[a>>2]=74516;c[a+108>>2]=74536;kY(a+8|0);sN(a+108|0);if((a|0)==0){return}yt(a);return}function kW(a){a=a|0;var b=0,d=0,e=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;c[a>>2]=74516;e=b+(d+108)|0;c[e>>2]=74536;kY(b+(d+8)|0);sN(e);if((a|0)==0){return}yt(a);return}function kX(a){a=a|0;kY(a);return}function kY(b){b=b|0;var d=0,e=0,f=0;d=b|0;c[d>>2]=74752;e=b+64|0;f=c[e>>2]|0;do{if((f|0)!=0){k3(b)|0;if((a_(f|0)|0)!=0){break}c[e>>2]=0}}while(0);do{if((a[b+96|0]&1)!=0){e=c[b+32>>2]|0;if((e|0)==0){break}yt(e)}}while(0);do{if((a[b+97|0]&1)!=0){e=c[b+56>>2]|0;if((e|0)==0){break}yt(e)}}while(0);c[d>>2]=74440;d=c[b+4>>2]|0;b=d+4|0;if(((I=c[b>>2]|0,c[b>>2]=I+ -1,I)|0)!=0){return}f2[c[(c[d>>2]|0)+8>>2]&1023](d|0);return}function kZ(a){a=a|0;kY(a);if((a|0)==0){return}yt(a);return}function k_(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;g=c[b+68>>2]|0;h=f5[c[(c[g>>2]|0)+24>>2]&255](g)|0;g=b+64|0;do{if((c[g>>2]|0)!=0){i=(h|0)>0;if(!(i|(d|0)==0&(e|0)==0)){break}if((f5[c[(c[b>>2]|0)+24>>2]&255](b)|0)!=0){break}if(f>>>0>=3){j=a;c[j>>2]=0;c[j+4>>2]=0;j=a+8|0;c[j>>2]=-1;c[j+4>>2]=-1;return}j=c[g>>2]|0;if(i){i=yV(h,(h|0)<0?-1:0,d,e)|0;k=i}else{k=0}if((e6(j|0,k|0,f|0)|0)==0){j=cy(c[g>>2]|0)|0;i=b+72|0;l=c[i+4>>2]|0;m=a;c[m>>2]=c[i>>2];c[m+4>>2]=l;l=a+8|0;c[l>>2]=j;c[l+4>>2]=(j|0)<0?-1:0;return}else{j=a;c[j>>2]=0;c[j+4>>2]=0;j=a+8|0;c[j>>2]=-1;c[j+4>>2]=-1;return}}}while(0);b=a;c[b>>2]=0;c[b+4>>2]=0;b=a+8|0;c[b>>2]=-1;c[b+4>>2]=-1;return}function k$(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=b+64|0;do{if((c[f>>2]|0)!=0){if((f5[c[(c[b>>2]|0)+24>>2]&255](b)|0)!=0){break}if((e6(c[f>>2]|0,c[d+8>>2]|0,0)|0)==0){g=d;h=c[g+4>>2]|0;j=b+72|0;c[j>>2]=c[g>>2];c[j+4>>2]=h;h=a;j=d;c[h>>2]=c[j>>2];c[h+4>>2]=c[j+4>>2];c[h+8>>2]=c[j+8>>2];c[h+12>>2]=c[j+12>>2];i=e;return}else{j=a;c[j>>2]=0;c[j+4>>2]=0;j=a+8|0;c[j>>2]=-1;c[j+4>>2]=-1;i=e;return}}}while(0);d=a;c[d>>2]=0;c[d+4>>2]=0;d=a+8|0;c[d>>2]=-1;c[d+4>>2]=-1;i=e;return}function k0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e|0;f5[c[(c[b>>2]|0)+24>>2]&255](b)|0;g=c[d>>2]|0;if((c[185094]|0)!=-1){c[f>>2]=740376;c[f+4>>2]=210;c[f+8>>2]=0;st(740376,f)}f=(c[185095]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=ff(4)|0;j=h;c[j>>2]=72472;dr(h|0,79072,408)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=ff(4)|0;j=h;c[j>>2]=72472;dr(h|0,79072,408)}h=g;c[b+68>>2]=h;j=b+98|0;f=a[j]&1;d=f5[c[(c[g>>2]|0)+28>>2]&255](h)|0;a[j]=d&1;if((f&255|0)==(d&1|0)){i=e;return}f=b+96|0;yB(b+8|0,0,24);j=(a[f]&1)!=0;if(d){d=b+32|0;do{if(j){h=c[d>>2]|0;if((h|0)==0){break}yt(h)}}while(0);h=b+97|0;a[f]=a[h]&1;g=b+60|0;c[b+52>>2]=c[g>>2];k=b+56|0;c[d>>2]=c[k>>2];c[g>>2]=0;c[k>>2]=0;a[h]=0;i=e;return}do{if(!j){h=b+32|0;k=c[h>>2]|0;if((k|0)==(b+44|0)){break}g=c[b+52>>2]|0;c[b+60>>2]=g;c[b+56>>2]=k;a[b+97|0]=0;k=(g|0)==0?1:g;while(1){l=ys(k)|0;if((l|0)!=0){m=1278;break}g=(I=c[185320]|0,c[185320]=I+0,I);if((g|0)==0){m=1272;break}gs[g&63]()}if((m|0)==1272){k=ff(4)|0;c[k>>2]=72440;dr(k|0,79056,316)}else if((m|0)==1278){c[h>>2]=l;a[f]=1;i=e;return}}}while(0);f=c[b+52>>2]|0;c[b+60>>2]=f;l=(f|0)==0?1:f;while(1){n=ys(l)|0;if((n|0)!=0){m=1294;break}f=(I=c[185320]|0,c[185320]=I+0,I);if((f|0)==0){m=1288;break}gs[f&63]()}if((m|0)==1288){l=ff(4)|0;c[l>>2]=72440;dr(l|0,79056,316)}else if((m|0)==1294){c[b+56>>2]=n;a[b+97|0]=1;i=e;return}}function k1(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b|0;g=b+96|0;yB(b+8|0,0,24);do{if((a[g]&1)!=0){h=c[b+32>>2]|0;if((h|0)==0){break}yt(h)}}while(0);h=b+97|0;do{if((a[h]&1)!=0){i=c[b+56>>2]|0;if((i|0)==0){break}yt(i)}}while(0);i=b+52|0;c[i>>2]=e;do{if(e>>>0>8){j=a[b+98|0]|0;if(!((j&1)==0|(d|0)==0)){c[b+32>>2]=d;a[g]=0;k=j;break}l=(e|0)==0?1:e;while(1){m=ys(l)|0;if((m|0)!=0){n=1326;break}o=(I=c[185320]|0,c[185320]=I+0,I);if((o|0)==0){break}gs[o&63]()}if((n|0)==1326){c[b+32>>2]=m;a[g]=1;k=j;break}l=ff(4)|0;c[l>>2]=72440;dr(l|0,79056,316);return 0}else{c[b+32>>2]=b+44;c[i>>2]=8;a[g]=0;k=a[b+98|0]|0}}while(0);if((k&1)!=0){c[b+60>>2]=0;c[b+56>>2]=0;a[h]=0;return f|0}k=(e|0)<8?8:e;c[b+60>>2]=k;if((d|0)!=0&k>>>0>7){c[b+56>>2]=d;a[h]=0;return f|0}d=(k|0)==0?1:k;while(1){p=ys(d)|0;if((p|0)!=0){n=1346;break}k=(I=c[185320]|0,c[185320]=I+0,I);if((k|0)==0){n=1340;break}gs[k&63]()}if((n|0)==1340){d=ff(4)|0;c[d>>2]=72440;dr(d|0,79056,316);return 0}else if((n|0)==1346){c[b+56>>2]=p;a[h]=1;return f|0}return 0}function k2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((c[b+64>>2]|0)==0){e=-1;return e|0}f=b+12|0;g=c[f>>2]|0;if((c[b+8>>2]|0)>>>0>=g>>>0){e=-1;return e|0}if((d|0)==-1){c[f>>2]=g-1;e=0;return e|0}h=g-1|0;do{if((c[b+88>>2]&16|0)==0){if((d<<24>>24|0)==(a[h]|0)){break}else{e=-1}return e|0}}while(0);c[f>>2]=h;a[h]=d&255;e=d;return e|0}function k3(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=f;h=b+64|0;if((c[h>>2]|0)==0){j=0;i=d;return j|0}k=b+92|0;l=c[k>>2]|0;do{if((l&16|0)==0){if((l&8|0)==0){break}m=b+80|0;n=c[m+4>>2]|0;c[f>>2]=c[m>>2];c[f+4>>2]=n;do{if((a[b+98|0]&1)==0){n=b+68|0;m=c[n>>2]|0;o=f5[c[(c[m>>2]|0)+24>>2]&255](m)|0;m=b+36|0;p=c[m>>2]|0;q=(c[b+40>>2]|0)-p|0;if((o|0)>0){r=(ag((c[b+16>>2]|0)-(c[b+12>>2]|0)|0,o)|0)+q|0;s=0;break}o=c[b+12>>2]|0;if((o|0)==(c[b+16>>2]|0)){r=q;s=0;break}t=c[n>>2]|0;n=b+32|0;u=f9[c[(c[t>>2]|0)+32>>2]&31](t,g,c[n>>2]|0,p,o-(c[b+8>>2]|0)|0)|0;r=q-u+(c[m>>2]|0)-(c[n>>2]|0)|0;s=1}else{r=(c[b+16>>2]|0)-(c[b+12>>2]|0)|0;s=0}}while(0);if((e6(c[h>>2]|0,-r|0,1)|0)!=0){j=-1;i=d;return j|0}if(s){n=b+72|0;m=c[f+4>>2]|0;c[n>>2]=c[f>>2];c[n+4>>2]=m}m=c[b+32>>2]|0;c[b+40>>2]=m;c[b+36>>2]=m;c[b+8>>2]=0;c[b+12>>2]=0;c[b+16>>2]=0;c[k>>2]=0}else{do{if((c[b+24>>2]|0)!=(c[b+20>>2]|0)){if((gm[c[(c[b>>2]|0)+52>>2]&127](b,-1)|0)==-1){j=-1}else{break}i=d;return j|0}}while(0);m=b+68|0;n=b+72|0;u=b+32|0;q=b+52|0;while(1){o=c[m>>2]|0;p=c[u>>2]|0;t=f9[c[(c[o>>2]|0)+20>>2]&31](o,n,p,p+(c[q>>2]|0)|0,e)|0;p=c[u>>2]|0;o=(c[e>>2]|0)-p|0;if((be(p|0,1,o|0,c[h>>2]|0)|0)!=(o|0)){j=-1;v=1388;break}if((t|0)==2){j=-1;v=1392;break}else if((t|0)!=1){v=1372;break}}if((v|0)==1392){i=d;return j|0}else if((v|0)==1372){if((a7(c[h>>2]|0)|0)==0){break}else{j=-1}i=d;return j|0}else if((v|0)==1388){i=d;return j|0}}}while(0);j=0;i=d;return j|0}function k4(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=b+64|0;if((c[h>>2]|0)==0){j=-1;i=e;return j|0}k=b+92|0;if((c[k>>2]&8|0)==0){c[b+24>>2]=0;c[b+20>>2]=0;c[b+28>>2]=0;if((a[b+98|0]&1)==0){l=c[b+56>>2]|0;m=l+(c[b+60>>2]|0)|0;c[b+8>>2]=l;c[b+12>>2]=m;c[b+16>>2]=m;n=m}else{m=c[b+32>>2]|0;l=m+(c[b+52>>2]|0)|0;c[b+8>>2]=m;c[b+12>>2]=l;c[b+16>>2]=l;n=l}c[k>>2]=8;o=1;p=n;q=b+12|0}else{n=b+12|0;o=0;p=c[n>>2]|0;q=n}if((p|0)==0){n=f+1|0;c[b+8>>2]=f;c[q>>2]=n;c[b+16>>2]=n;r=n;s=n}else{r=p;s=c[b+16>>2]|0}p=b+16|0;if(o){t=0}else{o=(s-(c[b+8>>2]|0)|0)/2|0;t=o>>>0>4?4:o}do{if((r|0)==(s|0)){o=b+8|0;yI(c[o>>2]|0,s+(-t|0)|0,t|0);if((a[b+98|0]&1)!=0){n=c[o>>2]|0;k=eM(n+t|0,1,(c[p>>2]|0)-t-n|0,c[h>>2]|0)|0;if((k|0)==0){u=-1;v=o;break}n=c[o>>2]|0;l=n+t|0;c[q>>2]=l;c[p>>2]=n+(k+t);u=d[l]|0;v=o;break}l=b+32|0;k=b+36|0;n=c[k>>2]|0;m=b+40|0;yI(c[l>>2]|0,n|0,(c[m>>2]|0)-n|0);n=c[l>>2]|0;w=n+((c[m>>2]|0)-(c[k>>2]|0))|0;c[k>>2]=w;if((n|0)==(b+44|0)){x=8}else{x=c[b+52>>2]|0}y=n+x|0;c[m>>2]=y;n=b+60|0;z=(c[n>>2]|0)-t|0;A=y-w|0;y=b+72|0;B=y;C=b+80|0;D=c[B+4>>2]|0;c[C>>2]=c[B>>2];c[C+4>>2]=D;D=eM(w|0,1,(A>>>0<z>>>0?A:z)|0,c[h>>2]|0)|0;if((D|0)==0){u=-1;v=o;break}z=(c[k>>2]|0)+D|0;c[m>>2]=z;D=c[b+68>>2]|0;A=c[o>>2]|0;if((gt[c[(c[D>>2]|0)+16>>2]&31](D,y,c[l>>2]|0,z,k,A+t|0,A+(c[n>>2]|0)|0,g)|0)==3){n=c[l>>2]|0;l=c[m>>2]|0;c[o>>2]=n;c[q>>2]=n;c[p>>2]=l;u=d[n]|0;v=o;break}n=c[g>>2]|0;l=c[o>>2]|0;m=l+t|0;if((n|0)==(m|0)){u=-1;v=o;break}c[o>>2]=l;c[q>>2]=m;c[p>>2]=n;u=d[m]|0;v=o}else{u=d[r]|0;v=b+8|0}}while(0);if((c[v>>2]|0)!=(f|0)){j=u;i=e;return j|0}c[v>>2]=0;c[q>>2]=0;c[p>>2]=0;j=u;i=e;return j|0}function k5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b+64|0;if((c[j>>2]|0)==0){k=-1;i=e;return k|0}l=b+92|0;if((c[l>>2]&16|0)==0){c[b+8>>2]=0;c[b+12>>2]=0;c[b+16>>2]=0;m=c[b+52>>2]|0;do{if(m>>>0>8){if((a[b+98|0]&1)==0){n=c[b+56>>2]|0;o=n+((c[b+60>>2]|0)-1)|0;c[b+24>>2]=n;c[b+20>>2]=n;c[b+28>>2]=o;p=n;q=o;break}else{o=c[b+32>>2]|0;n=o+(m-1)|0;c[b+24>>2]=o;c[b+20>>2]=o;c[b+28>>2]=n;p=o;q=n;break}}else{c[b+24>>2]=0;c[b+20>>2]=0;c[b+28>>2]=0;p=0;q=0}}while(0);c[l>>2]=16;r=p;s=q;t=b+20|0;u=b+28|0;v=p;w=b+24|0}else{p=b+20|0;q=b+28|0;l=b+24|0;r=c[p>>2]|0;s=c[q>>2]|0;t=p;u=q;v=c[l>>2]|0;w=l}l=(d|0)==-1;if(l){x=r;y=v}else{if((v|0)==0){c[w>>2]=f;c[t>>2]=f;c[u>>2]=f+1;z=f}else{z=v}a[z]=d&255;z=(c[w>>2]|0)+1|0;c[w>>2]=z;x=c[t>>2]|0;y=z}if((y|0)!=(x|0)){L1890:do{if((a[b+98|0]&1)==0){z=b+32|0;v=c[z>>2]|0;c[g>>2]=v;f=b+68|0;q=b+72|0;p=b+52|0;m=x;n=y;o=v;while(1){v=c[f>>2]|0;A=gt[c[(c[v>>2]|0)+12>>2]&31](v,q,m,n,h,o,o+(c[p>>2]|0)|0,g)|0;B=c[t>>2]|0;if((c[h>>2]|0)==(B|0)){k=-1;C=1454;break}if((A|0)==3){C=1442;break}if(A>>>0>=2){k=-1;C=1456;break}v=c[z>>2]|0;D=(c[g>>2]|0)-v|0;if((be(v|0,1,D|0,c[j>>2]|0)|0)!=(D|0)){k=-1;C=1451;break}if((A|0)!=1){break L1890}A=c[h>>2]|0;D=c[w>>2]|0;c[t>>2]=A;c[u>>2]=D;v=A+(D-A)|0;c[w>>2]=v;m=A;n=v;o=c[z>>2]|0}if((C|0)==1451){i=e;return k|0}else if((C|0)==1454){i=e;return k|0}else if((C|0)==1456){i=e;return k|0}else if((C|0)==1442){z=(c[w>>2]|0)-B|0;if((be(B|0,1,z|0,c[j>>2]|0)|0)==(z|0)){break}else{k=-1}i=e;return k|0}}else{z=y-x|0;if((be(x|0,1,z|0,c[j>>2]|0)|0)==(z|0)){break}else{k=-1}i=e;return k|0}}while(0);c[w>>2]=r;c[t>>2]=r;c[u>>2]=s}k=l?0:d;i=e;return k|0}function k6(a,b){a=a|0;b=b|0;oL(a,c[b>>2]|0);return}function k7(a,b){a=a|0;b=b|0;c[b>>2]=oG(a)|0;return}function k8(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+4>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function k9(a,c){a=a|0;c=c|0;b[c+4>>1]=(oG(a)|0)&65535;return}function la(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;i=i+8|0;j=h|0;k=g&255;g=b+4|0;l=c[g>>2]|0;m=b+8|0;if((l|0)!=(c[m>>2]|0)){if((l|0)==0){n=0}else{c[l>>2]=d;c[l+4>>2]=e;c[l+8>>2]=f;a[l+12|0]=k;o=l+13|0;p=j|0;a[o]=a[p]|0;a[o+1|0]=a[p+1|0]|0;a[o+2|0]=a[p+2|0]|0;n=c[g>>2]|0}c[g>>2]=n+16;i=h;return}n=b|0;b=c[n>>2]|0;p=l-b|0;l=p>>4;o=l+1|0;if(o>>>0>268435455){wA()}if(l>>>0>134217726){q=268435455;r=1478}else{s=p>>3;t=s>>>0<o>>>0?o:s;if((t|0)==0){u=0;v=0}else{q=t;r=1478}}do{if((r|0)==1478){t=q<<4;s=(t|0)==0?1:t;while(1){w=ys(s)|0;if((w|0)!=0){r=1489;break}t=(I=c[185320]|0,c[185320]=I+0,I);if((t|0)==0){break}gs[t&63]()}if((r|0)==1489){u=w;v=q;break}s=ff(4)|0;c[s>>2]=72440;dr(s|0,79056,316)}}while(0);q=u+(l<<4)|0;w=u+(v<<4)|0;if((q|0)!=0){c[q>>2]=d;c[u+(l<<4)+4>>2]=e;c[u+(l<<4)+8>>2]=f;a[u+(l<<4)+12|0]=k;k=q+13|0;q=j|0;a[k]=a[q]|0;a[k+1|0]=a[q+1|0]|0;a[k+2|0]=a[q+2|0]|0}q=u+(o<<4)|0;o=u;k=b;yE(o|0,k|0,p)|0;c[n>>2]=u;c[g>>2]=q;c[m>>2]=w;if((b|0)==0){i=h;return}yt(k);i=h;return}function lb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+6>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function lc(a,c){a=a|0;c=c|0;b[c+6>>1]=(oG(a)|0)&65535;return}function ld(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+8|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function le(b,c){b=b|0;c=c|0;a[c+8|0]=(oG(b)|0)&255;return}function lf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+9|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function lg(b,c){b=b|0;c=c|0;a[c+9|0]=(oG(b)|0)&255;return}function lh(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+10|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function li(b,c){b=b|0;c=c|0;a[c+10|0]=(oG(b)|0)&255;return}function lj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+11|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function lk(b,c){b=b|0;c=c|0;a[c+11|0]=(oG(b)|0)&255;return}function ll(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+12|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function lm(b,c){b=b|0;c=c|0;a[c+12|0]=(oG(b)|0)&255;return}function ln(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+13|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function lo(b,c){b=b|0;c=c|0;a[c+13|0]=(oG(b)|0)&255;return}function lp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+14|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function lq(b,c){b=b|0;c=c|0;a[c+14|0]=(oG(b)|0)&255;return}function lr(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+15|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function ls(b,c){b=b|0;c=c|0;a[c+15|0]=(oG(b)|0)&255;return}function lt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+16|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function lu(b,c){b=b|0;c=c|0;a[c+16|0]=(oG(b)|0)!=0|0;return}function lv(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+89|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function lw(b,c){b=b|0;c=c|0;a[c+89|0]=(oG(b)|0)!=0|0;return}function lx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[d+20>>2]|0;f=c[d+24>>2]|0;d=b|0;g=c[d>>2]|0;do{if((g|0)==0){h=b+4|0;i=(c[h>>2]|0)+1|0;c[h>>2]=i;j=i;k=h;l=1602}else{c[d>>2]=g+1;a[g]=f>>>16&255;h=c[d>>2]|0;i=b+4|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){j=m;k=i;l=1602;break}c[d>>2]=h+1;a[h]=f>>>8&255;h=c[d>>2]|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){n=m;o=i;break}c[d>>2]=h+1;a[h]=f&255;n=c[i>>2]|0;o=i}}while(0);if((l|0)==1602){l=j+1|0;c[k>>2]=l;n=l;o=k}c[o>>2]=n+1;n=c[d>>2]|0;if((n|0)==0){p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}yE(n|0,e|0,f)|0;c[d>>2]=(c[d>>2]|0)+f;p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}function ly(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[d+20>>2]|0;f=c[d+24>>2]|0;d=b|0;g=c[d>>2]|0;h=g+1|0;c[d>>2]=h;i=a[g]|0;j=b+4|0;b=c[j>>2]|0;c[j>>2]=b+1;k=g+2|0;c[d>>2]=k;l=a[h]|0;c[j>>2]=b+2;h=g+3|0;c[d>>2]=h;g=a[k]|0;c[j>>2]=b+3;b=(l&255|(i&255)<<8)<<8|g&255;g=b>>>0<f>>>0?b:f;yE(e|0,h|0,g)|0;c[d>>2]=(c[d>>2]|0)+b;c[j>>2]=(c[j>>2]|0)+b-g;return}function lz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[d+28>>2]|0;f=c[d+32>>2]|0;d=b|0;g=c[d>>2]|0;do{if((g|0)==0){h=b+4|0;i=(c[h>>2]|0)+1|0;c[h>>2]=i;j=i;k=h;l=1614}else{c[d>>2]=g+1;a[g]=f>>>16&255;h=c[d>>2]|0;i=b+4|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){j=m;k=i;l=1614;break}c[d>>2]=h+1;a[h]=f>>>8&255;h=c[d>>2]|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){n=m;o=i;break}c[d>>2]=h+1;a[h]=f&255;n=c[i>>2]|0;o=i}}while(0);if((l|0)==1614){l=j+1|0;c[k>>2]=l;n=l;o=k}c[o>>2]=n+1;n=c[d>>2]|0;if((n|0)==0){p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}yE(n|0,e|0,f)|0;c[d>>2]=(c[d>>2]|0)+f;p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}function lA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[d+28>>2]|0;f=c[d+32>>2]|0;d=b|0;g=c[d>>2]|0;h=g+1|0;c[d>>2]=h;i=a[g]|0;j=b+4|0;b=c[j>>2]|0;c[j>>2]=b+1;k=g+2|0;c[d>>2]=k;l=a[h]|0;c[j>>2]=b+2;h=g+3|0;c[d>>2]=h;g=a[k]|0;c[j>>2]=b+3;b=(l&255|(i&255)<<8)<<8|g&255;g=b>>>0<f>>>0?b:f;yE(e|0,h|0,g)|0;c[d>>2]=(c[d>>2]|0)+b;c[j>>2]=(c[j>>2]|0)+b-g;return}function lB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[d+36>>2]|0;f=c[d+40>>2]|0;d=b|0;g=c[d>>2]|0;do{if((g|0)==0){h=b+4|0;i=(c[h>>2]|0)+1|0;c[h>>2]=i;j=i;k=h;l=1626}else{c[d>>2]=g+1;a[g]=f>>>16&255;h=c[d>>2]|0;i=b+4|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){j=m;k=i;l=1626;break}c[d>>2]=h+1;a[h]=f>>>8&255;h=c[d>>2]|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){n=m;o=i;break}c[d>>2]=h+1;a[h]=f&255;n=c[i>>2]|0;o=i}}while(0);if((l|0)==1626){l=j+1|0;c[k>>2]=l;n=l;o=k}c[o>>2]=n+1;n=c[d>>2]|0;if((n|0)==0){p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}yE(n|0,e|0,f)|0;c[d>>2]=(c[d>>2]|0)+f;p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}function lC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[d+36>>2]|0;f=c[d+40>>2]|0;d=b|0;g=c[d>>2]|0;h=g+1|0;c[d>>2]=h;i=a[g]|0;j=b+4|0;b=c[j>>2]|0;c[j>>2]=b+1;k=g+2|0;c[d>>2]=k;l=a[h]|0;c[j>>2]=b+2;h=g+3|0;c[d>>2]=h;g=a[k]|0;c[j>>2]=b+3;b=(l&255|(i&255)<<8)<<8|g&255;g=b>>>0<f>>>0?b:f;yE(e|0,h|0,g)|0;c[d>>2]=(c[d>>2]|0)+b;c[j>>2]=(c[j>>2]|0)+b-g;return}function lD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[d+44>>2]|0;f=c[d+48>>2]|0;d=b|0;g=c[d>>2]|0;do{if((g|0)==0){h=b+4|0;i=(c[h>>2]|0)+1|0;c[h>>2]=i;j=i;k=h;l=1638}else{c[d>>2]=g+1;a[g]=f>>>16&255;h=c[d>>2]|0;i=b+4|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){j=m;k=i;l=1638;break}c[d>>2]=h+1;a[h]=f>>>8&255;h=c[d>>2]|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){n=m;o=i;break}c[d>>2]=h+1;a[h]=f&255;n=c[i>>2]|0;o=i}}while(0);if((l|0)==1638){l=j+1|0;c[k>>2]=l;n=l;o=k}c[o>>2]=n+1;n=c[d>>2]|0;if((n|0)==0){p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}yE(n|0,e|0,f)|0;c[d>>2]=(c[d>>2]|0)+f;p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}function lE(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[d+44>>2]|0;f=c[d+48>>2]|0;d=b|0;g=c[d>>2]|0;h=g+1|0;c[d>>2]=h;i=a[g]|0;j=b+4|0;b=c[j>>2]|0;c[j>>2]=b+1;k=g+2|0;c[d>>2]=k;l=a[h]|0;c[j>>2]=b+2;h=g+3|0;c[d>>2]=h;g=a[k]|0;c[j>>2]=b+3;b=(l&255|(i&255)<<8)<<8|g&255;g=b>>>0<f>>>0?b:f;yE(e|0,h|0,g)|0;c[d>>2]=(c[d>>2]|0)+b;c[j>>2]=(c[j>>2]|0)+b-g;return}function lF(a,b){a=a|0;b=b|0;oL(a,c[b+52>>2]|0);return}function lG(a,b){a=a|0;b=b|0;c[b+52>>2]=oG(a)|0;return}function lH(a,b){a=a|0;b=b|0;oL(a,c[b+56>>2]|0);return}function lI(a,b){a=a|0;b=b|0;c[b+56>>2]=oG(a)|0;return}function lJ(a,b){a=a|0;b=b|0;oL(a,c[b+60>>2]|0);return}function lK(a,b){a=a|0;b=b|0;c[b+60>>2]=oG(a)|0;return}function lL(a,b){a=a|0;b=b|0;oL(a,c[b+64>>2]|0);return}function lM(a,b){a=a|0;b=b|0;c[b+64>>2]=oG(a)|0;return}function lN(a,b){a=a|0;b=b|0;oL(a,c[b+68>>2]|0);return}function lO(a,b){a=a|0;b=b|0;c[b+68>>2]=oG(a)|0;return}function lP(a,b){a=a|0;b=b|0;oL(a,c[b+72>>2]|0);return}function lQ(a,b){a=a|0;b=b|0;c[b+72>>2]=oG(a)|0;return}function lR(a,b){a=a|0;b=b|0;oL(a,c[b+76>>2]|0);return}function lS(a,b){a=a|0;b=b|0;c[b+76>>2]=oG(a)|0;return}function lT(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+80>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function lU(a,c){a=a|0;c=c|0;b[c+80>>1]=(oG(a)|0)&65535;return}function lV(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+82>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function lW(a,c){a=a|0;c=c|0;b[c+82>>1]=(oG(a)|0)&65535;return}function lX(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+84>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function lY(a,c){a=a|0;c=c|0;b[c+84>>1]=(oG(a)|0)&65535;return}function lZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+86|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function l_(b,c){b=b|0;c=c|0;a[c+86|0]=(oG(b)|0)&255;return}function l$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+87|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function l0(b,c){b=b|0;c=c|0;a[c+87|0]=(oG(b)|0)&255;return}function l1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+88|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function l2(b,c){b=b|0;c=c|0;a[c+88|0]=(oG(b)|0)!=0|0;return}function l3(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+90|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function l4(b,c){b=b|0;c=c|0;a[c+90|0]=(oG(b)|0)!=0|0;return}function l5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+91|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function l6(b,c){b=b|0;c=c|0;a[c+91|0]=(oG(b)|0)!=0|0;return}function l7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+92|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function l8(b,c){b=b|0;c=c|0;a[c+92|0]=(oG(b)|0)!=0|0;return}function l9(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[d+96>>2]|0;f=c[d+100>>2]|0;d=b|0;g=c[d>>2]|0;do{if((g|0)==0){h=b+4|0;i=(c[h>>2]|0)+1|0;c[h>>2]=i;j=i;k=h;l=1751}else{c[d>>2]=g+1;a[g]=f>>>16&255;h=c[d>>2]|0;i=b+4|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){j=m;k=i;l=1751;break}c[d>>2]=h+1;a[h]=f>>>8&255;h=c[d>>2]|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){n=m;o=i;break}c[d>>2]=h+1;a[h]=f&255;n=c[i>>2]|0;o=i}}while(0);if((l|0)==1751){l=j+1|0;c[k>>2]=l;n=l;o=k}c[o>>2]=n+1;n=c[d>>2]|0;if((n|0)==0){p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}yE(n|0,e|0,f)|0;c[d>>2]=(c[d>>2]|0)+f;p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}function ma(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[d+96>>2]|0;f=c[d+100>>2]|0;d=b|0;g=c[d>>2]|0;h=g+1|0;c[d>>2]=h;i=a[g]|0;j=b+4|0;b=c[j>>2]|0;c[j>>2]=b+1;k=g+2|0;c[d>>2]=k;l=a[h]|0;c[j>>2]=b+2;h=g+3|0;c[d>>2]=h;g=a[k]|0;c[j>>2]=b+3;b=(l&255|(i&255)<<8)<<8|g&255;g=b>>>0<f>>>0?b:f;yE(e|0,h|0,g)|0;c[d>>2]=(c[d>>2]|0)+b;c[j>>2]=(c[j>>2]|0)+b-g;return}function mb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[d+104>>2]|0;f=c[d+108>>2]|0;d=b|0;g=c[d>>2]|0;do{if((g|0)==0){h=b+4|0;i=(c[h>>2]|0)+1|0;c[h>>2]=i;j=i;k=h;l=1763}else{c[d>>2]=g+1;a[g]=f>>>16&255;h=c[d>>2]|0;i=b+4|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){j=m;k=i;l=1763;break}c[d>>2]=h+1;a[h]=f>>>8&255;h=c[d>>2]|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){n=m;o=i;break}c[d>>2]=h+1;a[h]=f&255;n=c[i>>2]|0;o=i}}while(0);if((l|0)==1763){l=j+1|0;c[k>>2]=l;n=l;o=k}c[o>>2]=n+1;n=c[d>>2]|0;if((n|0)==0){p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}yE(n|0,e|0,f)|0;c[d>>2]=(c[d>>2]|0)+f;p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}function mc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[d+104>>2]|0;f=c[d+108>>2]|0;d=b|0;g=c[d>>2]|0;h=g+1|0;c[d>>2]=h;i=a[g]|0;j=b+4|0;b=c[j>>2]|0;c[j>>2]=b+1;k=g+2|0;c[d>>2]=k;l=a[h]|0;c[j>>2]=b+2;h=g+3|0;c[d>>2]=h;g=a[k]|0;c[j>>2]=b+3;b=(l&255|(i&255)<<8)<<8|g&255;g=b>>>0<f>>>0?b:f;yE(e|0,h|0,g)|0;c[d>>2]=(c[d>>2]|0)+b;c[j>>2]=(c[j>>2]|0)+b-g;return}function md(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[d+120>>2]|0;f=c[d+124>>2]|0;d=b|0;g=c[d>>2]|0;do{if((g|0)==0){h=b+4|0;i=(c[h>>2]|0)+1|0;c[h>>2]=i;j=i;k=h;l=1775}else{c[d>>2]=g+1;a[g]=f>>>16&255;h=c[d>>2]|0;i=b+4|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){j=m;k=i;l=1775;break}c[d>>2]=h+1;a[h]=f>>>8&255;h=c[d>>2]|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){n=m;o=i;break}c[d>>2]=h+1;a[h]=f&255;n=c[i>>2]|0;o=i}}while(0);if((l|0)==1775){l=j+1|0;c[k>>2]=l;n=l;o=k}c[o>>2]=n+1;if((f|0)==0){return}n=b+4|0;b=0;do{o=c[d>>2]|0;if((o|0)!=0){k=a[e+b|0]&1;c[d>>2]=o+1;a[o]=k}c[n>>2]=(c[n>>2]|0)+1;b=b+1|0;}while(b>>>0<f>>>0);return}function me(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=c[d+120>>2]|0;f=c[d+124>>2]|0;d=b|0;g=c[d>>2]|0;h=g+1|0;c[d>>2]=h;i=a[g]|0;j=b+4|0;b=c[j>>2]|0;c[j>>2]=b+1;k=g+2|0;c[d>>2]=k;l=a[h]|0;c[j>>2]=b+2;h=g+3|0;c[d>>2]=h;g=a[k]|0;k=b+3|0;c[j>>2]=k;b=(l&255|(i&255)<<8)<<8|g&255;g=b>>>0<f>>>0?b:f;if((g|0)==0){m=h;n=k;o=b-g|0;p=m+o|0;c[d>>2]=p;q=n+o|0;c[j>>2]=q;return}else{r=0;s=h;t=k}while(1){c[d>>2]=s+1;k=a[s]|0;c[j>>2]=t+1;a[e+r|0]=k<<24>>24!=0|0;k=r+1|0;h=c[d>>2]|0;f=c[j>>2]|0;if(k>>>0<g>>>0){r=k;s=h;t=f}else{m=h;n=f;break}}o=b-g|0;p=m+o|0;c[d>>2]=p;q=n+o|0;c[j>>2]=q;return}function mf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[d+112>>2]|0;f=c[d+116>>2]|0;d=b|0;g=c[d>>2]|0;do{if((g|0)==0){h=b+4|0;i=(c[h>>2]|0)+1|0;c[h>>2]=i;j=i;k=h;l=1794}else{c[d>>2]=g+1;a[g]=f>>>16&255;h=c[d>>2]|0;i=b+4|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){j=m;k=i;l=1794;break}c[d>>2]=h+1;a[h]=f>>>8&255;h=c[d>>2]|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){n=m;o=i;break}c[d>>2]=h+1;a[h]=f&255;n=c[i>>2]|0;o=i}}while(0);if((l|0)==1794){l=j+1|0;c[k>>2]=l;n=l;o=k}c[o>>2]=n+1;n=c[d>>2]|0;if((n|0)==0){p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}yE(n|0,e|0,f)|0;c[d>>2]=(c[d>>2]|0)+f;p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}function mg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[d+112>>2]|0;f=c[d+116>>2]|0;d=b|0;g=c[d>>2]|0;h=g+1|0;c[d>>2]=h;i=a[g]|0;j=b+4|0;b=c[j>>2]|0;c[j>>2]=b+1;k=g+2|0;c[d>>2]=k;l=a[h]|0;c[j>>2]=b+2;h=g+3|0;c[d>>2]=h;g=a[k]|0;c[j>>2]=b+3;b=(l&255|(i&255)<<8)<<8|g&255;g=b>>>0<f>>>0?b:f;yE(e|0,h|0,g)|0;c[d>>2]=(c[d>>2]|0)+b;c[j>>2]=(c[j>>2]|0)+b-g;return}function mh(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+144|0;d=b|0;f=c[d>>2]|0;do{if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+1|0;c[g>>2]=h;i=h;j=g;k=1806}else{c[d>>2]=f+1;a[f]=0;g=c[d>>2]|0;h=b+4|0;l=(c[h>>2]|0)+1|0;c[h>>2]=l;if((g|0)==0){i=l;j=h;k=1806;break}c[d>>2]=g+1;a[g]=0;g=c[d>>2]|0;l=(c[h>>2]|0)+1|0;c[h>>2]=l;if((g|0)==0){m=l;n=h;break}c[d>>2]=g+1;a[g]=10;m=c[h>>2]|0;n=h}}while(0);if((k|0)==1806){k=i+1|0;c[j>>2]=k;m=k;n=j}c[n>>2]=m+1;m=c[d>>2]|0;if((m|0)==0){o=b+4|0;p=c[o>>2]|0;q=p+10|0;c[o>>2]=q;return}yE(m|0,e|0,10)|0;c[d>>2]=(c[d>>2]|0)+10;o=b+4|0;p=c[o>>2]|0;q=p+10|0;c[o>>2]=q;return}function mi(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d+144|0;d=b|0;f=c[d>>2]|0;g=f+1|0;c[d>>2]=g;h=a[f]|0;i=b+4|0;b=c[i>>2]|0;c[i>>2]=b+1;j=f+2|0;c[d>>2]=j;k=a[g]|0;c[i>>2]=b+2;g=f+3|0;c[d>>2]=g;f=a[j]|0;c[i>>2]=b+3;b=(k&255|(h&255)<<8)<<8|f&255;f=b>>>0<10?b:10;yE(e|0,g|0,f)|0;c[d>>2]=(c[d>>2]|0)+b;c[i>>2]=(c[i>>2]|0)+b-f;return}function mj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+154|0;d=b|0;f=c[d>>2]|0;do{if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+1|0;c[g>>2]=h;i=h;j=g;k=1818}else{c[d>>2]=f+1;a[f]=0;g=c[d>>2]|0;h=b+4|0;l=(c[h>>2]|0)+1|0;c[h>>2]=l;if((g|0)==0){i=l;j=h;k=1818;break}c[d>>2]=g+1;a[g]=0;g=c[d>>2]|0;l=(c[h>>2]|0)+1|0;c[h>>2]=l;if((g|0)==0){m=l;n=h;break}c[d>>2]=g+1;a[g]=10;m=c[h>>2]|0;n=h}}while(0);if((k|0)==1818){k=i+1|0;c[j>>2]=k;m=k;n=j}c[n>>2]=m+1;m=c[d>>2]|0;if((m|0)==0){o=b+4|0;p=c[o>>2]|0;q=p+10|0;c[o>>2]=q;return}yE(m|0,e|0,10)|0;c[d>>2]=(c[d>>2]|0)+10;o=b+4|0;p=c[o>>2]|0;q=p+10|0;c[o>>2]=q;return}function mk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d+154|0;d=b|0;f=c[d>>2]|0;g=f+1|0;c[d>>2]=g;h=a[f]|0;i=b+4|0;b=c[i>>2]|0;c[i>>2]=b+1;j=f+2|0;c[d>>2]=j;k=a[g]|0;c[i>>2]=b+2;g=f+3|0;c[d>>2]=g;f=a[j]|0;c[i>>2]=b+3;b=(k&255|(h&255)<<8)<<8|f&255;f=b>>>0<10?b:10;yE(e|0,g|0,f)|0;c[d>>2]=(c[d>>2]|0)+b;c[i>>2]=(c[i>>2]|0)+b-f;return}function ml(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+164|0;d=b|0;f=c[d>>2]|0;do{if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+1|0;c[g>>2]=h;i=h;j=g;k=1830}else{c[d>>2]=f+1;a[f]=0;g=c[d>>2]|0;h=b+4|0;l=(c[h>>2]|0)+1|0;c[h>>2]=l;if((g|0)==0){i=l;j=h;k=1830;break}c[d>>2]=g+1;a[g]=0;g=c[d>>2]|0;l=(c[h>>2]|0)+1|0;c[h>>2]=l;if((g|0)==0){m=l;n=h;break}c[d>>2]=g+1;a[g]=10;m=c[h>>2]|0;n=h}}while(0);if((k|0)==1830){k=i+1|0;c[j>>2]=k;m=k;n=j}c[n>>2]=m+1;m=c[d>>2]|0;if((m|0)==0){o=b+4|0;p=c[o>>2]|0;q=p+10|0;c[o>>2]=q;return}yE(m|0,e|0,10)|0;c[d>>2]=(c[d>>2]|0)+10;o=b+4|0;p=c[o>>2]|0;q=p+10|0;c[o>>2]=q;return}function mm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d+164|0;d=b|0;f=c[d>>2]|0;g=f+1|0;c[d>>2]=g;h=a[f]|0;i=b+4|0;b=c[i>>2]|0;c[i>>2]=b+1;j=f+2|0;c[d>>2]=j;k=a[g]|0;c[i>>2]=b+2;g=f+3|0;c[d>>2]=g;f=a[j]|0;c[i>>2]=b+3;b=(k&255|(h&255)<<8)<<8|f&255;f=b>>>0<10?b:10;yE(e|0,g|0,f)|0;c[d>>2]=(c[d>>2]|0)+b;c[i>>2]=(c[i>>2]|0)+b-f;return}function mn(a,b){a=a|0;b=b|0;oL(a,c[b+128>>2]|0);return}function mo(a,b){a=a|0;b=b|0;c[b+128>>2]=oG(a)|0;return}function mp(a,b){a=a|0;b=b|0;oL(a,c[b+132>>2]|0);return}function mq(a,b){a=a|0;b=b|0;c[b+132>>2]=oG(a)|0;return}function mr(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+136>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function ms(a,c){a=a|0;c=c|0;b[c+136>>1]=(oG(a)|0)&65535;return}function mt(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+138>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function mu(a,c){a=a|0;c=c|0;b[c+138>>1]=(oG(a)|0)&65535;return}function mv(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+140>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function mw(a,c){a=a|0;c=c|0;b[c+140>>1]=(oG(a)|0)&65535;return}function mx(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+142>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function my(a,c){a=a|0;c=c|0;b[c+142>>1]=(oG(a)|0)&65535;return}function mz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+174|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mA(b,c){b=b|0;c=c|0;a[c+174|0]=(oG(b)|0)&255;return}function mB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+175|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mC(b,c){b=b|0;c=c|0;a[c+175|0]=(oG(b)|0)&255;return}function mD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+176|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mE(b,c){b=b|0;c=c|0;a[c+176|0]=(oG(b)|0)&255;return}function mF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+177|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mG(b,c){b=b|0;c=c|0;a[c+177|0]=(oG(b)|0)&255;return}function mH(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+178|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mI(b,c){b=b|0;c=c|0;a[c+178|0]=(oG(b)|0)&255;return}function mJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+179|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mK(b,c){b=b|0;c=c|0;a[c+179|0]=(oG(b)|0)&255;return}function mL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+180|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mM(b,c){b=b|0;c=c|0;a[c+180|0]=(oG(b)|0)&255;return}function mN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+181|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mO(b,c){b=b|0;c=c|0;a[c+181|0]=(oG(b)|0)&255;return}function mP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+182|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mQ(b,c){b=b|0;c=c|0;a[c+182|0]=(oG(b)|0)&255;return}function mR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+183|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mS(b,c){b=b|0;c=c|0;a[c+183|0]=(oG(b)|0)&255;return}function mT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+184|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mU(b,c){b=b|0;c=c|0;a[c+184|0]=(oG(b)|0)&255;return}function mV(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+185|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mW(b,c){b=b|0;c=c|0;a[c+185|0]=(oG(b)|0)&255;return}function mX(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+186|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function mY(b,c){b=b|0;c=c|0;a[c+186|0]=(oG(b)|0)&255;return}function mZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+187|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function m_(b,c){b=b|0;c=c|0;a[c+187|0]=(oG(b)|0)&255;return}function m$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+188|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function m0(b,c){b=b|0;c=c|0;a[c+188|0]=(oG(b)|0)&255;return}function m1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+189|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function m2(b,c){b=b|0;c=c|0;a[c+189|0]=(oG(b)|0)!=0|0;return}function m3(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+190|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function m4(b,c){b=b|0;c=c|0;a[c+190|0]=(oG(b)|0)!=0|0;return}function m5(a,b){a=a|0;b=b|0;oL(a,c[b+316>>2]|0);return}function m6(a,b){a=a|0;b=b|0;c[b+316>>2]=oG(a)|0;return}function m7(a,b){a=a|0;b=b|0;oL(a,c[b+192>>2]|0);return}function m8(a,b){a=a|0;b=b|0;c[b+192>>2]=oG(a)|0;return}function m9(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+196>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function na(a,c){a=a|0;c=c|0;b[c+196>>1]=(oG(a)|0)&65535;return}function nb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+199|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function nc(b,c){b=b|0;c=c|0;a[c+199|0]=(oG(b)|0)!=0|0;return}function nd(a,b){a=a|0;b=b|0;oL(a,c[b+200>>2]|0);return}function ne(a,b){a=a|0;b=b|0;c[b+200>>2]=oG(a)|0;return}function nf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+205|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function ng(b,c){b=b|0;c=c|0;a[c+205|0]=(oG(b)|0)&255;return}function nh(a,b){a=a|0;b=b|0;oL(a,c[b+208>>2]|0);return}function ni(a,b){a=a|0;b=b|0;c[b+208>>2]=oG(a)|0;return}function nj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+212|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function nk(b,c){b=b|0;c=c|0;a[c+212|0]=(oG(b)|0)&255;return}function nl(a,b){a=a|0;b=b|0;oL(a,c[b+216>>2]|0);return}function nm(a,b){a=a|0;b=b|0;c[b+216>>2]=oG(a)|0;return}function nn(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+220>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function no(a,c){a=a|0;c=c|0;b[c+220>>1]=(oG(a)|0)&65535;return}function np(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+198|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function nq(b,c){b=b|0;c=c|0;a[c+198|0]=(oG(b)|0)&255;return}function nr(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+204|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function ns(b,c){b=b|0;c=c|0;a[c+204|0]=(oG(b)|0)&255;return}function nt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+224|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function nu(b,c){b=b|0;c=c|0;a[c+224|0]=(oG(b)|0)&255;return}function nv(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+225|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function nw(b,c){b=b|0;c=c|0;a[c+225|0]=(oG(b)|0)!=0|0;return}function nx(a,b){a=a|0;b=b|0;oL(a,c[b+228>>2]|0);return}function ny(a,b){a=a|0;b=b|0;c[b+228>>2]=oG(a)|0;return}function nz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+233|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function nA(b,c){b=b|0;c=c|0;a[c+233|0]=(oG(b)|0)&255;return}function nB(a,b){a=a|0;b=b|0;oL(a,c[b+236>>2]|0);return}function nC(a,b){a=a|0;b=b|0;c[b+236>>2]=oG(a)|0;return}function nD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+240|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function nE(b,c){b=b|0;c=c|0;a[c+240|0]=(oG(b)|0)&255;return}function nF(a,b){a=a|0;b=b|0;oL(a,c[b+244>>2]|0);return}function nG(a,b){a=a|0;b=b|0;c[b+244>>2]=oG(a)|0;return}function nH(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+248>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function nI(a,c){a=a|0;c=c|0;b[c+248>>1]=(oG(a)|0)&65535;return}function nJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+232|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function nK(b,c){b=b|0;c=c|0;a[c+232|0]=(oG(b)|0)&255;return}function nL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+252|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function nM(b,c){b=b|0;c=c|0;a[c+252|0]=(oG(b)|0)&255;return}function nN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+253|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function nO(b,c){b=b|0;c=c|0;a[c+253|0]=(oG(b)|0)!=0|0;return}function nP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[d+256>>2]|0;f=c[d+260>>2]|0;d=b|0;g=c[d>>2]|0;do{if((g|0)==0){h=b+4|0;i=(c[h>>2]|0)+1|0;c[h>>2]=i;j=i;k=h;l=2200}else{c[d>>2]=g+1;a[g]=f>>>16&255;h=c[d>>2]|0;i=b+4|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){j=m;k=i;l=2200;break}c[d>>2]=h+1;a[h]=f>>>8&255;h=c[d>>2]|0;m=(c[i>>2]|0)+1|0;c[i>>2]=m;if((h|0)==0){n=m;o=i;break}c[d>>2]=h+1;a[h]=f&255;n=c[i>>2]|0;o=i}}while(0);if((l|0)==2200){l=j+1|0;c[k>>2]=l;n=l;o=k}c[o>>2]=n+1;n=c[d>>2]|0;if((n|0)==0){p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}yE(n|0,e|0,f)|0;c[d>>2]=(c[d>>2]|0)+f;p=b+4|0;q=c[p>>2]|0;r=q+f|0;c[p>>2]=r;return}function nQ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[d+256>>2]|0;f=c[d+260>>2]|0;d=b|0;g=c[d>>2]|0;h=g+1|0;c[d>>2]=h;i=a[g]|0;j=b+4|0;b=c[j>>2]|0;c[j>>2]=b+1;k=g+2|0;c[d>>2]=k;l=a[h]|0;c[j>>2]=b+2;h=g+3|0;c[d>>2]=h;g=a[k]|0;c[j>>2]=b+3;b=(l&255|(i&255)<<8)<<8|g&255;g=b>>>0<f>>>0?b:f;yE(e|0,h|0,g)|0;c[d>>2]=(c[d>>2]|0)+b;c[j>>2]=(c[j>>2]|0)+b-g;return}function nR(a,b){a=a|0;b=b|0;oL(a,c[b+264>>2]|0);return}function nS(a,b){a=a|0;b=b|0;c[b+264>>2]=oG(a)|0;return}function nT(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+268>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function nU(a,c){a=a|0;c=c|0;b[c+268>>1]=(oG(a)|0)&65535;return}function nV(a,b){a=a|0;b=b|0;oL(a,c[b+272>>2]|0);return}function nW(a,b){a=a|0;b=b|0;c[b+272>>2]=oG(a)|0;return}function nX(a,b){a=a|0;b=b|0;oL(a,c[b+276>>2]|0);return}function nY(a,b){a=a|0;b=b|0;c[b+276>>2]=oG(a)|0;return}function nZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+282|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function n_(b,c){b=b|0;c=c|0;a[c+282|0]=(oG(b)|0)&255;return}function n$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+283|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function n0(b,c){b=b|0;c=c|0;a[c+283|0]=(oG(b)|0)&255;return}function n1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+280|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function n2(b,c){b=b|0;c=c|0;a[c+280|0]=(oG(b)|0)&255;return}function n3(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+281|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function n4(b,c){b=b|0;c=c|0;a[c+281|0]=(oG(b)|0)&255;return}function n5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+284|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function n6(b,c){b=b|0;c=c|0;a[c+284|0]=(oG(b)|0)!=0|0;return}function n7(a,b){a=a|0;b=b|0;oL(a,c[b+288>>2]|0);return}function n8(a,b){a=a|0;b=b|0;c[b+288>>2]=oG(a)|0;return}function n9(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+292>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function oa(a,c){a=a|0;c=c|0;b[c+292>>1]=(oG(a)|0)&65535;return}function ob(a,b){a=a|0;b=b|0;oL(a,c[b+296>>2]|0);return}function oc(a,b){a=a|0;b=b|0;c[b+296>>2]=oG(a)|0;return}function od(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+300|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function oe(b,c){b=b|0;c=c|0;a[c+300|0]=(oG(b)|0)&255;return}function of(a,b){a=a|0;b=b|0;oL(a,c[b+304>>2]|0);return}function og(a,b){a=a|0;b=b|0;c[b+304>>2]=oG(a)|0;return}function oh(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[e+308>>1]|0;e=d|0;g=c[e>>2]|0;do{if((g|0)==0){h=d+4|0;i=(c[h>>2]|0)+3|0;c[h>>2]=i;j=i;k=h}else{a[g]=a[56928]|0;a[g+1|0]=a[56929|0]|0;a[g+2|0]=a[56930|0]|0;h=c[e>>2]|0;i=h+3|0;c[e>>2]=i;l=d+4|0;m=(c[l>>2]|0)+3|0;c[l>>2]=m;if((i|0)==0){j=m;k=l;break}c[e>>2]=h+4;a[i]=(f&65535)>>>8&255;i=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((i|0)==0){n=h;o=l;p=n+1|0;c[o>>2]=p;return}c[e>>2]=i+1;a[i]=f&255;n=c[l>>2]|0;o=l;p=n+1|0;c[o>>2]=p;return}}while(0);f=j+1|0;c[k>>2]=f;n=f;o=k;p=n+1|0;c[o>>2]=p;return}function oi(a,c){a=a|0;c=c|0;b[c+308>>1]=(oG(a)|0)&65535;return}function oj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+312|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function ok(b,c){b=b|0;c=c|0;a[c+312|0]=(oG(b)|0)&255;return}function ol(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+313|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function om(b,c){b=b|0;c=c|0;a[c+313|0]=(oG(b)|0)!=0|0;return}function on(a,b){a=a|0;b=b|0;oL(a,c[b+320>>2]|0);return}function oo(a,b){a=a|0;b=b|0;c[b+320>>2]=oG(a)|0;return}function op(a,b){a=a|0;b=b|0;oL(a,c[b+324>>2]|0);return}function oq(a,b){a=a|0;b=b|0;c[b+324>>2]=oG(a)|0;return}function or(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+328|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function os(b,c){b=b|0;c=c|0;a[c+328|0]=(oG(b)|0)&255;return}function ot(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+329|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function ou(b,c){b=b|0;c=c|0;a[c+329|0]=(oG(b)|0)&255;return}function ov(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+330|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function ow(b,c){b=b|0;c=c|0;a[c+330|0]=(oG(b)|0)&255;return}function ox(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+331|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function oy(b,c){b=b|0;c=c|0;a[c+331|0]=(oG(b)|0)&255;return}function oz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+332|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function oA(b,c){b=b|0;c=c|0;a[c+332|0]=(oG(b)|0)&255;return}function oB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+333|0]|0;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function oC(b,c){b=b|0;c=c|0;a[c+333|0]=(oG(b)|0)&255;return}function oD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a[d+334|0]&1;d=b|0;f=c[d>>2]|0;if((f|0)==0){g=b+4|0;h=(c[g>>2]|0)+3|0;c[g>>2]=h;i=h;j=g;k=i+1|0;c[j>>2]=k;return}a[f]=a[56944]|0;a[f+1|0]=a[56945|0]|0;a[f+2|0]=a[56946|0]|0;f=c[d>>2]|0;g=f+3|0;c[d>>2]=g;h=b+4|0;b=(c[h>>2]|0)+3|0;c[h>>2]=b;if((g|0)==0){i=b;j=h;k=i+1|0;c[j>>2]=k;return}c[d>>2]=f+4;a[g]=e;i=c[h>>2]|0;j=h;k=i+1|0;c[j>>2]=k;return}function oE(b,c){b=b|0;c=c|0;a[c+334|0]=(oG(b)|0)!=0|0;return}function oF(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;if((b|0)==0){return}d=a+4|0;a=c[d>>2]|0;if((b|0)!=(a|0)){c[d>>2]=a+(~((a-16+(-b|0)|0)>>>4)<<4)}yt(b);return}function oG(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b|0;e=c[d>>2]|0;f=e+1|0;c[d>>2]=f;g=a[e]|0;h=b+4|0;b=c[h>>2]|0;c[h>>2]=b+1;i=e+2|0;c[d>>2]=i;j=a[f]|0;c[h>>2]=b+2;f=e+3|0;c[d>>2]=f;k=a[i]|0;i=b+3|0;c[h>>2]=i;l=(j&255|(g&255)<<8)<<8|k&255;do{if(l>>>0>4){k=e+(l-1)|0;c[d>>2]=k;g=b-1+l|0;c[h>>2]=g;m=k;n=g;o=2403}else{if((l|0)==4){m=f;n=i;o=2403;break}else if((l|0)==2){p=0;q=f;r=i;o=2405;break}else if((l|0)==1){s=0;t=f;u=i;break}else if((l|0)==3){v=0;w=f;x=i;o=2404;break}else{y=0}return y|0}}while(0);if((o|0)==2403){i=m+1|0;c[d>>2]=i;f=a[m]|0;m=n+1|0;c[h>>2]=m;v=(f&255)<<8;w=i;x=m;o=2404}if((o|0)==2404){m=w+1|0;c[d>>2]=m;i=a[w]|0;w=x+1|0;c[h>>2]=w;p=(i&255|v)<<8;q=m;r=w;o=2405}if((o|0)==2405){o=q+1|0;c[d>>2]=o;w=a[q]|0;q=r+1|0;c[h>>2]=q;s=(w&255|p)<<8;t=o;u=q}c[d>>2]=t+1;d=a[t]|0;c[h>>2]=u+1;y=d&255|s;return y|0}function oH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;d=i;i=i+160|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+144|0;k=d+64|0;l=d+80|0;m=d+112|0;n=d+128|0;o=d+96|0;p=a;a=b;L2973:while(1){b=a;q=a-16|0;r=q|0;s=q;t=p;L2975:while(1){u=t;v=b-u|0;w=v>>4;switch(w|0){case 5:{x=2420;break L2973;break};case 3:{x=2415;break L2973;break};case 4:{x=2416;break L2973;break};case 0:case 1:{x=2463;break L2973;break};case 2:{x=2413;break L2973;break};default:{}}if((v|0)<496){x=2422;break L2973}y=(w|0)/2|0;z=t+(y<<4)|0;if((v|0)>15984){v=(w|0)/4|0;A=oJ(t,t+(v<<4)|0,z,t+(v+y<<4)|0,q)|0}else{A=oI(t,z,q)|0}y=t|0;v=c[y>>2]|0;w=c[z>>2]|0;do{if((db(v|0,w|0)|0)<0){B=q;C=A}else{D=q;while(1){E=D-16|0;if((t|0)==(E|0)){break}if((db(c[E>>2]|0,w|0)|0)<0){x=2445;break}else{D=E}}if((x|0)==2445){x=0;D=t;c[o>>2]=c[D>>2];c[o+4>>2]=c[D+4>>2];c[o+8>>2]=c[D+8>>2];c[o+12>>2]=c[D+12>>2];F=E;c[D>>2]=c[F>>2];c[D+4>>2]=c[F+4>>2];c[D+8>>2]=c[F+8>>2];c[D+12>>2]=c[F+12>>2];c[F>>2]=c[o>>2];c[F+4>>2]=c[o+4>>2];c[F+8>>2]=c[o+8>>2];c[F+12>>2]=c[o+12>>2];B=E;C=A+1|0;break}F=t+16|0;if((db(v|0,c[r>>2]|0)|0)<0){G=F}else{D=F;while(1){if((D|0)==(q|0)){x=2468;break L2973}H=D+16|0;if((db(v|0,c[D>>2]|0)|0)<0){break}else{D=H}}F=D;c[n>>2]=c[F>>2];c[n+4>>2]=c[F+4>>2];c[n+8>>2]=c[F+8>>2];c[n+12>>2]=c[F+12>>2];c[F>>2]=c[s>>2];c[F+4>>2]=c[s+4>>2];c[F+8>>2]=c[s+8>>2];c[F+12>>2]=c[s+12>>2];c[s>>2]=c[n>>2];c[s+4>>2]=c[n+4>>2];c[s+8>>2]=c[n+8>>2];c[s+12>>2]=c[n+12>>2];G=H}if((G|0)==(q|0)){x=2465;break L2973}else{I=q;J=G}while(1){F=c[y>>2]|0;K=J;while(1){L=K+16|0;if((db(F|0,c[K>>2]|0)|0)<0){M=I;break}else{K=L}}do{M=M-16|0;}while((db(F|0,c[M>>2]|0)|0)<0);if(K>>>0>=M>>>0){t=K;continue L2975}F=K;c[m>>2]=c[F>>2];c[m+4>>2]=c[F+4>>2];c[m+8>>2]=c[F+8>>2];c[m+12>>2]=c[F+12>>2];N=M;c[F>>2]=c[N>>2];c[F+4>>2]=c[N+4>>2];c[F+8>>2]=c[N+8>>2];c[F+12>>2]=c[N+12>>2];c[N>>2]=c[m>>2];c[N+4>>2]=c[m+4>>2];c[N+8>>2]=c[m+8>>2];c[N+12>>2]=c[m+12>>2];I=M;J=L}}}while(0);y=t+16|0;L3005:do{if(y>>>0<B>>>0){v=B;w=y;D=C;N=z;while(1){F=c[N>>2]|0;O=w;while(1){P=O+16|0;if((db(c[O>>2]|0,F|0)|0)<0){O=P}else{Q=v;break}}do{Q=Q-16|0;}while((db(c[Q>>2]|0,F|0)|0)>=0);if(O>>>0>Q>>>0){R=O;S=D;T=N;break L3005}F=O;c[l>>2]=c[F>>2];c[l+4>>2]=c[F+4>>2];c[l+8>>2]=c[F+8>>2];c[l+12>>2]=c[F+12>>2];K=Q;c[F>>2]=c[K>>2];c[F+4>>2]=c[K+4>>2];c[F+8>>2]=c[K+8>>2];c[F+12>>2]=c[K+12>>2];c[K>>2]=c[l>>2];c[K+4>>2]=c[l+4>>2];c[K+8>>2]=c[l+8>>2];c[K+12>>2]=c[l+12>>2];v=Q;w=P;D=D+1|0;N=(N|0)==(O|0)?Q:N}}else{R=y;S=C;T=z}}while(0);do{if((R|0)==(T|0)){U=S}else{if((db(c[T>>2]|0,c[R>>2]|0)|0)>=0){U=S;break}z=R;c[k>>2]=c[z>>2];c[k+4>>2]=c[z+4>>2];c[k+8>>2]=c[z+8>>2];c[k+12>>2]=c[z+12>>2];y=T;c[z>>2]=c[y>>2];c[z+4>>2]=c[y+4>>2];c[z+8>>2]=c[y+8>>2];c[z+12>>2]=c[y+12>>2];c[y>>2]=c[k>>2];c[y+4>>2]=c[k+4>>2];c[y+8>>2]=c[k+8>>2];c[y+12>>2]=c[k+12>>2];U=S+1|0}}while(0);if((U|0)==0){V=oK(t,R)|0;y=R+16|0;if(oK(y,a)|0){x=2457;break}if(V){t=y;continue}}y=R;if((y-u|0)>=(b-y|0)){x=2461;break}oH(t,R);t=R+16|0}if((x|0)==2457){x=0;if(V){x=2476;break}else{p=t;a=R;continue}}else if((x|0)==2461){x=0;oH(R+16|0,a);p=t;a=R;continue}}if((x|0)==2420){R=t+16|0;p=t+32|0;V=t+48|0;oJ(t,R,p,V,q)|0;i=d;return}else if((x|0)==2422){V=e;e=t+32|0;oI(t,t+16|0,e)|0;p=t+48|0;if((p|0)==(a|0)){i=d;return}else{W=e;X=p}while(1){p=c[X>>2]|0;if((db(p|0,c[W>>2]|0)|0)<0){e=X+4|0;c[V>>2]=c[e>>2];c[V+4>>2]=c[e+4>>2];c[V+8>>2]=c[e+8>>2];e=W;R=X;while(1){U=R;S=e;c[U>>2]=c[S>>2];c[U+4>>2]=c[S+4>>2];c[U+8>>2]=c[S+8>>2];c[U+12>>2]=c[S+12>>2];if((e|0)==(t|0)){Y=t;break}S=e-16|0;if((db(p|0,c[S>>2]|0)|0)<0){R=e;e=S}else{Y=e;break}}c[Y>>2]=p;e=Y+4|0;c[e>>2]=c[V>>2];c[e+4>>2]=c[V+4>>2];c[e+8>>2]=c[V+8>>2]}e=X+16|0;if((e|0)==(a|0)){break}else{W=X;X=e}}i=d;return}else if((x|0)==2476){i=d;return}else if((x|0)==2415){oI(t,t+16|0,q)|0;i=d;return}else if((x|0)==2416){q=t+16|0;X=t+32|0;W=f;f=g;g=h;oI(t,q,X)|0;h=X|0;if((db(c[r>>2]|0,c[h>>2]|0)|0)>=0){i=d;return}a=X;c[g>>2]=c[a>>2];c[g+4>>2]=c[a+4>>2];c[g+8>>2]=c[a+8>>2];c[g+12>>2]=c[a+12>>2];c[a>>2]=c[s>>2];c[a+4>>2]=c[s+4>>2];c[a+8>>2]=c[s+8>>2];c[a+12>>2]=c[s+12>>2];c[s>>2]=c[g>>2];c[s+4>>2]=c[g+4>>2];c[s+8>>2]=c[g+8>>2];c[s+12>>2]=c[g+12>>2];g=q|0;if((db(c[h>>2]|0,c[g>>2]|0)|0)>=0){i=d;return}h=q;c[W>>2]=c[h>>2];c[W+4>>2]=c[h+4>>2];c[W+8>>2]=c[h+8>>2];c[W+12>>2]=c[h+12>>2];c[h>>2]=c[a>>2];c[h+4>>2]=c[a+4>>2];c[h+8>>2]=c[a+8>>2];c[h+12>>2]=c[a+12>>2];c[a>>2]=c[W>>2];c[a+4>>2]=c[W+4>>2];c[a+8>>2]=c[W+8>>2];c[a+12>>2]=c[W+12>>2];if((db(c[g>>2]|0,c[t>>2]|0)|0)>=0){i=d;return}g=t;c[f>>2]=c[g>>2];c[f+4>>2]=c[g+4>>2];c[f+8>>2]=c[g+8>>2];c[f+12>>2]=c[g+12>>2];c[g>>2]=c[h>>2];c[g+4>>2]=c[h+4>>2];c[g+8>>2]=c[h+8>>2];c[g+12>>2]=c[h+12>>2];c[h>>2]=c[f>>2];c[h+4>>2]=c[f+4>>2];c[h+8>>2]=c[f+8>>2];c[h+12>>2]=c[f+12>>2];i=d;return}else if((x|0)==2463){i=d;return}else if((x|0)==2465){i=d;return}else if((x|0)==2468){i=d;return}else if((x|0)==2413){if((db(c[r>>2]|0,c[t>>2]|0)|0)>=0){i=d;return}r=j;j=t;c[r>>2]=c[j>>2];c[r+4>>2]=c[j+4>>2];c[r+8>>2]=c[j+8>>2];c[r+12>>2]=c[j+12>>2];c[j>>2]=c[s>>2];c[j+4>>2]=c[s+4>>2];c[j+8>>2]=c[s+8>>2];c[j+12>>2]=c[s+12>>2];c[s>>2]=c[r>>2];c[s+4>>2]=c[r+4>>2];c[s+8>>2]=c[r+8>>2];c[s+12>>2]=c[r+12>>2];i=d;return}}function oI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=b|0;m=c[l>>2]|0;n=a|0;o=(db(m|0,c[n>>2]|0)|0)<0;p=d|0;q=(db(c[p>>2]|0,m|0)|0)<0;if(!o){if(!q){r=0;i=e;return r|0}o=k;k=b;c[o>>2]=c[k>>2];c[o+4>>2]=c[k+4>>2];c[o+8>>2]=c[k+8>>2];c[o+12>>2]=c[k+12>>2];m=d;c[k>>2]=c[m>>2];c[k+4>>2]=c[m+4>>2];c[k+8>>2]=c[m+8>>2];c[k+12>>2]=c[m+12>>2];c[m>>2]=c[o>>2];c[m+4>>2]=c[o+4>>2];c[m+8>>2]=c[o+8>>2];c[m+12>>2]=c[o+12>>2];if((db(c[l>>2]|0,c[n>>2]|0)|0)>=0){r=1;i=e;return r|0}n=h;h=a;c[n>>2]=c[h>>2];c[n+4>>2]=c[h+4>>2];c[n+8>>2]=c[h+8>>2];c[n+12>>2]=c[h+12>>2];c[h>>2]=c[k>>2];c[h+4>>2]=c[k+4>>2];c[h+8>>2]=c[k+8>>2];c[h+12>>2]=c[k+12>>2];c[k>>2]=c[n>>2];c[k+4>>2]=c[n+4>>2];c[k+8>>2]=c[n+8>>2];c[k+12>>2]=c[n+12>>2];r=2;i=e;return r|0}if(q){q=f;f=a;c[q>>2]=c[f>>2];c[q+4>>2]=c[f+4>>2];c[q+8>>2]=c[f+8>>2];c[q+12>>2]=c[f+12>>2];n=d;c[f>>2]=c[n>>2];c[f+4>>2]=c[n+4>>2];c[f+8>>2]=c[n+8>>2];c[f+12>>2]=c[n+12>>2];c[n>>2]=c[q>>2];c[n+4>>2]=c[q+4>>2];c[n+8>>2]=c[q+8>>2];c[n+12>>2]=c[q+12>>2];r=1;i=e;return r|0}q=g;g=a;c[q>>2]=c[g>>2];c[q+4>>2]=c[g+4>>2];c[q+8>>2]=c[g+8>>2];c[q+12>>2]=c[g+12>>2];a=b;c[g>>2]=c[a>>2];c[g+4>>2]=c[a+4>>2];c[g+8>>2]=c[a+8>>2];c[g+12>>2]=c[a+12>>2];c[a>>2]=c[q>>2];c[a+4>>2]=c[q+4>>2];c[a+8>>2]=c[q+8>>2];c[a+12>>2]=c[q+12>>2];if((db(c[p>>2]|0,c[l>>2]|0)|0)>=0){r=1;i=e;return r|0}l=j;c[l>>2]=c[a>>2];c[l+4>>2]=c[a+4>>2];c[l+8>>2]=c[a+8>>2];c[l+12>>2]=c[a+12>>2];j=d;c[a>>2]=c[j>>2];c[a+4>>2]=c[j+4>>2];c[a+8>>2]=c[j+8>>2];c[a+12>>2]=c[j+12>>2];c[j>>2]=c[l>>2];c[j+4>>2]=c[l+4>>2];c[j+8>>2]=c[l+8>>2];c[j+12>>2]=c[l+12>>2];r=2;i=e;return r|0}function oJ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+112|0;h=g+48|0;j=g+64|0;k=g+80|0;l=g+96|0;m=g|0;n=g+16|0;o=g+32|0;p=oI(a,b,d)|0;q=e|0;r=d|0;do{if((db(c[q>>2]|0,c[r>>2]|0)|0)<0){s=d;c[o>>2]=c[s>>2];c[o+4>>2]=c[s+4>>2];c[o+8>>2]=c[s+8>>2];c[o+12>>2]=c[s+12>>2];t=e;c[s>>2]=c[t>>2];c[s+4>>2]=c[t+4>>2];c[s+8>>2]=c[t+8>>2];c[s+12>>2]=c[t+12>>2];c[t>>2]=c[o>>2];c[t+4>>2]=c[o+4>>2];c[t+8>>2]=c[o+8>>2];c[t+12>>2]=c[o+12>>2];t=b|0;if((db(c[r>>2]|0,c[t>>2]|0)|0)>=0){u=p+1|0;break}v=b;c[m>>2]=c[v>>2];c[m+4>>2]=c[v+4>>2];c[m+8>>2]=c[v+8>>2];c[m+12>>2]=c[v+12>>2];c[v>>2]=c[s>>2];c[v+4>>2]=c[s+4>>2];c[v+8>>2]=c[s+8>>2];c[v+12>>2]=c[s+12>>2];c[s>>2]=c[m>>2];c[s+4>>2]=c[m+4>>2];c[s+8>>2]=c[m+8>>2];c[s+12>>2]=c[m+12>>2];if((db(c[t>>2]|0,c[a>>2]|0)|0)<0){t=a;c[n>>2]=c[t>>2];c[n+4>>2]=c[t+4>>2];c[n+8>>2]=c[t+8>>2];c[n+12>>2]=c[t+12>>2];c[t>>2]=c[v>>2];c[t+4>>2]=c[v+4>>2];c[t+8>>2]=c[v+8>>2];c[t+12>>2]=c[v+12>>2];c[v>>2]=c[n>>2];c[v+4>>2]=c[n+4>>2];c[v+8>>2]=c[n+8>>2];c[v+12>>2]=c[n+12>>2];u=p+3|0;break}else{u=p+2|0;break}}else{u=p}}while(0);if((db(c[f>>2]|0,c[q>>2]|0)|0)>=0){w=u;i=g;return w|0}p=l;l=e;c[p>>2]=c[l>>2];c[p+4>>2]=c[l+4>>2];c[p+8>>2]=c[l+8>>2];c[p+12>>2]=c[l+12>>2];e=f;c[l>>2]=c[e>>2];c[l+4>>2]=c[e+4>>2];c[l+8>>2]=c[e+8>>2];c[l+12>>2]=c[e+12>>2];c[e>>2]=c[p>>2];c[e+4>>2]=c[p+4>>2];c[e+8>>2]=c[p+8>>2];c[e+12>>2]=c[p+12>>2];if((db(c[q>>2]|0,c[r>>2]|0)|0)>=0){w=u+1|0;i=g;return w|0}q=j;j=d;c[q>>2]=c[j>>2];c[q+4>>2]=c[j+4>>2];c[q+8>>2]=c[j+8>>2];c[q+12>>2]=c[j+12>>2];c[j>>2]=c[l>>2];c[j+4>>2]=c[l+4>>2];c[j+8>>2]=c[l+8>>2];c[j+12>>2]=c[l+12>>2];c[l>>2]=c[q>>2];c[l+4>>2]=c[q+4>>2];c[l+8>>2]=c[q+8>>2];c[l+12>>2]=c[q+12>>2];q=b|0;if((db(c[r>>2]|0,c[q>>2]|0)|0)>=0){w=u+2|0;i=g;return w|0}r=h;h=b;c[r>>2]=c[h>>2];c[r+4>>2]=c[h+4>>2];c[r+8>>2]=c[h+8>>2];c[r+12>>2]=c[h+12>>2];c[h>>2]=c[j>>2];c[h+4>>2]=c[j+4>>2];c[h+8>>2]=c[j+8>>2];c[h+12>>2]=c[j+12>>2];c[j>>2]=c[r>>2];c[j+4>>2]=c[r+4>>2];c[j+8>>2]=c[r+8>>2];c[j+12>>2]=c[r+12>>2];if((db(c[q>>2]|0,c[a>>2]|0)|0)>=0){w=u+3|0;i=g;return w|0}q=k;k=a;c[q>>2]=c[k>>2];c[q+4>>2]=c[k+4>>2];c[q+8>>2]=c[k+8>>2];c[q+12>>2]=c[k+12>>2];c[k>>2]=c[h>>2];c[k+4>>2]=c[h+4>>2];c[k+8>>2]=c[h+8>>2];c[k+12>>2]=c[h+12>>2];c[h>>2]=c[q>>2];c[h+4>>2]=c[q+4>>2];c[h+8>>2]=c[q+8>>2];c[h+12>>2]=c[q+12>>2];w=u+4|0;i=g;return w|0}function oK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+80|0;switch(b-a>>4|0){case 3:{oI(a,a+16|0,b-16|0)|0;e=1;i=d;return e|0};case 5:{oJ(a,a+16|0,a+32|0,a+48|0,b-16|0)|0;e=1;i=d;return e|0};case 0:case 1:{e=1;i=d;return e|0};case 2:{f=b-16|0;if((db(c[f>>2]|0,c[a>>2]|0)|0)>=0){e=1;i=d;return e|0}g=d+48|0;h=a;c[g>>2]=c[h>>2];c[g+4>>2]=c[h+4>>2];c[g+8>>2]=c[h+8>>2];c[g+12>>2]=c[h+12>>2];j=f;c[h>>2]=c[j>>2];c[h+4>>2]=c[j+4>>2];c[h+8>>2]=c[j+8>>2];c[h+12>>2]=c[j+12>>2];c[j>>2]=c[g>>2];c[j+4>>2]=c[g+4>>2];c[j+8>>2]=c[g+8>>2];c[j+12>>2]=c[g+12>>2];e=1;i=d;return e|0};case 4:{g=a+16|0;j=a+32|0;h=b-16|0;f=d|0;k=d+16|0;l=d+32|0;oI(a,g,j)|0;m=j|0;if((db(c[h>>2]|0,c[m>>2]|0)|0)>=0){e=1;i=d;return e|0}n=j;c[l>>2]=c[n>>2];c[l+4>>2]=c[n+4>>2];c[l+8>>2]=c[n+8>>2];c[l+12>>2]=c[n+12>>2];j=h;c[n>>2]=c[j>>2];c[n+4>>2]=c[j+4>>2];c[n+8>>2]=c[j+8>>2];c[n+12>>2]=c[j+12>>2];c[j>>2]=c[l>>2];c[j+4>>2]=c[l+4>>2];c[j+8>>2]=c[l+8>>2];c[j+12>>2]=c[l+12>>2];l=g|0;if((db(c[m>>2]|0,c[l>>2]|0)|0)>=0){e=1;i=d;return e|0}m=g;c[f>>2]=c[m>>2];c[f+4>>2]=c[m+4>>2];c[f+8>>2]=c[m+8>>2];c[f+12>>2]=c[m+12>>2];c[m>>2]=c[n>>2];c[m+4>>2]=c[n+4>>2];c[m+8>>2]=c[n+8>>2];c[m+12>>2]=c[n+12>>2];c[n>>2]=c[f>>2];c[n+4>>2]=c[f+4>>2];c[n+8>>2]=c[f+8>>2];c[n+12>>2]=c[f+12>>2];if((db(c[l>>2]|0,c[a>>2]|0)|0)>=0){e=1;i=d;return e|0}l=a;c[k>>2]=c[l>>2];c[k+4>>2]=c[l+4>>2];c[k+8>>2]=c[l+8>>2];c[k+12>>2]=c[l+12>>2];c[l>>2]=c[m>>2];c[l+4>>2]=c[m+4>>2];c[l+8>>2]=c[m+8>>2];c[l+12>>2]=c[m+12>>2];c[m>>2]=c[k>>2];c[m+4>>2]=c[k+4>>2];c[m+8>>2]=c[k+8>>2];c[m+12>>2]=c[k+12>>2];e=1;i=d;return e|0};default:{k=a+32|0;oI(a,a+16|0,k)|0;m=a+48|0;if((m|0)==(b|0)){e=1;i=d;return e|0}l=d+64|0;f=k;k=0;n=m;while(1){m=c[n>>2]|0;if((db(m|0,c[f>>2]|0)|0)<0){g=n+4|0;c[l>>2]=c[g>>2];c[l+4>>2]=c[g+4>>2];c[l+8>>2]=c[g+8>>2];g=f;j=n;while(1){h=j;o=g;c[h>>2]=c[o>>2];c[h+4>>2]=c[o+4>>2];c[h+8>>2]=c[o+8>>2];c[h+12>>2]=c[o+12>>2];if((g|0)==(a|0)){p=a;break}o=g-16|0;if((db(m|0,c[o>>2]|0)|0)<0){j=g;g=o}else{p=g;break}}c[p>>2]=m;g=p+4|0;c[g>>2]=c[l>>2];c[g+4>>2]=c[l+4>>2];c[g+8>>2]=c[l+8>>2];g=k+1|0;if((g|0)==8){break}else{q=g}}else{q=k}g=n+16|0;if((g|0)==(b|0)){e=1;r=2535;break}else{f=n;k=q;n=g}}if((r|0)==2535){i=d;return e|0}e=(n+16|0)==(b|0);i=d;return e|0}}return 0}function oL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=b|0;f=c[e>>2]|0;do{if((f|0)==0){g=b+4|0;h=c[g>>2]|0;c[g>>2]=h+3;i=g;j=h;k=2543}else{a[f]=a[56936]|0;a[f+1|0]=a[56937|0]|0;a[f+2|0]=a[56938|0]|0;h=c[e>>2]|0;g=h+3|0;c[e>>2]=g;l=b+4|0;m=c[l>>2]|0;c[l>>2]=m+3;if((g|0)==0){i=l;j=m;k=2543;break}c[e>>2]=h+4;a[g]=d>>>24&255;g=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((g|0)==0){n=h;o=l;k=2545;break}c[e>>2]=g+1;a[g]=d>>>16&255;g=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((g|0)==0){p=h;q=l;break}c[e>>2]=g+1;a[g]=d>>>8&255;g=c[e>>2]|0;h=(c[l>>2]|0)+1|0;c[l>>2]=h;if((g|0)==0){r=h;s=l;t=r+1|0;c[s>>2]=t;return}c[e>>2]=g+1;a[g]=d&255;r=c[l>>2]|0;s=l;t=r+1|0;c[s>>2]=t;return}}while(0);if((k|0)==2543){d=j+4|0;c[i>>2]=d;n=d;o=i;k=2545}if((k|0)==2545){k=n+1|0;c[o>>2]=k;p=k;q=o}o=p+1|0;c[q>>2]=o;r=o;s=q;t=r+1|0;c[s>>2]=t;return}function oM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=a[b+10|0]|0;if((f&4)==0){g=a[b+8|0]|0;h=g&255;return h|0}i=b|0;j=c[i>>2]|0;k=d[84328+(f&3)|0]|0;f=(e-j|0)>>>(k>>>0);l=(f<<k)+j|0;c[i>>2]=l;i=b+4|0;j=c[i>>2]|0;if(j>>>0>e>>>0){m=a[b+8|0]|0}else{if((j+4|0)>>>0<=e>>>0){c[i>>2]=-1}j=a[b+9|0]|0;a[b+8|0]=j;m=j}j=b+8|0;k=(m&255)+f|0;if(k>>>0>256){f=d[b+9|0]|0|-256;m=k;while(1){n=m+f|0;if(n>>>0>256){m=n}else{o=n;break}}}else{o=k}k=o&255;do{if((o|0)==256){m=l+3|0;c[i>>2]=m;if(m>>>0>e>>>0){p=0;break}if((l+7|0)>>>0<=e>>>0){c[i>>2]=-1}p=a[b+9|0]|0}else{p=k}}while(0);a[j]=p;g=p;h=g&255;return h|0}function oN(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=e+108|0;g=c[f>>2]|4;c[f>>2]=g;do{if((a[e+116|0]|0)!=0){if((c[e+112>>2]&g|0)==0){break}f=c[e+104>>2]|0;c[e+32>>2]=f;c[e+100>>2]=8;c[e+80>>2]=8;c[e+68>>2]=8;h=c[e+64>>2]|0;i=(c[e+(h<<2)>>2]|0)>>>0<f>>>0?h:8;c[e+60>>2]=i;c[e+36>>2]=c[e+(i<<2)>>2]}}while(0);g=e+24|0;i=(256-(d[b+9|0]|0)<<d[84328+(a[b+10|0]&3)|0])+(c[g>>2]|0)|0;c[g>>2]=i;g=(c[e+28>>2]|0)>>>0>i>>>0?6:7;c[e+96>>2]=g;i=c[e+92>>2]|0;b=(c[e+(i<<2)>>2]|0)>>>0<(c[e+(g<<2)>>2]|0)>>>0?i:g;c[e+76>>2]=b;g=c[e+72>>2]|0;i=(c[e+(g<<2)>>2]|0)>>>0<(c[e+(b<<2)>>2]|0)>>>0?g:b;c[e+64>>2]=i;b=c[e+68>>2]|0;g=(c[e+(i<<2)>>2]|0)>>>0<(c[e+(b<<2)>>2]|0)>>>0?i:b;c[e+60>>2]=g;c[e+36>>2]=c[e+(g<<2)>>2];return}function oO(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[b+2111|0]&1)==0){e=d[b+2164|0]|0;c[b>>2]=c[b+2116+((e&3)<<2)>>2];c[b+4>>2]=c[b+2116+((e>>>2&3)<<2)>>2];c[b+8>>2]=c[b+2116+((e>>>4&3)<<2)>>2];c[b+12>>2]=c[b+2116+(e>>>6<<2)>>2];e=d[b+2228|0]|0;c[b+128>>2]=c[b+2116+((e&3|4)<<2)>>2];c[b+132>>2]=c[b+2116+((e>>>2&3|4)<<2)>>2];c[b+136>>2]=c[b+2116+((e>>>4&3|4)<<2)>>2];c[b+140>>2]=c[b+2116+((e>>>6|4)<<2)>>2];e=d[b+2229|0]|0;c[b+144>>2]=c[b+2116+((e&3|8)<<2)>>2];c[b+148>>2]=c[b+2116+((e>>>2&3|8)<<2)>>2];c[b+152>>2]=c[b+2116+((e>>>4&3|8)<<2)>>2];c[b+156>>2]=c[b+2116+((e>>>6|8)<<2)>>2];return}else{e=0;do{f=d[b+2164+e|0]|0;g=e|1;h=d[b+2164+g|0]|0;i=f&31;j=(h<<8|f)>>>5&31;f=h>>>2&31;h=j<<1;k=e>>>1;c[b+(k<<2)>>2]=((f*11|0)+(i*3|0)+h|0)>>>1|(j*3|0)+f<<9|(f+(i*13|0)+h|0)>>>1<<16;h=d[b+2228+e|0]|0;i=d[b+2228+g|0]|0;g=h&31;f=(i<<8|h)>>>5&31;h=i>>>2&31;i=f<<1;c[b+128+(k<<2)>>2]=((h*11|0)+(g*3|0)+i|0)>>>1|(f*3|0)+h<<9|(h+(g*13|0)+i|0)>>>1<<16;e=e+2|0;}while(e>>>0<64);return}}function oP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[185292]=0;c[185293]=0;c[185294]=0;la(741168,56816,536,280,3);la(741168,56808,508,156,3);la(741168,56624,212,492,3);la(741168,56536,254,8,2);la(741168,56448,376,390,2);la(741168,56360,458,72,2);la(741168,56272,472,480,2);la(741168,56184,60,302,2);la(741168,56096,90,482,2);la(741168,56008,528,160,2);la(741168,56800,430,464,2);la(741168,56712,2,190,5);la(741168,56680,596,634,5);la(741168,56672,320,100,5);la(741168,56664,524,102,5);la(741168,15752,32,130,5);la(741168,56656,240,296,5);la(741168,56648,182,378,7);la(741168,56640,304,242,8);la(741168,56632,92,226,8);la(741168,56616,104,290,8);la(741168,56608,164,466,8);la(741168,56600,188,238,8);la(741168,56592,140,578,8);la(741168,56584,252,336,8);la(741168,56576,640,432,7);la(741168,56568,410,332,7);la(741168,56560,166,610,8);la(741168,56552,264,64,8);la(741168,56544,114,544,4);la(741168,56528,326,560,7);la(741168,56520,442,4,8);la(741168,56512,132,564,5);la(741168,56504,468,522,4);la(741168,56496,214,58,5);la(741168,56488,312,470,8);la(741168,56480,484,608,8);la(741168,56472,598,26,7);la(741168,56464,178,620,8);la(741168,56456,118,36,8);la(741168,56440,310,372,8);la(741168,56432,262,400,8);la(741168,56424,616,196,7);la(741168,56416,612,44,7);la(741168,56408,144,668,5);la(741168,56400,582,356,6);la(741168,56392,654,38,8);la(741168,56384,358,656,5);la(741168,56376,452,566,5);la(741168,56368,622,652,6);la(741168,56352,532,230,6);la(741168,56344,88,526,7);la(741168,56336,306,642,8);la(741168,56328,438,498,8);la(741168,56320,142,232,8);la(741168,56312,66,552,8);la(741168,56304,670,422,4);la(741168,56296,590,134,6);la(741168,56288,550,136,6);la(741168,56280,86,658,8);la(741168,56264,450,324,5);la(741168,56256,244,20,8);la(741168,56248,298,288,8);la(741168,56240,386,228,8);la(741168,56232,496,558,8);la(741168,56224,650,40,8);la(741168,56216,554,592,7);la(741168,56208,486,50,8);la(741168,56200,510,16,8);la(741168,56192,220,154,8);la(741168,56176,94,584,8);la(741168,56168,398,626,8);la(741168,56160,448,146,8);la(741168,56152,180,334,5);la(741168,56144,440,488,5);la(741168,56136,420,318,5);la(741168,56128,340,322,8);la(741168,56120,46,366,8);la(741168,56112,216,194,8);la(741168,56104,56,294,8);la(741168,56088,516,360,8);la(741168,56080,364,120,8);la(741168,56072,540,630,8);la(741168,56064,152,418,5);la(741168,56056,462,490,5);la(741168,56048,572,330,8);la(741168,56040,6,224,8);la(741168,56032,454,666,8);la(741168,56024,70,106,8);la(741168,56016,384,80,8);la(741168,56e3,348,662,8);la(741168,55992,342,580,8);la(741168,55984,556,346,8);la(741168,55976,380,162,5);la(741168,55968,570,54,5);la(741168,55960,250,52,8);la(741168,55952,316,284,8);la(741168,55944,618,148,8);la(741168,55936,474,588,8);la(741168,55928,476,506,8);la(741168,56792,10,24,8);la(741168,56784,42,110,8);la(741168,56776,416,328,5);la(741168,56768,624,548,8);la(741168,56760,278,542,8);la(741168,56752,494,186,8);la(741168,56744,30,62,8);la(741168,56736,234,514,6);la(741168,56728,168,388,6);la(741168,56720,122,660,5);la(741168,56704,128,370,5);la(741168,56696,96,632,5);la(741168,56688,174,76,7);oH(c[185292]|0,c[185293]|0);a[741180]=0;b=c[185293]|0;d=c[185292]|0;if((b|0)==(d|0)){e=ep(208,741168,r|0)|0;return}f=b-d>>4;b=0;g=0;while(1){h=a[d+(b<<4)+12|0]|0;if((h&255)>(g&255)){a[741180]=h;i=h}else{i=g}h=b+1|0;if(h>>>0<f>>>0){b=h;g=i}else{break}}e=ep(208,741168,r|0)|0;return}function oQ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[b+2094|0]|0)>-1){return}f=b+2300|0;g=c[f>>2]|0;h=b+264|0;i=b+291|0;j=b+272|0;if(g>>>0<=e>>>0){k=b|0;l=b+2016|0;m=b+2020|0;n=b+260|0;o=b+290|0;p=b+2024|0;q=g;do{g=c[h>>2]|0;r=a[i]&1;s=(q-g|0)>>>(r>>>0);c[h>>2]=(s<<r)+g;g=s+(c[j>>2]|0)|0;c[j>>2]=g;if((g|0)>-1){g=c[l>>2]|0;if((g|0)==0){t=566992}else{t=g+((ag(c[p>>2]|0,d[o]|0)|0)<<2)|0}c[m>>2]=t;f2[c[c[n>>2]>>2]&1023](k)}oY(b);q=c[f>>2]|0;}while(q>>>0<=e>>>0)}q=c[h>>2]|0;f=a[i]&1;i=(e-q|0)>>>(f>>>0);c[h>>2]=(i<<f)+q;q=i+(c[j>>2]|0)|0;c[j>>2]=q;if((q|0)<=-1){return}q=c[b+2016>>2]|0;if((q|0)==0){u=566992}else{u=q+((ag(c[b+2024>>2]|0,d[b+290|0]|0)|0)<<2)|0}c[b+2020>>2]=u;f2[c[c[b+260>>2]>>2]&1023](b|0);return}function oR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b+2300|0;g=c[f>>2]|0;do{if(g>>>0<=e>>>0){if((a[b+2094|0]|0)>-1){break}h=b+264|0;i=b+291|0;j=b+272|0;k=b|0;l=b+2016|0;m=b+2020|0;n=b+260|0;o=b+290|0;p=b+2024|0;q=g;do{r=c[h>>2]|0;s=a[i]&1;t=(q-r|0)>>>(s>>>0);c[h>>2]=(t<<s)+r;r=t+(c[j>>2]|0)|0;c[j>>2]=r;if((r|0)>-1){r=c[l>>2]|0;if((r|0)==0){u=566992}else{u=r+((ag(c[p>>2]|0,d[o]|0)|0)<<2)|0}c[m>>2]=u;f2[c[c[n>>2]>>2]&1023](k)}oY(b);q=c[f>>2]|0;}while(q>>>0<=e>>>0);q=c[h>>2]|0;r=a[i]&1;t=(e-q|0)>>>(r>>>0);c[h>>2]=(t<<r)+q;q=t+(c[j>>2]|0)|0;c[j>>2]=q;if((q|0)<=-1){break}q=c[l>>2]|0;if((q|0)==0){v=566992}else{v=q+((ag(c[p>>2]|0,d[o]|0)|0)<<2)|0}c[m>>2]=v;f2[c[c[n>>2]>>2]&1023](k)}}while(0);c[b+2332>>2]=-1;v=(c[b+2328>>2]|0)!=-1?4:5;c[b+2384>>2]=v;e=c[b+2388>>2]|0;u=(c[b+2312+(v<<2)>>2]|0)>>>0<(c[b+2312+(e<<2)>>2]|0)>>>0?v:e;c[b+2372>>2]=u;e=c[b+2368>>2]|0;v=(c[b+2312+(e<<2)>>2]|0)>>>0<(c[b+2312+(u<<2)>>2]|0)>>>0?e:u;c[b+2364>>2]=v;u=c[b+2312+(v<<2)>>2]|0;c[b+2344>>2]=u;c[b+2292>>2]=u;v=(c[b+2296>>2]|0)>>>0<=u>>>0|0;c[b+2308>>2]=v;c[f>>2]=c[b+2292+(v<<2)>>2];v=c[b+2392>>2]|0;c[v+28>>2]=u;b=(c[v+24>>2]|0)>>>0<u>>>0?6:7;c[v+96>>2]=b;u=c[v+92>>2]|0;f=(c[v+(u<<2)>>2]|0)>>>0<(c[v+(b<<2)>>2]|0)>>>0?u:b;c[v+76>>2]=f;b=c[v+72>>2]|0;u=(c[v+(b<<2)>>2]|0)>>>0<(c[v+(f<<2)>>2]|0)>>>0?b:f;c[v+64>>2]=u;f=c[v+68>>2]|0;b=(c[v+(u<<2)>>2]|0)>>>0<(c[v+(f<<2)>>2]|0)>>>0?u:f;c[v+60>>2]=b;c[v+36>>2]=c[v+(b<<2)>>2];return}function oS(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=b+2300|0;g=c[f>>2]|0;h=b+2094|0;do{if(g>>>0<=e>>>0){if((a[h]|0)>-1){i=1;return i|0}j=b+264|0;k=b+291|0;l=b+272|0;m=b|0;n=b+2016|0;o=b+2020|0;p=b+260|0;q=b+290|0;r=b+2024|0;s=g;do{t=c[j>>2]|0;u=a[k]&1;v=(s-t|0)>>>(u>>>0);c[j>>2]=(v<<u)+t;t=v+(c[l>>2]|0)|0;c[l>>2]=t;if((t|0)>-1){t=c[n>>2]|0;if((t|0)==0){w=566992}else{w=t+((ag(c[r>>2]|0,d[q]|0)|0)<<2)|0}c[o>>2]=w;f2[c[c[p>>2]>>2]&1023](m)}oY(b);s=c[f>>2]|0;}while(s>>>0<=e>>>0);s=c[j>>2]|0;t=a[k]&1;v=(e-s|0)>>>(t>>>0);c[j>>2]=(v<<t)+s;s=v+(c[l>>2]|0)|0;c[l>>2]=s;if((s|0)<=-1){break}s=c[n>>2]|0;if((s|0)==0){x=566992}else{x=s+((ag(c[r>>2]|0,d[q]|0)|0)<<2)|0}c[o>>2]=x;f2[c[c[p>>2]>>2]&1023](m)}}while(0);if((a[h]|0)>-1){i=1;return i|0}h=b+290|0;if((d[h]|0)>143){i=1;return i|0}x=b+284|0;w=c[x>>2]|0;g=b+291|0;s=a[g]|0;v=s&1;if((456-((w-e|0)>>>(v>>>0))|0)>>>0<80){i=1;return i|0}t=e+2+v-(a[b+2111|0]&1)|0;v=b+2412|0;u=c[v>>2]|0;if(u>>>0>e>>>0){y=u;z=w}else{w=c[f>>2]|0;u=b+264|0;A=b+272|0;B=b|0;if(w>>>0>e>>>0){C=s;D=B}else{E=b+2016|0;F=b+2020|0;G=b+260|0;H=b+2024|0;I=w;w=s;while(1){s=c[u>>2]|0;J=w&1;K=(I-s|0)>>>(J>>>0);c[u>>2]=(K<<J)+s;s=K+(c[A>>2]|0)|0;c[A>>2]=s;if((s|0)>-1){s=c[E>>2]|0;if((s|0)==0){L=566992}else{L=s+((ag(c[H>>2]|0,d[h]|0)|0)<<2)|0}c[F>>2]=L;f2[c[c[G>>2]>>2]&1023](B)}oY(b);s=c[f>>2]|0;K=a[g]|0;if(s>>>0>e>>>0){C=K;D=B;break}else{I=s;w=K}}}w=c[u>>2]|0;I=C&1;C=(e-w|0)>>>(I>>>0);e=(C<<I)+w|0;c[u>>2]=e;w=C+(c[A>>2]|0)|0;c[A>>2]=w;if((w|0)>-1){C=c[b+2016>>2]|0;if((C|0)==0){M=566992}else{M=C+((ag(c[b+2024>>2]|0,d[h]|0)|0)<<2)|0}c[b+2020>>2]=M;M=b+260|0;f2[c[c[M>>2]>>2]&1023](D);N=c[u>>2]|0;O=c[A>>2]|0;P=M}else{N=e;O=w;P=b+260|0}w=ga[c[(c[P>>2]|0)+4>>2]&127](D,167,-O|0)|0;O=(w<<(a[g]&1))+N|0;c[v>>2]=O;y=O;z=c[x>>2]|0}i=t>>>0>=(y>>>0<z>>>0?y:c[b+268>>2]|0)>>>0;return i|0}function oT(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=b+2300|0;g=c[f>>2]|0;h=b+2094|0;do{if(g>>>0<=e>>>0){if((a[h]|0)>-1){i=1;return i|0}j=b+264|0;k=b+291|0;l=b+272|0;m=b|0;n=b+2016|0;o=b+2020|0;p=b+260|0;q=b+290|0;r=b+2024|0;s=g;do{t=c[j>>2]|0;u=a[k]&1;v=(s-t|0)>>>(u>>>0);c[j>>2]=(v<<u)+t;t=v+(c[l>>2]|0)|0;c[l>>2]=t;if((t|0)>-1){t=c[n>>2]|0;if((t|0)==0){w=566992}else{w=t+((ag(c[r>>2]|0,d[q]|0)|0)<<2)|0}c[o>>2]=w;f2[c[c[p>>2]>>2]&1023](m)}oY(b);s=c[f>>2]|0;}while(s>>>0<=e>>>0);s=c[j>>2]|0;t=a[k]&1;v=(e-s|0)>>>(t>>>0);c[j>>2]=(v<<t)+s;s=v+(c[l>>2]|0)|0;c[l>>2]=s;if((s|0)<=-1){break}s=c[n>>2]|0;if((s|0)==0){x=566992}else{x=s+((ag(c[r>>2]|0,d[q]|0)|0)<<2)|0}c[o>>2]=x;f2[c[c[p>>2]>>2]&1023](m)}}while(0);if((a[h]|0)>-1){i=1;return i|0}h=b+290|0;if((d[h]|0)>143){i=1;return i|0}x=b+284|0;w=c[x>>2]|0;g=b+291|0;s=a[g]|0;v=s&1;if((456-((w-e|0)>>>(v>>>0))|0)>>>0<(v|80)>>>0){i=1;return i|0}v=b+2412|0;t=c[v>>2]|0;if(t>>>0>e>>>0){y=t;z=w;A=s}else{w=c[f>>2]|0;t=b+264|0;u=b+272|0;B=b|0;if(w>>>0>e>>>0){C=s;D=B}else{E=b+2016|0;F=b+2020|0;G=b+260|0;H=b+2024|0;I=w;w=s;while(1){s=c[t>>2]|0;J=w&1;K=(I-s|0)>>>(J>>>0);c[t>>2]=(K<<J)+s;s=K+(c[u>>2]|0)|0;c[u>>2]=s;if((s|0)>-1){s=c[E>>2]|0;if((s|0)==0){L=566992}else{L=s+((ag(c[H>>2]|0,d[h]|0)|0)<<2)|0}c[F>>2]=L;f2[c[c[G>>2]>>2]&1023](B)}oY(b);s=c[f>>2]|0;K=a[g]|0;if(s>>>0>e>>>0){C=K;D=B;break}else{I=s;w=K}}}w=c[t>>2]|0;I=C&1;C=(e-w|0)>>>(I>>>0);B=(C<<I)+w|0;c[t>>2]=B;w=C+(c[u>>2]|0)|0;c[u>>2]=w;if((w|0)>-1){C=c[b+2016>>2]|0;if((C|0)==0){M=566992}else{M=C+((ag(c[b+2024>>2]|0,d[h]|0)|0)<<2)|0}c[b+2020>>2]=M;M=b+260|0;f2[c[c[M>>2]>>2]&1023](D);N=c[t>>2]|0;O=c[u>>2]|0;P=M}else{N=B;O=w;P=b+260|0}w=ga[c[(c[P>>2]|0)+4>>2]&127](D,167,-O|0)|0;O=a[g]|0;g=(w<<(O&1))+N|0;c[v>>2]=g;y=g;z=c[x>>2]|0;A=O}i=((A&1^3)+(y>>>0<z>>>0?y:c[b+268>>2]|0)|0)>>>0<=e>>>0;return i|0}function oU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b+2412|0;c[d>>2]=0;e=b+2292|0;f=b+2340|0;g=c[f>>2]|0;do{if((g|0)!=-1){h=c[b+264>>2]|0;i=b+2111|0;j=b+291|0;if(g>>>0<=((a[i]&1)+h-(a[j]&1)|0)>>>0){break}k=ga[c[(c[b+260>>2]|0)+4>>2]&127](b|0,166,-(c[b+272>>2]|0)|0)|0;l=a[j]&1;j=(k<<l)+h+(a[i]&1)-l|0;c[f>>2]=j;l=(c[b+2336>>2]|0)>>>0<j>>>0?6:7;c[b+2388>>2]=l;j=c[b+2384>>2]|0;i=(c[b+2312+(j<<2)>>2]|0)>>>0<(c[b+2312+(l<<2)>>2]|0)>>>0?j:l;c[b+2372>>2]=i;l=c[b+2368>>2]|0;j=(c[b+2312+(l<<2)>>2]|0)>>>0<(c[b+2312+(i<<2)>>2]|0)>>>0?l:i;c[b+2364>>2]=j;i=c[b+2312+(j<<2)>>2]|0;c[b+2344>>2]=i;c[e>>2]=i;j=(c[b+2296>>2]|0)>>>0<=i>>>0|0;c[b+2308>>2]=j;c[b+2300>>2]=c[b+2292+(j<<2)>>2];j=c[b+2392>>2]|0;c[j+28>>2]=i;l=(c[j+24>>2]|0)>>>0<i>>>0?6:7;c[j+96>>2]=l;i=c[j+92>>2]|0;h=(c[j+(i<<2)>>2]|0)>>>0<(c[j+(l<<2)>>2]|0)>>>0?i:l;c[j+76>>2]=h;l=c[j+72>>2]|0;i=(c[j+(l<<2)>>2]|0)>>>0<(c[j+(h<<2)>>2]|0)>>>0?l:h;c[j+64>>2]=i;h=c[j+68>>2]|0;l=(c[j+(i<<2)>>2]|0)>>>0<(c[j+(h<<2)>>2]|0)>>>0?i:h;c[j+60>>2]=l;c[j+36>>2]=c[j+(l<<2)>>2]}}while(0);f=b+2332|0;g=c[f>>2]|0;if((g|0)==-1){return}l=b+291|0;if(g>>>0<=((c[b+268>>2]|0)+1-(a[l]&1)|0)>>>0){return}g=c[b+264>>2]|0;j=ga[c[(c[b+260>>2]|0)+4>>2]&127](b|0,167,-(c[b+272>>2]|0)|0)|0;h=a[l]&1;l=(j<<h)+g|0;c[d>>2]=l;d=(h^1)+l|0;c[f>>2]=d;f=(c[b+2328>>2]|0)>>>0<d>>>0?4:5;c[b+2384>>2]=f;d=c[b+2388>>2]|0;l=(c[b+2312+(f<<2)>>2]|0)>>>0<(c[b+2312+(d<<2)>>2]|0)>>>0?f:d;c[b+2372>>2]=l;d=c[b+2368>>2]|0;f=(c[b+2312+(d<<2)>>2]|0)>>>0<(c[b+2312+(l<<2)>>2]|0)>>>0?d:l;c[b+2364>>2]=f;l=c[b+2312+(f<<2)>>2]|0;c[b+2344>>2]=l;c[e>>2]=l;e=(c[b+2296>>2]|0)>>>0<=l>>>0|0;c[b+2308>>2]=e;c[b+2300>>2]=c[b+2292+(e<<2)>>2];e=c[b+2392>>2]|0;c[e+28>>2]=l;b=(c[e+24>>2]|0)>>>0<l>>>0?6:7;c[e+96>>2]=b;l=c[e+92>>2]|0;f=(c[e+(l<<2)>>2]|0)>>>0<(c[e+(b<<2)>>2]|0)>>>0?l:b;c[e+76>>2]=f;b=c[e+72>>2]|0;l=(c[e+(b<<2)>>2]|0)>>>0<(c[e+(f<<2)>>2]|0)>>>0?b:f;c[e+64>>2]=l;f=c[e+68>>2]|0;b=(c[e+(l<<2)>>2]|0)>>>0<(c[e+(f<<2)>>2]|0)>>>0?l:f;c[e+60>>2]=b;c[e+36>>2]=c[e+(b<<2)>>2];return}function oV(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=b+2094|0;do{if((a[h]|0)<=-1){i=b+2300|0;j=c[i>>2]|0;k=b+264|0;l=b+291|0;m=b+272|0;if(j>>>0<=g>>>0){n=b|0;o=b+2016|0;p=b+2020|0;q=b+260|0;r=b+290|0;s=b+2024|0;t=j;do{j=c[k>>2]|0;u=a[l]&1;v=(t-j|0)>>>(u>>>0);c[k>>2]=(v<<u)+j;j=v+(c[m>>2]|0)|0;c[m>>2]=j;if((j|0)>-1){j=c[o>>2]|0;if((j|0)==0){w=566992}else{w=j+((ag(c[s>>2]|0,d[r]|0)|0)<<2)|0}c[p>>2]=w;f2[c[c[q>>2]>>2]&1023](n)}oY(b);t=c[i>>2]|0;}while(t>>>0<=g>>>0)}t=c[k>>2]|0;i=a[l]&1;n=(g-t|0)>>>(i>>>0);c[k>>2]=(n<<i)+t;t=n+(c[m>>2]|0)|0;c[m>>2]=t;if((t|0)<=-1){break}t=c[b+2016>>2]|0;if((t|0)==0){x=566992}else{x=t+((ag(c[b+2024>>2]|0,d[b+290|0]|0)|0)<<2)|0}c[b+2020>>2]=x;f2[c[c[b+260>>2]>>2]&1023](b|0)}}while(0);qC(b+1880|0,g);x=c[b+2e3>>2]|0;w=a[x+7|0]&1;t=459-(((c[x>>2]|0)-(c[b+2008>>2]|0)|0)>>>(w>>>0))-(-w&3)|0;w=t>>>0>455?t-456|0:t;a[b+2012|0]=w>>>0>80?80:w&255;c[b+2004>>2]=f;if((a[h]|0)>-1){return}h=(80<<(a[b+291|0]&1))+(c[b+284>>2]|0)|0;f=e[b+288>>1]|0;w=h-((h-g|0)>>>0>f>>>0?f:0)|0;c[b+2328>>2]=w;f=(c[b+2332>>2]|0)>>>0>w>>>0?4:5;c[b+2384>>2]=f;w=c[b+2388>>2]|0;g=(c[b+2312+(f<<2)>>2]|0)>>>0<(c[b+2312+(w<<2)>>2]|0)>>>0?f:w;c[b+2372>>2]=g;w=c[b+2368>>2]|0;f=(c[b+2312+(w<<2)>>2]|0)>>>0<(c[b+2312+(g<<2)>>2]|0)>>>0?w:g;c[b+2364>>2]=f;g=c[b+2312+(f<<2)>>2]|0;c[b+2344>>2]=g;c[b+2292>>2]=g;f=(c[b+2296>>2]|0)>>>0<=g>>>0|0;c[b+2308>>2]=f;c[b+2300>>2]=c[b+2292+(f<<2)>>2];f=c[b+2392>>2]|0;c[f+28>>2]=g;b=(c[f+24>>2]|0)>>>0<g>>>0?6:7;c[f+96>>2]=b;g=c[f+92>>2]|0;w=(c[f+(g<<2)>>2]|0)>>>0<(c[f+(b<<2)>>2]|0)>>>0?g:b;c[f+76>>2]=w;b=c[f+72>>2]|0;g=(c[f+(b<<2)>>2]|0)>>>0<(c[f+(w<<2)>>2]|0)>>>0?b:w;c[f+64>>2]=g;w=c[f+68>>2]|0;b=(c[f+(g<<2)>>2]|0)>>>0<(c[f+(w<<2)>>2]|0)>>>0?g:w;c[f+60>>2]=b;c[f+36>>2]=c[f+(b<<2)>>2];return}function oW(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;h=b|0;i=b+2094|0;j=a[i]|0;k=j&255;do{if(j<<24>>24<=-1){l=b+2300|0;m=c[l>>2]|0;n=b+264|0;o=b+291|0;p=b+272|0;if(m>>>0<=g>>>0){q=b|0;r=b+2016|0;s=b+2020|0;t=b+260|0;u=b+290|0;v=b+2024|0;w=m;do{m=c[n>>2]|0;x=a[o]&1;y=(w-m|0)>>>(x>>>0);c[n>>2]=(y<<x)+m;m=y+(c[p>>2]|0)|0;c[p>>2]=m;if((m|0)>-1){m=c[r>>2]|0;if((m|0)==0){z=566992}else{z=m+((ag(c[v>>2]|0,d[u]|0)|0)<<2)|0}c[s>>2]=z;f2[c[c[t>>2]>>2]&1023](q)}oY(b);w=c[l>>2]|0;}while(w>>>0<=g>>>0)}w=c[n>>2]|0;l=a[o]&1;q=(g-w|0)>>>(l>>>0);c[n>>2]=(q<<l)+w;w=q+(c[p>>2]|0)|0;c[p>>2]=w;if((w|0)<=-1){break}w=c[b+2016>>2]|0;if((w|0)==0){A=566992}else{A=w+((ag(c[b+2024>>2]|0,d[b+290|0]|0)|0)<<2)|0}c[b+2020>>2]=A;f2[c[c[b+260>>2]>>2]&1023](b|0)}}while(0);A=k^f;if((A&128|0)!=0){pL(h,f,g);if((f&128|0)==0){z=b+2312|0;j=b+2344|0;w=b+2292|0;q=b+2296|0;l=b+2308|0;t=b+2300|0;s=b+2392|0;u=0;do{c[b+2312+(u<<2)>>2]=-1;f2[c[b+2348+(u>>1<<2)>>2]&1023](z);v=c[j>>2]|0;c[w>>2]=v;r=(c[q>>2]|0)>>>0<=v>>>0|0;c[l>>2]=r;c[t>>2]=c[b+2292+(r<<2)>>2];r=c[s>>2]|0;c[r+28>>2]=v;m=(c[r+24>>2]|0)>>>0<v>>>0?6:7;c[r+96>>2]=m;v=c[r+92>>2]|0;y=(c[r+(v<<2)>>2]|0)>>>0<(c[r+(m<<2)>>2]|0)>>>0?v:m;c[r+76>>2]=y;m=c[r+72>>2]|0;v=(c[r+(m<<2)>>2]|0)>>>0<(c[r+(y<<2)>>2]|0)>>>0?m:y;c[r+64>>2]=v;y=c[r+68>>2]|0;m=(c[r+(v<<2)>>2]|0)>>>0<(c[r+(y<<2)>>2]|0)>>>0?v:y;c[r+60>>2]=m;c[r+36>>2]=c[r+(m<<2)>>2];u=u+1|0;}while((u|0)<8);return}u=b+2400|0;a[b+2407|0]=a[b+2405|0]|0;s=a[b+2404|0]|0;a[b+2406|0]=s;t=b+2420|0;l=a[t]|0;a[b+2396|0]=l;a[b+2397|0]=s;do{if(s<<24>>24==0){if((l&64)==0){break}q=c[b+2392>>2]|0;w=q+108|0;j=c[w>>2]|2;c[w>>2]=j;if((a[q+116|0]|0)==0){break}if((c[q+112>>2]&j|0)==0){break}j=c[q+104>>2]|0;c[q+32>>2]=j;c[q+100>>2]=8;c[q+80>>2]=8;c[q+68>>2]=8;w=c[q+64>>2]|0;z=(c[q+(w<<2)>>2]|0)>>>0<j>>>0?w:8;c[q+60>>2]=z;c[q+36>>2]=c[q+(z<<2)>>2]}}while(0);l=b|0;s=b+264|0;z=c[s>>2]|0;q=b+260|0;w=b+272|0;j=ga[c[(c[q>>2]|0)+4>>2]&127](l,167,-(c[w>>2]|0)|0)|0;m=b+291|0;r=b+2412|0;c[r>>2]=(j<<(a[m]&1))+z;z=b+284|0;pA(u,z,g);j=z|0;z=c[j>>2]|0;y=b+2296|0;c[y>>2]=z;v=b+2292|0;x=(c[v>>2]|0)>>>0>=z>>>0|0;B=b+2308|0;c[B>>2]=x;C=b+2300|0;c[C>>2]=c[b+2292+(x<<2)>>2];x=(80<<(a[m]&1))+z|0;D=b+288|0;E=e[D>>1]|0;F=x-((x-g|0)>>>0>E>>>0?E:0)|0;E=b+2328|0;c[E>>2]=F;x=b+2332|0;G=(c[x>>2]|0)>>>0>F>>>0?4:5;F=b+2384|0;c[F>>2]=G;H=b+2388|0;I=c[H>>2]|0;J=(c[b+2312+(G<<2)>>2]|0)>>>0<(c[b+2312+(I<<2)>>2]|0)>>>0?G:I;I=b+2372|0;c[I>>2]=J;G=b+2368|0;K=c[G>>2]|0;L=(c[b+2312+(K<<2)>>2]|0)>>>0<(c[b+2312+(J<<2)>>2]|0)>>>0?K:J;J=b+2364|0;c[J>>2]=L;K=c[b+2312+(L<<2)>>2]|0;L=b+2344|0;c[L>>2]=K;c[v>>2]=K;M=z>>>0<=K>>>0|0;c[B>>2]=M;c[C>>2]=c[b+2292+(M<<2)>>2];M=b+2392|0;z=c[M>>2]|0;c[z+28>>2]=K;N=(c[z+24>>2]|0)>>>0<K>>>0?6:7;c[z+96>>2]=N;K=c[z+92>>2]|0;O=(c[z+(K<<2)>>2]|0)>>>0<(c[z+(N<<2)>>2]|0)>>>0?K:N;c[z+76>>2]=O;N=c[z+72>>2]|0;K=(c[z+(N<<2)>>2]|0)>>>0<(c[z+(O<<2)>>2]|0)>>>0?N:O;c[z+64>>2]=K;O=c[z+68>>2]|0;N=(c[z+(K<<2)>>2]|0)>>>0<(c[z+(O<<2)>>2]|0)>>>0?K:O;c[z+60>>2]=N;c[z+36>>2]=c[z+(N<<2)>>2];N=c[u>>2]|0;u=b+2324|0;c[u>>2]=N;z=b+2320|0;O=(c[z>>2]|0)>>>0<N>>>0?2:3;N=b+2380|0;c[N>>2]=O;K=b+2376|0;P=c[K>>2]|0;Q=(c[b+2312+(P<<2)>>2]|0)>>>0<(c[b+2312+(O<<2)>>2]|0)>>>0?P:O;c[G>>2]=Q;O=c[I>>2]|0;P=(c[b+2312+(Q<<2)>>2]|0)>>>0<(c[b+2312+(O<<2)>>2]|0)>>>0?Q:O;c[J>>2]=P;O=c[b+2312+(P<<2)>>2]|0;c[L>>2]=O;c[v>>2]=O;P=(c[y>>2]|0)>>>0<=O>>>0|0;c[B>>2]=P;c[C>>2]=c[b+2292+(P<<2)>>2];P=c[M>>2]|0;c[P+28>>2]=O;Q=(c[P+24>>2]|0)>>>0<O>>>0?6:7;c[P+96>>2]=Q;O=c[P+92>>2]|0;R=(c[P+(O<<2)>>2]|0)>>>0<(c[P+(Q<<2)>>2]|0)>>>0?O:Q;c[P+76>>2]=R;Q=c[P+72>>2]|0;O=(c[P+(Q<<2)>>2]|0)>>>0<(c[P+(R<<2)>>2]|0)>>>0?Q:R;c[P+64>>2]=O;R=c[P+68>>2]|0;Q=(c[P+(O<<2)>>2]|0)>>>0<(c[P+(R<<2)>>2]|0)>>>0?O:R;c[P+60>>2]=Q;c[P+36>>2]=c[P+(Q<<2)>>2];Q=b+290|0;P=a[m]&1;R=(((153-(d[Q]|0)|0)*456|0)+65664<<P)+(c[j>>2]|0)|0;O=70224<<P;P=R-((R-g|0)>>>0>O>>>0?O:0)|0;c[z>>2]=P;z=(c[u>>2]|0)>>>0>P>>>0?2:3;c[N>>2]=z;N=c[K>>2]|0;K=(c[b+2312+(N<<2)>>2]|0)>>>0<(c[b+2312+(z<<2)>>2]|0)>>>0?N:z;c[G>>2]=K;z=c[I>>2]|0;N=(c[b+2312+(K<<2)>>2]|0)>>>0<(c[b+2312+(z<<2)>>2]|0)>>>0?K:z;c[J>>2]=N;z=c[b+2312+(N<<2)>>2]|0;c[L>>2]=z;c[v>>2]=z;N=(c[y>>2]|0)>>>0<=z>>>0|0;c[B>>2]=N;c[C>>2]=c[b+2292+(N<<2)>>2];N=c[M>>2]|0;c[N+28>>2]=z;K=(c[N+24>>2]|0)>>>0<z>>>0?6:7;c[N+96>>2]=K;z=c[N+92>>2]|0;P=(c[N+(z<<2)>>2]|0)>>>0<(c[N+(K<<2)>>2]|0)>>>0?z:K;c[N+76>>2]=P;K=c[N+72>>2]|0;z=(c[N+(K<<2)>>2]|0)>>>0<(c[N+(P<<2)>>2]|0)>>>0?K:P;c[N+64>>2]=z;P=c[N+68>>2]|0;K=(c[N+(z<<2)>>2]|0)>>>0<(c[N+(P<<2)>>2]|0)>>>0?z:P;c[N+60>>2]=K;c[N+36>>2]=c[N+(K<<2)>>2];K=d[t]|0;if((K&32|0)==0){S=-1}else{N=(c[j>>2]|0)-g|0;j=a[Q]|0;do{if((j&255)>142){T=2743}else{Q=N>>>0<5;if(j<<24>>24==-114&Q){T=2743;break}if((K&8|0)!=0){T=2743;break}if(Q){U=(e[D>>1]|0)+N|0}else{U=N}V=U-4|0}}while(0);if((T|0)==2743){V=(ag(e[D>>1]|0,153-(j&255)|0)|0)+N|0}S=V+g|0}V=b+2336|0;c[V>>2]=S;N=b+2340|0;j=(c[N>>2]|0)>>>0>S>>>0?6:7;c[H>>2]=j;S=c[F>>2]|0;D=(c[b+2312+(S<<2)>>2]|0)>>>0<(c[b+2312+(j<<2)>>2]|0)>>>0?S:j;c[I>>2]=D;j=c[G>>2]|0;S=(c[b+2312+(j<<2)>>2]|0)>>>0<(c[b+2312+(D<<2)>>2]|0)>>>0?j:D;c[J>>2]=S;D=c[b+2312+(S<<2)>>2]|0;c[L>>2]=D;c[v>>2]=D;S=(c[y>>2]|0)>>>0<=D>>>0|0;c[B>>2]=S;c[C>>2]=c[b+2292+(S<<2)>>2];S=c[M>>2]|0;c[S+28>>2]=D;j=(c[S+24>>2]|0)>>>0<D>>>0?6:7;c[S+96>>2]=j;D=c[S+92>>2]|0;T=(c[S+(D<<2)>>2]|0)>>>0<(c[S+(j<<2)>>2]|0)>>>0?D:j;c[S+76>>2]=T;j=c[S+72>>2]|0;D=(c[S+(j<<2)>>2]|0)>>>0<(c[S+(T<<2)>>2]|0)>>>0?j:T;c[S+64>>2]=D;T=c[S+68>>2]|0;j=(c[S+(D<<2)>>2]|0)>>>0<(c[S+(T<<2)>>2]|0)>>>0?D:T;c[S+60>>2]=j;c[S+36>>2]=c[S+(j<<2)>>2];if((a[t]&8)!=0){t=c[s>>2]|0;s=ga[c[(c[q>>2]|0)+4>>2]&127](l,166,-(c[w>>2]|0)|0)|0;w=a[m]&1;l=(s<<w)+t+(a[b+2111|0]&1)-w|0;c[N>>2]=l;N=(c[V>>2]|0)>>>0<l>>>0?6:7;c[H>>2]=N;l=c[F>>2]|0;V=(c[b+2312+(l<<2)>>2]|0)>>>0<(c[b+2312+(N<<2)>>2]|0)>>>0?l:N;c[I>>2]=V;N=c[G>>2]|0;l=(c[b+2312+(N<<2)>>2]|0)>>>0<(c[b+2312+(V<<2)>>2]|0)>>>0?N:V;c[J>>2]=l;V=c[b+2312+(l<<2)>>2]|0;c[L>>2]=V;c[v>>2]=V;l=(c[y>>2]|0)>>>0<=V>>>0|0;c[B>>2]=l;c[C>>2]=c[b+2292+(l<<2)>>2];l=c[M>>2]|0;c[l+28>>2]=V;N=(c[l+24>>2]|0)>>>0<V>>>0?6:7;c[l+96>>2]=N;V=c[l+92>>2]|0;w=(c[l+(V<<2)>>2]|0)>>>0<(c[l+(N<<2)>>2]|0)>>>0?V:N;c[l+76>>2]=w;N=c[l+72>>2]|0;V=(c[l+(N<<2)>>2]|0)>>>0<(c[l+(w<<2)>>2]|0)>>>0?N:w;c[l+64>>2]=V;w=c[l+68>>2]|0;N=(c[l+(V<<2)>>2]|0)>>>0<(c[l+(w<<2)>>2]|0)>>>0?V:w;c[l+60>>2]=N;c[l+36>>2]=c[l+(N<<2)>>2]}if((c[x>>2]|0)==-1){return}N=a[m]&1;m=(c[b+268>>2]|0)+1-N|0;if(m>>>0>g>>>0){W=m}else{W=(c[r>>2]|0)+(N^1)|0}c[x>>2]=W;x=(c[E>>2]|0)>>>0<W>>>0?4:5;c[F>>2]=x;F=c[H>>2]|0;H=(c[b+2312+(x<<2)>>2]|0)>>>0<(c[b+2312+(F<<2)>>2]|0)>>>0?x:F;c[I>>2]=H;I=c[G>>2]|0;G=(c[b+2312+(I<<2)>>2]|0)>>>0<(c[b+2312+(H<<2)>>2]|0)>>>0?I:H;c[J>>2]=G;J=c[b+2312+(G<<2)>>2]|0;c[L>>2]=J;c[v>>2]=J;v=(c[y>>2]|0)>>>0<=J>>>0|0;c[B>>2]=v;c[C>>2]=c[b+2292+(v<<2)>>2];v=c[M>>2]|0;c[v+28>>2]=J;M=(c[v+24>>2]|0)>>>0<J>>>0?6:7;c[v+96>>2]=M;J=c[v+92>>2]|0;C=(c[v+(J<<2)>>2]|0)>>>0<(c[v+(M<<2)>>2]|0)>>>0?J:M;c[v+76>>2]=C;M=c[v+72>>2]|0;J=(c[v+(M<<2)>>2]|0)>>>0<(c[v+(C<<2)>>2]|0)>>>0?M:C;c[v+64>>2]=J;C=c[v+68>>2]|0;M=(c[v+(J<<2)>>2]|0)>>>0<(c[v+(C<<2)>>2]|0)>>>0?J:C;c[v+60>>2]=M;c[v+36>>2]=c[v+(M<<2)>>2];return}if((f&128|0)==0){pL(h,f,g);return}if((a[b+2111|0]&1)==0){pL(h,f,g);if((A&4|0)!=0){M=(80<<(a[b+291|0]&1))+(c[b+284>>2]|0)|0;v=e[b+288>>1]|0;C=M-((M-g|0)>>>0>v>>>0?v:0)|0;c[b+2328>>2]=C;v=(c[b+2332>>2]|0)>>>0>C>>>0?4:5;c[b+2384>>2]=v;C=c[b+2388>>2]|0;M=(c[b+2312+(v<<2)>>2]|0)>>>0<(c[b+2312+(C<<2)>>2]|0)>>>0?v:C;c[b+2372>>2]=M;C=c[b+2368>>2]|0;v=(c[b+2312+(C<<2)>>2]|0)>>>0<(c[b+2312+(M<<2)>>2]|0)>>>0?C:M;c[b+2364>>2]=v;M=c[b+2312+(v<<2)>>2]|0;c[b+2344>>2]=M;c[b+2292>>2]=M;v=(c[b+2296>>2]|0)>>>0<=M>>>0|0;c[b+2308>>2]=v;c[b+2300>>2]=c[b+2292+(v<<2)>>2];v=c[b+2392>>2]|0;c[v+28>>2]=M;C=(c[v+24>>2]|0)>>>0<M>>>0?6:7;c[v+96>>2]=C;M=c[v+92>>2]|0;J=(c[v+(M<<2)>>2]|0)>>>0<(c[v+(C<<2)>>2]|0)>>>0?M:C;c[v+76>>2]=J;C=c[v+72>>2]|0;M=(c[v+(C<<2)>>2]|0)>>>0<(c[v+(J<<2)>>2]|0)>>>0?C:J;c[v+64>>2]=M;J=c[v+68>>2]|0;C=(c[v+(M<<2)>>2]|0)>>>0<(c[v+(J<<2)>>2]|0)>>>0?M:J;c[v+60>>2]=C;c[v+36>>2]=c[v+(C<<2)>>2]}if((A&34|0)==0){return}oU(b);return}pL(h,k&235|f&20,g);if((A&4|0)==0){X=b+291|0}else{k=b+291|0;C=(80<<(a[k]&1))+(c[b+284>>2]|0)|0;v=e[b+288>>1]|0;J=C-((C-g|0)>>>0>v>>>0?v:0)|0;c[b+2328>>2]=J;v=(c[b+2332>>2]|0)>>>0>J>>>0?4:5;c[b+2384>>2]=v;J=c[b+2388>>2]|0;C=(c[b+2312+(v<<2)>>2]|0)>>>0<(c[b+2312+(J<<2)>>2]|0)>>>0?v:J;c[b+2372>>2]=C;J=c[b+2368>>2]|0;v=(c[b+2312+(J<<2)>>2]|0)>>>0<(c[b+2312+(C<<2)>>2]|0)>>>0?J:C;c[b+2364>>2]=v;C=c[b+2312+(v<<2)>>2]|0;c[b+2344>>2]=C;c[b+2292>>2]=C;v=(c[b+2296>>2]|0)>>>0<=C>>>0|0;c[b+2308>>2]=v;c[b+2300>>2]=c[b+2292+(v<<2)>>2];v=c[b+2392>>2]|0;c[v+28>>2]=C;J=(c[v+24>>2]|0)>>>0<C>>>0?6:7;c[v+96>>2]=J;C=c[v+92>>2]|0;M=(c[v+(C<<2)>>2]|0)>>>0<(c[v+(J<<2)>>2]|0)>>>0?C:J;c[v+76>>2]=M;J=c[v+72>>2]|0;C=(c[v+(J<<2)>>2]|0)>>>0<(c[v+(M<<2)>>2]|0)>>>0?J:M;c[v+64>>2]=C;M=c[v+68>>2]|0;J=(c[v+(C<<2)>>2]|0)>>>0<(c[v+(M<<2)>>2]|0)>>>0?C:M;c[v+60>>2]=J;c[v+36>>2]=c[v+(J<<2)>>2];X=k}k=a[X]|0;J=g+1|0;g=(k&1)+J|0;do{if((a[i]|0)>-1){Y=k}else{v=b+2300|0;M=c[v>>2]|0;C=b+264|0;B=b+272|0;if(M>>>0>g>>>0){Z=k}else{y=b|0;L=b+2016|0;G=b+2020|0;H=b+260|0;I=b+290|0;F=b+2024|0;x=M;M=k;while(1){W=c[C>>2]|0;E=M&1;N=(x-W|0)>>>(E>>>0);c[C>>2]=(N<<E)+W;W=N+(c[B>>2]|0)|0;c[B>>2]=W;if((W|0)>-1){W=c[L>>2]|0;if((W|0)==0){_=566992}else{_=W+((ag(c[F>>2]|0,d[I]|0)|0)<<2)|0}c[G>>2]=_;f2[c[c[H>>2]>>2]&1023](y)}oY(b);W=c[v>>2]|0;N=a[X]|0;if(W>>>0>g>>>0){Z=N;break}else{x=W;M=N}}}M=c[C>>2]|0;x=Z&1;v=(g-M|0)>>>(x>>>0);c[C>>2]=(v<<x)+M;M=v+(c[B>>2]|0)|0;c[B>>2]=M;if((M|0)<=-1){Y=Z;break}M=c[b+2016>>2]|0;if((M|0)==0){$=566992}else{$=M+((ag(c[b+2024>>2]|0,d[b+290|0]|0)|0)<<2)|0}c[b+2020>>2]=$;f2[c[c[b+260>>2]>>2]&1023](b|0);Y=a[X]|0}}while(0);pL(h,f,(Y&1)+J|0);if((A&32|0)==0){return}oU(b);return}function oX(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;g=b+2094|0;if((a[g]|0)>-1){h=0;return h|0}i=b+2300|0;j=c[i>>2]|0;do{if(j>>>0>f>>>0){k=b+290|0}else{l=b+264|0;m=b+291|0;n=b+272|0;o=b|0;p=b+2016|0;q=b+2020|0;r=b+260|0;s=b+290|0;t=b+2024|0;u=j;do{v=c[l>>2]|0;w=a[m]&1;x=(u-v|0)>>>(w>>>0);c[l>>2]=(x<<w)+v;v=x+(c[n>>2]|0)|0;c[n>>2]=v;if((v|0)>-1){v=c[p>>2]|0;if((v|0)==0){y=566992}else{y=v+((ag(c[t>>2]|0,d[s]|0)|0)<<2)|0}c[q>>2]=y;f2[c[c[r>>2]>>2]&1023](o)}oY(b);u=c[i>>2]|0;}while(u>>>0<=f>>>0);u=c[l>>2]|0;v=a[m]&1;x=(f-u|0)>>>(v>>>0);c[l>>2]=(x<<v)+u;u=x+(c[n>>2]|0)|0;c[n>>2]=u;if((u|0)<=-1){k=s;break}u=c[p>>2]|0;if((u|0)==0){z=566992}else{z=u+((ag(c[t>>2]|0,d[s]|0)|0)<<2)|0}c[q>>2]=z;f2[c[c[r>>2]>>2]&1023](o);k=s}}while(0);z=b+284|0;y=c[z>>2]|0;j=y-f|0;u=a[k]|0;do{if((u&255)>143){if((u&255)>=153){if(j>>>0<=(4-((a[b+291|0]&1)<<2)|0)>>>0){A=0;B=u;break}}A=1;B=u}else{x=b+291|0;v=a[x]|0;w=v&1;if((456-(j>>>(w>>>0))|0)>>>0<80){A=(c[b+2008>>2]|0)>>>0>f>>>0?0:2;B=u;break}C=f+2+w-(a[b+2111|0]&1)|0;w=b+2412|0;D=c[w>>2]|0;if(D>>>0>f>>>0){E=D;F=y;G=u}else{do{if((a[g]|0)>-1){H=b+264|0;I=b+272|0}else{D=c[i>>2]|0;J=b+264|0;K=b+272|0;if(D>>>0>f>>>0){L=v}else{M=b|0;N=b+2016|0;O=b+2020|0;P=b+260|0;Q=b+2024|0;R=D;D=v;while(1){S=c[J>>2]|0;T=D&1;U=(R-S|0)>>>(T>>>0);c[J>>2]=(U<<T)+S;S=U+(c[K>>2]|0)|0;c[K>>2]=S;if((S|0)>-1){S=c[N>>2]|0;if((S|0)==0){V=566992}else{V=S+((ag(c[Q>>2]|0,d[k]|0)|0)<<2)|0}c[O>>2]=V;f2[c[c[P>>2]>>2]&1023](M)}oY(b);S=c[i>>2]|0;U=a[x]|0;if(S>>>0>f>>>0){L=U;break}else{R=S;D=U}}}D=c[J>>2]|0;R=L&1;M=(f-D|0)>>>(R>>>0);c[J>>2]=(M<<R)+D;D=M+(c[K>>2]|0)|0;c[K>>2]=D;if((D|0)<=-1){H=J;I=K;break}D=c[b+2016>>2]|0;if((D|0)==0){W=566992}else{W=D+((ag(c[b+2024>>2]|0,d[k]|0)|0)<<2)|0}c[b+2020>>2]=W;f2[c[c[b+260>>2]>>2]&1023](b|0);H=J;I=K}}while(0);v=c[H>>2]|0;s=ga[c[(c[b+260>>2]|0)+4>>2]&127](b|0,167,-(c[I>>2]|0)|0)|0;o=(s<<(a[x]&1))+v|0;c[w>>2]=o;E=o;F=c[z>>2]|0;G=a[k]|0}A=C>>>0<(E>>>0<F>>>0?E:c[b+268>>2]|0)>>>0?3:0;B=G}}while(0);if((B&255|0)==(e|0)){if(j>>>0<=(4-((a[b+291|0]&1)<<2)|0)>>>0){X=2825}}else{X=2825}do{if((X|0)==2825){if(!((e|0)==0&B<<24>>24==-103)){h=A;return h|0}if(j>>>((a[b+291|0]&1)>>>0)>>>0<449){break}else{h=A}return h|0}}while(0);h=A|4;return h|0}
function tX(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+72|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+32|0;n=e+40|0;o=e+56|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==64){v=8}else if((u|0)==0){v=0}else if((u|0)==8){v=16}else{v=10}u=l|0;tP(n,c[h+28>>2]|0,u,m);yB(p|0,0,12);h=o;ss(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=a[m]|0;m=o+8|0;C=w;w=c[z>>2]|0;L3962:while(1){do{if((w|0)==0){D=0}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){D=w;break}if((f5[c[(c[w>>2]|0)+36>>2]&255](w)|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;F=c[f>>2]|0;do{if((F|0)==0){G=3674}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L3962}}if((f5[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[f>>2]=0;G=3674;break}else{if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L3962}}}}while(0);if((G|0)==3674){G=0;if(E){J=C;K=0;L=1;M=0;N=1;break}else{H=0;I=1}}F=(c[q>>2]|0)-C|0;O=a[p]|0;P=O&255;if((F|0)==(((P&1|0)==0?P>>>1:c[A>>2]|0)|0)){P=F<<1;do{if(F>>>0<P>>>0){ss(o,F)}else{if((O&1)==0){a[h+1+P|0]=0;a[p]=F<<2&255;break}else{a[(c[m>>2]|0)+P|0]=0;c[A>>2]=P;break}}}while(0);P=a[p]|0;if((P&1)==0){Q=10;R=P}else{P=c[g>>2]|0;Q=(P&-2)-1|0;R=P&255}P=R&255;O=(P&1|0)==0?P>>>1:c[A>>2]|0;do{if(O>>>0<Q>>>0){ss(o,Q-O|0)}else{if((R&1)==0){a[h+1+Q|0]=0;a[p]=Q<<1&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[A>>2]=Q;break}}}while(0);if((a[p]&1)==0){S=x}else{S=c[y>>2]|0}c[q>>2]=S+F;T=S}else{T=C}O=D+12|0;P=c[O>>2]|0;U=D+16|0;if((P|0)==(c[U>>2]|0)){V=(f5[c[(c[D>>2]|0)+36>>2]&255](D)|0)&255}else{V=a[P]|0}if((tM(V,v,T,q,t,B,n,l,s,u)|0)!=0){J=T;K=H;L=I;M=D;N=E;break}P=c[O>>2]|0;if((P|0)==(c[U>>2]|0)){U=c[(c[D>>2]|0)+40>>2]|0;f5[U&255](D)|0;C=T;w=D;continue}else{c[O>>2]=P+1;C=T;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){W=w>>>1}else{W=c[n+4>>2]|0}do{if((W|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}T=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=T}}while(0);c[k>>2]=tY(J,c[q>>2]|0,j,v)|0;tQ(n,l,c[s>>2]|0,j);do{if(N){X=0}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){X=M;break}if((f5[c[(c[M>>2]|0)+36>>2]&255](M)|0)!=-1){X=M;break}c[z>>2]=0;X=0}}while(0);z=(X|0)==0;L4030:do{if(L){G=3726}else{do{if((c[K+12>>2]|0)==(c[K+16>>2]|0)){if((f5[c[(c[K>>2]|0)+36>>2]&255](K)|0)!=-1){break}c[f>>2]=0;G=3726;break L4030}}while(0);if(!(z^(K|0)==0)){G=3728}}}while(0);if((G|0)==3726){if(z){G=3728}}if((G|0)==3728){c[j>>2]=c[j>>2]|2}c[b>>2]=X;do{if((a[p]&1)!=0){X=c[m>>2]|0;if((X|0)==0){break}yt(X)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}yt(D);i=e;return}function tY(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}if((a[b]|0)==45){c[e>>2]=4;j=0;i=g;return j|0}k=c[(er()|0)>>2]|0;c[(er()|0)>>2]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=a5(b|0,h|0,f|0,c[141570]|0)|0;f=K;b=c[(er()|0)>>2]|0;if((b|0)==0){c[(er()|0)>>2]=k}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=0;if((b|0)==34|(f>>>0>d>>>0|f>>>0==d>>>0&l>>>0>-1>>>0)){c[e>>2]=4;j=-1;i=g;return j|0}else{j=l;i=g;return j|0}return 0}function tZ(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+72|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+32|0;n=e+40|0;o=e+56|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==64){v=8}else if((u|0)==0){v=0}else if((u|0)==8){v=16}else{v=10}u=l|0;tP(n,c[h+28>>2]|0,u,m);yB(p|0,0,12);h=o;ss(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=a[m]|0;m=o+8|0;C=w;w=c[z>>2]|0;L4090:while(1){do{if((w|0)==0){D=0}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){D=w;break}if((f5[c[(c[w>>2]|0)+36>>2]&255](w)|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;F=c[f>>2]|0;do{if((F|0)==0){G=3781}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){if(E){H=F;I=0;break}else{J=C;L=F;M=0;N=D;O=0;break L4090}}if((f5[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[f>>2]=0;G=3781;break}else{if(E){H=F;I=0;break}else{J=C;L=F;M=0;N=D;O=0;break L4090}}}}while(0);if((G|0)==3781){G=0;if(E){J=C;L=0;M=1;N=0;O=1;break}else{H=0;I=1}}F=(c[q>>2]|0)-C|0;P=a[p]|0;Q=P&255;if((F|0)==(((Q&1|0)==0?Q>>>1:c[A>>2]|0)|0)){Q=F<<1;do{if(F>>>0<Q>>>0){ss(o,F)}else{if((P&1)==0){a[h+1+Q|0]=0;a[p]=F<<2&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[A>>2]=Q;break}}}while(0);Q=a[p]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[g>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[A>>2]|0;do{if(P>>>0<R>>>0){ss(o,R-P|0)}else{if((S&1)==0){a[h+1+R|0]=0;a[p]=R<<1&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[A>>2]=R;break}}}while(0);if((a[p]&1)==0){T=x}else{T=c[y>>2]|0}c[q>>2]=T+F;U=T}else{U=C}P=D+12|0;Q=c[P>>2]|0;V=D+16|0;if((Q|0)==(c[V>>2]|0)){W=(f5[c[(c[D>>2]|0)+36>>2]&255](D)|0)&255}else{W=a[Q]|0}if((tM(W,v,U,q,t,B,n,l,s,u)|0)!=0){J=U;L=H;M=I;N=D;O=E;break}Q=c[P>>2]|0;if((Q|0)==(c[V>>2]|0)){V=c[(c[D>>2]|0)+40>>2]|0;f5[V&255](D)|0;C=U;w=D;continue}else{c[P>>2]=Q+1;C=U;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){X=w>>>1}else{X=c[n+4>>2]|0}do{if((X|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}U=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=U}}while(0);t=t_(J,c[q>>2]|0,j,v)|0;c[k>>2]=t;c[k+4>>2]=K;tQ(n,l,c[s>>2]|0,j);do{if(O){Y=0}else{if((c[N+12>>2]|0)!=(c[N+16>>2]|0)){Y=N;break}if((f5[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){Y=N;break}c[z>>2]=0;Y=0}}while(0);z=(Y|0)==0;L4158:do{if(M){G=3833}else{do{if((c[L+12>>2]|0)==(c[L+16>>2]|0)){if((f5[c[(c[L>>2]|0)+36>>2]&255](L)|0)!=-1){break}c[f>>2]=0;G=3833;break L4158}}while(0);if(!(z^(L|0)==0)){G=3835}}}while(0);if((G|0)==3833){if(z){G=3835}}if((G|0)==3835){c[j>>2]=c[j>>2]|2}c[b>>2]=Y;do{if((a[p]&1)!=0){Y=c[m>>2]|0;if((Y|0)==0){break}yt(Y)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}yt(D);i=e;return}function t_(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+8|0;h=g|0;do{if((b|0)==(d|0)){c[e>>2]=4;j=0;k=0}else{if((a[b]|0)==45){c[e>>2]=4;j=0;k=0;break}l=c[(er()|0)>>2]|0;c[(er()|0)>>2]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);m=a5(b|0,h|0,f|0,c[141570]|0)|0;n=K;o=c[(er()|0)>>2]|0;if((o|0)==0){c[(er()|0)>>2]=l}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;k=0;break}if((o|0)!=34){j=n;k=m;break}c[e>>2]=4;j=-1;k=-1}}while(0);i=g;return(K=j,k)|0}function t$(b,e,f,g,h,i,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0;if(b<<24>>24==i<<24>>24){if((a[e]&1)==0){p=-1;return p|0}a[e]=0;i=c[h>>2]|0;c[h>>2]=i+1;a[i]=46;i=d[k]|0;if((i&1|0)==0){q=i>>>1}else{q=c[k+4>>2]|0}if((q|0)==0){p=0;return p|0}q=c[m>>2]|0;if((q-l|0)>=160){p=0;return p|0}i=c[n>>2]|0;c[m>>2]=q+4;c[q>>2]=i;p=0;return p|0}do{if(b<<24>>24==j<<24>>24){i=d[k]|0;if((i&1|0)==0){r=i>>>1}else{r=c[k+4>>2]|0}if((r|0)==0){break}if((a[e]&1)==0){p=-1;return p|0}i=c[m>>2]|0;if((i-l|0)>=160){p=0;return p|0}q=c[n>>2]|0;c[m>>2]=i+4;c[i>>2]=q;c[n>>2]=0;p=0;return p|0}}while(0);r=o+32|0;j=o;while(1){if((j|0)==(r|0)){s=r;break}if((a[j]|0)==b<<24>>24){s=j;break}else{j=j+1|0}}j=s-o|0;if((j|0)>31){p=-1;return p|0}o=a[80728+j|0]|0;if((j|0)==25|(j|0)==24){s=c[h>>2]|0;do{if((s|0)!=(g|0)){if((a[s-1|0]&95|0)==(a[f]&127|0)){break}else{p=-1}return p|0}}while(0);c[h>>2]=s+1;a[s]=o;p=0;return p|0}else if((j|0)==22|(j|0)==23){a[f]=80;s=c[h>>2]|0;c[h>>2]=s+1;a[s]=o;p=0;return p|0}else{s=a[f]|0;do{if((o&95|0)==(s<<24>>24|0)){a[f]=s|-128;if((a[e]&1)==0){break}a[e]=0;g=d[k]|0;if((g&1|0)==0){t=g>>>1}else{t=c[k+4>>2]|0}if((t|0)==0){break}g=c[m>>2]|0;if((g-l|0)>=160){break}b=c[n>>2]|0;c[m>>2]=g+4;c[g>>2]=b}}while(0);m=c[h>>2]|0;c[h>>2]=m+1;a[m]=o;if((j|0)>21){p=0;return p|0}c[n>>2]=(c[n>>2]|0)+1;p=0;return p|0}return 0}function t0(b,e,f,h,j,k,l){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+80|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7>>3<<3;c[h>>2]=c[m>>2];m=e+32|0;n=e+40|0;o=e+48|0;p=e+64|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;t2(o,c[j+28>>2]|0,x,m,n);yB(q|0,0,12);j=p;ss(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=h|0;h=p|0;D=p+4|0;E=a[m]|0;m=a[n]|0;n=p+8|0;F=z;z=c[C>>2]|0;L4271:while(1){do{if((z|0)==0){G=0}else{if((c[z+12>>2]|0)!=(c[z+16>>2]|0)){G=z;break}if((f5[c[(c[z>>2]|0)+36>>2]&255](z)|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;I=c[f>>2]|0;do{if((I|0)==0){J=3927}else{if((c[I+12>>2]|0)!=(c[I+16>>2]|0)){if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L4271}}if((f5[c[(c[I>>2]|0)+36>>2]&255](I)|0)==-1){c[f>>2]=0;J=3927;break}else{if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L4271}}}}while(0);if((J|0)==3927){J=0;if(H){M=F;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}I=(c[r>>2]|0)-F|0;R=a[q]|0;S=R&255;if((I|0)==(((S&1|0)==0?S>>>1:c[D>>2]|0)|0)){S=I<<1;do{if(I>>>0<S>>>0){ss(p,I)}else{if((R&1)==0){a[j+1+S|0]=0;a[q]=I<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[D>>2]=S;break}}}while(0);S=a[q]|0;if((S&1)==0){T=10;U=S}else{S=c[h>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[D>>2]|0;do{if(R>>>0<T>>>0){ss(p,T-R|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[q]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[D>>2]=T;break}}}while(0);if((a[q]&1)==0){V=A}else{V=c[B>>2]|0}c[r>>2]=V+I;W=V}else{W=F}R=G+12|0;S=c[R>>2]|0;X=G+16|0;if((S|0)==(c[X>>2]|0)){Y=(f5[c[(c[G>>2]|0)+36>>2]&255](G)|0)&255}else{Y=a[S]|0}if((t$(Y,v,w,W,r,E,m,o,y,t,u,x)|0)!=0){M=W;N=K;O=L;P=G;Q=H;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[G>>2]|0)+40>>2]|0;f5[X&255](G)|0;F=W;z=G;continue}else{c[R>>2]=S+1;F=W;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){Z=z>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}W=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=W}}while(0);g[l>>2]=+t1(M,c[r>>2]|0,k);tQ(o,y,c[t>>2]|0,k);do{if(Q){_=0}else{if((c[P+12>>2]|0)!=(c[P+16>>2]|0)){_=P;break}if((f5[c[(c[P>>2]|0)+36>>2]&255](P)|0)!=-1){_=P;break}c[C>>2]=0;_=0}}while(0);C=(_|0)==0;L4340:do{if(O){J=3980}else{do{if((c[N+12>>2]|0)==(c[N+16>>2]|0)){if((f5[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){break}c[f>>2]=0;J=3980;break L4340}}while(0);if(!(C^(N|0)==0)){J=3982}}}while(0);if((J|0)==3980){if(C){J=3982}}if((J|0)==3982){c[k>>2]=c[k>>2]|2}c[b>>2]=_;do{if((a[q]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}yt(_)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}yt(G);i=e;return}function t1(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0.0;f=i;i=i+8|0;g=f|0;if((b|0)==(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}j=c[(er()|0)>>2]|0;c[(er()|0)>>2]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);k=+yz(b,g);b=c[(er()|0)>>2]|0;if((b|0)==0){c[(er()|0)>>2]=j}if((c[g>>2]|0)!=(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}if((b|0)==34){c[e>>2]=4}h=k;i=f;return+h}function t2(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+32|0;j=h|0;k=h+16|0;l=d+4|0;I=c[l>>2]|0,c[l>>2]=I+1,I;if((c[185170]|0)!=-1){c[k>>2]=740680;c[k+4>>2]=210;c[k+8>>2]=0;st(740680,k)}k=(c[185171]|0)-1|0;m=d+12|0;n=d+8|0;o=c[n>>2]|0;do{if((c[m>>2]|0)-o>>2>>>0>k>>>0){p=c[o+(k<<2)>>2]|0;if((p|0)==0){break}q=p;r=c[(c[p>>2]|0)+32>>2]|0;gq[r&31](q,80728,80760,e)|0;if((c[185074]|0)!=-1){c[j>>2]=740296;c[j+4>>2]=210;c[j+8>>2]=0;st(740296,j)}q=(c[185075]|0)-1|0;r=c[n>>2]|0;do{if((c[m>>2]|0)-r>>2>>>0>q>>>0){p=c[r+(q<<2)>>2]|0;if((p|0)==0){break}s=p;t=p;a[f]=f5[c[(c[t>>2]|0)+12>>2]&255](s)|0;a[g]=f5[c[(c[t>>2]|0)+16>>2]&255](s)|0;f3[c[(c[p>>2]|0)+20>>2]&1023](b,s);if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){i=h;return}f2[c[(c[d>>2]|0)+8>>2]&1023](d);i=h;return}}while(0);q=ff(4)|0;c[q>>2]=72472;dr(q|0,79072,408)}}while(0);h=ff(4)|0;c[h>>2]=72472;dr(h|0,79072,408)}function t3(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+80|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=e+32|0;n=e+40|0;o=e+48|0;p=e+64|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;t2(o,c[j+28>>2]|0,x,m,n);yB(q|0,0,12);j=p;ss(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=g|0;g=p|0;D=p+4|0;E=a[m]|0;m=a[n]|0;n=p+8|0;F=z;z=c[C>>2]|0;L4415:while(1){do{if((z|0)==0){G=0}else{if((c[z+12>>2]|0)!=(c[z+16>>2]|0)){G=z;break}if((f5[c[(c[z>>2]|0)+36>>2]&255](z)|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;I=c[f>>2]|0;do{if((I|0)==0){J=4051}else{if((c[I+12>>2]|0)!=(c[I+16>>2]|0)){if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L4415}}if((f5[c[(c[I>>2]|0)+36>>2]&255](I)|0)==-1){c[f>>2]=0;J=4051;break}else{if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L4415}}}}while(0);if((J|0)==4051){J=0;if(H){M=F;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}I=(c[r>>2]|0)-F|0;R=a[q]|0;S=R&255;if((I|0)==(((S&1|0)==0?S>>>1:c[D>>2]|0)|0)){S=I<<1;do{if(I>>>0<S>>>0){ss(p,I)}else{if((R&1)==0){a[j+1+S|0]=0;a[q]=I<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[D>>2]=S;break}}}while(0);S=a[q]|0;if((S&1)==0){T=10;U=S}else{S=c[g>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[D>>2]|0;do{if(R>>>0<T>>>0){ss(p,T-R|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[q]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[D>>2]=T;break}}}while(0);if((a[q]&1)==0){V=A}else{V=c[B>>2]|0}c[r>>2]=V+I;W=V}else{W=F}R=G+12|0;S=c[R>>2]|0;X=G+16|0;if((S|0)==(c[X>>2]|0)){Y=(f5[c[(c[G>>2]|0)+36>>2]&255](G)|0)&255}else{Y=a[S]|0}if((t$(Y,v,w,W,r,E,m,o,y,t,u,x)|0)!=0){M=W;N=K;O=L;P=G;Q=H;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[G>>2]|0)+40>>2]|0;f5[X&255](G)|0;F=W;z=G;continue}else{c[R>>2]=S+1;F=W;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){Z=z>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}W=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=W}}while(0);h[l>>3]=+t4(M,c[r>>2]|0,k);tQ(o,y,c[t>>2]|0,k);do{if(Q){_=0}else{if((c[P+12>>2]|0)!=(c[P+16>>2]|0)){_=P;break}if((f5[c[(c[P>>2]|0)+36>>2]&255](P)|0)!=-1){_=P;break}c[C>>2]=0;_=0}}while(0);C=(_|0)==0;L4484:do{if(O){J=4104}else{do{if((c[N+12>>2]|0)==(c[N+16>>2]|0)){if((f5[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){break}c[f>>2]=0;J=4104;break L4484}}while(0);if(!(C^(N|0)==0)){J=4106}}}while(0);if((J|0)==4104){if(C){J=4106}}if((J|0)==4106){c[k>>2]=c[k>>2]|2}c[b>>2]=_;do{if((a[q]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}yt(_)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}yt(G);i=e;return}function t4(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0.0;f=i;i=i+8|0;g=f|0;if((b|0)==(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}j=c[(er()|0)>>2]|0;c[(er()|0)>>2]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);k=+yz(b,g);b=c[(er()|0)>>2]|0;if((b|0)==0){c[(er()|0)>>2]=j}if((c[g>>2]|0)!=(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}if((b|0)!=34){h=k;i=f;return+h}c[e>>2]=4;h=k;i=f;return+h}function t5(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+80|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=e+32|0;n=e+40|0;o=e+48|0;p=e+64|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;t2(o,c[j+28>>2]|0,x,m,n);yB(q|0,0,12);j=p;ss(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=g|0;g=p|0;D=p+4|0;E=a[m]|0;m=a[n]|0;n=p+8|0;F=z;z=c[C>>2]|0;L4534:while(1){do{if((z|0)==0){G=0}else{if((c[z+12>>2]|0)!=(c[z+16>>2]|0)){G=z;break}if((f5[c[(c[z>>2]|0)+36>>2]&255](z)|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;I=c[f>>2]|0;do{if((I|0)==0){J=4151}else{if((c[I+12>>2]|0)!=(c[I+16>>2]|0)){if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L4534}}if((f5[c[(c[I>>2]|0)+36>>2]&255](I)|0)==-1){c[f>>2]=0;J=4151;break}else{if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L4534}}}}while(0);if((J|0)==4151){J=0;if(H){M=F;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}I=(c[r>>2]|0)-F|0;R=a[q]|0;S=R&255;if((I|0)==(((S&1|0)==0?S>>>1:c[D>>2]|0)|0)){S=I<<1;do{if(I>>>0<S>>>0){ss(p,I)}else{if((R&1)==0){a[j+1+S|0]=0;a[q]=I<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[D>>2]=S;break}}}while(0);S=a[q]|0;if((S&1)==0){T=10;U=S}else{S=c[g>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[D>>2]|0;do{if(R>>>0<T>>>0){ss(p,T-R|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[q]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[D>>2]=T;break}}}while(0);if((a[q]&1)==0){V=A}else{V=c[B>>2]|0}c[r>>2]=V+I;W=V}else{W=F}R=G+12|0;S=c[R>>2]|0;X=G+16|0;if((S|0)==(c[X>>2]|0)){Y=(f5[c[(c[G>>2]|0)+36>>2]&255](G)|0)&255}else{Y=a[S]|0}if((t$(Y,v,w,W,r,E,m,o,y,t,u,x)|0)!=0){M=W;N=K;O=L;P=G;Q=H;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[G>>2]|0)+40>>2]|0;f5[X&255](G)|0;F=W;z=G;continue}else{c[R>>2]=S+1;F=W;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){Z=z>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}W=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=W}}while(0);h[l>>3]=+t6(M,c[r>>2]|0,k);tQ(o,y,c[t>>2]|0,k);do{if(Q){_=0}else{if((c[P+12>>2]|0)!=(c[P+16>>2]|0)){_=P;break}if((f5[c[(c[P>>2]|0)+36>>2]&255](P)|0)!=-1){_=P;break}c[C>>2]=0;_=0}}while(0);C=(_|0)==0;L4603:do{if(O){J=4204}else{do{if((c[N+12>>2]|0)==(c[N+16>>2]|0)){if((f5[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){break}c[f>>2]=0;J=4204;break L4603}}while(0);if(!(C^(N|0)==0)){J=4206}}}while(0);if((J|0)==4204){if(C){J=4206}}if((J|0)==4206){c[k>>2]=c[k>>2]|2}c[b>>2]=_;do{if((a[q]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}yt(_)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}yt(G);i=e;return}function t6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0.0;f=i;i=i+8|0;g=f|0;if((b|0)==(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}j=c[(er()|0)>>2]|0;c[(er()|0)>>2]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);k=+yz(b,g);b=c[(er()|0)>>2]|0;if((b|0)==0){c[(er()|0)>>2]=j}if((c[g>>2]|0)!=(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}if((b|0)!=34){h=k;i=f;return+h}c[e>>2]=4;h=k;i=f;return+h}function t7(a){a=a|0;return}function t8(a){a=a|0;if((a|0)==0){return}yt(a);return}function t9(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;d=i;i=i+64|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[k>>2];k=d|0;l=d+16|0;m=d+48|0;n=m;o=i;i=i+12|0;i=i+7>>3<<3;p=i;i=i+4|0;i=i+7>>3<<3;q=i;i=i+160|0;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+4|0;i=i+7>>3<<3;yB(n|0,0,12);t=o;u=c[g+28>>2]|0;g=u+4|0;I=c[g>>2]|0,c[g>>2]=I+1,I;if((c[185170]|0)!=-1){c[k>>2]=740680;c[k+4>>2]=210;c[k+8>>2]=0;st(740680,k)}k=(c[185171]|0)-1|0;v=c[u+8>>2]|0;do{if((c[u+12>>2]|0)-v>>2>>>0>k>>>0){w=c[v+(k<<2)>>2]|0;if((w|0)==0){break}x=w;y=l|0;z=c[(c[w>>2]|0)+32>>2]|0;gq[z&31](x,80728,80754,y)|0;if(((I=c[g>>2]|0,c[g>>2]=I+ -1,I)|0)==0){f2[c[(c[u>>2]|0)+8>>2]&1023](u)}yB(t|0,0,12);x=o;ss(o,10);if((a[t]&1)==0){z=x+1|0;A=z;B=z;C=o+8|0}else{z=o+8|0;A=c[z>>2]|0;B=x+1|0;C=z}c[p>>2]=A;z=q|0;c[r>>2]=z;c[s>>2]=0;w=e|0;D=f|0;E=o|0;F=o+4|0;G=o+8|0;H=A;J=c[w>>2]|0;L4669:while(1){do{if((J|0)==0){K=0}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){K=J;break}if((f5[c[(c[J>>2]|0)+36>>2]&255](J)|0)!=-1){K=J;break}c[w>>2]=0;K=0}}while(0);L=(K|0)==0;M=c[D>>2]|0;do{if((M|0)==0){N=4266}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){if(L){break}else{O=H;break L4669}}if((f5[c[(c[M>>2]|0)+36>>2]&255](M)|0)==-1){c[D>>2]=0;N=4266;break}else{if(L){break}else{O=H;break L4669}}}}while(0);if((N|0)==4266){N=0;if(L){O=H;break}}M=(c[p>>2]|0)-H|0;P=a[t]|0;Q=P&255;if((M|0)==(((Q&1|0)==0?Q>>>1:c[F>>2]|0)|0)){Q=M<<1;do{if(M>>>0<Q>>>0){ss(o,M)}else{if((P&1)==0){a[x+1+Q|0]=0;a[t]=M<<2&255;break}else{a[(c[G>>2]|0)+Q|0]=0;c[F>>2]=Q;break}}}while(0);Q=a[t]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[E>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[F>>2]|0;do{if(P>>>0<R>>>0){ss(o,R-P|0)}else{if((S&1)==0){a[x+1+R|0]=0;a[t]=R<<1&255;break}else{a[(c[G>>2]|0)+R|0]=0;c[F>>2]=R;break}}}while(0);if((a[t]&1)==0){T=B}else{T=c[C>>2]|0}c[p>>2]=T+M;U=T}else{U=H}P=K+12|0;Q=c[P>>2]|0;L=K+16|0;if((Q|0)==(c[L>>2]|0)){V=(f5[c[(c[K>>2]|0)+36>>2]&255](K)|0)&255}else{V=a[Q]|0}if((tM(V,16,U,p,s,0,m,z,r,y)|0)!=0){O=U;break}Q=c[P>>2]|0;if((Q|0)==(c[L>>2]|0)){L=c[(c[K>>2]|0)+40>>2]|0;f5[L&255](K)|0;H=U;J=K;continue}else{c[P>>2]=Q+1;H=U;J=K;continue}}a[O+3|0]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);J=ua(O,c[141570]|0,(H=i,i=i+8|0,c[H>>2]=j,H)|0)|0;i=H;if((J|0)!=1){c[h>>2]=4}J=c[w>>2]|0;do{if((J|0)==0){W=0}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){W=J;break}if((f5[c[(c[J>>2]|0)+36>>2]&255](J)|0)!=-1){W=J;break}c[w>>2]=0;W=0}}while(0);w=(W|0)==0;J=c[D>>2]|0;do{if((J|0)==0){N=4318}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){if(w){break}else{N=4320;break}}if((f5[c[(c[J>>2]|0)+36>>2]&255](J)|0)==-1){c[D>>2]=0;N=4318;break}else{if(w){break}else{N=4320;break}}}}while(0);if((N|0)==4318){if(w){N=4320}}if((N|0)==4320){c[h>>2]=c[h>>2]|2}c[b>>2]=W;do{if((a[t]&1)!=0){D=c[G>>2]|0;if((D|0)==0){break}yt(D)}}while(0);if((a[n]&1)==0){i=d;return}G=c[m+8>>2]|0;if((G|0)==0){i=d;return}yt(G);i=d;return}}while(0);d=ff(4)|0;c[d>>2]=72472;dr(d|0,79072,408)}function ua(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;g=eE(b|0)|0;b=b2(a|0,39184,f|0)|0;if((g|0)==0){i=e;return b|0}eE(g|0)|0;i=e;return b|0}function ub(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+88|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=k|0;m=k+16|0;n=k+32|0;o=k+40|0;p=k+48|0;q=k+56|0;r=k+64|0;if((c[g+4>>2]&1|0)==0){c[n>>2]=-1;s=c[(c[d>>2]|0)+16>>2]|0;t=e|0;c[p>>2]=c[t>>2];c[q>>2]=c[f>>2];gi[s&127](o,d,p,q,g,h,n);q=c[o>>2]|0;c[t>>2]=q;t=c[n>>2]|0;if((t|0)==0){a[j]=0}else if((t|0)==1){a[j]=1}else{a[j]=1;c[h>>2]=4}c[b>>2]=q;i=k;return}q=g+28|0;g=c[q>>2]|0;t=g+4|0;I=c[t>>2]|0,c[t>>2]=I+1,I;if((c[185168]|0)!=-1){c[m>>2]=740672;c[m+4>>2]=210;c[m+8>>2]=0;st(740672,m)}m=(c[185169]|0)-1|0;n=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-n>>2>>>0>m>>>0){o=c[n+(m<<2)>>2]|0;if((o|0)==0){break}p=o;if(((I=c[t>>2]|0,c[t>>2]=I+ -1,I)|0)==0){f2[c[(c[g>>2]|0)+8>>2]&1023](g)}o=c[q>>2]|0;d=o+4|0;I=c[d>>2]|0,c[d>>2]=I+1,I;if((c[185072]|0)!=-1){c[l>>2]=740288;c[l+4>>2]=210;c[l+8>>2]=0;st(740288,l)}s=(c[185073]|0)-1|0;u=c[o+8>>2]|0;do{if((c[o+12>>2]|0)-u>>2>>>0>s>>>0){v=c[u+(s<<2)>>2]|0;if((v|0)==0){break}w=v;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)==0){f2[c[(c[o>>2]|0)+8>>2]&1023](o)}x=r|0;y=v;f3[c[(c[y>>2]|0)+24>>2]&1023](x,w);v=r+12|0;f3[c[(c[y>>2]|0)+28>>2]&1023](v,w);a[j]=(uc(e,c[f>>2]|0,x,r+24|0,p,h,1)|0)==(x|0)|0;c[b>>2]=c[e>>2];do{if((a[v]&1)!=0){x=c[r+20>>2]|0;if((x|0)==0){break}yt(x)}}while(0);if((a[r]&1)==0){i=k;return}v=c[r+8>>2]|0;if((v|0)==0){i=k;return}yt(v);i=k;return}}while(0);p=ff(4)|0;c[p>>2]=72472;dr(p|0,79072,408)}}while(0);k=ff(4)|0;c[k>>2]=72472;dr(k|0,79072,408)}function uc(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;l=i;i=i+104|0;m=(g-f|0)/12|0;n=l|0;do{if(m>>>0>100){o=ys(m)|0;if((o|0)!=0){p=o;q=o;break}o=ff(4)|0;c[o>>2]=72440;dr(o|0,79056,316);return 0}else{p=n;q=0}}while(0);n=(f|0)==(g|0);if(n){r=m;s=0}else{o=m;m=0;t=p;u=f;while(1){v=d[u]|0;if((v&1|0)==0){w=v>>>1}else{w=c[u+4>>2]|0}if((w|0)==0){a[t]=2;x=m+1|0;y=o-1|0}else{a[t]=1;x=m;y=o}v=u+12|0;if((v|0)==(g|0)){r=y;s=x;break}else{o=y;m=x;t=t+1|0;u=v}}}u=b|0;b=h;t=0;x=s;s=r;r=e;L4833:while(1){e=(s|0)!=0;m=t;y=r;while(1){o=c[u>>2]|0;do{if((o|0)==0){z=0}else{w=c[o+12>>2]|0;if((w|0)==(c[o+16>>2]|0)){A=f5[c[(c[o>>2]|0)+36>>2]&255](o)|0}else{A=c[w>>2]|0}if((A|0)==-1){c[u>>2]=0;z=0;break}else{z=c[u>>2]|0;break}}}while(0);o=(z|0)==0;if((y|0)==0){B=z;C=0}else{w=c[y+12>>2]|0;if((w|0)==(c[y+16>>2]|0)){D=f5[c[(c[y>>2]|0)+36>>2]&255](y)|0}else{D=c[w>>2]|0}B=c[u>>2]|0;C=(D|0)==-1?0:y}E=(C|0)==0;if(!((o^E)&e)){break L4833}o=c[B+12>>2]|0;if((o|0)==(c[B+16>>2]|0)){F=f5[c[(c[B>>2]|0)+36>>2]&255](B)|0}else{F=c[o>>2]|0}if(k){G=F}else{G=gm[c[(c[b>>2]|0)+28>>2]&127](h,F)|0}H=m+1|0;if(n){m=H;y=C}else{break}}L4863:do{if(k){y=s;e=x;o=p;w=0;v=f;while(1){do{if((a[o]|0)==1){I=a[v]|0;if((I&1)==0){J=v+4|0}else{J=c[v+8>>2]|0}if((G|0)!=(c[J+(m<<2)>>2]|0)){a[o]=0;K=w;L=e;M=y-1|0;break}N=I&255;if((N&1|0)==0){O=N>>>1}else{O=c[v+4>>2]|0}if((O|0)!=(H|0)){K=1;L=e;M=y;break}a[o]=2;K=1;L=e+1|0;M=y-1|0}else{K=w;L=e;M=y}}while(0);N=v+12|0;if((N|0)==(g|0)){P=M;Q=L;R=K;break L4863}y=M;e=L;o=o+1|0;w=K;v=N}}else{v=s;w=x;o=p;e=0;y=f;while(1){do{if((a[o]|0)==1){N=y;if((a[N]&1)==0){S=y+4|0}else{S=c[y+8>>2]|0}if((G|0)!=(gm[c[(c[b>>2]|0)+28>>2]&127](h,c[S+(m<<2)>>2]|0)|0)){a[o]=0;T=e;U=w;V=v-1|0;break}I=d[N]|0;if((I&1|0)==0){W=I>>>1}else{W=c[y+4>>2]|0}if((W|0)!=(H|0)){T=1;U=w;V=v;break}a[o]=2;T=1;U=w+1|0;V=v-1|0}else{T=e;U=w;V=v}}while(0);I=y+12|0;if((I|0)==(g|0)){P=V;Q=U;R=T;break L4863}v=V;w=U;o=o+1|0;e=T;y=I}}}while(0);if(!R){t=H;x=Q;s=P;r=C;continue}m=c[u>>2]|0;y=m+12|0;e=c[y>>2]|0;if((e|0)==(c[m+16>>2]|0)){o=c[(c[m>>2]|0)+40>>2]|0;f5[o&255](m)|0}else{c[y>>2]=e+4}if((P+Q|0)>>>0<2){t=H;x=Q;s=P;r=C;continue}else{X=Q;Y=p;Z=f}while(1){do{if((a[Y]|0)==2){e=d[Z]|0;if((e&1|0)==0){_=e>>>1}else{_=c[Z+4>>2]|0}if((_|0)==(H|0)){$=X;break}a[Y]=0;$=X-1|0}else{$=X}}while(0);e=Z+12|0;if((e|0)==(g|0)){t=H;x=$;s=P;r=C;continue L4833}else{X=$;Y=Y+1|0;Z=e}}}do{if((B|0)==0){aa=1}else{Z=c[B+12>>2]|0;if((Z|0)==(c[B+16>>2]|0)){ab=f5[c[(c[B>>2]|0)+36>>2]&255](B)|0}else{ab=c[Z>>2]|0}if((ab|0)==-1){c[u>>2]=0;aa=1;break}else{aa=(c[u>>2]|0)==0;break}}}while(0);do{if(E){ac=4486}else{u=c[C+12>>2]|0;if((u|0)==(c[C+16>>2]|0)){ad=f5[c[(c[C>>2]|0)+36>>2]&255](C)|0}else{ad=c[u>>2]|0}if((ad|0)==-1){ac=4486;break}if(!aa){ac=4488}}}while(0);if((ac|0)==4486){if(aa){ac=4488}}if((ac|0)==4488){c[j>>2]=c[j>>2]|2}L4940:do{if(n){ac=4493}else{aa=f;ad=p;while(1){if((a[ad]|0)==2){ae=aa;break L4940}C=aa+12|0;if((C|0)==(g|0)){ac=4493;break L4940}aa=C;ad=ad+1|0}}}while(0);if((ac|0)==4493){c[j>>2]=c[j>>2]|4;ae=g}if((q|0)==0){i=l;return ae|0}yt(q);i=l;return ae|0}function ud(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0;n=c[g>>2]|0;o=(n|0)==(f|0);do{if(o){p=(c[m+96>>2]|0)==(b|0);if(!p){if((c[m+100>>2]|0)!=(b|0)){break}}c[g>>2]=f+1;a[f]=p?43:45;c[h>>2]=0;q=0;return q|0}}while(0);p=d[j]|0;if((p&1|0)==0){r=p>>>1}else{r=c[j+4>>2]|0}if((r|0)!=0&(b|0)==(i|0)){i=c[l>>2]|0;if((i-k|0)>=160){q=0;return q|0}k=c[h>>2]|0;c[l>>2]=i+4;c[i>>2]=k;c[h>>2]=0;q=0;return q|0}k=m+104|0;i=m;while(1){if((i|0)==(k|0)){s=k;break}if((c[i>>2]|0)==(b|0)){s=i;break}else{i=i+4|0}}i=s-m|0;m=i>>2;if((i|0)>92){q=-1;return q|0}do{if((e|0)==8|(e|0)==10){if((m|0)<(e|0)){break}else{q=-1}return q|0}else if((e|0)==16){if((i|0)<88){break}if(o){q=-1;return q|0}if((n-f|0)>=3){q=-1;return q|0}if((a[n-1|0]|0)!=48){q=-1;return q|0}c[h>>2]=0;s=a[80728+m|0]|0;b=c[g>>2]|0;c[g>>2]=b+1;a[b]=s;q=0;return q|0}}while(0);f=a[80728+m|0]|0;c[g>>2]=n+1;a[n]=f;c[h>>2]=(c[h>>2]|0)+1;q=0;return q|0}function ue(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+144|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==64){v=8}else if((u|0)==0){v=0}else{v=10}u=l|0;uf(n,c[h+28>>2]|0,u,m);yB(p|0,0,12);h=o;ss(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=c[m>>2]|0;m=o+8|0;C=w;w=c[z>>2]|0;L5006:while(1){do{if((w|0)==0){D=0}else{E=c[w+12>>2]|0;if((E|0)==(c[w+16>>2]|0)){F=f5[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{F=c[E>>2]|0}if((F|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;G=c[f>>2]|0;do{if((G|0)==0){H=4554}else{I=c[G+12>>2]|0;if((I|0)==(c[G+16>>2]|0)){J=f5[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{J=c[I>>2]|0}if((J|0)==-1){c[f>>2]=0;H=4554;break}else{if(E){K=G;L=0;break}else{M=C;N=G;O=0;P=D;Q=0;break L5006}}}}while(0);if((H|0)==4554){H=0;if(E){M=C;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}G=(c[q>>2]|0)-C|0;I=a[p]|0;R=I&255;if((G|0)==(((R&1|0)==0?R>>>1:c[A>>2]|0)|0)){R=G<<1;do{if(G>>>0<R>>>0){ss(o,G)}else{if((I&1)==0){a[h+1+R|0]=0;a[p]=G<<2&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[A>>2]=R;break}}}while(0);R=a[p]|0;if((R&1)==0){S=10;T=R}else{R=c[g>>2]|0;S=(R&-2)-1|0;T=R&255}R=T&255;I=(R&1|0)==0?R>>>1:c[A>>2]|0;do{if(I>>>0<S>>>0){ss(o,S-I|0)}else{if((T&1)==0){a[h+1+S|0]=0;a[p]=S<<1&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[A>>2]=S;break}}}while(0);if((a[p]&1)==0){U=x}else{U=c[y>>2]|0}c[q>>2]=U+G;V=U}else{V=C}I=D+12|0;R=c[I>>2]|0;W=D+16|0;if((R|0)==(c[W>>2]|0)){X=f5[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{X=c[R>>2]|0}if((ud(X,v,V,q,t,B,n,l,s,u)|0)!=0){M=V;N=K;O=L;P=D;Q=E;break}R=c[I>>2]|0;if((R|0)==(c[W>>2]|0)){W=c[(c[D>>2]|0)+40>>2]|0;f5[W&255](D)|0;C=V;w=D;continue}else{c[I>>2]=R+4;C=V;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){Y=w>>>1}else{Y=c[n+4>>2]|0}do{if((Y|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}V=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=V}}while(0);c[k>>2]=tO(M,c[q>>2]|0,j,v)|0;tQ(n,l,c[s>>2]|0,j);do{if(Q){Z=0}else{s=c[P+12>>2]|0;if((s|0)==(c[P+16>>2]|0)){_=f5[c[(c[P>>2]|0)+36>>2]&255](P)|0}else{_=c[s>>2]|0}if((_|0)!=-1){Z=P;break}c[z>>2]=0;Z=0}}while(0);z=(Z|0)==0;do{if(O){H=4607}else{P=c[N+12>>2]|0;if((P|0)==(c[N+16>>2]|0)){$=f5[c[(c[N>>2]|0)+36>>2]&255](N)|0}else{$=c[P>>2]|0}if(($|0)==-1){c[f>>2]=0;H=4607;break}else{if(z^(N|0)==0){break}else{H=4609;break}}}}while(0);if((H|0)==4607){if(z){H=4609}}if((H|0)==4609){c[j>>2]=c[j>>2]|2}c[b>>2]=Z;do{if((a[p]&1)!=0){Z=c[m>>2]|0;if((Z|0)==0){break}yt(Z)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}yt(D);i=e;return}function uf(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=f+16|0;j=b+4|0;I=c[j>>2]|0,c[j>>2]=I+1,I;if((c[185168]|0)!=-1){c[h>>2]=740672;c[h+4>>2]=210;c[h+8>>2]=0;st(740672,h)}h=(c[185169]|0)-1|0;k=b+12|0;l=b+8|0;m=c[l>>2]|0;do{if((c[k>>2]|0)-m>>2>>>0>h>>>0){n=c[m+(h<<2)>>2]|0;if((n|0)==0){break}o=n;p=c[(c[n>>2]|0)+48>>2]|0;gq[p&31](o,80728,80754,d)|0;if((c[185072]|0)!=-1){c[g>>2]=740288;c[g+4>>2]=210;c[g+8>>2]=0;st(740288,g)}o=(c[185073]|0)-1|0;p=c[l>>2]|0;do{if((c[k>>2]|0)-p>>2>>>0>o>>>0){n=c[p+(o<<2)>>2]|0;if((n|0)==0){break}q=n;c[e>>2]=f5[c[(c[n>>2]|0)+16>>2]&255](q)|0;f3[c[(c[n>>2]|0)+20>>2]&1023](a,q);if(((I=c[j>>2]|0,c[j>>2]=I+ -1,I)|0)!=0){i=f;return}f2[c[(c[b>>2]|0)+8>>2]&1023](b);i=f;return}}while(0);o=ff(4)|0;c[o>>2]=72472;dr(o|0,79072,408)}}while(0);f=ff(4)|0;c[f>>2]=72472;dr(f|0,79072,408)}function ug(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+144|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==64){v=8}else if((u|0)==0){v=0}else{v=10}u=l|0;uf(n,c[h+28>>2]|0,u,m);yB(p|0,0,12);h=o;ss(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=c[m>>2]|0;m=o+8|0;C=w;w=c[z>>2]|0;L5137:while(1){do{if((w|0)==0){D=0}else{E=c[w+12>>2]|0;if((E|0)==(c[w+16>>2]|0)){F=f5[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{F=c[E>>2]|0}if((F|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;G=c[f>>2]|0;do{if((G|0)==0){H=4664}else{I=c[G+12>>2]|0;if((I|0)==(c[G+16>>2]|0)){J=f5[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{J=c[I>>2]|0}if((J|0)==-1){c[f>>2]=0;H=4664;break}else{if(E){L=G;M=0;break}else{N=C;O=G;P=0;Q=D;R=0;break L5137}}}}while(0);if((H|0)==4664){H=0;if(E){N=C;O=0;P=1;Q=0;R=1;break}else{L=0;M=1}}G=(c[q>>2]|0)-C|0;I=a[p]|0;S=I&255;if((G|0)==(((S&1|0)==0?S>>>1:c[A>>2]|0)|0)){S=G<<1;do{if(G>>>0<S>>>0){ss(o,G)}else{if((I&1)==0){a[h+1+S|0]=0;a[p]=G<<2&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[A>>2]=S;break}}}while(0);S=a[p]|0;if((S&1)==0){T=10;U=S}else{S=c[g>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;I=(S&1|0)==0?S>>>1:c[A>>2]|0;do{if(I>>>0<T>>>0){ss(o,T-I|0)}else{if((U&1)==0){a[h+1+T|0]=0;a[p]=T<<1&255;break}else{a[(c[m>>2]|0)+T|0]=0;c[A>>2]=T;break}}}while(0);if((a[p]&1)==0){V=x}else{V=c[y>>2]|0}c[q>>2]=V+G;W=V}else{W=C}I=D+12|0;S=c[I>>2]|0;X=D+16|0;if((S|0)==(c[X>>2]|0)){Y=f5[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{Y=c[S>>2]|0}if((ud(Y,v,W,q,t,B,n,l,s,u)|0)!=0){N=W;O=L;P=M;Q=D;R=E;break}S=c[I>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[D>>2]|0)+40>>2]|0;f5[X&255](D)|0;C=W;w=D;continue}else{c[I>>2]=S+4;C=W;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){Z=w>>>1}else{Z=c[n+4>>2]|0}do{if((Z|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}W=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=W}}while(0);t=tS(N,c[q>>2]|0,j,v)|0;c[k>>2]=t;c[k+4>>2]=K;tQ(n,l,c[s>>2]|0,j);do{if(R){_=0}else{s=c[Q+12>>2]|0;if((s|0)==(c[Q+16>>2]|0)){$=f5[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{$=c[s>>2]|0}if(($|0)!=-1){_=Q;break}c[z>>2]=0;_=0}}while(0);z=(_|0)==0;do{if(P){H=4717}else{Q=c[O+12>>2]|0;if((Q|0)==(c[O+16>>2]|0)){aa=f5[c[(c[O>>2]|0)+36>>2]&255](O)|0}else{aa=c[Q>>2]|0}if((aa|0)==-1){c[f>>2]=0;H=4717;break}else{if(z^(O|0)==0){break}else{H=4719;break}}}}while(0);if((H|0)==4717){if(z){H=4719}}if((H|0)==4719){c[j>>2]=c[j>>2]|2}c[b>>2]=_;do{if((a[p]&1)!=0){_=c[m>>2]|0;if((_|0)==0){break}yt(_)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}yt(D);i=e;return}function uh(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=i;i=i+144|0;m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7>>3<<3;c[h>>2]=c[m>>2];m=f|0;n=f+104|0;o=f+112|0;p=f+128|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=c[j+4>>2]&74;if((v|0)==8){w=16}else if((v|0)==0){w=0}else if((v|0)==64){w=8}else{w=10}v=m|0;uf(o,c[j+28>>2]|0,v,n);yB(q|0,0,12);j=p;ss(p,10);if((a[q]&1)==0){m=j+1|0;x=m;y=m;z=p+8|0}else{m=p+8|0;x=c[m>>2]|0;y=j+1|0;z=m}c[r>>2]=x;m=s|0;c[t>>2]=m;c[u>>2]=0;A=g|0;g=h|0;h=p|0;B=p+4|0;C=c[n>>2]|0;n=p+8|0;D=x;x=c[A>>2]|0;L5244:while(1){do{if((x|0)==0){E=0}else{F=c[x+12>>2]|0;if((F|0)==(c[x+16>>2]|0)){G=f5[c[(c[x>>2]|0)+36>>2]&255](x)|0}else{G=c[F>>2]|0}if((G|0)!=-1){E=x;break}c[A>>2]=0;E=0}}while(0);F=(E|0)==0;H=c[g>>2]|0;do{if((H|0)==0){I=4751}else{J=c[H+12>>2]|0;if((J|0)==(c[H+16>>2]|0)){K=f5[c[(c[H>>2]|0)+36>>2]&255](H)|0}else{K=c[J>>2]|0}if((K|0)==-1){c[g>>2]=0;I=4751;break}else{if(F){L=H;M=0;break}else{N=D;O=H;P=0;Q=E;R=0;break L5244}}}}while(0);if((I|0)==4751){I=0;if(F){N=D;O=0;P=1;Q=0;R=1;break}else{L=0;M=1}}H=(c[r>>2]|0)-D|0;J=a[q]|0;S=J&255;if((H|0)==(((S&1|0)==0?S>>>1:c[B>>2]|0)|0)){S=H<<1;do{if(H>>>0<S>>>0){ss(p,H)}else{if((J&1)==0){a[j+1+S|0]=0;a[q]=H<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[B>>2]=S;break}}}while(0);S=a[q]|0;if((S&1)==0){T=10;U=S}else{S=c[h>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;J=(S&1|0)==0?S>>>1:c[B>>2]|0;do{if(J>>>0<T>>>0){ss(p,T-J|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[q]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[B>>2]=T;break}}}while(0);if((a[q]&1)==0){V=y}else{V=c[z>>2]|0}c[r>>2]=V+H;W=V}else{W=D}J=E+12|0;S=c[J>>2]|0;X=E+16|0;if((S|0)==(c[X>>2]|0)){Y=f5[c[(c[E>>2]|0)+36>>2]&255](E)|0}else{Y=c[S>>2]|0}if((ud(Y,w,W,r,u,C,o,m,t,v)|0)!=0){N=W;O=L;P=M;Q=E;R=F;break}S=c[J>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[E>>2]|0)+40>>2]|0;f5[X&255](E)|0;D=W;x=E;continue}else{c[J>>2]=S+4;D=W;x=E;continue}}E=o;x=d[E]|0;if((x&1|0)==0){Z=x>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){x=c[t>>2]|0;if((x-s|0)>=160){break}W=c[u>>2]|0;c[t>>2]=x+4;c[x>>2]=W}}while(0);b[l>>1]=tU(N,c[r>>2]|0,k,w)|0;tQ(o,m,c[t>>2]|0,k);do{if(R){_=0}else{t=c[Q+12>>2]|0;if((t|0)==(c[Q+16>>2]|0)){$=f5[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{$=c[t>>2]|0}if(($|0)!=-1){_=Q;break}c[A>>2]=0;_=0}}while(0);A=(_|0)==0;do{if(P){I=4804}else{Q=c[O+12>>2]|0;if((Q|0)==(c[O+16>>2]|0)){aa=f5[c[(c[O>>2]|0)+36>>2]&255](O)|0}else{aa=c[Q>>2]|0}if((aa|0)==-1){c[g>>2]=0;I=4804;break}else{if(A^(O|0)==0){break}else{I=4806;break}}}}while(0);if((I|0)==4804){if(A){I=4806}}if((I|0)==4806){c[k>>2]=c[k>>2]|2}c[e>>2]=_;do{if((a[q]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}yt(_)}}while(0);if((a[E]&1)==0){i=f;return}E=c[o+8>>2]|0;if((E|0)==0){i=f;return}yt(E);i=f;return}function ui(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+144|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==64){v=8}else if((u|0)==0){v=0}else{v=10}u=l|0;uf(n,c[h+28>>2]|0,u,m);yB(p|0,0,12);h=o;ss(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=c[m>>2]|0;m=o+8|0;C=w;w=c[z>>2]|0;L5351:while(1){do{if((w|0)==0){D=0}else{E=c[w+12>>2]|0;if((E|0)==(c[w+16>>2]|0)){F=f5[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{F=c[E>>2]|0}if((F|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;G=c[f>>2]|0;do{if((G|0)==0){H=4838}else{I=c[G+12>>2]|0;if((I|0)==(c[G+16>>2]|0)){J=f5[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{J=c[I>>2]|0}if((J|0)==-1){c[f>>2]=0;H=4838;break}else{if(E){K=G;L=0;break}else{M=C;N=G;O=0;P=D;Q=0;break L5351}}}}while(0);if((H|0)==4838){H=0;if(E){M=C;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}G=(c[q>>2]|0)-C|0;I=a[p]|0;R=I&255;if((G|0)==(((R&1|0)==0?R>>>1:c[A>>2]|0)|0)){R=G<<1;do{if(G>>>0<R>>>0){ss(o,G)}else{if((I&1)==0){a[h+1+R|0]=0;a[p]=G<<2&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[A>>2]=R;break}}}while(0);R=a[p]|0;if((R&1)==0){S=10;T=R}else{R=c[g>>2]|0;S=(R&-2)-1|0;T=R&255}R=T&255;I=(R&1|0)==0?R>>>1:c[A>>2]|0;do{if(I>>>0<S>>>0){ss(o,S-I|0)}else{if((T&1)==0){a[h+1+S|0]=0;a[p]=S<<1&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[A>>2]=S;break}}}while(0);if((a[p]&1)==0){U=x}else{U=c[y>>2]|0}c[q>>2]=U+G;V=U}else{V=C}I=D+12|0;R=c[I>>2]|0;W=D+16|0;if((R|0)==(c[W>>2]|0)){X=f5[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{X=c[R>>2]|0}if((ud(X,v,V,q,t,B,n,l,s,u)|0)!=0){M=V;N=K;O=L;P=D;Q=E;break}R=c[I>>2]|0;if((R|0)==(c[W>>2]|0)){W=c[(c[D>>2]|0)+40>>2]|0;f5[W&255](D)|0;C=V;w=D;continue}else{c[I>>2]=R+4;C=V;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){Y=w>>>1}else{Y=c[n+4>>2]|0}do{if((Y|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}V=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=V}}while(0);c[k>>2]=tW(M,c[q>>2]|0,j,v)|0;tQ(n,l,c[s>>2]|0,j);do{if(Q){Z=0}else{s=c[P+12>>2]|0;if((s|0)==(c[P+16>>2]|0)){_=f5[c[(c[P>>2]|0)+36>>2]&255](P)|0}else{_=c[s>>2]|0}if((_|0)!=-1){Z=P;break}c[z>>2]=0;Z=0}}while(0);z=(Z|0)==0;do{if(O){H=4891}else{P=c[N+12>>2]|0;if((P|0)==(c[N+16>>2]|0)){$=f5[c[(c[N>>2]|0)+36>>2]&255](N)|0}else{$=c[P>>2]|0}if(($|0)==-1){c[f>>2]=0;H=4891;break}else{if(z^(N|0)==0){break}else{H=4893;break}}}}while(0);if((H|0)==4891){if(z){H=4893}}if((H|0)==4893){c[j>>2]=c[j>>2]|2}c[b>>2]=Z;do{if((a[p]&1)!=0){Z=c[m>>2]|0;if((Z|0)==0){break}yt(Z)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}yt(D);i=e;return}function uj(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+144|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==0){v=0}else if((u|0)==64){v=8}else{v=10}u=l|0;uf(n,c[h+28>>2]|0,u,m);yB(p|0,0,12);h=o;ss(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=c[m>>2]|0;m=o+8|0;C=w;w=c[z>>2]|0;L5458:while(1){do{if((w|0)==0){D=0}else{E=c[w+12>>2]|0;if((E|0)==(c[w+16>>2]|0)){F=f5[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{F=c[E>>2]|0}if((F|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;G=c[f>>2]|0;do{if((G|0)==0){H=4925}else{I=c[G+12>>2]|0;if((I|0)==(c[G+16>>2]|0)){J=f5[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{J=c[I>>2]|0}if((J|0)==-1){c[f>>2]=0;H=4925;break}else{if(E){K=G;L=0;break}else{M=C;N=G;O=0;P=D;Q=0;break L5458}}}}while(0);if((H|0)==4925){H=0;if(E){M=C;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}G=(c[q>>2]|0)-C|0;I=a[p]|0;R=I&255;if((G|0)==(((R&1|0)==0?R>>>1:c[A>>2]|0)|0)){R=G<<1;do{if(G>>>0<R>>>0){ss(o,G)}else{if((I&1)==0){a[h+1+R|0]=0;a[p]=G<<2&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[A>>2]=R;break}}}while(0);R=a[p]|0;if((R&1)==0){S=10;T=R}else{R=c[g>>2]|0;S=(R&-2)-1|0;T=R&255}R=T&255;I=(R&1|0)==0?R>>>1:c[A>>2]|0;do{if(I>>>0<S>>>0){ss(o,S-I|0)}else{if((T&1)==0){a[h+1+S|0]=0;a[p]=S<<1&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[A>>2]=S;break}}}while(0);if((a[p]&1)==0){U=x}else{U=c[y>>2]|0}c[q>>2]=U+G;V=U}else{V=C}I=D+12|0;R=c[I>>2]|0;W=D+16|0;if((R|0)==(c[W>>2]|0)){X=f5[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{X=c[R>>2]|0}if((ud(X,v,V,q,t,B,n,l,s,u)|0)!=0){M=V;N=K;O=L;P=D;Q=E;break}R=c[I>>2]|0;if((R|0)==(c[W>>2]|0)){W=c[(c[D>>2]|0)+40>>2]|0;f5[W&255](D)|0;C=V;w=D;continue}else{c[I>>2]=R+4;C=V;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){Y=w>>>1}else{Y=c[n+4>>2]|0}do{if((Y|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}V=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=V}}while(0);c[k>>2]=tY(M,c[q>>2]|0,j,v)|0;tQ(n,l,c[s>>2]|0,j);do{if(Q){Z=0}else{s=c[P+12>>2]|0;if((s|0)==(c[P+16>>2]|0)){_=f5[c[(c[P>>2]|0)+36>>2]&255](P)|0}else{_=c[s>>2]|0}if((_|0)!=-1){Z=P;break}c[z>>2]=0;Z=0}}while(0);z=(Z|0)==0;do{if(O){H=4978}else{P=c[N+12>>2]|0;if((P|0)==(c[N+16>>2]|0)){$=f5[c[(c[N>>2]|0)+36>>2]&255](N)|0}else{$=c[P>>2]|0}if(($|0)==-1){c[f>>2]=0;H=4978;break}else{if(z^(N|0)==0){break}else{H=4980;break}}}}while(0);if((H|0)==4978){if(z){H=4980}}if((H|0)==4980){c[j>>2]=c[j>>2]|2}c[b>>2]=Z;do{if((a[p]&1)!=0){Z=c[m>>2]|0;if((Z|0)==0){break}yt(Z)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}yt(D);i=e;return}function uk(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+144|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==64){v=8}else if((u|0)==0){v=0}else{v=10}u=l|0;uf(n,c[h+28>>2]|0,u,m);yB(p|0,0,12);h=o;ss(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=c[m>>2]|0;m=o+8|0;C=w;w=c[z>>2]|0;L5565:while(1){do{if((w|0)==0){D=0}else{E=c[w+12>>2]|0;if((E|0)==(c[w+16>>2]|0)){F=f5[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{F=c[E>>2]|0}if((F|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;G=c[f>>2]|0;do{if((G|0)==0){H=5012}else{I=c[G+12>>2]|0;if((I|0)==(c[G+16>>2]|0)){J=f5[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{J=c[I>>2]|0}if((J|0)==-1){c[f>>2]=0;H=5012;break}else{if(E){L=G;M=0;break}else{N=C;O=G;P=0;Q=D;R=0;break L5565}}}}while(0);if((H|0)==5012){H=0;if(E){N=C;O=0;P=1;Q=0;R=1;break}else{L=0;M=1}}G=(c[q>>2]|0)-C|0;I=a[p]|0;S=I&255;if((G|0)==(((S&1|0)==0?S>>>1:c[A>>2]|0)|0)){S=G<<1;do{if(G>>>0<S>>>0){ss(o,G)}else{if((I&1)==0){a[h+1+S|0]=0;a[p]=G<<2&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[A>>2]=S;break}}}while(0);S=a[p]|0;if((S&1)==0){T=10;U=S}else{S=c[g>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;I=(S&1|0)==0?S>>>1:c[A>>2]|0;do{if(I>>>0<T>>>0){ss(o,T-I|0)}else{if((U&1)==0){a[h+1+T|0]=0;a[p]=T<<1&255;break}else{a[(c[m>>2]|0)+T|0]=0;c[A>>2]=T;break}}}while(0);if((a[p]&1)==0){V=x}else{V=c[y>>2]|0}c[q>>2]=V+G;W=V}else{W=C}I=D+12|0;S=c[I>>2]|0;X=D+16|0;if((S|0)==(c[X>>2]|0)){Y=f5[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{Y=c[S>>2]|0}if((ud(Y,v,W,q,t,B,n,l,s,u)|0)!=0){N=W;O=L;P=M;Q=D;R=E;break}S=c[I>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[D>>2]|0)+40>>2]|0;f5[X&255](D)|0;C=W;w=D;continue}else{c[I>>2]=S+4;C=W;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){Z=w>>>1}else{Z=c[n+4>>2]|0}do{if((Z|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}W=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=W}}while(0);t=t_(N,c[q>>2]|0,j,v)|0;c[k>>2]=t;c[k+4>>2]=K;tQ(n,l,c[s>>2]|0,j);do{if(R){_=0}else{s=c[Q+12>>2]|0;if((s|0)==(c[Q+16>>2]|0)){$=f5[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{$=c[s>>2]|0}if(($|0)!=-1){_=Q;break}c[z>>2]=0;_=0}}while(0);z=(_|0)==0;do{if(P){H=5065}else{Q=c[O+12>>2]|0;if((Q|0)==(c[O+16>>2]|0)){aa=f5[c[(c[O>>2]|0)+36>>2]&255](O)|0}else{aa=c[Q>>2]|0}if((aa|0)==-1){c[f>>2]=0;H=5065;break}else{if(z^(O|0)==0){break}else{H=5067;break}}}}while(0);if((H|0)==5065){if(z){H=5067}}if((H|0)==5067){c[j>>2]=c[j>>2]|2}c[b>>2]=_;do{if((a[p]&1)!=0){_=c[m>>2]|0;if((_|0)==0){break}yt(_)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}yt(D);i=e;return}function ul(b,e,f,g,h,i,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0;if((b|0)==(i|0)){if((a[e]&1)==0){p=-1;return p|0}a[e]=0;i=c[h>>2]|0;c[h>>2]=i+1;a[i]=46;i=d[k]|0;if((i&1|0)==0){q=i>>>1}else{q=c[k+4>>2]|0}if((q|0)==0){p=0;return p|0}q=c[m>>2]|0;if((q-l|0)>=160){p=0;return p|0}i=c[n>>2]|0;c[m>>2]=q+4;c[q>>2]=i;p=0;return p|0}do{if((b|0)==(j|0)){i=d[k]|0;if((i&1|0)==0){r=i>>>1}else{r=c[k+4>>2]|0}if((r|0)==0){break}if((a[e]&1)==0){p=-1;return p|0}i=c[m>>2]|0;if((i-l|0)>=160){p=0;return p|0}q=c[n>>2]|0;c[m>>2]=i+4;c[i>>2]=q;c[n>>2]=0;p=0;return p|0}}while(0);r=o+128|0;j=o;while(1){if((j|0)==(r|0)){s=r;break}if((c[j>>2]|0)==(b|0)){s=j;break}else{j=j+4|0}}j=s-o|0;o=j>>2;if((j|0)>124){p=-1;return p|0}s=a[80728+o|0]|0;do{if((o|0)==25|(o|0)==24){b=c[h>>2]|0;do{if((b|0)!=(g|0)){if((a[b-1|0]&95|0)==(a[f]&127|0)){break}else{p=-1}return p|0}}while(0);c[h>>2]=b+1;a[b]=s;p=0;return p|0}else if((o|0)==22|(o|0)==23){a[f]=80}else{r=a[f]|0;if((s&95|0)!=(r<<24>>24|0)){break}a[f]=r|-128;if((a[e]&1)==0){break}a[e]=0;r=d[k]|0;if((r&1|0)==0){t=r>>>1}else{t=c[k+4>>2]|0}if((t|0)==0){break}r=c[m>>2]|0;if((r-l|0)>=160){break}q=c[n>>2]|0;c[m>>2]=r+4;c[r>>2]=q}}while(0);m=c[h>>2]|0;c[h>>2]=m+1;a[m]=s;if((j|0)>84){p=0;return p|0}c[n>>2]=(c[n>>2]|0)+1;p=0;return p|0}function um(b,e,f,h,j,k,l){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+176|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7>>3<<3;c[h>>2]=c[m>>2];m=e+128|0;n=e+136|0;o=e+144|0;p=e+160|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;un(o,c[j+28>>2]|0,x,m,n);yB(q|0,0,12);j=p;ss(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=h|0;h=p|0;D=p+4|0;E=c[m>>2]|0;m=c[n>>2]|0;n=p+8|0;F=z;z=c[C>>2]|0;L5729:while(1){do{if((z|0)==0){G=0}else{H=c[z+12>>2]|0;if((H|0)==(c[z+16>>2]|0)){I=f5[c[(c[z>>2]|0)+36>>2]&255](z)|0}else{I=c[H>>2]|0}if((I|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;J=c[f>>2]|0;do{if((J|0)==0){K=5143}else{L=c[J+12>>2]|0;if((L|0)==(c[J+16>>2]|0)){M=f5[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{M=c[L>>2]|0}if((M|0)==-1){c[f>>2]=0;K=5143;break}else{if(H){N=J;O=0;break}else{P=F;Q=J;R=0;S=G;T=0;break L5729}}}}while(0);if((K|0)==5143){K=0;if(H){P=F;Q=0;R=1;S=0;T=1;break}else{N=0;O=1}}J=(c[r>>2]|0)-F|0;L=a[q]|0;U=L&255;if((J|0)==(((U&1|0)==0?U>>>1:c[D>>2]|0)|0)){U=J<<1;do{if(J>>>0<U>>>0){ss(p,J)}else{if((L&1)==0){a[j+1+U|0]=0;a[q]=J<<2&255;break}else{a[(c[n>>2]|0)+U|0]=0;c[D>>2]=U;break}}}while(0);U=a[q]|0;if((U&1)==0){V=10;W=U}else{U=c[h>>2]|0;V=(U&-2)-1|0;W=U&255}U=W&255;L=(U&1|0)==0?U>>>1:c[D>>2]|0;do{if(L>>>0<V>>>0){ss(p,V-L|0)}else{if((W&1)==0){a[j+1+V|0]=0;a[q]=V<<1&255;break}else{a[(c[n>>2]|0)+V|0]=0;c[D>>2]=V;break}}}while(0);if((a[q]&1)==0){X=A}else{X=c[B>>2]|0}c[r>>2]=X+J;Y=X}else{Y=F}L=G+12|0;U=c[L>>2]|0;Z=G+16|0;if((U|0)==(c[Z>>2]|0)){_=f5[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{_=c[U>>2]|0}if((ul(_,v,w,Y,r,E,m,o,y,t,u,x)|0)!=0){P=Y;Q=N;R=O;S=G;T=H;break}U=c[L>>2]|0;if((U|0)==(c[Z>>2]|0)){Z=c[(c[G>>2]|0)+40>>2]|0;f5[Z&255](G)|0;F=Y;z=G;continue}else{c[L>>2]=U+4;F=Y;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){$=z>>>1}else{$=c[o+4>>2]|0}do{if(($|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}Y=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=Y}}while(0);g[l>>2]=+t1(P,c[r>>2]|0,k);tQ(o,y,c[t>>2]|0,k);do{if(T){aa=0}else{t=c[S+12>>2]|0;if((t|0)==(c[S+16>>2]|0)){ab=f5[c[(c[S>>2]|0)+36>>2]&255](S)|0}else{ab=c[t>>2]|0}if((ab|0)!=-1){aa=S;break}c[C>>2]=0;aa=0}}while(0);C=(aa|0)==0;do{if(R){K=5197}else{S=c[Q+12>>2]|0;if((S|0)==(c[Q+16>>2]|0)){ac=f5[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{ac=c[S>>2]|0}if((ac|0)==-1){c[f>>2]=0;K=5197;break}else{if(C^(Q|0)==0){break}else{K=5199;break}}}}while(0);if((K|0)==5197){if(C){K=5199}}if((K|0)==5199){c[k>>2]=c[k>>2]|2}c[b>>2]=aa;do{if((a[q]&1)!=0){aa=c[n>>2]|0;if((aa|0)==0){break}yt(aa)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}yt(G);i=e;return}function un(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=b+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;if((c[185168]|0)!=-1){c[j>>2]=740672;c[j+4>>2]=210;c[j+8>>2]=0;st(740672,j)}j=(c[185169]|0)-1|0;l=b+12|0;m=b+8|0;n=c[m>>2]|0;do{if((c[l>>2]|0)-n>>2>>>0>j>>>0){o=c[n+(j<<2)>>2]|0;if((o|0)==0){break}p=o;q=c[(c[o>>2]|0)+48>>2]|0;gq[q&31](p,80728,80760,d)|0;if((c[185072]|0)!=-1){c[h>>2]=740288;c[h+4>>2]=210;c[h+8>>2]=0;st(740288,h)}p=(c[185073]|0)-1|0;q=c[m>>2]|0;do{if((c[l>>2]|0)-q>>2>>>0>p>>>0){o=c[q+(p<<2)>>2]|0;if((o|0)==0){break}r=o;s=o;c[e>>2]=f5[c[(c[s>>2]|0)+12>>2]&255](r)|0;c[f>>2]=f5[c[(c[s>>2]|0)+16>>2]&255](r)|0;f3[c[(c[o>>2]|0)+20>>2]&1023](a,r);if(((I=c[k>>2]|0,c[k>>2]=I+ -1,I)|0)!=0){i=g;return}f2[c[(c[b>>2]|0)+8>>2]&1023](b);i=g;return}}while(0);p=ff(4)|0;c[p>>2]=72472;dr(p|0,79072,408)}}while(0);g=ff(4)|0;c[g>>2]=72472;dr(g|0,79072,408)}function uo(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+176|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=e+128|0;n=e+136|0;o=e+144|0;p=e+160|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;un(o,c[j+28>>2]|0,x,m,n);yB(q|0,0,12);j=p;ss(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=g|0;g=p|0;D=p+4|0;E=c[m>>2]|0;m=c[n>>2]|0;n=p+8|0;F=z;z=c[C>>2]|0;L5857:while(1){do{if((z|0)==0){G=0}else{H=c[z+12>>2]|0;if((H|0)==(c[z+16>>2]|0)){I=f5[c[(c[z>>2]|0)+36>>2]&255](z)|0}else{I=c[H>>2]|0}if((I|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;J=c[f>>2]|0;do{if((J|0)==0){K=5251}else{L=c[J+12>>2]|0;if((L|0)==(c[J+16>>2]|0)){M=f5[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{M=c[L>>2]|0}if((M|0)==-1){c[f>>2]=0;K=5251;break}else{if(H){N=J;O=0;break}else{P=F;Q=J;R=0;S=G;T=0;break L5857}}}}while(0);if((K|0)==5251){K=0;if(H){P=F;Q=0;R=1;S=0;T=1;break}else{N=0;O=1}}J=(c[r>>2]|0)-F|0;L=a[q]|0;U=L&255;if((J|0)==(((U&1|0)==0?U>>>1:c[D>>2]|0)|0)){U=J<<1;do{if(J>>>0<U>>>0){ss(p,J)}else{if((L&1)==0){a[j+1+U|0]=0;a[q]=J<<2&255;break}else{a[(c[n>>2]|0)+U|0]=0;c[D>>2]=U;break}}}while(0);U=a[q]|0;if((U&1)==0){V=10;W=U}else{U=c[g>>2]|0;V=(U&-2)-1|0;W=U&255}U=W&255;L=(U&1|0)==0?U>>>1:c[D>>2]|0;do{if(L>>>0<V>>>0){ss(p,V-L|0)}else{if((W&1)==0){a[j+1+V|0]=0;a[q]=V<<1&255;break}else{a[(c[n>>2]|0)+V|0]=0;c[D>>2]=V;break}}}while(0);if((a[q]&1)==0){X=A}else{X=c[B>>2]|0}c[r>>2]=X+J;Y=X}else{Y=F}L=G+12|0;U=c[L>>2]|0;Z=G+16|0;if((U|0)==(c[Z>>2]|0)){_=f5[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{_=c[U>>2]|0}if((ul(_,v,w,Y,r,E,m,o,y,t,u,x)|0)!=0){P=Y;Q=N;R=O;S=G;T=H;break}U=c[L>>2]|0;if((U|0)==(c[Z>>2]|0)){Z=c[(c[G>>2]|0)+40>>2]|0;f5[Z&255](G)|0;F=Y;z=G;continue}else{c[L>>2]=U+4;F=Y;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){$=z>>>1}else{$=c[o+4>>2]|0}do{if(($|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}Y=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=Y}}while(0);h[l>>3]=+t4(P,c[r>>2]|0,k);tQ(o,y,c[t>>2]|0,k);do{if(T){aa=0}else{t=c[S+12>>2]|0;if((t|0)==(c[S+16>>2]|0)){ab=f5[c[(c[S>>2]|0)+36>>2]&255](S)|0}else{ab=c[t>>2]|0}if((ab|0)!=-1){aa=S;break}c[C>>2]=0;aa=0}}while(0);C=(aa|0)==0;do{if(R){K=5305}else{S=c[Q+12>>2]|0;if((S|0)==(c[Q+16>>2]|0)){ac=f5[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{ac=c[S>>2]|0}if((ac|0)==-1){c[f>>2]=0;K=5305;break}else{if(C^(Q|0)==0){break}else{K=5307;break}}}}while(0);if((K|0)==5305){if(C){K=5307}}if((K|0)==5307){c[k>>2]=c[k>>2]|2}c[b>>2]=aa;do{if((a[q]&1)!=0){aa=c[n>>2]|0;if((aa|0)==0){break}yt(aa)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}yt(G);i=e;return}function up(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+176|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=e+128|0;n=e+136|0;o=e+144|0;p=e+160|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;un(o,c[j+28>>2]|0,x,m,n);yB(q|0,0,12);j=p;ss(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=g|0;g=p|0;D=p+4|0;E=c[m>>2]|0;m=c[n>>2]|0;n=p+8|0;F=z;z=c[C>>2]|0;L5960:while(1){do{if((z|0)==0){G=0}else{H=c[z+12>>2]|0;if((H|0)==(c[z+16>>2]|0)){I=f5[c[(c[z>>2]|0)+36>>2]&255](z)|0}else{I=c[H>>2]|0}if((I|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;J=c[f>>2]|0;do{if((J|0)==0){K=5335}else{L=c[J+12>>2]|0;if((L|0)==(c[J+16>>2]|0)){M=f5[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{M=c[L>>2]|0}if((M|0)==-1){c[f>>2]=0;K=5335;break}else{if(H){N=J;O=0;break}else{P=F;Q=J;R=0;S=G;T=0;break L5960}}}}while(0);if((K|0)==5335){K=0;if(H){P=F;Q=0;R=1;S=0;T=1;break}else{N=0;O=1}}J=(c[r>>2]|0)-F|0;L=a[q]|0;U=L&255;if((J|0)==(((U&1|0)==0?U>>>1:c[D>>2]|0)|0)){U=J<<1;do{if(J>>>0<U>>>0){ss(p,J)}else{if((L&1)==0){a[j+1+U|0]=0;a[q]=J<<2&255;break}else{a[(c[n>>2]|0)+U|0]=0;c[D>>2]=U;break}}}while(0);U=a[q]|0;if((U&1)==0){V=10;W=U}else{U=c[g>>2]|0;V=(U&-2)-1|0;W=U&255}U=W&255;L=(U&1|0)==0?U>>>1:c[D>>2]|0;do{if(L>>>0<V>>>0){ss(p,V-L|0)}else{if((W&1)==0){a[j+1+V|0]=0;a[q]=V<<1&255;break}else{a[(c[n>>2]|0)+V|0]=0;c[D>>2]=V;break}}}while(0);if((a[q]&1)==0){X=A}else{X=c[B>>2]|0}c[r>>2]=X+J;Y=X}else{Y=F}L=G+12|0;U=c[L>>2]|0;Z=G+16|0;if((U|0)==(c[Z>>2]|0)){_=f5[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{_=c[U>>2]|0}if((ul(_,v,w,Y,r,E,m,o,y,t,u,x)|0)!=0){P=Y;Q=N;R=O;S=G;T=H;break}U=c[L>>2]|0;if((U|0)==(c[Z>>2]|0)){Z=c[(c[G>>2]|0)+40>>2]|0;f5[Z&255](G)|0;F=Y;z=G;continue}else{c[L>>2]=U+4;F=Y;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){$=z>>>1}else{$=c[o+4>>2]|0}do{if(($|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}Y=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=Y}}while(0);h[l>>3]=+t6(P,c[r>>2]|0,k);tQ(o,y,c[t>>2]|0,k);do{if(T){aa=0}else{t=c[S+12>>2]|0;if((t|0)==(c[S+16>>2]|0)){ab=f5[c[(c[S>>2]|0)+36>>2]&255](S)|0}else{ab=c[t>>2]|0}if((ab|0)!=-1){aa=S;break}c[C>>2]=0;aa=0}}while(0);C=(aa|0)==0;do{if(R){K=5389}else{S=c[Q+12>>2]|0;if((S|0)==(c[Q+16>>2]|0)){ac=f5[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{ac=c[S>>2]|0}if((ac|0)==-1){c[f>>2]=0;K=5389;break}else{if(C^(Q|0)==0){break}else{K=5391;break}}}}while(0);if((K|0)==5389){if(C){K=5391}}if((K|0)==5391){c[k>>2]=c[k>>2]|2}c[b>>2]=aa;do{if((a[q]&1)!=0){aa=c[n>>2]|0;if((aa|0)==0){break}yt(aa)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}yt(G);i=e;return}function uq(a){a=a|0;return}function ur(a){a=a|0;if((a|0)==0){return}yt(a);return}function us(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;d=i;i=i+136|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[k>>2];k=d|0;l=d+16|0;m=d+120|0;n=m;o=i;i=i+12|0;i=i+7>>3<<3;p=i;i=i+4|0;i=i+7>>3<<3;q=i;i=i+160|0;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+4|0;i=i+7>>3<<3;yB(n|0,0,12);t=o;u=c[g+28>>2]|0;g=u+4|0;I=c[g>>2]|0,c[g>>2]=I+1,I;if((c[185168]|0)!=-1){c[k>>2]=740672;c[k+4>>2]=210;c[k+8>>2]=0;st(740672,k)}k=(c[185169]|0)-1|0;v=c[u+8>>2]|0;do{if((c[u+12>>2]|0)-v>>2>>>0>k>>>0){w=c[v+(k<<2)>>2]|0;if((w|0)==0){break}x=w;y=l|0;z=c[(c[w>>2]|0)+48>>2]|0;gq[z&31](x,80728,80754,y)|0;if(((I=c[g>>2]|0,c[g>>2]=I+ -1,I)|0)==0){f2[c[(c[u>>2]|0)+8>>2]&1023](u)}yB(t|0,0,12);x=o;ss(o,10);if((a[t]&1)==0){z=x+1|0;A=z;B=z;C=o+8|0}else{z=o+8|0;A=c[z>>2]|0;B=x+1|0;C=z}c[p>>2]=A;z=q|0;c[r>>2]=z;c[s>>2]=0;w=e|0;D=f|0;E=o|0;F=o+4|0;G=o+8|0;H=A;J=c[w>>2]|0;L6079:while(1){do{if((J|0)==0){K=0}else{L=c[J+12>>2]|0;if((L|0)==(c[J+16>>2]|0)){M=f5[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{M=c[L>>2]|0}if((M|0)!=-1){K=J;break}c[w>>2]=0;K=0}}while(0);L=(K|0)==0;N=c[D>>2]|0;do{if((N|0)==0){O=5434}else{P=c[N+12>>2]|0;if((P|0)==(c[N+16>>2]|0)){Q=f5[c[(c[N>>2]|0)+36>>2]&255](N)|0}else{Q=c[P>>2]|0}if((Q|0)==-1){c[D>>2]=0;O=5434;break}else{if(L){break}else{R=H;break L6079}}}}while(0);if((O|0)==5434){O=0;if(L){R=H;break}}N=(c[p>>2]|0)-H|0;P=a[t]|0;S=P&255;if((N|0)==(((S&1|0)==0?S>>>1:c[F>>2]|0)|0)){S=N<<1;do{if(N>>>0<S>>>0){ss(o,N)}else{if((P&1)==0){a[x+1+S|0]=0;a[t]=N<<2&255;break}else{a[(c[G>>2]|0)+S|0]=0;c[F>>2]=S;break}}}while(0);S=a[t]|0;if((S&1)==0){T=10;U=S}else{S=c[E>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;P=(S&1|0)==0?S>>>1:c[F>>2]|0;do{if(P>>>0<T>>>0){ss(o,T-P|0)}else{if((U&1)==0){a[x+1+T|0]=0;a[t]=T<<1&255;break}else{a[(c[G>>2]|0)+T|0]=0;c[F>>2]=T;break}}}while(0);if((a[t]&1)==0){V=B}else{V=c[C>>2]|0}c[p>>2]=V+N;W=V}else{W=H}P=K+12|0;S=c[P>>2]|0;L=K+16|0;if((S|0)==(c[L>>2]|0)){X=f5[c[(c[K>>2]|0)+36>>2]&255](K)|0}else{X=c[S>>2]|0}if((ud(X,16,W,p,s,0,m,z,r,y)|0)!=0){R=W;break}S=c[P>>2]|0;if((S|0)==(c[L>>2]|0)){L=c[(c[K>>2]|0)+40>>2]|0;f5[L&255](K)|0;H=W;J=K;continue}else{c[P>>2]=S+4;H=W;J=K;continue}}a[R+3|0]=0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);J=ua(R,c[141570]|0,(H=i,i=i+8|0,c[H>>2]=j,H)|0)|0;i=H;if((J|0)!=1){c[h>>2]=4}J=c[w>>2]|0;do{if((J|0)==0){Y=0}else{H=c[J+12>>2]|0;if((H|0)==(c[J+16>>2]|0)){Z=f5[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{Z=c[H>>2]|0}if((Z|0)!=-1){Y=J;break}c[w>>2]=0;Y=0}}while(0);w=(Y|0)==0;J=c[D>>2]|0;do{if((J|0)==0){O=5486}else{H=c[J+12>>2]|0;if((H|0)==(c[J+16>>2]|0)){_=f5[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{_=c[H>>2]|0}if((_|0)==-1){c[D>>2]=0;O=5486;break}else{if(w){break}else{O=5488;break}}}}while(0);if((O|0)==5486){if(w){O=5488}}if((O|0)==5488){c[h>>2]=c[h>>2]|2}c[b>>2]=Y;do{if((a[t]&1)!=0){D=c[G>>2]|0;if((D|0)==0){break}yt(D)}}while(0);if((a[n]&1)==0){i=d;return}G=c[m+8>>2]|0;if((G|0)==0){i=d;return}yt(G);i=d;return}}while(0);d=ff(4)|0;c[d>>2]=72472;dr(d|0,79072,408)}function ut(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;i=i+40|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=j+16|0;m=j+24|0;if((c[f+4>>2]&1|0)==0){n=c[(c[d>>2]|0)+24>>2]|0;c[l>>2]=c[e>>2];ge[n&63](b,d,l,f,g,h&1);i=j;return}g=c[f+28>>2]|0;f=g+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[185074]|0)!=-1){c[k>>2]=740296;c[k+4>>2]=210;c[k+8>>2]=0;st(740296,k)}k=(c[185075]|0)-1|0;l=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-l>>2>>>0>k>>>0){d=c[l+(k<<2)>>2]|0;if((d|0)==0){break}n=d;if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f2[c[(c[g>>2]|0)+8>>2]&1023](g)}o=c[d>>2]|0;if(h){f3[c[o+24>>2]&1023](m,n)}else{f3[c[o+28>>2]&1023](m,n)}n=m;o=m;d=a[o]|0;if((d&1)==0){p=n+1|0;q=p;r=p;s=m+8|0}else{p=m+8|0;q=c[p>>2]|0;r=n+1|0;s=p}p=e|0;n=m+4|0;t=q;u=d;while(1){v=(u&1)==0;if(v){w=r}else{w=c[s>>2]|0}d=u&255;if((t|0)==(w+((d&1|0)==0?d>>>1:c[n>>2]|0)|0)){break}d=a[t]|0;x=c[p>>2]|0;do{if((x|0)!=0){y=x+24|0;z=c[y>>2]|0;if((z|0)!=(c[x+28>>2]|0)){c[y>>2]=z+1;a[z]=d;break}if((gm[c[(c[x>>2]|0)+52>>2]&127](x,d&255)|0)!=-1){break}c[p>>2]=0}}while(0);t=t+1|0;u=a[o]|0}c[b>>2]=c[p>>2];if(v){i=j;return}o=c[m+8>>2]|0;if((o|0)==0){i=j;return}yt(o);i=j;return}}while(0);j=ff(4)|0;c[j>>2]=72472;dr(j|0,79072,408)}function uu(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+72|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+48|0;n=d+56|0;o=d+64|0;p=j|0;a[p]=a[55784]|0;a[p+1|0]=a[55785|0]|0;a[p+2|0]=a[55786|0]|0;a[p+3|0]=a[55787|0]|0;a[p+4|0]=a[55788|0]|0;a[p+5|0]=a[55789|0]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==64){a[t]=111}else if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else{a[t]=100}}while(0);t=k|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);s=uv(t,12,c[141570]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+s|0;h=c[r>>2]&176;do{if((h|0)==32){v=p}else if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((s|0)>1&r<<24>>24==48)){w=5565;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=5565;break}v=k+2|0}else{w=5565}}while(0);if((w|0)==5565){v=t}w=l|0;l=o|0;k=c[f+28>>2]|0;c[l>>2]=k;s=k+4|0;I=c[s>>2]|0,c[s>>2]=I+1,I;uw(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;ux(b,y,w,z,A,f,g);i=d;return}f2[c[(c[o>>2]|0)+8>>2]&1023](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;ux(b,y,w,z,A,f,g);i=d;return}function uv(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=h;c[j>>2]=f;c[j+4>>2]=0;j=eE(d|0)|0;d=ey(a|0,b|0,e|0,h|0)|0;if((j|0)==0){i=g;return d|0}eE(j|0)|0;i=g;return d|0}function uw(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[185170]|0)!=-1){c[n>>2]=740680;c[n+4>>2]=210;c[n+8>>2]=0;st(740680,n)}n=(c[185171]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=ff(4)|0;s=r;c[s>>2]=72472;dr(r|0,79072,408)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=ff(4)|0;s=r;c[s>>2]=72472;dr(r|0,79072,408)}r=k;s=c[p>>2]|0;if((c[185074]|0)!=-1){c[m>>2]=740296;c[m+4>>2]=210;c[m+8>>2]=0;st(740296,m)}m=(c[185075]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=ff(4)|0;u=t;c[u>>2]=72472;dr(t|0,79072,408)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=ff(4)|0;u=t;c[u>>2]=72472;dr(t|0,79072,408)}t=s;f3[c[(c[s>>2]|0)+20>>2]&1023](o,t);u=o;m=o;p=d[m]|0;if((p&1|0)==0){v=p>>>1}else{v=c[o+4>>2]|0}do{if((v|0)==0){p=c[(c[k>>2]|0)+32>>2]|0;gq[p&31](r,b,f,g)|0;c[j>>2]=g+(f-b)}else{c[j>>2]=g;p=a[b]|0;if((p<<24>>24|0)==45|(p<<24>>24|0)==43){n=gm[c[(c[k>>2]|0)+28>>2]&127](r,p)|0;p=c[j>>2]|0;c[j>>2]=p+1;a[p]=n;w=b+1|0}else{w=b}do{if((f-w|0)>1){if((a[w]|0)!=48){x=w;break}n=w+1|0;p=a[n]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){x=w;break}p=k;q=gm[c[(c[p>>2]|0)+28>>2]&127](r,48)|0;y=c[j>>2]|0;c[j>>2]=y+1;a[y]=q;q=gm[c[(c[p>>2]|0)+28>>2]&127](r,a[n]|0)|0;n=c[j>>2]|0;c[j>>2]=n+1;a[n]=q;x=w+2|0}else{x=w}}while(0);do{if((x|0)!=(f|0)){q=f-1|0;if(x>>>0<q>>>0){z=x;A=q}else{break}do{q=a[z]|0;a[z]=a[A]|0;a[A]=q;z=z+1|0;A=A-1|0;}while(z>>>0<A>>>0)}}while(0);q=f5[c[(c[s>>2]|0)+16>>2]&255](t)|0;if(x>>>0<f>>>0){n=u+1|0;p=k;y=o+4|0;B=o+8|0;C=0;D=0;E=x;while(1){F=a[((a[m]&1)==0?n:c[B>>2]|0)+D|0]|0;if(F<<24>>24!=0&(C|0)==(F<<24>>24|0)){F=c[j>>2]|0;c[j>>2]=F+1;a[F]=q;F=d[m]|0;G=(D>>>0<(((F&1|0)==0?F>>>1:c[y>>2]|0)-1|0)>>>0)+D|0;H=0}else{G=D;H=C}F=gm[c[(c[p>>2]|0)+28>>2]&127](r,a[E]|0)|0;I=c[j>>2]|0;c[j>>2]=I+1;a[I]=F;F=E+1|0;if(F>>>0<f>>>0){C=H+1|0;D=G;E=F}else{break}}}E=g+(x-b)|0;D=c[j>>2]|0;if((E|0)==(D|0)){break}C=D-1|0;if(E>>>0<C>>>0){J=E;K=C}else{break}do{C=a[J]|0;a[J]=a[K]|0;a[K]=C;J=J+1|0;K=K-1|0;}while(J>>>0<K>>>0)}}while(0);if((e|0)==(f|0)){L=c[j>>2]|0}else{L=g+(e-b)|0}c[h>>2]=L;if((a[m]&1)==0){i=l;return}m=c[o+8>>2]|0;if((m|0)==0){i=l;return}yt(m);i=l;return}function ux(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=i;i=i+16|0;l=k|0;if((d|0)==0){c[b>>2]=0;i=k;return}m=g;g=e;n=m-g|0;o=h+12|0;h=c[o>>2]|0;p=(h|0)>(n|0)?h-n|0:0;n=f;h=n-g|0;do{if((h|0)>0){if((ga[c[(c[d>>2]|0)+48>>2]&127](d,e,h)|0)==(h|0)){break}c[b>>2]=0;i=k;return}}while(0);do{if((p|0)>0){do{if(p>>>0<11){h=p<<1&255;e=l;a[e]=h;q=l+1|0;r=h;s=e}else{e=p+16&-16;h=(e|0)==0?1:e;while(1){t=ys(h)|0;if((t|0)!=0){u=5658;break}g=(I=c[185320]|0,c[185320]=I+0,I);if((g|0)==0){break}gs[g&63]()}if((u|0)==5658){c[l+8>>2]=t;h=e|1;c[l>>2]=h;c[l+4>>2]=p;q=t;r=h&255;s=l;break}h=ff(4)|0;c[h>>2]=72440;dr(h|0,79056,316)}}while(0);yB(q|0,j|0,p|0);a[q+p|0]=0;if((r&1)==0){v=l+1|0}else{v=c[l+8>>2]|0}if((ga[c[(c[d>>2]|0)+48>>2]&127](d,v,p)|0)==(p|0)){if((a[s]&1)==0){break}h=c[l+8>>2]|0;if((h|0)==0){break}yt(h);break}c[b>>2]=0;if((a[s]&1)==0){i=k;return}h=c[l+8>>2]|0;if((h|0)==0){i=k;return}yt(h);i=k;return}}while(0);l=m-n|0;do{if((l|0)>0){if((ga[c[(c[d>>2]|0)+48>>2]&127](d,f,l)|0)==(l|0)){break}c[b>>2]=0;i=k;return}}while(0);c[o>>2]=0;c[b>>2]=d;i=k;return}function uy(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+104|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+80|0;o=d+88|0;p=d+96|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=100}}while(0);t=l|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);u=uv(t,22,c[141570]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+u|0;j=c[r>>2]&176;do{if((j|0)==32){v=q}else if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=5707;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=5707;break}v=l+2|0}else{w=5707}}while(0);if((w|0)==5707){v=t}w=m|0;m=p|0;l=c[f+28>>2]|0;c[m>>2]=l;u=l+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;uw(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;ux(b,y,w,z,A,f,g);i=d;return}f2[c[(c[p>>2]|0)+8>>2]&1023](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;ux(b,y,w,z,A,f,g);i=d;return}function uz(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+72|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+48|0;n=d+56|0;o=d+64|0;p=j|0;a[p]=a[55784]|0;a[p+1|0]=a[55785|0]|0;a[p+2|0]=a[55786|0]|0;a[p+3|0]=a[55787|0]|0;a[p+4|0]=a[55788|0]|0;a[p+5|0]=a[55789|0]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==64){a[t]=111}else if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else{a[t]=117}}while(0);t=k|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);s=uv(t,12,c[141570]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+s|0;h=c[r>>2]&176;do{if((h|0)==32){v=p}else if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((s|0)>1&r<<24>>24==48)){w=5738;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=5738;break}v=k+2|0}else{w=5738}}while(0);if((w|0)==5738){v=t}w=l|0;l=o|0;k=c[f+28>>2]|0;c[l>>2]=k;s=k+4|0;I=c[s>>2]|0,c[s>>2]=I+1,I;uw(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;ux(b,y,w,z,A,f,g);i=d;return}f2[c[(c[o>>2]|0)+8>>2]&1023](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;ux(b,y,w,z,A,f,g);i=d;return}function uA(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+104|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+80|0;o=d+88|0;p=d+96|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=117}}while(0);t=l|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);u=uv(t,23,c[141570]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+u|0;j=c[r>>2]&176;do{if((j|0)==32){v=q}else if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=5769;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=5769;break}v=l+2|0}else{w=5769}}while(0);if((w|0)==5769){v=t}w=m|0;m=p|0;l=c[f+28>>2]|0;c[m>>2]=l;u=l+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;uw(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;ux(b,y,w,z,A,f,g);i=d;return}f2[c[(c[p>>2]|0)+8>>2]&1023](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;ux(b,y,w,z,A,f,g);i=d;return}function uB(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+144|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+112|0;p=d+120|0;q=d+128|0;r=d+136|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){if((k&1|0)==0){a[w]=97;x=0;break}else{a[w]=65;x=0;break}}else{a[w]=46;u=w+2|0;a[w+1|0]=42;if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=c[141570]|0;if(x){v=uv(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=uv(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[741360]|0)==0;if(x){do{if(v){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=uC(m,c[141570]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);v=uC(m,c[141570]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=ff(4)|0;c[v>>2]=72440;dr(v|0,79056,316)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=5831;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=5831;break}E=D+2|0}else if((z|0)==32){E=m}else{F=5831}}while(0);if((F|0)==5831){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=ys(B<<1)|0;if((F|0)!=0){G=F;H=F;J=D;break}F=ff(4)|0;c[F>>2]=72440;dr(F|0,79056,316)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;uD(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){f2[c[(c[q>>2]|0)+8>>2]&1023](q|0)}q=e|0;ux(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){yt(H)}if((C|0)==0){i=d;return}yt(C);i=d;return}function uC(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f|0;h=g;c[h>>2]=e;c[h+4>>2]=0;h=eE(b|0)|0;b=fm(a|0,d|0,g|0)|0;if((h|0)==0){i=f;return b|0}eE(h|0)|0;i=f;return b|0}function uD(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[185170]|0)!=-1){c[n>>2]=740680;c[n+4>>2]=210;c[n+8>>2]=0;st(740680,n)}n=(c[185171]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=ff(4)|0;s=r;c[s>>2]=72472;dr(r|0,79072,408)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=ff(4)|0;s=r;c[s>>2]=72472;dr(r|0,79072,408)}r=k;s=c[p>>2]|0;if((c[185074]|0)!=-1){c[m>>2]=740296;c[m+4>>2]=210;c[m+8>>2]=0;st(740296,m)}m=(c[185075]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=ff(4)|0;u=t;c[u>>2]=72472;dr(t|0,79072,408)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=ff(4)|0;u=t;c[u>>2]=72472;dr(t|0,79072,408)}t=s;f3[c[(c[s>>2]|0)+20>>2]&1023](o,t);c[j>>2]=g;u=a[b]|0;if((u<<24>>24|0)==45|(u<<24>>24|0)==43){m=gm[c[(c[k>>2]|0)+28>>2]&127](r,u)|0;u=c[j>>2]|0;c[j>>2]=u+1;a[u]=m;v=b+1|0}else{v=b}m=f;L6596:do{if((m-v|0)>1){if((a[v]|0)!=48){w=v;x=5902;break}u=v+1|0;p=a[u]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){w=v;x=5902;break}p=k;n=gm[c[(c[p>>2]|0)+28>>2]&127](r,48)|0;q=c[j>>2]|0;c[j>>2]=q+1;a[q]=n;n=v+2|0;q=gm[c[(c[p>>2]|0)+28>>2]&127](r,a[u]|0)|0;u=c[j>>2]|0;c[j>>2]=u+1;a[u]=q;q=n;while(1){if(q>>>0>=f>>>0){y=q;z=n;break L6596}u=a[q]|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);if((a8(u<<24>>24|0,c[141570]|0)|0)==0){y=q;z=n;break}else{q=q+1|0}}}else{w=v;x=5902}}while(0);L6611:do{if((x|0)==5902){while(1){x=0;if(w>>>0>=f>>>0){y=w;z=v;break L6611}q=a[w]|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);if((eW(q<<24>>24|0,c[141570]|0)|0)==0){y=w;z=v;break}else{w=w+1|0;x=5902}}}}while(0);x=o;w=o;v=d[w]|0;if((v&1|0)==0){A=v>>>1}else{A=c[o+4>>2]|0}do{if((A|0)==0){v=c[j>>2]|0;u=c[(c[k>>2]|0)+32>>2]|0;gq[u&31](r,z,y,v)|0;c[j>>2]=(c[j>>2]|0)+(y-z)}else{do{if((z|0)!=(y|0)){v=y-1|0;if(z>>>0<v>>>0){B=z;C=v}else{break}do{v=a[B]|0;a[B]=a[C]|0;a[C]=v;B=B+1|0;C=C-1|0;}while(B>>>0<C>>>0)}}while(0);q=f5[c[(c[s>>2]|0)+16>>2]&255](t)|0;if(z>>>0<y>>>0){v=x+1|0;u=o+4|0;n=o+8|0;p=k;D=0;E=0;F=z;while(1){G=a[((a[w]&1)==0?v:c[n>>2]|0)+E|0]|0;if(G<<24>>24>0&(D|0)==(G<<24>>24|0)){G=c[j>>2]|0;c[j>>2]=G+1;a[G]=q;G=d[w]|0;H=(E>>>0<(((G&1|0)==0?G>>>1:c[u>>2]|0)-1|0)>>>0)+E|0;I=0}else{H=E;I=D}G=gm[c[(c[p>>2]|0)+28>>2]&127](r,a[F]|0)|0;J=c[j>>2]|0;c[j>>2]=J+1;a[J]=G;G=F+1|0;if(G>>>0<y>>>0){D=I+1|0;E=H;F=G}else{break}}}F=g+(z-b)|0;E=c[j>>2]|0;if((F|0)==(E|0)){break}D=E-1|0;if(F>>>0<D>>>0){K=F;L=D}else{break}do{D=a[K]|0;a[K]=a[L]|0;a[L]=D;K=K+1|0;L=L-1|0;}while(K>>>0<L>>>0)}}while(0);L6649:do{if(y>>>0<f>>>0){L=k;K=y;while(1){z=a[K]|0;if(z<<24>>24==46){break}H=gm[c[(c[L>>2]|0)+28>>2]&127](r,z)|0;z=c[j>>2]|0;c[j>>2]=z+1;a[z]=H;H=K+1|0;if(H>>>0<f>>>0){K=H}else{M=H;break L6649}}L=f5[c[(c[s>>2]|0)+12>>2]&255](t)|0;H=c[j>>2]|0;c[j>>2]=H+1;a[H]=L;M=K+1|0}else{M=y}}while(0);gq[c[(c[k>>2]|0)+32>>2]&31](r,M,f,c[j>>2]|0)|0;r=(c[j>>2]|0)+(m-M)|0;c[j>>2]=r;if((e|0)==(f|0)){N=r}else{N=g+(e-b)|0}c[h>>2]=N;if((a[w]&1)==0){i=l;return}w=c[o+8>>2]|0;if((w|0)==0){i=l;return}yt(w);i=l;return}function uE(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+144|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+112|0;p=d+120|0;q=d+128|0;r=d+136|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){a[w]=76;u=w+1|0;if((k&1|0)==0){a[u]=97;x=0;break}else{a[u]=65;x=0;break}}else{a[w]=46;a[w+1|0]=42;a[w+2|0]=76;u=w+3|0;if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=c[141570]|0;if(x){v=uv(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=uv(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[741360]|0)==0;if(x){do{if(v){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=uC(m,c[141570]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);v=uC(m,c[141570]|0,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=ff(4)|0;c[v>>2]=72440;dr(v|0,79056,316)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=6002;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=6002;break}E=D+2|0}else if((z|0)==32){E=m}else{F=6002}}while(0);if((F|0)==6002){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=ys(B<<1)|0;if((F|0)!=0){G=F;H=F;J=D;break}F=ff(4)|0;c[F>>2]=72440;dr(F|0,79056,316)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;uD(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){f2[c[(c[q>>2]|0)+8>>2]&1023](q|0)}q=e|0;ux(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){yt(H)}if((C|0)==0){i=d;return}yt(C);i=d;return}function uF(a){a=a|0;return}function uG(a){a=a|0;if((a|0)==0){return}yt(a);return}function uH(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+136|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+112|0;n=d+120|0;o=d+128|0;p=j|0;a[p]=a[55784]|0;a[p+1|0]=a[55785|0]|0;a[p+2|0]=a[55786|0]|0;a[p+3|0]=a[55787|0]|0;a[p+4|0]=a[55788|0]|0;a[p+5|0]=a[55789|0]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==64){a[t]=111}else if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else{a[t]=100}}while(0);t=k|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);s=uv(t,12,c[141570]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+s|0;h=c[r>>2]&176;do{if((h|0)==32){v=p}else if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((s|0)>1&r<<24>>24==48)){w=6053;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=6053;break}v=k+2|0}else{w=6053}}while(0);if((w|0)==6053){v=t}w=l|0;l=o|0;k=c[f+28>>2]|0;c[l>>2]=k;s=k+4|0;I=c[s>>2]|0,c[s>>2]=I+1,I;uL(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;uM(b,y,w,z,A,f,g);i=d;return}f2[c[(c[o>>2]|0)+8>>2]&1023](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;uM(b,y,w,z,A,f,g);i=d;return}function uI(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+88|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+24|0;l=d+48|0;m=d+16|0;a[m]=a[55792]|0;a[m+1|0]=a[55793|0]|0;a[m+2|0]=a[55794|0]|0;a[m+3|0]=a[55795|0]|0;a[m+4|0]=a[55796|0]|0;a[m+5|0]=a[55797|0]|0;n=k|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);o=uv(n,20,c[141570]|0,m,(m=i,i=i+8|0,c[m>>2]=h,m)|0)|0;i=m;m=k+o|0;h=c[f+4>>2]&176;do{if((h|0)==32){p=m}else if((h|0)==16){q=a[n]|0;if((q<<24>>24|0)==45|(q<<24>>24|0)==43){p=k+1|0;break}if(!((o|0)>1&q<<24>>24==48)){r=6074;break}q=a[k+1|0]|0;if(!((q<<24>>24|0)==120|(q<<24>>24|0)==88)){r=6074;break}p=k+2|0}else{r=6074}}while(0);if((r|0)==6074){p=n}r=c[f+28>>2]|0;h=r+4|0;I=c[h>>2]|0,c[h>>2]=I+1,I;if((c[185170]|0)!=-1){c[j>>2]=740680;c[j+4>>2]=210;c[j+8>>2]=0;st(740680,j)}j=(c[185171]|0)-1|0;q=c[r+8>>2]|0;do{if((c[r+12>>2]|0)-q>>2>>>0>j>>>0){s=c[q+(j<<2)>>2]|0;if((s|0)==0){break}t=s;if(((I=c[h>>2]|0,c[h>>2]=I+ -1,I)|0)==0){f2[c[(c[r>>2]|0)+8>>2]&1023](r)}u=l|0;v=c[(c[s>>2]|0)+32>>2]|0;gq[v&31](t,n,m,u)|0;t=l+o|0;if((p|0)==(m|0)){w=t;x=e|0;y=c[x>>2]|0;ux(b,y,u,w,t,f,g);i=d;return}w=l+(p-k)|0;x=e|0;y=c[x>>2]|0;ux(b,y,u,w,t,f,g);i=d;return}}while(0);d=ff(4)|0;c[d>>2]=72472;dr(d|0,79072,408)}function uJ(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;i=i+40|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=j+16|0;m=j+24|0;if((c[f+4>>2]&1|0)==0){n=c[(c[d>>2]|0)+24>>2]|0;c[l>>2]=c[e>>2];ge[n&63](b,d,l,f,g,h&1);i=j;return}g=c[f+28>>2]|0;f=g+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[185072]|0)!=-1){c[k>>2]=740288;c[k+4>>2]=210;c[k+8>>2]=0;st(740288,k)}k=(c[185073]|0)-1|0;l=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-l>>2>>>0>k>>>0){d=c[l+(k<<2)>>2]|0;if((d|0)==0){break}n=d;if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f2[c[(c[g>>2]|0)+8>>2]&1023](g)}o=c[d>>2]|0;if(h){f3[c[o+24>>2]&1023](m,n)}else{f3[c[o+28>>2]&1023](m,n)}n=m;o=a[n]|0;if((o&1)==0){d=m+4|0;p=d;q=d;r=m+8|0}else{d=m+8|0;p=c[d>>2]|0;q=m+4|0;r=d}d=e|0;s=p;t=o;while(1){u=(t&1)==0;if(u){v=q}else{v=c[r>>2]|0}o=t&255;if((o&1|0)==0){w=o>>>1}else{w=c[q>>2]|0}if((s|0)==(v+(w<<2)|0)){break}o=c[s>>2]|0;x=c[d>>2]|0;do{if((x|0)!=0){y=x+24|0;z=c[y>>2]|0;if((z|0)==(c[x+28>>2]|0)){A=gm[c[(c[x>>2]|0)+52>>2]&127](x,o)|0}else{c[y>>2]=z+4;c[z>>2]=o;A=o}if((A|0)!=-1){break}c[d>>2]=0}}while(0);s=s+4|0;t=a[n]|0}c[b>>2]=c[d>>2];if(u){i=j;return}n=c[m+8>>2]|0;if((n|0)==0){i=j;return}yt(n);i=j;return}}while(0);j=ff(4)|0;c[j>>2]=72472;dr(j|0,79072,408)}function uK(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+224|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+200|0;o=d+208|0;p=d+216|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=100}}while(0);t=l|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);u=uv(t,22,c[141570]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+u|0;j=c[r>>2]&176;do{if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=6156;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=6156;break}v=l+2|0}else if((j|0)==32){v=q}else{w=6156}}while(0);if((w|0)==6156){v=t}w=m|0;m=p|0;j=c[f+28>>2]|0;c[m>>2]=j;l=j+4|0;I=c[l>>2]|0,c[l>>2]=I+1,I;uL(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;uM(b,y,w,z,A,f,g);i=d;return}f2[c[(c[p>>2]|0)+8>>2]&1023](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;uM(b,y,w,z,A,f,g);i=d;return}function uL(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[185168]|0)!=-1){c[n>>2]=740672;c[n+4>>2]=210;c[n+8>>2]=0;st(740672,n)}n=(c[185169]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=ff(4)|0;s=r;c[s>>2]=72472;dr(r|0,79072,408)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=ff(4)|0;s=r;c[s>>2]=72472;dr(r|0,79072,408)}r=k;s=c[p>>2]|0;if((c[185072]|0)!=-1){c[m>>2]=740288;c[m+4>>2]=210;c[m+8>>2]=0;st(740288,m)}m=(c[185073]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=ff(4)|0;u=t;c[u>>2]=72472;dr(t|0,79072,408)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=ff(4)|0;u=t;c[u>>2]=72472;dr(t|0,79072,408)}t=s;f3[c[(c[s>>2]|0)+20>>2]&1023](o,t);u=o;m=o;p=d[m]|0;if((p&1|0)==0){v=p>>>1}else{v=c[o+4>>2]|0}do{if((v|0)==0){p=c[(c[k>>2]|0)+48>>2]|0;gq[p&31](r,b,f,g)|0;c[j>>2]=g+(f-b<<2)}else{c[j>>2]=g;p=a[b]|0;if((p<<24>>24|0)==45|(p<<24>>24|0)==43){n=gm[c[(c[k>>2]|0)+44>>2]&127](r,p)|0;p=c[j>>2]|0;c[j>>2]=p+4;c[p>>2]=n;w=b+1|0}else{w=b}do{if((f-w|0)>1){if((a[w]|0)!=48){x=w;break}n=w+1|0;p=a[n]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){x=w;break}p=k;q=gm[c[(c[p>>2]|0)+44>>2]&127](r,48)|0;y=c[j>>2]|0;c[j>>2]=y+4;c[y>>2]=q;q=gm[c[(c[p>>2]|0)+44>>2]&127](r,a[n]|0)|0;n=c[j>>2]|0;c[j>>2]=n+4;c[n>>2]=q;x=w+2|0}else{x=w}}while(0);do{if((x|0)!=(f|0)){q=f-1|0;if(x>>>0<q>>>0){z=x;A=q}else{break}do{q=a[z]|0;a[z]=a[A]|0;a[A]=q;z=z+1|0;A=A-1|0;}while(z>>>0<A>>>0)}}while(0);q=f5[c[(c[s>>2]|0)+16>>2]&255](t)|0;if(x>>>0<f>>>0){n=u+1|0;p=k;y=o+4|0;B=o+8|0;C=0;D=0;E=x;while(1){F=a[((a[m]&1)==0?n:c[B>>2]|0)+D|0]|0;if(F<<24>>24!=0&(C|0)==(F<<24>>24|0)){F=c[j>>2]|0;c[j>>2]=F+4;c[F>>2]=q;F=d[m]|0;G=(D>>>0<(((F&1|0)==0?F>>>1:c[y>>2]|0)-1|0)>>>0)+D|0;H=0}else{G=D;H=C}F=gm[c[(c[p>>2]|0)+44>>2]&127](r,a[E]|0)|0;I=c[j>>2]|0;c[j>>2]=I+4;c[I>>2]=F;F=E+1|0;if(F>>>0<f>>>0){C=H+1|0;D=G;E=F}else{break}}}E=g+(x-b<<2)|0;D=c[j>>2]|0;if((E|0)==(D|0)){break}C=D-4|0;if(E>>>0<C>>>0){J=E;K=C}else{break}do{C=c[J>>2]|0;c[J>>2]=c[K>>2];c[K>>2]=C;J=J+4|0;K=K-4|0;}while(J>>>0<K>>>0)}}while(0);if((e|0)==(f|0)){L=c[j>>2]|0}else{L=g+(e-b<<2)|0}c[h>>2]=L;if((a[m]&1)==0){i=l;return}m=c[o+8>>2]|0;if((m|0)==0){i=l;return}yt(m);i=l;return}function uM(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=i;i=i+16|0;l=k|0;if((d|0)==0){c[b>>2]=0;i=k;return}m=g;g=e;n=m-g>>2;o=h+12|0;h=c[o>>2]|0;p=(h|0)>(n|0)?h-n|0:0;n=f;h=n-g|0;g=h>>2;do{if((h|0)>0){if((ga[c[(c[d>>2]|0)+48>>2]&127](d,e,g)|0)==(g|0)){break}c[b>>2]=0;i=k;return}}while(0);do{if((p|0)>0){if(p>>>0>1073741822){su()}do{if(p>>>0<2){a[l]=p<<1&255;q=1;r=l+4|0}else{g=p+4&-4;e=g<<2;h=(e|0)==0?1:e;while(1){s=ys(h)|0;if((s|0)!=0){t=6245;break}e=(I=c[185320]|0,c[185320]=I+0,I);if((e|0)==0){break}gs[e&63]()}if((t|0)==6245){h=s;c[l+8>>2]=h;c[l>>2]=g|1;c[l+4>>2]=p;q=p;r=h;break}h=ff(4)|0;c[h>>2]=72440;dr(h|0,79056,316)}}while(0);h=q;e=r;while(1){u=h-1|0;c[e>>2]=j;if((u|0)==0){break}else{h=u;e=e+4|0}}c[r+(p<<2)>>2]=0;e=l;if((a[e]&1)==0){v=l+4|0}else{v=c[l+8>>2]|0}if((ga[c[(c[d>>2]|0)+48>>2]&127](d,v,p)|0)==(p|0)){if((a[e]&1)==0){break}h=c[l+8>>2]|0;if((h|0)==0){break}yt(h);break}c[b>>2]=0;if((a[e]&1)==0){i=k;return}e=c[l+8>>2]|0;if((e|0)==0){i=k;return}yt(e);i=k;return}}while(0);l=m-n|0;n=l>>2;do{if((l|0)>0){if((ga[c[(c[d>>2]|0)+48>>2]&127](d,f,n)|0)==(n|0)){break}c[b>>2]=0;i=k;return}}while(0);c[o>>2]=0;c[b>>2]=d;i=k;return}function uN(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+136|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+112|0;n=d+120|0;o=d+128|0;p=j|0;a[p]=a[55784]|0;a[p+1|0]=a[55785|0]|0;a[p+2|0]=a[55786|0]|0;a[p+3|0]=a[55787|0]|0;a[p+4|0]=a[55788|0]|0;a[p+5|0]=a[55789|0]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==64){a[t]=111}else if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else{a[t]=117}}while(0);t=k|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);s=uv(t,12,c[141570]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+s|0;h=c[r>>2]&176;do{if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((s|0)>1&r<<24>>24==48)){w=6296;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=6296;break}v=k+2|0}else if((h|0)==32){v=p}else{w=6296}}while(0);if((w|0)==6296){v=t}w=l|0;l=o|0;h=c[f+28>>2]|0;c[l>>2]=h;k=h+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;uL(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;uM(b,y,w,z,A,f,g);i=d;return}f2[c[(c[o>>2]|0)+8>>2]&1023](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;uM(b,y,w,z,A,f,g);i=d;return}function uO(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+232|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+208|0;o=d+216|0;p=d+224|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=117}}while(0);t=l|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);u=uv(t,23,c[141570]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+u|0;j=c[r>>2]&176;do{if((j|0)==32){v=q}else if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=6327;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=6327;break}v=l+2|0}else{w=6327}}while(0);if((w|0)==6327){v=t}w=m|0;m=p|0;l=c[f+28>>2]|0;c[m>>2]=l;u=l+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;uL(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;uM(b,y,w,z,A,f,g);i=d;return}f2[c[(c[p>>2]|0)+8>>2]&1023](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;uM(b,y,w,z,A,f,g);i=d;return}function uP(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+312|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+280|0;p=d+288|0;q=d+296|0;r=d+304|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){if((k&1|0)==0){a[w]=97;x=0;break}else{a[w]=65;x=0;break}}else{a[w]=46;u=w+2|0;a[w+1|0]=42;if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=c[141570]|0;if(x){v=uv(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=uv(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[741360]|0)==0;if(x){do{if(v){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=uC(m,c[141570]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);v=uC(m,c[141570]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=ff(4)|0;c[v>>2]=72440;dr(v|0,79056,316)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==32){E=m}else if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=6389;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=6389;break}E=D+2|0}else{F=6389}}while(0);if((F|0)==6389){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=ys(B<<3)|0;z=F;if((F|0)!=0){G=z;H=z;J=D;break}z=ff(4)|0;c[z>>2]=72440;dr(z|0,79056,316)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;uQ(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){f2[c[(c[q>>2]|0)+8>>2]&1023](q|0)}q=e|0;uM(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){yt(H)}if((C|0)==0){i=d;return}yt(C);i=d;return}function uQ(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[185168]|0)!=-1){c[n>>2]=740672;c[n+4>>2]=210;c[n+8>>2]=0;st(740672,n)}n=(c[185169]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=ff(4)|0;s=r;c[s>>2]=72472;dr(r|0,79072,408)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=ff(4)|0;s=r;c[s>>2]=72472;dr(r|0,79072,408)}r=k;s=c[p>>2]|0;if((c[185072]|0)!=-1){c[m>>2]=740288;c[m+4>>2]=210;c[m+8>>2]=0;st(740288,m)}m=(c[185073]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=ff(4)|0;u=t;c[u>>2]=72472;dr(t|0,79072,408)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=ff(4)|0;u=t;c[u>>2]=72472;dr(t|0,79072,408)}t=s;f3[c[(c[s>>2]|0)+20>>2]&1023](o,t);c[j>>2]=g;u=a[b]|0;if((u<<24>>24|0)==45|(u<<24>>24|0)==43){m=gm[c[(c[k>>2]|0)+44>>2]&127](r,u)|0;u=c[j>>2]|0;c[j>>2]=u+4;c[u>>2]=m;v=b+1|0}else{v=b}m=f;L7207:do{if((m-v|0)>1){if((a[v]|0)!=48){w=v;x=6449;break}u=v+1|0;p=a[u]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){w=v;x=6449;break}p=k;n=gm[c[(c[p>>2]|0)+44>>2]&127](r,48)|0;q=c[j>>2]|0;c[j>>2]=q+4;c[q>>2]=n;n=v+2|0;q=gm[c[(c[p>>2]|0)+44>>2]&127](r,a[u]|0)|0;u=c[j>>2]|0;c[j>>2]=u+4;c[u>>2]=q;q=n;while(1){if(q>>>0>=f>>>0){y=q;z=n;break L7207}u=a[q]|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);if((a8(u<<24>>24|0,c[141570]|0)|0)==0){y=q;z=n;break}else{q=q+1|0}}}else{w=v;x=6449}}while(0);L7222:do{if((x|0)==6449){while(1){x=0;if(w>>>0>=f>>>0){y=w;z=v;break L7222}q=a[w]|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);if((eW(q<<24>>24|0,c[141570]|0)|0)==0){y=w;z=v;break}else{w=w+1|0;x=6449}}}}while(0);x=o;w=o;v=d[w]|0;if((v&1|0)==0){A=v>>>1}else{A=c[o+4>>2]|0}do{if((A|0)==0){v=c[j>>2]|0;u=c[(c[k>>2]|0)+48>>2]|0;gq[u&31](r,z,y,v)|0;c[j>>2]=(c[j>>2]|0)+(y-z<<2)}else{do{if((z|0)!=(y|0)){v=y-1|0;if(z>>>0<v>>>0){B=z;C=v}else{break}do{v=a[B]|0;a[B]=a[C]|0;a[C]=v;B=B+1|0;C=C-1|0;}while(B>>>0<C>>>0)}}while(0);q=f5[c[(c[s>>2]|0)+16>>2]&255](t)|0;if(z>>>0<y>>>0){v=x+1|0;u=o+4|0;n=o+8|0;p=k;D=0;E=0;F=z;while(1){G=a[((a[w]&1)==0?v:c[n>>2]|0)+E|0]|0;if(G<<24>>24>0&(D|0)==(G<<24>>24|0)){G=c[j>>2]|0;c[j>>2]=G+4;c[G>>2]=q;G=d[w]|0;H=(E>>>0<(((G&1|0)==0?G>>>1:c[u>>2]|0)-1|0)>>>0)+E|0;I=0}else{H=E;I=D}G=gm[c[(c[p>>2]|0)+44>>2]&127](r,a[F]|0)|0;J=c[j>>2]|0;c[j>>2]=J+4;c[J>>2]=G;G=F+1|0;if(G>>>0<y>>>0){D=I+1|0;E=H;F=G}else{break}}}F=g+(z-b<<2)|0;E=c[j>>2]|0;if((F|0)==(E|0)){break}D=E-4|0;if(F>>>0<D>>>0){K=F;L=D}else{break}do{D=c[K>>2]|0;c[K>>2]=c[L>>2];c[L>>2]=D;K=K+4|0;L=L-4|0;}while(K>>>0<L>>>0)}}while(0);L7260:do{if(y>>>0<f>>>0){L=k;K=y;while(1){z=a[K]|0;if(z<<24>>24==46){break}H=gm[c[(c[L>>2]|0)+44>>2]&127](r,z)|0;z=c[j>>2]|0;c[j>>2]=z+4;c[z>>2]=H;H=K+1|0;if(H>>>0<f>>>0){K=H}else{M=H;break L7260}}L=f5[c[(c[s>>2]|0)+12>>2]&255](t)|0;H=c[j>>2]|0;c[j>>2]=H+4;c[H>>2]=L;M=K+1|0}else{M=y}}while(0);gq[c[(c[k>>2]|0)+48>>2]&31](r,M,f,c[j>>2]|0)|0;r=(c[j>>2]|0)+(m-M<<2)|0;c[j>>2]=r;if((e|0)==(f|0)){N=r}else{N=g+(e-b<<2)|0}c[h>>2]=N;if((a[w]&1)==0){i=l;return}w=c[o+8>>2]|0;if((w|0)==0){i=l;return}yt(w);i=l;return}function uR(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+312|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+280|0;p=d+288|0;q=d+296|0;r=d+304|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){a[w]=76;u=w+1|0;if((k&1|0)==0){a[u]=97;x=0;break}else{a[u]=65;x=0;break}}else{a[w]=46;a[w+1|0]=42;a[w+2|0]=76;u=w+3|0;if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=c[141570]|0;if(x){v=uv(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=uv(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[741360]|0)==0;if(x){do{if(v){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);l=uC(m,c[141570]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);v=uC(m,c[141570]|0,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=ff(4)|0;c[v>>2]=72440;dr(v|0,79056,316)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=6549;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=6549;break}E=D+2|0}else if((z|0)==32){E=m}else{F=6549}}while(0);if((F|0)==6549){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=ys(B<<3)|0;z=F;if((F|0)!=0){G=z;H=z;J=D;break}z=ff(4)|0;c[z>>2]=72440;dr(z|0,79056,316)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;uQ(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){f2[c[(c[q>>2]|0)+8>>2]&1023](q|0)}q=e|0;uM(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){yt(H)}if((C|0)==0){i=d;return}yt(C);i=d;return}function uS(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+200|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+24|0;l=d+48|0;m=d+16|0;a[m]=a[55792]|0;a[m+1|0]=a[55793|0]|0;a[m+2|0]=a[55794|0]|0;a[m+3|0]=a[55795|0]|0;a[m+4|0]=a[55796|0]|0;a[m+5|0]=a[55797|0]|0;n=k|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);o=uv(n,20,c[141570]|0,m,(m=i,i=i+8|0,c[m>>2]=h,m)|0)|0;i=m;m=k+o|0;h=c[f+4>>2]&176;do{if((h|0)==32){p=m}else if((h|0)==16){q=a[n]|0;if((q<<24>>24|0)==45|(q<<24>>24|0)==43){p=k+1|0;break}if(!((o|0)>1&q<<24>>24==48)){r=6584;break}q=a[k+1|0]|0;if(!((q<<24>>24|0)==120|(q<<24>>24|0)==88)){r=6584;break}p=k+2|0}else{r=6584}}while(0);if((r|0)==6584){p=n}r=c[f+28>>2]|0;h=r+4|0;I=c[h>>2]|0,c[h>>2]=I+1,I;if((c[185168]|0)!=-1){c[j>>2]=740672;c[j+4>>2]=210;c[j+8>>2]=0;st(740672,j)}j=(c[185169]|0)-1|0;q=c[r+8>>2]|0;do{if((c[r+12>>2]|0)-q>>2>>>0>j>>>0){s=c[q+(j<<2)>>2]|0;if((s|0)==0){break}t=s;if(((I=c[h>>2]|0,c[h>>2]=I+ -1,I)|0)==0){f2[c[(c[r>>2]|0)+8>>2]&1023](r)}u=l|0;v=c[(c[s>>2]|0)+48>>2]|0;gq[v&31](t,n,m,u)|0;t=l+(o<<2)|0;if((p|0)==(m|0)){w=t;x=e|0;y=c[x>>2]|0;uM(b,y,u,w,t,f,g);i=d;return}w=l+(p-k<<2)|0;x=e|0;y=c[x>>2]|0;uM(b,y,u,w,t,f,g);i=d;return}}while(0);d=ff(4)|0;c[d>>2]=72472;dr(d|0,79072,408)}function uT(a){a=a|0;return}function uU(a){a=a|0;return 2}function uV(a){a=a|0;if((a|0)==0){return}yt(a);return}function uW(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];uY(a,b,c[d>>2]|0,c[e>>2]|0,f,g,h,55776,55784);i=j;return}function uX(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d+8|0;m=f5[c[(c[l>>2]|0)+20>>2]&255](l)|0;l=a[m]|0;if((l&1)==0){n=m+1|0}else{n=c[m+8>>2]|0}o=l&255;if((o&1|0)==0){p=o>>>1}else{p=c[m+4>>2]|0}uY(b,d,c[e>>2]|0,c[f>>2]|0,g,h,j,n,n+p|0);i=k;return}function uY(d,e,f,g,h,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;n=i;i=i+40|0;o=n|0;p=n+16|0;q=n+24|0;r=n+32|0;s=c[h+28>>2]|0;t=s+4|0;I=c[t>>2]|0,c[t>>2]=I+1,I;if((c[185170]|0)!=-1){c[o>>2]=740680;c[o+4>>2]=210;c[o+8>>2]=0;st(740680,o)}o=(c[185171]|0)-1|0;u=c[s+8>>2]|0;do{if((c[s+12>>2]|0)-u>>2>>>0>o>>>0){v=c[u+(o<<2)>>2]|0;if((v|0)==0){break}w=v;if(((I=c[t>>2]|0,c[t>>2]=I+ -1,I)|0)==0){f2[c[(c[s>>2]|0)+8>>2]&1023](s)}c[j>>2]=0;L27:do{if((l|0)==(m|0)){x=f;y=f;z=g}else{A=v;B=v+8|0;C=v;D=e;E=q|0;F=r|0;G=p|0;H=l;J=f;K=g;L29:while(1){do{if((J|0)==0){L=0}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){L=J;break}L=(f5[c[(c[J>>2]|0)+36>>2]&255](J)|0)==-1?0:J}}while(0);M=(L|0)==0;do{if((K|0)==0){N=33}else{if((c[K+12>>2]|0)==(c[K+16>>2]|0)){if((f5[c[(c[K>>2]|0)+36>>2]&255](K)|0)==-1){N=33;break}}if(M){O=K}else{P=L;Q=K;N=34;break L29}}}while(0);if((N|0)==33){N=0;if(M){P=0;Q=0;N=34;break}else{O=0}}L43:do{if((ga[c[(c[A>>2]|0)+36>>2]&127](w,a[H]|0,0)|0)<<24>>24==37){R=H+1|0;if((R|0)==(m|0)){N=40;break L29}S=ga[c[(c[A>>2]|0)+36>>2]&127](w,a[R]|0,0)|0;if((S<<24>>24|0)==69|(S<<24>>24|0)==48){T=H+2|0;if((T|0)==(m|0)){N=43;break L29}U=S;V=ga[c[(c[A>>2]|0)+36>>2]&127](w,a[T]|0,0)|0;W=T}else{U=0;V=S;W=R}R=c[(c[D>>2]|0)+36>>2]|0;c[E>>2]=L;c[F>>2]=O;gk[R&15](p,e,q,r,h,j,k,V,U);X=W+1|0;Y=c[G>>2]|0;Z=O}else{R=a[H]|0;do{if(R<<24>>24>-1){S=c[B>>2]|0;if((b[S+(R<<24>>24<<1)>>1]&8192)==0){break}else{_=H}while(1){T=_+1|0;if((T|0)==(m|0)){$=m;break}aa=a[T]|0;if(aa<<24>>24<=-1){$=T;break}if((b[S+(aa<<24>>24<<1)>>1]&8192)==0){$=T;break}else{_=T}}S=L;T=O;aa=L;ab=O;while(1){do{if((S|0)==0){ac=0;ad=aa}else{if((c[S+12>>2]|0)!=(c[S+16>>2]|0)){ac=S;ad=aa;break}ae=(f5[c[(c[S>>2]|0)+36>>2]&255](S)|0)==-1;ac=ae?0:S;ad=ae?0:aa}}while(0);ae=(ac|0)==0;do{if((T|0)==0){af=ab;N=61}else{if((c[T+12>>2]|0)!=(c[T+16>>2]|0)){if(ae){ag=T;ah=ab;break}else{X=$;Y=ad;Z=ab;break L43}}if((f5[c[(c[T>>2]|0)+36>>2]&255](T)|0)==-1){af=0;N=61;break}if(ae){ag=T;ah=ab}else{X=$;Y=ad;Z=ab;break L43}}}while(0);if((N|0)==61){N=0;if(ae){X=$;Y=ad;Z=af;break L43}else{ag=0;ah=af}}ai=ac+12|0;aj=c[ai>>2]|0;ak=ac+16|0;if((aj|0)==(c[ak>>2]|0)){al=(f5[c[(c[ac>>2]|0)+36>>2]&255](ac)|0)&255}else{al=a[aj]|0}if(al<<24>>24<=-1){X=$;Y=ad;Z=ah;break L43}if((b[(c[B>>2]|0)+(al<<24>>24<<1)>>1]&8192)==0){X=$;Y=ad;Z=ah;break L43}aj=c[ai>>2]|0;if((aj|0)==(c[ak>>2]|0)){ak=c[(c[ac>>2]|0)+40>>2]|0;f5[ak&255](ac)|0;S=ac;T=ag;aa=ad;ab=ah;continue}else{c[ai>>2]=aj+1;S=ac;T=ag;aa=ad;ab=ah;continue}}}}while(0);R=L+12|0;ab=c[R>>2]|0;aa=L+16|0;if((ab|0)==(c[aa>>2]|0)){am=(f5[c[(c[L>>2]|0)+36>>2]&255](L)|0)&255}else{am=a[ab]|0}ab=gm[c[(c[C>>2]|0)+12>>2]&127](w,am)|0;if(ab<<24>>24!=(gm[c[(c[C>>2]|0)+12>>2]&127](w,a[H]|0)|0)<<24>>24){N=79;break L29}ab=c[R>>2]|0;if((ab|0)==(c[aa>>2]|0)){aa=c[(c[L>>2]|0)+40>>2]|0;f5[aa&255](L)|0}else{c[R>>2]=ab+1}X=H+1|0;Y=L;Z=O}}while(0);if((X|0)==(m|0)){x=Y;y=Y;z=Z;break L27}if((c[j>>2]|0)==0){H=X;J=Y;K=Z}else{x=Y;y=Y;z=Z;break L27}}if((N|0)==34){c[j>>2]=4;x=P;y=L;z=Q;break}else if((N|0)==40){c[j>>2]=4;x=L;y=L;z=O;break}else if((N|0)==43){c[j>>2]=4;x=L;y=L;z=O;break}else if((N|0)==79){c[j>>2]=4;x=L;y=L;z=O;break}}}while(0);do{if((x|0)==0){an=y}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){an=y;break}an=(f5[c[(c[x>>2]|0)+36>>2]&255](x)|0)==-1?0:y}}while(0);w=(an|0)==0;do{if((z|0)==0){N=87}else{if((c[z+12>>2]|0)==(c[z+16>>2]|0)){if((f5[c[(c[z>>2]|0)+36>>2]&255](z)|0)==-1){N=87;break}}if(!w){break}ao=d|0;c[ao>>2]=an;i=n;return}}while(0);do{if((N|0)==87){if(w){break}ao=d|0;c[ao>>2]=an;i=n;return}}while(0);c[j>>2]=c[j>>2]|2;ao=d|0;c[ao>>2]=an;i=n;return}}while(0);n=ff(4)|0;c[n>>2]=72472;dr(n|0,79072,408)}function uZ(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[185170]|0)!=-1){c[k>>2]=740680;c[k+4>>2]=210;c[k+8>>2]=0;st(740680,k)}k=(c[185171]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f2[c[(c[l>>2]|0)+8>>2]&1023](l)}o=c[e>>2]|0;p=b+8|0;q=f5[c[c[p>>2]>>2]&255](p)|0;p=(tL(d,o,q,q+168|0,n,g,0)|0)-q|0;if((p|0)>=168){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+24>>2]=((p|0)/12|0|0)%7|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=ff(4)|0;c[j>>2]=72472;dr(j|0,79072,408)}function u_(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[185170]|0)!=-1){c[k>>2]=740680;c[k+4>>2]=210;c[k+8>>2]=0;st(740680,k)}k=(c[185171]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f2[c[(c[l>>2]|0)+8>>2]&1023](l)}o=c[e>>2]|0;p=b+8|0;q=f5[c[(c[p>>2]|0)+4>>2]&255](p)|0;p=(tL(d,o,q,q+288|0,n,g,0)|0)-q|0;if((p|0)>=288){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+16>>2]=((p|0)/12|0|0)%12|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=ff(4)|0;c[j>>2]=72472;dr(j|0,79072,408)}function u$(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+16|0;j=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[j>>2];j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=b|0;k=c[f+28>>2]|0;f=k+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[185170]|0)!=-1){c[j>>2]=740680;c[j+4>>2]=210;c[j+8>>2]=0;st(740680,j)}j=(c[185171]|0)-1|0;l=c[k+8>>2]|0;do{if((c[k+12>>2]|0)-l>>2>>>0>j>>>0){m=c[l+(j<<2)>>2]|0;if((m|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f2[c[(c[k>>2]|0)+8>>2]&1023](k)}n=u3(d,c[e>>2]|0,g,m,4)|0;if((c[g>>2]&4|0)!=0){o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}if((n|0)<69){r=n+2e3|0}else{r=(n-69|0)>>>0<31?n+1900|0:n}c[h+20>>2]=r-1900;o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}}while(0);b=ff(4)|0;c[b>>2]=72472;dr(b|0,79072,408)}function u0(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;n=i;i=i+88|0;o=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[o>>2];o=h;h=i;i=i+4|0;i=i+7>>3<<3;c[h>>2]=c[o>>2];o=n|0;p=n+16|0;q=n+24|0;r=n+32|0;s=n+40|0;t=n+48|0;u=n+56|0;v=n+64|0;w=n+72|0;x=n+80|0;c[k>>2]=0;y=c[j+28>>2]|0;z=y+4|0;I=c[z>>2]|0,c[z>>2]=I+1,I;if((c[185170]|0)!=-1){c[o>>2]=740680;c[o+4>>2]=210;c[o+8>>2]=0;st(740680,o)}o=(c[185171]|0)-1|0;A=c[y+8>>2]|0;do{if((c[y+12>>2]|0)-A>>2>>>0>o>>>0){B=c[A+(o<<2)>>2]|0;if((B|0)==0){break}C=B;if(((I=c[z>>2]|0,c[z>>2]=I+ -1,I)|0)==0){f2[c[(c[y>>2]|0)+8>>2]&1023](y)}L179:do{switch(m<<24>>24|0){case 73:{D=l+8|0;E=u3(g,c[h>>2]|0,k,C,2)|0;F=c[k>>2]|0;do{if((F&4|0)==0){if((E-1|0)>>>0>=12){break}c[D>>2]=E;break L179}}while(0);c[k>>2]=F|4;break};case 106:{E=u3(g,c[h>>2]|0,k,C,3)|0;D=c[k>>2]|0;if((D&4|0)==0&(E|0)<366){c[l+28>>2]=E;break L179}else{c[k>>2]=D|4;break L179}break};case 109:{D=(u3(g,c[h>>2]|0,k,C,2)|0)-1|0;E=c[k>>2]|0;if((E&4|0)==0&(D|0)<12){c[l+16>>2]=D;break L179}else{c[k>>2]=E|4;break L179}break};case 77:{E=u3(g,c[h>>2]|0,k,C,2)|0;D=c[k>>2]|0;if((D&4|0)==0&(E|0)<60){c[l+4>>2]=E;break L179}else{c[k>>2]=D|4;break L179}break};case 110:case 116:{D=g|0;E=B+8|0;G=c[h>>2]|0;L198:while(1){H=c[D>>2]|0;do{if((H|0)==0){J=0}else{if((c[H+12>>2]|0)!=(c[H+16>>2]|0)){J=H;break}if((f5[c[(c[H>>2]|0)+36>>2]&255](H)|0)==-1){c[D>>2]=0;J=0;break}else{J=c[D>>2]|0;break}}}while(0);H=(J|0)==0;do{if((G|0)==0){K=199}else{if((c[G+12>>2]|0)==(c[G+16>>2]|0)){if((f5[c[(c[G>>2]|0)+36>>2]&255](G)|0)==-1){K=199;break}}if(H){L=0;M=G}else{N=G;O=0;break L198}}}while(0);if((K|0)==199){K=0;if(H){N=0;O=1;break}else{L=1;M=0}}P=c[D>>2]|0;Q=c[P+12>>2]|0;if((Q|0)==(c[P+16>>2]|0)){R=(f5[c[(c[P>>2]|0)+36>>2]&255](P)|0)&255}else{R=a[Q]|0}if(R<<24>>24<=-1){N=M;O=L;break}if((b[(c[E>>2]|0)+(R<<24>>24<<1)>>1]&8192)==0){N=M;O=L;break}Q=c[D>>2]|0;P=Q+12|0;S=c[P>>2]|0;if((S|0)==(c[Q+16>>2]|0)){T=c[(c[Q>>2]|0)+40>>2]|0;f5[T&255](Q)|0;G=M;continue}else{c[P>>2]=S+1;G=M;continue}}G=c[D>>2]|0;do{if((G|0)==0){U=0}else{if((c[G+12>>2]|0)!=(c[G+16>>2]|0)){U=G;break}if((f5[c[(c[G>>2]|0)+36>>2]&255](G)|0)==-1){c[D>>2]=0;U=0;break}else{U=c[D>>2]|0;break}}}while(0);D=(U|0)==0;do{if(O){K=217}else{if((c[N+12>>2]|0)!=(c[N+16>>2]|0)){if(D^(N|0)==0){break L179}else{break}}if((f5[c[(c[N>>2]|0)+36>>2]&255](N)|0)==-1){K=217;break}if(D){break L179}}}while(0);if((K|0)==217){if(!D){break L179}}c[k>>2]=c[k>>2]|2;break};case 112:{G=l+8|0;E=c[h>>2]|0;F=f+8|0;S=f5[c[(c[F>>2]|0)+8>>2]&255](F)|0;F=d[S]|0;if((F&1|0)==0){V=F>>>1}else{V=c[S+4>>2]|0}F=d[S+12|0]|0;if((F&1|0)==0){W=F>>>1}else{W=c[S+16>>2]|0}if((V|0)==(-W|0)){c[k>>2]=c[k>>2]|4;break L179}F=tL(g,E,S,S+24|0,C,k,0)|0;E=F-S|0;do{if((F|0)==(S|0)){if((c[G>>2]|0)!=12){break}c[G>>2]=0;break L179}}while(0);if((E|0)!=12){break L179}S=c[G>>2]|0;if((S|0)>=12){break L179}c[G>>2]=S+12;break};case 114:{S=g|0;uY(s,f,c[S>>2]|0,c[h>>2]|0,j,k,l,55744,55755);c[S>>2]=c[s>>2];break};case 82:{S=g|0;uY(t,f,c[S>>2]|0,c[h>>2]|0,j,k,l,55736,55741);c[S>>2]=c[t>>2];break};case 83:{S=u3(g,c[h>>2]|0,k,C,2)|0;F=c[k>>2]|0;if((F&4|0)==0&(S|0)<61){c[l>>2]=S;break L179}else{c[k>>2]=F|4;break L179}break};case 84:{F=g|0;uY(u,f,c[F>>2]|0,c[h>>2]|0,j,k,l,55728,55736);c[F>>2]=c[u>>2];break};case 119:{F=u3(g,c[h>>2]|0,k,C,1)|0;S=c[k>>2]|0;if((S&4|0)==0&(F|0)<7){c[l+24>>2]=F;break L179}else{c[k>>2]=S|4;break L179}break};case 120:{S=c[(c[f>>2]|0)+20>>2]|0;c[v>>2]=c[g>>2];c[w>>2]=c[h>>2];gi[S&127](e,f,v,w,j,k,l);i=n;return};case 88:{S=f+8|0;F=f5[c[(c[S>>2]|0)+24>>2]&255](S)|0;S=g|0;D=a[F]|0;if((D&1)==0){X=F+1|0}else{X=c[F+8>>2]|0}P=D&255;if((P&1|0)==0){Y=P>>>1}else{Y=c[F+4>>2]|0}uY(x,f,c[S>>2]|0,c[h>>2]|0,j,k,l,X,X+Y|0);c[S>>2]=c[x>>2];break};case 121:{S=u3(g,c[h>>2]|0,k,C,4)|0;if((c[k>>2]&4|0)!=0){break L179}if((S|0)<69){Z=S+2e3|0}else{Z=(S-69|0)>>>0<31?S+1900|0:S}c[l+20>>2]=Z-1900;break};case 99:{S=f+8|0;F=f5[c[(c[S>>2]|0)+12>>2]&255](S)|0;S=g|0;P=a[F]|0;if((P&1)==0){_=F+1|0}else{_=c[F+8>>2]|0}D=P&255;if((D&1|0)==0){$=D>>>1}else{$=c[F+4>>2]|0}uY(p,f,c[S>>2]|0,c[h>>2]|0,j,k,l,_,_+$|0);c[S>>2]=c[p>>2];break};case 100:case 101:{S=l+12|0;F=u3(g,c[h>>2]|0,k,C,2)|0;D=c[k>>2]|0;do{if((D&4|0)==0){if((F-1|0)>>>0>=31){break}c[S>>2]=F;break L179}}while(0);c[k>>2]=D|4;break};case 68:{F=g|0;uY(q,f,c[F>>2]|0,c[h>>2]|0,j,k,l,55768,55776);c[F>>2]=c[q>>2];break};case 70:{F=g|0;uY(r,f,c[F>>2]|0,c[h>>2]|0,j,k,l,55760,55768);c[F>>2]=c[r>>2];break};case 72:{F=u3(g,c[h>>2]|0,k,C,2)|0;S=c[k>>2]|0;if((S&4|0)==0&(F|0)<24){c[l+8>>2]=F;break L179}else{c[k>>2]=S|4;break L179}break};case 97:case 65:{S=c[h>>2]|0;F=f+8|0;G=f5[c[c[F>>2]>>2]&255](F)|0;F=(tL(g,S,G,G+168|0,C,k,0)|0)-G|0;if((F|0)>=168){break L179}c[l+24>>2]=((F|0)/12|0|0)%7|0;break};case 98:case 66:case 104:{F=c[h>>2]|0;G=f+8|0;S=f5[c[(c[G>>2]|0)+4>>2]&255](G)|0;G=(tL(g,F,S,S+288|0,C,k,0)|0)-S|0;if((G|0)>=288){break L179}c[l+16>>2]=((G|0)/12|0|0)%12|0;break};case 89:{G=u3(g,c[h>>2]|0,k,C,4)|0;if((c[k>>2]&4|0)!=0){break L179}c[l+20>>2]=G-1900;break};case 37:{G=c[h>>2]|0;S=g|0;F=c[S>>2]|0;do{if((F|0)==0){aa=0}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){aa=F;break}if((f5[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[S>>2]=0;aa=0;break}else{aa=c[S>>2]|0;break}}}while(0);F=(aa|0)==0;do{if((G|0)==0){K=267}else{if((c[G+12>>2]|0)==(c[G+16>>2]|0)){if((f5[c[(c[G>>2]|0)+36>>2]&255](G)|0)==-1){K=267;break}}if(F){ab=G;ac=0}else{K=268}}}while(0);if((K|0)==267){if(F){K=268}else{ab=0;ac=1}}if((K|0)==268){c[k>>2]=c[k>>2]|6;break L179}G=c[S>>2]|0;D=c[G+12>>2]|0;if((D|0)==(c[G+16>>2]|0)){ad=(f5[c[(c[G>>2]|0)+36>>2]&255](G)|0)&255}else{ad=a[D]|0}if((ga[c[(c[B>>2]|0)+36>>2]&127](C,ad,0)|0)<<24>>24!=37){c[k>>2]=c[k>>2]|4;break L179}D=c[S>>2]|0;G=D+12|0;E=c[G>>2]|0;if((E|0)==(c[D+16>>2]|0)){P=c[(c[D>>2]|0)+40>>2]|0;f5[P&255](D)|0}else{c[G>>2]=E+1}E=c[S>>2]|0;do{if((E|0)==0){ae=0}else{if((c[E+12>>2]|0)!=(c[E+16>>2]|0)){ae=E;break}if((f5[c[(c[E>>2]|0)+36>>2]&255](E)|0)==-1){c[S>>2]=0;ae=0;break}else{ae=c[S>>2]|0;break}}}while(0);S=(ae|0)==0;do{if(ac){K=286}else{if((c[ab+12>>2]|0)!=(c[ab+16>>2]|0)){if(S^(ab|0)==0){break L179}else{break}}if((f5[c[(c[ab>>2]|0)+36>>2]&255](ab)|0)==-1){K=286;break}if(S){break L179}}}while(0);if((K|0)==286){if(!S){break L179}}c[k>>2]=c[k>>2]|2;break};default:{c[k>>2]=c[k>>2]|4}}}while(0);c[e>>2]=c[g>>2];i=n;return}}while(0);n=ff(4)|0;c[n>>2]=72472;dr(n|0,79072,408)}function u1(a){a=a|0;return}function u2(a){a=a|0;return 2}function u3(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=d|0;d=c[i>>2]|0;do{if((d|0)==0){j=0}else{if((c[d+12>>2]|0)!=(c[d+16>>2]|0)){j=d;break}if((f5[c[(c[d>>2]|0)+36>>2]&255](d)|0)==-1){c[i>>2]=0;j=0;break}else{j=c[i>>2]|0;break}}}while(0);d=(j|0)==0;do{if((e|0)==0){k=305}else{if((c[e+12>>2]|0)==(c[e+16>>2]|0)){if((f5[c[(c[e>>2]|0)+36>>2]&255](e)|0)==-1){k=305;break}}if(d){l=e}else{k=306}}}while(0);if((k|0)==305){if(d){k=306}else{l=0}}if((k|0)==306){c[f>>2]=c[f>>2]|6;m=0;return m|0}d=c[i>>2]|0;e=c[d+12>>2]|0;if((e|0)==(c[d+16>>2]|0)){n=(f5[c[(c[d>>2]|0)+36>>2]&255](d)|0)&255}else{n=a[e]|0}do{if(n<<24>>24>-1){e=g+8|0;if((b[(c[e>>2]|0)+(n<<24>>24<<1)>>1]&2048)==0){break}d=g;j=(ga[c[(c[d>>2]|0)+36>>2]&127](g,n,0)|0)<<24>>24;o=c[i>>2]|0;p=o+12|0;q=c[p>>2]|0;if((q|0)==(c[o+16>>2]|0)){r=c[(c[o>>2]|0)+40>>2]|0;f5[r&255](o)|0;s=j;t=h;u=l}else{c[p>>2]=q+1;s=j;t=h;u=l}while(1){v=s-48|0;j=t-1|0;q=c[i>>2]|0;do{if((q|0)==0){w=0}else{if((c[q+12>>2]|0)!=(c[q+16>>2]|0)){w=q;break}if((f5[c[(c[q>>2]|0)+36>>2]&255](q)|0)==-1){c[i>>2]=0;w=0;break}else{w=c[i>>2]|0;break}}}while(0);q=(w|0)==0;if((u|0)==0){x=w;y=0}else{if((c[u+12>>2]|0)==(c[u+16>>2]|0)){z=(f5[c[(c[u>>2]|0)+36>>2]&255](u)|0)==-1?0:u}else{z=u}x=c[i>>2]|0;y=z}A=(y|0)==0;if(!((q^A)&(j|0)>0)){k=334;break}q=c[x+12>>2]|0;if((q|0)==(c[x+16>>2]|0)){B=(f5[c[(c[x>>2]|0)+36>>2]&255](x)|0)&255}else{B=a[q]|0}if(B<<24>>24<=-1){m=v;k=346;break}if((b[(c[e>>2]|0)+(B<<24>>24<<1)>>1]&2048)==0){m=v;k=347;break}q=((ga[c[(c[d>>2]|0)+36>>2]&127](g,B,0)|0)<<24>>24)+(v*10|0)|0;p=c[i>>2]|0;o=p+12|0;r=c[o>>2]|0;if((r|0)==(c[p+16>>2]|0)){C=c[(c[p>>2]|0)+40>>2]|0;f5[C&255](p)|0;s=q;t=j;u=y;continue}else{c[o>>2]=r+1;s=q;t=j;u=y;continue}}if((k|0)==334){do{if((x|0)==0){D=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){D=x;break}if((f5[c[(c[x>>2]|0)+36>>2]&255](x)|0)==-1){c[i>>2]=0;D=0;break}else{D=c[i>>2]|0;break}}}while(0);d=(D|0)==0;do{if(A){k=343}else{if((c[y+12>>2]|0)==(c[y+16>>2]|0)){if((f5[c[(c[y>>2]|0)+36>>2]&255](y)|0)==-1){k=343;break}}if(d){m=v}else{break}return m|0}}while(0);do{if((k|0)==343){if(d){break}else{m=v}return m|0}}while(0);c[f>>2]=c[f>>2]|2;m=v;return m|0}else if((k|0)==346){return m|0}else if((k|0)==347){return m|0}}}while(0);c[f>>2]=c[f>>2]|4;m=0;return m|0}function u4(a){a=a|0;if((a|0)==0){return}yt(a);return}function u5(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];u7(a,b,c[d>>2]|0,c[e>>2]|0,f,g,h,55696,55728);i=j;return}function u6(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d+8|0;m=f5[c[(c[l>>2]|0)+20>>2]&255](l)|0;l=a[m]|0;if((l&1)==0){n=m+4|0}else{n=c[m+8>>2]|0}o=l&255;if((o&1|0)==0){p=o>>>1}else{p=c[m+4>>2]|0}u7(b,d,c[e>>2]|0,c[f>>2]|0,g,h,j,n,n+(p<<2)|0);i=k;return}function u7(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;l=i;i=i+40|0;m=l|0;n=l+16|0;o=l+24|0;p=l+32|0;q=c[f+28>>2]|0;r=q+4|0;I=c[r>>2]|0,c[r>>2]=I+1,I;if((c[185168]|0)!=-1){c[m>>2]=740672;c[m+4>>2]=210;c[m+8>>2]=0;st(740672,m)}m=(c[185169]|0)-1|0;s=c[q+8>>2]|0;do{if((c[q+12>>2]|0)-s>>2>>>0>m>>>0){t=c[s+(m<<2)>>2]|0;if((t|0)==0){break}u=t;if(((I=c[r>>2]|0,c[r>>2]=I+ -1,I)|0)==0){f2[c[(c[q>>2]|0)+8>>2]&1023](q)}c[g>>2]=0;L468:do{if((j|0)==(k|0)){v=d;w=d;x=e}else{y=t;z=t;A=t;B=b;C=o|0;D=p|0;E=n|0;F=j;G=d;H=e;L470:while(1){if((G|0)==0){J=0}else{K=c[G+12>>2]|0;if((K|0)==(c[G+16>>2]|0)){L=f5[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{L=c[K>>2]|0}J=(L|0)==-1?0:G}K=(J|0)==0;do{if((H|0)==0){M=386}else{N=c[H+12>>2]|0;if((N|0)==(c[H+16>>2]|0)){O=f5[c[(c[H>>2]|0)+36>>2]&255](H)|0}else{O=c[N>>2]|0}if((O|0)==-1){M=386;break}if(K){P=H}else{Q=J;R=H;M=388;break L470}}}while(0);if((M|0)==386){M=0;if(K){Q=0;R=0;M=388;break}else{P=0}}L489:do{if((ga[c[(c[y>>2]|0)+52>>2]&127](u,c[F>>2]|0,0)|0)<<24>>24==37){N=F+4|0;if((N|0)==(k|0)){M=394;break L470}S=ga[c[(c[y>>2]|0)+52>>2]&127](u,c[N>>2]|0,0)|0;if((S<<24>>24|0)==69|(S<<24>>24|0)==48){T=F+8|0;if((T|0)==(k|0)){M=397;break L470}U=S;V=ga[c[(c[y>>2]|0)+52>>2]&127](u,c[T>>2]|0,0)|0;W=T}else{U=0;V=S;W=N}N=c[(c[B>>2]|0)+36>>2]|0;c[C>>2]=J;c[D>>2]=P;gk[N&15](n,b,o,p,f,g,h,V,U);X=W+4|0;Y=c[E>>2]|0;Z=P}else{if(ga[c[(c[z>>2]|0)+12>>2]&127](u,8192,c[F>>2]|0)|0){_=F}else{N=J+12|0;S=c[N>>2]|0;T=J+16|0;if((S|0)==(c[T>>2]|0)){$=f5[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{$=c[S>>2]|0}S=gm[c[(c[A>>2]|0)+28>>2]&127](u,$)|0;if((S|0)!=(gm[c[(c[A>>2]|0)+28>>2]&127](u,c[F>>2]|0)|0)){M=433;break L470}S=c[N>>2]|0;if((S|0)==(c[T>>2]|0)){T=c[(c[J>>2]|0)+40>>2]|0;f5[T&255](J)|0}else{c[N>>2]=S+4}X=F+4|0;Y=J;Z=P;break}while(1){S=_+4|0;if((S|0)==(k|0)){aa=k;break}if(ga[c[(c[z>>2]|0)+12>>2]&127](u,8192,c[S>>2]|0)|0){_=S}else{aa=S;break}}S=J;N=P;T=J;ab=P;while(1){if((S|0)==0){ac=0;ad=T}else{ae=c[S+12>>2]|0;if((ae|0)==(c[S+16>>2]|0)){af=f5[c[(c[S>>2]|0)+36>>2]&255](S)|0}else{af=c[ae>>2]|0}ae=(af|0)==-1;ac=ae?0:S;ad=ae?0:T}ae=(ac|0)==0;do{if((N|0)==0){ag=ab;M=416}else{ah=c[N+12>>2]|0;if((ah|0)==(c[N+16>>2]|0)){ai=f5[c[(c[N>>2]|0)+36>>2]&255](N)|0}else{ai=c[ah>>2]|0}if((ai|0)==-1){ag=0;M=416;break}if(ae){aj=N;ak=ab}else{X=aa;Y=ad;Z=ab;break L489}}}while(0);if((M|0)==416){M=0;if(ae){X=aa;Y=ad;Z=ag;break L489}else{aj=0;ak=ag}}ah=ac+12|0;al=c[ah>>2]|0;am=ac+16|0;if((al|0)==(c[am>>2]|0)){an=f5[c[(c[ac>>2]|0)+36>>2]&255](ac)|0}else{an=c[al>>2]|0}if(!(ga[c[(c[z>>2]|0)+12>>2]&127](u,8192,an)|0)){X=aa;Y=ad;Z=ak;break L489}al=c[ah>>2]|0;if((al|0)==(c[am>>2]|0)){am=c[(c[ac>>2]|0)+40>>2]|0;f5[am&255](ac)|0;S=ac;N=aj;T=ad;ab=ak;continue}else{c[ah>>2]=al+4;S=ac;N=aj;T=ad;ab=ak;continue}}}}while(0);if((X|0)==(k|0)){v=Y;w=Y;x=Z;break L468}if((c[g>>2]|0)==0){F=X;G=Y;H=Z}else{v=Y;w=Y;x=Z;break L468}}if((M|0)==388){c[g>>2]=4;v=Q;w=J;x=R;break}else if((M|0)==394){c[g>>2]=4;v=J;w=J;x=P;break}else if((M|0)==397){c[g>>2]=4;v=J;w=J;x=P;break}else if((M|0)==433){c[g>>2]=4;v=J;w=J;x=P;break}}}while(0);if((v|0)==0){ao=w}else{u=c[v+12>>2]|0;if((u|0)==(c[v+16>>2]|0)){ap=f5[c[(c[v>>2]|0)+36>>2]&255](v)|0}else{ap=c[u>>2]|0}ao=(ap|0)==-1?0:w}u=(ao|0)==0;do{if((x|0)==0){M=444}else{t=c[x+12>>2]|0;if((t|0)==(c[x+16>>2]|0)){aq=f5[c[(c[x>>2]|0)+36>>2]&255](x)|0}else{aq=c[t>>2]|0}if((aq|0)==-1){M=444;break}if(!u){break}ar=a|0;c[ar>>2]=ao;i=l;return}}while(0);do{if((M|0)==444){if(u){break}ar=a|0;c[ar>>2]=ao;i=l;return}}while(0);c[g>>2]=c[g>>2]|2;ar=a|0;c[ar>>2]=ao;i=l;return}}while(0);l=ff(4)|0;c[l>>2]=72472;dr(l|0,79072,408)}function u8(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[185168]|0)!=-1){c[k>>2]=740672;c[k+4>>2]=210;c[k+8>>2]=0;st(740672,k)}k=(c[185169]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f2[c[(c[l>>2]|0)+8>>2]&1023](l)}o=c[e>>2]|0;p=b+8|0;q=f5[c[c[p>>2]>>2]&255](p)|0;p=(uc(d,o,q,q+168|0,n,g,0)|0)-q|0;if((p|0)>=168){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+24>>2]=((p|0)/12|0|0)%7|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=ff(4)|0;c[j>>2]=72472;dr(j|0,79072,408)}function u9(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[185168]|0)!=-1){c[k>>2]=740672;c[k+4>>2]=210;c[k+8>>2]=0;st(740672,k)}k=(c[185169]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f2[c[(c[l>>2]|0)+8>>2]&1023](l)}o=c[e>>2]|0;p=b+8|0;q=f5[c[(c[p>>2]|0)+4>>2]&255](p)|0;p=(uc(d,o,q,q+288|0,n,g,0)|0)-q|0;if((p|0)>=288){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+16>>2]=((p|0)/12|0|0)%12|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=ff(4)|0;c[j>>2]=72472;dr(j|0,79072,408)}function va(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+16|0;j=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[j>>2];j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=b|0;k=c[f+28>>2]|0;f=k+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[185168]|0)!=-1){c[j>>2]=740672;c[j+4>>2]=210;c[j+8>>2]=0;st(740672,j)}j=(c[185169]|0)-1|0;l=c[k+8>>2]|0;do{if((c[k+12>>2]|0)-l>>2>>>0>j>>>0){m=c[l+(j<<2)>>2]|0;if((m|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f2[c[(c[k>>2]|0)+8>>2]&1023](k)}n=vA(d,c[e>>2]|0,g,m,4)|0;if((c[g>>2]&4|0)!=0){o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}if((n|0)<69){r=n+2e3|0}else{r=(n-69|0)>>>0<31?n+1900|0:n}c[h+20>>2]=r-1900;o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}}while(0);b=ff(4)|0;c[b>>2]=72472;dr(b|0,79072,408)}function vb(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;m=i;i=i+88|0;n=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[n>>2];n=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[n>>2];n=m|0;o=m+16|0;p=m+24|0;q=m+32|0;r=m+40|0;s=m+48|0;t=m+56|0;u=m+64|0;v=m+72|0;w=m+80|0;c[j>>2]=0;x=c[h+28>>2]|0;y=x+4|0;I=c[y>>2]|0,c[y>>2]=I+1,I;if((c[185168]|0)!=-1){c[n>>2]=740672;c[n+4>>2]=210;c[n+8>>2]=0;st(740672,n)}n=(c[185169]|0)-1|0;z=c[x+8>>2]|0;do{if((c[x+12>>2]|0)-z>>2>>>0>n>>>0){A=c[z+(n<<2)>>2]|0;if((A|0)==0){break}B=A;if(((I=c[y>>2]|0,c[y>>2]=I+ -1,I)|0)==0){f2[c[(c[x>>2]|0)+8>>2]&1023](x)}L631:do{switch(l<<24>>24|0){case 112:{C=k+8|0;D=c[g>>2]|0;E=e+8|0;F=f5[c[(c[E>>2]|0)+8>>2]&255](E)|0;E=d[F]|0;if((E&1|0)==0){G=E>>>1}else{G=c[F+4>>2]|0}E=d[F+12|0]|0;if((E&1|0)==0){H=E>>>1}else{H=c[F+16>>2]|0}if((G|0)==(-H|0)){c[j>>2]=c[j>>2]|4;break L631}E=uc(f,D,F,F+24|0,B,j,0)|0;D=E-F|0;do{if((E|0)==(F|0)){if((c[C>>2]|0)!=12){break}c[C>>2]=0;break L631}}while(0);if((D|0)!=12){break L631}F=c[C>>2]|0;if((F|0)>=12){break L631}c[C>>2]=F+12;break};case 120:{F=c[(c[e>>2]|0)+20>>2]|0;c[u>>2]=c[f>>2];c[v>>2]=c[g>>2];gi[F&127](b,e,u,v,h,j,k);i=m;return};case 88:{F=e+8|0;E=f5[c[(c[F>>2]|0)+24>>2]&255](F)|0;F=f|0;J=a[E]|0;if((J&1)==0){K=E+4|0}else{K=c[E+8>>2]|0}L=J&255;if((L&1|0)==0){M=L>>>1}else{M=c[E+4>>2]|0}u7(w,e,c[F>>2]|0,c[g>>2]|0,h,j,k,K,K+(M<<2)|0);c[F>>2]=c[w>>2];break};case 121:{F=vA(f,c[g>>2]|0,j,B,4)|0;if((c[j>>2]&4|0)!=0){break L631}if((F|0)<69){N=F+2e3|0}else{N=(F-69|0)>>>0<31?F+1900|0:F}c[k+20>>2]=N-1900;break};case 97:case 65:{F=c[g>>2]|0;E=e+8|0;L=f5[c[c[E>>2]>>2]&255](E)|0;E=(uc(f,F,L,L+168|0,B,j,0)|0)-L|0;if((E|0)>=168){break L631}c[k+24>>2]=((E|0)/12|0|0)%7|0;break};case 98:case 66:case 104:{E=c[g>>2]|0;L=e+8|0;F=f5[c[(c[L>>2]|0)+4>>2]&255](L)|0;L=(uc(f,E,F,F+288|0,B,j,0)|0)-F|0;if((L|0)>=288){break L631}c[k+16>>2]=((L|0)/12|0|0)%12|0;break};case 99:{L=e+8|0;F=f5[c[(c[L>>2]|0)+12>>2]&255](L)|0;L=f|0;E=a[F]|0;if((E&1)==0){O=F+4|0}else{O=c[F+8>>2]|0}J=E&255;if((J&1|0)==0){P=J>>>1}else{P=c[F+4>>2]|0}u7(o,e,c[L>>2]|0,c[g>>2]|0,h,j,k,O,O+(P<<2)|0);c[L>>2]=c[o>>2];break};case 100:case 101:{L=k+12|0;F=vA(f,c[g>>2]|0,j,B,2)|0;J=c[j>>2]|0;do{if((J&4|0)==0){if((F-1|0)>>>0>=31){break}c[L>>2]=F;break L631}}while(0);c[j>>2]=J|4;break};case 68:{F=f|0;u7(p,e,c[F>>2]|0,c[g>>2]|0,h,j,k,55664,55696);c[F>>2]=c[p>>2];break};case 70:{F=f|0;u7(q,e,c[F>>2]|0,c[g>>2]|0,h,j,k,55528,55560);c[F>>2]=c[q>>2];break};case 72:{F=vA(f,c[g>>2]|0,j,B,2)|0;L=c[j>>2]|0;if((L&4|0)==0&(F|0)<24){c[k+8>>2]=F;break L631}else{c[j>>2]=L|4;break L631}break};case 73:{L=k+8|0;F=vA(f,c[g>>2]|0,j,B,2)|0;C=c[j>>2]|0;do{if((C&4|0)==0){if((F-1|0)>>>0>=12){break}c[L>>2]=F;break L631}}while(0);c[j>>2]=C|4;break};case 106:{F=vA(f,c[g>>2]|0,j,B,3)|0;L=c[j>>2]|0;if((L&4|0)==0&(F|0)<366){c[k+28>>2]=F;break L631}else{c[j>>2]=L|4;break L631}break};case 109:{L=(vA(f,c[g>>2]|0,j,B,2)|0)-1|0;F=c[j>>2]|0;if((F&4|0)==0&(L|0)<12){c[k+16>>2]=L;break L631}else{c[j>>2]=F|4;break L631}break};case 77:{F=vA(f,c[g>>2]|0,j,B,2)|0;L=c[j>>2]|0;if((L&4|0)==0&(F|0)<60){c[k+4>>2]=F;break L631}else{c[j>>2]=L|4;break L631}break};case 110:case 116:{L=f|0;F=A;J=c[g>>2]|0;L709:while(1){D=c[L>>2]|0;do{if((D|0)==0){Q=1}else{E=c[D+12>>2]|0;if((E|0)==(c[D+16>>2]|0)){R=f5[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{R=c[E>>2]|0}if((R|0)==-1){c[L>>2]=0;Q=1;break}else{Q=(c[L>>2]|0)==0;break}}}while(0);do{if((J|0)==0){S=560}else{D=c[J+12>>2]|0;if((D|0)==(c[J+16>>2]|0)){T=f5[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{T=c[D>>2]|0}if((T|0)==-1){S=560;break}if(Q){U=0;V=J}else{W=J;X=0;break L709}}}while(0);if((S|0)==560){S=0;if(Q){W=0;X=1;break}else{U=1;V=0}}D=c[L>>2]|0;E=c[D+12>>2]|0;if((E|0)==(c[D+16>>2]|0)){Y=f5[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{Y=c[E>>2]|0}if(!(ga[c[(c[F>>2]|0)+12>>2]&127](B,8192,Y)|0)){W=V;X=U;break}E=c[L>>2]|0;D=E+12|0;Z=c[D>>2]|0;if((Z|0)==(c[E+16>>2]|0)){_=c[(c[E>>2]|0)+40>>2]|0;f5[_&255](E)|0;J=V;continue}else{c[D>>2]=Z+4;J=V;continue}}J=c[L>>2]|0;do{if((J|0)==0){$=1}else{F=c[J+12>>2]|0;if((F|0)==(c[J+16>>2]|0)){aa=f5[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{aa=c[F>>2]|0}if((aa|0)==-1){c[L>>2]=0;$=1;break}else{$=(c[L>>2]|0)==0;break}}}while(0);do{if(X){S=581}else{L=c[W+12>>2]|0;if((L|0)==(c[W+16>>2]|0)){ab=f5[c[(c[W>>2]|0)+36>>2]&255](W)|0}else{ab=c[L>>2]|0}if((ab|0)==-1){S=581;break}if($^(W|0)==0){break L631}}}while(0);if((S|0)==581){if(!$){break L631}}c[j>>2]=c[j>>2]|2;break};case 89:{L=vA(f,c[g>>2]|0,j,B,4)|0;if((c[j>>2]&4|0)!=0){break L631}c[k+20>>2]=L-1900;break};case 37:{L=c[g>>2]|0;J=f|0;F=c[J>>2]|0;do{if((F|0)==0){ac=1}else{C=c[F+12>>2]|0;if((C|0)==(c[F+16>>2]|0)){ad=f5[c[(c[F>>2]|0)+36>>2]&255](F)|0}else{ad=c[C>>2]|0}if((ad|0)==-1){c[J>>2]=0;ac=1;break}else{ac=(c[J>>2]|0)==0;break}}}while(0);do{if((L|0)==0){S=634}else{F=c[L+12>>2]|0;if((F|0)==(c[L+16>>2]|0)){ae=f5[c[(c[L>>2]|0)+36>>2]&255](L)|0}else{ae=c[F>>2]|0}if((ae|0)==-1){S=634;break}if(ac){af=L;ag=0}else{S=636}}}while(0);if((S|0)==634){if(ac){S=636}else{af=0;ag=1}}if((S|0)==636){c[j>>2]=c[j>>2]|6;break L631}L=c[J>>2]|0;F=c[L+12>>2]|0;if((F|0)==(c[L+16>>2]|0)){ah=f5[c[(c[L>>2]|0)+36>>2]&255](L)|0}else{ah=c[F>>2]|0}if((ga[c[(c[A>>2]|0)+52>>2]&127](B,ah,0)|0)<<24>>24!=37){c[j>>2]=c[j>>2]|4;break L631}F=c[J>>2]|0;L=F+12|0;C=c[L>>2]|0;if((C|0)==(c[F+16>>2]|0)){Z=c[(c[F>>2]|0)+40>>2]|0;f5[Z&255](F)|0}else{c[L>>2]=C+4}C=c[J>>2]|0;do{if((C|0)==0){ai=1}else{L=c[C+12>>2]|0;if((L|0)==(c[C+16>>2]|0)){aj=f5[c[(c[C>>2]|0)+36>>2]&255](C)|0}else{aj=c[L>>2]|0}if((aj|0)==-1){c[J>>2]=0;ai=1;break}else{ai=(c[J>>2]|0)==0;break}}}while(0);do{if(ag){S=657}else{J=c[af+12>>2]|0;if((J|0)==(c[af+16>>2]|0)){ak=f5[c[(c[af>>2]|0)+36>>2]&255](af)|0}else{ak=c[J>>2]|0}if((ak|0)==-1){S=657;break}if(ai^(af|0)==0){break L631}}}while(0);if((S|0)==657){if(!ai){break L631}}c[j>>2]=c[j>>2]|2;break};case 114:{J=f|0;u7(r,e,c[J>>2]|0,c[g>>2]|0,h,j,k,55616,55660);c[J>>2]=c[r>>2];break};case 82:{J=f|0;u7(s,e,c[J>>2]|0,c[g>>2]|0,h,j,k,55592,55612);c[J>>2]=c[s>>2];break};case 83:{J=vA(f,c[g>>2]|0,j,B,2)|0;C=c[j>>2]|0;if((C&4|0)==0&(J|0)<61){c[k>>2]=J;break L631}else{c[j>>2]=C|4;break L631}break};case 84:{C=f|0;u7(t,e,c[C>>2]|0,c[g>>2]|0,h,j,k,55560,55592);c[C>>2]=c[t>>2];break};case 119:{C=vA(f,c[g>>2]|0,j,B,1)|0;J=c[j>>2]|0;if((J&4|0)==0&(C|0)<7){c[k+24>>2]=C;break L631}else{c[j>>2]=J|4;break L631}break};default:{c[j>>2]=c[j>>2]|4}}}while(0);c[b>>2]=c[f>>2];i=m;return}}while(0);m=ff(4)|0;c[m>>2]=72472;dr(m|0,79072,408)}function vc(a){a=a|0;return}function vd(a){a=a|0;return 127}function ve(a){a=a|0;return 127}function vf(a){a=a|0;return 0}function vg(a){a=a|0;return}function vh(a){a=a|0;return 127}function vi(a){a=a|0;return 127}function vj(a){a=a|0;return 0}function vk(a){a=a|0;return}function vl(a){a=a|0;return 2147483647}function vm(a){a=a|0;return 2147483647}function vn(a){a=a|0;return 0}function vo(a){a=a|0;return}function vp(a){a=a|0;return 2147483647}function vq(a){a=a|0;return 2147483647}function vr(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function vs(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function vt(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function vu(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function vv(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function vw(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function vx(b,c){b=b|0;c=c|0;c=b;a[b]=2;a[c+1|0]=45;a[c+2|0]=0;return}function vy(b,c){b=b|0;c=c|0;c=b;a[b]=2;a[c+1|0]=45;a[c+2|0]=0;return}function vz(b,d){b=b|0;d=d|0;a[b]=2;d=b+4|0;c[d>>2]=45;c[d+4>>2]=0;return}function vA(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=a|0;a=c[g>>2]|0;do{if((a|0)==0){h=1}else{i=c[a+12>>2]|0;if((i|0)==(c[a+16>>2]|0)){j=f5[c[(c[a>>2]|0)+36>>2]&255](a)|0}else{j=c[i>>2]|0}if((j|0)==-1){c[g>>2]=0;h=1;break}else{h=(c[g>>2]|0)==0;break}}}while(0);do{if((b|0)==0){k=701}else{j=c[b+12>>2]|0;if((j|0)==(c[b+16>>2]|0)){l=f5[c[(c[b>>2]|0)+36>>2]&255](b)|0}else{l=c[j>>2]|0}if((l|0)==-1){k=701;break}if(h){m=b}else{k=703}}}while(0);if((k|0)==701){if(h){k=703}else{m=0}}if((k|0)==703){c[d>>2]=c[d>>2]|6;n=0;return n|0}h=c[g>>2]|0;b=c[h+12>>2]|0;if((b|0)==(c[h+16>>2]|0)){o=f5[c[(c[h>>2]|0)+36>>2]&255](h)|0}else{o=c[b>>2]|0}b=e;if(!(ga[c[(c[b>>2]|0)+12>>2]&127](e,2048,o)|0)){c[d>>2]=c[d>>2]|4;n=0;return n|0}h=e;l=(ga[c[(c[h>>2]|0)+52>>2]&127](e,o,0)|0)<<24>>24;o=c[g>>2]|0;j=o+12|0;a=c[j>>2]|0;if((a|0)==(c[o+16>>2]|0)){i=c[(c[o>>2]|0)+40>>2]|0;f5[i&255](o)|0;p=l;q=f;r=m}else{c[j>>2]=a+4;p=l;q=f;r=m}while(1){s=p-48|0;m=q-1|0;f=c[g>>2]|0;do{if((f|0)==0){t=0}else{l=c[f+12>>2]|0;if((l|0)==(c[f+16>>2]|0)){u=f5[c[(c[f>>2]|0)+36>>2]&255](f)|0}else{u=c[l>>2]|0}if((u|0)==-1){c[g>>2]=0;t=0;break}else{t=c[g>>2]|0;break}}}while(0);f=(t|0)==0;if((r|0)==0){v=t;w=0}else{l=c[r+12>>2]|0;if((l|0)==(c[r+16>>2]|0)){x=f5[c[(c[r>>2]|0)+36>>2]&255](r)|0}else{x=c[l>>2]|0}v=c[g>>2]|0;w=(x|0)==-1?0:r}y=(w|0)==0;if(!((f^y)&(m|0)>0)){break}f=c[v+12>>2]|0;if((f|0)==(c[v+16>>2]|0)){z=f5[c[(c[v>>2]|0)+36>>2]&255](v)|0}else{z=c[f>>2]|0}if(!(ga[c[(c[b>>2]|0)+12>>2]&127](e,2048,z)|0)){n=s;k=752;break}f=((ga[c[(c[h>>2]|0)+52>>2]&127](e,z,0)|0)<<24>>24)+(s*10|0)|0;l=c[g>>2]|0;a=l+12|0;j=c[a>>2]|0;if((j|0)==(c[l+16>>2]|0)){o=c[(c[l>>2]|0)+40>>2]|0;f5[o&255](l)|0;p=f;q=m;r=w;continue}else{c[a>>2]=j+4;p=f;q=m;r=w;continue}}if((k|0)==752){return n|0}do{if((v|0)==0){A=1}else{r=c[v+12>>2]|0;if((r|0)==(c[v+16>>2]|0)){B=f5[c[(c[v>>2]|0)+36>>2]&255](v)|0}else{B=c[r>>2]|0}if((B|0)==-1){c[g>>2]=0;A=1;break}else{A=(c[g>>2]|0)==0;break}}}while(0);do{if(y){k=744}else{g=c[w+12>>2]|0;if((g|0)==(c[w+16>>2]|0)){C=f5[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{C=c[g>>2]|0}if((C|0)==-1){k=744;break}if(A){n=s}else{break}return n|0}}while(0);do{if((k|0)==744){if(A){break}else{n=s}return n|0}}while(0);c[d>>2]=c[d>>2]|2;n=s;return n|0}function vB(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+112|0;f=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[f>>2];f=g|0;l=g+8|0;m=l|0;n=f|0;a[n]=37;o=f+1|0;a[o]=j;p=f+2|0;a[p]=k;a[f+3|0]=0;if(k<<24>>24!=0){a[o]=k;a[p]=j}j=dj(m|0,100,n|0,h|0,c[d+8>>2]|0)|0;d=l+j|0;l=c[e>>2]|0;if((j|0)==0){q=l;r=b|0;c[r>>2]=q;i=g;return}else{s=l;t=m}while(1){m=a[t]|0;if((s|0)==0){u=0}else{l=s+24|0;j=c[l>>2]|0;if((j|0)==(c[s+28>>2]|0)){v=gm[c[(c[s>>2]|0)+52>>2]&127](s,m&255)|0}else{c[l>>2]=j+1;a[j]=m;v=m&255}u=(v|0)==-1?0:s}m=t+1|0;if((m|0)==(d|0)){q=u;break}else{s=u;t=m}}r=b|0;c[r>>2]=q;i=g;return}function vC(a){a=a|0;if((a|0)==0){return}yt(a);return}function vD(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function vE(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function vF(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function vG(a){a=a|0;if((a|0)==0){return}yt(a);return}function vH(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function vI(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function vJ(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function vK(a){a=a|0;if((a|0)==0){return}yt(a);return}function vL(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function vM(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function vN(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function vO(a){a=a|0;if((a|0)==0){return}yt(a);return}function vP(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function vQ(b){b=b|0;var d=0,e=0,f=0;d=b;e=b+8|0;f=c[e>>2]|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);if((f|0)!=(c[141570]|0)){cF(c[e>>2]|0)}if((b|0)==0){return}yt(d);return}function vR(b){b=b|0;var d=0;d=b+8|0;b=c[d>>2]|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);if((b|0)==(c[141570]|0)){return}cF(c[d>>2]|0);return}function vS(b){b=b|0;var d=0,e=0,f=0;d=b;e=b+8|0;f=c[e>>2]|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);if((f|0)!=(c[141570]|0)){cF(c[e>>2]|0)}if((b|0)==0){return}yt(d);return}function vT(b){b=b|0;var d=0;d=b+8|0;b=c[d>>2]|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);if((b|0)==(c[141570]|0)){return}cF(c[d>>2]|0);return}function vU(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+528|0;f=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[f>>2];f=g|0;l=g+112|0;m=g+120|0;n=g+128|0;o=n|0;p=g+8|0;q=f|0;a[q]=37;r=f+1|0;a[r]=j;s=f+2|0;a[s]=k;a[f+3|0]=0;if(k<<24>>24!=0){a[r]=k;a[s]=j}j=d+8|0;dj(p|0,100,q|0,h|0,c[j>>2]|0)|0;c[l>>2]=0;c[l+4>>2]=0;c[m>>2]=p;p=eE(c[j>>2]|0)|0;j=yd(o,m,100,l)|0;if((p|0)!=0){eE(p|0)|0}if((j|0)==-1){v6(26544)}p=n+(j<<2)|0;n=c[e>>2]|0;if((j|0)==0){t=n;u=b|0;c[u>>2]=t;i=g;return}else{v=n;w=o}while(1){o=c[w>>2]|0;if((v|0)==0){x=0}else{n=v+24|0;j=c[n>>2]|0;if((j|0)==(c[v+28>>2]|0)){y=gm[c[(c[v>>2]|0)+52>>2]&127](v,o)|0}else{c[n>>2]=j+4;c[j>>2]=o;y=o}x=(y|0)==-1?0:v}o=w+4|0;if((o|0)==(p|0)){t=x;break}else{v=x;w=o}}u=b|0;c[u>>2]=t;i=g;return}function vV(a){a=a|0;return 0}function vW(a){a=a|0;return}function vX(a){a=a|0;return}function vY(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function vZ(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function v_(b,d){b=b|0;d=d|0;a[b]=2;d=b+4|0;c[d>>2]=45;c[d+4>>2]=0;return}function v$(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function v0(a,b){a=a|0;b=b|0;yB(a|0,0,12);return}function v1(a){a=a|0;if((a|0)==0){return}yt(a);return}function v2(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=i;i=i+264|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+120|0;o=d+128|0;p=d+136|0;q=d+144|0;r=d+160|0;s=n|0;c[s>>2]=m;t=n+4|0;c[t>>2]=344;u=m+100|0;m=c[h+28>>2]|0;v=m;w=m+4|0;I=c[w>>2]|0,c[w>>2]=I+1,I;if((c[185170]|0)!=-1){c[l>>2]=740680;c[l+4>>2]=210;c[l+8>>2]=0;st(740680,l)}l=(c[185171]|0)-1|0;w=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-w>>2>>>0>l>>>0){x=c[w+(l<<2)>>2]|0;if((x|0)==0){break}y=x;a[p]=0;z=f|0;do{if(v3(e,c[z>>2]|0,g,v,c[h+4>>2]|0,j,p,y,n,o,u)|0){A=q|0;B=c[(c[x>>2]|0)+32>>2]|0;gq[B&31](y,55512,55522,A)|0;B=r|0;C=c[o>>2]|0;D=c[s>>2]|0;E=C-D|0;do{if((E|0)>98){F=ys(E+2|0)|0;if((F|0)!=0){G=F;H=F;break}F=ff(4)|0;c[F>>2]=72440;dr(F|0,79056,316)}else{G=B;H=0}}while(0);if((a[p]&1)==0){J=G}else{a[G]=45;J=G+1|0}if(D>>>0<C>>>0){E=q+10|0;F=q;K=J;L=D;while(1){M=A;while(1){if((M|0)==(E|0)){N=E;break}if((a[M]|0)==(a[L]|0)){N=M;break}else{M=M+1|0}}a[K]=a[55512+(N-F)|0]|0;M=L+1|0;O=K+1|0;if(M>>>0<(c[o>>2]|0)>>>0){K=O;L=M}else{P=O;break}}}else{P=J}a[P]=0;L=eH(B|0,47496,(K=i,i=i+8|0,c[K>>2]=k,K)|0)|0;i=K;if((L|0)==1){if((H|0)==0){break}yt(H);break}L=ff(8)|0;c[L>>2]=72504;K=L+4|0;F=K;do{if((K|0)!=0){while(1){Q=ys(28)|0;if((Q|0)!=0){R=919;break}E=(I=c[185320]|0,c[185320]=I+0,I);if((E|0)==0){break}gs[E&63]()}if((R|0)==919){c[Q+4>>2]=15;c[Q>>2]=15;E=Q+12|0;c[F>>2]=E;c[Q+8>>2]=0;yE(E|0,46392,16)|0;break}E=ff(4)|0;c[E>>2]=72440;dr(E|0,79056,316)}}while(0);dr(L|0,79088,154)}}while(0);y=e|0;x=c[y>>2]|0;do{if((x|0)==0){S=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){S=x;break}if((f5[c[(c[x>>2]|0)+36>>2]&255](x)|0)!=-1){S=x;break}c[y>>2]=0;S=0}}while(0);y=(S|0)==0;x=c[z>>2]|0;do{if((x|0)==0){R=937}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){if(y){break}else{R=939;break}}if((f5[c[(c[x>>2]|0)+36>>2]&255](x)|0)==-1){c[z>>2]=0;R=937;break}else{if(y){break}else{R=939;break}}}}while(0);if((R|0)==937){if(y){R=939}}if((R|0)==939){c[j>>2]=c[j>>2]|2}c[b>>2]=S;z=m+4|0;if(((I=c[z>>2]|0,c[z>>2]=I+ -1,I)|0)==0){f2[c[(c[m>>2]|0)+8>>2]&1023](m)}z=c[s>>2]|0;c[s>>2]=0;if((z|0)==0){i=d;return}f2[c[t>>2]&1023](z);i=d;return}}while(0);d=ff(4)|0;c[d>>2]=72472;dr(d|0,79072,408)}function v3(e,f,g,h,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0;q=i;i=i+584|0;r=q|0;s=q+16|0;t=q+32|0;u=q+40|0;v=q+56|0;w=q+72|0;x=q+88|0;y=q+104|0;z=q+112|0;A=q+128|0;B=q+144|0;C=q+160|0;D=q+176|0;E=q+576|0;F=E;G=i;i=i+12|0;i=i+7>>3<<3;H=G;J=i;i=i+12|0;i=i+7>>3<<3;K=i;i=i+12|0;i=i+7>>3<<3;L=i;i=i+12|0;i=i+7>>3<<3;M=i;i=i+12|0;i=i+7>>3<<3;N=i;i=i+4|0;i=i+7>>3<<3;O=D|0;yB(H|0,0,12);P=J;Q=K;R=L;S=M;yB(P|0,0,12);yB(Q|0,0,12);yB(R|0,0,12);yB(S|0,0,12);T=u;U=v;V=w;W=x;X=z;Y=A;Z=B;_=C;L1146:do{if(g){$=t;if((c[185288]|0)!=-1){c[s>>2]=741152;c[s+4>>2]=210;c[s+8>>2]=0;st(741152,s)}aa=(c[185289]|0)-1|0;ab=c[h+8>>2]|0;do{if((c[h+12>>2]|0)-ab>>2>>>0>aa>>>0){ac=c[ab+(aa<<2)>>2]|0;if((ac|0)==0){break}ad=ac;f3[c[(c[ac>>2]|0)+44>>2]&1023]($,ad);c[E>>2]=c[t>>2];ae=ac;f3[c[(c[ae>>2]|0)+32>>2]&1023](u,ad);if((a[R]&1)==0){a[L+1|0]=0;a[R]=0}else{a[c[L+8>>2]|0]=0;c[L+4>>2]=0}sy(L);c[R>>2]=c[T>>2];c[R+4>>2]=c[T+4>>2];c[R+8>>2]=c[T+8>>2];yB(T|0,0,12);f3[c[(c[ae>>2]|0)+28>>2]&1023](v,ad);if((a[Q]&1)==0){a[K+1|0]=0;a[Q]=0}else{a[c[K+8>>2]|0]=0;c[K+4>>2]=0}sy(K);c[Q>>2]=c[U>>2];c[Q+4>>2]=c[U+4>>2];c[Q+8>>2]=c[U+8>>2];yB(U|0,0,12);af=ac;ag=f5[c[(c[af>>2]|0)+12>>2]&255](ad)|0;ah=f5[c[(c[af>>2]|0)+16>>2]&255](ad)|0;f3[c[(c[ae>>2]|0)+20>>2]&1023](w,ad);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}sy(G);c[H>>2]=c[V>>2];c[H+4>>2]=c[V+4>>2];c[H+8>>2]=c[V+8>>2];yB(V|0,0,12);f3[c[(c[ae>>2]|0)+24>>2]&1023](x,ad);if((a[P]&1)==0){a[J+1|0]=0;a[P]=0}else{a[c[J+8>>2]|0]=0;c[J+4>>2]=0}sy(J);c[P>>2]=c[W>>2];c[P+4>>2]=c[W+4>>2];c[P+8>>2]=c[W+8>>2];yB(W|0,0,12);ai=f5[c[(c[ac>>2]|0)+36>>2]&255](ad)|0;aj=ah;ak=ag;break L1146}}while(0);$=ff(4)|0;c[$>>2]=72472;dr($|0,79072,408);return 0}else{$=y;if((c[185290]|0)!=-1){c[r>>2]=741160;c[r+4>>2]=210;c[r+8>>2]=0;st(741160,r)}aa=(c[185291]|0)-1|0;ab=c[h+8>>2]|0;do{if((c[h+12>>2]|0)-ab>>2>>>0>aa>>>0){ag=c[ab+(aa<<2)>>2]|0;if((ag|0)==0){break}ah=ag;f3[c[(c[ag>>2]|0)+44>>2]&1023]($,ah);c[E>>2]=c[y>>2];ad=ag;f3[c[(c[ad>>2]|0)+32>>2]&1023](z,ah);if((a[R]&1)==0){a[L+1|0]=0;a[R]=0}else{a[c[L+8>>2]|0]=0;c[L+4>>2]=0}sy(L);c[R>>2]=c[X>>2];c[R+4>>2]=c[X+4>>2];c[R+8>>2]=c[X+8>>2];yB(X|0,0,12);f3[c[(c[ad>>2]|0)+28>>2]&1023](A,ah);if((a[Q]&1)==0){a[K+1|0]=0;a[Q]=0}else{a[c[K+8>>2]|0]=0;c[K+4>>2]=0}sy(K);c[Q>>2]=c[Y>>2];c[Q+4>>2]=c[Y+4>>2];c[Q+8>>2]=c[Y+8>>2];yB(Y|0,0,12);ac=ag;ae=f5[c[(c[ac>>2]|0)+12>>2]&255](ah)|0;af=f5[c[(c[ac>>2]|0)+16>>2]&255](ah)|0;f3[c[(c[ad>>2]|0)+20>>2]&1023](B,ah);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}sy(G);c[H>>2]=c[Z>>2];c[H+4>>2]=c[Z+4>>2];c[H+8>>2]=c[Z+8>>2];yB(Z|0,0,12);f3[c[(c[ad>>2]|0)+24>>2]&1023](C,ah);if((a[P]&1)==0){a[J+1|0]=0;a[P]=0}else{a[c[J+8>>2]|0]=0;c[J+4>>2]=0}sy(J);c[P>>2]=c[_>>2];c[P+4>>2]=c[_+4>>2];c[P+8>>2]=c[_+8>>2];yB(_|0,0,12);ai=f5[c[(c[ag>>2]|0)+36>>2]&255](ah)|0;aj=af;ak=ae;break L1146}}while(0);$=ff(4)|0;c[$>>2]=72472;dr($|0,79072,408);return 0}}while(0);_=n|0;c[o>>2]=c[_>>2];C=e|0;e=m+8|0;m=L+1|0;Z=L+4|0;B=L+8|0;Y=K+1|0;A=K+4|0;X=K+8|0;z=(j&512|0)!=0;j=J+1|0;y=J+4|0;E=J+8|0;J=M+1|0;h=M+4|0;r=M+8|0;W=F+3|0;x=n+4|0;n=G+4|0;V=M|0;M=p;p=344;w=O;U=O;O=D+400|0;D=0;v=0;T=ai;ai=f;L1220:while(1){f=c[C>>2]|0;do{if((f|0)==0){al=0}else{if((c[f+12>>2]|0)!=(c[f+16>>2]|0)){al=f;break}if((f5[c[(c[f>>2]|0)+36>>2]&255](f)|0)==-1){c[C>>2]=0;al=0;break}else{al=c[C>>2]|0;break}}}while(0);f=(al|0)==0;do{if((ai|0)==0){am=1035}else{if((c[ai+12>>2]|0)!=(c[ai+16>>2]|0)){if(f){an=ai;break}else{ao=p;ap=w;aq=U;ar=D;as=ai;am=1360;break L1220}}if((f5[c[(c[ai>>2]|0)+36>>2]&255](ai)|0)==-1){am=1035;break}if(f){an=ai}else{ao=p;ap=w;aq=U;ar=D;as=ai;am=1360;break L1220}}}while(0);if((am|0)==1035){am=0;if(f){ao=p;ap=w;aq=U;ar=D;as=0;am=1360;break}else{an=0}}L1240:do{switch(a[F+v|0]|0){case 3:{u=a[Q]|0;t=u&255;s=(t&1|0)==0?t>>>1:c[A>>2]|0;t=a[R]|0;g=t&255;$=(g&1|0)==0?g>>>1:c[Z>>2]|0;if((s|0)==(-$|0)){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L1240}g=(s|0)==0;s=c[C>>2]|0;aa=c[s+12>>2]|0;ab=c[s+16>>2]|0;ae=(aa|0)==(ab|0);if(!(g|($|0)==0)){if(ae){$=(f5[c[(c[s>>2]|0)+36>>2]&255](s)|0)&255;af=c[C>>2]|0;aB=$;aC=a[Q]|0;aD=af;aE=c[af+12>>2]|0;aF=c[af+16>>2]|0}else{aB=a[aa]|0;aC=u;aD=s;aE=aa;aF=ab}ab=aD+12|0;af=(aE|0)==(aF|0);if(aB<<24>>24==(a[(aC&1)==0?Y:c[X>>2]|0]|0)){if(af){$=c[(c[aD>>2]|0)+40>>2]|0;f5[$&255](aD)|0}else{c[ab>>2]=aE+1}ab=d[Q]|0;at=((ab&1|0)==0?ab>>>1:c[A>>2]|0)>>>0>1?K:D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L1240}if(af){aG=(f5[c[(c[aD>>2]|0)+36>>2]&255](aD)|0)&255}else{aG=a[aE]|0}if(aG<<24>>24!=(a[(a[R]&1)==0?m:c[B>>2]|0]|0)){am=1201;break L1220}af=c[C>>2]|0;ab=af+12|0;$=c[ab>>2]|0;if(($|0)==(c[af+16>>2]|0)){ah=c[(c[af>>2]|0)+40>>2]|0;f5[ah&255](af)|0}else{c[ab>>2]=$+1}a[l]=1;$=d[R]|0;at=(($&1|0)==0?$>>>1:c[Z>>2]|0)>>>0>1?L:D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L1240}if(g){if(ae){g=(f5[c[(c[s>>2]|0)+36>>2]&255](s)|0)&255;aH=g;aI=a[R]|0}else{aH=a[aa]|0;aI=t}if(aH<<24>>24!=(a[(aI&1)==0?m:c[B>>2]|0]|0)){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L1240}t=c[C>>2]|0;g=t+12|0;$=c[g>>2]|0;if(($|0)==(c[t+16>>2]|0)){ab=c[(c[t>>2]|0)+40>>2]|0;f5[ab&255](t)|0}else{c[g>>2]=$+1}a[l]=1;$=d[R]|0;at=(($&1|0)==0?$>>>1:c[Z>>2]|0)>>>0>1?L:D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L1240}if(ae){ae=(f5[c[(c[s>>2]|0)+36>>2]&255](s)|0)&255;aJ=ae;aK=a[Q]|0}else{aJ=a[aa]|0;aK=u}if(aJ<<24>>24!=(a[(aK&1)==0?Y:c[X>>2]|0]|0)){a[l]=1;at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L1240}u=c[C>>2]|0;aa=u+12|0;ae=c[aa>>2]|0;if((ae|0)==(c[u+16>>2]|0)){s=c[(c[u>>2]|0)+40>>2]|0;f5[s&255](u)|0}else{c[aa>>2]=ae+1}ae=d[Q]|0;at=((ae&1|0)==0?ae>>>1:c[A>>2]|0)>>>0>1?K:D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break};case 1:{if((v|0)==3){ao=p;ap=w;aq=U;ar=D;as=an;am=1360;break L1220}ae=c[C>>2]|0;aa=c[ae+12>>2]|0;if((aa|0)==(c[ae+16>>2]|0)){aL=(f5[c[(c[ae>>2]|0)+36>>2]&255](ae)|0)&255}else{aL=a[aa]|0}if(aL<<24>>24<=-1){am=1108;break L1220}if((b[(c[e>>2]|0)+(aL<<24>>24<<1)>>1]&8192)==0){am=1108;break L1220}aa=c[C>>2]|0;ae=aa+12|0;u=c[ae>>2]|0;if((u|0)==(c[aa+16>>2]|0)){aM=(f5[c[(c[aa>>2]|0)+40>>2]&255](aa)|0)&255}else{c[ae>>2]=u+1;aM=a[u]|0}u=a[S]|0;if((u&1)==0){aN=(u&255)>>>1;aO=10;aP=u}else{ae=c[V>>2]|0;aN=c[h>>2]|0;aO=(ae&-2)-1|0;aP=ae&255}if((aN|0)==(aO|0)){if((aO|0)==-3){am=1085;break L1220}ae=(aP&1)==0?J:c[r>>2]|0;do{if(aO>>>0<2147483631){aa=aO+1|0;s=aO<<1;$=aa>>>0<s>>>0?s:aa;if($>>>0<11){aQ=11;break}aQ=$+16&-16}else{aQ=-2}}while(0);$=(aQ|0)==0?1:aQ;while(1){aR=ys($)|0;if((aR|0)!=0){break}aa=(I=c[185320]|0,c[185320]=I+0,I);if((aa|0)==0){am=1099;break L1220}gs[aa&63]()}yE(aR|0,ae|0,aO)|0;if(!((aO|0)==10|(ae|0)==0)){yt(ae)}c[r>>2]=aR;$=aQ|1;c[V>>2]=$;aS=$&255}else{aS=u}if((aS&1)==0){a[S]=(aN<<1)+2&255;aT=J;aU=aN+1|0}else{$=c[r>>2]|0;aa=aN+1|0;c[h>>2]=aa;aT=$;aU=aa}a[aT+aN|0]=aM;a[aT+aU|0]=0;am=1109;break};case 0:{am=1109;break};case 2:{if(!((D|0)!=0|v>>>0<2)){if((v|0)==2){aV=(a[W]|0)!=0}else{aV=0}if(!(z|aV)){at=0;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L1240}}aa=a[P]|0;$=(aa&1)==0?j:c[E>>2]|0;L1338:do{if((v|0)==0){aW=$}else{if((d[F+(v-1)|0]|0)>=2){aW=$;break}s=aa&255;g=$+((s&1|0)==0?s>>>1:c[y>>2]|0)|0;s=$;while(1){if((s|0)==(g|0)){aX=g;break}t=a[s]|0;if(t<<24>>24<=-1){aX=s;break}if((b[(c[e>>2]|0)+(t<<24>>24<<1)>>1]&8192)==0){aX=s;break}else{s=s+1|0}}s=aX-$|0;g=a[S]|0;t=g&255;ab=(t&1|0)==0?t>>>1:c[h>>2]|0;if(s>>>0>ab>>>0){aW=$;break}t=(g&1)==0?J:c[r>>2]|0;g=t+ab|0;if((aX|0)==($|0)){aW=$;break}af=$;ah=t+(ab-s)|0;while(1){if((a[ah]|0)!=(a[af]|0)){aW=$;break L1338}s=ah+1|0;if((s|0)==(g|0)){aW=aX;break}else{af=af+1|0;ah=s}}}}while(0);u=aa&255;L1352:do{if((aW|0)==($+((u&1|0)==0?u>>>1:c[y>>2]|0)|0)){aY=aW;aZ=an}else{ae=an;ah=aW;af=an;while(1){g=c[C>>2]|0;do{if((g|0)==0){a_=0}else{if((c[g+12>>2]|0)!=(c[g+16>>2]|0)){a_=g;break}if((f5[c[(c[g>>2]|0)+36>>2]&255](g)|0)==-1){c[C>>2]=0;a_=0;break}else{a_=c[C>>2]|0;break}}}while(0);g=(a_|0)==0;do{if((ae|0)==0){a$=af;am=1229}else{if((c[ae+12>>2]|0)!=(c[ae+16>>2]|0)){if(g){a0=ae;a1=af;break}else{aY=ah;aZ=af;break L1352}}if((f5[c[(c[ae>>2]|0)+36>>2]&255](ae)|0)==-1){a$=0;am=1229;break}if(g){a0=ae;a1=af}else{aY=ah;aZ=af;break L1352}}}while(0);if((am|0)==1229){am=0;if(g){aY=ah;aZ=a$;break L1352}else{a0=0;a1=a$}}s=c[C>>2]|0;ab=c[s+12>>2]|0;if((ab|0)==(c[s+16>>2]|0)){a2=(f5[c[(c[s>>2]|0)+36>>2]&255](s)|0)&255}else{a2=a[ab]|0}if(a2<<24>>24!=(a[ah]|0)){aY=ah;aZ=a1;break L1352}ab=c[C>>2]|0;s=ab+12|0;t=c[s>>2]|0;if((t|0)==(c[ab+16>>2]|0)){ag=c[(c[ab>>2]|0)+40>>2]|0;f5[ag&255](ab)|0}else{c[s>>2]=t+1}t=ah+1|0;s=a[P]|0;ab=s&255;if((t|0)==(((s&1)==0?j:c[E>>2]|0)+((ab&1|0)==0?ab>>>1:c[y>>2]|0)|0)){aY=t;aZ=a1;break}else{ae=a0;ah=t;af=a1}}}}while(0);if(!z){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=aZ;break L1240}u=a[P]|0;$=u&255;if((aY|0)==(((u&1)==0?j:c[E>>2]|0)+(($&1|0)==0?$>>>1:c[y>>2]|0)|0)){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=aZ}else{am=1242;break L1220}break};case 4:{$=0;u=O;aa=U;af=w;ah=p;ae=M;t=an;L1385:while(1){ab=c[C>>2]|0;do{if((ab|0)==0){a3=0}else{if((c[ab+12>>2]|0)!=(c[ab+16>>2]|0)){a3=ab;break}if((f5[c[(c[ab>>2]|0)+36>>2]&255](ab)|0)==-1){c[C>>2]=0;a3=0;break}else{a3=c[C>>2]|0;break}}}while(0);ab=(a3|0)==0;do{if((t|0)==0){am=1254}else{if((c[t+12>>2]|0)!=(c[t+16>>2]|0)){if(ab){a4=t;break}else{a5=t;break L1385}}if((f5[c[(c[t>>2]|0)+36>>2]&255](t)|0)==-1){am=1254;break}if(ab){a4=t}else{a5=t;break L1385}}}while(0);if((am|0)==1254){am=0;if(ab){a5=0;break}else{a4=0}}s=c[C>>2]|0;ag=c[s+12>>2]|0;if((ag|0)==(c[s+16>>2]|0)){a6=(f5[c[(c[s>>2]|0)+36>>2]&255](s)|0)&255}else{a6=a[ag]|0}do{if(a6<<24>>24>-1){if((b[(c[e>>2]|0)+(a6<<24>>24<<1)>>1]&2048)==0){am=1274;break}ag=c[o>>2]|0;if((ag|0)==(ae|0)){s=(c[x>>2]|0)!=344;ad=c[_>>2]|0;ac=ae-ad|0;a7=ac>>>0<2147483647?ac<<1:-1;a8=yu(s?ad:0,a7)|0;if((a8|0)==0){am=1264;break L1220}do{if(s){c[_>>2]=a8;a9=a8}else{ad=c[_>>2]|0;c[_>>2]=a8;if((ad|0)==0){a9=a8;break}f2[c[x>>2]&1023](ad);a9=c[_>>2]|0}}while(0);c[x>>2]=174;a8=a9+ac|0;c[o>>2]=a8;ba=(c[_>>2]|0)+a7|0;bb=a8}else{ba=ae;bb=ag}c[o>>2]=bb+1;a[bb]=a6;bc=$+1|0;bd=u;be=aa;bf=af;bg=ah;bh=ba}else{am=1274}}while(0);if((am|0)==1274){am=0;ab=d[H]|0;if(!(($|0)!=0&(((ab&1|0)==0?ab>>>1:c[n>>2]|0)|0)!=0&a6<<24>>24==aj<<24>>24)){a5=a4;break}if((aa|0)==(u|0)){ab=aa-af|0;a8=ab>>>0<2147483647?ab<<1:-1;if((ah|0)==344){bi=0}else{bi=af}s=yu(bi,a8)|0;g=s;if((s|0)==0){am=1279;break L1220}bj=g+(a8>>>2<<2)|0;bk=g+(ab>>2<<2)|0;bl=g;bm=174}else{bj=u;bk=aa;bl=af;bm=ah}c[bk>>2]=$;bc=0;bd=bj;be=bk+4|0;bf=bl;bg=bm;bh=ae}g=c[C>>2]|0;ab=g+12|0;a8=c[ab>>2]|0;if((a8|0)==(c[g+16>>2]|0)){s=c[(c[g>>2]|0)+40>>2]|0;f5[s&255](g)|0;$=bc;u=bd;aa=be;af=bf;ah=bg;ae=bh;t=a4;continue}else{c[ab>>2]=a8+1;$=bc;u=bd;aa=be;af=bf;ah=bg;ae=bh;t=a4;continue}}if((af|0)==(aa|0)|($|0)==0){bn=u;bo=aa;bp=af;bq=ah}else{if((aa|0)==(u|0)){t=aa-af|0;a8=t>>>0<2147483647?t<<1:-1;if((ah|0)==344){br=0}else{br=af}ab=yu(br,a8)|0;g=ab;if((ab|0)==0){am=1291;break L1220}bs=g+(a8>>>2<<2)|0;bt=g+(t>>2<<2)|0;bu=g;bv=174}else{bs=u;bt=aa;bu=af;bv=ah}c[bt>>2]=$;bn=bs;bo=bt+4|0;bp=bu;bq=bv}if((T|0)>0){g=c[C>>2]|0;do{if((g|0)==0){bw=0}else{if((c[g+12>>2]|0)!=(c[g+16>>2]|0)){bw=g;break}if((f5[c[(c[g>>2]|0)+36>>2]&255](g)|0)==-1){c[C>>2]=0;bw=0;break}else{bw=c[C>>2]|0;break}}}while(0);g=(bw|0)==0;do{if((a5|0)==0){am=1307}else{if((c[a5+12>>2]|0)!=(c[a5+16>>2]|0)){if(g){bx=a5;break}else{am=1314;break L1220}}if((f5[c[(c[a5>>2]|0)+36>>2]&255](a5)|0)==-1){am=1307;break}if(g){bx=a5}else{am=1314;break L1220}}}while(0);if((am|0)==1307){am=0;if(g){am=1314;break L1220}else{bx=0}}$=c[C>>2]|0;ah=c[$+12>>2]|0;if((ah|0)==(c[$+16>>2]|0)){by=(f5[c[(c[$>>2]|0)+36>>2]&255]($)|0)&255}else{by=a[ah]|0}if(by<<24>>24!=ak<<24>>24){am=1314;break L1220}ah=c[C>>2]|0;$=ah+12|0;af=c[$>>2]|0;if((af|0)==(c[ah+16>>2]|0)){aa=c[(c[ah>>2]|0)+40>>2]|0;f5[aa&255](ah)|0;bz=ae;bA=bx;bB=T;bC=bx}else{c[$>>2]=af+1;bz=ae;bA=bx;bB=T;bC=bx}while(1){af=c[C>>2]|0;do{if((af|0)==0){bD=0}else{if((c[af+12>>2]|0)!=(c[af+16>>2]|0)){bD=af;break}if((f5[c[(c[af>>2]|0)+36>>2]&255](af)|0)==-1){c[C>>2]=0;bD=0;break}else{bD=c[C>>2]|0;break}}}while(0);af=(bD|0)==0;do{if((bA|0)==0){bE=bC;am=1329}else{if((c[bA+12>>2]|0)!=(c[bA+16>>2]|0)){if(af){bF=bA;bG=bC;break}else{am=1337;break L1220}}if((f5[c[(c[bA>>2]|0)+36>>2]&255](bA)|0)==-1){bE=0;am=1329;break}if(af){bF=bA;bG=bC}else{am=1337;break L1220}}}while(0);if((am|0)==1329){am=0;if(af){am=1337;break L1220}else{bF=0;bG=bE}}$=c[C>>2]|0;ah=c[$+12>>2]|0;if((ah|0)==(c[$+16>>2]|0)){bH=(f5[c[(c[$>>2]|0)+36>>2]&255]($)|0)&255}else{bH=a[ah]|0}if(bH<<24>>24<=-1){am=1337;break L1220}if((b[(c[e>>2]|0)+(bH<<24>>24<<1)>>1]&2048)==0){am=1337;break L1220}ah=c[o>>2]|0;if((ah|0)==(bz|0)){$=(c[x>>2]|0)!=344;aa=c[_>>2]|0;u=bz-aa|0;t=u>>>0<2147483647?u<<1:-1;a8=yu($?aa:0,t)|0;if((a8|0)==0){am=1340;break L1220}do{if($){c[_>>2]=a8;bI=a8}else{aa=c[_>>2]|0;c[_>>2]=a8;if((aa|0)==0){bI=a8;break}f2[c[x>>2]&1023](aa);bI=c[_>>2]|0}}while(0);c[x>>2]=174;a8=bI+u|0;c[o>>2]=a8;bJ=(c[_>>2]|0)+t|0;bK=a8}else{bJ=bz;bK=ah}a8=c[C>>2]|0;$=c[a8+12>>2]|0;if(($|0)==(c[a8+16>>2]|0)){af=(f5[c[(c[a8>>2]|0)+36>>2]&255](a8)|0)&255;bL=af;bM=c[o>>2]|0}else{bL=a[$]|0;bM=bK}c[o>>2]=bM+1;a[bM]=bL;$=bB-1|0;af=c[C>>2]|0;a8=af+12|0;aa=c[a8>>2]|0;if((aa|0)==(c[af+16>>2]|0)){ab=c[(c[af>>2]|0)+40>>2]|0;f5[ab&255](af)|0}else{c[a8>>2]=aa+1}if(($|0)>0){bz=bJ;bA=bF;bB=$;bC=bG}else{bN=bJ;bO=$;bP=bG;break}}}else{bN=ae;bO=T;bP=a5}if((c[o>>2]|0)==(c[_>>2]|0)){am=1358;break L1220}else{at=D;au=bn;av=bo;aw=bp;ax=bq;ay=bN;az=bO;aA=bP}break};default:{at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an}}}while(0);L1524:do{if((am|0)==1109){am=0;if((v|0)==3){ao=p;ap=w;aq=U;ar=D;as=an;am=1360;break L1220}else{bQ=an;bR=an}while(1){f=c[C>>2]|0;do{if((f|0)==0){bS=0}else{if((c[f+12>>2]|0)!=(c[f+16>>2]|0)){bS=f;break}if((f5[c[(c[f>>2]|0)+36>>2]&255](f)|0)==-1){c[C>>2]=0;bS=0;break}else{bS=c[C>>2]|0;break}}}while(0);f=(bS|0)==0;do{if((bQ|0)==0){bT=bR;am=1121}else{if((c[bQ+12>>2]|0)!=(c[bQ+16>>2]|0)){if(f){bU=bQ;bV=bR;break}else{at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=bR;break L1524}}if((f5[c[(c[bQ>>2]|0)+36>>2]&255](bQ)|0)==-1){bT=0;am=1121;break}if(f){bU=bQ;bV=bR}else{at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=bR;break L1524}}}while(0);if((am|0)==1121){am=0;if(f){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=bT;break L1524}else{bU=0;bV=bT}}ah=c[C>>2]|0;t=c[ah+12>>2]|0;if((t|0)==(c[ah+16>>2]|0)){bW=(f5[c[(c[ah>>2]|0)+36>>2]&255](ah)|0)&255}else{bW=a[t]|0}if(bW<<24>>24<=-1){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=bV;break L1524}if((b[(c[e>>2]|0)+(bW<<24>>24<<1)>>1]&8192)==0){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=bV;break L1524}t=c[C>>2]|0;ah=t+12|0;u=c[ah>>2]|0;if((u|0)==(c[t+16>>2]|0)){bX=(f5[c[(c[t>>2]|0)+40>>2]&255](t)|0)&255}else{c[ah>>2]=u+1;bX=a[u]|0}u=a[S]|0;if((u&1)==0){bY=(u&255)>>>1;bZ=10;b_=u}else{ah=c[V>>2]|0;bY=c[h>>2]|0;bZ=(ah&-2)-1|0;b_=ah&255}if((bY|0)==(bZ|0)){if((bZ|0)==-3){am=1138;break L1220}ah=(b_&1)==0?J:c[r>>2]|0;do{if(bZ>>>0<2147483631){t=bZ+1|0;g=bZ<<1;$=t>>>0<g>>>0?g:t;if($>>>0<11){b$=11;break}b$=$+16&-16}else{b$=-2}}while(0);f=(b$|0)==0?1:b$;while(1){b0=ys(f)|0;if((b0|0)!=0){break}$=(I=c[185320]|0,c[185320]=I+0,I);if(($|0)==0){am=1152;break L1220}gs[$&63]()}yE(b0|0,ah|0,bZ)|0;if(!((bZ|0)==10|(ah|0)==0)){yt(ah)}c[r>>2]=b0;f=b$|1;c[V>>2]=f;b1=f&255}else{b1=u}if((b1&1)==0){a[S]=(bY<<1)+2&255;b2=J;b3=bY+1|0}else{f=c[r>>2]|0;$=bY+1|0;c[h>>2]=$;b2=f;b3=$}a[b2+bY|0]=bX;a[b2+b3|0]=0;bQ=bU;bR=bV}}}while(0);ae=v+1|0;if(ae>>>0<4){M=ay;p=ax;w=aw;U=av;O=au;D=at;v=ae;T=az;ai=aA}else{ao=ax;ap=aw;aq=av;ar=at;as=aA;am=1360;break}}L1583:do{if((am|0)==1108){c[k>>2]=c[k>>2]|4;b4=0;b5=w;b6=p}else if((am|0)==1138){su();return 0}else if((am|0)==1152){aA=ff(4)|0;c[aA>>2]=72440;dr(aA|0,79056,316);return 0}else if((am|0)==1085){su();return 0}else if((am|0)==1099){aA=ff(4)|0;c[aA>>2]=72440;dr(aA|0,79056,316);return 0}else if((am|0)==1201){c[k>>2]=c[k>>2]|4;b4=0;b5=w;b6=p}else if((am|0)==1242){c[k>>2]=c[k>>2]|4;b4=0;b5=w;b6=p}else if((am|0)==1264){aA=ff(4)|0;c[aA>>2]=72440;dr(aA|0,79056,316);return 0}else if((am|0)==1279){aA=ff(4)|0;c[aA>>2]=72440;dr(aA|0,79056,316);return 0}else if((am|0)==1291){aA=ff(4)|0;c[aA>>2]=72440;dr(aA|0,79056,316);return 0}else if((am|0)==1314){c[k>>2]=c[k>>2]|4;b4=0;b5=bp;b6=bq}else if((am|0)==1337){c[k>>2]=c[k>>2]|4;b4=0;b5=bp;b6=bq}else if((am|0)==1340){aA=ff(4)|0;c[aA>>2]=72440;dr(aA|0,79056,316);return 0}else if((am|0)==1358){c[k>>2]=c[k>>2]|4;b4=0;b5=bp;b6=bq}else if((am|0)==1360){L1607:do{if((ar|0)!=0){aA=ar;at=ar+1|0;av=ar+8|0;aw=ar+4|0;ax=1;ai=as;L1609:while(1){az=d[aA]|0;if((az&1|0)==0){b7=az>>>1}else{b7=c[aw>>2]|0}if(ax>>>0>=b7>>>0){break L1607}az=c[C>>2]|0;do{if((az|0)==0){b8=0}else{if((c[az+12>>2]|0)!=(c[az+16>>2]|0)){b8=az;break}if((f5[c[(c[az>>2]|0)+36>>2]&255](az)|0)==-1){c[C>>2]=0;b8=0;break}else{b8=c[C>>2]|0;break}}}while(0);az=(b8|0)==0;do{if((ai|0)==0){am=1377}else{if((c[ai+12>>2]|0)!=(c[ai+16>>2]|0)){if(az){b9=ai;break}else{break L1609}}if((f5[c[(c[ai>>2]|0)+36>>2]&255](ai)|0)==-1){am=1377;break}if(az){b9=ai}else{break L1609}}}while(0);if((am|0)==1377){am=0;if(az){break}else{b9=0}}u=c[C>>2]|0;ah=c[u+12>>2]|0;if((ah|0)==(c[u+16>>2]|0)){ca=(f5[c[(c[u>>2]|0)+36>>2]&255](u)|0)&255}else{ca=a[ah]|0}if((a[aA]&1)==0){cb=at}else{cb=c[av>>2]|0}if(ca<<24>>24!=(a[cb+ax|0]|0)){break}ah=ax+1|0;u=c[C>>2]|0;T=u+12|0;v=c[T>>2]|0;if((v|0)==(c[u+16>>2]|0)){D=c[(c[u>>2]|0)+40>>2]|0;f5[D&255](u)|0;ax=ah;ai=b9;continue}else{c[T>>2]=v+1;ax=ah;ai=b9;continue}}c[k>>2]=c[k>>2]|4;b4=0;b5=ap;b6=ao;break L1583}}while(0);if((ap|0)==(aq|0)){b4=1;b5=aq;b6=ao;break}c[N>>2]=0;tQ(G,ap,aq,N);if((c[N>>2]|0)==0){b4=1;b5=ap;b6=ao;break}c[k>>2]=c[k>>2]|4;b4=0;b5=ap;b6=ao}}while(0);do{if((a[S]&1)!=0){ao=c[r>>2]|0;if((ao|0)==0){break}yt(ao)}}while(0);do{if((a[R]&1)!=0){r=c[B>>2]|0;if((r|0)==0){break}yt(r)}}while(0);do{if((a[Q]&1)!=0){B=c[X>>2]|0;if((B|0)==0){break}yt(B)}}while(0);do{if((a[P]&1)!=0){X=c[E>>2]|0;if((X|0)==0){break}yt(X)}}while(0);do{if((a[H]&1)!=0){E=c[G+8>>2]|0;if((E|0)==0){break}yt(E)}}while(0);if((b5|0)==0){i=q;return b4|0}f2[b6&1023](b5);i=q;return b4|0}function v4(a){a=a|0;return}function v5(a){a=a|0;if((a|0)==0){return}yt(a);return}function v6(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=ff(8)|0;c[b>>2]=72504;d=b+4|0;e=d;if((d|0)==0){dr(b|0,79088,154)}d=yA(a|0)|0;f=d+13|0;g=(f|0)==0?1:f;while(1){h=ys(g)|0;if((h|0)!=0){i=1437;break}f=(I=c[185320]|0,c[185320]=I+0,I);if((f|0)==0){i=1431;break}gs[f&63]()}if((i|0)==1437){g=d+1|0;c[h+4>>2]=d;c[h>>2]=d;d=h+12|0;c[e>>2]=d;c[h+8>>2]=0;yE(d|0,a|0,g)|0;dr(b|0,79088,154)}else if((i|0)==1431){i=ff(4)|0;c[i>>2]=72440;dr(i|0,79056,316)}}function v7(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;d=i;i=i+144|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+120|0;o=d+128|0;p=d+136|0;q=n|0;c[q>>2]=m;r=n+4|0;c[r>>2]=344;s=m+100|0;m=c[h+28>>2]|0;t=m;u=m+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;if((c[185170]|0)!=-1){c[l>>2]=740680;c[l+4>>2]=210;c[l+8>>2]=0;st(740680,l)}l=(c[185171]|0)-1|0;u=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-u>>2>>>0>l>>>0){v=c[u+(l<<2)>>2]|0;if((v|0)==0){break}w=v;a[p]=0;x=f|0;y=c[x>>2]|0;do{if(v3(e,y,g,t,c[h+4>>2]|0,j,p,w,n,o,s)|0){z=k;if((a[z]&1)==0){a[k+1|0]=0;a[z]=0}else{a[c[k+8>>2]|0]=0;c[k+4>>2]=0}A=v;if((a[p]&1)!=0){B=gm[c[(c[A>>2]|0)+28>>2]&127](w,45)|0;C=a[z]|0;if((C&1)==0){D=(C&255)>>>1;E=10}else{D=c[k+4>>2]|0;E=(c[k>>2]&-2)-1|0}if((D|0)==(E|0)){sA(k,E,1,E,E,0);F=a[z]|0}else{F=C}if((F&1)==0){a[z]=(D<<1)+2&255;G=k+1|0;H=D+1|0}else{C=c[k+8>>2]|0;J=D+1|0;c[k+4>>2]=J;G=C;H=J}a[G+D|0]=B;a[G+H|0]=0}B=gm[c[(c[A>>2]|0)+28>>2]&127](w,48)|0;A=c[o>>2]|0;J=A-1|0;C=c[q>>2]|0;while(1){if(C>>>0>=J>>>0){break}if((a[C]|0)==B<<24>>24){C=C+1|0}else{break}}B=C;J=a[z]|0;K=J&255;if((K&1|0)==0){L=K>>>1}else{L=c[k+4>>2]|0}if((J&1)==0){M=10;N=J}else{J=c[k>>2]|0;M=(J&-2)-1|0;N=J&255}J=A-B|0;if((A|0)==(C|0)){break}if((M-L|0)>>>0<J>>>0){sA(k,M,L+J-M|0,L,L,0);O=a[z]|0}else{O=N}if((O&1)==0){P=k+1|0}else{P=c[k+8>>2]|0}K=A+(L-B)|0;B=C;Q=P+L|0;while(1){a[Q]=a[B]|0;R=B+1|0;if((R|0)==(A|0)){break}B=R;Q=Q+1|0}a[P+K|0]=0;Q=L+J|0;if((a[z]&1)==0){a[z]=Q<<1&255;break}else{c[k+4>>2]=Q;break}}}while(0);w=e|0;v=c[w>>2]|0;do{if((v|0)==0){S=0}else{if((c[v+12>>2]|0)!=(c[v+16>>2]|0)){S=v;break}if((f5[c[(c[v>>2]|0)+36>>2]&255](v)|0)!=-1){S=v;break}c[w>>2]=0;S=0}}while(0);w=(S|0)==0;do{if((y|0)==0){T=1499}else{if((c[y+12>>2]|0)!=(c[y+16>>2]|0)){if(w){break}else{T=1501;break}}if((f5[c[(c[y>>2]|0)+36>>2]&255](y)|0)==-1){c[x>>2]=0;T=1499;break}else{if(w){break}else{T=1501;break}}}}while(0);if((T|0)==1499){if(w){T=1501}}if((T|0)==1501){c[j>>2]=c[j>>2]|2}c[b>>2]=S;x=m+4|0;if(((I=c[x>>2]|0,c[x>>2]=I+ -1,I)|0)==0){f2[c[(c[m>>2]|0)+8>>2]&1023](m)}x=c[q>>2]|0;c[q>>2]=0;if((x|0)==0){i=d;return}f2[c[r>>2]&1023](x);i=d;return}}while(0);d=ff(4)|0;c[d>>2]=72472;dr(d|0,79072,408)}function v8(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=i;i=i+584|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+416|0;o=d+424|0;p=d+432|0;q=d+440|0;r=d+480|0;s=n|0;c[s>>2]=m;t=n+4|0;c[t>>2]=344;u=m+400|0;m=c[h+28>>2]|0;v=m;w=m+4|0;I=c[w>>2]|0,c[w>>2]=I+1,I;if((c[185168]|0)!=-1){c[l>>2]=740672;c[l+4>>2]=210;c[l+8>>2]=0;st(740672,l)}l=(c[185169]|0)-1|0;w=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-w>>2>>>0>l>>>0){x=c[w+(l<<2)>>2]|0;if((x|0)==0){break}y=x;a[p]=0;z=f|0;do{if(v9(e,c[z>>2]|0,g,v,c[h+4>>2]|0,j,p,y,n,o,u)|0){A=q|0;B=c[(c[x>>2]|0)+48>>2]|0;gq[B&31](y,55496,55506,A)|0;B=r|0;C=c[o>>2]|0;D=c[s>>2]|0;E=C-D|0;do{if((E|0)>392){F=ys((E>>2)+2|0)|0;if((F|0)!=0){G=F;H=F;break}F=ff(4)|0;c[F>>2]=72440;dr(F|0,79056,316)}else{G=B;H=0}}while(0);if((a[p]&1)==0){J=G}else{a[G]=45;J=G+1|0}if(D>>>0<C>>>0){E=q+40|0;F=q;K=J;L=D;while(1){M=A;while(1){if((M|0)==(E|0)){N=E;break}if((c[M>>2]|0)==(c[L>>2]|0)){N=M;break}else{M=M+4|0}}a[K]=a[55496+(N-F>>2)|0]|0;M=L+4|0;O=K+1|0;if(M>>>0<(c[o>>2]|0)>>>0){K=O;L=M}else{P=O;break}}}else{P=J}a[P]=0;L=eH(B|0,47496,(K=i,i=i+8|0,c[K>>2]=k,K)|0)|0;i=K;if((L|0)==1){if((H|0)==0){break}yt(H);break}L=ff(8)|0;c[L>>2]=72504;K=L+4|0;F=K;do{if((K|0)!=0){while(1){Q=ys(28)|0;if((Q|0)!=0){R=1557;break}E=(I=c[185320]|0,c[185320]=I+0,I);if((E|0)==0){break}gs[E&63]()}if((R|0)==1557){c[Q+4>>2]=15;c[Q>>2]=15;E=Q+12|0;c[F>>2]=E;c[Q+8>>2]=0;yE(E|0,46392,16)|0;break}E=ff(4)|0;c[E>>2]=72440;dr(E|0,79056,316)}}while(0);dr(L|0,79088,154)}}while(0);y=e|0;x=c[y>>2]|0;do{if((x|0)==0){S=0}else{F=c[x+12>>2]|0;if((F|0)==(c[x+16>>2]|0)){T=f5[c[(c[x>>2]|0)+36>>2]&255](x)|0}else{T=c[F>>2]|0}if((T|0)!=-1){S=x;break}c[y>>2]=0;S=0}}while(0);y=(S|0)==0;x=c[z>>2]|0;do{if((x|0)==0){R=1576}else{F=c[x+12>>2]|0;if((F|0)==(c[x+16>>2]|0)){U=f5[c[(c[x>>2]|0)+36>>2]&255](x)|0}else{U=c[F>>2]|0}if((U|0)==-1){c[z>>2]=0;R=1576;break}else{if(y){break}else{R=1578;break}}}}while(0);if((R|0)==1576){if(y){R=1578}}if((R|0)==1578){c[j>>2]=c[j>>2]|2}c[b>>2]=S;z=m+4|0;if(((I=c[z>>2]|0,c[z>>2]=I+ -1,I)|0)==0){f2[c[(c[m>>2]|0)+8>>2]&1023](m)}z=c[s>>2]|0;c[s>>2]=0;if((z|0)==0){i=d;return}f2[c[t>>2]&1023](z);i=d;return}}while(0);d=ff(4)|0;c[d>>2]=72472;dr(d|0,79072,408)}function v9(b,e,f,g,h,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0;p=i;i=i+592|0;q=p|0;r=p+16|0;s=p+32|0;t=p+40|0;u=p+56|0;v=p+72|0;w=p+88|0;x=p+104|0;y=p+112|0;z=p+128|0;A=p+144|0;B=p+160|0;C=p+176|0;D=p+184|0;E=p+584|0;F=E;G=i;i=i+12|0;i=i+7>>3<<3;H=G;I=i;i=i+12|0;i=i+7>>3<<3;J=i;i=i+12|0;i=i+7>>3<<3;K=i;i=i+12|0;i=i+7>>3<<3;L=i;i=i+12|0;i=i+7>>3<<3;M=i;i=i+4|0;i=i+7>>3<<3;c[C>>2]=o;o=D|0;yB(H|0,0,12);N=I;O=J;P=K;Q=L;yB(N|0,0,12);yB(O|0,0,12);yB(P|0,0,12);yB(Q|0,0,12);R=t;S=u;T=v;U=w;V=y;W=z;X=A;Y=B;L1858:do{if(f){Z=s;if((c[185284]|0)!=-1){c[r>>2]=741136;c[r+4>>2]=210;c[r+8>>2]=0;st(741136,r)}_=(c[185285]|0)-1|0;$=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-$>>2>>>0>_>>>0){aa=c[$+(_<<2)>>2]|0;if((aa|0)==0){break}ab=aa;f3[c[(c[aa>>2]|0)+44>>2]&1023](Z,ab);c[E>>2]=c[s>>2];ac=aa;f3[c[(c[ac>>2]|0)+32>>2]&1023](t,ab);if((a[P]&1)==0){c[K+4>>2]=0;a[P]=0}else{c[c[K+8>>2]>>2]=0;c[K+4>>2]=0}sK(K);c[P>>2]=c[R>>2];c[P+4>>2]=c[R+4>>2];c[P+8>>2]=c[R+8>>2];yB(R|0,0,12);f3[c[(c[ac>>2]|0)+28>>2]&1023](u,ab);if((a[O]&1)==0){c[J+4>>2]=0;a[O]=0}else{c[c[J+8>>2]>>2]=0;c[J+4>>2]=0}sK(J);c[O>>2]=c[S>>2];c[O+4>>2]=c[S+4>>2];c[O+8>>2]=c[S+8>>2];yB(S|0,0,12);ad=aa;ae=f5[c[(c[ad>>2]|0)+12>>2]&255](ab)|0;af=f5[c[(c[ad>>2]|0)+16>>2]&255](ab)|0;f3[c[(c[aa>>2]|0)+20>>2]&1023](v,ab);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}sy(G);c[H>>2]=c[T>>2];c[H+4>>2]=c[T+4>>2];c[H+8>>2]=c[T+8>>2];yB(T|0,0,12);f3[c[(c[ac>>2]|0)+24>>2]&1023](w,ab);if((a[N]&1)==0){c[I+4>>2]=0;a[N]=0}else{c[c[I+8>>2]>>2]=0;c[I+4>>2]=0}sK(I);c[N>>2]=c[U>>2];c[N+4>>2]=c[U+4>>2];c[N+8>>2]=c[U+8>>2];yB(U|0,0,12);ag=f5[c[(c[ad>>2]|0)+36>>2]&255](ab)|0;ah=af;ai=ae;break L1858}}while(0);Z=ff(4)|0;c[Z>>2]=72472;dr(Z|0,79072,408);return 0}else{Z=x;if((c[185286]|0)!=-1){c[q>>2]=741144;c[q+4>>2]=210;c[q+8>>2]=0;st(741144,q)}_=(c[185287]|0)-1|0;$=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-$>>2>>>0>_>>>0){ae=c[$+(_<<2)>>2]|0;if((ae|0)==0){break}af=ae;f3[c[(c[ae>>2]|0)+44>>2]&1023](Z,af);c[E>>2]=c[x>>2];ab=ae;f3[c[(c[ab>>2]|0)+32>>2]&1023](y,af);if((a[P]&1)==0){c[K+4>>2]=0;a[P]=0}else{c[c[K+8>>2]>>2]=0;c[K+4>>2]=0}sK(K);c[P>>2]=c[V>>2];c[P+4>>2]=c[V+4>>2];c[P+8>>2]=c[V+8>>2];yB(V|0,0,12);f3[c[(c[ab>>2]|0)+28>>2]&1023](z,af);if((a[O]&1)==0){c[J+4>>2]=0;a[O]=0}else{c[c[J+8>>2]>>2]=0;c[J+4>>2]=0}sK(J);c[O>>2]=c[W>>2];c[O+4>>2]=c[W+4>>2];c[O+8>>2]=c[W+8>>2];yB(W|0,0,12);ad=ae;ac=f5[c[(c[ad>>2]|0)+12>>2]&255](af)|0;aa=f5[c[(c[ad>>2]|0)+16>>2]&255](af)|0;f3[c[(c[ae>>2]|0)+20>>2]&1023](A,af);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}sy(G);c[H>>2]=c[X>>2];c[H+4>>2]=c[X+4>>2];c[H+8>>2]=c[X+8>>2];yB(X|0,0,12);f3[c[(c[ab>>2]|0)+24>>2]&1023](B,af);if((a[N]&1)==0){c[I+4>>2]=0;a[N]=0}else{c[c[I+8>>2]>>2]=0;c[I+4>>2]=0}sK(I);c[N>>2]=c[Y>>2];c[N+4>>2]=c[Y+4>>2];c[N+8>>2]=c[Y+8>>2];yB(Y|0,0,12);ag=f5[c[(c[ad>>2]|0)+36>>2]&255](af)|0;ah=aa;ai=ac;break L1858}}while(0);Z=ff(4)|0;c[Z>>2]=72472;dr(Z|0,79072,408);return 0}}while(0);Y=m|0;c[n>>2]=c[Y>>2];B=b|0;b=l;X=K+4|0;A=K+8|0;W=J+4|0;z=J+8|0;V=(h&512|0)!=0;h=I+4|0;y=I+8|0;I=L+4|0;x=L+8|0;E=F+3|0;g=G+4|0;q=L|0;U=344;w=o;T=o;o=D+400|0;D=0;v=0;S=ag;ag=e;L1932:while(1){e=c[B>>2]|0;do{if((e|0)==0){aj=1}else{u=c[e+12>>2]|0;if((u|0)==(c[e+16>>2]|0)){ak=f5[c[(c[e>>2]|0)+36>>2]&255](e)|0}else{ak=c[u>>2]|0}if((ak|0)==-1){c[B>>2]=0;aj=1;break}else{aj=(c[B>>2]|0)==0;break}}}while(0);do{if((ag|0)==0){al=1675}else{e=c[ag+12>>2]|0;if((e|0)==(c[ag+16>>2]|0)){am=f5[c[(c[ag>>2]|0)+36>>2]&255](ag)|0}else{am=c[e>>2]|0}if((am|0)==-1){al=1675;break}if(aj){an=ag}else{ao=U;ap=w;aq=T;ar=D;as=ag;al=1940;break L1932}}}while(0);if((al|0)==1675){al=0;if(aj){ao=U;ap=w;aq=T;ar=D;as=0;al=1940;break}else{an=0}}L1954:do{switch(a[F+v|0]|0){case 4:{e=0;u=o;R=T;t=w;s=U;r=an;L1955:while(1){f=c[B>>2]|0;do{if((f|0)==0){at=1}else{Z=c[f+12>>2]|0;if((Z|0)==(c[f+16>>2]|0)){au=f5[c[(c[f>>2]|0)+36>>2]&255](f)|0}else{au=c[Z>>2]|0}if((au|0)==-1){c[B>>2]=0;at=1;break}else{at=(c[B>>2]|0)==0;break}}}while(0);do{if((r|0)==0){al=1853}else{f=c[r+12>>2]|0;if((f|0)==(c[r+16>>2]|0)){av=f5[c[(c[r>>2]|0)+36>>2]&255](r)|0}else{av=c[f>>2]|0}if((av|0)==-1){al=1853;break}if(at){aw=r}else{ax=r;break L1955}}}while(0);if((al|0)==1853){al=0;if(at){ax=0;break}else{aw=0}}f=c[B>>2]|0;Z=c[f+12>>2]|0;if((Z|0)==(c[f+16>>2]|0)){ay=f5[c[(c[f>>2]|0)+36>>2]&255](f)|0}else{ay=c[Z>>2]|0}if(ga[c[(c[b>>2]|0)+12>>2]&127](l,2048,ay)|0){Z=c[n>>2]|0;if((Z|0)==(c[C>>2]|0)){wd(m,n,C);az=c[n>>2]|0}else{az=Z}c[n>>2]=az+4;c[az>>2]=ay;aA=e+1|0;aB=u;aC=R;aD=t;aE=s}else{Z=d[H]|0;if(!((((((Z&1|0)==0?Z>>>1:c[g>>2]|0)|0)==0|(e|0)==0)^1)&(ay|0)==(ah|0))){ax=aw;break}if((R|0)==(u|0)){Z=R-t|0;f=Z>>>0<2147483647?Z<<1:-1;if((s|0)==344){aF=0}else{aF=t}_=yu(aF,f)|0;$=_;if((_|0)==0){al=1869;break L1932}aG=$+(f>>>2<<2)|0;aH=$+(Z>>2<<2)|0;aI=$;aJ=174}else{aG=u;aH=R;aI=t;aJ=s}c[aH>>2]=e;aA=0;aB=aG;aC=aH+4|0;aD=aI;aE=aJ}$=c[B>>2]|0;Z=$+12|0;f=c[Z>>2]|0;if((f|0)==(c[$+16>>2]|0)){_=c[(c[$>>2]|0)+40>>2]|0;f5[_&255]($)|0;e=aA;u=aB;R=aC;t=aD;s=aE;r=aw;continue}else{c[Z>>2]=f+4;e=aA;u=aB;R=aC;t=aD;s=aE;r=aw;continue}}if((t|0)==(R|0)|(e|0)==0){aK=u;aL=R;aM=t;aN=s}else{if((R|0)==(u|0)){r=R-t|0;f=r>>>0<2147483647?r<<1:-1;if((s|0)==344){aO=0}else{aO=t}Z=yu(aO,f)|0;$=Z;if((Z|0)==0){al=1881;break L1932}aP=$+(f>>>2<<2)|0;aQ=$+(r>>2<<2)|0;aR=$;aS=174}else{aP=u;aQ=R;aR=t;aS=s}c[aQ>>2]=e;aK=aP;aL=aQ+4|0;aM=aR;aN=aS}if((S|0)>0){$=c[B>>2]|0;do{if(($|0)==0){aT=1}else{r=c[$+12>>2]|0;if((r|0)==(c[$+16>>2]|0)){aU=f5[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{aU=c[r>>2]|0}if((aU|0)==-1){c[B>>2]=0;aT=1;break}else{aT=(c[B>>2]|0)==0;break}}}while(0);do{if((ax|0)==0){al=1898}else{$=c[ax+12>>2]|0;if(($|0)==(c[ax+16>>2]|0)){aV=f5[c[(c[ax>>2]|0)+36>>2]&255](ax)|0}else{aV=c[$>>2]|0}if((aV|0)==-1){al=1898;break}if(aT){aW=ax}else{al=1904;break L1932}}}while(0);if((al|0)==1898){al=0;if(aT){al=1904;break L1932}else{aW=0}}$=c[B>>2]|0;e=c[$+12>>2]|0;if((e|0)==(c[$+16>>2]|0)){aX=f5[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{aX=c[e>>2]|0}if((aX|0)!=(ai|0)){al=1904;break L1932}e=c[B>>2]|0;$=e+12|0;s=c[$>>2]|0;if((s|0)==(c[e+16>>2]|0)){t=c[(c[e>>2]|0)+40>>2]|0;f5[t&255](e)|0;aY=aW;aZ=S;a_=aW}else{c[$>>2]=s+4;aY=aW;aZ=S;a_=aW}while(1){s=c[B>>2]|0;do{if((s|0)==0){a$=1}else{$=c[s+12>>2]|0;if(($|0)==(c[s+16>>2]|0)){a0=f5[c[(c[s>>2]|0)+36>>2]&255](s)|0}else{a0=c[$>>2]|0}if((a0|0)==-1){c[B>>2]=0;a$=1;break}else{a$=(c[B>>2]|0)==0;break}}}while(0);do{if((aY|0)==0){a1=a_;al=1920}else{s=c[aY+12>>2]|0;if((s|0)==(c[aY+16>>2]|0)){a2=f5[c[(c[aY>>2]|0)+36>>2]&255](aY)|0}else{a2=c[s>>2]|0}if((a2|0)==-1){a1=0;al=1920;break}if(a$){a3=aY;a4=a_}else{al=1927;break L1932}}}while(0);if((al|0)==1920){al=0;if(a$){al=1927;break L1932}else{a3=0;a4=a1}}s=c[B>>2]|0;$=c[s+12>>2]|0;if(($|0)==(c[s+16>>2]|0)){a5=f5[c[(c[s>>2]|0)+36>>2]&255](s)|0}else{a5=c[$>>2]|0}if(!(ga[c[(c[b>>2]|0)+12>>2]&127](l,2048,a5)|0)){al=1927;break L1932}if((c[n>>2]|0)==(c[C>>2]|0)){wd(m,n,C)}$=c[B>>2]|0;s=c[$+12>>2]|0;if((s|0)==(c[$+16>>2]|0)){a6=f5[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{a6=c[s>>2]|0}s=c[n>>2]|0;c[n>>2]=s+4;c[s>>2]=a6;s=aZ-1|0;$=c[B>>2]|0;e=$+12|0;t=c[e>>2]|0;if((t|0)==(c[$+16>>2]|0)){R=c[(c[$>>2]|0)+40>>2]|0;f5[R&255]($)|0}else{c[e>>2]=t+4}if((s|0)>0){aY=a3;aZ=s;a_=a4}else{a7=s;a8=a4;break}}}else{a7=S;a8=ax}if((c[n>>2]|0)==(c[Y>>2]|0)){al=1938;break L1932}else{a9=D;ba=aK;bb=aL;bc=aM;bd=aN;be=a7;bf=a8}break};case 1:{if((v|0)==3){ao=U;ap=w;aq=T;ar=D;as=an;al=1940;break L1932}s=c[B>>2]|0;t=c[s+12>>2]|0;if((t|0)==(c[s+16>>2]|0)){bg=f5[c[(c[s>>2]|0)+36>>2]&255](s)|0}else{bg=c[t>>2]|0}if(!(ga[c[(c[b>>2]|0)+12>>2]&127](l,8192,bg)|0)){al=1725;break L1932}t=c[B>>2]|0;s=t+12|0;e=c[s>>2]|0;if((e|0)==(c[t+16>>2]|0)){bh=f5[c[(c[t>>2]|0)+40>>2]&255](t)|0}else{c[s>>2]=e+4;bh=c[e>>2]|0}e=a[Q]|0;if((e&1)==0){bi=(e&255)>>>1;bj=1}else{bi=c[I>>2]|0;bj=(c[q>>2]&-2)-1|0}if((bi|0)==(bj|0)){sL(L,bj,1,bj,bj,0,0);bk=a[Q]|0}else{bk=e}if((bk&1)==0){a[Q]=(bi<<1)+2&255;bl=I;bm=bi+1|0}else{e=c[x>>2]|0;s=bi+1|0;c[I>>2]=s;bl=e;bm=s}c[bl+(bi<<2)>>2]=bh;c[bl+(bm<<2)>>2]=0;al=1726;break};case 3:{s=a[O]|0;e=s&255;t=(e&1|0)==0?e>>>1:c[W>>2]|0;e=a[P]|0;$=e&255;R=($&1|0)==0?$>>>1:c[X>>2]|0;if((t|0)==(-R|0)){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L1954}$=(t|0)==0;t=c[B>>2]|0;u=c[t+12>>2]|0;r=c[t+16>>2]|0;f=(u|0)==(r|0);if(!($|(R|0)==0)){if(f){R=f5[c[(c[t>>2]|0)+36>>2]&255](t)|0;Z=c[B>>2]|0;bn=R;bo=a[O]|0;bp=Z;bq=c[Z+12>>2]|0;br=c[Z+16>>2]|0}else{bn=c[u>>2]|0;bo=s;bp=t;bq=u;br=r}r=bp+12|0;Z=(bq|0)==(br|0);if((bn|0)==(c[((bo&1)==0?W:c[z>>2]|0)>>2]|0)){if(Z){R=c[(c[bp>>2]|0)+40>>2]|0;f5[R&255](bp)|0}else{c[r>>2]=bq+4}r=d[O]|0;a9=((r&1|0)==0?r>>>1:c[W>>2]|0)>>>0>1?J:D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L1954}if(Z){bs=f5[c[(c[bp>>2]|0)+36>>2]&255](bp)|0}else{bs=c[bq>>2]|0}if((bs|0)!=(c[((a[P]&1)==0?X:c[A>>2]|0)>>2]|0)){al=1798;break L1932}Z=c[B>>2]|0;r=Z+12|0;R=c[r>>2]|0;if((R|0)==(c[Z+16>>2]|0)){_=c[(c[Z>>2]|0)+40>>2]|0;f5[_&255](Z)|0}else{c[r>>2]=R+4}a[k]=1;R=d[P]|0;a9=((R&1|0)==0?R>>>1:c[X>>2]|0)>>>0>1?K:D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L1954}if($){if(f){$=f5[c[(c[t>>2]|0)+36>>2]&255](t)|0;bt=$;bu=a[P]|0}else{bt=c[u>>2]|0;bu=e}if((bt|0)!=(c[((bu&1)==0?X:c[A>>2]|0)>>2]|0)){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L1954}e=c[B>>2]|0;$=e+12|0;R=c[$>>2]|0;if((R|0)==(c[e+16>>2]|0)){r=c[(c[e>>2]|0)+40>>2]|0;f5[r&255](e)|0}else{c[$>>2]=R+4}a[k]=1;R=d[P]|0;a9=((R&1|0)==0?R>>>1:c[X>>2]|0)>>>0>1?K:D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L1954}if(f){f=f5[c[(c[t>>2]|0)+36>>2]&255](t)|0;bv=f;bw=a[O]|0}else{bv=c[u>>2]|0;bw=s}if((bv|0)!=(c[((bw&1)==0?W:c[z>>2]|0)>>2]|0)){a[k]=1;a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L1954}s=c[B>>2]|0;u=s+12|0;f=c[u>>2]|0;if((f|0)==(c[s+16>>2]|0)){t=c[(c[s>>2]|0)+40>>2]|0;f5[t&255](s)|0}else{c[u>>2]=f+4}f=d[O]|0;a9=((f&1|0)==0?f>>>1:c[W>>2]|0)>>>0>1?J:D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break};case 0:{al=1726;break};case 2:{if(!((D|0)!=0|v>>>0<2)){if((v|0)==2){bx=(a[E]|0)!=0}else{bx=0}if(!(V|bx)){a9=0;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L1954}}f=a[N]|0;u=c[y>>2]|0;s=(f&1)==0?h:u;L2164:do{if((v|0)==0){by=s;bz=f;bA=u}else{if((d[F+(v-1)|0]|0)>=2){by=s;bz=f;bA=u;break}t=f&255;L2167:do{if((((t&1|0)==0?t>>>1:c[h>>2]|0)|0)==0){bB=f;bC=s;bD=u}else{R=s;while(1){if(!(ga[c[(c[b>>2]|0)+12>>2]&127](l,8192,c[R>>2]|0)|0)){break}$=R+4|0;e=a[N]|0;r=c[y>>2]|0;Z=e&255;if(($|0)==(((e&1)==0?h:r)+(((Z&1|0)==0?Z>>>1:c[h>>2]|0)<<2)|0)){bB=e;bC=$;bD=r;break L2167}else{R=$}}bB=a[N]|0;bC=R;bD=c[y>>2]|0}}while(0);t=(bB&1)==0?h:bD;$=bC-t>>2;r=a[Q]|0;e=r&255;Z=(e&1|0)==0?e>>>1:c[I>>2]|0;if($>>>0>Z>>>0){by=t;bz=bB;bA=bD;break}e=(r&1)==0?I:c[x>>2]|0;r=e+(Z<<2)|0;if(($|0)==0){by=bC;bz=bB;bA=bD;break}_=e+(Z-$<<2)|0;$=t;while(1){if((c[_>>2]|0)!=(c[$>>2]|0)){by=t;bz=bB;bA=bD;break L2164}Z=_+4|0;if((Z|0)==(r|0)){by=bC;bz=bB;bA=bD;break}else{_=Z;$=$+4|0}}}}while(0);s=bz&255;L2180:do{if((by|0)==(((bz&1)==0?h:bA)+(((s&1|0)==0?s>>>1:c[h>>2]|0)<<2)|0)){bE=by;bF=an}else{u=an;f=by;$=an;while(1){_=c[B>>2]|0;do{if((_|0)==0){bG=1}else{r=c[_+12>>2]|0;if((r|0)==(c[_+16>>2]|0)){bH=f5[c[(c[_>>2]|0)+36>>2]&255](_)|0}else{bH=c[r>>2]|0}if((bH|0)==-1){c[B>>2]=0;bG=1;break}else{bG=(c[B>>2]|0)==0;break}}}while(0);do{if((u|0)==0){bI=$;al=1828}else{_=c[u+12>>2]|0;if((_|0)==(c[u+16>>2]|0)){bJ=f5[c[(c[u>>2]|0)+36>>2]&255](u)|0}else{bJ=c[_>>2]|0}if((bJ|0)==-1){bI=0;al=1828;break}if(bG){bK=u;bL=$}else{bE=f;bF=$;break L2180}}}while(0);if((al|0)==1828){al=0;if(bG){bE=f;bF=bI;break L2180}else{bK=0;bL=bI}}_=c[B>>2]|0;R=c[_+12>>2]|0;if((R|0)==(c[_+16>>2]|0)){bM=f5[c[(c[_>>2]|0)+36>>2]&255](_)|0}else{bM=c[R>>2]|0}if((bM|0)!=(c[f>>2]|0)){bE=f;bF=bL;break L2180}R=c[B>>2]|0;_=R+12|0;r=c[_>>2]|0;if((r|0)==(c[R+16>>2]|0)){t=c[(c[R>>2]|0)+40>>2]|0;f5[t&255](R)|0}else{c[_>>2]=r+4}r=f+4|0;_=a[N]|0;R=_&255;if((r|0)==(((_&1)==0?h:c[y>>2]|0)+(((R&1|0)==0?R>>>1:c[h>>2]|0)<<2)|0)){bE=r;bF=bL;break}else{u=bK;f=r;$=bL}}}}while(0);if(!V){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=bF;break L1954}s=a[N]|0;$=s&255;if((bE|0)==(((s&1)==0?h:c[y>>2]|0)+((($&1|0)==0?$>>>1:c[h>>2]|0)<<2)|0)){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=bF}else{al=1840;break L1932}break};default:{a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an}}}while(0);L2214:do{if((al|0)==1726){al=0;if((v|0)==3){ao=U;ap=w;aq=T;ar=D;as=an;al=1940;break L1932}else{bN=an;bO=an}while(1){$=c[B>>2]|0;do{if(($|0)==0){bP=1}else{s=c[$+12>>2]|0;if((s|0)==(c[$+16>>2]|0)){bQ=f5[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{bQ=c[s>>2]|0}if((bQ|0)==-1){c[B>>2]=0;bP=1;break}else{bP=(c[B>>2]|0)==0;break}}}while(0);do{if((bN|0)==0){bR=bO;al=1739}else{$=c[bN+12>>2]|0;if(($|0)==(c[bN+16>>2]|0)){bS=f5[c[(c[bN>>2]|0)+36>>2]&255](bN)|0}else{bS=c[$>>2]|0}if((bS|0)==-1){bR=0;al=1739;break}if(bP){bT=bN;bU=bO}else{a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=bO;break L2214}}}while(0);if((al|0)==1739){al=0;if(bP){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=bR;break L2214}else{bT=0;bU=bR}}$=c[B>>2]|0;s=c[$+12>>2]|0;if((s|0)==(c[$+16>>2]|0)){bV=f5[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{bV=c[s>>2]|0}if(!(ga[c[(c[b>>2]|0)+12>>2]&127](l,8192,bV)|0)){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=bU;break L2214}s=c[B>>2]|0;$=s+12|0;f=c[$>>2]|0;if((f|0)==(c[s+16>>2]|0)){bW=f5[c[(c[s>>2]|0)+40>>2]&255](s)|0}else{c[$>>2]=f+4;bW=c[f>>2]|0}f=a[Q]|0;if((f&1)==0){bX=(f&255)>>>1;bY=1}else{bX=c[I>>2]|0;bY=(c[q>>2]&-2)-1|0}if((bX|0)==(bY|0)){sL(L,bY,1,bY,bY,0,0);bZ=a[Q]|0}else{bZ=f}if((bZ&1)==0){a[Q]=(bX<<1)+2&255;b_=I;b$=bX+1|0}else{f=c[x>>2]|0;$=bX+1|0;c[I>>2]=$;b_=f;b$=$}c[b_+(bX<<2)>>2]=bW;c[b_+(b$<<2)>>2]=0;bN=bT;bO=bU}}}while(0);$=v+1|0;if($>>>0<4){U=bd;w=bc;T=bb;o=ba;D=a9;v=$;S=be;ag=bf}else{ao=bd;ap=bc;aq=bb;ar=a9;as=bf;al=1940;break}}L2261:do{if((al|0)==1840){c[j>>2]=c[j>>2]|4;b0=0;b1=w;b2=U}else if((al|0)==1725){c[j>>2]=c[j>>2]|4;b0=0;b1=w;b2=U}else if((al|0)==1798){c[j>>2]=c[j>>2]|4;b0=0;b1=w;b2=U}else if((al|0)==1869){bf=ff(4)|0;c[bf>>2]=72440;dr(bf|0,79056,316);return 0}else if((al|0)==1881){bf=ff(4)|0;c[bf>>2]=72440;dr(bf|0,79056,316);return 0}else if((al|0)==1904){c[j>>2]=c[j>>2]|4;b0=0;b1=aM;b2=aN}else if((al|0)==1927){c[j>>2]=c[j>>2]|4;b0=0;b1=aM;b2=aN}else if((al|0)==1938){c[j>>2]=c[j>>2]|4;b0=0;b1=aM;b2=aN}else if((al|0)==1940){L2273:do{if((ar|0)!=0){bf=ar;a9=ar+4|0;bb=ar+8|0;bc=1;bd=as;L2275:while(1){ag=d[bf]|0;if((ag&1|0)==0){b3=ag>>>1}else{b3=c[a9>>2]|0}if(bc>>>0>=b3>>>0){break L2273}ag=c[B>>2]|0;do{if((ag|0)==0){b4=1}else{be=c[ag+12>>2]|0;if((be|0)==(c[ag+16>>2]|0)){b5=f5[c[(c[ag>>2]|0)+36>>2]&255](ag)|0}else{b5=c[be>>2]|0}if((b5|0)==-1){c[B>>2]=0;b4=1;break}else{b4=(c[B>>2]|0)==0;break}}}while(0);do{if((bd|0)==0){al=1958}else{ag=c[bd+12>>2]|0;if((ag|0)==(c[bd+16>>2]|0)){b6=f5[c[(c[bd>>2]|0)+36>>2]&255](bd)|0}else{b6=c[ag>>2]|0}if((b6|0)==-1){al=1958;break}if(b4){b7=bd}else{break L2275}}}while(0);if((al|0)==1958){al=0;if(b4){break}else{b7=0}}ag=c[B>>2]|0;be=c[ag+12>>2]|0;if((be|0)==(c[ag+16>>2]|0)){b8=f5[c[(c[ag>>2]|0)+36>>2]&255](ag)|0}else{b8=c[be>>2]|0}if((a[bf]&1)==0){b9=a9}else{b9=c[bb>>2]|0}if((b8|0)!=(c[b9+(bc<<2)>>2]|0)){break}be=bc+1|0;ag=c[B>>2]|0;S=ag+12|0;v=c[S>>2]|0;if((v|0)==(c[ag+16>>2]|0)){D=c[(c[ag>>2]|0)+40>>2]|0;f5[D&255](ag)|0;bc=be;bd=b7;continue}else{c[S>>2]=v+4;bc=be;bd=b7;continue}}c[j>>2]=c[j>>2]|4;b0=0;b1=ap;b2=ao;break L2261}}while(0);if((ap|0)==(aq|0)){b0=1;b1=aq;b2=ao;break}c[M>>2]=0;tQ(G,ap,aq,M);if((c[M>>2]|0)==0){b0=1;b1=ap;b2=ao;break}c[j>>2]=c[j>>2]|4;b0=0;b1=ap;b2=ao}}while(0);do{if((a[Q]&1)!=0){ao=c[x>>2]|0;if((ao|0)==0){break}yt(ao)}}while(0);do{if((a[P]&1)!=0){x=c[A>>2]|0;if((x|0)==0){break}yt(x)}}while(0);do{if((a[O]&1)!=0){A=c[z>>2]|0;if((A|0)==0){break}yt(A)}}while(0);do{if((a[N]&1)!=0){z=c[y>>2]|0;if((z|0)==0){break}yt(z)}}while(0);do{if((a[H]&1)!=0){y=c[G+8>>2]|0;if((y|0)==0){break}yt(y)}}while(0);if((b1|0)==0){i=p;return b0|0}f2[b2&1023](b1);i=p;return b0|0}function wa(a){a=a|0;return}function wb(a){a=a|0;if((a|0)==0){return}yt(a);return}function wc(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;d=i;i=i+440|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+416|0;o=d+424|0;p=d+432|0;q=n|0;c[q>>2]=m;r=n+4|0;c[r>>2]=344;s=m+400|0;m=c[h+28>>2]|0;t=m;u=m+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;if((c[185168]|0)!=-1){c[l>>2]=740672;c[l+4>>2]=210;c[l+8>>2]=0;st(740672,l)}l=(c[185169]|0)-1|0;u=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-u>>2>>>0>l>>>0){v=c[u+(l<<2)>>2]|0;if((v|0)==0){break}w=v;a[p]=0;x=f|0;y=c[x>>2]|0;do{if(v9(e,y,g,t,c[h+4>>2]|0,j,p,w,n,o,s)|0){z=k;if((a[z]&1)==0){c[k+4>>2]=0;a[z]=0}else{c[c[k+8>>2]>>2]=0;c[k+4>>2]=0}A=v;if((a[p]&1)!=0){B=gm[c[(c[A>>2]|0)+44>>2]&127](w,45)|0;C=a[z]|0;if((C&1)==0){D=(C&255)>>>1;E=1}else{D=c[k+4>>2]|0;E=(c[k>>2]&-2)-1|0}if((D|0)==(E|0)){sL(k,E,1,E,E,0,0);F=a[z]|0}else{F=C}if((F&1)==0){a[z]=(D<<1)+2&255;G=k+4|0;H=D+1|0}else{C=c[k+8>>2]|0;J=D+1|0;c[k+4>>2]=J;G=C;H=J}c[G+(D<<2)>>2]=B;c[G+(H<<2)>>2]=0}B=gm[c[(c[A>>2]|0)+44>>2]&127](w,48)|0;A=c[o>>2]|0;J=A-4|0;C=c[q>>2]|0;while(1){if(C>>>0>=J>>>0){break}if((c[C>>2]|0)==(B|0)){C=C+4|0}else{break}}B=C;K=a[z]|0;L=K&255;if((L&1|0)==0){M=L>>>1}else{M=c[k+4>>2]|0}if((K&1)==0){N=1;O=K}else{K=c[k>>2]|0;N=(K&-2)-1|0;O=K&255}K=A-B>>2;if((K|0)==0){break}if((N-M|0)>>>0<K>>>0){sL(k,N,M+K-N|0,M,M,0,0);P=a[z]|0}else{P=O}if((P&1)==0){Q=k+4|0}else{Q=c[k+8>>2]|0}L=Q+(M<<2)|0;if((C|0)==(A|0)){R=L}else{S=((J+(-B|0)|0)>>>2)+1|0;B=C;T=L;while(1){c[T>>2]=c[B>>2];L=B+4|0;if((L|0)==(A|0)){break}B=L;T=T+4|0}R=Q+(S+M<<2)|0}c[R>>2]=0;T=M+K|0;if((a[z]&1)==0){a[z]=T<<1&255;break}else{c[k+4>>2]=T;break}}}while(0);w=e|0;v=c[w>>2]|0;do{if((v|0)==0){U=0}else{T=c[v+12>>2]|0;if((T|0)==(c[v+16>>2]|0)){V=f5[c[(c[v>>2]|0)+36>>2]&255](v)|0}else{V=c[T>>2]|0}if((V|0)!=-1){U=v;break}c[w>>2]=0;U=0}}while(0);w=(U|0)==0;do{if((y|0)==0){W=2060}else{v=c[y+12>>2]|0;if((v|0)==(c[y+16>>2]|0)){X=f5[c[(c[y>>2]|0)+36>>2]&255](y)|0}else{X=c[v>>2]|0}if((X|0)==-1){c[x>>2]=0;W=2060;break}else{if(w){break}else{W=2062;break}}}}while(0);if((W|0)==2060){if(w){W=2062}}if((W|0)==2062){c[j>>2]=c[j>>2]|2}c[b>>2]=U;x=m+4|0;if(((I=c[x>>2]|0,c[x>>2]=I+ -1,I)|0)==0){f2[c[(c[m>>2]|0)+8>>2]&1023](m)}x=c[q>>2]|0;c[q>>2]=0;if((x|0)==0){i=d;return}f2[c[r>>2]&1023](x);i=d;return}}while(0);d=ff(4)|0;c[d>>2]=72472;dr(d|0,79072,408)}function wd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a+4|0;f=(c[e>>2]|0)!=344;g=a|0;a=c[g>>2]|0;h=a;i=(c[d>>2]|0)-h|0;j=i>>>0<2147483647?i<<1:-1;i=(c[b>>2]|0)-h>>2;if(f){k=a}else{k=0}a=yu(k,j)|0;k=a;if((a|0)==0){a=ff(4)|0;c[a>>2]=72440;dr(a|0,79056,316)}do{if(f){c[g>>2]=k;l=k}else{a=c[g>>2]|0;c[g>>2]=k;if((a|0)==0){l=k;break}f2[c[e>>2]&1023](a);l=c[g>>2]|0}}while(0);c[e>>2]=174;c[b>>2]=l+(i<<2);c[d>>2]=(c[g>>2]|0)+(j>>>2<<2);return}function we(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=+l;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+272|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=e|0;n=e+120|0;o=e+232|0;p=e+240|0;q=e+248|0;r=e+256|0;s=r;t=i;i=i+12|0;i=i+7>>3<<3;u=t;v=i;i=i+12|0;i=i+7>>3<<3;w=v;x=i;i=i+4|0;i=i+7>>3<<3;y=i;i=i+100|0;i=i+7>>3<<3;z=i;i=i+4|0;i=i+7>>3<<3;A=i;i=i+4|0;i=i+7>>3<<3;B=e+16|0;c[n>>2]=B;C=e+128|0;D=b5(B|0,100,44992,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;do{if(D>>>0>99){do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);E=uC(n,c[141570]|0,44992,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;F=c[n>>2]|0;if((F|0)==0){G=ff(4)|0;c[G>>2]=72440;dr(G|0,79056,316)}G=ys(E)|0;if((G|0)!=0){H=G;J=E;K=F;L=G;break}G=ff(4)|0;c[G>>2]=72440;dr(G|0,79056,316)}else{H=C;J=D;K=0;L=0}}while(0);D=c[j+28>>2]|0;C=D;B=D+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[185170]|0)!=-1){c[m>>2]=740680;c[m+4>>2]=210;c[m+8>>2]=0;st(740680,m)}m=(c[185171]|0)-1|0;B=c[D+8>>2]|0;do{if((c[D+12>>2]|0)-B>>2>>>0>m>>>0){G=c[B+(m<<2)>>2]|0;if((G|0)==0){break}F=G;E=c[n>>2]|0;M=E+J|0;N=c[(c[G>>2]|0)+32>>2]|0;gq[N&31](F,E,M,H)|0;if((J|0)==0){O=0}else{O=(a[c[n>>2]|0]|0)==45}yB(s|0,0,12);yB(u|0,0,12);yB(w|0,0,12);wf(g,O,C,o,p,q,r,t,v,x);M=y|0;E=c[x>>2]|0;if((J|0)>(E|0)){N=d[w]|0;if((N&1|0)==0){P=N>>>1}else{P=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){Q=N>>>1}else{Q=c[t+4>>2]|0}R=P+(J-E<<1|1)+Q|0}else{N=d[w]|0;if((N&1|0)==0){S=N>>>1}else{S=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){T=N>>>1}else{T=c[t+4>>2]|0}R=S+2+T|0}N=R+E|0;do{if(N>>>0>100){G=ys(N)|0;if((G|0)!=0){U=G;V=G;break}G=ff(4)|0;c[G>>2]=72440;dr(G|0,79056,316)}else{U=M;V=0}}while(0);wg(U,z,A,c[j+4>>2]|0,H,H+J|0,F,O,o,a[p]|0,a[q]|0,r,t,v,E);ux(b,c[f>>2]|0,U,c[z>>2]|0,c[A>>2]|0,j,k);if((V|0)!=0){yt(V)}do{if((a[w]&1)!=0){M=c[v+8>>2]|0;if((M|0)==0){break}yt(M)}}while(0);do{if((a[u]&1)!=0){E=c[t+8>>2]|0;if((E|0)==0){break}yt(E)}}while(0);do{if((a[s]&1)!=0){E=c[r+8>>2]|0;if((E|0)==0){break}yt(E)}}while(0);E=D+4|0;if(((I=c[E>>2]|0,c[E>>2]=I+ -1,I)|0)==0){f2[c[(c[D>>2]|0)+8>>2]&1023](D)}if((L|0)!=0){yt(L)}if((K|0)==0){i=e;return}yt(K);i=e;return}}while(0);e=ff(4)|0;c[e>>2]=72472;dr(e|0,79072,408)}function wf(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;n=i;i=i+40|0;o=n|0;p=n+16|0;q=n+32|0;r=q;s=i;i=i+12|0;i=i+7>>3<<3;t=s;u=i;i=i+4|0;i=i+7>>3<<3;v=u;w=i;i=i+12|0;i=i+7>>3<<3;x=w;y=i;i=i+12|0;i=i+7>>3<<3;z=y;A=i;i=i+12|0;i=i+7>>3<<3;B=A;D=i;i=i+4|0;i=i+7>>3<<3;E=D;F=i;i=i+12|0;i=i+7>>3<<3;G=F;H=i;i=i+4|0;i=i+7>>3<<3;I=H;J=i;i=i+12|0;i=i+7>>3<<3;K=J;L=i;i=i+12|0;i=i+7>>3<<3;M=L;N=i;i=i+12|0;i=i+7>>3<<3;O=N;if(b){if((c[185288]|0)!=-1){c[p>>2]=741152;c[p+4>>2]=210;c[p+8>>2]=0;st(741152,p)}p=(c[185289]|0)-1|0;b=c[e+8>>2]|0;if((c[e+12>>2]|0)-b>>2>>>0<=p>>>0){P=ff(4)|0;Q=P;c[Q>>2]=72472;dr(P|0,79072,408)}R=c[b+(p<<2)>>2]|0;if((R|0)==0){P=ff(4)|0;Q=P;c[Q>>2]=72472;dr(P|0,79072,408)}P=R;Q=c[R>>2]|0;if(d){f3[c[Q+44>>2]&1023](r,P);r=f;C=c[q>>2]|0;a[r]=C&255;C=C>>8;a[r+1|0]=C&255;C=C>>8;a[r+2|0]=C&255;C=C>>8;a[r+3|0]=C&255;f3[c[(c[R>>2]|0)+32>>2]&1023](s,P);s=l;if((a[s]&1)==0){a[l+1|0]=0;a[s]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}sy(l);c[s>>2]=c[t>>2];c[s+4>>2]=c[t+4>>2];c[s+8>>2]=c[t+8>>2];yB(t|0,0,12)}else{f3[c[Q+40>>2]&1023](v,P);v=f;C=c[u>>2]|0;a[v]=C&255;C=C>>8;a[v+1|0]=C&255;C=C>>8;a[v+2|0]=C&255;C=C>>8;a[v+3|0]=C&255;f3[c[(c[R>>2]|0)+28>>2]&1023](w,P);w=l;if((a[w]&1)==0){a[l+1|0]=0;a[w]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}sy(l);c[w>>2]=c[x>>2];c[w+4>>2]=c[x+4>>2];c[w+8>>2]=c[x+8>>2];yB(x|0,0,12)}x=R;a[g]=f5[c[(c[x>>2]|0)+12>>2]&255](P)|0;a[h]=f5[c[(c[x>>2]|0)+16>>2]&255](P)|0;x=R;f3[c[(c[x>>2]|0)+20>>2]&1023](y,P);y=j;if((a[y]&1)==0){a[j+1|0]=0;a[y]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}sy(j);c[y>>2]=c[z>>2];c[y+4>>2]=c[z+4>>2];c[y+8>>2]=c[z+8>>2];yB(z|0,0,12);f3[c[(c[x>>2]|0)+24>>2]&1023](A,P);A=k;if((a[A]&1)==0){a[k+1|0]=0;a[A]=0}else{a[c[k+8>>2]|0]=0;c[k+4>>2]=0}sy(k);c[A>>2]=c[B>>2];c[A+4>>2]=c[B+4>>2];c[A+8>>2]=c[B+8>>2];yB(B|0,0,12);S=f5[c[(c[R>>2]|0)+36>>2]&255](P)|0;c[m>>2]=S;i=n;return}else{if((c[185290]|0)!=-1){c[o>>2]=741160;c[o+4>>2]=210;c[o+8>>2]=0;st(741160,o)}o=(c[185291]|0)-1|0;P=c[e+8>>2]|0;if((c[e+12>>2]|0)-P>>2>>>0<=o>>>0){T=ff(4)|0;U=T;c[U>>2]=72472;dr(T|0,79072,408)}e=c[P+(o<<2)>>2]|0;if((e|0)==0){T=ff(4)|0;U=T;c[U>>2]=72472;dr(T|0,79072,408)}T=e;U=c[e>>2]|0;if(d){f3[c[U+44>>2]&1023](E,T);E=f;C=c[D>>2]|0;a[E]=C&255;C=C>>8;a[E+1|0]=C&255;C=C>>8;a[E+2|0]=C&255;C=C>>8;a[E+3|0]=C&255;f3[c[(c[e>>2]|0)+32>>2]&1023](F,T);F=l;if((a[F]&1)==0){a[l+1|0]=0;a[F]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}sy(l);c[F>>2]=c[G>>2];c[F+4>>2]=c[G+4>>2];c[F+8>>2]=c[G+8>>2];yB(G|0,0,12)}else{f3[c[U+40>>2]&1023](I,T);I=f;C=c[H>>2]|0;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;f3[c[(c[e>>2]|0)+28>>2]&1023](J,T);J=l;if((a[J]&1)==0){a[l+1|0]=0;a[J]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}sy(l);c[J>>2]=c[K>>2];c[J+4>>2]=c[K+4>>2];c[J+8>>2]=c[K+8>>2];yB(K|0,0,12)}K=e;a[g]=f5[c[(c[K>>2]|0)+12>>2]&255](T)|0;a[h]=f5[c[(c[K>>2]|0)+16>>2]&255](T)|0;K=e;f3[c[(c[K>>2]|0)+20>>2]&1023](L,T);L=j;if((a[L]&1)==0){a[j+1|0]=0;a[L]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}sy(j);c[L>>2]=c[M>>2];c[L+4>>2]=c[M+4>>2];c[L+8>>2]=c[M+8>>2];yB(M|0,0,12);f3[c[(c[K>>2]|0)+24>>2]&1023](N,T);N=k;if((a[N]&1)==0){a[k+1|0]=0;a[N]=0}else{a[c[k+8>>2]|0]=0;c[k+4>>2]=0}sy(k);c[N>>2]=c[O>>2];c[N+4>>2]=c[O+4>>2];c[N+8>>2]=c[O+8>>2];yB(O|0,0,12);S=f5[c[(c[e>>2]|0)+36>>2]&255](T)|0;c[m>>2]=S;i=n;return}}function wg(d,e,f,g,h,i,j,k,l,m,n,o,p,q,r){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;c[f>>2]=d;s=j;t=q;u=q+1|0;v=q+8|0;w=q+4|0;q=p;x=(g&512|0)==0;y=p+1|0;z=p+4|0;A=p+8|0;p=j+8|0;B=(r|0)>0;C=o;D=o+1|0;E=o+8|0;F=o+4|0;o=-r|0;G=r-1|0;H=(G|0)>0;I=h;h=0;while(1){L2610:do{switch(a[l+h|0]|0){case 1:{c[e>>2]=c[f>>2];J=gm[c[(c[s>>2]|0)+28>>2]&127](j,32)|0;K=c[f>>2]|0;c[f>>2]=K+1;a[K]=J;L=I;break};case 3:{J=a[t]|0;K=J&255;if((K&1|0)==0){M=K>>>1}else{M=c[w>>2]|0}if((M|0)==0){L=I;break L2610}if((J&1)==0){N=u}else{N=c[v>>2]|0}J=a[N]|0;K=c[f>>2]|0;c[f>>2]=K+1;a[K]=J;L=I;break};case 2:{J=a[q]|0;K=J&255;O=(K&1|0)==0;if(O){P=K>>>1}else{P=c[z>>2]|0}if((P|0)==0|x){L=I;break L2610}if((J&1)==0){Q=y}else{Q=c[A>>2]|0}if(O){R=K>>>1}else{R=c[z>>2]|0}K=Q+R|0;O=c[f>>2]|0;if((R|0)==0){S=O}else{J=Q;T=O;while(1){a[T]=a[J]|0;U=J+1|0;if((U|0)==(K|0)){break}else{J=U;T=T+1|0}}S=O+R|0}c[f>>2]=S;L=I;break};case 4:{T=c[f>>2]|0;J=k?I+1|0:I;K=J;while(1){if(K>>>0>=i>>>0){break}U=a[K]|0;if(U<<24>>24<=-1){break}if((b[(c[p>>2]|0)+(U<<24>>24<<1)>>1]&2048)==0){break}else{K=K+1|0}}O=K;if(B){if(K>>>0>J>>>0){U=J+(-O|0)|0;O=U>>>0<o>>>0?o:U;U=O+r|0;V=K-1|0;W=a[V]|0;c[f>>2]=T+1;a[T]=W;if(V>>>0>J>>>0&H){W=V;V=G;while(1){X=c[f>>2]|0;Y=W-1|0;Z=a[Y]|0;c[f>>2]=X+1;a[X]=Z;Z=V-1|0;X=(Z|0)>0;if(Y>>>0>J>>>0&X){W=Y;V=Z}else{_=X;break}}}else{_=H}V=K+O|0;if(_){$=U;aa=V;ab=2274}else{ac=0;ad=U;ae=V}}else{$=r;aa=K;ab=2274}if((ab|0)==2274){ab=0;ac=gm[c[(c[s>>2]|0)+28>>2]&127](j,48)|0;ad=$;ae=aa}V=c[f>>2]|0;c[f>>2]=V+1;if((ad|0)>0){W=ad;X=V;while(1){a[X]=ac;Z=W-1|0;Y=c[f>>2]|0;c[f>>2]=Y+1;if((Z|0)>0){W=Z;X=Y}else{af=Y;break}}}else{af=V}a[af]=m;ag=ae}else{ag=K}if((ag|0)==(J|0)){X=gm[c[(c[s>>2]|0)+28>>2]&127](j,48)|0;W=c[f>>2]|0;c[f>>2]=W+1;a[W]=X}else{X=a[C]|0;W=X&255;if((W&1|0)==0){ah=W>>>1}else{ah=c[F>>2]|0}if((ah|0)==0){ai=ag;aj=0;ak=0;al=-1}else{if((X&1)==0){am=D}else{am=c[E>>2]|0}ai=ag;aj=0;ak=0;al=a[am]|0}while(1){do{if((aj|0)==(al|0)){X=c[f>>2]|0;c[f>>2]=X+1;a[X]=n;X=ak+1|0;W=a[C]|0;U=W&255;if((U&1|0)==0){an=U>>>1}else{an=c[F>>2]|0}if(X>>>0>=an>>>0){ao=al;ap=X;aq=0;break}U=(W&1)==0;if(U){ar=D}else{ar=c[E>>2]|0}if((a[ar+X|0]|0)==127){ao=-1;ap=X;aq=0;break}if(U){as=D}else{as=c[E>>2]|0}ao=a[as+X|0]|0;ap=X;aq=0}else{ao=al;ap=ak;aq=aj}}while(0);X=ai-1|0;U=a[X]|0;W=c[f>>2]|0;c[f>>2]=W+1;a[W]=U;if((X|0)==(J|0)){break}else{ai=X;aj=aq+1|0;ak=ap;al=ao}}}K=c[f>>2]|0;if((T|0)==(K|0)){L=J;break L2610}V=K-1|0;if(T>>>0<V>>>0){at=T;au=V}else{L=J;break L2610}while(1){V=a[at]|0;a[at]=a[au]|0;a[au]=V;V=at+1|0;K=au-1|0;if(V>>>0<K>>>0){at=V;au=K}else{L=J;break}}break};case 0:{c[e>>2]=c[f>>2];L=I;break};default:{L=I}}}while(0);J=h+1|0;if(J>>>0<4){I=L;h=J}else{break}}h=a[t]|0;t=h&255;L=(t&1|0)==0;if(L){av=t>>>1}else{av=c[w>>2]|0}if(av>>>0>1){if((h&1)==0){aw=u}else{aw=c[v>>2]|0}if(L){ax=t>>>1}else{ax=c[w>>2]|0}w=aw+ax|0;t=c[f>>2]|0;if((ax|0)==1){ay=t}else{L=ax-1|0;ax=t;v=aw+1|0;while(1){a[ax]=a[v]|0;aw=v+1|0;if((aw|0)==(w|0)){break}else{ax=ax+1|0;v=aw}}ay=t+L|0}c[f>>2]=ay}ay=g&176;if((ay|0)==32){c[e>>2]=c[f>>2];return}else if((ay|0)==16){return}else{c[e>>2]=d;return}}function wh(a){a=a|0;return}function wi(a){a=a|0;if((a|0)==0){return}yt(a);return}function wj(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+56|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=e|0;m=e+16|0;n=e+24|0;o=e+32|0;p=e+40|0;q=p;r=i;i=i+12|0;i=i+7>>3<<3;s=r;t=i;i=i+12|0;i=i+7>>3<<3;u=t;v=i;i=i+4|0;i=i+7>>3<<3;w=i;i=i+100|0;i=i+7>>3<<3;x=i;i=i+4|0;i=i+7>>3<<3;y=i;i=i+4|0;i=i+7>>3<<3;z=c[h+28>>2]|0;A=z;B=z+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[185170]|0)!=-1){c[l>>2]=740680;c[l+4>>2]=210;c[l+8>>2]=0;st(740680,l)}l=(c[185171]|0)-1|0;B=c[z+8>>2]|0;do{if((c[z+12>>2]|0)-B>>2>>>0>l>>>0){C=c[B+(l<<2)>>2]|0;if((C|0)==0){break}D=C;E=k;F=k;G=a[F]|0;H=G&255;if((H&1|0)==0){J=H>>>1}else{J=c[k+4>>2]|0}if((J|0)==0){K=0}else{if((G&1)==0){L=E+1|0}else{L=c[k+8>>2]|0}G=a[L]|0;K=G<<24>>24==(gm[c[(c[C>>2]|0)+28>>2]&127](D,45)|0)<<24>>24}yB(q|0,0,12);yB(s|0,0,12);yB(u|0,0,12);wf(g,K,A,m,n,o,p,r,t,v);C=w|0;G=a[F]|0;F=G&255;H=(F&1|0)==0;if(H){M=F>>>1}else{M=c[k+4>>2]|0}N=c[v>>2]|0;if((M|0)>(N|0)){if(H){O=F>>>1}else{O=c[k+4>>2]|0}P=d[u]|0;if((P&1|0)==0){Q=P>>>1}else{Q=c[t+4>>2]|0}P=d[s]|0;if((P&1|0)==0){R=P>>>1}else{R=c[r+4>>2]|0}S=Q+(O-N<<1|1)+R|0}else{P=d[u]|0;if((P&1|0)==0){T=P>>>1}else{T=c[t+4>>2]|0}P=d[s]|0;if((P&1|0)==0){U=P>>>1}else{U=c[r+4>>2]|0}S=T+2+U|0}P=S+N|0;do{if(P>>>0>100){V=ys(P)|0;if((V|0)!=0){W=V;X=V;break}V=ff(4)|0;c[V>>2]=72440;dr(V|0,79056,316)}else{W=C;X=0}}while(0);if((G&1)==0){Y=E+1|0}else{Y=c[k+8>>2]|0}if(H){Z=F>>>1}else{Z=c[k+4>>2]|0}wg(W,x,y,c[h+4>>2]|0,Y,Y+Z|0,D,K,m,a[n]|0,a[o]|0,p,r,t,N);ux(b,c[f>>2]|0,W,c[x>>2]|0,c[y>>2]|0,h,j);if((X|0)!=0){yt(X)}do{if((a[u]&1)!=0){C=c[t+8>>2]|0;if((C|0)==0){break}yt(C)}}while(0);do{if((a[s]&1)!=0){N=c[r+8>>2]|0;if((N|0)==0){break}yt(N)}}while(0);do{if((a[q]&1)!=0){N=c[p+8>>2]|0;if((N|0)==0){break}yt(N)}}while(0);N=z+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)!=0){i=e;return}f2[c[(c[z>>2]|0)+8>>2]&1023](z);i=e;return}}while(0);e=ff(4)|0;c[e>>2]=72472;dr(e|0,79072,408)}function wk(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=+l;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+568|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=e|0;n=e+120|0;o=e+528|0;p=e+536|0;q=e+544|0;r=e+552|0;s=r;t=i;i=i+12|0;i=i+7>>3<<3;u=t;v=i;i=i+12|0;i=i+7>>3<<3;w=v;x=i;i=i+4|0;i=i+7>>3<<3;y=i;i=i+400|0;z=i;i=i+4|0;i=i+7>>3<<3;A=i;i=i+4|0;i=i+7>>3<<3;B=e+16|0;c[n>>2]=B;C=e+128|0;D=b5(B|0,100,44992,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;do{if(D>>>0>99){do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);E=uC(n,c[141570]|0,44992,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;F=c[n>>2]|0;if((F|0)==0){G=ff(4)|0;c[G>>2]=72440;dr(G|0,79056,316)}G=ys(E<<2)|0;H=G;if((G|0)!=0){J=H;K=E;L=F;M=H;break}H=ff(4)|0;c[H>>2]=72440;dr(H|0,79056,316)}else{J=C;K=D;L=0;M=0}}while(0);D=c[j+28>>2]|0;C=D;B=D+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[185168]|0)!=-1){c[m>>2]=740672;c[m+4>>2]=210;c[m+8>>2]=0;st(740672,m)}m=(c[185169]|0)-1|0;B=c[D+8>>2]|0;do{if((c[D+12>>2]|0)-B>>2>>>0>m>>>0){H=c[B+(m<<2)>>2]|0;if((H|0)==0){break}F=H;E=c[n>>2]|0;G=E+K|0;N=c[(c[H>>2]|0)+48>>2]|0;gq[N&31](F,E,G,J)|0;if((K|0)==0){O=0}else{O=(a[c[n>>2]|0]|0)==45}yB(s|0,0,12);yB(u|0,0,12);yB(w|0,0,12);wl(g,O,C,o,p,q,r,t,v,x);G=y|0;E=c[x>>2]|0;if((K|0)>(E|0)){N=d[w]|0;if((N&1|0)==0){P=N>>>1}else{P=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){Q=N>>>1}else{Q=c[t+4>>2]|0}R=P+(K-E<<1|1)+Q|0}else{N=d[w]|0;if((N&1|0)==0){S=N>>>1}else{S=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){T=N>>>1}else{T=c[t+4>>2]|0}R=S+2+T|0}N=R+E|0;do{if(N>>>0>100){H=ys(N<<2)|0;U=H;if((H|0)!=0){V=U;W=U;break}U=ff(4)|0;c[U>>2]=72440;dr(U|0,79056,316)}else{V=G;W=0}}while(0);wm(V,z,A,c[j+4>>2]|0,J,J+(K<<2)|0,F,O,o,c[p>>2]|0,c[q>>2]|0,r,t,v,E);uM(b,c[f>>2]|0,V,c[z>>2]|0,c[A>>2]|0,j,k);if((W|0)!=0){yt(W)}do{if((a[w]&1)!=0){G=c[v+8>>2]|0;if((G|0)==0){break}yt(G)}}while(0);do{if((a[u]&1)!=0){E=c[t+8>>2]|0;if((E|0)==0){break}yt(E)}}while(0);do{if((a[s]&1)!=0){E=c[r+8>>2]|0;if((E|0)==0){break}yt(E)}}while(0);E=D+4|0;if(((I=c[E>>2]|0,c[E>>2]=I+ -1,I)|0)==0){f2[c[(c[D>>2]|0)+8>>2]&1023](D)}if((M|0)!=0){yt(M)}if((L|0)==0){i=e;return}yt(L);i=e;return}}while(0);e=ff(4)|0;c[e>>2]=72472;dr(e|0,79072,408)}function wl(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;n=i;i=i+40|0;o=n|0;p=n+16|0;q=n+32|0;r=q;s=i;i=i+12|0;i=i+7>>3<<3;t=s;u=i;i=i+4|0;i=i+7>>3<<3;v=u;w=i;i=i+12|0;i=i+7>>3<<3;x=w;y=i;i=i+12|0;i=i+7>>3<<3;z=y;A=i;i=i+12|0;i=i+7>>3<<3;B=A;D=i;i=i+4|0;i=i+7>>3<<3;E=D;F=i;i=i+12|0;i=i+7>>3<<3;G=F;H=i;i=i+4|0;i=i+7>>3<<3;I=H;J=i;i=i+12|0;i=i+7>>3<<3;K=J;L=i;i=i+12|0;i=i+7>>3<<3;M=L;N=i;i=i+12|0;i=i+7>>3<<3;O=N;if(b){if((c[185284]|0)!=-1){c[p>>2]=741136;c[p+4>>2]=210;c[p+8>>2]=0;st(741136,p)}p=(c[185285]|0)-1|0;b=c[e+8>>2]|0;if((c[e+12>>2]|0)-b>>2>>>0<=p>>>0){P=ff(4)|0;Q=P;c[Q>>2]=72472;dr(P|0,79072,408)}R=c[b+(p<<2)>>2]|0;if((R|0)==0){P=ff(4)|0;Q=P;c[Q>>2]=72472;dr(P|0,79072,408)}P=R;Q=c[R>>2]|0;if(d){f3[c[Q+44>>2]&1023](r,P);r=f;C=c[q>>2]|0;a[r]=C&255;C=C>>8;a[r+1|0]=C&255;C=C>>8;a[r+2|0]=C&255;C=C>>8;a[r+3|0]=C&255;f3[c[(c[R>>2]|0)+32>>2]&1023](s,P);s=l;if((a[s]&1)==0){c[l+4>>2]=0;a[s]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}sK(l);c[s>>2]=c[t>>2];c[s+4>>2]=c[t+4>>2];c[s+8>>2]=c[t+8>>2];yB(t|0,0,12)}else{f3[c[Q+40>>2]&1023](v,P);v=f;C=c[u>>2]|0;a[v]=C&255;C=C>>8;a[v+1|0]=C&255;C=C>>8;a[v+2|0]=C&255;C=C>>8;a[v+3|0]=C&255;f3[c[(c[R>>2]|0)+28>>2]&1023](w,P);w=l;if((a[w]&1)==0){c[l+4>>2]=0;a[w]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}sK(l);c[w>>2]=c[x>>2];c[w+4>>2]=c[x+4>>2];c[w+8>>2]=c[x+8>>2];yB(x|0,0,12)}x=R;c[g>>2]=f5[c[(c[x>>2]|0)+12>>2]&255](P)|0;c[h>>2]=f5[c[(c[x>>2]|0)+16>>2]&255](P)|0;f3[c[(c[R>>2]|0)+20>>2]&1023](y,P);y=j;if((a[y]&1)==0){a[j+1|0]=0;a[y]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}sy(j);c[y>>2]=c[z>>2];c[y+4>>2]=c[z+4>>2];c[y+8>>2]=c[z+8>>2];yB(z|0,0,12);f3[c[(c[R>>2]|0)+24>>2]&1023](A,P);A=k;if((a[A]&1)==0){c[k+4>>2]=0;a[A]=0}else{c[c[k+8>>2]>>2]=0;c[k+4>>2]=0}sK(k);c[A>>2]=c[B>>2];c[A+4>>2]=c[B+4>>2];c[A+8>>2]=c[B+8>>2];yB(B|0,0,12);S=f5[c[(c[x>>2]|0)+36>>2]&255](P)|0;c[m>>2]=S;i=n;return}else{if((c[185286]|0)!=-1){c[o>>2]=741144;c[o+4>>2]=210;c[o+8>>2]=0;st(741144,o)}o=(c[185287]|0)-1|0;P=c[e+8>>2]|0;if((c[e+12>>2]|0)-P>>2>>>0<=o>>>0){T=ff(4)|0;U=T;c[U>>2]=72472;dr(T|0,79072,408)}e=c[P+(o<<2)>>2]|0;if((e|0)==0){T=ff(4)|0;U=T;c[U>>2]=72472;dr(T|0,79072,408)}T=e;U=c[e>>2]|0;if(d){f3[c[U+44>>2]&1023](E,T);E=f;C=c[D>>2]|0;a[E]=C&255;C=C>>8;a[E+1|0]=C&255;C=C>>8;a[E+2|0]=C&255;C=C>>8;a[E+3|0]=C&255;f3[c[(c[e>>2]|0)+32>>2]&1023](F,T);F=l;if((a[F]&1)==0){c[l+4>>2]=0;a[F]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}sK(l);c[F>>2]=c[G>>2];c[F+4>>2]=c[G+4>>2];c[F+8>>2]=c[G+8>>2];yB(G|0,0,12)}else{f3[c[U+40>>2]&1023](I,T);I=f;C=c[H>>2]|0;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;f3[c[(c[e>>2]|0)+28>>2]&1023](J,T);J=l;if((a[J]&1)==0){c[l+4>>2]=0;a[J]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}sK(l);c[J>>2]=c[K>>2];c[J+4>>2]=c[K+4>>2];c[J+8>>2]=c[K+8>>2];yB(K|0,0,12)}K=e;c[g>>2]=f5[c[(c[K>>2]|0)+12>>2]&255](T)|0;c[h>>2]=f5[c[(c[K>>2]|0)+16>>2]&255](T)|0;f3[c[(c[e>>2]|0)+20>>2]&1023](L,T);L=j;if((a[L]&1)==0){a[j+1|0]=0;a[L]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}sy(j);c[L>>2]=c[M>>2];c[L+4>>2]=c[M+4>>2];c[L+8>>2]=c[M+8>>2];yB(M|0,0,12);f3[c[(c[e>>2]|0)+24>>2]&1023](N,T);N=k;if((a[N]&1)==0){c[k+4>>2]=0;a[N]=0}else{c[c[k+8>>2]>>2]=0;c[k+4>>2]=0}sK(k);c[N>>2]=c[O>>2];c[N+4>>2]=c[O+4>>2];c[N+8>>2]=c[O+8>>2];yB(O|0,0,12);S=f5[c[(c[K>>2]|0)+36>>2]&255](T)|0;c[m>>2]=S;i=n;return}}function wm(b,d,e,f,g,h,i,j,k,l,m,n,o,p,q){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;c[e>>2]=b;r=i;s=p;t=p+4|0;u=p+8|0;p=o;v=(f&512|0)==0;w=o+4|0;x=o+8|0;o=i;y=(q|0)>0;z=n;A=n+1|0;B=n+8|0;C=n+4|0;n=g;g=0;while(1){L2969:do{switch(a[k+g|0]|0){case 0:{c[d>>2]=c[e>>2];D=n;break};case 1:{c[d>>2]=c[e>>2];E=gm[c[(c[r>>2]|0)+44>>2]&127](i,32)|0;F=c[e>>2]|0;c[e>>2]=F+4;c[F>>2]=E;D=n;break};case 2:{E=a[p]|0;F=E&255;G=(F&1|0)==0;if(G){H=F>>>1}else{H=c[w>>2]|0}if((H|0)==0|v){D=n;break L2969}if((E&1)==0){I=w}else{I=c[x>>2]|0}if(G){J=F>>>1}else{J=c[w>>2]|0}F=I+(J<<2)|0;G=c[e>>2]|0;if((J|0)==0){K=G}else{E=I+(J-1<<2)+(-I|0)|0;L=I;M=G;while(1){c[M>>2]=c[L>>2];N=L+4|0;if((N|0)==(F|0)){break}L=N;M=M+4|0}K=G+((E>>>2)+1<<2)|0}c[e>>2]=K;D=n;break};case 4:{M=c[e>>2]|0;L=j?n+4|0:n;F=L;while(1){if(F>>>0>=h>>>0){break}if(ga[c[(c[o>>2]|0)+12>>2]&127](i,2048,c[F>>2]|0)|0){F=F+4|0}else{break}}if(y){do{if(F>>>0>L>>>0){E=F;G=q;do{E=E-4|0;N=c[E>>2]|0;O=c[e>>2]|0;c[e>>2]=O+4;c[O>>2]=N;G=G-1|0;P=(G|0)>0;}while(E>>>0>L>>>0&P);if(P){Q=G;R=E;S=2598;break}N=c[e>>2]|0;c[e>>2]=N+4;T=N;U=E}else{Q=q;R=F;S=2598}}while(0);do{if((S|0)==2598){S=0;N=gm[c[(c[r>>2]|0)+44>>2]&127](i,48)|0;O=c[e>>2]|0;c[e>>2]=O+4;if((Q|0)>0){V=Q;W=O}else{T=O;U=R;break}while(1){c[W>>2]=N;O=V-1|0;X=c[e>>2]|0;c[e>>2]=X+4;if((O|0)>0){V=O;W=X}else{T=X;U=R;break}}}}while(0);c[T>>2]=l;Y=U}else{Y=F}if((Y|0)==(L|0)){N=gm[c[(c[r>>2]|0)+44>>2]&127](i,48)|0;E=c[e>>2]|0;c[e>>2]=E+4;c[E>>2]=N}else{N=a[z]|0;E=N&255;if((E&1|0)==0){Z=E>>>1}else{Z=c[C>>2]|0}if((Z|0)==0){_=Y;$=0;aa=0;ab=-1}else{if((N&1)==0){ac=A}else{ac=c[B>>2]|0}_=Y;$=0;aa=0;ab=a[ac]|0}while(1){do{if(($|0)==(ab|0)){N=c[e>>2]|0;c[e>>2]=N+4;c[N>>2]=m;N=aa+1|0;E=a[z]|0;G=E&255;if((G&1|0)==0){ad=G>>>1}else{ad=c[C>>2]|0}if(N>>>0>=ad>>>0){ae=ab;af=N;ag=0;break}G=(E&1)==0;if(G){ah=A}else{ah=c[B>>2]|0}if((a[ah+N|0]|0)==127){ae=-1;af=N;ag=0;break}if(G){ai=A}else{ai=c[B>>2]|0}ae=a[ai+N|0]|0;af=N;ag=0}else{ae=ab;af=aa;ag=$}}while(0);N=_-4|0;G=c[N>>2]|0;E=c[e>>2]|0;c[e>>2]=E+4;c[E>>2]=G;if((N|0)==(L|0)){break}else{_=N;$=ag+1|0;aa=af;ab=ae}}}F=c[e>>2]|0;if((M|0)==(F|0)){D=L;break L2969}N=F-4|0;if(M>>>0<N>>>0){aj=M;ak=N}else{D=L;break L2969}while(1){N=c[aj>>2]|0;c[aj>>2]=c[ak>>2];c[ak>>2]=N;N=aj+4|0;F=ak-4|0;if(N>>>0<F>>>0){aj=N;ak=F}else{D=L;break}}break};case 3:{L=a[s]|0;M=L&255;if((M&1|0)==0){al=M>>>1}else{al=c[t>>2]|0}if((al|0)==0){D=n;break L2969}if((L&1)==0){am=t}else{am=c[u>>2]|0}L=c[am>>2]|0;M=c[e>>2]|0;c[e>>2]=M+4;c[M>>2]=L;D=n;break};default:{D=n}}}while(0);L=g+1|0;if(L>>>0<4){n=D;g=L}else{break}}g=a[s]|0;s=g&255;D=(s&1|0)==0;if(D){an=s>>>1}else{an=c[t>>2]|0}if(an>>>0>1){if((g&1)==0){ao=t}else{ao=c[u>>2]|0}if(D){ap=s>>>1}else{ap=c[t>>2]|0}t=ao+(ap<<2)|0;s=c[e>>2]|0;if((ap|0)==1){aq=s}else{D=(ao+(ap-2<<2)+(-ao|0)|0)>>>2;ap=s;u=ao+4|0;while(1){c[ap>>2]=c[u>>2];ao=u+4|0;if((ao|0)==(t|0)){break}else{ap=ap+4|0;u=ao}}aq=s+(D+1<<2)|0}c[e>>2]=aq}aq=f&176;if((aq|0)==32){c[d>>2]=c[e>>2];return}else if((aq|0)==16){return}else{c[d>>2]=b;return}}function wn(a){a=a|0;return}function wo(a){a=a|0;return}function wp(a){a=a|0;if((a|0)==0){return}yt(a);return}function wq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((a[d]&1)==0){f=d+1|0}else{f=c[d+8>>2]|0}d=bI(f|0,200)|0;return d>>>(((d|0)!=-1|0)>>>0)|0}function wr(a,b){a=a|0;b=b|0;ea(((b|0)==-1?-1:b<<1)|0)|0;return}function ws(a){a=a|0;if((a|0)==0){return}yt(a);return}function wt(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((a[d]&1)==0){f=d+1|0}else{f=c[d+8>>2]|0}d=bI(f|0,200)|0;return d>>>(((d|0)!=-1|0)>>>0)|0}function wu(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+56|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=e|0;m=e+16|0;n=e+24|0;o=e+32|0;p=e+40|0;q=p;r=i;i=i+12|0;i=i+7>>3<<3;s=r;t=i;i=i+12|0;i=i+7>>3<<3;u=t;v=i;i=i+4|0;i=i+7>>3<<3;w=i;i=i+400|0;x=i;i=i+4|0;i=i+7>>3<<3;y=i;i=i+4|0;i=i+7>>3<<3;z=c[h+28>>2]|0;A=z;B=z+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[185168]|0)!=-1){c[l>>2]=740672;c[l+4>>2]=210;c[l+8>>2]=0;st(740672,l)}l=(c[185169]|0)-1|0;B=c[z+8>>2]|0;do{if((c[z+12>>2]|0)-B>>2>>>0>l>>>0){C=c[B+(l<<2)>>2]|0;if((C|0)==0){break}D=C;E=k;F=a[E]|0;G=F&255;if((G&1|0)==0){H=G>>>1}else{H=c[k+4>>2]|0}if((H|0)==0){J=0}else{if((F&1)==0){K=k+4|0}else{K=c[k+8>>2]|0}F=c[K>>2]|0;J=(F|0)==(gm[c[(c[C>>2]|0)+44>>2]&127](D,45)|0)}yB(q|0,0,12);yB(s|0,0,12);yB(u|0,0,12);wl(g,J,A,m,n,o,p,r,t,v);C=w|0;F=a[E]|0;E=F&255;G=(E&1|0)==0;if(G){L=E>>>1}else{L=c[k+4>>2]|0}M=c[v>>2]|0;if((L|0)>(M|0)){if(G){N=E>>>1}else{N=c[k+4>>2]|0}O=d[u]|0;if((O&1|0)==0){P=O>>>1}else{P=c[t+4>>2]|0}O=d[s]|0;if((O&1|0)==0){Q=O>>>1}else{Q=c[r+4>>2]|0}R=P+(N-M<<1|1)+Q|0}else{O=d[u]|0;if((O&1|0)==0){S=O>>>1}else{S=c[t+4>>2]|0}O=d[s]|0;if((O&1|0)==0){T=O>>>1}else{T=c[r+4>>2]|0}R=S+2+T|0}O=R+M|0;do{if(O>>>0>100){U=ys(O<<2)|0;V=U;if((U|0)!=0){W=V;X=V;break}V=ff(4)|0;c[V>>2]=72440;dr(V|0,79056,316)}else{W=C;X=0}}while(0);if((F&1)==0){Y=k+4|0}else{Y=c[k+8>>2]|0}if(G){Z=E>>>1}else{Z=c[k+4>>2]|0}wm(W,x,y,c[h+4>>2]|0,Y,Y+(Z<<2)|0,D,J,m,c[n>>2]|0,c[o>>2]|0,p,r,t,M);uM(b,c[f>>2]|0,W,c[x>>2]|0,c[y>>2]|0,h,j);if((X|0)!=0){yt(X)}do{if((a[u]&1)!=0){C=c[t+8>>2]|0;if((C|0)==0){break}yt(C)}}while(0);do{if((a[s]&1)!=0){M=c[r+8>>2]|0;if((M|0)==0){break}yt(M)}}while(0);do{if((a[q]&1)!=0){M=c[p+8>>2]|0;if((M|0)==0){break}yt(M)}}while(0);M=z+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)!=0){i=e;return}f2[c[(c[z>>2]|0)+8>>2]&1023](z);i=e;return}}while(0);e=ff(4)|0;c[e>>2]=72472;dr(e|0,79072,408)}function wv(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=i;i=i+16|0;j=d|0;k=j;yB(k|0,0,12);l=b;m=a[h]|0;if((m&1)==0){n=h+1|0}else{n=c[h+8>>2]|0}o=m&255;if((o&1|0)==0){p=o>>>1}else{p=c[h+4>>2]|0}h=n+p|0;do{if((p|0)>0){o=j+1|0;m=j+8|0;q=j|0;r=j+4|0;s=n;t=0;L3198:while(1){u=a[s]|0;if((t&1)==0){v=(t&255)>>>1;w=10;x=t}else{y=c[q>>2]|0;v=c[r>>2]|0;w=(y&-2)-1|0;x=y&255}if((v|0)==(w|0)){if((w|0)==-3){z=2763;break}y=(x&1)==0?o:c[m>>2]|0;do{if(w>>>0<2147483631){A=w+1|0;B=w<<1;C=A>>>0<B>>>0?B:A;if(C>>>0<11){D=11;break}D=C+16&-16}else{D=-2}}while(0);C=(D|0)==0?1:D;while(1){E=ys(C)|0;if((E|0)!=0){break}A=(I=c[185320]|0,c[185320]=I+0,I);if((A|0)==0){z=2777;break L3198}gs[A&63]()}yE(E|0,y|0,w)|0;if(!((w|0)==10|(y|0)==0)){yt(y)}c[m>>2]=E;C=D|1;c[q>>2]=C;F=C&255}else{F=t}if((F&1)==0){a[k]=(v<<1)+2&255;G=o;H=v+1|0}else{C=c[m>>2]|0;A=v+1|0;c[r>>2]=A;G=C;H=A}a[G+v|0]=u;a[G+H|0]=0;A=s+1|0;J=a[k]|0;if(A>>>0<h>>>0){s=A;t=J}else{z=2786;break}}if((z|0)==2786){K=(J&1)==0?o:c[m>>2]|0;L=(e|0)==-1?-1:e<<1;break}else if((z|0)==2777){t=ff(4)|0;c[t>>2]=72440;dr(t|0,79056,316)}else if((z|0)==2763){su()}}else{K=j+1|0;L=(e|0)==-1?-1:e<<1}}while(0);e=fZ(L|0,f|0,g|0,K|0)|0;yB(l|0,0,12);K=yA(e|0)|0;g=e+K|0;L3233:do{if((K|0)>0){f=b+1|0;L=b+8|0;z=b+4|0;J=b|0;h=e;H=0;while(1){G=a[h]|0;if((H&1)==0){M=(H&255)>>>1;N=10}else{M=c[z>>2]|0;N=(c[J>>2]&-2)-1|0}if((M|0)==(N|0)){sA(b,N,1,N,N,0);O=a[l]|0}else{O=H}if((O&1)==0){a[l]=(M<<1)+2&255;P=f;Q=M+1|0}else{v=c[L>>2]|0;F=M+1|0;c[z>>2]=F;P=v;Q=F}a[P+M|0]=G;a[P+Q|0]=0;G=h+1|0;if(G>>>0>=g>>>0){break L3233}h=G;H=a[l]|0}}}while(0);if((a[k]&1)==0){i=d;return}k=c[j+8>>2]|0;if((k|0)==0){i=d;return}yt(k);i=d;return}function ww(a,b){a=a|0;b=b|0;ea(((b|0)==-1?-1:b<<1)|0)|0;return}function wx(a){a=a|0;wB(a);if((a|0)==0){return}yt(a);return}function wy(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;d=i;i=i+224|0;j=d|0;k=d+8|0;l=d+40|0;m=d+48|0;n=d+56|0;o=d+64|0;p=d+192|0;q=d+200|0;r=d+208|0;s=r;t=i;i=i+8|0;u=i;i=i+8|0;yB(s|0,0,12);v=b;w=t|0;c[t+4>>2]=0;c[t>>2]=74240;x=a[h]|0;if((x&1)==0){y=h+4|0}else{y=c[h+8>>2]|0}z=x&255;if((z&1|0)==0){A=z>>>1}else{A=c[h+4>>2]|0}h=y+(A<<2)|0;do{if((A|0)>0){z=t;x=k|0;B=k+32|0;C=r+1|0;D=r+8|0;E=r|0;F=r+4|0;G=y;H=74240;L3276:while(1){c[m>>2]=G;J=(gt[c[H+12>>2]&31](w,j,G,h,m,x,B,l)|0)==2;K=c[m>>2]|0;if(J|(K|0)==(G|0)){L=2837;break}if(x>>>0<(c[l>>2]|0)>>>0){J=x;do{M=a[J]|0;N=a[s]|0;if((N&1)==0){O=(N&255)>>>1;P=10;Q=N}else{R=c[E>>2]|0;O=c[F>>2]|0;P=(R&-2)-1|0;Q=R&255}if((O|0)==(P|0)){if((P|0)==-3){L=2862;break L3276}R=(Q&1)==0?C:c[D>>2]|0;do{if(P>>>0<2147483631){S=P+1|0;T=P<<1;U=S>>>0<T>>>0?T:S;if(U>>>0<11){V=11;break}V=U+16&-16}else{V=-2}}while(0);U=(V|0)==0?1:V;while(1){W=ys(U)|0;if((W|0)!=0){break}S=(I=c[185320]|0,c[185320]=I+0,I);if((S|0)==0){L=2876;break L3276}gs[S&63]()}yE(W|0,R|0,P)|0;if(!((P|0)==10|(R|0)==0)){yt(R)}c[D>>2]=W;U=V|1;c[E>>2]=U;X=U&255}else{X=N}if((X&1)==0){a[s]=(O<<1)+2&255;Y=C;Z=O+1|0}else{U=c[D>>2]|0;S=O+1|0;c[F>>2]=S;Y=U;Z=S}a[Y+O|0]=M;a[Y+Z|0]=0;J=J+1|0;}while(J>>>0<(c[l>>2]|0)>>>0);_=c[m>>2]|0}else{_=K}if(_>>>0>=h>>>0){L=2888;break}G=_;H=c[z>>2]|0}if((L|0)==2876){z=ff(4)|0;c[z>>2]=72440;dr(z|0,79056,316)}else if((L|0)==2837){z=ff(8)|0;c[z>>2]=72504;H=z+4|0;G=H;do{if((H|0)!=0){while(1){$=ys(33)|0;if(($|0)!=0){L=2852;break}F=(I=c[185320]|0,c[185320]=I+0,I);if((F|0)==0){break}gs[F&63]()}if((L|0)==2852){c[$+4>>2]=20;c[$>>2]=20;K=$+12|0;c[G>>2]=K;c[$+8>>2]=0;yE(K|0,26544,21)|0;break}K=ff(4)|0;c[K>>2]=72440;dr(K|0,79056,316)}}while(0);dr(z|0,79088,154)}else if((L|0)==2888){aa=(a[s]&1)==0?C:c[D>>2]|0;ab=(e|0)==-1?-1:e<<1;break}else if((L|0)==2862){su()}}else{aa=r+1|0;ab=(e|0)==-1?-1:e<<1}}while(0);e=fZ(ab|0,f|0,g|0,aa|0)|0;yB(v|0,0,12);aa=u|0;c[u+4>>2]=0;c[u>>2]=74184;g=yA(e|0)|0;f=e+g|0;L3330:do{if((g|0)>=1){ab=u;$=f;_=o|0;h=o+128|0;m=b+4|0;l=b+8|0;Z=b|0;Y=e;O=74184;while(1){c[q>>2]=Y;X=(gt[c[O+16>>2]&31](aa,n,Y,($-Y|0)>32?Y+32|0:f,q,_,h,p)|0)==2;V=c[q>>2]|0;if(X|(V|0)==(Y|0)){break}if(_>>>0<(c[p>>2]|0)>>>0){X=_;do{W=c[X>>2]|0;P=a[v]|0;if((P&1)==0){ac=(P&255)>>>1;ad=1}else{ac=c[m>>2]|0;ad=(c[Z>>2]&-2)-1|0}if((ac|0)==(ad|0)){sL(b,ad,1,ad,ad,0,0);ae=a[v]|0}else{ae=P}if((ae&1)==0){a[v]=(ac<<1)+2&255;af=m;ag=ac+1|0}else{P=c[l>>2]|0;Q=ac+1|0;c[m>>2]=Q;af=P;ag=Q}c[af+(ac<<2)>>2]=W;c[af+(ag<<2)>>2]=0;X=X+4|0;}while(X>>>0<(c[p>>2]|0)>>>0);ah=c[q>>2]|0}else{ah=V}if(ah>>>0>=f>>>0){break L3330}Y=ah;O=c[ab>>2]|0}ab=ff(8)|0;c[ab>>2]=72504;O=ab+4|0;Y=O;do{if((O|0)!=0){while(1){ai=ys(33)|0;if((ai|0)!=0){L=2916;break}m=(I=c[185320]|0,c[185320]=I+0,I);if((m|0)==0){break}gs[m&63]()}if((L|0)==2916){c[ai+4>>2]=20;c[ai>>2]=20;V=ai+12|0;c[Y>>2]=V;c[ai+8>>2]=0;yE(V|0,26544,21)|0;break}V=ff(4)|0;c[V>>2]=72440;dr(V|0,79056,316)}}while(0);dr(ab|0,79088,154)}}while(0);if((a[s]&1)==0){i=d;return}s=c[r+8>>2]|0;if((s|0)==0){i=d;return}yt(s);i=d;return}function wz(b){b=b|0;var d=0;c[b>>2]=73632;d=b+8|0;b=c[d>>2]|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);if((b|0)==(c[141570]|0)){return}cF(c[d>>2]|0);return}function wA(){var b=0,d=0,e=0,f=0,g=0,h=0;b=ff(8)|0;c[b>>2]=72600;d=b+4|0;e=d;if((d|0)==0){f=b;c[f>>2]=72568;dr(b|0,79120,202)}while(1){g=ys(19)|0;if((g|0)!=0){h=2978;break}d=(I=c[185320]|0,c[185320]=I+0,I);if((d|0)==0){h=2972;break}gs[d&63]()}if((h|0)==2972){d=ff(4)|0;c[d>>2]=72440;dr(d|0,79056,316)}else if((h|0)==2978){c[g+4>>2]=6;c[g>>2]=6;h=g+12|0;c[e>>2]=h;c[g+8>>2]=0;a[h]=a[43512]|0;a[h+1|0]=a[43513|0]|0;a[h+2|0]=a[43514|0]|0;a[h+3|0]=a[43515|0]|0;a[h+4|0]=a[43516|0]|0;a[h+5|0]=a[43517|0]|0;a[h+6|0]=a[43518|0]|0;f=b;c[f>>2]=72568;dr(b|0,79120,202)}}function wB(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[b>>2]=73888;d=b+12|0;e=c[d>>2]|0;f=b+8|0;g=c[f>>2]|0;if((e|0)==(g|0)){h=e}else{i=0;j=g;g=e;while(1){e=c[j+(i<<2)>>2]|0;if((e|0)==0){k=g;l=j}else{m=e+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)==0){f2[c[(c[e>>2]|0)+8>>2]&1023](e|0)}k=c[d>>2]|0;l=c[f>>2]|0}e=i+1|0;if(e>>>0<k-l>>2>>>0){i=e;j=l;g=k}else{h=l;break}}}do{if((a[b+144|0]&1)==0){n=h}else{l=c[b+152>>2]|0;if((l|0)==0){n=h;break}yt(l);n=c[f>>2]|0}}while(0);if((n|0)==0){return}f=c[d>>2]|0;if((n|0)!=(f|0)){c[d>>2]=f+(~((f-4+(-n|0)|0)>>>2)<<2)}if((n|0)==(b+24|0)){a[b+136|0]=0;return}else{yt(n);return}}
function jV(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+16|0;g=f|0;h=f+8|0;if((a[405432]&1)!=0){j=c[140620]|0;k=(j|0)!=0?j:c[t>>2]|0;eS(k|0,19416,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;k=c[140620]|0;j=(k|0)!=0?k:c[t>>2]|0;a7(j|0)|0}c[g>>2]=0;c[h>>2]=0;et(3379,g|0);et(34024,h|0);if((a[405432]&1)!=0){j=c[140620]|0;k=(j|0)!=0?j:c[t>>2]|0;j=c[g>>2]|0;g=c[h>>2]|0;eS(k|0,17040,(l=i,i=i+16|0,c[l>>2]=j,c[l+8>>2]=g,l)|0)|0;i=l;g=c[140620]|0;j=(g|0)!=0?g:c[t>>2]|0;a7(j|0)|0}a6(3553,0);j=b+48|0;em(c[j>>2]|0,b+1644|0);g=(a[504460]&1)==0;k=(a[504461]&1)!=0;do{if(k){do{if((a[b+2584|0]&1)==0){h=bd(7939)|0;if((h|0)==0){m=0;break}m=(bJ(h|0,14808)|0)!=0}else{m=0}}while(0);if((a[405432]&1)!=0){h=c[140620]|0;n=(h|0)!=0?h:c[t>>2]|0;h=m?51896:49248;eS(n|0,54624,(l=i,i=i+16|0,c[l>>2]=14808,c[l+8>>2]=h,l)|0)|0;i=l;h=c[140620]|0;n=(h|0)!=0?h:c[t>>2]|0;a7(n|0)|0}if(m){break}else{o=0}i=f;return o|0}}while(0);L2185:do{if(g){if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=1639;break L2185}cm(36160,c[b+1644+(m<<2)>>2]|0);d_(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=cK(36160)|0;if((n|0)==36053){m=m+1|0}else{q=m;r=n;p=1638;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=1639;break L2185}cm(36160,c[b+1644+(m<<2)>>2]|0);d_(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=cK(36160)|0;if((n|0)==36053){m=m+1|0}else{q=m;r=n;p=1638;break}}}}else{dl(c[j>>2]|0,b+1676|0);a[b+1709|0]=1;if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=1639;break L2185}cm(36160,c[b+1644+(m<<2)>>2]|0);d_(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;dx(36161,c[n>>2]|0);cC(36161,35056,d|0,e|0);dx(36161,0);en(36160,36096,36161,c[n>>2]|0);en(36160,36128,36161,c[n>>2]|0);n=cK(36160)|0;if((n|0)==36053){m=m+1|0}else{q=m;r=n;p=1638;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=1639;break L2185}cm(36160,c[b+1644+(m<<2)>>2]|0);d_(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;dx(36161,c[n>>2]|0);cC(36161,33189,d|0,e|0);dx(36161,0);en(36160,36096,36161,c[n>>2]|0);n=cK(36160)|0;if((n|0)==36053){m=m+1|0}else{q=m;r=n;p=1638;break}}}}}while(0);if((p|0)==1638){e=c[140620]|0;d=(e|0)!=0?e:c[t>>2]|0;eS(d|0,12328,(l=i,i=i+16|0,c[l>>2]=q,c[l+8>>2]=r,l)|0)|0;i=l;l=c[140620]|0;r=(l|0)!=0?l:c[t>>2]|0;a7(r|0)|0;o=0;i=f;return o|0}else if((p|0)==1639){cm(36160,0);a[b+1708|0]=1;o=1;i=f;return o|0}return 0}function jW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0.0,A=0,B=0.0,C=0,D=0.0;d=i;i=i+64|0;e=d|0;f=+g[c>>2];h=+g[c+4>>2];j=+g[c+8>>2];k=+g[c+12>>2];l=+g[c+16>>2];m=+g[c+20>>2];n=+g[c+24>>2];o=+g[c+28>>2];p=+g[c+32>>2];q=+g[c+36>>2];r=+g[c+40>>2];s=+g[c+44>>2];t=+g[c+48>>2];u=+g[c+52>>2];v=+g[c+56>>2];w=+g[c+60>>2];c=0;do{x=+g[b+(c<<2)>>2];y=c+4|0;z=+g[b+(y<<2)>>2];A=c+8|0;B=+g[b+(A<<2)>>2];C=c+12|0;D=+g[b+(C<<2)>>2];g[e+(c<<2)>>2]=x*f+0.0+z*h+B*j+D*k;g[e+(y<<2)>>2]=x*l+0.0+z*m+B*n+D*o;g[e+(A<<2)>>2]=x*p+0.0+z*q+B*r+D*s;g[e+(C<<2)>>2]=x*t+0.0+z*u+B*v+D*w;c=c+1|0;}while(c>>>0<4);c=a;a=e;yE(c|0,a|0,64)|0;i=d;return}function jX(a){a=a|0;var b=0;b=c[a+2048>>2]|0;if((b|0)==0){return}f2[c[(c[a+2056>>2]|0)+12>>2]&1023](b);br(1,a+2060|0);b=c[a+2076>>2]|0;if((b|0)==0){return}yt(b);return}function jY(b,d,e){b=b|0;d=d|0;e=+e;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0;d=i;if((a[319540]&1)==0){f=0;i=d;return f|0}h=b+2056|0;j=b+2048|0;k=i1((a[315437]|0)!=0?315437:564064,+g[79884])|0;c[j>>2]=k;if((k|0)==0){k=c[140620]|0;l=(k|0)!=0?k:c[t>>2]|0;eS(l|0,50864,(m=i,i=i+8|0,c[m>>2]=46600,m)|0)|0;i=m;l=c[140620]|0;k=(l|0)!=0?l:c[t>>2]|0;a7(k|0)|0;c[h>>2]=0;c[j>>2]=0;j=c[140620]|0;k=(j|0)!=0?j:c[t>>2]|0;be(50136,49,1,k|0)|0;k=c[140620]|0;j=(k|0)!=0?k:c[t>>2]|0;a7(j|0)|0;f=0;i=d;return f|0}if((a[405432]&1)!=0){j=c[140620]|0;k=(j|0)!=0?j:c[t>>2]|0;eS(k|0,46720,(m=i,i=i+8|0,c[m>>2]=46600,m)|0)|0;i=m;m=c[140620]|0;k=(m|0)!=0?m:c[t>>2]|0;a7(k|0)|0}c[h>>2]=8368;h=b+2060|0;bM(1,h|0);a6(3553,c[h>>2]|0);fL(3553,10242,33071);fL(3553,10243,33071);fL(3553,10240,9729);fL(3553,10241,9729);a6(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);et(3379,b+2064|0);e=+g[79888];g[b+2344>>2]=e;n=+g[79889];g[b+2348>>2]=n;o=+g[79890];g[b+2352>>2]=o;g[b+2356>>2]=1.0;p=+g[79888];g[b+2360>>2]=p;q=+g[79889];g[b+2364>>2]=q;r=+g[79890];g[b+2368>>2]=r;g[b+2372>>2]=1.0;s=+g[79888];g[b+2376>>2]=s;u=+g[79889];g[b+2380>>2]=u;v=+g[79890];g[b+2384>>2]=v;g[b+2388>>2]=1.0;w=+g[79888];g[b+2392>>2]=w;x=+g[79889];g[b+2396>>2]=x;y=+g[79890];g[b+2400>>2]=y;g[b+2404>>2]=1.0;g[b+2408>>2]=e*.3;g[b+2412>>2]=n*.3;g[b+2416>>2]=o*.3;g[b+2420>>2]=1.0;g[b+2424>>2]=p*.3;g[b+2428>>2]=q*.3;g[b+2432>>2]=r*.3;g[b+2436>>2]=1.0;g[b+2440>>2]=s*.3;g[b+2444>>2]=u*.3;g[b+2448>>2]=v*.3;g[b+2452>>2]=1.0;g[b+2456>>2]=w*.3;g[b+2460>>2]=x*.3;g[b+2464>>2]=y*.3;g[b+2468>>2]=1.0;f=1;i=d;return f|0}function jZ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0.0,ae=0.0,af=0.0,ah=0.0;f=i;i=i+168|0;h=f|0;j=f+64|0;k=f+96|0;l=f+128|0;m=f+160|0;do{if((e|0)==0){n=+g[79886];o=+g[79887];if((a[319541]&1)==0){p=n;q=o;r=1.0;break}p=n;q=o;r=+((c[b+1744>>2]|0)>>>0>>>0)/+((c[b+1720>>2]|0)>>>0>>>0)}else{p=+g[e>>2];q=+g[e+4>>2];r=+g[e+8>>2]}}while(0);e=b+2048|0;if((c[e>>2]|0)==0){i=f;return}s=b+4|0;t=c[s>>2]|0;if((t|0)!=0){f2[c[t+12>>2]&1023](15)}jr(b,c[b+1728>>2]|0,c[b+1732>>2]|0,0);e1(3042);a6(3553,c[b+2060>>2]|0);t=l|0;u=b+2e3|0;v=u;w=b+2008|0;c[w>>2]=t;x=b+2080|0;if((db(x|0,d|0)|0)==0){y=c[b+2336>>2]|0;z=c[b+2340>>2]|0;A=b+2068|0;B=b+2072|0}else{C=b+2056|0;gr[c[(c[C>>2]|0)+4>>2]&127](c[e>>2]|0,d,m);D=c[m>>2]|0;E=c[D+24>>2]|0;F=(c[D+4>>2]|0)+E|0;G=c[D+28>>2]|0;H=(c[D+8>>2]|0)+G|0;I=c[D+48>>2]|0;if((I|0)==0){J=H;K=G;L=F;M=E}else{N=H;H=G;G=F;F=E;E=I;while(1){I=c[E+24>>2]|0;O=(c[E+4>>2]|0)+I|0;P=c[E+28>>2]|0;Q=(c[E+8>>2]|0)+P|0;R=(I|0)<(F|0)?I:F;I=(O|0)>(G|0)?O:G;O=(P|0)<(H|0)?P:H;P=(Q|0)>(N|0)?Q:N;Q=c[E+48>>2]|0;if((Q|0)==0){J=P;K=O;L=I;M=R;break}else{N=P;H=O;G=I;F=R;E=Q}}}E=L-M|0;L=J-K|0;J=E-1|0;F=J>>>1|J;J=F>>>2|F;F=J>>>4|J;J=F>>>8|F;F=(J>>>16|J)+1|0;J=L-1|0;G=J>>>1|J;J=G>>>2|G;G=J>>>4|J;J=G>>>8|G;G=(J>>>16|J)+1|0;J=c[b+2064>>2]|0;H=(F|0)>(J|0)?J:F;F=(G|0)>(J|0)?J:G;G=b+2068|0;J=c[G>>2]|0;N=b+2072|0;do{if((H|0)>(J|0)){S=1678}else{Q=c[N>>2]|0;if((F|0)>(Q|0)){S=1678;break}T=J;U=Q;V=b+2076|0}}while(0);if((S|0)==1678){J=b+2076|0;Q=c[J>>2]|0;c[J>>2]=yu(Q,ag(H<<2,F)|0)|0;eI(3553,0,6408,H|0,F|0,0,6408,5121,0);c[G>>2]=H;c[N>>2]=F;T=H;U=F;V=J}J=c[V>>2]|0;yB(J|0,0,ag(U<<2,T)|0);if((D|0)!=0){T=D;do{D=c[V>>2]|0;U=c[G>>2]|0;J=c[N>>2]|0;F=(c[T+24>>2]|0)-M|0;H=c[T+8>>2]|0;Q=J-H+(K-(c[T+28>>2]|0))|0;R=Q-1|0;I=c[T>>2]|0;O=(F|0)<0;P=(c[T+4>>2]|0)+(O?F:0)|0;W=(R|0)<0;X=(W?R:0)+H|0;if(O){_=I+(-F|0)|0;$=0}else{_=I;$=F}if(W){aa=_+(ag(c[T+12>>2]|0,1-Q|0)|0)|0;ab=0}else{aa=_;ab=R}R=($+P|0)>(U|0)?U-$|0:P;P=(ab+X|0)>(J|0)?J-ab|0:X;do{if((P|0)>0){X=T+12|0;if((R|0)<=0){break}J=aa;Q=D+((ag(ab,U)|0)+$<<2)|0;W=0;while(1){F=Q;I=0;while(1){a[F]=-1;a[F+1|0]=-1;a[F+2|0]=-1;a[F+3|0]=a[J+I|0]|0;O=I+1|0;if((O|0)<(R|0)){F=F+4|0;I=O}else{break}}I=W+1|0;if((I|0)<(P|0)){J=J+(c[X>>2]|0)|0;Q=Q+(U<<2)|0;W=I}else{break}}}}while(0);T=c[T+48>>2]|0;}while((T|0)!=0)}fV(3317,8);eK(3553,0,0,0,c[G>>2]|0,c[N>>2]|0,6408,5121,c[V>>2]|0);f3[c[(c[C>>2]|0)+8>>2]&1023](c[e>>2]|0,m);m=256;e=x;x=d;while(1){d=m-1|0;if((d|0)==0){S=1694;break}C=a[x]|0;a[e]=C;if(C<<24>>24==0){break}else{m=d;e=e+1|0;x=x+1|0}}do{if((S|0)==1694){a[e]=0;if((a[x]|0)==0){break}else{ac=x}do{ac=ac+1|0;}while((a[ac]|0)!=0)}}while(0);c[b+2336>>2]=E;c[b+2340>>2]=L;y=E;z=L;A=G;B=N}N=j|0;G=k|0;o=+(y|0);n=+((c[b+1744>>2]|0)>>>0>>>0);ad=p+r*o/n;ae=+(z|0);af=+((c[b+1748>>2]|0)>>>0>>>0);ah=q+r*ae/af;g[N>>2]=p;g[j+8>>2]=ad;g[j+16>>2]=p;g[j+24>>2]=ad;g[j+4>>2]=ah;g[j+12>>2]=ah;g[j+20>>2]=q;g[j+28>>2]=q;r=2.0/n;n=2.0/af;af=p-r;g[G>>2]=af;p=ah-n;g[k+4>>2]=p;ah=ad-r;g[k+8>>2]=ah;g[k+12>>2]=p;g[k+16>>2]=af;af=q-n;g[k+20>>2]=af;g[k+24>>2]=ah;g[k+28>>2]=af;af=o/+(c[A>>2]|0);o=1.0-ae/+(c[B>>2]|0);g[t>>2]=0.0;g[l+8>>2]=af;g[l+16>>2]=0.0;g[l+24>>2]=af;g[l+4>>2]=o;g[l+12>>2]=o;g[l+20>>2]=1.0;g[l+28>>2]=1.0;l=u;c[l>>2]=G;G=b+2004|0;c[G>>2]=b+2408;u=b+1872|0;t=c[s>>2]|0;do{if((t|0)!=0){B=c[t+32>>2]|0;f5[B&255](v)|0;B=c[s>>2]|0;if((B|0)==0){break}A=c[B+36>>2]|0;f5[A&255](u)|0}}while(0);dC(5,0,4);c[l>>2]=N;c[G>>2]=b+2344;N=c[s>>2]|0;do{if((N|0)!=0){t=c[N+32>>2]|0;f5[t&255](v)|0;t=c[s>>2]|0;if((t|0)==0){break}A=c[t+36>>2]|0;f5[A&255](u)|0}}while(0);dC(5,0,4);c[l>>2]=c[b+2016>>2];c[w>>2]=b+1840;c[G>>2]=c[b+2020>>2];a6(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);dI(3042);G=b+1936|0;yB(G|0,0,48);g[b+1996>>2]=1.0;g[G>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;o=+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0;af=+Y(+o);ae=+Z(+o);yB(h|0,0,60);g[h+40>>2]=1.0;g[h+60>>2]=1.0;g[h>>2]=af;g[h+20>>2]=af;g[h+16>>2]=-0.0-ae;g[h+4>>2]=ae;jW(u,h,G);i=f;return}function j_(a){a=a|0;return}function j$(a,b){a=a|0;b=b|0;return}function j0(){return}function j1(a){a=a|0;return 0}function j2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return 0}function j3(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;if(a[8152]|0){e=0}else{a[8152]=1;e=1}return e|0}function j4(a,b){a=a|0;b=b|0;c[a>>2]=c[101354];c[b>>2]=c[101356];return}function j5(){return a[8152]|0}function j6(a,b){a=a|0;b=b|0;return+(+(a>>>0>>>0)/+(b>>>0>>>0))}function j7(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;if((a[405432]&1)!=0){g=c[140620]|0;h=(g|0)!=0?g:c[t>>2]|0;be(37e3,45,1,h|0)|0;h=c[140620]|0;g=(h|0)!=0?h:c[t>>2]|0;a7(g|0)|0}if(a[8152]|0){if((a[405432]&1)==0){j=1;i=b;return j|0}g=c[140620]|0;h=(g|0)!=0?g:c[t>>2]|0;be(29680,64,1,h|0)|0;h=c[140620]|0;g=(h|0)!=0?h:c[t>>2]|0;a7(g|0)|0;j=1;i=b;return j|0}g=fQ(0)|0;c[140892]=g;do{if((g|0)!=0){do{if((c$(g|0,0,0)|0)!=0){if((eX(c[140892]|0,8032,563584,1,f|0)|0)==0){break}h=bm(c[140892]|0,c[140896]|0,0,8016)|0;c[140894]=h;if((h|0)==0){break}h=eR(c[140892]|0,c[140896]|0,0,0)|0;c[140890]=h;if((h|0)==0){break}if((d1(c[140892]|0,h|0,h|0,c[140894]|0)|0)==0){break}h=c[140892]|0;k=c[140890]|0;fU(h|0,k|0,12375,d|0)|0;k=c[140892]|0;h=c[140890]|0;fU(k|0,h|0,12374,e|0)|0;h=c[d>>2]|0;c[101354]=h;k=c[e>>2]|0;c[101356]=k;if((a[405432]&1)==0){j=1;i=b;return j|0}l=c[140620]|0;m=(l|0)!=0?l:c[t>>2]|0;eS(m|0,25112,(m=i,i=i+16|0,c[m>>2]=h,c[m+8>>2]=k,m)|0)|0;i=m;m=c[140620]|0;k=(m|0)!=0?m:c[t>>2]|0;a7(k|0)|0;j=1;i=b;return j|0}}while(0);k=c[140892]|0;if((k|0)==0){break}d1(k|0,0,0,0)|0;k=c[140894]|0;if((k|0)!=0){m=c[140892]|0;dQ(m|0,k|0)|0}k=c[140890]|0;if((k|0)!=0){m=c[140892]|0;a3(m|0,k|0)|0}k=c[140892]|0;ct(k|0)|0}}while(0);c[140894]=0;c[140890]=0;c[140892]=0;c[140896]=0;a[8152]=0;j=0;i=b;return j|0}function j8(){var b=0,d=0;b=c[140892]|0;if((b|0)!=0){d1(b|0,0,0,0)|0;b=c[140894]|0;if((b|0)!=0){d=c[140892]|0;dQ(d|0,b|0)|0}b=c[140890]|0;if((b|0)!=0){d=c[140892]|0;a3(d|0,b|0)|0}b=c[140892]|0;ct(b|0)|0}c[140894]=0;c[140890]=0;c[140892]=0;c[140896]=0;a[8152]=0;return}function j9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)==1){d=(bs(12448)|0)!=0}else{d=0}return d|0}function ka(){var b=0,d=0,e=0.0,f=0,g=0,j=0,k=0,l=0,m=0;b=i;i=i+128|0;d=b|0;a[d]=0;e=+bk()*1.0e3;f=~~e>>>0;g=+V(e)>=1.0?e>0.0?(al(+U(e/4294967296.0),4294967295.0)|0)>>>0:~~+af((e- +(~~e>>>0))/4294967296.0)>>>0:0;do{if((c[140560]|0)==0){c[75754]=f;c[75755]=g;c[75752]=f;c[75753]=g;b5(d|0,128,32576,(j=i,i=i+8|0,c[j>>2]=562244,j)|0)|0;i=j}else{k=553784;l=c[k>>2]|0;m=yL(l,c[k+4>>2]|0,1,0)|0;k=553784;c[k>>2]=m;c[k+4>>2]=K;k=yM(f,g,c[75754]|0,c[75755]|0)|0;m=537400+((l&2047)<<3)|0;c[m>>2]=k;c[m+4>>2]=K;c[75754]=f;c[75755]=g;m=c[140560]|0;if((m&255|0)==0){k=yM(f,g,c[75752]|0,c[75753]|0)|0;c[75752]=f;c[75753]=g;e=256.0e6/(+(k>>>0)+ +(K|0)*4294967296.0);b5(d|0,128,13968,(j=i,i=i+24|0,c[j>>2]=562244,h[j+8>>3]=e,c[j+16>>2]=m,j)|0)|0;i=j;break}else{i=b;return}}}while(0);if((a[405432]&1)==0){i=b;return}g=c[140620]|0;eS(((g|0)!=0?g:c[t>>2]|0)|0,50096,(j=i,i=i+8|0,c[j>>2]=d,j)|0)|0;i=j;j=c[140620]|0;a7(((j|0)!=0?j:c[t>>2]|0)|0)|0;i=b;return}function kb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;g=i;i=i+24|0;h=g|0;j=g+8|0;cV(h|0,j|0,g+16|0);k=c[h>>2]|0;c[e>>2]=k;h=c[j>>2]|0;c[f>>2]=h;a[d]=(c[e>>2]|0)==(c[101354]|0)&(h|0)==(c[101356]|0)&1^1;c[101354]=k;c[101356]=h;a[b]=0;i=g;return}function kc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;c[a>>2]=0;d=ys(48)|0;if((d|0)==0){return}if((c[d-4>>2]&3|0)!=0){yB(d|0,0,48)}e=bz()|0;c[d+44>>2]=e;if((e|0)==0){yt(d);return}yB(84648,0,1292);e=5088;f=276;while(1){c[84648+(f<<2)>>2]=c[e>>2];g=c[e+12>>2]|0;if((g|0)==0){break}else{e=e+8|0;f=g}}c[a>>2]=6128;c[b>>2]=d;return}function kd(a){a=a|0;return cx(a|0)|0}function ke(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a5=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0.0,cX=0.0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,dc=0,dd=0,de=0,df=0,dg=0;e=i;i=i+848|0;f=e|0;j=e+64|0;k=e+128|0;l=e+192|0;m=e+256|0;n=e+320|0;o=e+384|0;p=e+448|0;q=e+512|0;r=e+576|0;s=e+640|0;u=e+704|0;v=e+768|0;w=e+832|0;x=ys(109528)|0;if((x|0)==0){c[73716]=0;y=0;i=e;return y|0}if((c[x-4>>2]&3|0)!=0){yB(x|0,0,109528)}z=x;c[73716]=z;L2389:do{if((d|0)==0){A=c[140620]|0;B=(A|0)!=0?A:c[t>>2]|0;be(29616,59,1,B|0)|0;B=c[140620]|0;A=(B|0)!=0?B:c[t>>2]|0;a7(A|0)|0;c[(c[73716]|0)+72>>2]=1;A=dW(((a[294896]&1)!=0?21e3:21376)|0)|0;c[(c[73716]|0)+4172>>2]=A;A=dW(((a[294896]&1)!=0?22056:22480)|0)|0;B=c[73716]|0;c[B+4176>>2]=A;a[B+4|0]=1}else{B=cE(d|0,46)|0;A=(B|0)==0?564064:B+1|0;if((db(A|0,42248)|0)==0){B=4096;C=x+76|0;D=d;while(1){E=B-1|0;if((E|0)==0){F=1787;break}G=a[D]|0;a[C]=G;if(G<<24>>24==0){break}else{B=E;C=C+1|0;D=D+1|0}}do{if((F|0)==1787){a[C]=0;if((a[D]|0)==0){break}else{H=D}do{H=H+1|0;}while((a[H]|0)!=0)}}while(0);c[x+72>>2]=1;a[x+4|0]=1;break}do{if((db(A|0,50088)|0)==0){D=hC(d,0)|0;if((D|0)==0){break}C=iX(D,c[73716]|0)|0;a[(c[73716]|0)+4|0]=1;hA(D);if(C){break L2389}}else{C=v|0;if((a[405432]&1)!=0){D=c[140620]|0;B=(D|0)!=0?D:c[t>>2]|0;eS(B|0,25464,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;B=c[140620]|0;D=(B|0)!=0?B:c[t>>2]|0;a7(D|0)|0}D=io(d)|0;B=(D|0)!=0;L2410:do{if(B){E=D|0;G=c[E>>2]|0;if((G|0)==0){break}else{J=G}L2413:while(1){do{if((c[J+20>>2]|0)==0){if((db(c[J>>2]|0,19552)|0)!=0){break}K=J+8|0;G=K;while(1){L=c[G>>2]|0;if((L|0)==0){F=1808;break}if((db(17240,c[L>>2]|0)|0)==0){F=1803;break}else{G=L+8|0}}L2421:do{if((F|0)==1803){F=0;G=c[L+4>>2]|0;if((G|0)==0){F=1808;break}else{M=64;N=C;O=G}while(1){G=M-1|0;if((G|0)==0){break}P=a[O]|0;a[N]=P;if(P<<24>>24==0){break L2421}else{M=G;N=N+1|0;O=O+1|0}}a[N]=0;if((a[O]|0)==0){break}else{Q=O}do{Q=Q+1|0;}while((a[Q]|0)!=0)}}while(0);if((F|0)==1808){F=0;a[C]=0}if((db(C|0,14864)|0)==0){break L2413}}}while(0);G=c[J+16>>2]|0;if((G|0)==0){break L2410}else{J=G}}c[x>>2]=2;G=K;while(1){R=c[G>>2]|0;if((R|0)==0){F=1818;break}if((db(12464,c[R>>2]|0)|0)==0){F=1813;break}else{G=R+8|0}}L2437:do{if((F|0)==1813){G=c[R+4>>2]|0;if((G|0)==0){F=1818;break}else{S=64;T=C;U=G}while(1){G=S-1|0;if((G|0)==0){break}P=a[U]|0;a[T]=P;if(P<<24>>24==0){break L2437}else{S=G;T=T+1|0;U=U+1|0}}a[T]=0;if((a[U]|0)==0){break}else{V=U}do{V=V+1|0;}while((a[V]|0)!=0)}}while(0);if((F|0)==1818){a[C]=0}G=x+4|0;a[G]=(db(C|0,54712)|0)==0|0;P=x+5|0;W=K;while(1){X=c[W>>2]|0;if((X|0)==0){F=1823;break}if((db(52024,c[X>>2]|0)|0)==0){F=1822;break}else{W=X+8|0}}do{if((F|0)==1822){W=c[X+4>>2]|0;if((W|0)==0){F=1823;break}else{Y=64;Z=0;_=P;$=W}while(1){W=Y-1|0;if((W|0)==0){F=1826;break}aa=a[$]|0;a[_]=aa;if(aa<<24>>24==0){ab=Z;break}else{Y=W;Z=Z+1|0;_=_+1|0;$=$+1|0}}do{if((F|0)==1826){a[_]=0;if((a[$]|0)==0){ab=Z;break}else{ac=$;ad=Z}while(1){W=ac+1|0;aa=ad+1|0;if((a[W]|0)==0){ab=aa;break}else{ac=W;ad=aa}}}}while(0);if(ab>>>0>=64){break}if((a[405432]&1)==0){break}aa=c[140620]|0;eS(((aa|0)!=0?aa:c[t>>2]|0)|0,49288,(I=i,i=i+8|0,c[I>>2]=P,I)|0)|0;i=I;aa=c[140620]|0;a7(((aa|0)!=0?aa:c[t>>2]|0)|0)|0}}while(0);if((F|0)==1823){a[P]=0}do{if((a[G]&1)==0){aa=c[140620]|0;W=(aa|0)!=0?aa:c[t>>2]|0;be(46608,57,1,W|0)|0;W=c[140620]|0;aa=(W|0)!=0?W:c[t>>2]|0;a7(aa|0)|0}else{if((a[405432]&1)==0){break}aa=c[140620]|0;W=(aa|0)!=0?aa:c[t>>2]|0;be(47664,54,1,W|0)|0;W=c[140620]|0;aa=(W|0)!=0?W:c[t>>2]|0;a7(aa|0)|0}}while(0);P=c[J+12>>2]|0;aa=x+72|0;L2471:do{if((P|0)==0){F=2156}else{W=f|0;ae=j|0;af=k|0;ag=l|0;ah=m|0;ai=n|0;aj=o|0;ak=p|0;al=q|0;am=r|0;an=s|0;ao=u|0;ap=x+66444|0;aq=x+99792|0;ar=x+109012|0;as=x+109016|0;at=P;L2473:while(1){if((c[aa>>2]|0)>>>0>=16){break L2471}do{if((c[at+20>>2]|0)==0){au=at+4|0;av=c[au>>2]|0;if((av|0)==0){break}aw=dW(av|0)|0;if((aw|0)==0){break}av=c[aa>>2]|0;ax=c[at>>2]|0;if((db(ax|0,45248)|0)==0){ay=z+76+(av*4148|0)+4096|0;if((c[ay>>2]|0)!=0){F=1844;break L2473}az=iZ(aw,d,at)|0;if((az|0)==0){F=1846;break L2473}c[ay>>2]=az;break}if((db(ax|0,40488)|0)!=0){if((db(ax|0,36448)|0)==0){yt(aw);az=c[ap>>2]|0;if(az>>>0>7){ay=c[140620]|0;aA=(ay|0)!=0?ay:c[t>>2]|0;be(13616,58,1,aA|0)|0;aA=c[140620]|0;ay=(aA|0)!=0?aA:c[t>>2]|0;a7(ay|0)|0;break}ay=z+66448+(az*4168|0)|0;aA=at+8|0;aB=aA;while(1){aC=c[aB>>2]|0;if((aC|0)==0){F=2013;break}if((db(16048,c[aC>>2]|0)|0)==0){F=2008;break}else{aB=aC+8|0}}L2495:do{if((F|0)==2008){F=0;aB=c[aC+4>>2]|0;if((aB|0)==0){F=2013;break}else{aD=64;aE=ay;aF=aB}while(1){aB=aD-1|0;if((aB|0)==0){break}aG=a[aF]|0;a[aE]=aG;if(aG<<24>>24==0){break L2495}else{aD=aB;aE=aE+1|0;aF=aF+1|0}}a[aE]=0;if((a[aF]|0)==0){break}else{aH=aF}do{aH=aH+1|0;}while((a[aH]|0)!=0)}}while(0);if((F|0)==2013){F=0;a[ay]=0}aB=z+66448+(az*4168|0)+64|0;aG=aA;while(1){aI=c[aG>>2]|0;if((aI|0)==0){F=2022;break}if((db(13504,c[aI>>2]|0)|0)==0){F=2017;break}else{aG=aI+8|0}}L2509:do{if((F|0)==2017){F=0;aG=c[aI+4>>2]|0;if((aG|0)==0){F=2022;break}else{aJ=4096;aK=aB;aL=aG}while(1){aG=aJ-1|0;if((aG|0)==0){break}aM=a[aL]|0;a[aK]=aM;if(aM<<24>>24==0){break L2509}else{aJ=aG;aK=aK+1|0;aL=aL+1|0}}a[aK]=0;if((a[aL]|0)==0){break}else{aN=aL}do{aN=aN+1|0;}while((a[aN]|0)!=0)}}while(0);if((F|0)==2022){F=0;a[aB]=0}yB(W|0,0,64);aG=aA;while(1){aO=c[aG>>2]|0;if((aO|0)==0){F=2031;break}if((db(13336,c[aO>>2]|0)|0)==0){F=2026;break}else{aG=aO+8|0}}L2523:do{if((F|0)==2026){F=0;aG=c[aO+4>>2]|0;if((aG|0)==0){F=2031;break}else{aP=64;aQ=W;aR=aG}while(1){aG=aP-1|0;if((aG|0)==0){break}aA=a[aR]|0;a[aQ]=aA;if(aA<<24>>24==0){break L2523}else{aP=aG;aQ=aQ+1|0;aR=aR+1|0}}a[aQ]=0;if((a[aR]|0)==0){break}else{aS=aR}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);if((F|0)==2031){F=0;a[W]=0}if((a[ay]|0)==0){F=2033;break L2473}if((a[aB]|0)==0){F=2035;break L2473}do{if((db(W|0,12744)|0)==0){c[z+66448+(az*4168|0)+4160>>2]=1}else{if((db(W|0,12544)|0)==0){c[z+66448+(az*4168|0)+4160>>2]=2;break}if((a[W]|0)!=0){F=2042;break L2473}c[z+66448+(az*4168|0)+4160>>2]=0}}while(0);c[ap>>2]=(c[ap>>2]|0)+1;break}if((db(ax|0,33992)|0)!=0){if((db(ax|0,32584)|0)!=0){break}yt(aw);if((c[ar>>2]|0)!=0){F=2129;break L2473}az=at+8|0;aB=az;while(1){aT=c[aB>>2]|0;if((aT|0)==0){F=2138;break}if((db(17344,c[aT>>2]|0)|0)==0){F=2133;break}else{aB=aT+8|0}}L2552:do{if((F|0)==2133){F=0;aB=c[aT+4>>2]|0;if((aB|0)==0){F=2138;break}else{aU=512;aV=as;aW=aB}while(1){aB=aU-1|0;if((aB|0)==0){break}ax=a[aW]|0;a[aV]=ax;if(ax<<24>>24==0){aX=az;break L2552}else{aU=aB;aV=aV+1|0;aW=aW+1|0}}a[aV]=0;if((a[aW]|0)==0){aX=az;break}else{aY=aW}while(1){aB=aY+1|0;if((a[aB]|0)==0){aX=az;break}else{aY=aB}}}}while(0);if((F|0)==2138){F=0;a[as]=0;aX=az}while(1){aZ=c[aX>>2]|0;if((aZ|0)==0){F=2146;break}if((db(17240,c[aZ>>2]|0)|0)==0){F=2141;break}else{aX=aZ+8|0}}L2565:do{if((F|0)==2141){F=0;az=c[aZ+4>>2]|0;if((az|0)==0){F=2146;break}else{a_=64;a$=W;a0=az}while(1){az=a_-1|0;if((az|0)==0){break}aB=a[a0]|0;a[a$]=aB;if(aB<<24>>24==0){break L2565}else{a_=az;a$=a$+1|0;a0=a0+1|0}}a[a$]=0;if((a[a0]|0)==0){break}else{a1=a0}do{a1=a1+1|0;}while((a[a1]|0)!=0)}}while(0);if((F|0)==2146){F=0;a[W]=0}if((db(W|0,20552)|0)!=0){F=2148;break L2473}az=c[au>>2]|0;if((az|0)==0){F=2150;break L2473}aB=dW(az|0)|0;c[ar>>2]=aB;if((aB|0)==0){F=2154;break L2473}az=iZ(aB,d,at)|0;c[ar>>2]=az;if((az|0)==0){F=2153;break L2473}else{break}}yt(aw);az=c[aq>>2]|0;if(az>>>0>63){F=2047;break L2473}aB=z+99796+(az*80|0)|0;ax=at+8|0;ay=ax;while(1){a2=c[ay>>2]|0;if((a2|0)==0){F=2056;break}if((db(16048,c[a2>>2]|0)|0)==0){F=2051;break}else{ay=a2+8|0}}L2584:do{if((F|0)==2051){F=0;ay=c[a2+4>>2]|0;if((ay|0)==0){F=2056;break}else{a3=64;a5=aB;a8=ay}while(1){ay=a3-1|0;if((ay|0)==0){break}au=a[a8]|0;a[a5]=au;if(au<<24>>24==0){a9=ax;break L2584}else{a3=ay;a5=a5+1|0;a8=a8+1|0}}a[a5]=0;if((a[a8]|0)==0){a9=ax;break}else{ba=a8}while(1){ay=ba+1|0;if((a[ay]|0)==0){a9=ax;break}else{ba=ay}}}}while(0);if((F|0)==2056){F=0;a[aB]=0;a9=ax}while(1){bb=c[a9>>2]|0;if((bb|0)==0){F=2064;break}if((db(15904,c[bb>>2]|0)|0)==0){F=2059;break}else{a9=bb+8|0}}L2597:do{if((F|0)==2059){F=0;ay=c[bb+4>>2]|0;if((ay|0)==0){F=2064;break}else{bc=64;bd=W;bf=ay}while(1){ay=bc-1|0;if((ay|0)==0){break}au=a[bf]|0;a[bd]=au;if(au<<24>>24==0){bg=ax;break L2597}else{bc=ay;bd=bd+1|0;bf=bf+1|0}}a[bd]=0;if((a[bf]|0)==0){bg=ax;break}else{bh=bf}while(1){ay=bh+1|0;if((a[ay]|0)==0){bg=ax;break}else{bh=ay}}}}while(0);if((F|0)==2064){F=0;a[W]=0;bg=ax}while(1){bi=c[bg>>2]|0;if((bi|0)==0){F=2072;break}if((db(15752,c[bi>>2]|0)|0)==0){F=2067;break}else{bg=bi+8|0}}L2610:do{if((F|0)==2067){F=0;ay=c[bi+4>>2]|0;if((ay|0)==0){F=2072;break}else{bj=64;bk=ae;bl=ay}while(1){ay=bj-1|0;if((ay|0)==0){break}au=a[bl]|0;a[bk]=au;if(au<<24>>24==0){bm=ax;break L2610}else{bj=ay;bk=bk+1|0;bl=bl+1|0}}a[bk]=0;if((a[bl]|0)==0){bm=ax;break}else{bn=bl}while(1){ay=bn+1|0;if((a[ay]|0)==0){bm=ax;break}else{bn=ay}}}}while(0);if((F|0)==2072){F=0;a[ae]=0;bm=ax}while(1){bo=c[bm>>2]|0;if((bo|0)==0){F=2080;break}if((db(15608,c[bo>>2]|0)|0)==0){F=2075;break}else{bm=bo+8|0}}L2623:do{if((F|0)==2075){F=0;ay=c[bo+4>>2]|0;if((ay|0)==0){F=2080;break}else{bp=64;bq=af;br=ay}while(1){ay=bp-1|0;if((ay|0)==0){break}au=a[br]|0;a[bq]=au;if(au<<24>>24==0){bs=ax;break L2623}else{bp=ay;bq=bq+1|0;br=br+1|0}}a[bq]=0;if((a[br]|0)==0){bs=ax;break}else{bt=br}while(1){ay=bt+1|0;if((a[ay]|0)==0){bs=ax;break}else{bt=ay}}}}while(0);if((F|0)==2080){F=0;a[af]=0;bs=ax}while(1){bu=c[bs>>2]|0;if((bu|0)==0){F=2088;break}if((db(15408,c[bu>>2]|0)|0)==0){F=2083;break}else{bs=bu+8|0}}L2636:do{if((F|0)==2083){F=0;ay=c[bu+4>>2]|0;if((ay|0)==0){F=2088;break}else{bv=64;bw=ag;bx=ay}while(1){ay=bv-1|0;if((ay|0)==0){break}au=a[bx]|0;a[bw]=au;if(au<<24>>24==0){by=ax;break L2636}else{bv=ay;bw=bw+1|0;bx=bx+1|0}}a[bw]=0;if((a[bx]|0)==0){by=ax;break}else{bz=bx}while(1){ay=bz+1|0;if((a[ay]|0)==0){by=ax;break}else{bz=ay}}}}while(0);if((F|0)==2088){F=0;a[ag]=0;by=ax}while(1){bA=c[by>>2]|0;if((bA|0)==0){F=2096;break}if((db(15200,c[bA>>2]|0)|0)==0){F=2091;break}else{by=bA+8|0}}L2649:do{if((F|0)==2091){F=0;ax=c[bA+4>>2]|0;if((ax|0)==0){F=2096;break}else{bB=64;bC=ah;bD=ax}while(1){ax=bB-1|0;if((ax|0)==0){break}ay=a[bD]|0;a[bC]=ay;if(ay<<24>>24==0){break L2649}else{bB=ax;bC=bC+1|0;bD=bD+1|0}}a[bC]=0;if((a[bD]|0)==0){break}else{bE=bD}do{bE=bE+1|0;}while((a[bE]|0)!=0)}}while(0);if((F|0)==2096){F=0;a[ah]=0}if((a[W]|0)==0){F=2099;break L2473}if((a[aB]|0)==0){F=2099;break L2473}do{if((db(W|0,22768)|0)==0){c[z+99796+(az*80|0)+68>>2]=0;F=2113}else{if((db(W|0,21216)|0)==0){c[z+99796+(az*80|0)+68>>2]=1;F=2113;break}if((db(W|0,22280)|0)==0){c[z+99796+(az*80|0)+68>>2]=2;F=2113;break}if((db(W|0,21616)|0)==0){c[z+99796+(az*80|0)+68>>2]=3;F=2113;break}if((db(W|0,20720)|0)==0){c[z+99796+(az*80|0)+68>>2]=4;F=2113;break}if((db(W|0,20552)|0)!=0){F=2111;break L2473}c[z+99796+(az*80|0)+68>>2]=5}}while(0);do{if((F|0)==2113){F=0;if((a[af]|0)==0){if((a[ae]|0)==0){F=2120;break L2473}c[z+99796+(az*80|0)+64>>2]=a4(ae|0,0,16)|0;c[z+99796+(az*80|0)+72>>2]=1;break}aB=a4(af|0,0,0)|0;if((aB|0)==1){c[z+99796+(az*80|0)+72>>2]=2;break}else if((aB|0)==2){c[z+99796+(az*80|0)+72>>2]=3;break}else{F=2117;break L2473}}}while(0);if((a[ag]|0)!=0){b[z+99796+(az*80|0)+76>>1]=(a4(ag|0,0,16)|0)&65535}if((a[ah]|0)!=0){b[z+99796+(az*80|0)+78>>1]=(a4(ah|0,0,16)|0)&65535}c[aq>>2]=(c[aq>>2]|0)+1;break}if((a[G]&1)!=0){if((c[z+76+(av*4148|0)+4096>>2]|0)==0){F=1851;break L2473}}aB=iZ(aw,d,at)|0;if((aB|0)==0){F=1853;break L2473}c[z+76+(av*4148|0)+4100>>2]=aB;aB=z+76+(av*4148|0)+4144|0;c[aB>>2]=0;ax=z+76+(av*4148|0)+4136|0;c[ax>>2]=0;ay=z+76+(av*4148|0)+4132|0;a[ay]=0;au=z+76+(av*4148|0)+4116|0;g[au>>2]=1.0;aG=z+76+(av*4148|0)+4120|0;g[aG>>2]=1.0;aA=z+76+(av*4148|0)+4112|0;c[aA>>2]=0;aM=z+76+(av*4148|0)+4108|0;c[aM>>2]=0;bF=z+76+(av*4148|0)+4104|0;a[bF]=0;bG=at+8|0;bH=bG;while(1){bI=c[bH>>2]|0;if((bI|0)==0){F=1858;break}if((db(13336,c[bI>>2]|0)|0)==0){F=1857;break}else{bH=bI+8|0}}do{if((F|0)==1857){F=0;bH=c[bI+4>>2]|0;if((bH|0)==0){F=1858;break}else{bJ=64;bK=0;bL=W;bN=bH}while(1){bH=bJ-1|0;if((bH|0)==0){F=1861;break}az=a[bN]|0;a[bL]=az;if(az<<24>>24==0){bO=bK;break}else{bJ=bH;bK=bK+1|0;bL=bL+1|0;bN=bN+1|0}}do{if((F|0)==1861){F=0;a[bL]=0;if((a[bN]|0)==0){bO=bK;break}else{bP=bN;bQ=bK}while(1){bH=bP+1|0;az=bQ+1|0;if((a[bH]|0)==0){bO=az;break}else{bP=bH;bQ=az}}}}while(0);if(bO>>>0>=64){bR=bG;F=1871;break}if((db(W|0,12544)|0)==0){c[ax>>2]=2;if((a[405432]&1)==0){bR=bG;F=1871;break}az=c[140620]|0;bH=(az|0)!=0?az:c[t>>2]|0;be(11816,42,1,bH|0)|0;bH=c[140620]|0;az=(bH|0)!=0?bH:c[t>>2]|0;a7(az|0)|0;bR=bG;F=1871;break}if((db(W|0,12744)|0)!=0){az=c[140620]|0;bH=(az|0)!=0?az:c[t>>2]|0;be(11440,54,1,bH|0)|0;bH=c[140620]|0;az=(bH|0)!=0?bH:c[t>>2]|0;a7(az|0)|0;bS=0;break}c[ax>>2]=1;if((a[405432]&1)==0){bR=bG;F=1871;break}az=c[140620]|0;be(11616,41,1,((az|0)!=0?az:c[t>>2]|0)|0)|0;az=c[140620]|0;a7(((az|0)!=0?az:c[t>>2]|0)|0)|0;bR=bG;F=1871}}while(0);if((F|0)==1858){F=0;a[W]=0;bR=bG;F=1871}do{if((F|0)==1871){while(1){F=0;bT=c[bR>>2]|0;if((bT|0)==0){F=1878;break}if((db(11344,c[bT>>2]|0)|0)==0){F=1873;break}else{bR=bT+8|0;F=1871}}L2727:do{if((F|0)==1873){F=0;ax=c[bT+4>>2]|0;if((ax|0)==0){F=1878;break}else{bU=64;bV=ae;bW=ax}while(1){ax=bU-1|0;if((ax|0)==0){break}az=a[bW]|0;a[bV]=az;if(az<<24>>24==0){bX=bG;break L2727}else{bU=ax;bV=bV+1|0;bW=bW+1|0}}a[bV]=0;if((a[bW]|0)==0){bX=bG;break}else{bY=bW}while(1){ax=bY+1|0;if((a[ax]|0)==0){bX=bG;break}else{bY=ax}}}}while(0);if((F|0)==1878){F=0;a[ae]=0;bX=bG}while(1){bZ=c[bX>>2]|0;if((bZ|0)==0){F=1886;break}if((db(11192,c[bZ>>2]|0)|0)==0){F=1881;break}else{bX=bZ+8|0}}L2740:do{if((F|0)==1881){F=0;ax=c[bZ+4>>2]|0;if((ax|0)==0){F=1886;break}else{b_=64;b$=af;b0=ax}while(1){ax=b_-1|0;if((ax|0)==0){break}az=a[b0]|0;a[b$]=az;if(az<<24>>24==0){b1=bG;break L2740}else{b_=ax;b$=b$+1|0;b0=b0+1|0}}a[b$]=0;if((a[b0]|0)==0){b1=bG;break}else{b2=b0}while(1){ax=b2+1|0;if((a[ax]|0)==0){b1=bG;break}else{b2=ax}}}}while(0);if((F|0)==1886){F=0;a[af]=0;b1=bG}while(1){b3=c[b1>>2]|0;if((b3|0)==0){F=1894;break}if((db(11064,c[b3>>2]|0)|0)==0){F=1889;break}else{b1=b3+8|0}}L2753:do{if((F|0)==1889){F=0;ax=c[b3+4>>2]|0;if((ax|0)==0){F=1894;break}else{b4=64;b5=ag;b6=ax}while(1){ax=b4-1|0;if((ax|0)==0){break}az=a[b6]|0;a[b5]=az;if(az<<24>>24==0){b7=bG;break L2753}else{b4=ax;b5=b5+1|0;b6=b6+1|0}}a[b5]=0;if((a[b6]|0)==0){b7=bG;break}else{b8=b6}while(1){ax=b8+1|0;if((a[ax]|0)==0){b7=bG;break}else{b8=ax}}}}while(0);if((F|0)==1894){F=0;a[ag]=0;b7=bG}while(1){b9=c[b7>>2]|0;if((b9|0)==0){F=1902;break}if((db(10904,c[b9>>2]|0)|0)==0){F=1897;break}else{b7=b9+8|0}}L2766:do{if((F|0)==1897){F=0;ax=c[b9+4>>2]|0;if((ax|0)==0){F=1902;break}else{ca=64;cb=ah;cc=ax}while(1){ax=ca-1|0;if((ax|0)==0){break}az=a[cc]|0;a[cb]=az;if(az<<24>>24==0){cd=bG;break L2766}else{ca=ax;cb=cb+1|0;cc=cc+1|0}}a[cb]=0;if((a[cc]|0)==0){cd=bG;break}else{ce=cc}while(1){ax=ce+1|0;if((a[ax]|0)==0){cd=bG;break}else{ce=ax}}}}while(0);if((F|0)==1902){F=0;a[ah]=0;cd=bG}while(1){cf=c[cd>>2]|0;if((cf|0)==0){F=1910;break}if((db(55008,c[cf>>2]|0)|0)==0){F=1905;break}else{cd=cf+8|0}}L2779:do{if((F|0)==1905){F=0;ax=c[cf+4>>2]|0;if((ax|0)==0){F=1910;break}else{cg=64;ch=ai;ci=ax}while(1){ax=cg-1|0;if((ax|0)==0){break}az=a[ci]|0;a[ch]=az;if(az<<24>>24==0){cj=bG;break L2779}else{cg=ax;ch=ch+1|0;ci=ci+1|0}}a[ch]=0;if((a[ci]|0)==0){cj=bG;break}else{ck=ci}while(1){ax=ck+1|0;if((a[ax]|0)==0){cj=bG;break}else{ck=ax}}}}while(0);if((F|0)==1910){F=0;a[ai]=0;cj=bG}while(1){cl=c[cj>>2]|0;if((cl|0)==0){F=1918;break}if((db(54816,c[cl>>2]|0)|0)==0){F=1913;break}else{cj=cl+8|0}}L2792:do{if((F|0)==1913){F=0;ax=c[cl+4>>2]|0;if((ax|0)==0){F=1918;break}else{cm=64;cn=aj;co=ax}while(1){ax=cm-1|0;if((ax|0)==0){break}az=a[co]|0;a[cn]=az;if(az<<24>>24==0){cp=bG;break L2792}else{cm=ax;cn=cn+1|0;co=co+1|0}}a[cn]=0;if((a[co]|0)==0){cp=bG;break}else{cq=co}while(1){ax=cq+1|0;if((a[ax]|0)==0){cp=bG;break}else{cq=ax}}}}while(0);if((F|0)==1918){F=0;a[aj]=0;cp=bG}while(1){cr=c[cp>>2]|0;if((cr|0)==0){F=1926;break}if((db(54232,c[cr>>2]|0)|0)==0){F=1921;break}else{cp=cr+8|0}}L2805:do{if((F|0)==1921){F=0;ax=c[cr+4>>2]|0;if((ax|0)==0){F=1926;break}else{cs=64;ct=ak;cu=ax}while(1){ax=cs-1|0;if((ax|0)==0){break}az=a[cu]|0;a[ct]=az;if(az<<24>>24==0){cv=bG;break L2805}else{cs=ax;ct=ct+1|0;cu=cu+1|0}}a[ct]=0;if((a[cu]|0)==0){cv=bG;break}else{cw=cu}while(1){ax=cw+1|0;if((a[ax]|0)==0){cv=bG;break}else{cw=ax}}}}while(0);if((F|0)==1926){F=0;a[ak]=0;cv=bG}while(1){cx=c[cv>>2]|0;if((cx|0)==0){F=1934;break}if((db(54088,c[cx>>2]|0)|0)==0){F=1929;break}else{cv=cx+8|0}}L2818:do{if((F|0)==1929){F=0;ax=c[cx+4>>2]|0;if((ax|0)==0){F=1934;break}else{cy=64;cz=al;cA=ax}while(1){ax=cy-1|0;if((ax|0)==0){break}az=a[cA]|0;a[cz]=az;if(az<<24>>24==0){cB=bG;break L2818}else{cy=ax;cz=cz+1|0;cA=cA+1|0}}a[cz]=0;if((a[cA]|0)==0){cB=bG;break}else{cC=cA}while(1){ax=cC+1|0;if((a[ax]|0)==0){cB=bG;break}else{cC=ax}}}}while(0);if((F|0)==1934){F=0;a[al]=0;cB=bG}while(1){cD=c[cB>>2]|0;if((cD|0)==0){F=1942;break}if((db(53872,c[cD>>2]|0)|0)==0){F=1937;break}else{cB=cD+8|0}}L2831:do{if((F|0)==1937){F=0;ax=c[cD+4>>2]|0;if((ax|0)==0){F=1942;break}else{cF=64;cG=am;cH=ax}while(1){ax=cF-1|0;if((ax|0)==0){break}az=a[cH]|0;a[cG]=az;if(az<<24>>24==0){cI=bG;break L2831}else{cF=ax;cG=cG+1|0;cH=cH+1|0}}a[cG]=0;if((a[cH]|0)==0){cI=bG;break}else{cJ=cH}while(1){ax=cJ+1|0;if((a[ax]|0)==0){cI=bG;break}else{cJ=ax}}}}while(0);if((F|0)==1942){F=0;a[am]=0;cI=bG}while(1){cK=c[cI>>2]|0;if((cK|0)==0){F=1950;break}if((db(53688,c[cK>>2]|0)|0)==0){F=1945;break}else{cI=cK+8|0}}L2844:do{if((F|0)==1945){F=0;ax=c[cK+4>>2]|0;if((ax|0)==0){F=1950;break}else{cL=64;cM=an;cN=ax}while(1){ax=cL-1|0;if((ax|0)==0){break}az=a[cN]|0;a[cM]=az;if(az<<24>>24==0){cO=bG;break L2844}else{cL=ax;cM=cM+1|0;cN=cN+1|0}}a[cM]=0;if((a[cN]|0)==0){cO=bG;break}else{cP=cN}while(1){ax=cP+1|0;if((a[ax]|0)==0){cO=bG;break}else{cP=ax}}}}while(0);if((F|0)==1950){F=0;a[an]=0;cO=bG}while(1){cQ=c[cO>>2]|0;if((cQ|0)==0){F=1958;break}if((db(53512,c[cQ>>2]|0)|0)==0){F=1953;break}else{cO=cQ+8|0}}L2857:do{if((F|0)==1953){F=0;ax=c[cQ+4>>2]|0;if((ax|0)==0){F=1958;break}else{cR=64;cS=ao;cT=ax}while(1){ax=cR-1|0;if((ax|0)==0){break}az=a[cT]|0;a[cS]=az;if(az<<24>>24==0){break L2857}else{cR=ax;cS=cS+1|0;cT=cT+1|0}}a[cS]=0;if((a[cT]|0)==0){break}else{cU=cT}do{cU=cU+1|0;}while((a[cU]|0)!=0)}}while(0);if((F|0)==1958){F=0;a[ao]=0}a[ay]=(db(ao|0,53312)|0)==0|0;do{if((a[an]|0)!=0){ax=a4(an|0,0,0)|0;c[aB>>2]=ax;if((a[405432]&1)==0){break}az=c[140620]|0;bH=(az|0)!=0?az:c[t>>2]|0;eS(bH|0,53144,(I=i,i=i+8|0,c[I>>2]=ax,I)|0)|0;i=I;ax=c[140620]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}}while(0);do{if((a[ae]|0)==0){cV=0}else{cW=+yz(ae,0);g[au>>2]=cW;g[aG>>2]=cW;a[bF]=1;if((a[405432]&1)==0){cV=1;break}bH=c[140620]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cX=cW;eS(ax|0,52704,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[140620]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0;cV=1}}while(0);if((a[af]|0)==0){cY=cV}else{cX=+yz(af,0);g[au>>2]=cX;a[bF]=1;if((a[405432]&1)!=0){bH=c[140620]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cW=cX;eS(ax|0,52472,(I=i,i=i+8|0,h[I>>3]=cW,I)|0)|0;i=I;ax=c[140620]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}cY=cV+1|0}if((a[ag]|0)==0){cZ=cV}else{cW=+yz(ag,0);g[aG>>2]=cW;a[bF]=1;if((a[405432]&1)!=0){bH=c[140620]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cX=cW;eS(ax|0,52128,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[140620]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}cZ=cV+1|0}if((a[ah]|0)==0){c_=cY;c$=cZ}else{bH=a4(ah|0,0,0)|0;c[z+76+(av*4148|0)+4128>>2]=bH;c[z+76+(av*4148|0)+4124>>2]=bH;a[bF]=1;c[aA>>2]=1;c[aM>>2]=1;if((a[405432]&1)!=0){ax=c[140620]|0;az=(ax|0)!=0?ax:c[t>>2]|0;eS(az|0,51512,(I=i,i=i+8|0,c[I>>2]=bH,I)|0)|0;i=I;bH=c[140620]|0;az=(bH|0)!=0?bH:c[t>>2]|0;a7(az|0)|0}c_=cY+1|0;c$=cZ+1|0}if((a[ai]|0)==0){c0=c_}else{az=a4(ai|0,0,0)|0;c[z+76+(av*4148|0)+4124>>2]=az;a[bF]=1;c[aM>>2]=1;if((a[405432]&1)!=0){bH=c[140620]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;eS(ax|0,51200,(I=i,i=i+8|0,c[I>>2]=az,I)|0)|0;i=I;az=c[140620]|0;ax=(az|0)!=0?az:c[t>>2]|0;a7(ax|0)|0}c0=c_+1|0}if((a[aj]|0)==0){c1=c$}else{ax=a4(aj|0,0,0)|0;c[z+76+(av*4148|0)+4128>>2]=ax;a[bF]=1;c[aA>>2]=1;if((a[405432]&1)!=0){az=c[140620]|0;bH=(az|0)!=0?az:c[t>>2]|0;eS(bH|0,50832,(I=i,i=i+8|0,c[I>>2]=ax,I)|0)|0;i=I;ax=c[140620]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}c1=c$+1|0}if((a[ak]|0)==0){c2=c0;c3=c1}else{cX=+yz(ak,0);g[aG>>2]=cX;g[au>>2]=cX;a[bF]=1;c[aA>>2]=2;c[aM>>2]=2;if((a[405432]&1)!=0){bH=c[140620]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cW=cX;eS(ax|0,50568,(I=i,i=i+8|0,h[I>>3]=cW,I)|0)|0;i=I;ax=c[140620]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}c2=c0+1|0;c3=c1+1|0}if((a[al]|0)==0){c4=c2}else{cW=+yz(al,0);g[au>>2]=cW;a[bF]=1;c[aM>>2]=2;if((a[405432]&1)!=0){bH=c[140620]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cX=cW;eS(ax|0,50456,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[140620]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}c4=c2+1|0}if((a[am]|0)==0){c5=c3}else{cX=+yz(am,0);g[aG>>2]=cX;a[bF]=1;c[aA>>2]=2;if((a[405432]&1)!=0){bH=c[140620]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cW=cX;eS(ax|0,50208,(I=i,i=i+8|0,h[I>>3]=cW,I)|0)|0;i=I;ax=c[140620]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}c5=c3+1|0}if(c4>>>0>1){bS=0;break}bS=c5>>>0<2}}while(0);if(!bS){F=2e3;break L2473}c[aa>>2]=(c[aa>>2]|0)+1}}while(0);aA=c[at+16>>2]|0;if((aA|0)==0){F=2156;break L2471}else{at=aA}}if((F|0)==2129){at=c[140620]|0;am=(at|0)!=0?at:c[t>>2]|0;be(17504,46,1,am|0)|0;am=c[140620]|0;at=(am|0)!=0?am:c[t>>2]|0;a7(at|0)|0;F=2154}else if((F|0)==2033){at=c[140620]|0;be(13184,51,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=2044}else if((F|0)==2035){at=c[140620]|0;be(12912,57,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=2044}else if((F|0)==2099){at=c[140620]|0;be(14976,57,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=2126}else if((F|0)==2111){at=c[140620]|0;be(14432,56,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=2126}else if((F|0)==2117){at=c[140620]|0;be(14200,52,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=2126}else if((F|0)==2120){at=c[140620]|0;be(13792,65,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=2126}else if((F|0)==2148){at=c[140620]|0;be(16808,52,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=2154}else if((F|0)==2150){c[ar>>2]=0;F=2154}else if((F|0)==2153){at=c[140620]|0;be(16560,48,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=2154}else if((F|0)==2042){at=c[140620]|0;be(12016,46,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=2044}else if((F|0)==2047){at=c[140620]|0;be(16248,51,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=2126}else if((F|0)==1844){at=c[140620]|0;be(43704,75,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;yt(aw);break L2410}else if((F|0)==1846){at=c[140620]|0;be(41568,74,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;break L2410}else if((F|0)==1851){at=c[140620]|0;be(39488,98,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;yt(aw);break L2410}else if((F|0)==1853){at=c[140620]|0;be(41568,74,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;break L2410}else if((F|0)==2e3){at=c[140620]|0;be(38216,78,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;break L2410}if((F|0)==2126){at=c[140620]|0;am=(at|0)!=0?at:c[t>>2]|0;be(33384,46,1,am|0)|0;am=c[140620]|0;at=(am|0)!=0?am:c[t>>2]|0;a7(at|0)|0;break L2410}else if((F|0)==2154){at=c[140620]|0;be(31896,40,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;break L2410}else if((F|0)==2044){at=c[140620]|0;be(35128,51,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[140620]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;break L2410}}}while(0);do{if((F|0)==2156){if((c[aa>>2]|0)!=0){break}G=c[140620]|0;P=(G|0)!=0?G:c[t>>2]|0;be(31488,82,1,P|0)|0;P=c[140620]|0;G=(P|0)!=0?P:c[t>>2]|0;a7(G|0)|0;break L2410}}while(0);aa=c[E>>2]|0;if((aa|0)!=0){iq(aa)}yt(D);break L2389}else{aa=c[140620]|0;eS(((aa|0)!=0?aa:c[t>>2]|0)|0,21968,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;aa=c[140620]|0;a7(((aa|0)!=0?aa:c[t>>2]|0)|0)|0}}while(0);C=c[140620]|0;aa=(C|0)!=0?C:c[t>>2]|0;be(31064,51,1,aa|0)|0;aa=c[140620]|0;C=(aa|0)!=0?aa:c[t>>2]|0;a7(C|0)|0;if(!B){break}C=c[D>>2]|0;if((C|0)!=0){iq(C)}yt(D)}}while(0);A=c[140620]|0;C=(A|0)!=0?A:c[t>>2]|0;be(36936,56,1,C|0)|0;C=c[140620]|0;A=(C|0)!=0?C:c[t>>2]|0;a7(A|0)|0;y=0;i=e;return y|0}}while(0);i$(c[73716]|0,d);d=(a[294896]&1)==0;L2965:do{if((a[(c[73716]|0)+4|0]&1)==0){aw=c[140620]|0;bS=(aw|0)!=0?aw:c[t>>2]|0;be(25016,90,1,bS|0)|0;bS=c[140620]|0;aw=(bS|0)!=0?bS:c[t>>2]|0;a7(aw|0)|0}else{aw=kq(d?21376:21e3,d?22480:22056,0)|0;c[75576]=aw;if((aw|0)==0){aw=c[140620]|0;bS=(aw|0)!=0?aw:c[t>>2]|0;be(21808,60,1,bS|0)|0;bS=c[140620]|0;aw=(bS|0)!=0?bS:c[t>>2]|0;a7(aw|0)|0;break}else{c6=0}while(1){c7=c[73716]|0;if(c6>>>0>=(c[c7+72>>2]|0)>>>0){F=2180;break}c8=c7+76+(c6*4148|0)|0;aw=c7+76+(c6*4148|0)+4096|0;if((a[c8]|0)==0){c9=c[aw>>2]|0;da=c[c7+76+(c6*4148|0)+4100>>2]|0}else{if((hb(c8,aw)|0)<1){F=2177;break}bS=dW(c[aw>>2]|0)|0;c[c7+76+(c6*4148|0)+4100>>2]=bS;if((bS|0)==0){F=2177;break}c5=c[aw>>2]|0;if((c5|0)==0){F=2177;break}else{c9=c5;da=bS}}a[c8]=0;bS=kq(c9,da,c6)|0;c5=c6+1|0;c[302304+(c5<<2)>>2]=bS;if((bS|0)==0){F=2179;break}else{c6=c5}}if((F|0)==2177){c5=c[140620]|0;bS=(c5|0)!=0?c5:c[t>>2]|0;eS(bS|0,28920,(I=i,i=i+8|0,c[I>>2]=c8,I)|0)|0;i=I;bS=c[140620]|0;c5=(bS|0)!=0?bS:c[t>>2]|0;a7(c5|0)|0;break}else if((F|0)==2179){c5=c[140620]|0;eS(((c5|0)!=0?c5:c[t>>2]|0)|0,28536,(I=i,i=i+8|0,c[I>>2]=c6,I)|0)|0;i=I;c5=c[140620]|0;a7(((c5|0)!=0?c5:c[t>>2]|0)|0)|0;break}else if((F|0)==2180){c5=w;L2983:do{if((c[c7+66444>>2]|0)==0){dc=0}else{bM(1,302264);bS=c[73716]|0;if((c[bS+66444>>2]|0)==0){dc=0;break}aw=w|0;c4=w+4|0;c3=w+8|0;c2=0;c1=bS;while(1){if((a[405432]&1)==0){dd=c1}else{bS=c[140620]|0;c0=(bS|0)!=0?bS:c[t>>2]|0;bS=c1+66448+(c2*4168|0)+64|0;eS(c0|0,30080,(I=i,i=i+8|0,c[I>>2]=bS,I)|0)|0;i=I;bS=c[140620]|0;c0=(bS|0)!=0?bS:c[t>>2]|0;a7(c0|0)|0;dd=c[73716]|0}yB(c5|0,0,12);c0=dd+66448+(c2*4168|0)+64|0;if((a[563828]&1)==0){if(!(i5(c0,w,16,0)|0)){break}}else{if(!(i5(c0,w,0,16)|0)){break}}a6(3553,c[302264+(c2<<2)>>2]|0);fL(3553,10242,33071);fL(3553,10243,33071);c0=(c[(c[73716]|0)+66448+(c2*4168|0)+4160>>2]|0)==2?9728:9729;fL(3553,10240,c0|0);fL(3553,10241,c0|0);fV(3317,4);c0=(a[563828]&1)!=0?6408:32993;bS=c[c3>>2]|0;eI(3553,0,c0|0,c[aw>>2]|0,c[c4>>2]|0,0,c0|0,5121,bS|0);a6(3553,0);yt(bS);bS=c2+1|0;c0=c[73716]|0;if(bS>>>0<(c[c0+66444>>2]|0)>>>0){c2=bS;c1=c0}else{dc=0;break L2983}}c1=c[140620]|0;eS(((c1|0)!=0?c1:c[t>>2]|0)|0,29352,(I=i,i=i+8|0,c[I>>2]=(c[73716]|0)+66448+(c2*4168|0)+64,I)|0)|0;i=I;c1=c[140620]|0;a7(((c1|0)!=0?c1:c[t>>2]|0)|0)|0;c1=c[140620]|0;be(19360,48,1,((c1|0)!=0?c1:c[t>>2]|0)|0)|0;c1=c[140620]|0;a7(((c1|0)!=0?c1:c[t>>2]|0)|0)|0;break L2965}}while(0);do{kr(dc,c[302304+(dc<<2)>>2]|0,294904+(dc*460|0)|0);dc=dc+1|0;de=c[73716]|0;}while(dc>>>0<=(c[de+72>>2]|0)>>>0);do{if((c[de+99792>>2]|0)!=0){c5=f5[c[21528]&255](2)|0;c1=c[73716]|0;c4=c[c1+99792>>2]|0;aw=ys(12)|0;if((aw|0)==0){c[75574]=0}else{if((c[aw-4>>2]&3|0)!=0){yB(aw|0,0,12)}c3=aw;D=(c4|0)==0;do{if(D){df=0}else{B=c4*112|0;if(c4>>>0<=65535){df=B;break}df=((B>>>0)/(c4>>>0)|0|0)==112?B:-1}}while(0);c2=ys(df)|0;do{if((c2|0)!=0){if((c[c2-4>>2]&3|0)==0){break}yB(c2|0,0,df|0)}}while(0);B=c2;c0=aw;c[c0>>2]=B;c[aw+4>>2]=c4;L3015:do{if(!D){bS=aw+8|0;c$=aw+10|0;z=(c5|0)==0?84632:c5;c_=0;cZ=B;while(1){cY=64;cV=cZ+(c_*112|0)|0;cU=c1+99796+(c_*80|0)|0;while(1){cT=cY-1|0;if((cT|0)==0){F=2207;break}cS=a[cU]|0;a[cV]=cS;if(cS<<24>>24==0){break}else{cY=cT;cV=cV+1|0;cU=cU+1|0}}do{if((F|0)==2207){F=0;a[cV]=0;if((a[cU]|0)==0){break}else{dg=cU}do{dg=dg+1|0;}while((a[dg]|0)!=0)}}while(0);c[(c[c0>>2]|0)+(c_*112|0)+76>>2]=c[c1+99796+(c_*80|0)+64>>2];c[(c[c0>>2]|0)+(c_*112|0)+84>>2]=c[c1+99796+(c_*80|0)+68>>2];cU=b[c1+99796+(c_*80|0)+76>>1]|0;b[(c[c0>>2]|0)+(c_*112|0)+80>>1]=cU<<16>>16==0?-1:cU;b[(c[c0>>2]|0)+(c_*112|0)+82>>1]=b[c1+99796+(c_*80|0)+78>>1]|0;cU=c[c1+99796+(c_*80|0)+72>>2]|0;if((cU|0)==1){c[(c[c0>>2]|0)+(c_*112|0)+72>>2]=z}else if((cU|0)==2){c[(c[c0>>2]|0)+(c_*112|0)+68>>2]=bS;a[(c[c0>>2]|0)+(c_*112|0)+64|0]=1}else if((cU|0)==3){c[(c[c0>>2]|0)+(c_*112|0)+68>>2]=c$;a[(c[c0>>2]|0)+(c_*112|0)+64|0]=1}else{c[(c[c0>>2]|0)+(c_*112|0)+72>>2]=84632}cU=c_+1|0;if(cU>>>0>=c4>>>0){break L3015}c_=cU;cZ=c[c0>>2]|0}}}while(0);c[75574]=c3;if((aw|0)!=0){break}}c0=c[140620]|0;c4=(c0|0)!=0?c0:c[t>>2]|0;be(16984,50,1,c4|0)|0;c4=c[140620]|0;c0=(c4|0)!=0?c4:c[t>>2]|0;a7(c0|0)|0}}while(0);a[7856]=1;c0=c[73716]|0;c4=c0+72|0;c[302304+((c[c4>>2]|0)+1<<2)>>2]=c[75576];c1=294904+(((c[c4>>2]|0)+1|0)*460|0)|0;yE(c1|0,294904,460)|0;if((a[c0+4|0]&1)==0){c[75591]=c[75576];yE(301804,294904,460)|0}else{c0=(a[294896]&1)!=0;c1=kq(c0?51664:54360,c0?12176:14616,15)|0;c[75591]=c1;kr(0,c1,301804)}if((c[75750]|0)!=0){c1=0;do{dt(c[302888+(c1<<2)>>2]|0);c1=c1+1|0;}while(c1>>>0<(c[75750]|0)>>>0)}c[75750]=0;c1=0;while(1){fa(1,278224+(c1*1040|0)|0);fa(1,278744+(c1*1040|0)|0);c0=c1+1|0;if(c0>>>0<16){c1=c0}else{y=1;break}}i=e;return y|0}}}while(0);kf();y=0;i=e;return y|0}function kf(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;eG(0);f=e;g=e;h=0;do{j=c[302304+(h<<2)>>2]|0;do{if((j|0)!=0){if((h|0)!=0&(j|0)==(c[75576]|0)){break}c[e>>2]=0;c[e+4>>2]=0;cl(j|0,2,d|0,g|0);if((c[d>>2]|0)>0){k=0;do{l=f+(k<<2)|0;dg(j|0,c[l>>2]|0);by(c[l>>2]|0);k=k+1|0;}while((k|0)<(c[d>>2]|0))}cz(j|0)}}while(0);h=h+1|0;}while(h>>>0<16);h=c[73716]|0;do{if((h|0)==0){m=0}else{d=c[h+66444>>2]|0;if((d|0)==0){m=h;break}br(d|0,302264);m=c[73716]|0}}while(0);yB(302304,0,64);yB(294904,0,7360);a[7856]=0;c[141014]=0;if((m|0)!=0){if((c[m+72>>2]|0)==0){n=m}else{h=0;d=m;while(1){yt(c[d+76+(h*4148|0)+4096>>2]|0);yt(c[(c[73716]|0)+76+(h*4148|0)+4100>>2]|0);m=h+1|0;f=c[73716]|0;if(m>>>0<(c[f+72>>2]|0)>>>0){h=m;d=f}else{n=f;break}}}yt(c[n+109012>>2]|0);yt(c[73716]|0);c[73716]=0}n=c[75574]|0;if((n|0)!=0){yt(c[n>>2]|0);yt(n)}c[75574]=0;if((c[75750]|0)!=0){n=0;do{dt(c[302888+(n<<2)>>2]|0);n=n+1|0;}while(n>>>0<(c[75750]|0)>>>0)}c[75750]=0;n=0;do{d=278224+(n*1040|0)|0;if((c[d>>2]|0)!=0){fP(1,d|0)}d=278744+(n*1040|0)|0;if((c[d>>2]|0)!=0){fP(1,d|0)}n=n+1|0;}while(n>>>0<16);yB(278224,0,16640);i=b;return}function kg(){return c[(c[73716]|0)+72>>2]|0}function kh(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==0|a[7856]^1){e=0;return e|0}f=c[(c[73716]|0)+76+((b-1|0)*4148|0)+4136>>2]|0;if((f|0)==0){e=0;return e|0}a[d]=(f|0)==1|0;e=1;return e|0}function ki(b){b=b|0;var d=0;if((b|0)==0|a[7856]^1){d=0;return d|0}d=c[(c[73716]|0)+76+((b-1|0)*4148|0)+4140>>2]|0;return d|0}function kj(e,f,h,j,k,l,m,n,o,p,q){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;r=i;i=i+920|0;s=r|0;t=r+512|0;u=r+896|0;v=r+904|0;w=r+912|0;if(!(a[7856]|0)){i=r;return}x=c[141014]|0;if((c[302304+(x<<2)>>2]|0)==0){i=r;return}y=t|0;z=u|0;g[z>>2]=+(e>>>0>>>0);g[u+4>>2]=+(f>>>0>>>0);f=v|0;g[f>>2]=+(k>>>0>>>0);g[v+4>>2]=+(l>>>0>>>0);l=w|0;g[l>>2]=+(h>>>0>>>0);g[w+4>>2]=+(j>>>0>>>0);j=c[294924+(x*460|0)>>2]|0;if((j|0)>-1){bj(j|0,1,z|0)}z=c[294928+(x*460|0)>>2]|0;if((z|0)>-1){bj(z|0,1,f|0)}f=c[294932+(x*460|0)>>2]|0;if((f|0)>-1){bj(f|0,1,l|0)}l=c[294936+(x*460|0)>>2]|0;f=c[141014]|0;if((l|0)>-1&(f|0)!=0){z=c[(c[73716]|0)+76+((f-1|0)*4148|0)+4144>>2]|0;if((z|0)==0){A=m}else{A=(m>>>0)%(z>>>0)|0}b_(l|0,A|0);B=A}else{B=m}m=c[294944+(x*460|0)>>2]|0;if((m|0)>-1){b_(m|0,((a[553976]&1)!=0?-1:1)|0)}m=c[73716]|0;if((c[m+66444>>2]|0)==0){D=0}else{A=0;l=m;while(1){m=294948+(x*460|0)+(A<<2)|0;if((c[m>>2]|0)>-1){c8(A+33985|0);a6(3553,c[302264+(A<<2)>>2]|0);z=A+1|0;b_(c[m>>2]|0,z|0);E=c[73716]|0;F=z}else{E=l;F=A+1|0}z=c[E+66444>>2]|0;if(F>>>0<z>>>0){A=F;l=E}else{D=z;break}}}E=D+1|0;do{if((c[141014]|0)>>>0>1){l=294980+(x*460|0)|0;if((c[l>>2]|0)>-1){c8(D+33985|0);b_(c[l>>2]|0,E|0);a6(3553,c[n>>2]|0)}l=D+2|0;F=c[294988+(x*460|0)>>2]|0;if((F|0)>-1){bj(F|0,1,n+12|0)}F=c[294984+(x*460|0)>>2]|0;if((F|0)>-1){bj(F|0,1,n+4|0)}F=c[294992+(x*460|0)>>2]|0;if((F|0)>-1){c[t>>2]=F;c[t+4>>2]=2;c[t+8>>2]=0;F=t+12|0;A=s;z=n+20|0;yE(A|0,z|0,32)|0;G=8;H=1;I=F}else{G=0;H=0;I=y}if((q|0)==0){J=I;K=H;L=l;M=G;N=0;break}c8(q+33985+D|0);a6(3553,c[p+((q-1|0)*52|0)>>2]|0);F=I;z=H;A=l;l=0;m=G;while(1){f=c[294996+(x*460|0)+(l<<4)>>2]|0;if((f|0)!=0){b_(f|0,A|0)}f=c[294996+(x*460|0)+(l<<4)+8>>2]|0;if((f|0)>-1){bj(f|0,1,p+(l*52|0)+12|0)}f=c[294996+(x*460|0)+(l<<4)+4>>2]|0;if((f|0)>-1){bj(f|0,1,p+(l*52|0)+4|0)}f=c[294996+(x*460|0)+(l<<4)+12>>2]|0;if((f|0)>-1){c[F>>2]=f;c[F+4>>2]=2;c[F+8>>2]=m<<2;f=z+1|0;j=F+12|0;w=s+(m<<2)|0;h=p+(l*52|0)+20|0;yE(w|0,h|0,32)|0;O=m+8|0;P=f;Q=j}else{O=m;P=z;Q=F}j=l+1|0;if(j>>>0<q>>>0){F=Q;z=P;A=A+1|0;l=j;m=O}else{break}}J=Q;K=P;L=q+2+D|0;M=O;N=0}else{c8(D+33985|0);a6(3553,0);if((c[(c[73716]|0)+72>>2]|0)==0){J=y;K=0;L=E;M=0;N=0;break}m=D+33986|0;l=0;while(1){c8(m+l|0);a6(3553,0);A=l+1|0;if(A>>>0<(c[(c[73716]|0)+72>>2]|0)>>>0){l=A}else{J=y;K=0;L=E;M=0;N=0;break}}}}while(0);while(1){E=295252+(x*460|0)+(N<<4)|0;if((c[E>>2]|0)>-1){c8(L+33984|0);a6(3553,c[o+(N*52|0)>>2]|0);b_(c[E>>2]|0,L|0);R=L+1|0}else{R=L}E=c[295252+(x*460|0)+(N<<4)+8>>2]|0;if((E|0)>-1){bj(E|0,1,o+(N*52|0)+12|0)}E=c[295252+(x*460|0)+(N<<4)+4>>2]|0;if((E|0)>-1){bj(E|0,1,o+(N*52|0)+4|0)}E=c[295252+(x*460|0)+(N<<4)+12>>2]|0;if((E|0)>-1){c[J>>2]=E;c[J+4>>2]=2;c[J+8>>2]=M<<2;E=K+1|0;D=J+12|0;O=s+(M<<2)|0;q=o+(N*52|0)+20|0;yE(O|0,q|0,32)|0;S=M+8|0;T=E;U=D}else{S=M;T=K;U=J}D=N+1|0;if(D>>>0<7){J=U;K=T;L=R+1|0;M=S;N=D}else{break}}if((S|0)!=0){N=c[141014]|0;kp(c[278744+(N*1040|0)>>2]|0,278748+(N*1040|0)|0,279260+(N*1040|0)|0,s|0,S,y,T)}c8(33984);T=c[75574]|0;if((T|0)==0){i=r;return}if((c[141014]|0)==1){y=c[T+4>>2]|0;S=y>>>0<64?y:64;y=c[140914]|0;if((y|0)!=0){s=4;N=0;M=0;R=y;while(1){y=c[200+(s-4<<2)>>2]|0;V=((f4[c[R+8>>2]&15](c[140917]|0,248,0,1,0,y)|0)<<16>>16!=0)<<s|N;W=((f4[c[(c[140914]|0)+8>>2]&15](c[140917]|0,248,1,1,0,y)|0)<<16>>16!=0)<<s|M;y=s+1|0;if(y>>>0>=16){break}s=y;N=V&65535;M=W&65535;R=c[140914]|0}R=T+8|0;C=W<<16|V&65535;b[R>>1]=C&65535;b[R+2>>1]=C>>16}L3200:do{if((S|0)!=0){R=T|0;V=0;while(1){W=c[R>>2]|0;c[302368+(V<<3)>>2]=W+(V*112|0);switch(c[W+(V*112|0)+84>>2]|0){case 0:{if((a[W+(V*112|0)+64|0]&1)==0){X=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{X=b[c[W+(V*112|0)+68>>2]>>1]|0}M=b[W+(V*112|0)+80>>1]&X;N=b[W+(V*112|0)+82>>1]|0;g[302372+(V<<3)>>2]=N<<16>>16==0|M<<16>>16==N<<16>>16?+((M&65535)>>>0):0.0;break};case 1:{M=W+(V*112|0)+88|0;N=c[M>>2]|0;s=(a[W+(V*112|0)+64|0]&1)==0;if(s){Y=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{Y=b[c[W+(V*112|0)+68>>2]>>1]|0}y=b[W+(V*112|0)+80>>1]|0;L=y&Y;K=b[W+(V*112|0)+82>>1]|0;U=K<<16>>16==0;J=W+(V*112|0)+92|0;if((N|0)==((U|L<<16>>16==K<<16>>16?L&65535:0)|0)){Z=c[J>>2]|0}else{c[J>>2]=N;if(s){_=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{_=b[c[W+(V*112|0)+68>>2]>>1]|0}s=_&y;c[M>>2]=U|s<<16>>16==K<<16>>16?s&65535:0;Z=N}g[302372+(V<<3)>>2]=+(Z>>>0>>>0);break};case 2:{N=W+(V*112|0)+104|0;s=(a[W+(V*112|0)+64|0]&1)==0;if(s){$=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{$=b[c[W+(V*112|0)+68>>2]>>1]|0}K=b[W+(V*112|0)+80>>1]|0;U=K&$;M=b[W+(V*112|0)+82>>1]|0;y=M<<16>>16==0;if((c[N>>2]|0)==((y|U<<16>>16==M<<16>>16?U&65535:0)|0)){aa=c[W+(V*112|0)+96>>2]|0}else{if(s){ab=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ab=b[c[W+(V*112|0)+68>>2]>>1]|0}s=ab&K;c[N>>2]=y|s<<16>>16==M<<16>>16?s&65535:0;c[W+(V*112|0)+96>>2]=B;aa=B}g[302372+(V<<3)>>2]=+(aa|0);break};case 3:{s=W+(V*112|0)+104|0;M=(a[W+(V*112|0)+64|0]&1)==0;if(M){ac=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ac=b[c[W+(V*112|0)+68>>2]>>1]|0}y=b[W+(V*112|0)+80>>1]|0;N=y&ac;K=b[W+(V*112|0)+82>>1]|0;U=K<<16>>16==0;if((c[s>>2]|0)==((U|N<<16>>16==K<<16>>16?N&65535:0)|0)){ad=c[W+(V*112|0)+108>>2]|0}else{if(M){ae=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ae=b[c[W+(V*112|0)+68>>2]>>1]|0}M=ae&y;c[s>>2]=U|M<<16>>16==K<<16>>16?M&65535:0;M=W+(V*112|0)+108|0;K=(c[M>>2]|0)+1|0;c[M>>2]=K;ad=K}g[302372+(V<<3)>>2]=+(ad|0);break};case 4:{K=W+(V*112|0)+104|0;M=(a[W+(V*112|0)+64|0]&1)==0;if(M){af=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{af=b[c[W+(V*112|0)+68>>2]>>1]|0}U=b[W+(V*112|0)+80>>1]|0;s=U&af;y=b[W+(V*112|0)+82>>1]|0;N=y<<16>>16==0;if((c[K>>2]|0)==((N|s<<16>>16==y<<16>>16?s&65535:0)|0)){ag=c[W+(V*112|0)+100>>2]|0}else{if(M){ah=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ah=b[c[W+(V*112|0)+68>>2]>>1]|0}M=ah&U;c[K>>2]=N|M<<16>>16==y<<16>>16?M&65535:0;M=W+(V*112|0)+96|0;y=c[M>>2]|0;c[W+(V*112|0)+100>>2]=y;c[M>>2]=B;ag=y}g[302372+(V<<3)>>2]=+(ag|0);break};default:{}}V=V+1|0;if(V>>>0>=S>>>0){break L3200}}}}while(0);c[75720]=S;ai=S}else{ai=c[75720]|0}if((ai|0)==0){i=r;return}else{aj=0}do{ai=d6(c[302304+(c[141014]<<2)>>2]|0,c[302368+(aj<<3)>>2]|0)|0;bS(ai|0,+(+g[302372+(aj<<3)>>2]));aj=aj+1|0;}while(aj>>>0<(c[75720]|0)>>>0);i=r;return}function kk(b){b=b|0;var d=0;if(!(a[7856]|0)){return}if((c[75750]|0)!=0){d=0;do{dt(c[302888+(d<<2)>>2]|0);d=d+1|0;}while(d>>>0<(c[75750]|0)>>>0)}c[75750]=0;c[141014]=b;eG(c[302304+(b<<2)>>2]|0);return}function kl(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(!(a[7856]|0)){b=0;return b|0}d=c[(c[73716]|0)+72>>2]|0;if((d|0)==0){b=0;return b|0}else{e=0;f=1}while(1){if((c[295252+(f*460|0)>>2]|0)>-1){g=(e|0)==0?1:e}else{g=e}if((c[295268+(f*460|0)>>2]|0)>-1){h=g>>>0<2?2:g}else{h=g}if((c[295284+(f*460|0)>>2]|0)>-1){i=h>>>0<3?3:h}else{i=h}if((c[295300+(f*460|0)>>2]|0)>-1){j=i>>>0<4?4:i}else{j=i}if((c[295316+(f*460|0)>>2]|0)>-1){k=j>>>0<5?5:j}else{k=j}if((c[295332+(f*460|0)>>2]|0)>-1){l=k>>>0<6?6:k}else{l=k}if((c[295348+(f*460|0)>>2]|0)>-1){m=l>>>0<7?7:l}else{m=l}n=f+1|0;if(n>>>0>d>>>0){b=m;break}else{e=m;f=n}}return b|0}function km(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0|a[7856]^1){a[d|0]=0;return}else{e=d|0;d=(c[73716]|0)+76+((b-1|0)*4148|0)+4104|0;yE(e|0,d|0,32)|0;return}}function kn(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+560|0;e=d|0;f=d+512|0;if(!(a[7856]|0)){g=0;i=d;return g|0}if((a[(c[73716]|0)+4|0]&1)==0){g=0;i=d;return g|0}h=f|0;j=c[141014]|0;k=c[294908+(j*460|0)>>2]|0;if((k|0)>-1){c[f>>2]=k;c[f+4>>2]=2;c[f+8>>2]=0;k=f+12|0;f=e;l=c[b+8>>2]|0;yE(f|0,l|0,32)|0;m=k;n=1;o=8}else{m=h;n=0;o=0}k=c[294912+(j*460|0)>>2]|0;if((k|0)>-1){c[m>>2]=k;c[m+4>>2]=2;c[m+8>>2]=o<<2;k=n+1|0;l=m+12|0;f=e+(o<<2)|0;p=c[b>>2]|0;yE(f|0,p|0,32)|0;q=l;r=k;s=o+8|0}else{q=m;r=n;s=o}o=c[294916+(j*460|0)>>2]|0;if((o|0)>-1){c[q>>2]=o;c[q+4>>2]=4;c[q+8>>2]=s<<2;o=r+1|0;n=q+12|0;m=e+(s<<2)|0;k=c[b+4>>2]|0;yE(m|0,k|0,64)|0;t=n;u=o;v=s+16|0}else{t=q;u=r;v=s}s=c[294920+(j*460|0)>>2]|0;if((s|0)>-1){c[t>>2]=s;c[t+4>>2]=2;c[t+8>>2]=v<<2;t=u+1|0;s=e+(v<<2)|0;r=c[b+12>>2]|0;yE(s|0,r|0,32)|0;w=t;x=v+8|0}else{w=u;x=v}if((x|0)==0){g=1;i=d;return g|0}kp(c[278224+(j*1040|0)>>2]|0,278228+(j*1040|0)|0,278740+(j*1040|0)|0,e|0,x,h,w);g=1;i=d;return g|0}function ko(b){b=b|0;var d=0,e=0;if(!(a[7856]|0)){d=0;return d|0}if((a[(c[73716]|0)+4|0]&1)==0){d=0;return d|0}e=c[294904+((c[141014]|0)*460|0)>>2]|0;if((e|0)<=-1){d=1;return d|0}fB(e|0,1,0,b|0);d=1;return d|0}function kp(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;cf(34962,a|0);if((c[d>>2]|0)==(f|0)){a=e;i=b;j=f<<2;if((yJ(a|0,i|0,j|0)|0)!=0){k=i;l=a;m=j;n=2450}}else{k=b;l=e;m=f<<2;n=2450}if((n|0)==2450){yE(k|0,l|0,m)|0;d4(34962,m|0,l|0,35044);c[d>>2]=f}if((h|0)==0){cf(34962,0);return}else{o=0}do{f=c[g+(o*12|0)>>2]|0;dS(f|0);d=c[75750]|0;c[75750]=d+1;c[302888+(d<<2)>>2]=f;cd(f|0,c[g+(o*12|0)+4>>2]|0,5126,0,0,c[g+(o*12|0)+8>>2]|0);o=o+1|0;}while(o>>>0<h>>>0);cf(34962,0);return}function kq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+88|0;g=f|0;h=f+64|0;j=f+72|0;k=f+80|0;l=fi()|0;if((l|0)==0){m=0;i=f;return m|0}n=(b|0)!=0;do{if(n){if((a[405432]&1)!=0){o=c[140620]|0;p=(o|0)!=0?o:c[t>>2]|0;be(28176,37,1,p|0)|0;p=c[140620]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0}o=bY(35633)|0;if(kt(o,27728,b)|0){cG(l|0,o|0);break}o=c[140620]|0;p=(o|0)!=0?o:c[t>>2]|0;eS(p|0,27320,(q=i,i=i+8|0,c[q>>2]=e,q)|0)|0;i=q;p=c[140620]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0;m=0;i=f;return m|0}}while(0);b=(d|0)!=0;do{if(b){if((a[405432]&1)!=0){o=c[140620]|0;p=(o|0)!=0?o:c[t>>2]|0;be(26984,39,1,p|0)|0;p=c[140620]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0}o=bY(35632)|0;if(kt(o,26592,d)|0){cG(l|0,o|0);break}o=c[140620]|0;p=(o|0)!=0?o:c[t>>2]|0;eS(p|0,26112,(q=i,i=i+8|0,c[q>>2]=e,q)|0)|0;i=q;p=c[140620]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0;m=0;i=f;return m|0}}while(0);if(!(n|b)){m=l;i=f;return m|0}if((a[405432]&1)!=0){b=c[140620]|0;n=(b|0)!=0?b:c[t>>2]|0;be(25520,33,1,n|0)|0;n=c[140620]|0;b=(n|0)!=0?n:c[t>>2]|0;a7(b|0)|0}b4(l|0);eg(l|0,35714,k|0);c[h>>2]=0;eg(l|0,35716,j|0);b=c[j>>2]|0;do{if((b|0)!=0){j=ys(b)|0;if((j|0)==0){break}eJ(l|0,b|0,h|0,j|0);do{if((c[h>>2]|0)>0){if((a[405432]&1)==0){break}n=c[140620]|0;d=(n|0)!=0?n:c[t>>2]|0;eS(d|0,24496,(q=i,i=i+8|0,c[q>>2]=j,q)|0)|0;i=q;d=c[140620]|0;n=(d|0)!=0?d:c[t>>2]|0;a7(n|0)|0}}while(0);yt(j)}}while(0);if((c[k>>2]|0)!=1){k=c[140620]|0;h=(k|0)!=0?k:c[t>>2]|0;eS(h|0,24712,(q=i,i=i+8|0,c[q>>2]=e,q)|0)|0;i=q;e=c[140620]|0;h=(e|0)!=0?e:c[t>>2]|0;a7(h|0)|0;m=0;i=f;return m|0}eG(l|0);eG(l|0);h=g|0;b5(h|0,64,31832,(q=i,i=i+16|0,c[q>>2]=(c[73716]|0)+5,c[q+8>>2]=31432,q)|0)|0;i=q;g=d6(l|0,h|0)|0;L3403:do{if((g|0)>-1){r=g}else{e=0;while(1){if(e>>>0>=2){r=-1;break L3403}b5(h|0,64,31832,(q=i,i=i+16|0,c[q>>2]=c[7848+(e<<2)>>2],c[q+8>>2]=31432,q)|0)|0;i=q;k=d6(l|0,h|0)|0;if((k|0)>-1){r=k;break}else{e=e+1|0}}}}while(0);b_(r|0,0);eG(0);m=l;i=f;return m|0}function kr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e+64|0;eG(b|0);g=e|0;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=49232,h)|0)|0;i=h;j=d6(b|0,g|0)|0;L3410:do{if((j|0)>-1){k=j}else{l=0;while(1){if(l>>>0>=2){k=-1;break L3410}b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(l<<2)>>2],c[h+8>>2]=49232,h)|0)|0;i=h;m=d6(b|0,g|0)|0;if((m|0)>-1){k=m;break}else{l=l+1|0}}}}while(0);c[d>>2]=k;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=47592,h)|0)|0;i=h;k=d6(b|0,g|0)|0;L3415:do{if((k|0)>-1){n=k}else{j=0;while(1){if(j>>>0>=2){n=-1;break L3415}b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(j<<2)>>2],c[h+8>>2]=47592,h)|0)|0;i=h;l=fc(b|0,g|0)|0;if((l|0)>-1){n=l;break}else{j=j+1|0}}}}while(0);c[d+4>>2]=n;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=46496,h)|0)|0;i=h;n=d6(b|0,g|0)|0;L3420:do{if((n|0)>-1){o=n}else{k=0;while(1){if(k>>>0>=2){o=-1;break L3420}b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(k<<2)>>2],c[h+8>>2]=46496,h)|0)|0;i=h;j=fc(b|0,g|0)|0;if((j|0)>-1){o=j;break}else{k=k+1|0}}}}while(0);c[d+8>>2]=o;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=45072,h)|0)|0;i=h;o=d6(b|0,g|0)|0;L3425:do{if((o|0)>-1){p=o}else{n=0;while(1){if(n>>>0>=2){p=-1;break L3425}b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(n<<2)>>2],c[h+8>>2]=45072,h)|0)|0;i=h;k=fc(b|0,g|0)|0;if((k|0)>-1){p=k;break}else{n=n+1|0}}}}while(0);c[d+12>>2]=p;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=43584,h)|0)|0;i=h;p=d6(b|0,g|0)|0;L3430:do{if((p|0)>-1){q=p}else{o=0;while(1){if(o>>>0>=2){q=-1;break L3430}b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(o<<2)>>2],c[h+8>>2]=43584,h)|0)|0;i=h;n=fc(b|0,g|0)|0;if((n|0)>-1){q=n;break}else{o=o+1|0}}}}while(0);c[d+16>>2]=q;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=42456,h)|0)|0;i=h;q=d6(b|0,g|0)|0;L3435:do{if((q|0)>-1){r=q}else{p=0;while(1){if(p>>>0>=2){r=-1;break L3435}b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(p<<2)>>2],c[h+8>>2]=42456,h)|0)|0;i=h;o=d6(b|0,g|0)|0;if((o|0)>-1){r=o;break}else{p=p+1|0}}}}while(0);c[d+20>>2]=r;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=41392,h)|0)|0;i=h;r=d6(b|0,g|0)|0;L3440:do{if((r|0)>-1){s=r}else{q=0;while(1){if(q>>>0>=2){s=-1;break L3440}b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(q<<2)>>2],c[h+8>>2]=41392,h)|0)|0;i=h;p=d6(b|0,g|0)|0;if((p|0)>-1){s=p;break}else{q=q+1|0}}}}while(0);c[d+24>>2]=s;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=40376,h)|0)|0;i=h;s=d6(b|0,g|0)|0;L3445:do{if((s|0)>-1){t=s}else{r=0;while(1){if(r>>>0>=2){t=-1;break L3445}b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(r<<2)>>2],c[h+8>>2]=40376,h)|0)|0;i=h;q=d6(b|0,g|0)|0;if((q|0)>-1){t=q;break}else{r=r+1|0}}}}while(0);c[d+28>>2]=t;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=39360,h)|0)|0;i=h;t=d6(b|0,g|0)|0;L3450:do{if((t|0)>-1){u=t}else{s=0;while(1){if(s>>>0>=2){u=-1;break L3450}b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(s<<2)>>2],c[h+8>>2]=39360,h)|0)|0;i=h;r=d6(b|0,g|0)|0;if((r|0)>-1){u=r;break}else{s=s+1|0}}}}while(0);c[d+32>>2]=u;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=38072,h)|0)|0;i=h;u=d6(b|0,g|0)|0;L3455:do{if((u|0)>-1){v=u}else{t=0;while(1){if(t>>>0>=2){v=-1;break L3455}b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(t<<2)>>2],c[h+8>>2]=38072,h)|0)|0;i=h;s=d6(b|0,g|0)|0;if((s|0)>-1){v=s;break}else{t=t+1|0}}}}while(0);c[d+40>>2]=v;v=c[73716]|0;if((c[v+66444>>2]|0)!=0){g=0;u=v;do{c[d+44+(g<<2)>>2]=d6(b|0,u+66448+(g*4168|0)|0)|0;g=g+1|0;u=c[73716]|0;}while(g>>>0<(c[u+66444>>2]|0)>>>0)}u=d+76|0;yB(u|0,-1|0,16);ks(b,u,36376);g=f|0;if(a>>>0>1){b5(g|0,64,35e3,(h=i,i=i+8|0,c[h>>2]=a,h)|0)|0;i=h;ks(b,u,g);w=0}else{w=0}while(1){u=w+1|0;b5(g|0,64,33896,(h=i,i=i+8|0,c[h>>2]=u,h)|0)|0;i=h;f=d+92+(w<<4)|0;yB(f|0,-1|0,16);ks(b,f,g);if((w|0)!=0&u>>>0<a>>>0){v=a-w|0;b5(g|0,64,35e3,(h=i,i=i+8|0,c[h>>2]=v,h)|0)|0;i=h;ks(b,f,g)}if(u>>>0<16){w=u}else{break}}w=d+348|0;yB(w|0,-1|0,16);ks(b,w,33344);b5(g|0,64,32528,(h=i,i=i+8|0,c[h>>2]=1,h)|0)|0;i=h;w=d+364|0;yB(w|0,-1|0,16);ks(b,w,g);b5(g|0,64,32528,(h=i,i=i+8|0,c[h>>2]=2,h)|0)|0;i=h;w=d+380|0;yB(w|0,-1|0,16);ks(b,w,g);b5(g|0,64,32528,(h=i,i=i+8|0,c[h>>2]=3,h)|0)|0;i=h;w=d+396|0;yB(w|0,-1|0,16);ks(b,w,g);b5(g|0,64,32528,(h=i,i=i+8|0,c[h>>2]=4,h)|0)|0;i=h;w=d+412|0;yB(w|0,-1|0,16);ks(b,w,g);b5(g|0,64,32528,(h=i,i=i+8|0,c[h>>2]=5,h)|0)|0;i=h;w=d+428|0;yB(w|0,-1|0,16);ks(b,w,g);b5(g|0,64,32528,(h=i,i=i+8|0,c[h>>2]=6,h)|0)|0;i=h;h=d+444|0;yB(h|0,-1|0,16);ks(b,h,g);eG(0);i=e;return}function ks(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+320|0;f=e|0;g=e+64|0;b5(g|0,64,31832,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=31432,h)|0)|0;i=h;j=e+128|0;b5(j|0,64,31832,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=40376,h)|0)|0;i=h;k=e+192|0;b5(k|0,64,31832,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=42456,h)|0)|0;i=h;l=e+256|0;b5(l|0,64,31832,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=47592,h)|0)|0;i=h;d=b|0;if((c[d>>2]|0)<0){m=f|0;n=(c[73716]|0)+5|0;b5(m|0,64,31832,(h=i,i=i+16|0,c[h>>2]=n,c[h+8>>2]=g,h)|0)|0;i=h;n=d6(a|0,m|0)|0;L3475:do{if((n|0)>-1){o=n}else{p=0;while(1){if(p>>>0>=2){o=-1;break L3475}b5(m|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(p<<2)>>2],c[h+8>>2]=g,h)|0)|0;i=h;q=d6(a|0,m|0)|0;if((q|0)>-1){o=q;break}else{p=p+1|0}}}}while(0);c[d>>2]=o}o=b+8|0;if((c[o>>2]|0)<0){d=f|0;m=(c[73716]|0)+5|0;b5(d|0,64,31832,(h=i,i=i+16|0,c[h>>2]=m,c[h+8>>2]=j,h)|0)|0;i=h;m=d6(a|0,d|0)|0;L3483:do{if((m|0)>-1){r=m}else{g=0;while(1){if(g>>>0>=2){r=-1;break L3483}b5(d|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(g<<2)>>2],c[h+8>>2]=j,h)|0)|0;i=h;n=d6(a|0,d|0)|0;if((n|0)>-1){r=n;break}else{g=g+1|0}}}}while(0);c[o>>2]=r}r=b+4|0;if((c[r>>2]|0)<0){o=f|0;d=(c[73716]|0)+5|0;b5(o|0,64,31832,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=k,h)|0)|0;i=h;d=d6(a|0,o|0)|0;L3491:do{if((d|0)>-1){s=d}else{j=0;while(1){if(j>>>0>=2){s=-1;break L3491}b5(o|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(j<<2)>>2],c[h+8>>2]=k,h)|0)|0;i=h;m=d6(a|0,o|0)|0;if((m|0)>-1){s=m;break}else{j=j+1|0}}}}while(0);c[r>>2]=s}s=b+12|0;if((c[s>>2]|0)>=0){i=e;return}b=f|0;b5(b|0,64,31832,(h=i,i=i+16|0,c[h>>2]=(c[73716]|0)+5,c[h+8>>2]=l,h)|0)|0;i=h;f=d6(a|0,b|0)|0;L3500:do{if((f|0)>-1){t=f}else{r=0;while(1){if(r>>>0>=2){t=-1;break L3500}b5(b|0,64,31832,(h=i,i=i+16|0,c[h>>2]=c[7848+(r<<2)>>2],c[h+8>>2]=l,h)|0)|0;i=h;o=fc(a|0,b|0)|0;if((o|0)>-1){t=o;break}else{r=r+1|0}}}}while(0);c[s>>2]=t;i=e;return}function kt(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+72|0;g=f|0;h=f+8|0;j=f+48|0;k=f+64|0;l=f+16|0;yB(l|0,0,32);do{if((a[294896]&1)!=0){if((bJ(e|0,24256)|0)!=0){break}m=((c[73718]|0)*10|0)+((c[73720]|0)*100|0)|0;if((m|0)==300){n=130}else if((m|0)==310){n=140}else if((m|0)==320){n=150}else{n=m}b5(l|0,32,23944,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;if((a[405432]&1)==0){break}m=c[140620]|0;p=(m|0)!=0?m:c[t>>2]|0;eS(p|0,23656,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;p=c[140620]|0;m=(p|0)!=0?p:c[t>>2]|0;a7(m|0)|0}}while(0);n=j|0;c[n>>2]=l;c[j+4>>2]=d;c[j+8>>2]=e;ca(b|0,3,n|0,0);bo(b|0);dh(b|0,35713,k|0);c[g>>2]=0;dh(b|0,35716,h|0);n=c[h>>2]|0;if((n|0)==0){q=c[k>>2]|0;r=(q|0)==1;i=f;return r|0}h=ys(n)|0;if((h|0)==0){q=c[k>>2]|0;r=(q|0)==1;i=f;return r|0}eP(b|0,n|0,g|0,h|0);do{if((c[g>>2]|0)>0){if((a[405432]&1)==0){break}n=c[140620]|0;b=(n|0)!=0?n:c[t>>2]|0;eS(b|0,23384,(o=i,i=i+8|0,c[o>>2]=h,o)|0)|0;i=o;b=c[140620]|0;n=(b|0)!=0?b:c[t>>2]|0;a7(n|0)|0}}while(0);yt(h);q=c[k>>2]|0;r=(q|0)==1;i=f;return r|0}function ku(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=i;k=e|0;l=e+4|0;m=e+9|0;switch(d[m]|0){case 2:{n=(d[e+8|0]|0)*3|0;o=((ag(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 6:{n=d[e+8|0]<<2;o=((ag(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 4:{n=d[e+8|0]<<1;o=((ag(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 0:{n=d[e+8|0]|0;o=((ag(c[k>>2]|0,n)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 3:{n=d[e+8|0]|0;o=((ag(c[k>>2]|0,n)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};default:{o=0;p=0}}n=o+1|0;if((ag(c[l>>2]|0,n)|0)>>>0>g>>>0){q=0;i=j;return q|0}g=ys(o)|0;do{if((g|0)!=0){if((c[g-4>>2]&3|0)==0){break}yB(g|0,0,o|0)}}while(0);r=ys(o)|0;L3543:do{if((r|0)==0){s=c[t>>2]|0;eS(s|0,49880,(u=i,i=i+8|0,c[u>>2]=394,u)|0)|0;i=u;v=0}else{if((c[r-4>>2]&3|0)!=0){yB(r|0,0,o|0)}if((c[l>>2]|0)==0){v=1;break}s=e+8|0;w=(p|0)==0;x=(o|0)==0;y=0;z=f;A=b;L3549:while(1){L3551:do{switch(d[z]|0){case 1:{if(w){B=0}else{C=0;while(1){D=C+1|0;a[r+C|0]=a[z+D|0]|0;if(D>>>0<p>>>0){C=D}else{B=p;break}}}if(B>>>0<o>>>0){E=B}else{break L3551}while(1){C=E+1|0;a[r+E|0]=(a[z+C|0]|0)+(a[r+(E-B)|0]|0)&255;if(C>>>0<o>>>0){E=C}else{break}}break};case 2:{if(x){break L3551}else{F=0}while(1){C=F+1|0;a[r+F|0]=(a[z+C|0]|0)+(a[g+F|0]|0)&255;if(C>>>0<o>>>0){F=C}else{break}}break};case 3:{if(w){G=0}else{C=0;while(1){D=C+1|0;a[r+C|0]=((d[g+C|0]|0)>>>1)+(a[z+D|0]|0)&255;if(D>>>0<p>>>0){C=D}else{G=p;break}}}if(G>>>0<o>>>0){H=G}else{break L3551}while(1){C=H+1|0;a[r+H|0]=(((d[g+H|0]|0)+(d[r+(H-G)|0]|0)|0)>>>1)+(d[z+C|0]|0)&255;if(C>>>0<o>>>0){H=C}else{break}}break};case 0:{C=z+1|0;yE(r|0,C|0,o)|0;break};case 4:{if(w){I=0}else{C=0;while(1){D=C+1|0;a[r+C|0]=(a[z+D|0]|0)+(a[g+C|0]|0)&255;if(D>>>0<p>>>0){C=D}else{I=p;break}}}if(I>>>0<o>>>0){J=I}else{break L3551}while(1){C=J-I|0;D=a[r+C|0]|0;K=D&255;L=a[g+J|0]|0;M=L&255;N=a[g+C|0]|0;C=N&255;O=M+K-C|0;P=O-K|0;K=(P|0)>-1?P:-P|0;P=O-M|0;M=(P|0)>-1?P:-P|0;P=O-C|0;C=(P|0)>-1?P:-P|0;if((K|0)>(M|0)|(K|0)>(C|0)){Q=(M|0)>(C|0)?N:L}else{Q=D}D=J+1|0;a[r+J|0]=(a[z+D|0]|0)+Q&255;if(D>>>0<o>>>0){J=D}else{break}}break};default:{break L3549}}}while(0);L3581:do{switch(a[m]|0){case 3:{D=c[k>>2]|0;L=d[s]|0;N=(1<<L)-1|0;if((D|0)==0){break L3581}C=8-L|0;M=0;K=0;while(1){c[A+(K<<2)>>2]=c[h+(((d[r+(M>>>3)|0]|0)>>>((C-(M&7)|0)>>>0)&N)<<2)>>2];P=K+1|0;if(P>>>0<D>>>0){M=M+L|0;K=P}else{break}}break};case 2:{K=c[k>>2]|0;L=(d[s]|0)>>>3;if((K|0)==0){break L3581}M=L<<1;D=M+L|0;N=0;C=r;while(1){c[A+(N<<2)>>2]=d[C]<<16|d[C+L|0]<<8|d[C+M|0]|-16777216;P=N+1|0;if(P>>>0<K>>>0){N=P;C=C+D|0}else{break}}break};case 4:{D=c[k>>2]|0;C=(d[s]|0)>>>3;if((D|0)==0){break L3581}N=C<<1;K=0;M=r;while(1){c[A+(K<<2)>>2]=d[M+C|0]<<24|((d[M]|0)*65793|0);L=K+1|0;if(L>>>0<D>>>0){K=L;M=M+N|0}else{break}}break};case 0:{N=c[k>>2]|0;M=a[s]|0;K=M&255;if(M<<24>>24==16){if((N|0)==0){break L3581}else{R=0}while(1){c[A+(R<<2)>>2]=(d[r+(R<<1)|0]|0)*65793|0|-16777216;R=R+1|0;if(R>>>0>=N>>>0){break L3581}}}M=(1<<K)-1|0;if((N|0)==0){break L3581}D=8-K|0;C=(c[8240+(K<<2)>>2]|0)*65793|0;L=0;P=0;while(1){c[A+(P<<2)>>2]=ag(C,(d[r+(L>>>3)|0]|0)>>>((D-(L&7)|0)>>>0)&M)|0|-16777216;O=P+1|0;if(O>>>0<N>>>0){L=L+K|0;P=O}else{break}}break};case 6:{P=c[k>>2]|0;K=(d[s]|0)>>>3;if((P|0)==0){break L3581}L=K<<1;N=L+K|0;M=N+K|0;D=0;C=r;while(1){c[A+(D<<2)>>2]=d[C+K|0]<<8|d[C]<<16|d[C+L|0]|d[C+N|0]<<24;O=D+1|0;if(O>>>0<P>>>0){D=O;C=C+M|0}else{break}}break};default:{}}}while(0);yE(g|0,r|0,o)|0;M=y+1|0;if(M>>>0<(c[l>>2]|0)>>>0){y=M;z=z+n|0;A=A+(c[k>>2]<<2)|0}else{v=1;break L3543}}eS(c[t>>2]|0,49880,(u=i,i=i+8|0,c[u>>2]=439,u)|0)|0;i=u;v=0}}while(0);yt(r);yt(g);q=v;i=j;return q|0}function kv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+16|0;d=b|0;e=b+8|0;if((a|0)==0){f=-2;i=b;return f|0}g=c[a+28>>2]|0;if((g|0)==0){f=-2;i=b;return f|0}h=g;j=(c[h+11008>>2]|0)>0?9:8;k=a+4|0;l=c[k>>2]|0;m=h+11e3|0;n=c[m>>2]|0;c[m>>2]=0;m=h+43780|0;if((c[m>>2]|0)<0){f=-3;i=b;return f|0}o=h+11004|0;c[o>>2]=c[o>>2]|1;if((n|0)!=0){c[d>>2]=c[k>>2];n=a+16|0;c[e>>2]=c[n>>2];o=g;p=a|0;q=a+12|0;r=c[q>>2]|0;s=kw(o,c[p>>2]|0,d,r,r,e,j|4)|0;c[m>>2]=s;r=c[d>>2]|0;c[p>>2]=(c[p>>2]|0)+r;c[k>>2]=(c[k>>2]|0)-r;p=a+8|0;c[p>>2]=(c[p>>2]|0)+r;c[a+40>>2]=c[o+28>>2];o=c[e>>2]|0;c[q>>2]=(c[q>>2]|0)+o;c[n>>2]=(c[n>>2]|0)-o;n=a+20|0;c[n>>2]=(c[n>>2]|0)+o;if((s|0)<0){f=-3;i=b;return f|0}if((s|0)==0){f=1;i=b;return f|0}c[m>>2]=-1;f=-5;i=b;return f|0}s=h+10996|0;o=c[s>>2]|0;if((o|0)!=0){n=a+16|0;q=c[n>>2]|0;r=o>>>0<q>>>0?o:q;q=a+12|0;o=c[q>>2]|0;p=h+10992|0;t=(c[p>>2]|0)+(h+11012)|0;yE(o|0,t|0,r)|0;c[q>>2]=(c[q>>2]|0)+r;c[n>>2]=(c[n>>2]|0)-r;n=a+20|0;c[n>>2]=(c[n>>2]|0)+r;n=c[s>>2]|0;c[s>>2]=n-r;c[p>>2]=(c[p>>2]|0)+r&32767;if((c[m>>2]|0)!=0){f=0;i=b;return f|0}f=(n|0)==(r|0)|0;i=b;return f|0}r=h+10992|0;n=g;g=a|0;p=h+11012|0;q=a+8|0;t=n+28|0;o=a+40|0;u=a+16|0;v=a+12|0;w=a+20|0;a=c[r>>2]|0;L3639:do{if((l|0)==0){x=a;while(1){c[d>>2]=c[k>>2];c[e>>2]=32768-x;y=kw(n,c[g>>2]|0,d,p,h+11012+x|0,e,j)|0;c[m>>2]=y;z=c[d>>2]|0;c[g>>2]=(c[g>>2]|0)+z;c[k>>2]=(c[k>>2]|0)-z;c[q>>2]=(c[q>>2]|0)+z;c[o>>2]=c[t>>2];z=c[e>>2]|0;c[s>>2]=z;A=c[u>>2]|0;B=z>>>0<A>>>0?z:A;A=c[v>>2]|0;z=(c[r>>2]|0)+(h+11012)|0;yE(A|0,z|0,B)|0;c[v>>2]=(c[v>>2]|0)+B;c[u>>2]=(c[u>>2]|0)-B;c[w>>2]=(c[w>>2]|0)+B;z=(c[s>>2]|0)-B|0;c[s>>2]=z;A=(c[r>>2]|0)+B&32767;c[r>>2]=A;if((y|0)<0){f=-3;C=2655;break}if((y|0)==1){f=-5;C=2649;break}else if((y|0)==0){D=z;break L3639}if((c[u>>2]|0)==0){f=-5;C=2651;break}else{x=A}}if((C|0)==2649){i=b;return f|0}else if((C|0)==2651){i=b;return f|0}else if((C|0)==2655){i=b;return f|0}}else{x=a;while(1){c[d>>2]=c[k>>2];c[e>>2]=32768-x;A=kw(n,c[g>>2]|0,d,p,h+11012+x|0,e,j)|0;c[m>>2]=A;z=c[d>>2]|0;c[g>>2]=(c[g>>2]|0)+z;c[k>>2]=(c[k>>2]|0)-z;c[q>>2]=(c[q>>2]|0)+z;c[o>>2]=c[t>>2];z=c[e>>2]|0;c[s>>2]=z;y=c[u>>2]|0;B=z>>>0<y>>>0?z:y;y=c[v>>2]|0;z=(c[r>>2]|0)+(h+11012)|0;yE(y|0,z|0,B)|0;c[v>>2]=(c[v>>2]|0)+B;c[u>>2]=(c[u>>2]|0)-B;c[w>>2]=(c[w>>2]|0)+B;z=(c[s>>2]|0)-B|0;c[s>>2]=z;y=(c[r>>2]|0)+B&32767;c[r>>2]=y;if((A|0)<0){f=-3;C=2661;break}if((A|0)==0){D=z;break L3639}if((c[u>>2]|0)==0){f=-5;C=2650;break}else{x=y}}if((C|0)==2650){i=b;return f|0}else if((C|0)==2661){i=b;return f|0}}}while(0);f=(D|0)!=0?-5:1;i=b;return f|0}function kw(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gj=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0,hQ=0,hR=0,hS=0,hT=0,hU=0,hV=0,hW=0,hX=0,hY=0,hZ=0,h_=0,h$=0,h0=0,h1=0,h2=0,h3=0,h4=0,h5=0,h6=0,h7=0,h8=0,h9=0,ia=0,ib=0,ic=0,id=0,ie=0,ig=0,ih=0,ii=0,ij=0,ik=0,il=0,im=0,io=0,ip=0,iq=0,ir=0,is=0,it=0,iu=0,iv=0,iw=0,ix=0,iy=0,iz=0,iA=0,iB=0,iC=0,iD=0,iE=0,iF=0,iG=0,iH=0,iI=0,iJ=0,iK=0,iL=0,iM=0,iN=0,iO=0,iP=0,iQ=0,iR=0,iS=0,iT=0,iU=0,iV=0,iW=0,iX=0,iY=0,iZ=0,i_=0,i$=0,i0=0,i1=0,i2=0,i3=0,i4=0,i5=0,i6=0,i7=0,i8=0,i9=0,ja=0,jb=0,jc=0,jd=0,je=0,jf=0,jg=0,jh=0,ji=0,jj=0,jk=0,jl=0,jm=0,jn=0,jo=0,jp=0,jq=0,jr=0,js=0,jt=0,ju=0,jv=0,jw=0,jx=0,jy=0,jz=0,jA=0,jB=0,jC=0,jD=0,jE=0,jF=0,jG=0,jH=0,jI=0,jJ=0,jK=0,jL=0,jM=0,jN=0,jO=0,jP=0,jQ=0,jR=0,jS=0,jT=0,jU=0,jV=0,jW=0,jX=0,jY=0,jZ=0,j_=0,j$=0,j0=0,j1=0,j2=0,j3=0,j4=0,j5=0,j6=0,j7=0,j8=0,j9=0,ka=0,kb=0,kc=0,kd=0,ke=0,kf=0,kg=0,kh=0,ki=0,kj=0,kk=0,kl=0,km=0,kn=0,ko=0,kp=0,kq=0,kr=0,ks=0,kt=0,ku=0,kv=0,kw=0,kx=0,ky=0,kz=0,kA=0,kB=0,kC=0,kD=0,kE=0,kF=0,kG=0,kH=0,kI=0,kJ=0,kK=0,kL=0,kM=0,kN=0,kO=0,kP=0,kQ=0,kR=0,kS=0,kT=0,kU=0,kV=0,kW=0,kX=0,kY=0,kZ=0,k_=0,k$=0,k0=0,k1=0,k2=0,k3=0,k4=0,k5=0,k6=0,k7=0,k8=0,k9=0,la=0,lb=0,lc=0,ld=0,le=0,lf=0,lg=0,lh=0,li=0,lj=0,lk=0,ll=0,lm=0,ln=0,lo=0,lp=0,lq=0,lr=0,ls=0,lt=0,lu=0,lv=0,lw=0,lx=0,ly=0,lz=0,lA=0,lB=0,lC=0,lD=0,lE=0,lF=0,lG=0,lH=0,lI=0,lJ=0,lK=0,lL=0,lM=0,lN=0,lO=0,lP=0,lQ=0,lR=0,lS=0,lT=0,lU=0,lV=0,lW=0,lX=0,lY=0,lZ=0,l_=0,l$=0,l0=0,l1=0,l2=0,l3=0,l4=0,l5=0,l6=0,l7=0,l8=0,l9=0,ma=0,mb=0,mc=0,md=0,me=0,mf=0,mg=0,mh=0,mi=0,mj=0,mk=0,ml=0,mm=0,mn=0,mo=0,mp=0,mq=0,mr=0,ms=0,mt=0,mu=0,mv=0,mw=0,mx=0,my=0,mz=0,mA=0,mB=0,mC=0,mD=0,mE=0,mF=0,mG=0,mH=0,mI=0,mJ=0,mK=0,mL=0,mM=0,mN=0,mO=0,mP=0,mQ=0,mR=0,mS=0,mT=0,mU=0,mV=0,mW=0,mX=0,mY=0,mZ=0,m_=0,m$=0,m0=0,m1=0,m2=0,m3=0,m4=0,m5=0;m=i;i=i+136|0;n=m|0;o=m+72|0;p=c[g>>2]|0;q=f+p|0;r=c[k>>2]|0;s=j+r|0;t=(l&4|0)!=0;if(t){u=-1}else{u=j+~h+r|0}r=u+1|0;if((r&u|0)!=0|j>>>0<h>>>0){c[k>>2]=0;c[g>>2]=0;v=-3;i=m;return v|0}w=e+4|0;x=c[w>>2]|0;y=e+56|0;z=c[y>>2]|0;A=e+32|0;B=c[A>>2]|0;D=e+36|0;E=c[D>>2]|0;F=e+40|0;G=c[F>>2]|0;H=e+60|0;I=c[H>>2]|0;J=e|0;L3665:do{switch(c[J>>2]|0){case 17:{K=x;L=B;M=E;N=G;O=z;P=I;Q=f;R=j;S=2823;break};case 18:{if((p|0)<=0){T=x;U=B;V=E;W=G;X=z;Y=I;Z=f;_=j;S=2826;break L3665}$=d[f]|0;aa=x;ab=B;ac=E;ad=G;ae=z;af=I;ag=f+1|0;ah=j;S=2831;break};case 14:{if((p|0)<=0){ai=x;aj=B;ak=E;al=G;am=z;an=I;ao=f;ap=j;S=2765;break L3665}aq=x;ar=B;as=E;at=d[f]|0;au=G;av=z;aw=I;ax=f+1|0;ay=j;S=2770;break};case 26:{if((p|0)<=0){az=x;aA=B;aB=E;aC=G;aD=z;aE=I;aF=f;aG=j;S=2899;break L3665}aH=d[f]|0;aI=x;aJ=B;aK=E;aL=G;aM=z;aN=I;aO=f+1|0;aP=j;S=2904;break};case 24:{aQ=x;aR=B;aS=E;aT=G;aU=z;aV=I;aW=f;aX=j;S=2860;break};case 32:{if((p|0)<=0){aY=x;aZ=B;a_=E;a$=G;a0=z;a1=I;a2=f;a3=j;S=2935;break L3665}a4=d[f]|0;a5=x;a6=B;a7=E;a8=G;a9=z;ba=I;bb=f+1|0;bc=j;S=2940;break};case 41:{if((p|0)<=0){bd=x;be=B;bf=E;bg=G;bh=z;bi=I;bj=f;bk=j;S=2946;break L3665}bl=d[f]|0;bm=x;bn=B;bo=E;bp=G;bq=z;br=I;bs=f+1|0;bt=j;S=2951;break};case 42:{if((p|0)<=0){bu=x;bv=B;bw=E;bx=G;by=z;bz=I;bA=f;bB=j;S=2954;break L3665}bC=d[f]|0;bD=x;bE=B;bF=E;bG=G;bH=z;bI=I;bJ=f+1|0;bK=j;S=2959;break};case 34:{bL=x;bM=B;bN=E;bO=G;bP=z;bQ=I;bR=f;bS=j;S=2960;break};case 9:{bT=x;bU=B;bV=E;bW=G;bX=z;bY=I;bZ=f;b_=j;S=2743;break};case 38:{b$=x;b0=B;b1=E;b2=G;b3=z;b4=I;b5=f;b6=j;S=2745;break};case 40:{b7=x;b8=B;b9=E;ca=G;cb=z;cc=I;cd=f;ce=j;S=2748;break};case 5:{if((p|0)<=0){cf=x;cg=B;ch=E;ci=G;cj=z;ck=I;cl=f;cm=j;S=2701;break L3665}cn=x;co=B;cp=E;cq=G;cr=z;cs=d[f]|0;ct=I;cu=f+1|0;cv=j;S=2706;break};case 3:{if((p|0)<=0){cw=x;cx=B;cy=E;cz=G;cA=z;cB=I;cC=f;cD=j;S=2692;break L3665}cE=x;cF=B;cG=E;cH=G;cI=z;cJ=d[f]|0;cK=I;cL=f+1|0;cM=j;S=2697;break};case 25:{if((p|0)<=0){cN=x;cO=B;cP=E;cQ=G;cR=z;cS=I;cT=f;cU=j;S=2883;break L3665}cV=d[f]|0;cW=x;cX=B;cY=E;cZ=G;c_=z;c$=I;c0=f+1|0;c1=j;S=2888;break};case 51:{if((p|0)<=0){c2=x;c3=B;c4=E;c5=G;c6=z;c7=I;c8=f;c9=j;S=2732;break L3665}da=x;db=B;dc=E;dd=G;de=z;df=d[f]|0;dg=I;dh=f+1|0;di=j;S=2737;break};case 52:{dj=x;dk=B;dl=E;dm=G;dn=z;dp=I;dq=f;dr=j;S=2739;break};case 27:{if((p|0)<=0){ds=x;dt=B;du=E;dv=G;dw=z;dx=I;dy=f;dz=j;S=2912;break L3665}dA=d[f]|0;dB=x;dC=B;dD=E;dE=G;dF=z;dG=I;dH=f+1|0;dI=j;S=2917;break};case 37:{dJ=x;dK=B;dL=E;dM=G;dN=z;dO=I;dP=f;dQ=j;S=2920;break};case 53:{dR=x;dS=B;dT=E;dU=G;dV=z;dW=I;dX=f;dY=j;S=2923;break};case 35:{dZ=x;d_=B;d$=E;d0=G;d1=z;d2=I;d3=f;d4=j;S=2780;break};case 36:{d5=x;d6=B;d7=E;d8=G;d9=z;ea=f;S=2689;break};case 39:{eb=x;ec=B;ed=E;ee=G;ef=z;eg=I;eh=f;ei=j;S=2728;break};case 2:{if((p|0)<=0){ej=x;ek=B;el=E;em=G;en=z;eo=f;S=2676;break L3665}ep=d[f]|0;c[e+12>>2]=ep;eq=x;er=B;es=G;et=z;eu=f+1|0;ev=ep;S=2682;break};case 16:{if((p|0)<=0){ew=x;ex=B;ey=E;ez=G;eA=z;eB=I;eC=f;eD=j;S=2810;break L3665}eE=d[f]|0;eF=x;eG=B;eH=E;eI=G;eJ=z;eK=I;eL=f+1|0;eM=j;S=2815;break};case 7:{if((p|0)<=0){eN=x;eO=B;eP=E;eQ=G;eR=z;eS=I;eT=f;eU=j;S=2720;break L3665}a[e+10528+E|0]=a[f]|0;eV=x;eW=B;eX=E;eY=G;eZ=z;e_=I;e$=f+1|0;e0=j;S=2726;break};case 23:{if((p|0)<=0){e1=x;e2=B;e3=E;e4=G;e5=z;e6=I;e7=f;e8=j;S=2849;break L3665}e9=d[f]|0;fa=x;fb=B;fc=E;fd=G;fe=z;ff=I;fg=f+1|0;fh=j;S=2854;break};case 11:{if((p|0)<=0){fi=x;fj=B;fk=E;fl=G;fm=z;fn=I;fo=f;fp=j;S=2754;break L3665}fq=x;fr=B;fs=E;ft=G;fu=d[f]|0;fv=z;fw=I;fx=f+1|0;fy=j;S=2759;break};case 10:{fz=x;fA=B;fB=E;fC=G;fD=z;fE=I;fF=f;fG=j;S=2750;break};case 21:{fH=x;fI=B;fJ=E;fK=G;fL=z;fM=I;fN=f;fO=j;S=2836;break};case 1:{if((p|0)<=0){fP=x;fQ=B;fR=E;fS=G;fT=z;S=2669;break L3665}c[e+8>>2]=d[f]|0;fU=x;fV=B;fW=E;fX=G;fY=z;fZ=f+1|0;S=2675;break};case 6:{if((p|0)<=0){f_=x;f$=B;f0=E;f1=G;f2=z;f3=I;f4=f;f5=j;S=2712;break L3665}f6=x;f7=B;f8=E;f9=G;ga=z;gb=d[f]|0;gc=I;gd=f+1|0;ge=j;S=2717;break};case 0:{c[e+12>>2]=0;ep=e+8|0;c[ep>>2]=0;c[e+28>>2]=1;c[e+16>>2]=1;if((l&1|0)==0){gf=0;gg=0;gh=0;gi=0;gj=0;gk=I;gl=f;gm=j;S=2690;break L3665}if((p|0)<1){fP=0;fQ=0;fR=0;fS=0;fT=0;S=2669;break L3665}c[ep>>2]=d[f]|0;fU=0;fV=0;fW=0;fX=0;fY=0;fZ=f+1|0;S=2675;break};default:{gn=-1;go=x;gp=B;gq=E;gr=G;gs=z;gt=I;gu=f;gv=j;S=2961}}}while(0);do{if((S|0)==2669){if((l&2|0)==0){c[e+8>>2]=0;fU=fP;fV=fQ;fW=fR;fX=fS;fY=fT;fZ=f;S=2675;break}else{c[J>>2]=1;gn=1;go=fP;gp=fQ;gq=fR;gr=fS;gs=fT;gt=I;gu=f;gv=j;S=2961;break}}}while(0);do{if((S|0)==2675){if(fZ>>>0>=q>>>0){ej=fU;ek=fV;el=fW;em=fX;en=fY;eo=fZ;S=2676;break}fT=d[fZ]|0;c[e+12>>2]=fT;eq=fU;er=fV;es=fX;et=fY;eu=fZ+1|0;ev=fT;S=2682}}while(0);do{if((S|0)==2676){if((l&2|0)==0){c[e+12>>2]=0;eq=ej;er=ek;es=em;et=en;eu=eo;ev=0;S=2682;break}else{c[J>>2]=2;gn=1;go=ej;gp=ek;gq=el;gr=em;gs=en;gt=I;gu=eo;gv=j;S=2961;break}}}while(0);if((S|0)==2682){eo=c[e+8>>2]|0;if((((eo<<8|ev)>>>0)%31|0|ev&32|0)==0){gw=(eo&15|0)!=8|0}else{gw=1}if(t){gx=gw}else{ev=1<<(eo>>>4)+8;if(ev>>>0>32768){gy=1}else{gy=r>>>0<ev>>>0|0}gx=gy|gw}if((gx|0)==0){gf=eq;gg=er;gh=0;gi=es;gj=et;gk=I;gl=eu;gm=j;S=2690}else{d5=eq;d6=er;d7=gx;d8=es;d9=et;ea=eu;S=2689}}if((S|0)==2689){c[J>>2]=36;gn=-1;go=d5;gp=d6;gq=d7;gr=d8;gs=d9;gt=I;gu=ea;gv=j;S=2961}L3731:while(1){do{if((S|0)==2706){S=0;ea=cs<<cn|cr;I=cn+8|0;if(I>>>0<(I&7)>>>0){gz=I;gA=co;gB=cp;gC=cq;gD=ea;gE=ct;gF=cu;gG=cv;S=2700}else{gH=I;gI=co;gJ=cq;gK=ea;gL=ct;gM=cu;gN=cv;S=2707}}else if((S|0)==2823){S=0;c[J>>2]=17;gn=-1;go=K;gp=L;gq=M;gr=N;gs=O;gt=P;gu=Q;gv=R;S=2961;continue L3731}else if((S|0)==2826){S=0;if((l&2|0)==0){$=0;aa=T;ab=U;ac=V;ad=W;ae=X;af=Y;ag=Z;ah=_;S=2831;continue L3731}c[J>>2]=18;gn=1;go=T;gp=U;gq=V;gr=W;gs=X;gt=Y;gu=Z;gv=_;S=2961;continue L3731}else if((S|0)==2690){S=0;if(gf>>>0<3){gO=gf;gP=gg;gQ=gh;gR=gi;gS=gj;gT=gk;gU=gl;gV=gm;S=2691}else{gW=gf;gX=gg;gY=gh;gZ=gi;g_=gj;g$=gk;g0=gl;g1=gm;S=2698}}else if((S|0)==2692){S=0;if((l&2|0)==0){cE=cw;cF=cx;cG=cy;cH=cz;cI=cA;cJ=0;cK=cB;cL=cC;cM=cD;S=2697;continue L3731}c[J>>2]=3;gn=1;go=cw;gp=cx;gq=cy;gr=cz;gs=cA;gt=cB;gu=cC;gv=cD;S=2961;continue L3731}else if((S|0)==2765){S=0;if((l&2|0)==0){aq=ai;ar=aj;as=ak;at=0;au=al;av=am;aw=an;ax=ao;ay=ap;S=2770;continue L3731}c[J>>2]=14;gn=1;go=ai;gp=aj;gq=ak;gr=al;gs=am;gt=an;gu=ao;gv=ap;S=2961;continue L3731}else if((S|0)==2770){S=0;ea=at<<aq|av;I=aq+8|0;if(I>>>0<3){g2=I;g3=ar;g4=as;g5=au;g6=ea;g7=aw;g8=ax;g9=ay;S=2764}else{ha=I;hb=ar;hc=as;hd=au;he=ea;hf=aw;hg=ax;hh=ay;S=2771}}else if((S|0)==2899){S=0;if((l&2|0)==0){aH=0;aI=az;aJ=aA;aK=aB;aL=aC;aM=aD;aN=aE;aO=aF;aP=aG;S=2904;continue L3731}c[J>>2]=26;gn=1;go=az;gp=aA;gq=aB;gr=aC;gs=aD;gt=aE;gu=aF;gv=aG;S=2961;continue L3731}else if((S|0)==2904){S=0;ea=aH<<aI|aM;I=aI+8|0;if(I>>>0<15){hi=I;hj=aJ;hk=aK;hl=aL;hm=ea;hn=aN;ho=aO;hp=aP;S=2892}else{hq=I;hr=aK;hs=ea;ht=aN;hu=aO;hv=aP;S=2906}}else if((S|0)==2860){S=0;if(aX>>>0<s>>>0){a[aX]=aS&255;hw=aQ;hx=aR;hy=aS;hz=aT;hA=aU;hB=aV;hC=aW;hD=aX+1|0;S=2863;break}else{c[J>>2]=24;gn=2;go=aQ;gp=aR;gq=aS;gr=aT;gs=aU;gt=aV;gu=aW;gv=aX;S=2961;continue L3731}}else if((S|0)==2759){S=0;ea=fu<<fq|fv;I=fq+8|0;d9=a[51624+fs|0]|0;if(I>>>0<d9<<24>>24>>>0){hE=I;hF=fr;hG=fs;hH=ft;hI=ea;hJ=fw;hK=fx;hL=fy;S=2753}else{hM=I;hN=fr;hO=fs;hP=ft;hQ=ea;hR=fw;hS=fx;hT=fy;hU=d9;S=2760}}else if((S|0)==2935){S=0;if((l&2|0)==0){a4=0;a5=aY;a6=aZ;a7=a_;a8=a$;a9=a0;ba=a1;bb=a2;bc=a3;S=2940;continue L3731}c[J>>2]=32;gn=1;go=aY;gp=aZ;gq=a_;gr=a$;gs=a0;gt=a1;gu=a2;gv=a3;S=2961;continue L3731}else if((S|0)==2940){S=0;d9=a4<<a5|a9;ea=a5+8|0;if(ea>>>0<(ea&7)>>>0){hV=ea;hW=a6;hX=a7;hY=a8;hZ=d9;h_=ba;h$=bb;h0=bc;S=2934}else{h1=ea;h2=a6;h3=a8;h4=d9;h5=ba;h6=bb;h7=bc;S=2941}}else if((S|0)==2946){S=0;if((l&2|0)==0){bl=0;bm=bd;bn=be;bo=bf;bp=bg;bq=bh;br=bi;bs=bj;bt=bk;S=2951;continue L3731}c[J>>2]=41;gn=1;go=bd;gp=be;gq=bf;gr=bg;gs=bh;gt=bi;gu=bj;gv=bk;S=2961;continue L3731}else if((S|0)==2951){S=0;d9=bl<<bm|bq;ea=bm+8|0;if(bm>>>0>4294967287){h8=ea;h9=bn;ia=bo;ib=bp;ic=d9;id=br;ie=bs;ig=bt;S=2945}else{ih=ea;ii=bn;ij=bo;ik=bp;il=d9;im=br;io=bs;ip=bt;S=2952}}else if((S|0)==2954){S=0;if((l&2|0)==0){bC=0;bD=bu;bE=bv;bF=bw;bG=bx;bH=by;bI=bz;bJ=bA;bK=bB;S=2959;continue L3731}c[J>>2]=42;gn=1;go=bu;gp=bv;gq=bw;gr=bx;gs=by;gt=bz;gu=bA;gv=bB;S=2961;continue L3731}else if((S|0)==2959){S=0;d9=e+16|0;c[d9>>2]=c[d9>>2]<<8|bC;iq=bD;ir=bE;is=bF+1|0;it=bG;iu=bH;iv=bI;iw=bJ;ix=bK;S=2942}else if((S|0)==2960){S=0;c[J>>2]=34;gn=0;go=bL;gp=bM;gq=bN;gr=bO;gs=bP;gt=bQ;gu=bR;gv=bS;S=2961;continue L3731}else if((S|0)==2961){S=0;c[w>>2]=go;c[y>>2]=gs;c[A>>2]=gp;c[D>>2]=gq;c[F>>2]=gr;c[H>>2]=gt;c[g>>2]=gu-f;iy=gv-j|0;c[k>>2]=iy;if((l&9|0)!=0&(gn|0)>-1){break L3731}else{v=gn;S=2977;break L3731}}else if((S|0)==2743){S=0;if(b_>>>0<s>>>0){b$=bT;b0=bU;b1=bV;b2=bW;b3=bX;b4=bY;b5=bZ;b6=b_;S=2745;continue L3731}c[J>>2]=9;gn=2;go=bT;gp=bU;gq=bV;gr=bW;gs=bX;gt=bY;gu=bZ;gv=b_;S=2961;continue L3731}else if((S|0)==2745){S=0;if(b5>>>0<q>>>0){d9=s-b6|0;ea=q-b5|0;I=d9>>>0<ea>>>0?d9:ea;ea=I>>>0<b1>>>0?I:b1;yE(b6|0,b5|0,ea)|0;iz=b$;iA=b0;iB=b1-ea|0;iC=b2;iD=b3;iE=b4;iF=b5+ea|0;iG=b6+ea|0;S=2742;break}if((l&2|0)==0){b7=b$;b8=b0;b9=b1;ca=b2;cb=b3;cc=b4;cd=b5;ce=b6;S=2748;continue L3731}c[J>>2]=38;gn=1;go=b$;gp=b0;gq=b1;gr=b2;gs=b3;gt=b4;gu=b5;gv=b6;S=2961;continue L3731}else if((S|0)==2748){S=0;c[J>>2]=40;gn=-1;go=b7;gp=b8;gq=b9;gr=ca;gs=cb;gt=cc;gu=cd;gv=ce;S=2961;continue L3731}else if((S|0)==2701){S=0;if((l&2|0)==0){cn=cf;co=cg;cp=ch;cq=ci;cr=cj;cs=0;ct=ck;cu=cl;cv=cm;S=2706;continue L3731}c[J>>2]=5;gn=1;go=cf;gp=cg;gq=ch;gr=ci;gs=cj;gt=ck;gu=cl;gv=cm;S=2961;continue L3731}else if((S|0)==2883){S=0;if((l&2|0)==0){cV=0;cW=cN;cX=cO;cY=cP;cZ=cQ;c_=cR;c$=cS;c0=cT;c1=cU;S=2888;continue L3731}c[J>>2]=25;gn=1;go=cN;gp=cO;gq=cP;gr=cQ;gs=cR;gt=cS;gu=cT;gv=cU;S=2961;continue L3731}else if((S|0)==2888){S=0;ea=cV<<cW|c_;I=cW+8|0;if(I>>>0<cZ>>>0){iH=I;iI=cX;iJ=cY;iK=cZ;iL=ea;iM=c$;iN=c0;iO=c1;S=2882}else{iP=I;iQ=cX;iR=cY;iS=cZ;iT=ea;iU=c$;iV=c0;iW=c1;S=2889}}else if((S|0)==2732){S=0;if((l&2|0)==0){da=c2;db=c3;dc=c4;dd=c5;de=c6;df=0;dg=c7;dh=c8;di=c9;S=2737;continue L3731}c[J>>2]=51;gn=1;go=c2;gp=c3;gq=c4;gr=c5;gs=c6;gt=c7;gu=c8;gv=c9;S=2961;continue L3731}else if((S|0)==2739){S=0;if(dr>>>0<s>>>0){a[dr]=dk&255;iX=dj;iY=dk;iZ=dl-1|0;i_=dm;i$=dn;i0=dp;i1=dq;i2=dr+1|0;S=2729;break}else{c[J>>2]=52;gn=2;go=dj;gp=dk;gq=dl;gr=dm;gs=dn;gt=dp;gu=dq;gv=dr;S=2961;continue L3731}}else if((S|0)==2697){S=0;ea=cJ<<cE|cI;I=cE+8|0;if(I>>>0<3){gO=I;gP=cF;gQ=cG;gR=cH;gS=ea;gT=cK;gU=cL;gV=cM;S=2691}else{gW=I;gX=cF;gY=cG;gZ=cH;g_=ea;g$=cK;g0=cL;g1=cM;S=2698}}else if((S|0)==2912){S=0;if((l&2|0)==0){dA=0;dB=ds;dC=dt;dD=du;dE=dv;dF=dw;dG=dx;dH=dy;dI=dz;S=2917;continue L3731}c[J>>2]=27;gn=1;go=ds;gp=dt;gq=du;gr=dv;gs=dw;gt=dx;gu=dy;gv=dz;S=2961;continue L3731}else if((S|0)==2917){S=0;ea=dA<<dB|dF;I=dB+8|0;if(I>>>0<dE>>>0){i3=I;i4=dC;i5=dD;i6=dE;i7=ea;i8=dG;i9=dH;ja=dI;S=2911}else{jb=I;jc=dC;jd=dD;je=dE;jf=ea;jg=dH;jh=dI;S=2918}}else if((S|0)==2920){S=0;c[J>>2]=37;gn=-1;go=dJ;gp=dK;gq=dL;gr=dM;gs=dN;gt=dO;gu=dP;gv=dQ;S=2961;continue L3731}else if((S|0)==2923){S=0;if(dY>>>0<s>>>0){a[dY]=a[h+(dW-dS&u)|0]|0;ji=dR;jj=dS;jk=dT;jl=dU;jm=dV;jn=dW+1|0;jo=dX;jp=dY+1|0;S=2922;break}else{c[J>>2]=53;gn=2;go=dR;gp=dS;gq=dT;gr=dU;gs=dV;gt=dW;gu=dX;gv=dY;S=2961;continue L3731}}else if((S|0)==2780){S=0;c[J>>2]=35;gn=-1;go=dZ;gp=d_;gq=d$;gr=d0;gs=d1;gt=d2;gu=d3;gv=d4;S=2961;continue L3731}else if((S|0)==2726){S=0;jq=eV;jr=eW;js=eX+1|0;jt=eY;ju=eZ;jv=e_;jw=e$;jx=e0;S=2708}else if((S|0)==2728){S=0;c[J>>2]=39;gn=-1;go=eb;gp=ec;gq=ed;gr=ee;gs=ef;gt=eg;gu=eh;gv=ei;S=2961;continue L3731}else if((S|0)==2810){S=0;if((l&2|0)==0){eE=0;eF=ew;eG=ex;eH=ey;eI=ez;eJ=eA;eK=eB;eL=eC;eM=eD;S=2815;continue L3731}c[J>>2]=16;gn=1;go=ew;gp=ex;gq=ey;gr=ez;gs=eA;gt=eB;gu=eC;gv=eD;S=2961;continue L3731}else if((S|0)==2815){S=0;ea=eE<<eF|eJ;I=eF+8|0;if(I>>>0<15){jy=I;jz=eG;jA=eH;jB=eI;jC=ea;jD=eK;jE=eL;jF=eM;S=2803}else{jG=I;jH=eH;jI=eI;jJ=ea;jK=eK;jL=eL;jM=eM;S=2817}}else if((S|0)==2849){S=0;if((l&2|0)==0){e9=0;fa=e1;fb=e2;fc=e3;fd=e4;fe=e5;ff=e6;fg=e7;fh=e8;S=2854;continue L3731}c[J>>2]=23;gn=1;go=e1;gp=e2;gq=e3;gr=e4;gs=e5;gt=e6;gu=e7;gv=e8;S=2961;continue L3731}else if((S|0)==2854){S=0;ea=e9<<fa|fe;I=fa+8|0;if(I>>>0<15){jN=I;jO=fb;jP=fc;jQ=fd;jR=ea;jS=ff;jT=fg;jU=fh;S=2842}else{jV=I;jW=fb;jX=fd;jY=ea;jZ=ff;j_=fg;j$=fh;S=2856}}else if((S|0)==2754){S=0;if((l&2|0)==0){fq=fi;fr=fj;fs=fk;ft=fl;fu=0;fv=fm;fw=fn;fx=fo;fy=fp;S=2759;continue L3731}c[J>>2]=11;gn=1;go=fi;gp=fj;gq=fk;gr=fl;gs=fm;gt=fn;gu=fo;gv=fp;S=2961;continue L3731}else if((S|0)==2750){S=0;c[J>>2]=10;gn=-1;go=fz;gp=fA;gq=fB;gr=fC;gs=fD;gt=fE;gu=fF;gv=fG;S=2961;continue L3731}else if((S|0)==2737){S=0;ea=df<<da|de;I=da+8|0;if(da>>>0>4294967287){j0=I;j1=db;j2=dc;j3=dd;j4=ea;j5=dg;j6=dh;j7=di;S=2731}else{j8=I;j9=dc;ka=dd;kb=ea;kc=dg;kd=dh;ke=di;S=2738}}else if((S|0)==2831){S=0;ea=$<<aa|ae;I=aa+8|0;if(I>>>0<ad>>>0){kf=I;kg=ab;kh=ac;ki=ad;kj=ea;kk=af;kl=ag;km=ah;S=2825}else{kn=I;ko=ab;kp=ac;kq=ad;kr=ea;ks=af;kt=ag;ku=ah;S=2832}}else if((S|0)==2836){S=0;c[J>>2]=21;gn=-1;go=fH;gp=fI;gq=fJ;gr=fK;gs=fL;gt=fM;gu=fN;gv=fO;S=2961;continue L3731}else if((S|0)==2717){S=0;ea=gb<<f6|ga;I=f6+8|0;if(f6>>>0>4294967287){kv=I;kw=f7;kx=f8;ky=f9;kz=ea;kA=gc;kB=gd;kC=ge;S=2711}else{kD=I;kE=f7;kF=f8;kG=f9;kH=ea;kI=gc;kJ=gd;kK=ge;S=2718}}else if((S|0)==2720){S=0;if((l&2|0)==0){a[e+10528+eP|0]=0;eV=eN;eW=eO;eX=eP;eY=eQ;eZ=eR;e_=eS;e$=eT;e0=eU;S=2726;continue L3731}else{c[J>>2]=7;gn=1;go=eN;gp=eO;gq=eP;gr=eQ;gs=eR;gt=eS;gu=eT;gv=eU;S=2961;continue L3731}}else if((S|0)==2712){S=0;if((l&2|0)==0){f6=f_;f7=f$;f8=f0;f9=f1;ga=f2;gb=0;gc=f3;gd=f4;ge=f5;S=2717;continue L3731}c[J>>2]=6;gn=1;go=f_;gp=f$;gq=f0;gr=f1;gs=f2;gt=f3;gu=f4;gv=f5;S=2961;continue L3731}}while(0);if((S|0)==2691){S=0;if(gU>>>0>=q>>>0){cw=gO;cx=gP;cy=gQ;cz=gR;cA=gS;cB=gT;cC=gU;cD=gV;S=2692;continue}cE=gO;cF=gP;cG=gQ;cH=gR;cI=gS;cJ=d[gU]|0;cK=gT;cL=gU+1|0;cM=gV;S=2697;continue}do{if((S|0)==2698){S=0;ea=g_&7;c[e+20>>2]=ea;I=g_>>>3;d9=gW-3|0;d8=ea>>>1;ea=e+24|0;c[ea>>2]=d8;if((d8|0)==1){c[e+44>>2]=288;c[e+48>>2]=32;yB(e+3552|0,5,32);yB(e+64|0,8,144);yB(e+208|0,9,112);yB(e+320|0,7,24);d7=e+344|0;d6=d7|0;C=134744072;a[d6]=C&255;C=C>>8;a[d6+1|0]=C&255;C=C>>8;a[d6+2|0]=C&255;C=C>>8;a[d6+3|0]=C&255;d6=d7+4|0;C=134744072;a[d6]=C&255;C=C>>8;a[d6+1|0]=C&255;C=C>>8;a[d6+2|0]=C&255;C=C>>8;a[d6+3|0]=C&255;kL=d9;kM=gX;kN=gY;kO=gZ;kP=I;kQ=g$;kR=g0;kS=g1;kT=ea;kU=1;S=2774;break}else if((d8|0)==0){if(d9>>>0<(d9&7)>>>0){gz=d9;gA=gX;gB=gY;gC=gZ;gD=I;gE=g$;gF=g0;gG=g1;S=2700;break}else{gH=d9;gI=gX;gJ=gZ;gK=I;gL=g$;gM=g0;gN=g1;S=2707;break}}else if((d8|0)==3){fz=d9;fA=gX;fB=gY;fC=gZ;fD=I;fE=g$;fF=g0;fG=g1;S=2750;continue L3731}else{kV=d9;kW=gX;kX=0;kY=gZ;kZ=I;k_=g$;k$=g0;k0=g1;S=2751;break}}}while(0);if((S|0)==2707){S=0;I=gH&7;jq=gH-I|0;jr=gI;js=0;jt=gJ;ju=gK>>>(I>>>0);jv=gL;jw=gM;jx=gN;S=2708}else if((S|0)==2700){S=0;if(gF>>>0>=q>>>0){cf=gz;cg=gA;ch=gB;ci=gC;cj=gD;ck=gE;cl=gF;cm=gG;S=2701;continue}cn=gz;co=gA;cp=gB;cq=gC;cr=gD;cs=d[gF]|0;ct=gE;cu=gF+1|0;cv=gG;S=2706;continue}do{if((S|0)==2708){S=0;if(js>>>0>=4){I=d[e+10529|0]<<8|d[e+10528|0];if((I|0)==((d[e+10531|0]<<8|d[e+10530|0])^65535|0)){iX=jq;iY=jr;iZ=I;i_=jt;i$=ju;i0=jv;i1=jw;i2=jx;S=2729;break}else{eb=jq;ec=jr;ed=I;ee=jt;ef=ju;eg=jv;eh=jw;ei=jx;S=2728;continue L3731}}if((jq|0)!=0){if(jq>>>0<8){kv=jq;kw=jr;kx=js;ky=jt;kz=ju;kA=jv;kB=jw;kC=jx;S=2711;break}else{kD=jq;kE=jr;kF=js;kG=jt;kH=ju;kI=jv;kJ=jw;kK=jx;S=2718;break}}if(jw>>>0>=q>>>0){eN=0;eO=jr;eP=js;eQ=jt;eR=ju;eS=jv;eT=jw;eU=jx;S=2720;continue L3731}a[e+10528+js|0]=a[jw]|0;eV=0;eW=jr;eX=js;eY=jt;eZ=ju;e_=jv;e$=jw+1|0;e0=jx;S=2726;continue L3731}}while(0);do{if((S|0)==2711){S=0;if(kB>>>0>=q>>>0){f_=kv;f$=kw;f0=kx;f1=ky;f2=kz;f3=kA;f4=kB;f5=kC;S=2712;continue L3731}f6=kv;f7=kw;f8=kx;f9=ky;ga=kz;gb=d[kB]|0;gc=kA;gd=kB+1|0;ge=kC;S=2717;continue L3731}else if((S|0)==2718){S=0;a[e+10528+kF|0]=kH&255;eV=kD-8|0;eW=kE;eX=kF;eY=kG;eZ=kH>>>8;e_=kI;e$=kJ;e0=kK;S=2726;continue L3731}else if((S|0)==2729){S=0;if((iZ|0)==0|(iX|0)==0){iz=iX;iA=iY;iB=iZ;iC=i_;iD=i$;iE=i0;iF=i1;iG=i2;S=2742;break}if(iX>>>0<8){j0=iX;j1=iY;j2=iZ;j3=i_;j4=i$;j5=i0;j6=i1;j7=i2;S=2731}else{j8=iX;j9=iZ;ka=i_;kb=i$;kc=i0;kd=i1;ke=i2;S=2738}}}while(0);if((S|0)==2731){S=0;if(j6>>>0>=q>>>0){c2=j0;c3=j1;c4=j2;c5=j3;c6=j4;c7=j5;c8=j6;c9=j7;S=2732;continue}da=j0;db=j1;dc=j2;dd=j3;de=j4;df=d[j6]|0;dg=j5;dh=j6+1|0;di=j7;S=2737;continue}else if((S|0)==2742){S=0;if((iB|0)==0){k1=iz;k2=iA;k3=0;k4=iC;k5=iD;k6=iE;k7=iF;k8=iG;S=2931}else{bT=iz;bU=iA;bV=iB;bW=iC;bX=iD;bY=iE;bZ=iF;b_=iG;S=2743;continue}}else if((S|0)==2738){S=0;dj=j8-8|0;dk=kb&255;dl=j9;dm=ka;dn=kb>>>8;dp=kc;dq=kd;dr=ke;S=2739;continue}L3844:while(1){L3845:do{if((S|0)==2803){S=0;I=b[e+7328+((jC&1023)<<1)>>1]|0;d9=I<<16>>16;if(I<<16>>16>-1){I=d9>>9;if((I|0)==0|jy>>>0<I>>>0){S=2809;break L3844}else{jG=jy;jH=jA;jI=jB;jJ=jC;jK=jD;jL=jE;jM=jF;S=2817;continue L3844}}if(jy>>>0>10){k9=10;la=d9}else{S=2809;break L3844}while(1){lb=b[e+9376+((jC>>>(k9>>>0)&1)+~la<<1)>>1]|0;if(lb<<16>>16>=0){jG=jy;jH=jA;jI=jB;jJ=jC;jK=jD;jL=jE;jM=jF;S=2817;continue L3844}if(jy>>>0<(k9+2|0)>>>0){break}else{k9=k9+1|0;la=lb<<16>>16}}if(lb<<16>>16>-1){jG=jy;jH=jA;jI=jB;jJ=jC;jK=jD;jL=jE;jM=jF;S=2817;continue L3844}else{S=2809;break L3844}}else if((S|0)==2825){S=0;if(kl>>>0<q>>>0){S=2830;break L3844}else{T=kf;U=kg;V=kh;W=ki;X=kj;Y=kk;Z=kl;_=km;S=2826;continue L3731}}else if((S|0)==2764){S=0;if(g8>>>0<q>>>0){S=2769;break L3844}else{ai=g2;aj=g3;ak=g4;al=g5;am=g6;an=g7;ao=g8;ap=g9;S=2765;continue L3731}}else if((S|0)==2889){S=0;lc=iP-iS|0;ld=iQ;le=((1<<iS)-1&iT)+iR|0;lf=iS;lg=iT>>>(iS>>>0);lh=iU;li=iV;lj=iW}else if((S|0)==2892){S=0;d9=b[e+3840+((hm&1023)<<1)>>1]|0;I=d9<<16>>16;if(d9<<16>>16>-1){d9=I>>9;if((d9|0)==0|hi>>>0<d9>>>0){S=2898;break L3844}else{hq=hi;hr=hk;hs=hm;ht=hn;hu=ho;hv=hp;S=2906;continue L3844}}if(hi>>>0>10){lk=10;ll=I}else{S=2898;break L3844}while(1){lm=b[e+5888+((hm>>>(lk>>>0)&1)+~ll<<1)>>1]|0;if(lm<<16>>16>=0){hq=hi;hr=hk;hs=hm;ht=hn;hu=ho;hv=hp;S=2906;continue L3844}if(hi>>>0<(lk+2|0)>>>0){break}else{lk=lk+1|0;ll=lm<<16>>16}}if(lm<<16>>16>-1){hq=hi;hr=hk;hs=hm;ht=hn;hu=ho;hv=hp;S=2906;continue L3844}else{S=2898;break L3844}}else if((S|0)==2863){S=0;I=q;d9=I-hC|0;L3866:do{if((d9|0)<4){ln=hD;lo=hC;lp=hA;lq=hy;lr=hw;ls=d9}else{d8=s;ea=hD;d6=hC;d7=hA;d5=hy;eu=hw;et=d9;while(1){if((d8-ea|0)<2){ln=ea;lo=d6;lp=d7;lq=d5;lr=eu;ls=et;break L3866}if(eu>>>0<15){lt=eu+16|0;lu=(d[d6+1|0]<<8|d[d6])<<eu|d7;lv=d6+2|0}else{lt=eu;lu=d7;lv=d6}es=b[e+352+((lu&1023)<<1)>>1]|0;gx=es<<16>>16;if(es<<16>>16>-1){lw=gx>>9;lx=gx}else{es=10;er=gx;while(1){gx=es+1|0;eq=b[e+2400+((lu>>>(es>>>0)&1)+~er<<1)>>1]|0;gw=eq<<16>>16;if(eq<<16>>16<0){es=gx;er=gw}else{lw=gx;lx=gw;break}}}er=lu>>>(lw>>>0);es=lt-lw|0;if((lx&256|0)!=0){ly=es;lz=hx;lA=lx;lB=hz;lC=er;lD=hB;lE=lv;lF=ea;S=2879;break L3845}if(es>>>0<15){lG=es+16|0;lH=(d[lv+1|0]<<8|d[lv])<<es|er;lI=lv+2|0}else{lG=es;lH=er;lI=lv}er=b[e+352+((lH&1023)<<1)>>1]|0;es=er<<16>>16;if(er<<16>>16>-1){lJ=es>>9;lK=es}else{er=10;gw=es;while(1){es=er+1|0;gx=b[e+2400+((lH>>>(er>>>0)&1)+~gw<<1)>>1]|0;eq=gx<<16>>16;if(gx<<16>>16<0){er=es;gw=eq}else{lJ=es;lK=eq;break}}}lL=lH>>>(lJ>>>0);lM=lG-lJ|0;a[ea]=lx&255;if((lK&256|0)!=0){break}a[ea+1|0]=lK&255;gw=ea+2|0;er=I-lI|0;if((er|0)<4){ln=gw;lo=lI;lp=lL;lq=lx;lr=lM;ls=er;break L3866}else{ea=gw;d6=lI;d7=lL;d5=lx;eu=lM;et=er}}ly=lM;lz=hx;lA=lK;lB=hz;lC=lL;lD=hB;lE=lI;lF=ea+1|0;S=2879;break L3845}}while(0);if(lr>>>0>=15){jV=lr;jW=hx;jX=hz;jY=lp;jZ=hB;j_=lo;j$=ln;S=2856;continue L3844}if((ls|0)<2){jN=lr;jO=hx;jP=lq;jQ=hz;jR=lp;jS=hB;jT=lo;jU=ln;S=2842;continue L3844}jV=lr+16|0;jW=hx;jX=hz;jY=d[lo]<<lr|lp|d[lo+1|0]<<lr+8;jZ=hB;j_=lo+2|0;j$=ln;S=2856;continue L3844}else if((S|0)==2760){S=0;I=hU<<24>>24;c[e+44+(hO<<2)>>2]=(c[256+(hO<<2)>>2]|0)+(hQ&(1<<I)-1);kV=hM-I|0;kW=hN;kX=hO+1|0;kY=hP;kZ=hQ>>>(I>>>0);k_=hR;k$=hS;k0=hT;S=2751;continue L3844}else if((S|0)==2931){S=0;if((c[e+20>>2]&1|0)==0){gf=k1;gg=k2;gh=k3;gi=k4;gj=k5;gk=k6;gl=k7;gm=k8;S=2690;continue L3731}if((l&1|0)==0){bL=k1;bM=k2;bN=k3;bO=k4;bP=k5;bQ=k6;bR=k7;bS=k8;S=2960;continue L3731}if(k1>>>0<(k1&7)>>>0){hV=k1;hW=k2;hX=k3;hY=k4;hZ=k5;h_=k6;h$=k7;h0=k8;S=2934;continue L3844}else{h1=k1;h2=k2;h3=k4;h4=k5;h5=k6;h6=k7;h7=k8;S=2941;continue L3844}}else if((S|0)==2934){S=0;if(h$>>>0<q>>>0){S=2939;break L3844}else{aY=hV;aZ=hW;a_=hX;a$=hY;a0=hZ;a1=h_;a2=h$;a3=h0;S=2935;continue L3731}}else if((S|0)==2941){S=0;I=h1&7;iq=h1-I|0;ir=h2;is=0;it=h3;iu=h4>>>(I>>>0);iv=h5;iw=h6;ix=h7;S=2942;continue L3844}else if((S|0)==2942){S=0;if(is>>>0>=4){bL=iq;bM=ir;bN=is;bO=it;bP=iu;bQ=iv;bR=iw;bS=ix;S=2960;continue L3731}if((iq|0)==0){S=2953;break L3844}if(iq>>>0<8){h8=iq;h9=ir;ia=is;ib=it;ic=iu;id=iv;ie=iw;ig=ix;S=2945;continue L3844}else{ih=iq;ii=ir;ij=is;ik=it;il=iu;im=iv;io=iw;ip=ix;S=2952;continue L3844}}else if((S|0)==2945){S=0;if(ie>>>0<q>>>0){S=2950;break L3844}else{bd=h8;be=h9;bf=ia;bg=ib;bh=ic;bi=id;bj=ie;bk=ig;S=2946;continue L3731}}else if((S|0)==2952){S=0;bC=il&255;bD=ih-8|0;bE=ii;bF=ij;bG=ik;bH=il>>>8;bI=im;bJ=io;bK=ip;S=2959;continue L3731}else if((S|0)==2771){S=0;a[(d[400+hc|0]|0)+(e+7040)|0]=he&7;lN=ha-3|0;lO=hb;lP=hc+1|0;lQ=hd;lR=he>>>3;lS=hf;lT=hg;lU=hh;S=2762}else if((S|0)==2774){S=0;if((kU|0)<=-1){hw=kL;hx=kM;hy=kN;hz=kO;hA=kP;hB=kQ;hC=kR;hD=kS;S=2863;continue L3844}yB(o|0,0,64);yB(e+64+(kU*3488|0)+288|0,0,3200);I=c[kT>>2]|0;d9=c[e+44+(I<<2)>>2]|0;if((d9|0)==0){lV=0;lW=0;lX=0;lY=0;lZ=0;l_=0;l$=0;l0=0;l1=0;l2=0;l3=0;l4=0;l5=0;l6=0;l7=0;l8=0}else{et=0;do{eu=o+(d[e+64+(kU*3488|0)+et|0]<<2)|0;c[eu>>2]=(c[eu>>2]|0)+1;et=et+1|0;}while(et>>>0<d9>>>0);lV=c[o+4>>2]|0;lW=c[o+8>>2]|0;lX=c[o+12>>2]|0;lY=c[o+16>>2]|0;lZ=c[o+20>>2]|0;l_=c[o+24>>2]|0;l$=c[o+28>>2]|0;l0=c[o+32>>2]|0;l1=c[o+36>>2]|0;l2=c[o+40>>2]|0;l3=c[o+44>>2]|0;l4=c[o+48>>2]|0;l5=c[o+52>>2]|0;l6=c[o+56>>2]|0;l7=c[o+60>>2]|0;l8=d9}c[n+4>>2]=0;c[n>>2]=0;et=lV<<1;c[n+8>>2]=et;eu=et+lW<<1;c[n+12>>2]=eu;et=eu+lX<<1;c[n+16>>2]=et;eu=et+lY<<1;c[n+20>>2]=eu;et=eu+lZ<<1;c[n+24>>2]=et;eu=et+l_<<1;c[n+28>>2]=eu;et=eu+l$<<1;c[n+32>>2]=et;eu=et+l0<<1;c[n+36>>2]=eu;et=eu+l1<<1;c[n+40>>2]=et;eu=et+l2<<1;c[n+44>>2]=eu;et=eu+l3<<1;c[n+48>>2]=et;eu=et+l4<<1;c[n+52>>2]=eu;et=eu+l5<<1;c[n+56>>2]=et;eu=et+l6<<1;c[n+60>>2]=eu;et=eu+l7<<1;c[n+64>>2]=et;if((et|0)!=65536&(l6+l7+l5+l4+l3+l2+l1+l0+l$+l_+lZ+lY+lX+lW+lV|0)>>>0>1){dZ=kL;d_=kM;d$=kN;d0=kO;d1=kP;d2=kQ;d3=kR;d4=kS;S=2780;continue L3731}if((l8|0)==0){l9=I}else{et=-1;eu=0;while(1){d5=a[e+64+(kU*3488|0)+eu|0]|0;d7=d5&255;L3916:do{if(d5<<24>>24==0){ma=et}else{d6=n+(d7<<2)|0;d8=c[d6>>2]|0;c[d6>>2]=d8+1;d6=0;er=d7;gw=d8;while(1){mb=d6<<1|gw&1;d8=er-1|0;if((d8|0)==0){break}else{d6=mb;er=d8;gw=gw>>>1}}if((d5&255)<11){gw=(d7<<9|eu)&65535;if(mb>>>0>=1024){ma=et;break}er=1<<d7;d8=mb;while(1){b[e+64+(kU*3488|0)+288+(d8<<1)>>1]=gw;eq=d8+er|0;if(eq>>>0<1024){d8=eq}else{ma=et;break L3916}}}d8=e+64+(kU*3488|0)+288+((mb&1023)<<1)|0;er=b[d8>>1]|0;if(er<<16>>16==0){b[d8>>1]=et&65535;mc=et;md=et-2|0}else{mc=er<<16>>16;md=et}er=d6>>>9;d8=mc-(er&1)|0;if((d5&255)>11){gw=md;eq=d7;es=er&4194303;er=d8;while(1){gx=e+64+(kU*3488|0)+2336+(~er<<1)|0;gy=b[gx>>1]|0;if(gy<<16>>16==0){b[gx>>1]=gw&65535;me=gw;mf=gw-2|0}else{me=gy<<16>>16;mf=gw}gy=eq-1|0;gx=es>>>1;ev=me-(gx&1)|0;if(gy>>>0>11){gw=mf;eq=gy;es=gx;er=ev}else{mg=mf;mh=ev;break}}}else{mg=md;mh=d8}b[e+64+(kU*3488|0)+2336+(~mh<<1)>>1]=eu&65535;ma=mg}}while(0);d7=eu+1|0;d5=c[kT>>2]|0;if(d7>>>0<(c[e+44+(d5<<2)>>2]|0)>>>0){et=ma;eu=d7}else{l9=d5;break}}}if((l9|0)==2){mi=kL;mj=kM;mk=0;ml=kO;mm=kP;mn=kQ;mo=kR;mp=kS;S=2800;break}mq=kL;mr=kM;ms=kN;mt=kO;mu=kP;mv=kQ;mw=kR;mx=kS;my=l9;mz=e+24|0;S=2838}else if((S|0)==2882){S=0;if(iN>>>0<q>>>0){S=2887;break L3844}else{cN=iH;cO=iI;cP=iJ;cQ=iK;cR=iL;cS=iM;cT=iN;cU=iO;S=2883;continue L3731}}else if((S|0)==2906){S=0;eu=b[e+3840+((hs&1023)<<1)>>1]|0;et=eu<<16>>16;if(eu<<16>>16>-1){mA=et>>9;mB=et&511}else{eu=10;I=et;while(1){et=eu+1|0;d9=b[e+5888+((hs>>>(eu>>>0)&1)+~I<<1)>>1]|0;d5=d9<<16>>16;if(d9<<16>>16<0){eu=et;I=d5}else{mA=et;mB=d5;break}}}I=hs>>>(mA>>>0);eu=hq-mA|0;d5=c[552+(mB<<2)>>2]|0;et=c[680+(mB<<2)>>2]|0;if((mB-4|0)>>>0>=26){mC=eu;mD=et;mE=hr;mF=d5;mG=I;mH=hu;mI=hv;S=2919;break}if(eu>>>0<d5>>>0){i3=eu;i4=et;i5=hr;i6=d5;i7=I;i8=ht;i9=hu;ja=hv;S=2911;continue L3844}else{jb=eu;jc=et;jd=hr;je=d5;jf=I;jg=hu;jh=hv;S=2918;continue L3844}}else if((S|0)==2911){S=0;if(i9>>>0<q>>>0){S=2916;break L3844}else{ds=i3;dt=i4;du=i5;dv=i6;dw=i7;dx=i8;dy=i9;dz=ja;S=2912;continue L3731}}else if((S|0)==2918){S=0;mC=jb-je|0;mD=((1<<je)-1&jf)+jc|0;mE=jd;mF=je;mG=jf>>>(je>>>0);mH=jg;mI=jh;S=2919}else if((S|0)==2922){S=0;I=jk-1|0;if((jk|0)==0){hw=ji;hx=jj;hy=I;hz=jl;hA=jm;hB=jn;hC=jo;hD=jp;S=2863;continue L3844}else{dR=ji;dS=jj;dT=I;dU=jl;dV=jm;dW=jn;dX=jo;dY=jp;S=2923;continue L3731}}else if((S|0)==2817){S=0;I=b[e+7328+((jJ&1023)<<1)>>1]|0;d5=I<<16>>16;if(I<<16>>16>-1){mJ=d5>>9;mK=d5&511}else{I=10;et=d5;while(1){d5=I+1|0;eu=b[e+9376+((jJ>>>(I>>>0)&1)+~et<<1)>>1]|0;d9=eu<<16>>16;if(eu<<16>>16<0){I=d5;et=d9}else{mJ=d5;mK=d9;break}}}et=jJ>>>(mJ>>>0);I=jG-mJ|0;if(mK>>>0<16){a[e+10532+jH|0]=mK&255;mi=I;mj=mK;mk=jH+1|0;ml=jI;mm=et;mn=jK;mo=jL;mp=jM;S=2800;break}if((mK|0)==16&(jH|0)==0){K=I;L=16;M=0;N=jI;O=et;P=jK;Q=jL;R=jM;S=2823;continue L3731}d9=a[49192+(mK-16)|0]|0;if(I>>>0<d9>>>0){kf=I;kg=mK;kh=jH;ki=d9;kj=et;kk=jK;kl=jL;km=jM;S=2825;continue L3844}else{kn=I;ko=mK;kp=jH;kq=d9;kr=et;ks=jK;kt=jL;ku=jM;S=2832;continue L3844}}else if((S|0)==2842){S=0;et=b[e+352+((jR&1023)<<1)>>1]|0;d9=et<<16>>16;if(et<<16>>16>-1){et=d9>>9;if((et|0)==0|jN>>>0<et>>>0){S=2848;break L3844}else{jV=jN;jW=jO;jX=jQ;jY=jR;jZ=jS;j_=jT;j$=jU;S=2856;continue L3844}}if(jN>>>0>10){mL=10;mM=d9}else{S=2848;break L3844}while(1){mN=b[e+2400+((jR>>>(mL>>>0)&1)+~mM<<1)>>1]|0;if(mN<<16>>16>=0){jV=jN;jW=jO;jX=jQ;jY=jR;jZ=jS;j_=jT;j$=jU;S=2856;continue L3844}if(jN>>>0<(mL+2|0)>>>0){break}else{mL=mL+1|0;mM=mN<<16>>16}}if(mN<<16>>16>-1){jV=jN;jW=jO;jX=jQ;jY=jR;jZ=jS;j_=jT;j$=jU;S=2856;continue L3844}else{S=2848;break L3844}}else if((S|0)==2856){S=0;d9=b[e+352+((jY&1023)<<1)>>1]|0;et=d9<<16>>16;if(d9<<16>>16>-1){mO=et>>9;mP=et&511}else{d9=10;I=et;while(1){et=d9+1|0;d5=b[e+2400+((jY>>>(d9>>>0)&1)+~I<<1)>>1]|0;eu=d5<<16>>16;if(d5<<16>>16<0){d9=et;I=eu}else{mO=et;mP=eu;break}}}I=jY>>>(mO>>>0);d9=jV-mO|0;if(mP>>>0>255){ly=d9;lz=jW;lA=mP;lB=jX;lC=I;lD=jZ;lE=j_;lF=j$;S=2879}else{aQ=d9;aR=jW;aS=mP;aT=jX;aU=I;aV=jZ;aW=j_;aX=j$;S=2860;continue L3731}}else if((S|0)==2751){S=0;if(kX>>>0<3){I=a[51624+kX|0]|0;if(kV>>>0<I<<24>>24>>>0){hE=kV;hF=kW;hG=kX;hH=kY;hI=kZ;hJ=k_;hK=k$;hL=k0;S=2753;continue L3844}else{hM=kV;hN=kW;hO=kX;hP=kY;hQ=kZ;hR=k_;hS=k$;hT=k0;hU=I;S=2760;continue L3844}}else{yB(e+7040|0,0,288);lN=kV;lO=kW;lP=0;lQ=kY;lR=kZ;lS=k_;lT=k$;lU=k0;S=2762;break}}else if((S|0)==2753){S=0;if(hK>>>0<q>>>0){S=2758;break L3844}else{fi=hE;fj=hF;fk=hG;fl=hH;fm=hI;fn=hJ;fo=hK;fp=hL;S=2754;continue L3731}}else if((S|0)==2832){S=0;I=(a[47560+(ko-16)|0]|0)+((1<<kq)-1&kr)|0;if((ko|0)==16){mQ=a[kp-1+(e+10532)|0]|0}else{mQ=0}yB(e+10532+kp|0,mQ|0,I|0);mi=kn-kq|0;mj=ko;mk=I+kp|0;ml=kq;mm=kr>>>(kq>>>0);mn=ks;mo=kt;mp=ku;S=2800}}while(0);do{if((S|0)==2800){S=0;I=c[e+44>>2]|0;d9=c[e+48>>2]|0;eu=d9+I|0;if(mk>>>0>=eu>>>0){if((eu|0)!=(mk|0)){fH=mi;fI=mj;fJ=mk;fK=ml;fL=mm;fM=mn;fN=mo;fO=mp;S=2836;continue L3731}eu=e+64|0;et=e+10532|0;yE(eu|0,et|0,I)|0;et=e+3552|0;eu=e+10532+I|0;yE(et|0,eu|0,d9)|0;d9=e+24|0;mq=mi;mr=mj;ms=mk;mt=ml;mu=mm;mv=mn;mw=mo;mx=mp;my=c[d9>>2]|0;mz=d9;S=2838;break}if(mi>>>0>=15){jG=mi;jH=mk;jI=ml;jJ=mm;jK=mn;jL=mo;jM=mp;S=2817;continue L3844}if((q-mo|0)<2){jy=mi;jz=mj;jA=mk;jB=ml;jC=mm;jD=mn;jE=mo;jF=mp;S=2803;continue L3844}jG=mi+16|0;jH=mk;jI=ml;jJ=d[mo]<<mi|mm|d[mo+1|0]<<mi+8;jK=mn;jL=mo+2|0;jM=mp;S=2817;continue L3844}else if((S|0)==2762){S=0;d9=e+52|0;if(lP>>>0<(c[d9>>2]|0)>>>0){if(lN>>>0<3){g2=lN;g3=lO;g4=lP;g5=lQ;g6=lR;g7=lS;g8=lT;g9=lU;S=2764;continue L3844}else{ha=lN;hb=lO;hc=lP;hd=lQ;he=lR;hf=lS;hg=lT;hh=lU;S=2771;continue L3844}}else{c[d9>>2]=19;d9=e+24|0;kL=lN;kM=lO;kN=lP;kO=lQ;kP=lR;kQ=lS;kR=lT;kS=lU;kT=d9;kU=c[d9>>2]|0;S=2774;continue L3844}}else if((S|0)==2879){S=0;d9=lA&511;if((d9|0)==256){k1=ly;k2=lz;k3=256;k4=lB;k5=lC;k6=lD;k7=lE;k8=lF;S=2931;continue L3844}eu=d9-257|0;et=c[272+(eu<<2)>>2]|0;I=c[424+(eu<<2)>>2]|0;if((d9-265|0)>>>0>=20){lc=ly;ld=lz;le=I;lf=et;lg=lC;lh=lD;li=lE;lj=lF;break}if(ly>>>0<et>>>0){iH=ly;iI=lz;iJ=I;iK=et;iL=lC;iM=lD;iN=lE;iO=lF;S=2882;continue L3844}else{iP=ly;iQ=lz;iR=I;iS=et;iT=lC;iU=lD;iV=lE;iW=lF;S=2889;continue L3844}}else if((S|0)==2919){S=0;et=mI-h|0;if(!(mD>>>0<=et>>>0|t^1)){dJ=mC;dK=mD;dL=mE;dM=mF;dN=mG;dO=et;dP=mH;dQ=mI;S=2920;continue L3731}I=h+(et-mD&u)|0;if(((mI>>>0>I>>>0?mI:I)+mE|0)>>>0>s>>>0){ji=mC;jj=mD;jk=mE;jl=mF;jm=mG;jn=et;jo=mH;jp=mI;S=2922;continue L3844}else{mR=I;mS=mE;mT=mI}while(1){a[mT]=a[mR]|0;a[mT+1|0]=a[mR+1|0]|0;a[mT+2|0]=a[mR+2|0]|0;mU=mT+3|0;mV=mR+3|0;mW=mS-3|0;if((mW|0)>2){mR=mV;mS=mW;mT=mU}else{break}}if((mW|0)<=0){hw=mC;hx=mD;hy=mW;hz=mF;hA=mG;hB=et;hC=mH;hD=mU;S=2863;continue L3844}a[mU]=a[mV]|0;if((mW|0)>1){a[mT+4|0]=a[mR+4|0]|0}hw=mC;hx=mD;hy=mW;hz=mF;hA=mG;hB=et;hC=mH;hD=mT+mS|0;S=2863;continue L3844}}while(0);if((S|0)==2838){S=0;I=my-1|0;c[mz>>2]=I;kL=mq;kM=mr;kN=ms;kO=mt;kP=mu;kQ=mv;kR=mw;kS=mx;kT=mz;kU=I;S=2774;continue}if(lc>>>0>=15){hq=lc;hr=le;hs=lg;ht=lh;hu=li;hv=lj;S=2906;continue}if((q-li|0)<2){hi=lc;hj=ld;hk=le;hl=lf;hm=lg;hn=lh;ho=li;hp=lj;S=2892;continue}hq=lc+16|0;hr=le;hs=d[li]<<lc|lg|d[li+1|0]<<lc+8;ht=lh;hu=li+2|0;hv=lj;S=2906}if((S|0)==2769){S=0;aq=g2;ar=g3;as=g4;at=d[g8]|0;au=g5;av=g6;aw=g7;ax=g8+1|0;ay=g9;S=2770;continue}else if((S|0)==2898){S=0;if(ho>>>0>=q>>>0){az=hi;aA=hj;aB=hk;aC=hl;aD=hm;aE=hn;aF=ho;aG=hp;S=2899;continue}aH=d[ho]|0;aI=hi;aJ=hj;aK=hk;aL=hl;aM=hm;aN=hn;aO=ho+1|0;aP=hp;S=2904;continue}else if((S|0)==2758){S=0;fq=hE;fr=hF;fs=hG;ft=hH;fu=d[hK]|0;fv=hI;fw=hJ;fx=hK+1|0;fy=hL;S=2759;continue}else if((S|0)==2939){S=0;a4=d[h$]|0;a5=hV;a6=hW;a7=hX;a8=hY;a9=hZ;ba=h_;bb=h$+1|0;bc=h0;S=2940;continue}else if((S|0)==2950){S=0;bl=d[ie]|0;bm=h8;bn=h9;bo=ia;bp=ib;bq=ic;br=id;bs=ie+1|0;bt=ig;S=2951;continue}else if((S|0)==2953){S=0;if(iw>>>0>=q>>>0){bu=0;bv=ir;bw=is;bx=it;by=iu;bz=iv;bA=iw;bB=ix;S=2954;continue}bC=d[iw]|0;bD=0;bE=ir;bF=is;bG=it;bH=iu;bI=iv;bJ=iw+1|0;bK=ix;S=2959;continue}else if((S|0)==2887){S=0;cV=d[iN]|0;cW=iH;cX=iI;cY=iJ;cZ=iK;c_=iL;c$=iM;c0=iN+1|0;c1=iO;S=2888;continue}else if((S|0)==2916){S=0;dA=d[i9]|0;dB=i3;dC=i4;dD=i5;dE=i6;dF=i7;dG=i8;dH=i9+1|0;dI=ja;S=2917;continue}else if((S|0)==2809){S=0;if(jE>>>0>=q>>>0){ew=jy;ex=jz;ey=jA;ez=jB;eA=jC;eB=jD;eC=jE;eD=jF;S=2810;continue}eE=d[jE]|0;eF=jy;eG=jz;eH=jA;eI=jB;eJ=jC;eK=jD;eL=jE+1|0;eM=jF;S=2815;continue}else if((S|0)==2848){S=0;if(jT>>>0>=q>>>0){e1=jN;e2=jO;e3=jP;e4=jQ;e5=jR;e6=jS;e7=jT;e8=jU;S=2849;continue}e9=d[jT]|0;fa=jN;fb=jO;fc=jP;fd=jQ;fe=jR;ff=jS;fg=jT+1|0;fh=jU;S=2854;continue}else if((S|0)==2830){S=0;$=d[kl]|0;aa=kf;ab=kg;ac=kh;ad=ki;ae=kj;af=kk;ag=kl+1|0;ah=km;S=2831;continue}}if((S|0)==2977){i=m;return v|0}S=e+28|0;km=c[S>>2]|0;ah=km&65535;kl=km>>>16;if((gv|0)==(j|0)){mX=ah;mY=kl}else{gv=j;j=iy;km=ah;ah=kl;kl=(iy>>>0)%5552|0;while(1){if(kl>>>0>7){iy=gv;ag=0;kk=km;af=ah;while(1){kj=(d[iy]|0)+kk|0;ae=kj+(d[iy+1|0]|0)|0;ki=ae+(d[iy+2|0]|0)|0;ad=ki+(d[iy+3|0]|0)|0;kh=ad+(d[iy+4|0]|0)|0;ac=kh+(d[iy+5|0]|0)|0;kg=ac+(d[iy+6|0]|0)|0;ab=kg+(d[iy+7|0]|0)|0;kf=kj+af+ae+ki+ad+kh+ac+kg+ab|0;kg=ag+8|0;ac=iy+8|0;if((kg|7)>>>0<kl>>>0){iy=ac;ag=kg;kk=ab;af=kf}else{mZ=ac;m_=kg;m$=ab;m0=kf;break}}}else{mZ=gv;m_=0;m$=km;m0=ah}if(m_>>>0<kl>>>0){af=mZ;kk=m_;ag=m$;iy=m0;while(1){m1=(d[af]|0)+ag|0;m2=m1+iy|0;kf=kk+1|0;if(kf>>>0<kl>>>0){af=af+1|0;kk=kf;ag=m1;iy=m2}else{break}}m3=mZ+(kl-m_)|0;m4=m1;m5=m2}else{m3=mZ;m4=m$;m5=m0}iy=(m4>>>0)%65521|0;ag=(m5>>>0)%65521|0;if((j|0)==(kl|0)){mX=iy;mY=ag;break}else{gv=m3;j=j-kl|0;km=iy;ah=ag;kl=5552}}}kl=mY<<16|mX;c[S>>2]=kl;if((gn|0)!=0){v=gn;i=m;return v|0}if((l&1|0)==0){v=0;i=m;return v|0}else{i=m;return((kl|0)==(c[e+16>>2]|0)?0:-2)|0}return 0}function kx(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0;h=f|0;i=f+20112|0;j=c[i>>2]|0;k=f+16920|0;l=c[k>>2]|0;m=f+17559|0;n=a[m]|0;if(l>>>0>j>>>0){o=c[f+17e3>>2]|0;p=c[f+16988>>2]|0;q=c[f+16980>>2]|0;r=f+16996|0;s=f+16984|0;t=f+16976|0;u=f+16972|0;v=f+16948|0;w=n&1}else{x=n&1;n=(70224<<x)+l|0;c[k>>2]=n;l=(c[f+16924>>2]|0)>>>0>n>>>0?2:3;c[f+17e3>>2]=l;n=f+16996|0;y=c[n>>2]|0;z=(c[f+16912+(y<<2)>>2]|0)>>>0<(c[f+16912+(l<<2)>>2]|0)>>>0?y:l;y=f+16984|0;c[y>>2]=z;A=c[f+16988>>2]|0;B=(c[f+16912+(z<<2)>>2]|0)>>>0<(c[f+16912+(A<<2)>>2]|0)>>>0?z:A;z=f+16976|0;c[z>>2]=B;C=c[f+16980>>2]|0;D=(c[f+16912+(B<<2)>>2]|0)>>>0<(c[f+16912+(C<<2)>>2]|0)>>>0?B:C;B=f+16972|0;c[B>>2]=D;E=f+16948|0;c[E>>2]=c[f+16912+(D<<2)>>2];o=l;p=A;q=C;r=n;s=y;t=z;u=B;v=E;w=x}x=(g<<w)+j|0;j=f+16916|0;c[j>>2]=x;w=f+16912|0;g=(c[w>>2]|0)>>>0>=x>>>0|0;c[r>>2]=g;r=(c[f+16912+(g<<2)>>2]|0)>>>0<(c[f+16912+(o<<2)>>2]|0)>>>0?g:o;c[s>>2]=r;s=(c[f+16912+(r<<2)>>2]|0)>>>0<(c[f+16912+(p<<2)>>2]|0)>>>0?r:p;c[t>>2]=s;t=(c[f+16912+(s<<2)>>2]|0)>>>0<(c[f+16912+(q<<2)>>2]|0)>>>0?s:q;c[u>>2]=t;c[v>>2]=c[f+16912+(t<<2)>>2];t=f+20136|0;v=a[t]|0;u=c[i>>2]|0;if((c[j>>2]|0)==-1){F=u;G=v;a[t]=G;c[i>>2]=F;return}q=f+20116|0;s=f+17028|0;p=f+16948|0;r=f+20143|0;o=f+20118|0;g=f+20138|0;x=f+20137|0;E=f+20124|0;B=f+20128|0;z=f+20132|0;y=f+20142|0;n=f+20141|0;C=f+20120|0;A=f+20140|0;l=f+20139|0;D=f+511|0;H=f+19379|0;I=f+16944|0;J=f+17012|0;K=f+16992|0;L=f+16980|0;M=f+16976|0;N=f+16972|0;O=f+16908|0;P=f+17020|0;Q=f+271|0;R=f+17024|0;S=f+17016|0;T=f+333|0;U=f+16996|0;V=f+17e3|0;W=f+16984|0;X=f+16988|0;Y=f+19692|0;Z=f+17268|0;_=f+19362|0;$=f+17532|0;aa=f+17558|0;ab=f+17552|0;ac=f+19148|0;ad=f+17556|0;ae=f+19276|0;af=f+19268|0;ah=f+19280|0;ai=f+17528|0;aj=f+17540|0;ak=f+320|0;al=f+19588|0;am=f+16924|0;an=Z|0;ao=f+19680|0;ap=f+19668|0;aq=f+17552|0;ar=aq|0;as=f+19564|0;at=f+19560|0;au=f+19576|0;av=f+19568|0;aw=f+19596|0;ax=f+19600|0;ay=f+19652|0;az=f+19656|0;aA=f+19640|0;aB=f+19636|0;aC=f+19632|0;aD=f+19612|0;aE=f+19660|0;aF=ap|0;aG=f+19592|0;aH=f+19648|0;aI=f+19644|0;aJ=f+19688|0;aK=f+19604|0;aL=f+19608|0;aM=f+17536|0;aN=f+19284|0;aO=f+19288|0;aP=f+19292|0;aQ=u;u=v;while(1){v=b[q>>1]|0;aR=c[p>>2]|0;aS=aQ>>>0<aR>>>0;L4064:do{if((a[s]&2)==0){if(aS){aT=v;aU=aQ;aV=u}else{aW=u;aX=aQ;aY=v;break}while(1){aZ=aT&65535;a_=c[f+17032+(aZ>>>12<<2)>>2]|0;if((a_|0)==0){a$=kQ(h,aZ,aU)|0}else{a$=d[a_+aZ|0]|0}aZ=aU+4|0;if((a[r]&1)==0){a0=aT+1&65535}else{a[r]=0;a0=aT}L4077:do{switch(a$&255|0){case 135:{a_=aV&255;c[C>>2]=a_;c[E>>2]=a_;a1=a_<<1;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aZ;a4=a0;break};case 136:{a1=aV&255;c[C>>2]=a1;a_=c[z>>2]|0;a5=d[x]|0;c[E>>2]=a5|a_&256;a6=a5+a1+(a_>>>8&1)|0;c[z>>2]=a6;c[B>>2]=a6;a2=a6&255;a3=aZ;a4=a0;break};case 137:{a6=aV&255;c[C>>2]=a6;a_=c[z>>2]|0;a1=d[g]|0;c[E>>2]=a1|a_&256;a5=a1+a6+(a_>>>8&1)|0;c[z>>2]=a5;c[B>>2]=a5;a2=a5&255;a3=aZ;a4=a0;break};case 138:{a5=aV&255;c[C>>2]=a5;a_=c[z>>2]|0;a6=d[l]|0;c[E>>2]=a6|a_&256;a1=a6+a5+(a_>>>8&1)|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aZ;a4=a0;break};case 139:{a1=aV&255;c[C>>2]=a1;a_=c[z>>2]|0;a5=d[A]|0;c[E>>2]=a5|a_&256;a6=a5+a1+(a_>>>8&1)|0;c[z>>2]=a6;c[B>>2]=a6;a2=a6&255;a3=aZ;a4=a0;break};case 140:{a6=aV&255;c[C>>2]=a6;a_=c[z>>2]|0;a1=d[n]|0;c[E>>2]=a1|a_&256;a5=a1+a6+(a_>>>8&1)|0;c[z>>2]=a5;c[B>>2]=a5;a2=a5&255;a3=aZ;a4=a0;break};case 141:{a5=aV&255;c[C>>2]=a5;a_=c[z>>2]|0;a6=d[y]|0;c[E>>2]=a6|a_&256;a1=a6+a5+(a_>>>8&1)|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aZ;a4=a0;break};case 142:{a1=d[n]|0;a_=a1<<8|d[y];a5=c[f+17032+(a1>>>4<<2)>>2]|0;if((a5|0)==0){a7=kQ(h,a_,aZ)|0}else{a7=d[a5+a_|0]|0}a_=aV&255;c[C>>2]=a_;a5=c[z>>2]|0;c[E>>2]=a5&256|a7;a1=a7+a_+(a5>>>8&1)|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aU+8|0;a4=a0;break};case 143:{a1=aV&255;c[C>>2]=a1;a5=c[z>>2]|0;c[E>>2]=a5&256|a1;a_=a5>>>8&1|a1<<1;c[z>>2]=a_;c[B>>2]=a_;a2=a_&255;a3=aZ;a4=a0;break};case 144:{a_=aV&255;c[C>>2]=a_;a1=d[x]|0;a5=a_-a1|0;c[z>>2]=a5;c[B>>2]=a5;c[E>>2]=a1|1024;a2=a5&255;a3=aZ;a4=a0;break};case 145:{a5=aV&255;c[C>>2]=a5;a1=d[g]|0;a_=a5-a1|0;c[z>>2]=a_;c[B>>2]=a_;c[E>>2]=a1|1024;a2=a_&255;a3=aZ;a4=a0;break};case 119:{a_=d[n]|0;a1=a_<<8|d[y];a5=c[f+17096+(a_>>>4<<2)>>2]|0;if((a5|0)==0){kP(h,a1,aV&255,aZ)}else{a[a5+a1|0]=aV}a2=aV;a3=aU+8|0;a4=a0;break};case 120:{a2=a[x]|0;a3=aZ;a4=a0;break};case 121:{a2=a[g]|0;a3=aZ;a4=a0;break};case 122:{a2=a[l]|0;a3=aZ;a4=a0;break};case 123:{a2=a[A]|0;a3=aZ;a4=a0;break};case 124:{a2=a[n]|0;a3=aZ;a4=a0;break};case 125:{a2=a[y]|0;a3=aZ;a4=a0;break};case 126:{a1=d[n]|0;a5=a1<<8|d[y];a_=c[f+17032+(a1>>>4<<2)>>2]|0;if((a_|0)==0){a8=(kQ(h,a5,aZ)|0)&255}else{a8=a[a_+a5|0]|0}a2=a8;a3=aU+8|0;a4=a0;break};case 128:{a5=aV&255;c[C>>2]=a5;a_=d[x]|0;c[E>>2]=a_;a1=a_+a5|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aZ;a4=a0;break};case 129:{a1=aV&255;c[C>>2]=a1;a5=d[g]|0;c[E>>2]=a5;a_=a5+a1|0;c[z>>2]=a_;c[B>>2]=a_;a2=a_&255;a3=aZ;a4=a0;break};case 130:{a_=aV&255;c[C>>2]=a_;a1=d[l]|0;c[E>>2]=a1;a5=a1+a_|0;c[z>>2]=a5;c[B>>2]=a5;a2=a5&255;a3=aZ;a4=a0;break};case 131:{a5=aV&255;c[C>>2]=a5;a_=d[A]|0;c[E>>2]=a_;a1=a_+a5|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aZ;a4=a0;break};case 132:{a1=aV&255;c[C>>2]=a1;a5=d[n]|0;c[E>>2]=a5;a_=a5+a1|0;c[z>>2]=a_;c[B>>2]=a_;a2=a_&255;a3=aZ;a4=a0;break};case 133:{a_=aV&255;c[C>>2]=a_;a1=d[y]|0;c[E>>2]=a1;a5=a1+a_|0;c[z>>2]=a5;c[B>>2]=a5;a2=a5&255;a3=aZ;a4=a0;break};case 134:{a5=d[n]|0;a_=a5<<8|d[y];a1=c[f+17032+(a5>>>4<<2)>>2]|0;if((a1|0)==0){a9=kQ(h,a_,aZ)|0}else{a9=d[a1+a_|0]|0}a_=aV&255;c[C>>2]=a_;c[E>>2]=a9;a1=a9+a_|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aU+8|0;a4=a0;break};case 196:{if((c[B>>2]&255|0)==0){a2=aV;a3=aU+12|0;a4=a0+2&65535;break L4077}a1=(e[o>>1]|0)+65535|0;b[o>>1]=a1&65535;a_=a1&65535;a1=a0&65535;a5=a1+2|0;a6=a5>>>8;ba=c[f+17096+(a_>>>12<<2)>>2]|0;if((ba|0)==0){kP(h,a_,a6&255,aZ)}else{a[ba+a_|0]=a6&255}a6=(e[o>>1]|0)+65535|0;b[o>>1]=a6&65535;a_=a6&65535;a6=c[f+17096+(a_>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,a_,a5&255,aU+8|0)}else{a[a6+a_|0]=a5&255}a5=c[f+17032+(a1>>>12<<2)>>2]|0;if((a5|0)==0){bb=kQ(h,a1,aU+12|0)|0}else{bb=d[a5+a1|0]|0}a5=a1+1&65535;a1=c[f+17032+(a5>>>12<<2)>>2]|0;if((a1|0)==0){bc=kQ(h,a5,aU+16|0)|0}else{bc=d[a1+a5|0]|0}a2=aV;a3=aU+24|0;a4=(bc<<8|bb)&65535;break};case 197:{a5=(e[o>>1]|0)+65535|0;b[o>>1]=a5&65535;a1=a5&65535;a5=a[x]|0;a_=c[f+17096+(a1>>>12<<2)>>2]|0;if((a_|0)==0){kP(h,a1,a5&255,aZ)}else{a[a_+a1|0]=a5}a5=(e[o>>1]|0)+65535|0;b[o>>1]=a5&65535;a1=a5&65535;a5=a[g]|0;a_=c[f+17096+(a1>>>12<<2)>>2]|0;if((a_|0)==0){kP(h,a1,a5&255,aU+8|0)}else{a[a_+a1|0]=a5}a2=aV;a3=aU+16|0;a4=a0;break};case 198:{a5=a0&65535;a1=c[f+17032+(a5>>>12<<2)>>2]|0;if((a1|0)==0){bd=kQ(h,a5,aZ)|0}else{bd=d[a1+a5|0]|0}a5=aV&255;c[C>>2]=a5;c[E>>2]=bd;a1=bd+a5|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aU+8|0;a4=a0+1&65535;break};case 199:{a1=(e[o>>1]|0)+65535|0;b[o>>1]=a1&65535;a5=a1&65535;a1=a0&65535;a_=a1>>>8;a6=c[f+17096+(a5>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,a5,a_,aZ)}else{a[a6+a5|0]=a_&255}a_=(e[o>>1]|0)+65535|0;b[o>>1]=a_&65535;a5=a_&65535;a_=c[f+17096+(a5>>>12<<2)>>2]|0;if((a_|0)==0){kP(h,a5,a1&255,aU+8|0)}else{a[a_+a5|0]=a0&255}a2=aV;a3=aU+16|0;a4=0;break};case 207:{a5=(e[o>>1]|0)+65535|0;b[o>>1]=a5&65535;a_=a5&65535;a5=a0&65535;a1=a5>>>8;a6=c[f+17096+(a_>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,a_,a1,aZ)}else{a[a6+a_|0]=a1&255}a1=(e[o>>1]|0)+65535|0;b[o>>1]=a1&65535;a_=a1&65535;a1=c[f+17096+(a_>>>12<<2)>>2]|0;if((a1|0)==0){kP(h,a_,a5&255,aU+8|0)}else{a[a1+a_|0]=a0&255}a2=aV;a3=aU+16|0;a4=8;break};case 208:{a_=aU+8|0;if((c[z>>2]&256|0)!=0){a2=aV;a3=a_;a4=a0;break L4077}a1=b[o>>1]|0;a5=a1&65535;a6=c[f+17032+(a5>>>12<<2)>>2]|0;if((a6|0)==0){ba=kQ(h,a5,a_)|0;be=ba;bf=b[o>>1]|0}else{be=d[a6+a5|0]|0;bf=a1}a1=(bf&65535)+1|0;a5=a1&65535;b[o>>1]=a5;a6=a1&65535;a1=c[f+17032+(a6>>>12<<2)>>2]|0;if((a1|0)==0){ba=kQ(h,a6,aU+12|0)|0;bg=ba;bh=b[o>>1]|0}else{bg=d[a1+a6|0]|0;bh=a5}b[o>>1]=bh+1&65535;a2=aV;a3=aU+20|0;a4=(bg<<8|be)&65535;break};case 209:{a5=b[o>>1]|0;a6=a5&65535;a1=c[f+17032+(a6>>>12<<2)>>2]|0;if((a1|0)==0){ba=(kQ(h,a6,aZ)|0)&255;bi=ba;bj=b[o>>1]|0}else{bi=a[a1+a6|0]|0;bj=a5}a[A]=bi;a5=(bj&65535)+1|0;a6=a5&65535;b[o>>1]=a6;a1=a5&65535;a5=c[f+17032+(a1>>>12<<2)>>2]|0;if((a5|0)==0){ba=(kQ(h,a1,aU+8|0)|0)&255;bk=ba;bl=b[o>>1]|0}else{bk=a[a5+a1|0]|0;bl=a6}a[l]=bk;b[o>>1]=bl+1&65535;a2=aV;a3=aU+12|0;a4=a0;break};case 210:{if((c[z>>2]&256|0)!=0){a2=aV;a3=aU+12|0;a4=a0+2&65535;break L4077}a6=a0&65535;a1=c[f+17032+(a6>>>12<<2)>>2]|0;if((a1|0)==0){bm=kQ(h,a6,aZ)|0}else{bm=d[a1+a6|0]|0}a1=a6+1&65535;a6=c[f+17032+(a1>>>12<<2)>>2]|0;if((a6|0)==0){bn=kQ(h,a1,aU+8|0)|0}else{bn=d[a6+a1|0]|0}a2=aV;a3=aU+16|0;a4=(bn<<8|bm)&65535;break};case 212:{if((c[z>>2]&256|0)!=0){a2=aV;a3=aU+12|0;a4=a0+2&65535;break L4077}a1=(e[o>>1]|0)+65535|0;b[o>>1]=a1&65535;a6=a1&65535;a1=a0&65535;a5=a1+2|0;ba=a5>>>8;a_=c[f+17096+(a6>>>12<<2)>>2]|0;if((a_|0)==0){kP(h,a6,ba&255,aZ)}else{a[a_+a6|0]=ba&255}ba=(e[o>>1]|0)+65535|0;b[o>>1]=ba&65535;a6=ba&65535;ba=c[f+17096+(a6>>>12<<2)>>2]|0;if((ba|0)==0){kP(h,a6,a5&255,aU+8|0)}else{a[ba+a6|0]=a5&255}a5=c[f+17032+(a1>>>12<<2)>>2]|0;if((a5|0)==0){bo=kQ(h,a1,aU+12|0)|0}else{bo=d[a5+a1|0]|0}a5=a1+1&65535;a1=c[f+17032+(a5>>>12<<2)>>2]|0;if((a1|0)==0){bp=kQ(h,a5,aU+16|0)|0}else{bp=d[a1+a5|0]|0}a2=aV;a3=aU+24|0;a4=(bp<<8|bo)&65535;break};case 213:{a5=(e[o>>1]|0)+65535|0;b[o>>1]=a5&65535;a1=a5&65535;a5=a[l]|0;a6=c[f+17096+(a1>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,a1,a5&255,aZ)}else{a[a6+a1|0]=a5}a5=(e[o>>1]|0)+65535|0;b[o>>1]=a5&65535;a1=a5&65535;a5=a[A]|0;a6=c[f+17096+(a1>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,a1,a5&255,aU+8|0)}else{a[a6+a1|0]=a5}a2=aV;a3=aU+16|0;a4=a0;break};case 214:{a5=a0&65535;a1=c[f+17032+(a5>>>12<<2)>>2]|0;if((a1|0)==0){bq=kQ(h,a5,aZ)|0}else{bq=d[a1+a5|0]|0}a5=aV&255;c[C>>2]=a5;a1=a5-bq|0;c[z>>2]=a1;c[B>>2]=a1;c[E>>2]=bq|1024;a2=a1&255;a3=aU+8|0;a4=a0+1&65535;break};case 215:{a1=(e[o>>1]|0)+65535|0;b[o>>1]=a1&65535;a5=a1&65535;a1=a0&65535;a6=a1>>>8;ba=c[f+17096+(a5>>>12<<2)>>2]|0;if((ba|0)==0){kP(h,a5,a6,aZ)}else{a[ba+a5|0]=a6&255}a6=(e[o>>1]|0)+65535|0;b[o>>1]=a6&65535;a5=a6&65535;a6=c[f+17096+(a5>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,a5,a1&255,aU+8|0)}else{a[a6+a5|0]=a0&255}a2=aV;a3=aU+16|0;a4=16;break};case 216:{a5=aU+8|0;if((c[z>>2]&256|0)==0){a2=aV;a3=a5;a4=a0;break L4077}a6=b[o>>1]|0;a1=a6&65535;ba=c[f+17032+(a1>>>12<<2)>>2]|0;if((ba|0)==0){a_=kQ(h,a1,a5)|0;br=a_;bs=b[o>>1]|0}else{br=d[ba+a1|0]|0;bs=a6}a6=(bs&65535)+1|0;a1=a6&65535;b[o>>1]=a1;ba=a6&65535;a6=c[f+17032+(ba>>>12<<2)>>2]|0;if((a6|0)==0){a_=kQ(h,ba,aU+12|0)|0;bt=a_;bu=b[o>>1]|0}else{bt=d[a6+ba|0]|0;bu=a1}b[o>>1]=bu+1&65535;a2=aV;a3=aU+20|0;a4=(bt<<8|br)&65535;break};case 217:{a1=b[o>>1]|0;ba=a1&65535;a6=c[f+17032+(ba>>>12<<2)>>2]|0;if((a6|0)==0){a_=kQ(h,ba,aZ)|0;bv=a_;bw=b[o>>1]|0}else{bv=d[a6+ba|0]|0;bw=a1}a1=(bw&65535)+1|0;ba=a1&65535;b[o>>1]=ba;a6=a1&65535;a1=c[f+17032+(a6>>>12<<2)>>2]|0;if((a1|0)==0){a_=kQ(h,a6,aU+8|0)|0;bx=a_;by=b[o>>1]|0}else{bx=d[a1+a6|0]|0;by=ba}b[o>>1]=by+1&65535;ba=a[s]|0;do{if((ba&1)==0){a[s]=ba|1;a6=aU+13|0;c[S>>2]=a6;if((c[R>>2]&c[P>>2]|0)==0){break}c[I>>2]=a6;c[J>>2]=8;c[K>>2]=8;c[L>>2]=8;a1=c[M>>2]|0;a_=(c[f+16912+(a1<<2)>>2]|0)>>>0<a6>>>0?a1:8;c[N>>2]=a_;c[p>>2]=c[f+16912+(a_<<2)>>2]}}while(0);a2=aV;a3=aU+16|0;a4=(bx<<8|bv)&65535;break};case 218:{if((c[z>>2]&256|0)==0){a2=aV;a3=aU+12|0;a4=a0+2&65535;break L4077}ba=a0&65535;a_=c[f+17032+(ba>>>12<<2)>>2]|0;if((a_|0)==0){bz=kQ(h,ba,aZ)|0}else{bz=d[a_+ba|0]|0}a_=ba+1&65535;ba=c[f+17032+(a_>>>12<<2)>>2]|0;if((ba|0)==0){bA=kQ(h,a_,aU+8|0)|0}else{bA=d[ba+a_|0]|0}a2=aV;a3=aU+16|0;a4=(bA<<8|bz)&65535;break};case 220:{if((c[z>>2]&256|0)==0){a2=aV;a3=aU+12|0;a4=a0+2&65535;break L4077}a_=(e[o>>1]|0)+65535|0;b[o>>1]=a_&65535;ba=a_&65535;a_=a0&65535;a1=a_+2|0;a6=a1>>>8;a5=c[f+17096+(ba>>>12<<2)>>2]|0;if((a5|0)==0){kP(h,ba,a6&255,aZ)}else{a[a5+ba|0]=a6&255}a6=(e[o>>1]|0)+65535|0;b[o>>1]=a6&65535;ba=a6&65535;a6=c[f+17096+(ba>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,ba,a1&255,aU+8|0)}else{a[a6+ba|0]=a1&255}a1=c[f+17032+(a_>>>12<<2)>>2]|0;if((a1|0)==0){bB=kQ(h,a_,aU+12|0)|0}else{bB=d[a1+a_|0]|0}a1=a_+1&65535;a_=c[f+17032+(a1>>>12<<2)>>2]|0;if((a_|0)==0){bC=kQ(h,a1,aU+16|0)|0}else{bC=d[a_+a1|0]|0}a2=aV;a3=aU+24|0;a4=(bC<<8|bB)&65535;break};case 222:{a1=a0&65535;a_=c[f+17032+(a1>>>12<<2)>>2]|0;if((a_|0)==0){bD=kQ(h,a1,aZ)|0}else{bD=d[a_+a1|0]|0}a1=aV&255;c[C>>2]=a1;a_=c[z>>2]|0;c[E>>2]=bD|a_&256|1024;ba=a1-(a_>>>8&1)-bD|0;c[z>>2]=ba;c[B>>2]=ba;a2=ba&255;a3=aU+8|0;a4=a0+1&65535;break};case 223:{ba=(e[o>>1]|0)+65535|0;b[o>>1]=ba&65535;a_=ba&65535;ba=a0&65535;a1=ba>>>8;a6=c[f+17096+(a_>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,a_,a1,aZ)}else{a[a6+a_|0]=a1&255}a1=(e[o>>1]|0)+65535|0;b[o>>1]=a1&65535;a_=a1&65535;a1=c[f+17096+(a_>>>12<<2)>>2]|0;if((a1|0)==0){kP(h,a_,ba&255,aU+8|0)}else{a[a1+a_|0]=a0&255}a2=aV;a3=aU+16|0;a4=24;break};case 224:{a_=a0&65535;a1=c[f+17032+(a_>>>12<<2)>>2]|0;if((a1|0)==0){bE=kQ(h,a_,aZ)|0}else{bE=d[a1+a_|0]|0}a_=bE|65280;if((a_-65408|0)>>>0<127){a[f+(a_-65024)|0]=aV}else{kR(h,a_,aV&255,aU+8|0)}a2=aV;a3=aU+12|0;a4=a0+1&65535;break};case 225:{a_=b[o>>1]|0;a1=a_&65535;ba=c[f+17032+(a1>>>12<<2)>>2]|0;if((ba|0)==0){a6=(kQ(h,a1,aZ)|0)&255;bF=a6;bG=b[o>>1]|0}else{bF=a[ba+a1|0]|0;bG=a_}a[y]=bF;a_=(bG&65535)+1|0;a1=a_&65535;b[o>>1]=a1;ba=a_&65535;a_=c[f+17032+(ba>>>12<<2)>>2]|0;if((a_|0)==0){a6=(kQ(h,ba,aU+8|0)|0)&255;bH=a6;bI=b[o>>1]|0}else{bH=a[a_+ba|0]|0;bI=a1}a[n]=bH;b[o>>1]=bI+1&65535;a2=aV;a3=aU+12|0;a4=a0;break};case 226:{a1=d[g]|65280;if((a1-65408|0)>>>0<127){a[f+(a1-65024)|0]=aV}else{kR(h,a1,aV&255,aZ)}a2=aV;a3=aU+8|0;a4=a0;break};case 229:{a1=(e[o>>1]|0)+65535|0;b[o>>1]=a1&65535;ba=a1&65535;a1=a[n]|0;a_=c[f+17096+(ba>>>12<<2)>>2]|0;if((a_|0)==0){kP(h,ba,a1&255,aZ)}else{a[a_+ba|0]=a1}a1=(e[o>>1]|0)+65535|0;b[o>>1]=a1&65535;ba=a1&65535;a1=a[y]|0;a_=c[f+17096+(ba>>>12<<2)>>2]|0;if((a_|0)==0){kP(h,ba,a1&255,aU+8|0)}else{a[a_+ba|0]=a1}a2=aV;a3=aU+16|0;a4=a0;break};case 50:{a1=d[n]|0;ba=a1<<8|d[y];a_=c[f+17096+(a1>>>4<<2)>>2]|0;if((a_|0)==0){kP(h,ba,aV&255,aZ)}else{a[a_+ba|0]=aV}a_=ba+65535|0;a[y]=a_&255;a[n]=a_>>>8&255;a2=aV;a3=aU+8|0;a4=a0;break};case 51:{b[o>>1]=(b[o>>1]|0)+1&65535;a2=aV;a3=aU+8|0;a4=a0;break};case 52:{a_=d[n]|0;ba=a_<<8|d[y];a1=a_>>>4;a_=c[f+17032+(a1<<2)>>2]|0;if((a_|0)==0){bJ=kQ(h,ba,aZ)|0}else{bJ=d[a_+ba|0]|0}c[E>>2]=bJ;a_=bJ+1|0;c[B>>2]=a_;a6=c[f+17096+(a1<<2)>>2]|0;if((a6|0)==0){kP(h,ba,a_&255,aU+8|0)}else{a[a6+ba|0]=a_&255}c[E>>2]=c[E>>2]|2048;a2=aV;a3=aU+12|0;a4=a0;break};case 34:{a_=d[n]|0;ba=a_<<8|d[y];a6=c[f+17096+(a_>>>4<<2)>>2]|0;if((a6|0)==0){kP(h,ba,aV&255,aZ)}else{a[a6+ba|0]=aV}a6=ba+1|0;a[y]=a6&255;a[n]=a6>>>8&255;a2=aV;a3=aU+8|0;a4=a0;break};case 17:{a6=a0&65535;ba=c[f+17032+(a6>>>12<<2)>>2]|0;if((ba|0)==0){bK=(kQ(h,a6,aZ)|0)&255}else{bK=a[ba+a6|0]|0}a[A]=bK;ba=a6+1&65535;a6=c[f+17032+(ba>>>12<<2)>>2]|0;if((a6|0)==0){bL=(kQ(h,ba,aU+8|0)|0)&255}else{bL=a[a6+ba|0]|0}a[l]=bL;a2=aV;a3=aU+12|0;a4=a0+2&65535;break};case 40:{if((c[B>>2]&255|0)!=0){a2=aV;a3=aU+8|0;a4=a0+1&65535;break L4077}ba=a0&65535;a6=c[f+17032+(ba>>>12<<2)>>2]|0;if((a6|0)==0){bM=kQ(h,ba,aZ)|0}else{bM=d[a6+ba|0]|0}a2=aV;a3=aU+12|0;a4=ba+65409+(bM^128)&65535;break};case 41:{ba=d[y]|0;a6=ba<<1;a[y]=a6&255;a_=d[n]|0;c[C>>2]=a_;c[E>>2]=a6&256|a_;a6=a_<<1|ba>>>7;c[z>>2]=a6;a[n]=a6&255;a2=aV;a3=aU+8|0;a4=a0;break};case 38:{a6=a0&65535;ba=c[f+17032+(a6>>>12<<2)>>2]|0;if((ba|0)==0){bN=(kQ(h,a6,aZ)|0)&255}else{bN=a[ba+a6|0]|0}a[n]=bN;a2=aV;a3=aU+8|0;a4=a0+1&65535;break};case 39:{a6=c[E>>2]|0;ba=(a6>>>8&1)+(a6&15)|0;a_=(a6&2048|0)==0;a1=a_?c[C>>2]&15:ba;a5=a_?ba:1;ba=a6&1024;a_=(ba|0)==0;if(a_){bO=a1+a5<<5}else{bO=a1-a5|0}a5=(c[z>>2]&256|0)!=0?96:0;a1=a5|6;bP=((bO|a6)&512|0)==0?a5:a1;c[E>>2]=ba;ba=aV&255;if(a_){a_=(ba&14)>>>0>9?a1:bP;a1=(aV&255)>153?a_|96:a_;bQ=a1;bR=a1+ba|0}else{bQ=bP;bR=ba-bP|0}bP=bR&255;c[z>>2]=bQ<<2&256;c[B>>2]=bP&255;a2=bP;a3=aZ;a4=a0;break};case 1:{bP=a0&65535;ba=c[f+17032+(bP>>>12<<2)>>2]|0;if((ba|0)==0){bS=(kQ(h,bP,aZ)|0)&255}else{bS=a[ba+bP|0]|0}a[g]=bS;ba=bP+1&65535;bP=c[f+17032+(ba>>>12<<2)>>2]|0;if((bP|0)==0){bT=(kQ(h,ba,aU+8|0)|0)&255}else{bT=a[bP+ba|0]|0}a[x]=bT;a2=aV;a3=aU+12|0;a4=a0+2&65535;break};case 35:{ba=(d[y]|0)+1|0;a[y]=ba&255;a[n]=(ba>>>8)+(d[n]|0)&255;a2=aV;a3=aU+8|0;a4=a0;break};case 36:{ba=d[n]|0;c[E>>2]=ba|2048;bP=ba+1|0;c[B>>2]=bP;a[n]=bP&255;a2=aV;a3=aZ;a4=a0;break};case 146:{bP=aV&255;c[C>>2]=bP;ba=d[l]|0;a1=bP-ba|0;c[z>>2]=a1;c[B>>2]=a1;c[E>>2]=ba|1024;a2=a1&255;a3=aZ;a4=a0;break};case 147:{a1=aV&255;c[C>>2]=a1;ba=d[A]|0;bP=a1-ba|0;c[z>>2]=bP;c[B>>2]=bP;c[E>>2]=ba|1024;a2=bP&255;a3=aZ;a4=a0;break};case 148:{bP=aV&255;c[C>>2]=bP;ba=d[n]|0;a1=bP-ba|0;c[z>>2]=a1;c[B>>2]=a1;c[E>>2]=ba|1024;a2=a1&255;a3=aZ;a4=a0;break};case 149:{a1=aV&255;c[C>>2]=a1;ba=d[y]|0;bP=a1-ba|0;c[z>>2]=bP;c[B>>2]=bP;c[E>>2]=ba|1024;a2=bP&255;a3=aZ;a4=a0;break};case 150:{bP=d[n]|0;ba=bP<<8|d[y];a1=c[f+17032+(bP>>>4<<2)>>2]|0;if((a1|0)==0){bU=kQ(h,ba,aZ)|0}else{bU=d[a1+ba|0]|0}ba=aV&255;c[C>>2]=ba;a1=ba-bU|0;c[z>>2]=a1;c[B>>2]=a1;c[E>>2]=bU|1024;a2=a1&255;a3=aU+8|0;a4=a0;break};case 151:{c[E>>2]=1024;c[B>>2]=0;c[z>>2]=0;a2=0;a3=aZ;a4=a0;break};case 152:{a1=aV&255;c[C>>2]=a1;ba=c[z>>2]|0;bP=d[x]|0;c[E>>2]=ba&256|bP|1024;a_=a1-(ba>>>8&1)-bP|0;c[z>>2]=a_;c[B>>2]=a_;a2=a_&255;a3=aZ;a4=a0;break};case 153:{a_=aV&255;c[C>>2]=a_;bP=c[z>>2]|0;ba=d[g]|0;c[E>>2]=bP&256|ba|1024;a1=a_-(bP>>>8&1)-ba|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aZ;a4=a0;break};case 154:{a1=aV&255;c[C>>2]=a1;ba=c[z>>2]|0;bP=d[l]|0;c[E>>2]=ba&256|bP|1024;a_=a1-(ba>>>8&1)-bP|0;c[z>>2]=a_;c[B>>2]=a_;a2=a_&255;a3=aZ;a4=a0;break};case 155:{a_=aV&255;c[C>>2]=a_;bP=c[z>>2]|0;ba=d[A]|0;c[E>>2]=bP&256|ba|1024;a1=a_-(bP>>>8&1)-ba|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aZ;a4=a0;break};case 156:{a1=aV&255;c[C>>2]=a1;ba=c[z>>2]|0;bP=d[n]|0;c[E>>2]=ba&256|bP|1024;a_=a1-(ba>>>8&1)-bP|0;c[z>>2]=a_;c[B>>2]=a_;a2=a_&255;a3=aZ;a4=a0;break};case 157:{a_=aV&255;c[C>>2]=a_;bP=c[z>>2]|0;ba=d[y]|0;c[E>>2]=bP&256|ba|1024;a1=a_-(bP>>>8&1)-ba|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aZ;a4=a0;break};case 158:{a1=d[n]|0;ba=a1<<8|d[y];bP=c[f+17032+(a1>>>4<<2)>>2]|0;if((bP|0)==0){bV=kQ(h,ba,aZ)|0}else{bV=d[bP+ba|0]|0}ba=aV&255;c[C>>2]=ba;bP=c[z>>2]|0;c[E>>2]=bV|bP&256|1024;a1=ba-(bP>>>8&1)-bV|0;c[z>>2]=a1;c[B>>2]=a1;a2=a1&255;a3=aU+8|0;a4=a0;break};case 53:{a1=d[n]|0;bP=a1<<8|d[y];ba=a1>>>4;a1=c[f+17032+(ba<<2)>>2]|0;if((a1|0)==0){bW=kQ(h,bP,aZ)|0}else{bW=d[a1+bP|0]|0}c[E>>2]=bW;a1=bW-1|0;c[B>>2]=a1;a_=c[f+17096+(ba<<2)>>2]|0;if((a_|0)==0){kP(h,bP,a1&255,aU+8|0)}else{a[a_+bP|0]=a1&255}c[E>>2]=c[E>>2]|3072;a2=aV;a3=aU+12|0;a4=a0;break};case 54:{a1=a0&65535;bP=c[f+17032+(a1>>>12<<2)>>2]|0;if((bP|0)==0){bX=kQ(h,a1,aZ)|0}else{bX=d[bP+a1|0]|0}a1=d[n]|0;bP=a1<<8|d[y];a_=c[f+17096+(a1>>>4<<2)>>2]|0;if((a_|0)==0){kP(h,bP,bX,aU+8|0)}else{a[a_+bP|0]=bX&255}a2=aV;a3=aU+12|0;a4=a0+1&65535;break};case 55:{c[z>>2]=256;c[E>>2]=0;a2=aV;a3=aZ;a4=a0;break};case 56:{if((c[z>>2]&256|0)==0){a2=aV;a3=aU+8|0;a4=a0+1&65535;break L4077}bP=a0&65535;a_=c[f+17032+(bP>>>12<<2)>>2]|0;if((a_|0)==0){bY=kQ(h,bP,aZ)|0}else{bY=d[a_+bP|0]|0}a2=aV;a3=aU+12|0;a4=bP+65409+(bY^128)&65535;break};case 175:{c[B>>2]=0;c[E>>2]=0;c[z>>2]=0;a2=0;a3=aZ;a4=a0;break};case 176:{c[E>>2]=0;c[z>>2]=0;bP=a[x]|aV;c[B>>2]=bP&255;a2=bP;a3=aZ;a4=a0;break};case 177:{c[E>>2]=0;c[z>>2]=0;bP=a[g]|aV;c[B>>2]=bP&255;a2=bP;a3=aZ;a4=a0;break};case 178:{c[E>>2]=0;c[z>>2]=0;bP=a[l]|aV;c[B>>2]=bP&255;a2=bP;a3=aZ;a4=a0;break};case 179:{c[E>>2]=0;c[z>>2]=0;bP=a[A]|aV;c[B>>2]=bP&255;a2=bP;a3=aZ;a4=a0;break};case 180:{c[E>>2]=0;c[z>>2]=0;bP=a[n]|aV;c[B>>2]=bP&255;a2=bP;a3=aZ;a4=a0;break};case 181:{c[E>>2]=0;c[z>>2]=0;bP=a[y]|aV;c[B>>2]=bP&255;a2=bP;a3=aZ;a4=a0;break};case 182:{bP=d[n]|0;a_=bP<<8|d[y];a1=c[f+17032+(bP>>>4<<2)>>2]|0;if((a1|0)==0){bZ=kQ(h,a_,aZ)|0}else{bZ=d[a1+a_|0]|0}c[E>>2]=0;c[z>>2]=0;a_=bZ|aV&255;c[B>>2]=a_&255;a2=a_&255;a3=aU+8|0;a4=a0;break};case 183:{c[B>>2]=aV&255;c[z>>2]=0;c[E>>2]=0;a2=aV;a3=aZ;a4=a0;break};case 184:{a_=aV&255;c[C>>2]=a_;a1=d[x]|0;bP=a_-a1|0;c[z>>2]=bP;c[B>>2]=bP;c[E>>2]=a1|1024;a2=aV;a3=aZ;a4=a0;break};case 185:{a1=aV&255;c[C>>2]=a1;bP=d[g]|0;a_=a1-bP|0;c[z>>2]=a_;c[B>>2]=a_;c[E>>2]=bP|1024;a2=aV;a3=aZ;a4=a0;break};case 186:{bP=aV&255;c[C>>2]=bP;a_=d[l]|0;a1=bP-a_|0;c[z>>2]=a1;c[B>>2]=a1;c[E>>2]=a_|1024;a2=aV;a3=aZ;a4=a0;break};case 187:{a_=aV&255;c[C>>2]=a_;a1=d[A]|0;bP=a_-a1|0;c[z>>2]=bP;c[B>>2]=bP;c[E>>2]=a1|1024;a2=aV;a3=aZ;a4=a0;break};case 188:{a1=aV&255;c[C>>2]=a1;bP=d[n]|0;a_=a1-bP|0;c[z>>2]=a_;c[B>>2]=a_;c[E>>2]=bP|1024;a2=aV;a3=aZ;a4=a0;break};case 189:{bP=aV&255;c[C>>2]=bP;a_=d[y]|0;a1=bP-a_|0;c[z>>2]=a1;c[B>>2]=a1;c[E>>2]=a_|1024;a2=aV;a3=aZ;a4=a0;break};case 190:{a_=d[n]|0;a1=a_<<8|d[y];bP=c[f+17032+(a_>>>4<<2)>>2]|0;if((bP|0)==0){b_=kQ(h,a1,aZ)|0}else{b_=d[bP+a1|0]|0}a1=aV&255;c[C>>2]=a1;bP=a1-b_|0;c[z>>2]=bP;c[B>>2]=bP;c[E>>2]=b_|1024;a2=aV;a3=aU+8|0;a4=a0;break};case 37:{bP=d[n]|0;c[E>>2]=bP|3072;a1=bP-1|0;c[B>>2]=a1;a[n]=a1&255;a2=aV;a3=aZ;a4=a0;break};case 63:{c[z>>2]=c[z>>2]^256;c[E>>2]=0;a2=aV;a3=aZ;a4=a0;break};case 65:{a[x]=a[g]|0;a2=aV;a3=aZ;a4=a0;break};case 66:{a[x]=a[l]|0;a2=aV;a3=aZ;a4=a0;break};case 67:{a[x]=a[A]|0;a2=aV;a3=aZ;a4=a0;break};case 68:{a[x]=a[n]|0;a2=aV;a3=aZ;a4=a0;break};case 69:{a[x]=a[y]|0;a2=aV;a3=aZ;a4=a0;break};case 70:{a1=d[n]|0;bP=a1<<8|d[y];a_=c[f+17032+(a1>>>4<<2)>>2]|0;if((a_|0)==0){b$=(kQ(h,bP,aZ)|0)&255}else{b$=a[a_+bP|0]|0}a[x]=b$;a2=aV;a3=aU+8|0;a4=a0;break};case 71:{a[x]=aV;a2=aV;a3=aZ;a4=a0;break};case 72:{a[g]=a[x]|0;a2=aV;a3=aZ;a4=a0;break};case 74:{a[g]=a[l]|0;a2=aV;a3=aZ;a4=a0;break};case 75:{a[g]=a[A]|0;a2=aV;a3=aZ;a4=a0;break};case 76:{a[g]=a[n]|0;a2=aV;a3=aZ;a4=a0;break};case 77:{a[g]=a[y]|0;a2=aV;a3=aZ;a4=a0;break};case 78:{bP=d[n]|0;a_=bP<<8|d[y];a1=c[f+17032+(bP>>>4<<2)>>2]|0;if((a1|0)==0){b0=(kQ(h,a_,aZ)|0)&255}else{b0=a[a1+a_|0]|0}a[g]=b0;a2=aV;a3=aU+8|0;a4=a0;break};case 79:{a[g]=aV;a2=aV;a3=aZ;a4=a0;break};case 80:{a[l]=a[x]|0;a2=aV;a3=aZ;a4=a0;break};case 81:{a[l]=a[g]|0;a2=aV;a3=aZ;a4=a0;break};case 83:{a[l]=a[A]|0;a2=aV;a3=aZ;a4=a0;break};case 84:{a[l]=a[n]|0;a2=aV;a3=aZ;a4=a0;break};case 85:{a[l]=a[y]|0;a2=aV;a3=aZ;a4=a0;break};case 86:{a_=d[n]|0;a1=a_<<8|d[y];bP=c[f+17032+(a_>>>4<<2)>>2]|0;if((bP|0)==0){b1=(kQ(h,a1,aZ)|0)&255}else{b1=a[bP+a1|0]|0}a[l]=b1;a2=aV;a3=aU+8|0;a4=a0;break};case 87:{a[l]=aV;a2=aV;a3=aZ;a4=a0;break};case 88:{a[A]=a[x]|0;a2=aV;a3=aZ;a4=a0;break};case 89:{a[A]=a[g]|0;a2=aV;a3=aZ;a4=a0;break};case 90:{a[A]=a[l]|0;a2=aV;a3=aZ;a4=a0;break};case 92:{a[A]=a[n]|0;a2=aV;a3=aZ;a4=a0;break};case 93:{a[A]=a[y]|0;a2=aV;a3=aZ;a4=a0;break};case 94:{a1=d[n]|0;bP=a1<<8|d[y];a_=c[f+17032+(a1>>>4<<2)>>2]|0;if((a_|0)==0){b2=(kQ(h,bP,aZ)|0)&255}else{b2=a[a_+bP|0]|0}a[A]=b2;a2=aV;a3=aU+8|0;a4=a0;break};case 95:{a[A]=aV;a2=aV;a3=aZ;a4=a0;break};case 96:{a[n]=a[x]|0;a2=aV;a3=aZ;a4=a0;break};case 97:{a[n]=a[g]|0;a2=aV;a3=aZ;a4=a0;break};case 98:{a[n]=a[l]|0;a2=aV;a3=aZ;a4=a0;break};case 99:{a[n]=a[A]|0;a2=aV;a3=aZ;a4=a0;break};case 101:{a[n]=a[y]|0;a2=aV;a3=aZ;a4=a0;break};case 29:{bP=d[A]|0;c[E>>2]=bP|3072;a_=bP-1|0;c[B>>2]=a_;a[A]=a_&255;a2=aV;a3=aZ;a4=a0;break};case 30:{a_=a0&65535;bP=c[f+17032+(a_>>>12<<2)>>2]|0;if((bP|0)==0){b3=(kQ(h,a_,aZ)|0)&255}else{b3=a[bP+a_|0]|0}a[A]=b3;a2=aV;a3=aU+8|0;a4=a0+1&65535;break};case 204:{if((c[B>>2]&255|0)!=0){a2=aV;a3=aU+12|0;a4=a0+2&65535;break L4077}a_=(e[o>>1]|0)+65535|0;b[o>>1]=a_&65535;bP=a_&65535;a_=a0&65535;a1=a_+2|0;ba=a1>>>8;a5=c[f+17096+(bP>>>12<<2)>>2]|0;if((a5|0)==0){kP(h,bP,ba&255,aZ)}else{a[a5+bP|0]=ba&255}ba=(e[o>>1]|0)+65535|0;b[o>>1]=ba&65535;bP=ba&65535;ba=c[f+17096+(bP>>>12<<2)>>2]|0;if((ba|0)==0){kP(h,bP,a1&255,aU+8|0)}else{a[ba+bP|0]=a1&255}a1=c[f+17032+(a_>>>12<<2)>>2]|0;if((a1|0)==0){b4=kQ(h,a_,aU+12|0)|0}else{b4=d[a1+a_|0]|0}a1=a_+1&65535;a_=c[f+17032+(a1>>>12<<2)>>2]|0;if((a_|0)==0){b5=kQ(h,a1,aU+16|0)|0}else{b5=d[a_+a1|0]|0}a2=aV;a3=aU+24|0;a4=(b5<<8|b4)&65535;break};case 205:{a1=(e[o>>1]|0)+65535|0;b[o>>1]=a1&65535;a_=a1&65535;a1=a0&65535;bP=a1+2|0;ba=bP>>>8;a5=c[f+17096+(a_>>>12<<2)>>2]|0;if((a5|0)==0){kP(h,a_,ba&255,aZ)}else{a[a5+a_|0]=ba&255}ba=(e[o>>1]|0)+65535|0;b[o>>1]=ba&65535;a_=ba&65535;ba=c[f+17096+(a_>>>12<<2)>>2]|0;if((ba|0)==0){kP(h,a_,bP&255,aU+8|0)}else{a[ba+a_|0]=bP&255}bP=c[f+17032+(a1>>>12<<2)>>2]|0;if((bP|0)==0){b6=kQ(h,a1,aU+12|0)|0}else{b6=d[bP+a1|0]|0}bP=a1+1&65535;a1=c[f+17032+(bP>>>12<<2)>>2]|0;if((a1|0)==0){b7=kQ(h,bP,aU+16|0)|0}else{b7=d[a1+bP|0]|0}a2=aV;a3=aU+24|0;a4=(b7<<8|b6)&65535;break};case 206:{bP=a0&65535;a1=c[f+17032+(bP>>>12<<2)>>2]|0;if((a1|0)==0){b8=kQ(h,bP,aZ)|0}else{b8=d[a1+bP|0]|0}bP=aV&255;c[C>>2]=bP;a1=c[z>>2]|0;c[E>>2]=a1&256|b8;a_=b8+bP+(a1>>>8&1)|0;c[z>>2]=a_;c[B>>2]=a_;a2=a_&255;a3=aU+8|0;a4=a0+1&65535;break};case 200:{a_=aU+8|0;if((c[B>>2]&255|0)!=0){a2=aV;a3=a_;a4=a0;break L4077}a1=b[o>>1]|0;bP=a1&65535;ba=c[f+17032+(bP>>>12<<2)>>2]|0;if((ba|0)==0){a5=kQ(h,bP,a_)|0;b9=a5;ca=b[o>>1]|0}else{b9=d[ba+bP|0]|0;ca=a1}a1=(ca&65535)+1|0;bP=a1&65535;b[o>>1]=bP;ba=a1&65535;a1=c[f+17032+(ba>>>12<<2)>>2]|0;if((a1|0)==0){a5=kQ(h,ba,aU+12|0)|0;cb=a5;cc=b[o>>1]|0}else{cb=d[a1+ba|0]|0;cc=bP}b[o>>1]=cc+1&65535;a2=aV;a3=aU+20|0;a4=(cb<<8|b9)&65535;break};case 201:{bP=b[o>>1]|0;ba=bP&65535;a1=c[f+17032+(ba>>>12<<2)>>2]|0;if((a1|0)==0){a5=kQ(h,ba,aZ)|0;cd=a5;ce=b[o>>1]|0}else{cd=d[a1+ba|0]|0;ce=bP}bP=(ce&65535)+1|0;ba=bP&65535;b[o>>1]=ba;a1=bP&65535;bP=c[f+17032+(a1>>>12<<2)>>2]|0;if((bP|0)==0){a5=kQ(h,a1,aU+8|0)|0;cf=a5;cg=b[o>>1]|0}else{cf=d[bP+a1|0]|0;cg=ba}b[o>>1]=cg+1&65535;a2=aV;a3=aU+16|0;a4=(cf<<8|cd)&65535;break};case 202:{if((c[B>>2]&255|0)!=0){a2=aV;a3=aU+12|0;a4=a0+2&65535;break L4077}ba=a0&65535;a1=c[f+17032+(ba>>>12<<2)>>2]|0;if((a1|0)==0){ch=kQ(h,ba,aZ)|0}else{ch=d[a1+ba|0]|0}a1=ba+1&65535;ba=c[f+17032+(a1>>>12<<2)>>2]|0;if((ba|0)==0){ci=kQ(h,a1,aU+8|0)|0}else{ci=d[ba+a1|0]|0}a2=aV;a3=aU+16|0;a4=(ci<<8|ch)&65535;break};case 203:{a1=a0&65535;ba=c[f+17032+(a1>>>12<<2)>>2]|0;if((ba|0)==0){cj=kQ(h,a1,aZ)|0}else{cj=d[ba+a1|0]|0}a1=a0+1&65535;ba=aU+8|0;switch(cj&255|0){case 0:{bP=d[x]|0;a5=bP<<1;c[z>>2]=a5;a_=a5|bP>>>7;c[B>>2]=a_;a[x]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 1:{a_=d[g]|0;bP=a_<<1;c[z>>2]=bP;a5=bP|a_>>>7;c[B>>2]=a5;a[g]=a5&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 2:{a5=d[l]|0;a_=a5<<1;c[z>>2]=a_;bP=a_|a5>>>7;c[B>>2]=bP;a[l]=bP&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 3:{bP=d[A]|0;a5=bP<<1;c[z>>2]=a5;a_=a5|bP>>>7;c[B>>2]=a_;a[A]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 4:{a_=d[n]|0;bP=a_<<1;c[z>>2]=bP;a5=bP|a_>>>7;c[B>>2]=a5;a[n]=a5&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 5:{a5=d[y]|0;a_=a5<<1;c[z>>2]=a_;bP=a_|a5>>>7;c[B>>2]=bP;a[y]=bP&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 6:{bP=d[n]|0;a5=bP<<8|d[y];a_=bP>>>4;bP=c[f+17032+(a_<<2)>>2]|0;if((bP|0)==0){ck=kQ(h,a5,ba)|0}else{ck=d[bP+a5|0]|0}bP=ck<<1;c[z>>2]=bP;a6=ck>>>7&16777215|bP;c[B>>2]=a6;bP=c[f+17096+(a_<<2)>>2]|0;if((bP|0)==0){kP(h,a5,a6&255,aU+12|0)}else{a[bP+a5|0]=a6&255}c[E>>2]=0;a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 7:{a6=aV&255;a5=a6<<1;c[z>>2]=a5;bP=a5|a6>>>7;c[B>>2]=bP;c[E>>2]=0;a2=bP&255;a3=ba;a4=a1;break L4077;break};case 8:{bP=d[x]|0;c[B>>2]=bP;a6=bP<<8;c[z>>2]=a6;a[x]=(a6|bP)>>>1&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 9:{bP=d[g]|0;c[B>>2]=bP;a6=bP<<8;c[z>>2]=a6;a[g]=(a6|bP)>>>1&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 10:{bP=d[l]|0;c[B>>2]=bP;a6=bP<<8;c[z>>2]=a6;a[l]=(a6|bP)>>>1&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 11:{bP=d[A]|0;c[B>>2]=bP;a6=bP<<8;c[z>>2]=a6;a[A]=(a6|bP)>>>1&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 12:{bP=d[n]|0;c[B>>2]=bP;a6=bP<<8;c[z>>2]=a6;a[n]=(a6|bP)>>>1&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 13:{bP=d[y]|0;c[B>>2]=bP;a6=bP<<8;c[z>>2]=a6;a[y]=(a6|bP)>>>1&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 14:{bP=d[n]|0;a6=bP<<8|d[y];a5=bP>>>4;bP=c[f+17032+(a5<<2)>>2]|0;if((bP|0)==0){cl=kQ(h,a6,ba)|0}else{cl=d[bP+a6|0]|0}c[B>>2]=cl;bP=cl<<8;c[z>>2]=bP;a_=(bP|cl)>>>1;bP=c[f+17096+(a5<<2)>>2]|0;if((bP|0)==0){kP(h,a6,a_&255,aU+12|0)}else{a[bP+a6|0]=a_&255}c[E>>2]=0;a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 97:{c[B>>2]=a[g]&16;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 98:{c[B>>2]=a[l]&16;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 99:{c[B>>2]=a[A]&16;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 100:{c[B>>2]=a[n]&16;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 101:{c[B>>2]=a[y]&16;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 102:{a_=d[n]|0;a6=a_<<8|d[y];bP=c[f+17032+(a_>>>4<<2)>>2]|0;if((bP|0)==0){cm=kQ(h,a6,ba)|0}else{cm=d[bP+a6|0]|0}c[B>>2]=cm&16;c[E>>2]=512;a2=aV;a3=aU+12|0;a4=a1;break L4077;break};case 103:{c[B>>2]=aV&16;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 104:{c[B>>2]=a[x]&32;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 105:{c[B>>2]=a[g]&32;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 106:{c[B>>2]=a[l]&32;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 107:{c[B>>2]=a[A]&32;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 108:{c[B>>2]=a[n]&32;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 109:{c[B>>2]=a[y]&32;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 110:{a6=d[n]|0;bP=a6<<8|d[y];a_=c[f+17032+(a6>>>4<<2)>>2]|0;if((a_|0)==0){cn=kQ(h,bP,ba)|0}else{cn=d[a_+bP|0]|0}c[B>>2]=cn&32;c[E>>2]=512;a2=aV;a3=aU+12|0;a4=a1;break L4077;break};case 111:{c[B>>2]=aV&32;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 112:{c[B>>2]=a[x]&64;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 113:{c[B>>2]=a[g]&64;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 114:{c[B>>2]=a[l]&64;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 115:{c[B>>2]=a[A]&64;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 116:{c[B>>2]=a[n]&64;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 117:{c[B>>2]=a[y]&64;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 118:{bP=d[n]|0;a_=bP<<8|d[y];a6=c[f+17032+(bP>>>4<<2)>>2]|0;if((a6|0)==0){co=kQ(h,a_,ba)|0}else{co=d[a6+a_|0]|0}c[B>>2]=co&64;c[E>>2]=512;a2=aV;a3=aU+12|0;a4=a1;break L4077;break};case 119:{c[B>>2]=aV&64;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 120:{c[B>>2]=a[x]&128;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 121:{c[B>>2]=a[g]&128;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 122:{c[B>>2]=a[l]&128;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 123:{c[B>>2]=a[A]&128;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 124:{c[B>>2]=a[n]&128;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 125:{c[B>>2]=a[y]&128;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 126:{a_=d[n]|0;a6=a_<<8|d[y];bP=c[f+17032+(a_>>>4<<2)>>2]|0;if((bP|0)==0){cp=kQ(h,a6,ba)|0}else{cp=d[bP+a6|0]|0}c[B>>2]=cp&128;c[E>>2]=512;a2=aV;a3=aU+12|0;a4=a1;break L4077;break};case 127:{c[B>>2]=aV&128;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 128:{a[x]=a[x]&-2;a2=aV;a3=ba;a4=a1;break L4077;break};case 129:{a[g]=a[g]&-2;a2=aV;a3=ba;a4=a1;break L4077;break};case 130:{a[l]=a[l]&-2;a2=aV;a3=ba;a4=a1;break L4077;break};case 131:{a[A]=a[A]&-2;a2=aV;a3=ba;a4=a1;break L4077;break};case 132:{a[n]=a[n]&-2;a2=aV;a3=ba;a4=a1;break L4077;break};case 133:{a[y]=a[y]&-2;a2=aV;a3=ba;a4=a1;break L4077;break};case 134:{a6=d[n]|0;bP=a6<<8|d[y];a_=a6>>>4;a6=c[f+17032+(a_<<2)>>2]|0;if((a6|0)==0){cq=kQ(h,bP,ba)|0}else{cq=d[a6+bP|0]|0}a6=cq&-2;a5=c[f+17096+(a_<<2)>>2]|0;if((a5|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a5+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 135:{a2=aV&-2;a3=ba;a4=a1;break L4077;break};case 136:{a[x]=a[x]&-3;a2=aV;a3=ba;a4=a1;break L4077;break};case 137:{a[g]=a[g]&-3;a2=aV;a3=ba;a4=a1;break L4077;break};case 138:{a[l]=a[l]&-3;a2=aV;a3=ba;a4=a1;break L4077;break};case 139:{a[A]=a[A]&-3;a2=aV;a3=ba;a4=a1;break L4077;break};case 140:{a[n]=a[n]&-3;a2=aV;a3=ba;a4=a1;break L4077;break};case 141:{a[y]=a[y]&-3;a2=aV;a3=ba;a4=a1;break L4077;break};case 142:{a6=d[n]|0;bP=a6<<8|d[y];a5=a6>>>4;a6=c[f+17032+(a5<<2)>>2]|0;if((a6|0)==0){cr=kQ(h,bP,ba)|0}else{cr=d[a6+bP|0]|0}a6=cr&-3;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a_+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 143:{a2=aV&-3;a3=ba;a4=a1;break L4077;break};case 144:{a[x]=a[x]&-5;a2=aV;a3=ba;a4=a1;break L4077;break};case 145:{a[g]=a[g]&-5;a2=aV;a3=ba;a4=a1;break L4077;break};case 146:{a[l]=a[l]&-5;a2=aV;a3=ba;a4=a1;break L4077;break};case 147:{a[A]=a[A]&-5;a2=aV;a3=ba;a4=a1;break L4077;break};case 148:{a[n]=a[n]&-5;a2=aV;a3=ba;a4=a1;break L4077;break};case 149:{a[y]=a[y]&-5;a2=aV;a3=ba;a4=a1;break L4077;break};case 150:{a6=d[n]|0;bP=a6<<8|d[y];a_=a6>>>4;a6=c[f+17032+(a_<<2)>>2]|0;if((a6|0)==0){cs=kQ(h,bP,ba)|0}else{cs=d[a6+bP|0]|0}a6=cs&-5;a5=c[f+17096+(a_<<2)>>2]|0;if((a5|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a5+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 151:{a2=aV&-5;a3=ba;a4=a1;break L4077;break};case 152:{a[x]=a[x]&-9;a2=aV;a3=ba;a4=a1;break L4077;break};case 153:{a[g]=a[g]&-9;a2=aV;a3=ba;a4=a1;break L4077;break};case 154:{a[l]=a[l]&-9;a2=aV;a3=ba;a4=a1;break L4077;break};case 155:{a[A]=a[A]&-9;a2=aV;a3=ba;a4=a1;break L4077;break};case 156:{a[n]=a[n]&-9;a2=aV;a3=ba;a4=a1;break L4077;break};case 157:{a[y]=a[y]&-9;a2=aV;a3=ba;a4=a1;break L4077;break};case 158:{a6=d[n]|0;bP=a6<<8|d[y];a5=a6>>>4;a6=c[f+17032+(a5<<2)>>2]|0;if((a6|0)==0){ct=kQ(h,bP,ba)|0}else{ct=d[a6+bP|0]|0}a6=ct&-9;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a_+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 159:{a2=aV&-9;a3=ba;a4=a1;break L4077;break};case 160:{a[x]=a[x]&-17;a2=aV;a3=ba;a4=a1;break L4077;break};case 161:{a[g]=a[g]&-17;a2=aV;a3=ba;a4=a1;break L4077;break};case 162:{a[l]=a[l]&-17;a2=aV;a3=ba;a4=a1;break L4077;break};case 163:{a[A]=a[A]&-17;a2=aV;a3=ba;a4=a1;break L4077;break};case 164:{a[n]=a[n]&-17;a2=aV;a3=ba;a4=a1;break L4077;break};case 165:{a[y]=a[y]&-17;a2=aV;a3=ba;a4=a1;break L4077;break};case 166:{a6=d[n]|0;bP=a6<<8|d[y];a_=a6>>>4;a6=c[f+17032+(a_<<2)>>2]|0;if((a6|0)==0){cu=kQ(h,bP,ba)|0}else{cu=d[a6+bP|0]|0}a6=cu&-17;a5=c[f+17096+(a_<<2)>>2]|0;if((a5|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a5+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 167:{a2=aV&-17;a3=ba;a4=a1;break L4077;break};case 168:{a[x]=a[x]&-33;a2=aV;a3=ba;a4=a1;break L4077;break};case 169:{a[g]=a[g]&-33;a2=aV;a3=ba;a4=a1;break L4077;break};case 170:{a[l]=a[l]&-33;a2=aV;a3=ba;a4=a1;break L4077;break};case 171:{a[A]=a[A]&-33;a2=aV;a3=ba;a4=a1;break L4077;break};case 172:{a[n]=a[n]&-33;a2=aV;a3=ba;a4=a1;break L4077;break};case 173:{a[y]=a[y]&-33;a2=aV;a3=ba;a4=a1;break L4077;break};case 174:{a6=d[n]|0;bP=a6<<8|d[y];a5=a6>>>4;a6=c[f+17032+(a5<<2)>>2]|0;if((a6|0)==0){cv=kQ(h,bP,ba)|0}else{cv=d[a6+bP|0]|0}a6=cv&-33;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a_+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 175:{a2=aV&-33;a3=ba;a4=a1;break L4077;break};case 176:{a[x]=a[x]&-65;a2=aV;a3=ba;a4=a1;break L4077;break};case 177:{a[g]=a[g]&-65;a2=aV;a3=ba;a4=a1;break L4077;break};case 178:{a[l]=a[l]&-65;a2=aV;a3=ba;a4=a1;break L4077;break};case 179:{a[A]=a[A]&-65;a2=aV;a3=ba;a4=a1;break L4077;break};case 180:{a[n]=a[n]&-65;a2=aV;a3=ba;a4=a1;break L4077;break};case 181:{a[y]=a[y]&-65;a2=aV;a3=ba;a4=a1;break L4077;break};case 182:{a6=d[n]|0;bP=a6<<8|d[y];a_=a6>>>4;a6=c[f+17032+(a_<<2)>>2]|0;if((a6|0)==0){cw=kQ(h,bP,ba)|0}else{cw=d[a6+bP|0]|0}a6=cw&-65;a5=c[f+17096+(a_<<2)>>2]|0;if((a5|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a5+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 183:{a2=aV&-65;a3=ba;a4=a1;break L4077;break};case 184:{a[x]=a[x]&127;a2=aV;a3=ba;a4=a1;break L4077;break};case 185:{a[g]=a[g]&127;a2=aV;a3=ba;a4=a1;break L4077;break};case 186:{a[l]=a[l]&127;a2=aV;a3=ba;a4=a1;break L4077;break};case 187:{a[A]=a[A]&127;a2=aV;a3=ba;a4=a1;break L4077;break};case 188:{a[n]=a[n]&127;a2=aV;a3=ba;a4=a1;break L4077;break};case 189:{a[y]=a[y]&127;a2=aV;a3=ba;a4=a1;break L4077;break};case 190:{a6=d[n]|0;bP=a6<<8|d[y];a5=a6>>>4;a6=c[f+17032+(a5<<2)>>2]|0;if((a6|0)==0){cx=kQ(h,bP,ba)|0}else{cx=d[a6+bP|0]|0}a6=cx&-129;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a_+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 191:{a2=aV&127;a3=ba;a4=a1;break L4077;break};case 192:{a[x]=a[x]|1;a2=aV;a3=ba;a4=a1;break L4077;break};case 193:{a[g]=a[g]|1;a2=aV;a3=ba;a4=a1;break L4077;break};case 194:{a[l]=a[l]|1;a2=aV;a3=ba;a4=a1;break L4077;break};case 195:{a[A]=a[A]|1;a2=aV;a3=ba;a4=a1;break L4077;break};case 196:{a[n]=a[n]|1;a2=aV;a3=ba;a4=a1;break L4077;break};case 197:{a[y]=a[y]|1;a2=aV;a3=ba;a4=a1;break L4077;break};case 198:{a6=d[n]|0;bP=a6<<8|d[y];a_=a6>>>4;a6=c[f+17032+(a_<<2)>>2]|0;if((a6|0)==0){cy=kQ(h,bP,ba)|0}else{cy=d[a6+bP|0]|0}a6=cy|1;a5=c[f+17096+(a_<<2)>>2]|0;if((a5|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a5+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 199:{a2=aV|1;a3=ba;a4=a1;break L4077;break};case 200:{a[x]=a[x]|2;a2=aV;a3=ba;a4=a1;break L4077;break};case 201:{a[g]=a[g]|2;a2=aV;a3=ba;a4=a1;break L4077;break};case 202:{a[l]=a[l]|2;a2=aV;a3=ba;a4=a1;break L4077;break};case 203:{a[A]=a[A]|2;a2=aV;a3=ba;a4=a1;break L4077;break};case 204:{a[n]=a[n]|2;a2=aV;a3=ba;a4=a1;break L4077;break};case 205:{a[y]=a[y]|2;a2=aV;a3=ba;a4=a1;break L4077;break};case 206:{a6=d[n]|0;bP=a6<<8|d[y];a5=a6>>>4;a6=c[f+17032+(a5<<2)>>2]|0;if((a6|0)==0){cz=kQ(h,bP,ba)|0}else{cz=d[a6+bP|0]|0}a6=cz|2;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a_+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 207:{a2=aV|2;a3=ba;a4=a1;break L4077;break};case 208:{a[x]=a[x]|4;a2=aV;a3=ba;a4=a1;break L4077;break};case 209:{a[g]=a[g]|4;a2=aV;a3=ba;a4=a1;break L4077;break};case 210:{a[l]=a[l]|4;a2=aV;a3=ba;a4=a1;break L4077;break};case 211:{a[A]=a[A]|4;a2=aV;a3=ba;a4=a1;break L4077;break};case 212:{a[n]=a[n]|4;a2=aV;a3=ba;a4=a1;break L4077;break};case 213:{a[y]=a[y]|4;a2=aV;a3=ba;a4=a1;break L4077;break};case 214:{a6=d[n]|0;bP=a6<<8|d[y];a_=a6>>>4;a6=c[f+17032+(a_<<2)>>2]|0;if((a6|0)==0){cA=kQ(h,bP,ba)|0}else{cA=d[a6+bP|0]|0}a6=cA|4;a5=c[f+17096+(a_<<2)>>2]|0;if((a5|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a5+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 215:{a2=aV|4;a3=ba;a4=a1;break L4077;break};case 216:{a[x]=a[x]|8;a2=aV;a3=ba;a4=a1;break L4077;break};case 217:{a[g]=a[g]|8;a2=aV;a3=ba;a4=a1;break L4077;break};case 218:{a[l]=a[l]|8;a2=aV;a3=ba;a4=a1;break L4077;break};case 219:{a[A]=a[A]|8;a2=aV;a3=ba;a4=a1;break L4077;break};case 220:{a[n]=a[n]|8;a2=aV;a3=ba;a4=a1;break L4077;break};case 221:{a[y]=a[y]|8;a2=aV;a3=ba;a4=a1;break L4077;break};case 222:{a6=d[n]|0;bP=a6<<8|d[y];a5=a6>>>4;a6=c[f+17032+(a5<<2)>>2]|0;if((a6|0)==0){cB=kQ(h,bP,ba)|0}else{cB=d[a6+bP|0]|0}a6=cB|8;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a_+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 223:{a2=aV|8;a3=ba;a4=a1;break L4077;break};case 224:{a[x]=a[x]|16;a2=aV;a3=ba;a4=a1;break L4077;break};case 225:{a[g]=a[g]|16;a2=aV;a3=ba;a4=a1;break L4077;break};case 226:{a[l]=a[l]|16;a2=aV;a3=ba;a4=a1;break L4077;break};case 227:{a[A]=a[A]|16;a2=aV;a3=ba;a4=a1;break L4077;break};case 228:{a[n]=a[n]|16;a2=aV;a3=ba;a4=a1;break L4077;break};case 229:{a[y]=a[y]|16;a2=aV;a3=ba;a4=a1;break L4077;break};case 230:{a6=d[n]|0;bP=a6<<8|d[y];a_=a6>>>4;a6=c[f+17032+(a_<<2)>>2]|0;if((a6|0)==0){cC=kQ(h,bP,ba)|0}else{cC=d[a6+bP|0]|0}a6=cC|16;a5=c[f+17096+(a_<<2)>>2]|0;if((a5|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a5+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 231:{a2=aV|16;a3=ba;a4=a1;break L4077;break};case 232:{a[x]=a[x]|32;a2=aV;a3=ba;a4=a1;break L4077;break};case 233:{a[g]=a[g]|32;a2=aV;a3=ba;a4=a1;break L4077;break};case 234:{a[l]=a[l]|32;a2=aV;a3=ba;a4=a1;break L4077;break};case 235:{a[A]=a[A]|32;a2=aV;a3=ba;a4=a1;break L4077;break};case 236:{a[n]=a[n]|32;a2=aV;a3=ba;a4=a1;break L4077;break};case 237:{a[y]=a[y]|32;a2=aV;a3=ba;a4=a1;break L4077;break};case 238:{a6=d[n]|0;bP=a6<<8|d[y];a5=a6>>>4;a6=c[f+17032+(a5<<2)>>2]|0;if((a6|0)==0){cD=kQ(h,bP,ba)|0}else{cD=d[a6+bP|0]|0}a6=cD|32;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a_+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 239:{a2=aV|32;a3=ba;a4=a1;break L4077;break};case 240:{a[x]=a[x]|64;a2=aV;a3=ba;a4=a1;break L4077;break};case 241:{a[g]=a[g]|64;a2=aV;a3=ba;a4=a1;break L4077;break};case 242:{a[l]=a[l]|64;a2=aV;a3=ba;a4=a1;break L4077;break};case 243:{a[A]=a[A]|64;a2=aV;a3=ba;a4=a1;break L4077;break};case 244:{a[n]=a[n]|64;a2=aV;a3=ba;a4=a1;break L4077;break};case 245:{a[y]=a[y]|64;a2=aV;a3=ba;a4=a1;break L4077;break};case 246:{a6=d[n]|0;bP=a6<<8|d[y];a_=a6>>>4;a6=c[f+17032+(a_<<2)>>2]|0;if((a6|0)==0){cE=kQ(h,bP,ba)|0}else{cE=d[a6+bP|0]|0}a6=cE|64;a5=c[f+17096+(a_<<2)>>2]|0;if((a5|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a5+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 247:{a2=aV|64;a3=ba;a4=a1;break L4077;break};case 248:{a[x]=a[x]|-128;a2=aV;a3=ba;a4=a1;break L4077;break};case 249:{a[g]=a[g]|-128;a2=aV;a3=ba;a4=a1;break L4077;break};case 250:{a[l]=a[l]|-128;a2=aV;a3=ba;a4=a1;break L4077;break};case 251:{a[A]=a[A]|-128;a2=aV;a3=ba;a4=a1;break L4077;break};case 252:{a[n]=a[n]|-128;a2=aV;a3=ba;a4=a1;break L4077;break};case 253:{a[y]=a[y]|-128;a2=aV;a3=ba;a4=a1;break L4077;break};case 254:{a6=d[n]|0;bP=a6<<8|d[y];a5=a6>>>4;a6=c[f+17032+(a5<<2)>>2]|0;if((a6|0)==0){cF=kQ(h,bP,ba)|0}else{cF=d[a6+bP|0]|0}a6=cF|128;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a_+bP|0]=a6&255}a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 255:{a2=aV|-128;a3=ba;a4=a1;break L4077;break};case 47:{a6=aV&255;c[z>>2]=a6<<8;bP=a6>>>1;c[B>>2]=bP;c[E>>2]=0;a2=(bP|a6&128)&255;a3=ba;a4=a1;break L4077;break};case 48:{c[E>>2]=0;c[z>>2]=0;a6=a[x]|0;c[B>>2]=a6&255;a[x]=a6<<4|(a6&255)>>>4;a2=aV;a3=ba;a4=a1;break L4077;break};case 49:{c[E>>2]=0;c[z>>2]=0;a6=a[g]|0;c[B>>2]=a6&255;a[g]=a6<<4|(a6&255)>>>4;a2=aV;a3=ba;a4=a1;break L4077;break};case 50:{c[E>>2]=0;c[z>>2]=0;a6=a[l]|0;c[B>>2]=a6&255;a[l]=a6<<4|(a6&255)>>>4;a2=aV;a3=ba;a4=a1;break L4077;break};case 51:{c[E>>2]=0;c[z>>2]=0;a6=a[A]|0;c[B>>2]=a6&255;a[A]=a6<<4|(a6&255)>>>4;a2=aV;a3=ba;a4=a1;break L4077;break};case 52:{c[E>>2]=0;c[z>>2]=0;a6=a[n]|0;c[B>>2]=a6&255;a[n]=a6<<4|(a6&255)>>>4;a2=aV;a3=ba;a4=a1;break L4077;break};case 53:{c[E>>2]=0;c[z>>2]=0;a6=a[y]|0;c[B>>2]=a6&255;a[y]=a6<<4|(a6&255)>>>4;a2=aV;a3=ba;a4=a1;break L4077;break};case 54:{a6=d[n]|0;bP=a6<<8|d[y];a_=a6>>>4;a6=c[f+17032+(a_<<2)>>2]|0;if((a6|0)==0){cG=kQ(h,bP,ba)|0}else{cG=d[a6+bP|0]|0}c[B>>2]=cG;a6=cG<<4|cG>>>4;a5=c[f+17096+(a_<<2)>>2]|0;if((a5|0)==0){kP(h,bP,a6&255,aU+12|0)}else{a[a5+bP|0]=a6&255}c[E>>2]=0;c[z>>2]=0;a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 55:{c[E>>2]=0;c[z>>2]=0;c[B>>2]=aV&255;a2=aV<<4|(aV&255)>>>4;a3=ba;a4=a1;break L4077;break};case 56:{a6=d[x]|0;c[z>>2]=a6<<8;bP=a6>>>1;c[B>>2]=bP;a[x]=bP&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 57:{bP=d[g]|0;c[z>>2]=bP<<8;a6=bP>>>1;c[B>>2]=a6;a[g]=a6&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 58:{a6=d[l]|0;c[z>>2]=a6<<8;bP=a6>>>1;c[B>>2]=bP;a[l]=bP&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 59:{bP=d[A]|0;c[z>>2]=bP<<8;a6=bP>>>1;c[B>>2]=a6;a[A]=a6&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 60:{a6=d[n]|0;c[z>>2]=a6<<8;bP=a6>>>1;c[B>>2]=bP;a[n]=bP&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 61:{bP=d[y]|0;c[z>>2]=bP<<8;a6=bP>>>1;c[B>>2]=a6;a[y]=a6&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 62:{a6=d[n]|0;bP=a6<<8|d[y];a5=a6>>>4;a6=c[f+17032+(a5<<2)>>2]|0;if((a6|0)==0){cH=kQ(h,bP,ba)|0}else{cH=d[a6+bP|0]|0}c[z>>2]=cH;a6=cH>>>1;c[B>>2]=a6;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,bP,a6,aU+12|0)}else{a[a_+bP|0]=a6&255}c[z>>2]=c[z>>2]<<8;c[E>>2]=0;a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 63:{a6=aV&255;c[z>>2]=a6<<8;bP=a6>>>1;c[B>>2]=bP;c[E>>2]=0;a2=bP&255;a3=ba;a4=a1;break L4077;break};case 64:{c[B>>2]=a[x]&1;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 65:{c[B>>2]=a[g]&1;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 66:{c[B>>2]=a[l]&1;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 67:{c[B>>2]=a[A]&1;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 68:{c[B>>2]=a[n]&1;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 31:{bP=c[z>>2]&256;a6=aV&255;c[z>>2]=a6<<8;a_=(bP|a6)>>>1;c[B>>2]=a_;c[E>>2]=0;a2=a_&255;a3=ba;a4=a1;break L4077;break};case 32:{a_=d[x]<<1;c[z>>2]=a_;c[B>>2]=a_;a[x]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 33:{a_=d[g]<<1;c[z>>2]=a_;c[B>>2]=a_;a[g]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 34:{a_=d[l]<<1;c[z>>2]=a_;c[B>>2]=a_;a[l]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 35:{a_=d[A]<<1;c[z>>2]=a_;c[B>>2]=a_;a[A]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 36:{a_=d[n]<<1;c[z>>2]=a_;c[B>>2]=a_;a[n]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 37:{a_=d[y]<<1;c[z>>2]=a_;c[B>>2]=a_;a[y]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 38:{a_=d[n]|0;a6=a_<<8|d[y];bP=a_>>>4;a_=c[f+17032+(bP<<2)>>2]|0;if((a_|0)==0){cI=kQ(h,a6,ba)|0}else{cI=d[a_+a6|0]|0}a_=cI<<1;c[z>>2]=a_;c[B>>2]=a_;a5=c[f+17096+(bP<<2)>>2]|0;if((a5|0)==0){kP(h,a6,a_&254,aU+12|0)}else{a[a5+a6|0]=a_&255}c[E>>2]=0;a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 39:{a_=(aV&255)<<1;c[z>>2]=a_;c[B>>2]=a_;c[E>>2]=0;a2=a_&255;a3=ba;a4=a1;break L4077;break};case 40:{a_=d[x]|0;c[z>>2]=a_<<8;a6=a_>>>1;c[B>>2]=a6;a[x]=(a_&128|a6)&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 41:{a6=d[g]|0;c[z>>2]=a6<<8;a_=a6>>>1;c[B>>2]=a_;a[g]=(a6&128|a_)&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 42:{a_=d[l]|0;c[z>>2]=a_<<8;a6=a_>>>1;c[B>>2]=a6;a[l]=(a_&128|a6)&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 43:{a6=d[A]|0;c[z>>2]=a6<<8;a_=a6>>>1;c[B>>2]=a_;a[A]=(a6&128|a_)&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 44:{a_=d[n]|0;c[z>>2]=a_<<8;a6=a_>>>1;c[B>>2]=a6;a[n]=(a_&128|a6)&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 45:{a6=d[y]|0;c[z>>2]=a6<<8;a_=a6>>>1;c[B>>2]=a_;a[y]=(a6&128|a_)&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 46:{a_=d[n]|0;a6=a_<<8|d[y];a5=a_>>>4;a_=c[f+17032+(a5<<2)>>2]|0;if((a_|0)==0){cJ=kQ(h,a6,ba)|0}else{cJ=d[a_+a6|0]|0}c[z>>2]=cJ;a_=cJ>>>1;c[B>>2]=a_;bP=cJ&128|a_;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,a6,bP,aU+12|0)}else{a[a_+a6|0]=bP&255}c[z>>2]=c[z>>2]<<8;c[E>>2]=0;a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 15:{bP=aV&255;c[B>>2]=bP;a6=bP<<8;c[z>>2]=a6;c[E>>2]=0;a2=(a6|bP)>>>1&255;a3=ba;a4=a1;break L4077;break};case 16:{bP=(c[z>>2]|0)>>>8&1;a6=d[x]<<1;c[z>>2]=a6;a_=a6|bP;c[B>>2]=a_;a[x]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 17:{a_=(c[z>>2]|0)>>>8&1;bP=d[g]<<1;c[z>>2]=bP;a6=bP|a_;c[B>>2]=a6;a[g]=a6&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 18:{a6=(c[z>>2]|0)>>>8&1;a_=d[l]<<1;c[z>>2]=a_;bP=a_|a6;c[B>>2]=bP;a[l]=bP&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 19:{bP=(c[z>>2]|0)>>>8&1;a6=d[A]<<1;c[z>>2]=a6;a_=a6|bP;c[B>>2]=a_;a[A]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 20:{a_=(c[z>>2]|0)>>>8&1;bP=d[n]<<1;c[z>>2]=bP;a6=bP|a_;c[B>>2]=a6;a[n]=a6&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 21:{a6=(c[z>>2]|0)>>>8&1;a_=d[y]<<1;c[z>>2]=a_;bP=a_|a6;c[B>>2]=bP;a[y]=bP&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 22:{bP=d[n]|0;a6=bP<<8|d[y];a_=(c[z>>2]|0)>>>8&1;a5=bP>>>4;bP=c[f+17032+(a5<<2)>>2]|0;if((bP|0)==0){cK=kQ(h,a6,ba)|0}else{cK=d[bP+a6|0]|0}bP=cK<<1;c[z>>2]=bP;cL=bP|a_;c[B>>2]=cL;a_=c[f+17096+(a5<<2)>>2]|0;if((a_|0)==0){kP(h,a6,cL&255,aU+12|0)}else{a[a_+a6|0]=cL&255}c[E>>2]=0;a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 23:{cL=(c[z>>2]|0)>>>8&1;a6=(aV&255)<<1;c[z>>2]=a6;a_=cL|a6;c[B>>2]=a_;c[E>>2]=0;a2=a_&255;a3=ba;a4=a1;break L4077;break};case 24:{a_=c[z>>2]&256;a6=d[x]|0;c[z>>2]=a6<<8;cL=(a6|a_)>>>1;c[B>>2]=cL;a[x]=cL&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 25:{cL=c[z>>2]&256;a_=d[g]|0;c[z>>2]=a_<<8;a6=(a_|cL)>>>1;c[B>>2]=a6;a[g]=a6&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 26:{a6=c[z>>2]&256;cL=d[l]|0;c[z>>2]=cL<<8;a_=(cL|a6)>>>1;c[B>>2]=a_;a[l]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 27:{a_=c[z>>2]&256;a6=d[A]|0;c[z>>2]=a6<<8;cL=(a6|a_)>>>1;c[B>>2]=cL;a[A]=cL&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 28:{cL=c[z>>2]&256;a_=d[n]|0;c[z>>2]=a_<<8;a6=(a_|cL)>>>1;c[B>>2]=a6;a[n]=a6&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 29:{a6=c[z>>2]&256;cL=d[y]|0;c[z>>2]=cL<<8;a_=(cL|a6)>>>1;c[B>>2]=a_;a[y]=a_&255;c[E>>2]=0;a2=aV;a3=ba;a4=a1;break L4077;break};case 30:{a_=d[n]|0;a6=a_<<8|d[y];cL=a_>>>4;a_=c[f+17032+(cL<<2)>>2]|0;if((a_|0)==0){cM=kQ(h,a6,ba)|0}else{cM=d[a_+a6|0]|0}a_=c[z>>2]&256;c[z>>2]=cM<<8;a5=(a_|cM)>>>1;c[B>>2]=a5;a_=c[f+17096+(cL<<2)>>2]|0;if((a_|0)==0){kP(h,a6,a5,aU+12|0)}else{a[a_+a6|0]=a5&255}c[E>>2]=0;a2=aV;a3=aU+16|0;a4=a1;break L4077;break};case 69:{c[B>>2]=a[y]&1;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 70:{a5=d[n]|0;a6=a5<<8|d[y];a_=c[f+17032+(a5>>>4<<2)>>2]|0;if((a_|0)==0){cN=kQ(h,a6,ba)|0}else{cN=d[a_+a6|0]|0}c[B>>2]=cN&1;c[E>>2]=512;a2=aV;a3=aU+12|0;a4=a1;break L4077;break};case 71:{c[B>>2]=aV&1;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 72:{c[B>>2]=a[x]&2;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 73:{c[B>>2]=a[g]&2;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 74:{c[B>>2]=a[l]&2;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 75:{c[B>>2]=a[A]&2;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 76:{c[B>>2]=a[n]&2;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 77:{c[B>>2]=a[y]&2;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 78:{a6=d[n]|0;a_=a6<<8|d[y];a5=c[f+17032+(a6>>>4<<2)>>2]|0;if((a5|0)==0){cO=kQ(h,a_,ba)|0}else{cO=d[a5+a_|0]|0}c[B>>2]=cO&2;c[E>>2]=512;a2=aV;a3=aU+12|0;a4=a1;break L4077;break};case 79:{c[B>>2]=aV&2;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 80:{c[B>>2]=a[x]&4;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 81:{c[B>>2]=a[g]&4;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 82:{c[B>>2]=a[l]&4;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 83:{c[B>>2]=a[A]&4;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 84:{c[B>>2]=a[n]&4;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 85:{c[B>>2]=a[y]&4;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 86:{a_=d[n]|0;a5=a_<<8|d[y];a6=c[f+17032+(a_>>>4<<2)>>2]|0;if((a6|0)==0){cP=kQ(h,a5,ba)|0}else{cP=d[a6+a5|0]|0}c[B>>2]=cP&4;c[E>>2]=512;a2=aV;a3=aU+12|0;a4=a1;break L4077;break};case 87:{c[B>>2]=aV&4;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 88:{c[B>>2]=a[x]&8;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 89:{c[B>>2]=a[g]&8;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 90:{c[B>>2]=a[l]&8;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 91:{c[B>>2]=a[A]&8;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 92:{c[B>>2]=a[n]&8;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 93:{c[B>>2]=a[y]&8;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 94:{a5=d[n]|0;a6=a5<<8|d[y];a_=c[f+17032+(a5>>>4<<2)>>2]|0;if((a_|0)==0){cQ=kQ(h,a6,ba)|0}else{cQ=d[a_+a6|0]|0}c[B>>2]=cQ&8;c[E>>2]=512;a2=aV;a3=aU+12|0;a4=a1;break L4077;break};case 95:{c[B>>2]=aV&8;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};case 96:{c[B>>2]=a[x]&16;c[E>>2]=512;a2=aV;a3=ba;a4=a1;break L4077;break};default:{a2=aV;a3=ba;a4=a1;break L4077}}break};case 102:{a1=d[n]|0;ba=a1<<8|d[y];a6=c[f+17032+(a1>>>4<<2)>>2]|0;if((a6|0)==0){cR=(kQ(h,ba,aZ)|0)&255}else{cR=a[a6+ba|0]|0}a[n]=cR;a2=aV;a3=aU+8|0;a4=a0;break};case 103:{a[n]=aV;a2=aV;a3=aZ;a4=a0;break};case 104:{a[y]=a[x]|0;a2=aV;a3=aZ;a4=a0;break};case 105:{a[y]=a[g]|0;a2=aV;a3=aZ;a4=a0;break};case 106:{a[y]=a[l]|0;a2=aV;a3=aZ;a4=a0;break};case 107:{a[y]=a[A]|0;a2=aV;a3=aZ;a4=a0;break};case 108:{a[y]=a[n]|0;a2=aV;a3=aZ;a4=a0;break};case 110:{ba=d[n]|0;a6=ba<<8|d[y];a1=c[f+17032+(ba>>>4<<2)>>2]|0;if((a1|0)==0){cS=(kQ(h,a6,aZ)|0)&255}else{cS=a[a1+a6|0]|0}a[y]=cS;a2=aV;a3=aU+8|0;a4=a0;break};case 111:{a[y]=aV;a2=aV;a3=aZ;a4=a0;break};case 112:{a6=d[n]|0;a1=a6<<8|d[y];ba=a[x]|0;a_=c[f+17096+(a6>>>4<<2)>>2]|0;if((a_|0)==0){kP(h,a1,ba&255,aZ)}else{a[a_+a1|0]=ba}a2=aV;a3=aU+8|0;a4=a0;break};case 113:{ba=d[n]|0;a1=ba<<8|d[y];a_=a[g]|0;a6=c[f+17096+(ba>>>4<<2)>>2]|0;if((a6|0)==0){kP(h,a1,a_&255,aZ)}else{a[a6+a1|0]=a_}a2=aV;a3=aU+8|0;a4=a0;break};case 114:{a_=d[n]|0;a1=a_<<8|d[y];a6=a[l]|0;ba=c[f+17096+(a_>>>4<<2)>>2]|0;if((ba|0)==0){kP(h,a1,a6&255,aZ)}else{a[ba+a1|0]=a6}a2=aV;a3=aU+8|0;a4=a0;break};case 27:{a6=(d[A]|0)-1|0;a[A]=a6&255;a[l]=(d[l]|0)-(a6>>>8&1)&255;a2=aV;a3=aU+8|0;a4=a0;break};case 28:{a6=d[A]|0;c[E>>2]=a6|2048;a1=a6+1|0;c[B>>2]=a1;a[A]=a1&255;a2=aV;a3=aZ;a4=a0;break};case 32:{if((c[B>>2]&255|0)==0){a2=aV;a3=aU+8|0;a4=a0+1&65535;break L4077}a1=a0&65535;a6=c[f+17032+(a1>>>12<<2)>>2]|0;if((a6|0)==0){cT=kQ(h,a1,aZ)|0}else{cT=d[a6+a1|0]|0}a2=aV;a3=aU+12|0;a4=a1+65409+(cT^128)&65535;break};case 115:{a1=d[n]|0;a6=a1<<8|d[y];ba=a[A]|0;a_=c[f+17096+(a1>>>4<<2)>>2]|0;if((a_|0)==0){kP(h,a6,ba&255,aZ)}else{a[a_+a6|0]=ba}a2=aV;a3=aU+8|0;a4=a0;break};case 116:{ba=a[n]|0;a6=ba&255;a_=a6<<8|d[y];a1=c[f+17096+(a6>>>4<<2)>>2]|0;if((a1|0)==0){kP(h,a_,a6,aZ)}else{a[a1+a_|0]=ba}a2=aV;a3=aU+8|0;a4=a0;break};case 117:{ba=d[n]|0;a_=a[y]|0;a1=a_&255;a6=ba<<8|a1;a5=c[f+17096+(ba>>>4<<2)>>2]|0;if((a5|0)==0){kP(h,a6,a1,aZ)}else{a[a5+a6|0]=a_}a2=aV;a3=aU+8|0;a4=a0;break};case 118:{a_=a[s]|0;do{if((a_&1)==0){if((c[O>>2]|0)!=-1){kO(h,aZ)}kM(h,aZ);a6=c[P>>2]|0;a[Q]=a6&255;if((a6&31&d[D]|0)==0){cU=a[s]|0;break}if((a[H]&1)==0){a[r]=1;a2=aV;a3=aZ;a4=a0;break L4077}else{a2=aV;a3=aU+8|0;a4=a0;break L4077}}else{cU=a_}}while(0);a[s]=cU|2;if((c[R>>2]&c[P>>2]|0)==0){cV=c[p>>2]|0}else{a_=c[S>>2]|0;c[I>>2]=a_;c[J>>2]=8;c[K>>2]=8;c[L>>2]=8;a6=c[M>>2]|0;a5=(c[f+16912+(a6<<2)>>2]|0)>>>0<a_>>>0?a6:8;c[N>>2]=a5;a6=c[f+16912+(a5<<2)>>2]|0;c[p>>2]=a6;cV=a6}if(aZ>>>0>=cV>>>0){a2=aV;a3=aZ;a4=a0;break L4077}a2=aV;a3=(aZ-cV&3)+cV|0;a4=a0;break};case 57:{a6=e[o>>1]|0;a5=a6+(d[y]|0)|0;a[y]=a5&255;a_=d[n]|0;c[C>>2]=a_;c[E>>2]=(a5^a6)&256|a6>>>8;a6=(a5>>>8)+a_|0;c[z>>2]=a6;a[n]=a6&255;a2=aV;a3=aU+8|0;a4=a0;break};case 58:{a6=d[n]|0;a_=a6<<8|d[y];a5=c[f+17032+(a6>>>4<<2)>>2]|0;if((a5|0)==0){cW=(kQ(h,a_,aZ)|0)&255}else{cW=a[a5+a_|0]|0}a5=a_+65535|0;a[y]=a5&255;a[n]=a5>>>8&255;a2=cW;a3=aU+8|0;a4=a0;break};case 59:{b[o>>1]=(b[o>>1]|0)-1&65535;a2=aV;a3=aU+8|0;a4=a0;break};case 60:{a5=aV&255;c[E>>2]=a5|2048;a_=a5+1|0;c[B>>2]=a_;a2=a_&255;a3=aZ;a4=a0;break};case 61:{a_=aV&255;c[E>>2]=a_|3072;a5=a_-1|0;c[B>>2]=a5;a2=a5&255;a3=aZ;a4=a0;break};case 62:{a5=a0&65535;a_=c[f+17032+(a5>>>12<<2)>>2]|0;if((a_|0)==0){cX=(kQ(h,a5,aZ)|0)&255}else{cX=a[a_+a5|0]|0}a2=cX;a3=aU+8|0;a4=a0+1&65535;break};case 19:{a5=(d[A]|0)+1|0;a[A]=a5&255;a[l]=(a5>>>8)+(d[l]|0)&255;a2=aV;a3=aU+8|0;a4=a0;break};case 20:{a5=d[l]|0;c[E>>2]=a5|2048;a_=a5+1|0;c[B>>2]=a_;a[l]=a_&255;a2=aV;a3=aZ;a4=a0;break};case 191:{c[B>>2]=0;c[z>>2]=0;c[E>>2]=1024;a2=aV;a3=aZ;a4=a0;break};case 192:{a_=aU+8|0;if((c[B>>2]&255|0)==0){a2=aV;a3=a_;a4=a0;break L4077}a5=b[o>>1]|0;a6=a5&65535;a1=c[f+17032+(a6>>>12<<2)>>2]|0;if((a1|0)==0){ba=kQ(h,a6,a_)|0;cY=ba;cZ=b[o>>1]|0}else{cY=d[a1+a6|0]|0;cZ=a5}a5=(cZ&65535)+1|0;a6=a5&65535;b[o>>1]=a6;a1=a5&65535;a5=c[f+17032+(a1>>>12<<2)>>2]|0;if((a5|0)==0){ba=kQ(h,a1,aU+12|0)|0;c_=ba;c$=b[o>>1]|0}else{c_=d[a5+a1|0]|0;c$=a6}b[o>>1]=c$+1&65535;a2=aV;a3=aU+20|0;a4=(c_<<8|cY)&65535;break};case 193:{a6=b[o>>1]|0;a1=a6&65535;a5=c[f+17032+(a1>>>12<<2)>>2]|0;if((a5|0)==0){ba=(kQ(h,a1,aZ)|0)&255;c0=ba;c1=b[o>>1]|0}else{c0=a[a5+a1|0]|0;c1=a6}a[g]=c0;a6=(c1&65535)+1|0;a1=a6&65535;b[o>>1]=a1;a5=a6&65535;a6=c[f+17032+(a5>>>12<<2)>>2]|0;if((a6|0)==0){ba=(kQ(h,a5,aU+8|0)|0)&255;c2=ba;c3=b[o>>1]|0}else{c2=a[a6+a5|0]|0;c3=a1}a[x]=c2;b[o>>1]=c3+1&65535;a2=aV;a3=aU+12|0;a4=a0;break};case 194:{if((c[B>>2]&255|0)==0){a2=aV;a3=aU+12|0;a4=a0+2&65535;break L4077}a1=a0&65535;a5=c[f+17032+(a1>>>12<<2)>>2]|0;if((a5|0)==0){c4=kQ(h,a1,aZ)|0}else{c4=d[a5+a1|0]|0}a5=a1+1&65535;a1=c[f+17032+(a5>>>12<<2)>>2]|0;if((a1|0)==0){c5=kQ(h,a5,aU+8|0)|0}else{c5=d[a1+a5|0]|0}a2=aV;a3=aU+16|0;a4=(c5<<8|c4)&65535;break};case 195:{a5=a0&65535;a1=c[f+17032+(a5>>>12<<2)>>2]|0;if((a1|0)==0){c6=kQ(h,a5,aZ)|0}else{c6=d[a1+a5|0]|0}a1=a5+1&65535;a5=c[f+17032+(a1>>>12<<2)>>2]|0;if((a5|0)==0){c7=kQ(h,a1,aU+8|0)|0}else{c7=d[a5+a1|0]|0}a2=aV;a3=aU+16|0;a4=(c7<<8|c6)&65535;break};case 21:{a1=d[l]|0;c[E>>2]=a1|3072;a5=a1-1|0;c[B>>2]=a5;a[l]=a5&255;a2=aV;a3=aZ;a4=a0;break};case 22:{a5=a0&65535;a1=c[f+17032+(a5>>>12<<2)>>2]|0;if((a1|0)==0){c8=(kQ(h,a5,aZ)|0)&255}else{c8=a[a1+a5|0]|0}a[l]=c8;a2=aV;a3=aU+8|0;a4=a0+1&65535;break};case 23:{a5=(c[z>>2]|0)>>>8&1;a1=(aV&255)<<1;c[z>>2]=a1;c[E>>2]=0;c[B>>2]=1;a2=(a5|a1)&255;a3=aZ;a4=a0;break};case 24:{a1=a0&65535;a5=c[f+17032+(a1>>>12<<2)>>2]|0;if((a5|0)==0){c9=kQ(h,a1,aZ)|0}else{c9=d[a5+a1|0]|0}a2=aV;a3=aU+12|0;a4=a1+65409+(c9^128)&65535;break};case 25:{a1=(d[A]|0)+(d[y]|0)|0;a[y]=a1&255;a5=d[n]|0;c[C>>2]=a5;a6=d[l]|0;c[E>>2]=a6|a1&256;ba=(a1>>>8)+a5+a6|0;c[z>>2]=ba;a[n]=ba&255;a2=aV;a3=aU+8|0;a4=a0;break};case 33:{ba=a0&65535;a6=c[f+17032+(ba>>>12<<2)>>2]|0;if((a6|0)==0){da=(kQ(h,ba,aZ)|0)&255}else{da=a[a6+ba|0]|0}a[y]=da;a6=ba+1&65535;ba=c[f+17032+(a6>>>12<<2)>>2]|0;if((ba|0)==0){db=(kQ(h,a6,aU+8|0)|0)&255}else{db=a[ba+a6|0]|0}a[n]=db;a2=aV;a3=aU+12|0;a4=a0+2&65535;break};case 31:{a6=c[z>>2]&256;ba=aV&255;c[z>>2]=ba<<8;c[E>>2]=0;c[B>>2]=1;a2=(a6|ba)>>>1&255;a3=aZ;a4=a0;break};case 26:{ba=d[l]|0;a6=ba<<8|d[A];a5=c[f+17032+(ba>>>4<<2)>>2]|0;if((a5|0)==0){dc=(kQ(h,a6,aZ)|0)&255}else{dc=a[a5+a6|0]|0}a2=dc;a3=aU+8|0;a4=a0;break};case 2:{a6=d[x]|0;a5=a6<<8|d[g];ba=c[f+17096+(a6>>>4<<2)>>2]|0;if((ba|0)==0){kP(h,a5,aV&255,aZ)}else{a[ba+a5|0]=aV}a2=aV;a3=aU+8|0;a4=a0;break};case 3:{a5=(d[g]|0)+1|0;a[g]=a5&255;a[x]=(a5>>>8)+(d[x]|0)&255;a2=aV;a3=aU+8|0;a4=a0;break};case 4:{a5=d[x]|0;c[E>>2]=a5|2048;ba=a5+1|0;c[B>>2]=ba;a[x]=ba&255;a2=aV;a3=aZ;a4=a0;break};case 5:{ba=d[x]|0;c[E>>2]=ba|3072;a5=ba-1|0;c[B>>2]=a5;a[x]=a5&255;a2=aV;a3=aZ;a4=a0;break};case 6:{a5=a0&65535;ba=c[f+17032+(a5>>>12<<2)>>2]|0;if((ba|0)==0){dd=(kQ(h,a5,aZ)|0)&255}else{dd=a[ba+a5|0]|0}a[x]=dd;a2=aV;a3=aU+8|0;a4=a0+1&65535;break};case 7:{a5=aV&255;ba=a5<<1;c[z>>2]=ba;c[E>>2]=0;c[B>>2]=1;a2=(ba|a5>>>7)&255;a3=aZ;a4=a0;break};case 8:{a5=a0&65535;ba=c[f+17032+(a5>>>12<<2)>>2]|0;if((ba|0)==0){de=kQ(h,a5,aZ)|0}else{de=d[ba+a5|0]|0}ba=a5+1&65535;a5=c[f+17032+(ba>>>12<<2)>>2]|0;if((a5|0)==0){df=kQ(h,ba,aU+8|0)|0}else{df=d[a5+ba|0]|0}ba=df<<8|de;a5=b[o>>1]|0;a6=c[f+17096+(ba>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,ba,a5&255,aU+12|0)}else{a[a6+ba|0]=a5&255}a5=ba+1&65535;ba=(e[o>>1]|0)>>>8;a6=c[f+17096+(a5>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,a5,ba,aU+16|0)}else{a[a6+a5|0]=ba&255}a2=aV;a3=aU+20|0;a4=a0+2&65535;break};case 9:{ba=(d[g]|0)+(d[y]|0)|0;a[y]=ba&255;a5=d[n]|0;c[C>>2]=a5;a6=d[x]|0;c[E>>2]=a6|ba&256;a1=(ba>>>8)+a5+a6|0;c[z>>2]=a1;a[n]=a1&255;a2=aV;a3=aU+8|0;a4=a0;break};case 10:{a1=d[x]|0;a6=a1<<8|d[g];a5=c[f+17032+(a1>>>4<<2)>>2]|0;if((a5|0)==0){dg=(kQ(h,a6,aZ)|0)&255}else{dg=a[a5+a6|0]|0}a2=dg;a3=aU+8|0;a4=a0;break};case 11:{a6=(d[g]|0)-1|0;a[g]=a6&255;a[x]=(d[x]|0)-(a6>>>8&1)&255;a2=aV;a3=aU+8|0;a4=a0;break};case 12:{a6=d[g]|0;c[E>>2]=a6|2048;a5=a6+1|0;c[B>>2]=a5;a[g]=a5&255;a2=aV;a3=aZ;a4=a0;break};case 13:{a5=d[g]|0;c[E>>2]=a5|3072;a6=a5-1|0;c[B>>2]=a6;a[g]=a6&255;a2=aV;a3=aZ;a4=a0;break};case 14:{a6=a0&65535;a5=c[f+17032+(a6>>>12<<2)>>2]|0;if((a5|0)==0){dh=(kQ(h,a6,aZ)|0)&255}else{dh=a[a5+a6|0]|0}a[g]=dh;a2=aV;a3=aU+8|0;a4=a0+1&65535;break};case 15:{a6=aV&255;a5=a6<<8|a6;c[z>>2]=a5;c[E>>2]=0;c[B>>2]=1;a2=a5>>>1&255;a3=aZ;a4=a0;break};case 16:{a5=a0+1&65535;a6=a[m]&1;a1=(4<<a6)+aZ|0;do{if((a[T]&1&a[H])<<24>>24!=0){kS(Y,a1,a6);do{if((a[_]|0)>-1){di=0}else{ba=c[av>>2]|0;if(ba>>>0<=a1>>>0){a_=ba;do{ba=c[$>>2]|0;cL=a[m]&1;bP=(a_-ba|0)>>>(cL>>>0);c[$>>2]=(bP<<cL)+ba;ba=bP+(c[aj>>2]|0)|0;c[aj>>2]=ba;if((ba|0)>-1){ba=c[aN>>2]|0;if((ba|0)==0){dj=566992}else{dj=ba+((ag(c[aP>>2]|0,d[aa]|0)|0)<<2)|0}c[aO>>2]=dj;f2[c[c[ai>>2]>>2]&1023](an)}oY(Z);a_=c[av>>2]|0;}while(a_>>>0<=a1>>>0)}a_=c[$>>2]|0;ba=a[m]&1;bP=(a1-a_|0)>>>(ba>>>0);c[$>>2]=(bP<<ba)+a_;a_=bP+(c[aj>>2]|0)|0;c[aj>>2]=a_;if((a_|0)>-1){a_=c[aN>>2]|0;if((a_|0)==0){dk=566992}else{dk=a_+((ag(c[aP>>2]|0,d[aa]|0)|0)<<2)|0}c[aO>>2]=dk;f2[c[c[ai>>2]>>2]&1023](an)}if((a[_]|0)>=0){di=0;break}di=((d[aa]|0)*456|0)+456-(((c[ab>>2]|0)-(c[$>>2]|0)|0)>>>((a[m]&1)>>>0))|0}}while(0);qC(ac,a1);a_=a[m]&1^1;a[m]=a_;bP=a_&255;b[ad>>1]=456<<bP&65535;a_=c[$>>2]|0;ba=(di>>>0)/456|0;a[aa]=ba&255;c[ab>>2]=(456-di+((ba&255)*456|0)<<bP)+a_;qC(ac,a1);a_=c[af>>2]|0;bP=a[a_+7|0]&1;ba=459-(((c[a_>>2]|0)-(c[ae>>2]|0)|0)>>>(bP>>>0))-(-bP&3)|0;bP=ba>>>0>455?ba-456|0:ba;a[ah]=bP>>>0>80?80:bP&255;bP=c[ai>>2]|0;do{if((bP|0)==84312|(bP|0)==84296){ba=c[aj>>2]|0;if((a[m]&1)==0){c[aj>>2]=ba+3;break}else{c[aj>>2]=ba-3;break}}}while(0);do{if((a[_]|0)<=-1){ba=c[$>>2]|0;a_=ga[c[bP+4>>2]&127](an,167,-(c[aj>>2]|0)|0)|0;c[ao>>2]=(a_<<(a[m]&1))+ba;pA(ap,aq,a1);ba=c[ar>>2]|0;c[as>>2]=ba;a_=(c[at>>2]|0)>>>0>=ba>>>0|0;c[au>>2]=a_;c[av>>2]=c[f+19560+(a_<<2)>>2];a_=(80<<(a[m]&1))+ba|0;cL=e[ad>>1]|0;dl=a_-((a_-a1|0)>>>0>cL>>>0?cL:0)|0;c[aw>>2]=dl;cL=(c[ax>>2]|0)>>>0>dl>>>0?4:5;c[ay>>2]=cL;dl=c[az>>2]|0;a_=(c[f+19580+(cL<<2)>>2]|0)>>>0<(c[f+19580+(dl<<2)>>2]|0)>>>0?cL:dl;c[aA>>2]=a_;dl=c[aB>>2]|0;cL=(c[f+19580+(dl<<2)>>2]|0)>>>0<(c[f+19580+(a_<<2)>>2]|0)>>>0?dl:a_;c[aC>>2]=cL;a_=c[f+19580+(cL<<2)>>2]|0;c[aD>>2]=a_;c[at>>2]=a_;cL=ba>>>0<=a_>>>0|0;c[au>>2]=cL;c[av>>2]=c[f+19560+(cL<<2)>>2];cL=c[aE>>2]|0;c[cL+28>>2]=a_;ba=(c[cL+24>>2]|0)>>>0<a_>>>0?6:7;c[cL+96>>2]=ba;a_=c[cL+92>>2]|0;dl=(c[cL+(a_<<2)>>2]|0)>>>0<(c[cL+(ba<<2)>>2]|0)>>>0?a_:ba;c[cL+76>>2]=dl;ba=c[cL+72>>2]|0;a_=(c[cL+(ba<<2)>>2]|0)>>>0<(c[cL+(dl<<2)>>2]|0)>>>0?ba:dl;c[cL+64>>2]=a_;dl=c[cL+68>>2]|0;ba=(c[cL+(a_<<2)>>2]|0)>>>0<(c[cL+(dl<<2)>>2]|0)>>>0?a_:dl;c[cL+60>>2]=ba;c[cL+36>>2]=c[cL+(ba<<2)>>2];ba=c[aF>>2]|0;c[aG>>2]=ba;cL=(c[al>>2]|0)>>>0<ba>>>0?2:3;c[aH>>2]=cL;ba=c[aI>>2]|0;dl=(c[f+19580+(ba<<2)>>2]|0)>>>0<(c[f+19580+(cL<<2)>>2]|0)>>>0?ba:cL;c[aB>>2]=dl;cL=c[aA>>2]|0;ba=(c[f+19580+(dl<<2)>>2]|0)>>>0<(c[f+19580+(cL<<2)>>2]|0)>>>0?dl:cL;c[aC>>2]=ba;cL=c[f+19580+(ba<<2)>>2]|0;c[aD>>2]=cL;c[at>>2]=cL;ba=(c[as>>2]|0)>>>0<=cL>>>0|0;c[au>>2]=ba;c[av>>2]=c[f+19560+(ba<<2)>>2];ba=c[aE>>2]|0;c[ba+28>>2]=cL;dl=(c[ba+24>>2]|0)>>>0<cL>>>0?6:7;c[ba+96>>2]=dl;cL=c[ba+92>>2]|0;a_=(c[ba+(cL<<2)>>2]|0)>>>0<(c[ba+(dl<<2)>>2]|0)>>>0?cL:dl;c[ba+76>>2]=a_;dl=c[ba+72>>2]|0;cL=(c[ba+(dl<<2)>>2]|0)>>>0<(c[ba+(a_<<2)>>2]|0)>>>0?dl:a_;c[ba+64>>2]=cL;a_=c[ba+68>>2]|0;dl=(c[ba+(cL<<2)>>2]|0)>>>0<(c[ba+(a_<<2)>>2]|0)>>>0?cL:a_;c[ba+60>>2]=dl;c[ba+36>>2]=c[ba+(dl<<2)>>2];dl=a[m]&1;ba=(((153-(d[aa]|0)|0)*456|0)+65664<<dl)+(c[ar>>2]|0)|0;a_=70224<<dl;dl=ba-((ba-a1|0)>>>0>a_>>>0?a_:0)|0;c[al>>2]=dl;a_=(c[aG>>2]|0)>>>0>dl>>>0?2:3;c[aH>>2]=a_;dl=c[aI>>2]|0;ba=(c[f+19580+(dl<<2)>>2]|0)>>>0<(c[f+19580+(a_<<2)>>2]|0)>>>0?dl:a_;c[aB>>2]=ba;a_=c[aA>>2]|0;dl=(c[f+19580+(ba<<2)>>2]|0)>>>0<(c[f+19580+(a_<<2)>>2]|0)>>>0?ba:a_;c[aC>>2]=dl;a_=c[f+19580+(dl<<2)>>2]|0;c[aD>>2]=a_;c[at>>2]=a_;dl=(c[as>>2]|0)>>>0<=a_>>>0|0;c[au>>2]=dl;c[av>>2]=c[f+19560+(dl<<2)>>2];dl=c[aE>>2]|0;c[dl+28>>2]=a_;ba=(c[dl+24>>2]|0)>>>0<a_>>>0?6:7;c[dl+96>>2]=ba;a_=c[dl+92>>2]|0;cL=(c[dl+(a_<<2)>>2]|0)>>>0<(c[dl+(ba<<2)>>2]|0)>>>0?a_:ba;c[dl+76>>2]=cL;ba=c[dl+72>>2]|0;a_=(c[dl+(ba<<2)>>2]|0)>>>0<(c[dl+(cL<<2)>>2]|0)>>>0?ba:cL;c[dl+64>>2]=a_;cL=c[dl+68>>2]|0;ba=(c[dl+(a_<<2)>>2]|0)>>>0<(c[dl+(cL<<2)>>2]|0)>>>0?a_:cL;c[dl+60>>2]=ba;c[dl+36>>2]=c[dl+(ba<<2)>>2];ba=d[aJ]|0;if((ba&32|0)==0){dm=-1}else{dl=(c[ar>>2]|0)-a1|0;cL=a[aa]|0;do{if((cL&255)>142){dn=3061}else{a_=dl>>>0<5;if(cL<<24>>24==-114&a_){dn=3061;break}if((ba&8|0)!=0){dn=3061;break}if(a_){dp=(e[ad>>1]|0)+dl|0}else{dp=dl}dq=dp-4|0}}while(0);if((dn|0)==3061){dn=0;dq=(ag(e[ad>>1]|0,153-(cL&255)|0)|0)+dl|0}dm=dq+a1|0}c[aK>>2]=dm;ba=(c[aL>>2]|0)>>>0>dm>>>0?6:7;c[az>>2]=ba;a_=c[ay>>2]|0;dr=(c[f+19580+(a_<<2)>>2]|0)>>>0<(c[f+19580+(ba<<2)>>2]|0)>>>0?a_:ba;c[aA>>2]=dr;ba=c[aB>>2]|0;a_=(c[f+19580+(ba<<2)>>2]|0)>>>0<(c[f+19580+(dr<<2)>>2]|0)>>>0?ba:dr;c[aC>>2]=a_;dr=c[f+19580+(a_<<2)>>2]|0;c[aD>>2]=dr;c[at>>2]=dr;a_=(c[as>>2]|0)>>>0<=dr>>>0|0;c[au>>2]=a_;c[av>>2]=c[f+19560+(a_<<2)>>2];a_=c[aE>>2]|0;c[a_+28>>2]=dr;ba=(c[a_+24>>2]|0)>>>0<dr>>>0?6:7;c[a_+96>>2]=ba;dr=c[a_+92>>2]|0;ds=(c[a_+(dr<<2)>>2]|0)>>>0<(c[a_+(ba<<2)>>2]|0)>>>0?dr:ba;c[a_+76>>2]=ds;ba=c[a_+72>>2]|0;dr=(c[a_+(ba<<2)>>2]|0)>>>0<(c[a_+(ds<<2)>>2]|0)>>>0?ba:ds;c[a_+64>>2]=dr;ds=c[a_+68>>2]|0;ba=(c[a_+(dr<<2)>>2]|0)>>>0<(c[a_+(ds<<2)>>2]|0)>>>0?dr:ds;c[a_+60>>2]=ba;c[a_+36>>2]=c[a_+(ba<<2)>>2];ba=c[aL>>2]|0;do{if((ba|0)!=-1){if((ba-a1|0)>>>0<=1){break}a_=c[$>>2]|0;ds=ga[c[(c[ai>>2]|0)+4>>2]&127](an,166,-(c[aj>>2]|0)|0)|0;dr=a[m]&1;dt=(ds<<dr)+a_+(a[H]&1)-dr|0;c[aL>>2]=dt;dr=(c[aK>>2]|0)>>>0<dt>>>0?6:7;c[az>>2]=dr;dt=c[ay>>2]|0;a_=(c[f+19580+(dt<<2)>>2]|0)>>>0<(c[f+19580+(dr<<2)>>2]|0)>>>0?dt:dr;c[aA>>2]=a_;dr=c[aB>>2]|0;dt=(c[f+19580+(dr<<2)>>2]|0)>>>0<(c[f+19580+(a_<<2)>>2]|0)>>>0?dr:a_;c[aC>>2]=dt;a_=c[f+19580+(dt<<2)>>2]|0;c[aD>>2]=a_;c[at>>2]=a_;dt=(c[as>>2]|0)>>>0<=a_>>>0|0;c[au>>2]=dt;c[av>>2]=c[f+19560+(dt<<2)>>2];dt=c[aE>>2]|0;c[dt+28>>2]=a_;dr=(c[dt+24>>2]|0)>>>0<a_>>>0?6:7;c[dt+96>>2]=dr;a_=c[dt+92>>2]|0;ds=(c[dt+(a_<<2)>>2]|0)>>>0<(c[dt+(dr<<2)>>2]|0)>>>0?a_:dr;c[dt+76>>2]=ds;dr=c[dt+72>>2]|0;a_=(c[dt+(dr<<2)>>2]|0)>>>0<(c[dt+(ds<<2)>>2]|0)>>>0?dr:ds;c[dt+64>>2]=a_;ds=c[dt+68>>2]|0;dr=(c[dt+(a_<<2)>>2]|0)>>>0<(c[dt+(ds<<2)>>2]|0)>>>0?a_:ds;c[dt+60>>2]=dr;c[dt+36>>2]=c[dt+(dr<<2)>>2]}}while(0);ba=c[ax>>2]|0;if((ba|0)==-1){break}if((ba-a1|0)>>>0<=1){break}ba=a[m]&1;dl=(c[aM>>2]|0)+1-ba|0;if(dl>>>0>a1>>>0){du=dl}else{du=(c[ao>>2]|0)+(ba^1)|0}c[ax>>2]=du;ba=(c[aw>>2]|0)>>>0<du>>>0?4:5;c[ay>>2]=ba;dl=c[az>>2]|0;cL=(c[f+19580+(ba<<2)>>2]|0)>>>0<(c[f+19580+(dl<<2)>>2]|0)>>>0?ba:dl;c[aA>>2]=cL;dl=c[aB>>2]|0;ba=(c[f+19580+(dl<<2)>>2]|0)>>>0<(c[f+19580+(cL<<2)>>2]|0)>>>0?dl:cL;c[aC>>2]=ba;cL=c[f+19580+(ba<<2)>>2]|0;c[aD>>2]=cL;c[at>>2]=cL;ba=(c[as>>2]|0)>>>0<=cL>>>0|0;c[au>>2]=ba;c[av>>2]=c[f+19560+(ba<<2)>>2];ba=c[aE>>2]|0;c[ba+28>>2]=cL;dl=(c[ba+24>>2]|0)>>>0<cL>>>0?6:7;c[ba+96>>2]=dl;cL=c[ba+92>>2]|0;dr=(c[ba+(cL<<2)>>2]|0)>>>0<(c[ba+(dl<<2)>>2]|0)>>>0?cL:dl;c[ba+76>>2]=dr;dl=c[ba+72>>2]|0;cL=(c[ba+(dl<<2)>>2]|0)>>>0<(c[ba+(dr<<2)>>2]|0)>>>0?dl:dr;c[ba+64>>2]=cL;dr=c[ba+68>>2]|0;dl=(c[ba+(cL<<2)>>2]|0)>>>0<(c[ba+(dr<<2)>>2]|0)>>>0?cL:dr;c[ba+60>>2]=dl;c[ba+36>>2]=c[ba+(dl<<2)>>2]}}while(0);a[T]=a[T]&-128^-128;if((a[ak]|0)<0){dv=c[al>>2]|0}else{dv=(70224<<(a[m]&1))+a1|0}c[k>>2]=dv;bP=(c[am>>2]|0)>>>0>dv>>>0?2:3;c[V>>2]=bP;dl=c[U>>2]|0;ba=f+16912+(bP<<2)|0;dr=(c[f+16912+(dl<<2)>>2]|0)>>>0<(c[ba>>2]|0)>>>0?dl:bP;c[W>>2]=dr;dl=c[X>>2]|0;cL=f+16912+(dl<<2)|0;dt=(c[f+16912+(dr<<2)>>2]|0)>>>0<(c[cL>>2]|0)>>>0?dr:dl;c[M>>2]=dt;dr=c[L>>2]|0;ds=f+16912+(dr<<2)|0;a_=(c[f+16912+(dt<<2)>>2]|0)>>>0<(c[ds>>2]|0)>>>0?dt:dr;c[N>>2]=a_;c[p>>2]=c[f+16912+(a_<<2)>>2];a_=c[j>>2]|0;if(a_>>>0<=a1>>>0){break}dt=a_-a1|0;a_=((a[m]&1)!=0?dt<<1:dt>>>1)+a1|0;c[j>>2]=a_;dt=(c[w>>2]|0)>>>0>=a_>>>0|0;c[U>>2]=dt;a_=(c[f+16912+(dt<<2)>>2]|0)>>>0<(c[ba>>2]|0)>>>0?dt:bP;c[W>>2]=a_;bP=(c[f+16912+(a_<<2)>>2]|0)>>>0<(c[cL>>2]|0)>>>0?a_:dl;c[M>>2]=bP;dl=(c[f+16912+(bP<<2)>>2]|0)>>>0<(c[ds>>2]|0)>>>0?bP:dr;c[N>>2]=dl;c[p>>2]=c[f+16912+(dl<<2)>>2]}}while(0);a[s]=a[s]|2;if((c[R>>2]&c[P>>2]|0)!=0){a6=c[S>>2]|0;c[I>>2]=a6;c[J>>2]=8;c[K>>2]=8;c[L>>2]=8;dl=c[M>>2]|0;dr=(c[f+16912+(dl<<2)>>2]|0)>>>0<a6>>>0?dl:8;c[N>>2]=dr;c[p>>2]=c[f+16912+(dr<<2)>>2]}dr=a1+131072+((a[m]&1)<<3)|0;c[w>>2]=dr;dl=(c[j>>2]|0)>>>0<=dr>>>0|0;c[U>>2]=dl;dr=c[V>>2]|0;a6=(c[f+16912+(dl<<2)>>2]|0)>>>0<(c[f+16912+(dr<<2)>>2]|0)>>>0?dl:dr;c[W>>2]=a6;dr=c[X>>2]|0;dl=(c[f+16912+(a6<<2)>>2]|0)>>>0<(c[f+16912+(dr<<2)>>2]|0)>>>0?a6:dr;c[M>>2]=dl;dr=c[L>>2]|0;a6=(c[f+16912+(dl<<2)>>2]|0)>>>0<(c[f+16912+(dr<<2)>>2]|0)>>>0?dl:dr;c[N>>2]=a6;dr=c[f+16912+(a6<<2)>>2]|0;c[p>>2]=dr;if(a1>>>0>=dr>>>0){a2=aV;a3=a1;a4=a5;break L4077}a2=aV;a3=(a1-dr&3)+dr|0;a4=a5;break};case 47:{c[E>>2]=1536;a2=~aV;a3=aZ;a4=a0;break};case 48:{if((c[z>>2]&256|0)!=0){a2=aV;a3=aU+8|0;a4=a0+1&65535;break L4077}dr=a0&65535;a6=c[f+17032+(dr>>>12<<2)>>2]|0;if((a6|0)==0){dw=kQ(h,dr,aZ)|0}else{dw=d[a6+dr|0]|0}a2=aV;a3=aU+12|0;a4=dr+65409+(dw^128)&65535;break};case 49:{dr=a0&65535;a6=c[f+17032+(dr>>>12<<2)>>2]|0;if((a6|0)==0){dx=kQ(h,dr,aZ)|0}else{dx=d[a6+dr|0]|0}a6=dr+1&65535;dr=c[f+17032+(a6>>>12<<2)>>2]|0;if((dr|0)==0){dy=kQ(h,a6,aU+8|0)|0}else{dy=d[dr+a6|0]|0}b[o>>1]=(dy<<8|dx)&65535;a2=aV;a3=aU+12|0;a4=a0+2&65535;break};case 18:{a6=d[l]|0;dr=a6<<8|d[A];dl=c[f+17096+(a6>>>4<<2)>>2]|0;if((dl|0)==0){kP(h,dr,aV&255,aZ)}else{a[dl+dr|0]=aV}a2=aV;a3=aU+8|0;a4=a0;break};case 42:{dr=d[n]|0;dl=dr<<8|d[y];a6=c[f+17032+(dr>>>4<<2)>>2]|0;if((a6|0)==0){dz=(kQ(h,dl,aZ)|0)&255}else{dz=a[a6+dl|0]|0}a6=dl+1|0;a[y]=a6&255;a[n]=a6>>>8&255;a2=dz;a3=aU+8|0;a4=a0;break};case 43:{a6=(d[y]|0)-1|0;a[y]=a6&255;a[n]=(d[n]|0)-(a6>>>8&1)&255;a2=aV;a3=aU+8|0;a4=a0;break};case 44:{a6=d[y]|0;c[E>>2]=a6|2048;dl=a6+1|0;c[B>>2]=dl;a[y]=dl&255;a2=aV;a3=aZ;a4=a0;break};case 45:{dl=d[y]|0;c[E>>2]=dl|3072;a6=dl-1|0;c[B>>2]=a6;a[y]=a6&255;a2=aV;a3=aZ;a4=a0;break};case 46:{a6=a0&65535;dl=c[f+17032+(a6>>>12<<2)>>2]|0;if((dl|0)==0){dA=(kQ(h,a6,aZ)|0)&255}else{dA=a[dl+a6|0]|0}a[y]=dA;a2=aV;a3=aU+8|0;a4=a0+1&65535;break};case 159:{a6=aV&255;c[C>>2]=a6;dl=c[z>>2]|0;c[E>>2]=a6|dl&256|1024;a6=-(dl>>>8&1)|0;c[z>>2]=a6;c[B>>2]=a6;a2=a6&255;a3=aZ;a4=a0;break};case 160:{c[E>>2]=512;c[z>>2]=0;a6=a[x]&aV;c[B>>2]=a6&255;a2=a6;a3=aZ;a4=a0;break};case 161:{c[E>>2]=512;c[z>>2]=0;a6=a[g]&aV;c[B>>2]=a6&255;a2=a6;a3=aZ;a4=a0;break};case 162:{c[E>>2]=512;c[z>>2]=0;a6=a[l]&aV;c[B>>2]=a6&255;a2=a6;a3=aZ;a4=a0;break};case 163:{c[E>>2]=512;c[z>>2]=0;a6=a[A]&aV;c[B>>2]=a6&255;a2=a6;a3=aZ;a4=a0;break};case 164:{c[E>>2]=512;c[z>>2]=0;a6=a[n]&aV;c[B>>2]=a6&255;a2=a6;a3=aZ;a4=a0;break};case 165:{c[E>>2]=512;c[z>>2]=0;a6=a[y]&aV;c[B>>2]=a6&255;a2=a6;a3=aZ;a4=a0;break};case 166:{a6=d[n]|0;dl=a6<<8|d[y];dr=c[f+17032+(a6>>>4<<2)>>2]|0;if((dr|0)==0){dB=kQ(h,dl,aZ)|0}else{dB=d[dr+dl|0]|0}c[E>>2]=512;c[z>>2]=0;dl=dB&(aV&255);c[B>>2]=dl;a2=dl&255;a3=aU+8|0;a4=a0;break};case 167:{c[B>>2]=aV&255;c[z>>2]=0;c[E>>2]=512;a2=aV;a3=aZ;a4=a0;break};case 168:{c[E>>2]=0;c[z>>2]=0;dl=a[x]^aV;c[B>>2]=dl&255;a2=dl;a3=aZ;a4=a0;break};case 169:{c[E>>2]=0;c[z>>2]=0;dl=a[g]^aV;c[B>>2]=dl&255;a2=dl;a3=aZ;a4=a0;break};case 170:{c[E>>2]=0;c[z>>2]=0;dl=a[l]^aV;c[B>>2]=dl&255;a2=dl;a3=aZ;a4=a0;break};case 171:{c[E>>2]=0;c[z>>2]=0;dl=a[A]^aV;c[B>>2]=dl&255;a2=dl;a3=aZ;a4=a0;break};case 172:{c[E>>2]=0;c[z>>2]=0;dl=a[n]^aV;c[B>>2]=dl&255;a2=dl;a3=aZ;a4=a0;break};case 173:{c[E>>2]=0;c[z>>2]=0;dl=a[y]^aV;c[B>>2]=dl&255;a2=dl;a3=aZ;a4=a0;break};case 174:{dl=d[n]|0;dr=dl<<8|d[y];a6=c[f+17032+(dl>>>4<<2)>>2]|0;if((a6|0)==0){dC=kQ(h,dr,aZ)|0}else{dC=d[a6+dr|0]|0}c[E>>2]=0;c[z>>2]=0;dr=dC^aV&255;c[B>>2]=dr&255;a2=dr&255;a3=aU+8|0;a4=a0;break};case 230:{dr=a0&65535;a6=c[f+17032+(dr>>>12<<2)>>2]|0;if((a6|0)==0){dD=kQ(h,dr,aZ)|0}else{dD=d[a6+dr|0]|0}c[E>>2]=512;c[z>>2]=0;dr=dD&(aV&255);c[B>>2]=dr;a2=dr&255;a3=aU+8|0;a4=a0+1&65535;break};case 231:{dr=(e[o>>1]|0)+65535|0;b[o>>1]=dr&65535;a6=dr&65535;dr=a0&65535;dl=dr>>>8;bP=c[f+17096+(a6>>>12<<2)>>2]|0;if((bP|0)==0){kP(h,a6,dl,aZ)}else{a[bP+a6|0]=dl&255}dl=(e[o>>1]|0)+65535|0;b[o>>1]=dl&65535;a6=dl&65535;dl=c[f+17096+(a6>>>12<<2)>>2]|0;if((dl|0)==0){kP(h,a6,dr&255,aU+8|0)}else{a[dl+a6|0]=a0&255}a2=aV;a3=aU+16|0;a4=32;break};case 232:{a6=a0&65535;dl=c[f+17032+(a6>>>12<<2)>>2]|0;if((dl|0)==0){dE=kQ(h,a6,aZ)|0}else{dE=d[dl+a6|0]|0}a6=(dE^128)-128|0;dl=e[o>>1]|0;dr=dl+a6|0;bP=dl^a6^dr;c[z>>2]=bP;c[E>>2]=bP<<5&512;c[B>>2]=1;b[o>>1]=dr&65535;a2=aV;a3=aU+16|0;a4=a0+1&65535;break};case 233:{a2=aV;a3=aZ;a4=d[n]<<8|d[y];break};case 234:{dr=a0&65535;bP=c[f+17032+(dr>>>12<<2)>>2]|0;if((bP|0)==0){dF=kQ(h,dr,aZ)|0}else{dF=d[bP+dr|0]|0}bP=dr+1&65535;dr=c[f+17032+(bP>>>12<<2)>>2]|0;if((dr|0)==0){dG=kQ(h,bP,aU+8|0)|0}else{dG=d[dr+bP|0]|0}bP=dG<<8|dF;dr=c[f+17096+(bP>>>12<<2)>>2]|0;if((dr|0)==0){kP(h,bP,aV&255,aU+12|0)}else{a[dr+bP|0]=aV}a2=aV;a3=aU+16|0;a4=a0+2&65535;break};case 238:{bP=a0&65535;dr=c[f+17032+(bP>>>12<<2)>>2]|0;if((dr|0)==0){dH=kQ(h,bP,aZ)|0}else{dH=d[dr+bP|0]|0}c[E>>2]=0;c[z>>2]=0;bP=dH^aV&255;c[B>>2]=bP&255;a2=bP&255;a3=aU+8|0;a4=a0+1&65535;break};case 239:{bP=(e[o>>1]|0)+65535|0;b[o>>1]=bP&65535;dr=bP&65535;bP=a0&65535;a6=bP>>>8;dl=c[f+17096+(dr>>>12<<2)>>2]|0;if((dl|0)==0){kP(h,dr,a6,aZ)}else{a[dl+dr|0]=a6&255}a6=(e[o>>1]|0)+65535|0;b[o>>1]=a6&65535;dr=a6&65535;a6=c[f+17096+(dr>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,dr,bP&255,aU+8|0)}else{a[a6+dr|0]=a0&255}a2=aV;a3=aU+16|0;a4=40;break};case 240:{dr=a0&65535;a6=c[f+17032+(dr>>>12<<2)>>2]|0;if((a6|0)==0){dI=kQ(h,dr,aZ)|0}else{dI=d[a6+dr|0]|0}dr=dI|65280;if(dr>>>0<65408){dJ=(kK(h,dr,aU+8|0)|0)&255}else{dJ=a[f+(dr-65024)|0]|0}a2=dJ;a3=aU+12|0;a4=a0+1&65535;break};case 241:{dr=b[o>>1]|0;a6=dr&65535;bP=c[f+17032+(a6>>>12<<2)>>2]|0;if((bP|0)==0){dl=kQ(h,a6,aZ)|0;dK=dl;dL=b[o>>1]|0}else{dK=d[bP+a6|0]|0;dL=dr}dr=(dL&65535)+1|0;a6=dr&65535;b[o>>1]=a6;bP=dr&65535;dr=c[f+17032+(bP>>>12<<2)>>2]|0;if((dr|0)==0){dl=(kQ(h,bP,aU+8|0)|0)&255;dM=dl;dN=b[o>>1]|0}else{dM=a[dr+bP|0]|0;dN=a6}b[o>>1]=dN+1&65535;c[B>>2]=dK&128^128;a6=dK<<4;c[E>>2]=a6&1536;c[z>>2]=a6&256;a2=dM;a3=aU+12|0;a4=a0;break};case 242:{a6=d[g]|65280;if(a6>>>0<65408){dO=(kK(h,a6,aZ)|0)&255}else{dO=a[f+(a6-65024)|0]|0}a2=dO;a3=aU+8|0;a4=a0;break};case 243:{a6=a[s]&-2;a[s]=a6;if(a6<<24>>24!=0){a2=aV;a3=aZ;a4=a0;break L4077}c[I>>2]=-1;c[J>>2]=8;c[K>>2]=8;c[L>>2]=8;a6=c[M>>2]|0;bP=(c[f+16912+(a6<<2)>>2]|0)!=-1?a6:8;c[N>>2]=bP;c[p>>2]=c[f+16912+(bP<<2)>>2];a2=aV;a3=aZ;a4=a0;break};case 245:{bP=c[E>>2]|0;a6=(bP>>>8&1)+(bP&15)|0;dr=(bP&2048|0)==0;dl=dr?c[C>>2]&15:a6;ds=dr?a6:1;if((bP&1024|0)==0){dP=dl+ds<<5}else{dP=dl-ds|0}ds=dP&512|bP;c[E>>2]=ds;bP=(ds&1536|c[z>>2]&256)>>>4|((c[B>>2]&255|0)!=0?0:128);ds=(e[o>>1]|0)+65535|0;b[o>>1]=ds&65535;dl=ds&65535;ds=c[f+17096+(dl>>>12<<2)>>2]|0;if((ds|0)==0){kP(h,dl,aV&255,aZ)}else{a[ds+dl|0]=aV}dl=(e[o>>1]|0)+65535|0;b[o>>1]=dl&65535;ds=dl&65535;dl=c[f+17096+(ds>>>12<<2)>>2]|0;if((dl|0)==0){kP(h,ds,bP,aU+8|0)}else{a[dl+ds|0]=bP&255}a2=aV;a3=aU+16|0;a4=a0;break};case 246:{bP=a0&65535;ds=c[f+17032+(bP>>>12<<2)>>2]|0;if((ds|0)==0){dQ=kQ(h,bP,aZ)|0}else{dQ=d[ds+bP|0]|0}c[E>>2]=0;c[z>>2]=0;bP=dQ|aV&255;c[B>>2]=bP&255;a2=bP&255;a3=aU+8|0;a4=a0+1&65535;break};case 247:{bP=(e[o>>1]|0)+65535|0;b[o>>1]=bP&65535;ds=bP&65535;bP=a0&65535;dl=bP>>>8;a6=c[f+17096+(ds>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,ds,dl,aZ)}else{a[a6+ds|0]=dl&255}dl=(e[o>>1]|0)+65535|0;b[o>>1]=dl&65535;ds=dl&65535;dl=c[f+17096+(ds>>>12<<2)>>2]|0;if((dl|0)==0){kP(h,ds,bP&255,aU+8|0)}else{a[dl+ds|0]=a0&255}a2=aV;a3=aU+16|0;a4=48;break};case 248:{ds=a0&65535;dl=c[f+17032+(ds>>>12<<2)>>2]|0;if((dl|0)==0){dR=kQ(h,ds,aZ)|0}else{dR=d[dl+ds|0]|0}ds=(dR^128)-128|0;dl=e[o>>1]|0;bP=dl+ds|0;a6=dl^ds^bP;c[z>>2]=a6;c[E>>2]=a6<<5&512;c[B>>2]=1;a[y]=bP&255;a[n]=bP>>>8&255;a2=aV;a3=aU+12|0;a4=a0+1&65535;break};case 249:{b[o>>1]=d[n]<<8|d[y];a2=aV;a3=aU+8|0;a4=a0;break};case 250:{bP=a0&65535;a6=c[f+17032+(bP>>>12<<2)>>2]|0;if((a6|0)==0){dS=kQ(h,bP,aZ)|0}else{dS=d[a6+bP|0]|0}a6=bP+1&65535;bP=c[f+17032+(a6>>>12<<2)>>2]|0;if((bP|0)==0){dT=kQ(h,a6,aU+8|0)|0}else{dT=d[bP+a6|0]|0}a6=dT<<8|dS;bP=c[f+17032+(a6>>>12<<2)>>2]|0;if((bP|0)==0){dU=(kQ(h,a6,aU+12|0)|0)&255}else{dU=a[bP+a6|0]|0}a2=dU;a3=aU+16|0;a4=a0+2&65535;break};case 251:{a6=a[s]|0;if((a6&1)!=0){a2=aV;a3=aZ;a4=a0;break L4077}a[s]=a6|1;a6=aU+5|0;c[S>>2]=a6;if((c[R>>2]&c[P>>2]|0)==0){a2=aV;a3=aZ;a4=a0;break L4077}c[I>>2]=a6;c[J>>2]=8;c[K>>2]=8;c[L>>2]=8;bP=c[M>>2]|0;ds=(c[f+16912+(bP<<2)>>2]|0)>>>0<a6>>>0?bP:8;c[N>>2]=ds;c[p>>2]=c[f+16912+(ds<<2)>>2];a2=aV;a3=aZ;a4=a0;break};case 254:{ds=a0&65535;bP=c[f+17032+(ds>>>12<<2)>>2]|0;if((bP|0)==0){dV=kQ(h,ds,aZ)|0}else{dV=d[bP+ds|0]|0}ds=aV&255;c[C>>2]=ds;bP=ds-dV|0;c[z>>2]=bP;c[B>>2]=bP;c[E>>2]=dV|1024;a2=aV;a3=aU+8|0;a4=a0+1&65535;break};case 255:{bP=(e[o>>1]|0)+65535|0;b[o>>1]=bP&65535;ds=bP&65535;bP=a0&65535;a6=bP>>>8;dl=c[f+17096+(ds>>>12<<2)>>2]|0;if((dl|0)==0){kP(h,ds,a6,aZ)}else{a[dl+ds|0]=a6&255}a6=(e[o>>1]|0)+65535|0;b[o>>1]=a6&65535;ds=a6&65535;a6=c[f+17096+(ds>>>12<<2)>>2]|0;if((a6|0)==0){kP(h,ds,bP&255,aU+8|0)}else{a[a6+ds|0]=a0&255}a2=aV;a3=aU+16|0;a4=56;break};default:{a2=aV;a3=aZ;a4=a0}}}while(0);if(a3>>>0<(c[p>>2]|0)>>>0){aT=a4;aU=a3;aV=a2}else{aW=a2;aX=a3;aY=a4;break L4064}}}else{if(!aS){aW=u;aX=aQ;aY=v;break}aW=u;aX=(aQ-aR&3)+aR|0;aY=v}}while(0);b[q>>1]=aY;v=kN(h,aX)|0;if((c[j>>2]|0)==-1){F=v;G=aW;break}else{aQ=v;u=aW}}a[t]=G;c[i>>2]=F;return}function ky(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;h=f|0;i=f+20112|0;j=kJ(h,c[i>>2]|0)|0;k=f+16908|0;if((c[k>>2]|0)!=-1){kO(h,j)}l=f+17256|0;a[f+261|0]=(oM(l,j)|0)&255;if((c[k>>2]|0)!=-1){kO(h,j)}kM(h,j);a[f+271|0]=c[f+17020>>2]&255;if((c[k>>2]|0)!=-1){kO(h,j)}h=f+294|0;if((a[h]|0)<0){kS(f+19692|0,j,a[f+17559|0]&1);m=a[f+19805|0]&1|a[f+19901|0]<<1&2|a[f+19974|0]<<2&4|a[f+20065|0]<<3|-16}else{m=112}a[h]=m;c[g+52>>2]=c[f+16904>>2];c[g+64>>2]=c[f+16924>>2];c[g+76>>2]=c[f+16912>>2];c[g+68>>2]=c[k>>2];b[g+82>>1]=b[f+20100>>1]|0;b[g+84>>1]=b[f+20102>>1]|0;a[g+87|0]=a[f+20104|0]|0;c[g+72>>2]=c[f+17016>>2];k=f+17028|0;a[g+88|0]=a[k]&1;a[g+89|0]=(d[k]|0)>>>1&1;b[g+80>>1]=b[f+17248>>1]|0;a[g+86|0]=a[f+17250|0]|0;a[g+90|0]=a[f+17251|0]&1;a[g+91|0]=a[f+17252|0]&1;c[g+320>>2]=c[f+17224>>2];c[g+324>>2]=c[f+17232>>2];a[g+328|0]=a[f+17240|0]|0;a[g+329|0]=a[f+17241|0]|0;a[g+330|0]=a[f+17242|0]|0;a[g+331|0]=a[f+17243|0]|0;a[g+332|0]=a[f+17244|0]|0;a[g+333|0]=a[f+17245|0]|0;a[g+334|0]=a[f+17247|0]&1;c[g+56>>2]=c[l>>2];c[g+60>>2]=c[f+17260>>2];a[g+92|0]=(c[f+19600>>2]|0)!=-1|0;l=f+17532|0;b[g+138>>1]=(c[f+19608>>2]|0)-(c[l>>2]|0)&65535;a[g+190|0]=(c[f+19580>>2]|0)!=-1|0;a[g+184|0]=a[f+19674|0]|0;a[g+185|0]=a[f+19665|0]|0;c[g+132>>2]=c[f+19276>>2];if((a[f+19362|0]|0)<0){n=((d[f+17558|0]|0)*456|0)+456-(((c[f+17552>>2]|0)-(c[l>>2]|0)|0)>>>((a[f+17559|0]&1)>>>0))|0}else{n=0}c[g+128>>2]=n;a[g+175|0]=a[f+19377|0]|0;a[g+176|0]=a[f+19378|0]|0;a[g+177|0]=a[f+19371|0]|0;a[g+178|0]=a[f+19372|0]|0;b[g+140>>1]=c[f+17544>>2]&65535;b[g+142>>1]=c[f+17548>>2]&65535;a[g+179|0]=a[f+19373|0]|0;a[g+180|0]=a[f+19374|0]|0;a[g+187|0]=a[f+19368|0]|0;a[g+174|0]=a[f+19370|0]|0;a[g+186|0]=a[f+19366|0]|0;a[g+188|0]=a[f+19369|0]|0;a[g+189|0]=a[f+19380|0]&1;n=0;do{a[g+144+n|0]=a[f+19296+(n<<2)+3|0]|0;k=f+19340+(n<<1)|0;a[g+154+n|0]=b[k>>1]&255;a[g+164+n|0]=(e[k>>1]|0)>>>8&255;n=n+1|0;}while(n>>>0<10);a[g+182|0]=a[f+19375|0]|0;a[g+183|0]=a[f+19376|0]|0;a[g+181|0]=a[(c[f+17528>>2]|0)+8|0]|0;b[g+136>>1]=(c[l>>2]|0)-(c[f+17536>>2]|0)&65535;c[g+192>>2]=c[f+19772>>2];b[g+196>>1]=b[f+19784>>1]|0;a[g+198|0]=a[f+19786|0]|0;a[g+199|0]=a[f+19787|0]&1;l=f+19792|0;n=c[l>>2]|0;k=f+19740|0;m=c[k>>2]|0;if(m>>>0>n>>>0){o=m;p=f+19744|0;q=f+19746|0}else{h=f+19744|0;r=e[h>>1]|0;s=(((n-m|0)>>>0)/(r>>>0)|0)+1|0;n=(ag(s,r)|0)+m|0;c[k>>2]=n;k=f+19746|0;a[k]=(d[k]|0)+s&7;o=n;p=h;q=k}c[g+200>>2]=o;a[g+204|0]=2048-((e[p>>1]|0)>>>1)&255;a[g+205|0]=a[q]|0;c[g+208>>2]=c[f+19756>>2];a[g+212|0]=a[f+19765|0]|0;c[g+216>>2]=c[f+19720>>2];b[g+220>>1]=b[f+19728>>1]|0;c[g+316>>2]=c[l>>2];a[g+224|0]=a[f+19804|0]|0;a[g+225|0]=a[f+19805|0]&1;l=c[f+19888>>2]|0;q=f+19856|0;p=c[q>>2]|0;if(p>>>0>l>>>0){t=p;u=f+19860|0;v=f+19862|0}else{o=f+19860|0;k=e[o>>1]|0;h=(((l-p|0)>>>0)/(k>>>0)|0)+1|0;l=(ag(h,k)|0)+p|0;c[q>>2]=l;q=f+19862|0;a[q]=(d[q]|0)+h&7;t=l;u=o;v=q}c[g+228>>2]=t;a[g+232|0]=2048-((e[u>>1]|0)>>>1)&255;a[g+233|0]=a[v]|0;c[g+236>>2]=c[f+19872>>2];a[g+240|0]=a[f+19881|0]|0;c[g+244>>2]=c[f+19836>>2];b[g+248>>1]=b[f+19844>>1]|0;a[g+252|0]=a[f+19900|0]|0;a[g+253|0]=a[f+19901|0]&1;c[g+264>>2]=c[f+19936>>2];b[g+268>>1]=b[f+19944>>1]|0;c[g+272>>2]=c[f+19960>>2];c[g+276>>2]=c[f+19964>>2];a[g+280|0]=a[f+19969|0]|0;a[g+281|0]=a[f+19970|0]|0;a[g+282|0]=a[f+19971|0]|0;a[g+283|0]=a[f+19973|0]|0;a[g+284|0]=a[f+19974|0]&1;pc(f+20032|0,c[f+20052>>2]|0);c[g+288>>2]=c[f+20040>>2];b[g+292>>1]=b[f+20044>>1]|0;c[g+296>>2]=c[f+20020>>2];a[g+300|0]=a[f+20029|0]|0;c[g+304>>2]=c[f+20004>>2];b[g+308>>1]=b[f+20012>>1]|0;a[g+312|0]=a[f+20064|0]|0;a[g+313|0]=a[f+20065|0]&1;c[i>>2]=j;i=f+20124|0;v=c[i>>2]|0;u=(v>>>8&1)+(v&15)|0;t=(v&2048|0)==0;q=t?c[f+20120>>2]&15:u;o=t?u:1;if((v&1024|0)==0){w=q+o<<5;x=w&512;y=x|v;c[i>>2]=y;z=g|0;c[z>>2]=j;A=f+20116|0;B=b[A>>1]|0;C=g+4|0;b[C>>1]=B;D=f+20118|0;E=b[D>>1]|0;F=g+6|0;b[F>>1]=E;G=f+20136|0;H=a[G]|0;I=g+8|0;a[I]=H;J=f+20137|0;K=a[J]|0;L=g+9|0;a[L]=K;M=f+20138|0;N=a[M]|0;O=g+10|0;a[O]=N;P=f+20139|0;Q=a[P]|0;R=g+11|0;a[R]=Q;S=f+20140|0;T=a[S]|0;U=g+12|0;a[U]=T;V=c[i>>2]|0;W=V&1536;X=f+20132|0;Y=c[X>>2]|0;Z=Y&256;_=Z|W;$=_>>>4;aa=f+20128|0;ab=c[aa>>2]|0;ac=ab&255;ad=(ac|0)!=0;ae=ad?0:128;af=ae|$;ah=af&255;ai=g+13|0;a[ai]=ah;aj=f+20141|0;ak=a[aj]|0;al=g+14|0;a[al]=ak;am=f+20142|0;an=a[am]|0;ao=g+15|0;a[ao]=an;ap=f+20143|0;aq=a[ap]|0;ar=aq&1;as=g+16|0;a[as]=ar;return}else{w=q-o|0;x=w&512;y=x|v;c[i>>2]=y;z=g|0;c[z>>2]=j;A=f+20116|0;B=b[A>>1]|0;C=g+4|0;b[C>>1]=B;D=f+20118|0;E=b[D>>1]|0;F=g+6|0;b[F>>1]=E;G=f+20136|0;H=a[G]|0;I=g+8|0;a[I]=H;J=f+20137|0;K=a[J]|0;L=g+9|0;a[L]=K;M=f+20138|0;N=a[M]|0;O=g+10|0;a[O]=N;P=f+20139|0;Q=a[P]|0;R=g+11|0;a[R]=Q;S=f+20140|0;T=a[S]|0;U=g+12|0;a[U]=T;V=c[i>>2]|0;W=V&1536;X=f+20132|0;Y=c[X>>2]|0;Z=Y&256;_=Z|W;$=_>>>4;aa=f+20128|0;ab=c[aa>>2]|0;ac=ab&255;ad=(ac|0)!=0;ae=ad?0:128;af=ae|$;ah=af&255;ai=g+13|0;a[ai]=ah;aj=f+20141|0;ak=a[aj]|0;al=g+14|0;a[al]=ak;am=f+20142|0;an=a[am]|0;ao=g+15|0;a[ao]=an;ap=f+20143|0;aq=a[ap]|0;ar=aq&1;as=g+16|0;a[as]=ar;return}}function kz(a){a=a|0;var b=0;b=c[a>>2]|0;if((b|0)==0){return}a=c[b+19684>>2]|0;if((a|0)!=0){f2[c[(c[a>>2]|0)+4>>2]&1023](a)}a=c[b+17160>>2]|0;if((a|0)!=0){yt(a)}yt(b|0);return}function kA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=c[185312]|0;c[d+19284>>2]=575888;c[d+19292>>2]=256;c[d+19288>>2]=566992;d=c[185312]|0;c[d+20068>>2]=723344;c[d+20084>>2]=0;d=c[185312]|0;kx(d|0,c[b>>2]<<1);e=d+20112|0;f=c[e>>2]|0;g=c[d+16920>>2]|0;if(g>>>0>f>>>0){h=-1}else{h=(f-g|0)>>>((a[d+17559|0]&1)>>>0)}if((f|0)<0){c[e>>2]=kJ(d|0,f)|0}f=c[185312]|0;kS(f+19692|0,c[f+20112>>2]|0,a[f+17559|0]&1);d=f+20080|0;e=c[d>>2]|0;g=c[f+20068>>2]|0;i=f+20084|0;f=c[i>>2]|0;j=f>>>3;if((j|0)==0){k=f;l=g;m=e}else{n=j;o=g;p=e;while(1){e=(c[o>>2]|0)+p|0;c[o>>2]=e^32768;q=o+4|0;r=e+(c[q>>2]|0)|0;c[q>>2]=r^32768;q=o+8|0;e=r+(c[q>>2]|0)|0;c[q>>2]=e^32768;q=o+12|0;r=e+(c[q>>2]|0)|0;c[q>>2]=r^32768;q=o+16|0;e=r+(c[q>>2]|0)|0;c[q>>2]=e^32768;q=o+20|0;r=e+(c[q>>2]|0)|0;c[q>>2]=r^32768;q=o+24|0;e=r+(c[q>>2]|0)|0;c[q>>2]=e^32768;q=o+28|0;s=e+(c[q>>2]|0)|0;c[q>>2]=s^32768;q=n-1|0;if((q|0)==0){break}else{n=q;o=o+32|0;p=s}}p=j<<3;k=f-p|0;l=g+(p<<2)|0;m=s}if((k|0)==0){t=m}else{s=m;m=l;l=k;while(1){k=l-1|0;p=(c[m>>2]|0)+s|0;c[m>>2]=p^32768;if((k|0)==0){t=p;break}else{s=p;m=m+4|0;l=k}}}c[d>>2]=t;t=c[i>>2]|0;c[b>>2]=t;if((h|0)<0){u=h;return u|0}u=t-(h>>1)|0;return u|0}function kB(a){a=a|0;var b=0,d=0;c[a+100>>2]=8;c[a+80>>2]=8;c[a+68>>2]=8;b=c[a+64>>2]|0;d=(c[a+(b<<2)>>2]|0)>>>0<(c[a+32>>2]|0)>>>0?b:8;c[a+60>>2]=d;c[a+36>>2]=c[a+(d<<2)>>2];return}function kC(a){a=a|0;var b=0,d=0,e=0;b=(c[a+24>>2]|0)>>>0<(c[a+28>>2]|0)>>>0?6:7;c[a+96>>2]=b;d=c[a+92>>2]|0;e=(c[a+(d<<2)>>2]|0)>>>0<(c[a+(b<<2)>>2]|0)>>>0?d:b;c[a+76>>2]=e;b=c[a+72>>2]|0;d=(c[a+(b<<2)>>2]|0)>>>0<(c[a+(e<<2)>>2]|0)>>>0?b:e;c[a+64>>2]=d;e=c[a+68>>2]|0;b=(c[a+(d<<2)>>2]|0)>>>0<(c[a+(e<<2)>>2]|0)>>>0?d:e;c[a+60>>2]=b;c[a+36>>2]=c[a+(b<<2)>>2];return}function kD(a){a=a|0;var b=0,d=0,e=0;b=(c[a+16>>2]|0)>>>0<(c[a+20>>2]|0)>>>0?4:5;c[a+92>>2]=b;d=c[a+96>>2]|0;e=(c[a+(b<<2)>>2]|0)>>>0<(c[a+(d<<2)>>2]|0)>>>0?b:d;c[a+76>>2]=e;d=c[a+72>>2]|0;b=(c[a+(d<<2)>>2]|0)>>>0<(c[a+(e<<2)>>2]|0)>>>0?d:e;c[a+64>>2]=b;e=c[a+68>>2]|0;d=(c[a+(b<<2)>>2]|0)>>>0<(c[a+(e<<2)>>2]|0)>>>0?b:e;c[a+60>>2]=d;c[a+36>>2]=c[a+(d<<2)>>2];return}function kE(a){a=a|0;var b=0,d=0,e=0;b=(c[a+8>>2]|0)>>>0<(c[a+12>>2]|0)>>>0?2:3;c[a+88>>2]=b;d=c[a+84>>2]|0;e=(c[a+(d<<2)>>2]|0)>>>0<(c[a+(b<<2)>>2]|0)>>>0?d:b;c[a+72>>2]=e;b=c[a+76>>2]|0;d=(c[a+(e<<2)>>2]|0)>>>0<(c[a+(b<<2)>>2]|0)>>>0?e:b;c[a+64>>2]=d;b=c[a+68>>2]|0;e=(c[a+(d<<2)>>2]|0)>>>0<(c[a+(b<<2)>>2]|0)>>>0?d:b;c[a+60>>2]=e;c[a+36>>2]=c[a+(e<<2)>>2];return}function kF(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+336|0;f=e|0;yB(f+20|0,0,24);yB(f+96|0,0,32);g=f+256|0;c[g>>2]=0;h=f+260|0;c[h>>2]=0;j=c[185312]|0;c[f+20>>2]=j+512;c[f+24>>2]=16384;c[f+44>>2]=j;c[f+48>>2]=512;k=c[j+17180>>2]|0;l=j+17172|0;m=(c[l>>2]|0)-k|0;c[f+28>>2]=k;c[f+32>>2]=m;m=c[l>>2]|0;l=(c[j+17184>>2]|0)-m|0;c[f+36>>2]=m;c[f+40>>2]=l;c[f+96>>2]=j+19432;c[f+100>>2]=64;c[f+104>>2]=j+19496;c[f+108>>2]=64;c[f+112>>2]=j+19148;c[f+116>>2]=80;c[f+120>>2]=j+19228;c[f+124>>2]=40;c[g>>2]=j+19904;c[h>>2]=16;kH(f,(a[j+19379|0]&1)!=0,(a[j+20148|0]&1)!=0);j=c[185312]|0;kL(j|0,f);c[j+20112>>2]=c[f>>2];b[j+20116>>1]=b[f+4>>1]|0;b[j+20118>>1]=b[f+6>>1]|0;a[j+20136|0]=a[f+8|0]|0;a[j+20137|0]=a[f+9|0]|0;a[j+20138|0]=a[f+10|0]|0;a[j+20139|0]=a[f+11|0]|0;a[j+20140|0]=a[f+12|0]|0;h=d[f+13|0]|0;c[j+20128>>2]=h&128^128;g=h<<4;c[j+20124>>2]=g&1536;c[j+20132>>2]=g&256;a[j+20141|0]=a[f+14|0]|0;a[j+20142|0]=a[f+15|0]|0;a[j+20143|0]=a[f+16|0]&1;i=e;return}function kG(){var a=0,b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;a=i;i=i+344|0;b=a|0;e=a+8|0;yB(e+20|0,0,24);yB(e+96|0,0,32);f=e+256|0;c[f>>2]=0;g=e+260|0;c[g>>2]=0;h=c[185312]|0;c[e+20>>2]=h+512;c[e+24>>2]=16384;c[e+44>>2]=h;c[e+48>>2]=512;j=c[h+17180>>2]|0;k=h+17172|0;l=(c[k>>2]|0)-j|0;c[e+28>>2]=j;c[e+32>>2]=l;l=c[k>>2]|0;k=(c[h+17184>>2]|0)-l|0;c[e+36>>2]=l;c[e+40>>2]=k;c[e+96>>2]=h+19432;c[e+100>>2]=64;c[e+104>>2]=h+19496;c[e+108>>2]=64;c[e+112>>2]=h+19148;c[e+116>>2]=80;c[e+120>>2]=h+19228;c[e+124>>2]=40;c[f>>2]=h+19904;c[g>>2]=16;ky(h|0,e);h=b|0;c[h>>2]=0;g=b+4|0;c[g>>2]=5;f=c[185292]|0;if((f|0)==(c[185293]|0)){m=5;i=a;return m|0}else{n=f;o=0}while(1){f=d[n+12|0]|0;if((o|0)!=0){k=c[n>>2]|0;yE(o|0,k|0,f)|0;c[h>>2]=(c[h>>2]|0)+f}c[g>>2]=(c[g>>2]|0)+f;f3[c[n+4>>2]&1023](b,e);f=n+16|0;if((f|0)==(c[185293]|0)){break}n=f;o=c[h>>2]|0}m=c[g>>2]|0;i=a;return m|0}function kH(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=d|0;c[h>>2]=f?66208:102348;b[d+4>>1]=256;b[d+6>>1]=-2;a[d+8|0]=(f&1)<<4|1;a[d+9|0]=f&g&1;a[d+10|0]=19;a[d+11|0]=0;a[d+12|0]=-40;a[d+13|0]=-80;a[d+14|0]=1;a[d+15|0]=77;a[d+16|0]=0;yB(c[d+28>>2]|0,-1|0,c[d+32>>2]|0);g=c[d+20>>2]|0;yB(g|0,0,16384);i=0;do{a[g+((i<<1)+16)|0]=a[72136+i|0]|0;i=i+1|0;}while(i>>>0<200);if(f){i=c[d+36>>2]|0;j=0;while(1){k=i+j|0;l=k|0;C=-1;a[l]=C&255;C=C>>8;a[l+1|0]=C&255;C=C>>8;a[l+2|0]=C&255;C=C>>8;a[l+3|0]=C&255;l=k+4|0;C=-1;a[l]=C&255;C=C>>8;a[l+1|0]=C&255;C=C>>8;a[l+2|0]=C&255;C=C>>8;a[l+3|0]=C&255;l=i+(j|8)|0;k=l|0;C=0;a[k]=C&255;C=C>>8;a[k+1|0]=C&255;C=C>>8;a[k+2|0]=C&255;C=C>>8;a[k+3|0]=C&255;k=l+4|0;C=0;a[k]=C&255;C=C>>8;a[k+1|0]=C&255;C=C>>8;a[k+2|0]=C&255;C=C>>8;a[k+3|0]=C&255;k=j+16|0;if(k>>>0<2048){j=k}else{m=2048;break}}while(1){j=i+m|0;k=j|0;C=0;a[k]=C&255;C=C>>8;a[k+1|0]=C&255;C=C>>8;a[k+2|0]=C&255;C=C>>8;a[k+3|0]=C&255;k=j+4|0;C=0;a[k]=C&255;C=C>>8;a[k+1|0]=C&255;C=C>>8;a[k+2|0]=C&255;C=C>>8;a[k+3|0]=C&255;k=i+(m|8)|0;j=k|0;C=-1;a[j]=C&255;C=C>>8;a[j+1|0]=C&255;C=C>>8;a[j+2|0]=C&255;C=C>>8;a[j+3|0]=C&255;j=k+4|0;C=-1;a[j]=C&255;C=C>>8;a[j+1|0]=C&255;C=C>>8;a[j+2|0]=C&255;C=C>>8;a[j+3|0]=C&255;j=m+16|0;if(j>>>0<4096){m=j}else{n=3584;break}}do{a[i+(n|2)|0]=-1;a[i+(n|10)|0]=0;n=n+16|0;}while(n>>>0<4096);n=i+4096|0;yE(n|0,i|0,4096)|0;n=i+12288|0;yE(n|0,i|0,4096)|0;n=i+16384|0;yE(n|0,i|0,4096)|0;n=i+20480|0;yE(n|0,i|0,4096)|0;n=i+24576|0;yE(n|0,i|0,4096)|0;n=i+28672|0;yE(n|0,i|0,4096)|0;yB(i+8192|0,0,4096);n=0;do{a[i+(e[61752+(n<<2)>>1]|0)|0]=a[61754+(n<<2)|0]|0;n=n+1|0;}while(n>>>0<2596);n=c[d+44>>2]|0;yB(n|0,0,160);i=n+160|0;yE(i|0,57624,96)|0;i=n+256|0;yE(i|0,57368,256)|0}else{a[g+6404|0]=1;a[g+6405|0]=2;a[g+6406|0]=3;a[g+6407|0]=4;a[g+6408|0]=5;a[g+6409|0]=6;a[g+6410|0]=7;a[g+6411|0]=8;a[g+6412|0]=9;a[g+6413|0]=10;a[g+6414|0]=11;a[g+6415|0]=12;a[g+6416|0]=25;a[g+6436|0]=13;a[g+6437|0]=14;a[g+6438|0]=15;a[g+6439|0]=16;a[g+6440|0]=17;a[g+6441|0]=18;a[g+6442|0]=19;a[g+6443|0]=20;a[g+6444|0]=21;a[g+6445|0]=22;a[g+6446|0]=23;a[g+6447|0]=24;g=c[d+36>>2]|0;yB(g|0,0,256);yB(g+256|0,-1|0,256);yB(g+512|0,0,256);yB(g+768|0,-1|0,256);yB(g+1024|0,0,256);yB(g+1280|0,-1|0,256);yB(g+1536|0,0,256);yB(g+1792|0,-1|0,512);yB(g+2304|0,0,256);yB(g+2560|0,-1|0,256);yB(g+2816|0,0,256);yB(g+3072|0,-1|0,256);yB(g+3328|0,0,256);yB(g+3584|0,-1|0,256);yB(g+3840|0,0,256);i=g+4096|0;yE(i|0,g|0,4096)|0;i=0;do{a[g+(e[57720+(i<<2)>>1]|0)|0]=a[57722+(i<<2)|0]|0;i=i+1|0;}while(i>>>0<1008);i=c[d+44>>2]|0;yE(i|0,57208,160)|0;yB(i+160|0,0,96);g=i+256|0;yE(g|0,56952,256)|0}g=d+44|0;a[(c[g>>2]|0)+260|0]=28;a[(c[g>>2]|0)+320|0]=-111;a[(c[g>>2]|0)+324|0]=0;c[d+52>>2]=0;c[d+56>>2]=0;c[d+60>>2]=-1;c[d+64>>2]=-1;c[d+68>>2]=-1;c[d+76>>2]=-1;c[d+72>>2]=0;b[d+80>>1]=1;yB(d+82|0,0,5);a[d+87|0]=-2;i=d+96|0;yB(d+88|0,0,5);n=0;do{a[(c[i>>2]|0)+n|0]=-1;a[(c[i>>2]|0)+(n|1)|0]=127;n=n+2|0;}while(n>>>0<64);n=d+104|0;m=c[n>>2]|0;yE(m|0,56864,64)|0;if(!f){a[c[i>>2]|0]=a[(c[g>>2]|0)+327|0]|0;a[c[n>>2]|0]=a[(c[g>>2]|0)+328|0]|0;a[(c[n>>2]|0)+1|0]=a[(c[g>>2]|0)+329|0]|0}n=d+112|0;i=0;do{a[(c[n>>2]|0)+i|0]=a[(c[g>>2]|0)+(i<<1&-4|i&1)|0]|0;i=i+1|0;}while(i>>>0<80);yB(c[d+120>>2]|0,0,40);yB(d+144|0,0,30);c[d+128>>2]=f?65828:70164;f=c[h>>2]|0;c[d+132>>2]=f;a[d+174|0]=-1;b[d+140>>1]=0;b[d+142>>1]=0;yB(d+175|0,0,9);h=c[g>>2]|0;i=h+325|0;a[d+184|0]=a[i]|0;a[d+185|0]=a[i]|0;a[d+189|0]=0;a[d+187|0]=0;a[d+188|0]=0;b[d+136>>1]=1234;b[d+138>>1]=0;a[d+186|0]=a[h+330|0]|0;a[d+190|0]=0;i=f>>>1&4095;f=i|4096;n=d+316|0;c[n>>2]=f;c[d+192>>2]=-1;m=f+4096&16382;j=d+196|0;C=0;b[j>>1]=C&65535;b[j+2>>1]=C>>16;c[d+200>>2]=m;a[d+204|0]=0;a[d+205|0]=0;c[d+208>>2]=-1;a[d+212|0]=0;c[d+216>>2]=-1;b[d+220>>1]=64;a[d+224|0]=0;a[d+225|0]=1;c[d+228>>2]=m;a[d+232|0]=0;a[d+233|0]=0;c[d+236>>2]=(i|266240)-(f+28672&32767);a[d+240|0]=0;c[d+244>>2]=-1;b[d+248>>1]=64;a[d+252|0]=0;a[d+253|0]=0;f=d+256|0;a[c[f>>2]|0]=a[h+304|0]|0;a[(c[f>>2]|0)+1|0]=a[(c[g>>2]|0)+305|0]|0;a[(c[f>>2]|0)+2|0]=a[(c[g>>2]|0)+306|0]|0;a[(c[f>>2]|0)+3|0]=a[(c[g>>2]|0)+307|0]|0;a[(c[f>>2]|0)+4|0]=a[(c[g>>2]|0)+308|0]|0;a[(c[f>>2]|0)+5|0]=a[(c[g>>2]|0)+309|0]|0;a[(c[f>>2]|0)+6|0]=a[(c[g>>2]|0)+310|0]|0;a[(c[f>>2]|0)+7|0]=a[(c[g>>2]|0)+311|0]|0;a[(c[f>>2]|0)+8|0]=a[(c[g>>2]|0)+312|0]|0;a[(c[f>>2]|0)+9|0]=a[(c[g>>2]|0)+313|0]|0;a[(c[f>>2]|0)+10|0]=a[(c[g>>2]|0)+314|0]|0;a[(c[f>>2]|0)+11|0]=a[(c[g>>2]|0)+315|0]|0;a[(c[f>>2]|0)+12|0]=a[(c[g>>2]|0)+316|0]|0;a[(c[f>>2]|0)+13|0]=a[(c[g>>2]|0)+317|0]|0;a[(c[f>>2]|0)+14|0]=a[(c[g>>2]|0)+318|0]|0;a[(c[f>>2]|0)+15|0]=a[(c[g>>2]|0)+319|0]|0;c[d+264>>2]=-1;b[d+268>>1]=256;c[d+272>>2]=-1;c[d+276>>2]=-1;yB(d+280|0,0,5);g=c[n>>2]|0;c[d+288>>2]=g+4;b[d+292>>1]=255;c[d+296>>2]=g+262144-(g+28672&32767);a[d+300|0]=0;c[d+304>>2]=-1;b[d+308>>1]=64;a[d+312|0]=0;a[d+313|0]=0;g=fp(0)|0;c[d+320>>2]=g;c[d+324>>2]=g;a[d+328|0]=5;yB(d+329|0,0,6);return}function kI(a){a=a|0;var b=0,d=0,e=0;b=(c[a>>2]|0)>>>0>=(c[a+4>>2]|0)>>>0|0;c[a+84>>2]=b;d=c[a+88>>2]|0;e=(c[a+(b<<2)>>2]|0)>>>0<(c[a+(d<<2)>>2]|0)>>>0?b:d;c[a+72>>2]=e;d=c[a+76>>2]|0;b=(c[a+(e<<2)>>2]|0)>>>0<(c[a+(d<<2)>>2]|0)>>>0?e:d;c[a+64>>2]=b;d=c[a+68>>2]|0;e=(c[a+(b<<2)>>2]|0)>>>0<(c[a+(d<<2)>>2]|0)>>>0?b:d;c[a+60>>2]=e;c[a+36>>2]=c[a+(e<<2)>>2];return}function kJ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;f=b+16908|0;if((c[f>>2]|0)!=-1){kO(b,e)}kM(b,e);g=b+16904|0;h=c[g>>2]|0;i=(e-h|0)>>>8;j=b+260|0;a[j]=(d[j]|0)+i&255;j=(i<<8)+h|0;c[g>>2]=j;if(e>>>0<65536){k=0}else{k=e-32768&-32768}if((j|0)!=-1){c[g>>2]=j-k}j=c[f>>2]|0;if((j|0)!=-1){c[f>>2]=j-k}j=b+16924|0;f=c[j>>2]|0;if((f|0)!=-1){c[j>>2]=f-k;f2[c[b+16956>>2]&1023](b+16912|0)}f=b+16928|0;j=c[f>>2]|0;if((j|0)!=-1){c[f>>2]=j-k;f2[c[b+16960>>2]&1023](b+16912|0)}j=b+16920|0;f=c[j>>2]|0;if((f|0)!=-1){c[j>>2]=f-k;f2[c[b+16956>>2]&1023](b+16912|0)}f=b+16916|0;j=c[f>>2]|0;if((j|0)!=-1){c[f>>2]=j-k;f2[c[b+16952>>2]&1023](b+16912|0)}j=b+16912|0;f=c[j>>2]|0;if((f|0)!=-1){c[j>>2]=f-k;f2[c[b+16952>>2]&1023](b+16912|0)}f=e-k|0;j=b+17016|0;g=c[j>>2]|0;h=g>>>0<e>>>0?0:g-k|0;c[j>>2]=h;j=b+16944|0;if((c[j>>2]|0)!=-1){c[j>>2]=h;c[b+17012>>2]=8;c[b+16992>>2]=8;c[b+16980>>2]=8;j=c[b+16976>>2]|0;g=(c[b+16912+(j<<2)>>2]|0)>>>0<h>>>0?j:8;c[b+16972>>2]=g;c[b+16948>>2]=c[b+16912+(g<<2)>>2]}g=a[b+17266|0]|0;do{if((g&4)!=0){j=b+16936|0;i=c[j>>2]|0;if(i>>>0>e>>>0){l=i;m=84328+(g&3)|0}else{n=b+17265|0;o=b+16940|0;p=b+17008|0;q=b+17004|0;r=b+16988|0;s=b+16984|0;t=b+16976|0;u=b+16980|0;v=b+16972|0;w=b+16948|0;x=b+17020|0;y=b+17024|0;z=b+16944|0;A=b+17012|0;B=b+16992|0;C=(a[b+17028|0]|0)==0;D=c[x>>2]|0;E=i;while(1){i=D|4;c[x>>2]=i;do{if(!C){if((c[y>>2]&i|0)==0){break}c[z>>2]=h;c[A>>2]=8;c[B>>2]=8;c[u>>2]=8;F=c[t>>2]|0;G=(c[b+16912+(F<<2)>>2]|0)>>>0<h>>>0?F:8;c[v>>2]=G;c[w>>2]=c[b+16912+(G<<2)>>2]}}while(0);G=84328+(g&3)|0;F=(256-(d[n]|0)<<d[G])+E|0;c[j>>2]=F;H=(c[o>>2]|0)>>>0>F>>>0?6:7;c[p>>2]=H;I=c[q>>2]|0;J=(c[b+16912+(I<<2)>>2]|0)>>>0<(c[b+16912+(H<<2)>>2]|0)>>>0?I:H;c[r>>2]=J;H=c[s>>2]|0;I=(c[b+16912+(H<<2)>>2]|0)>>>0<(c[b+16912+(J<<2)>>2]|0)>>>0?H:J;c[t>>2]=I;J=c[u>>2]|0;H=(c[b+16912+(I<<2)>>2]|0)>>>0<(c[b+16912+(J<<2)>>2]|0)>>>0?I:J;c[v>>2]=H;c[w>>2]=c[b+16912+(H<<2)>>2];if(F>>>0>e>>>0){l=F;m=G;break}else{D=i;E=F}}}E=b+17256|0;D=c[E>>2]|0;w=d[m]|0;v=(e-D|0)>>>(w>>>0);u=(v<<w)+D|0;c[E>>2]=u;D=b+17260|0;w=c[D>>2]|0;if(w>>>0>e>>>0){K=a[b+17264|0]|0;L=w}else{if((w+4|0)>>>0>e>>>0){M=w}else{c[D>>2]=-1;M=-1}w=a[b+17265|0]|0;a[b+17264|0]=w;K=w;L=M}w=b+17264|0;t=(K&255)+v|0;if(t>>>0>256){v=d[b+17265|0]|-256;s=t;while(1){r=s+v|0;if(r>>>0>256){s=r}else{N=r;break}}}else{N=t}do{if((N|0)==256){s=u+3|0;c[D>>2]=s;if(s>>>0>e>>>0){O=0;P=s;break}if((u+7|0)>>>0>e>>>0){Q=s}else{c[D>>2]=-1;Q=-1}O=a[b+17265|0]|0;P=Q}else{O=N&255;P=L}}while(0);a[w]=O;c[E>>2]=u-k;t=l-k|0;c[j>>2]=t;s=(c[b+16940>>2]|0)>>>0>t>>>0?6:7;c[b+17008>>2]=s;t=c[b+17004>>2]|0;v=(c[b+16912+(t<<2)>>2]|0)>>>0<(c[b+16912+(s<<2)>>2]|0)>>>0?t:s;c[b+16988>>2]=v;s=c[b+16984>>2]|0;t=(c[b+16912+(s<<2)>>2]|0)>>>0<(c[b+16912+(v<<2)>>2]|0)>>>0?s:v;c[b+16976>>2]=t;v=c[b+16980>>2]|0;s=(c[b+16912+(t<<2)>>2]|0)>>>0<(c[b+16912+(v<<2)>>2]|0)>>>0?t:v;c[b+16972>>2]=s;c[b+16948>>2]=c[b+16912+(s<<2)>>2];if((P|0)==-1){break}c[D>>2]=P-k}}while(0);P=b+17268|0;l=b+19362|0;do{if((a[l]|0)>-1){R=b+17532|0}else{O=b+19568|0;L=c[O>>2]|0;N=b+17532|0;Q=b+17559|0;K=b+17540|0;if(L>>>0<=e>>>0){M=P|0;m=b+19284|0;g=b+19288|0;h=b+17528|0;s=b+17558|0;v=b+19292|0;t=L;do{L=c[N>>2]|0;r=a[Q]&1;q=(t-L|0)>>>(r>>>0);c[N>>2]=(q<<r)+L;L=q+(c[K>>2]|0)|0;c[K>>2]=L;if((L|0)>-1){L=c[m>>2]|0;if((L|0)==0){S=566992}else{S=L+((ag(c[v>>2]|0,d[s]|0)|0)<<2)|0}c[g>>2]=S;f2[c[c[h>>2]>>2]&1023](M)}oY(P);t=c[O>>2]|0;}while(t>>>0<=e>>>0)}t=c[N>>2]|0;O=a[Q]&1;M=(e-t|0)>>>(O>>>0);c[N>>2]=(M<<O)+t;t=M+(c[K>>2]|0)|0;c[K>>2]=t;if((t|0)<=-1){R=N;break}t=c[b+19284>>2]|0;if((t|0)==0){T=566992}else{T=t+((ag(c[b+19292>>2]|0,d[b+17558|0]|0)|0)<<2)|0}c[b+19288>>2]=T;f2[c[c[b+17528>>2]>>2]&1023](P|0);R=N}}while(0);P=c[R>>2]|0;if((a[l]|0)<0){T=b+17558|0;S=b+17552|0;t=a[b+17559|0]|0;U=((d[T]|0)*456|0)+456-(((c[S>>2]|0)-P|0)>>>((t&1)>>>0))|0;V=t;W=T;X=S}else{U=0;V=a[b+17559|0]|0;W=b+17558|0;X=b+17552|0}S=P-k|0;c[R>>2]=S;R=b+17536|0;P=c[R>>2]|0;c[R>>2]=(P|0)==0?0:P-k|0;P=(U>>>0)/456|0;a[W]=P&255;c[X>>2]=(456-U+((P&255)*456|0)<<(V&1))+S;qC(b+19148|0,e);S=b+19276|0;c[S>>2]=(c[S>>2]|0)-k;if((a[l]|0)>-1){Y=b+19692|0;Z=b+17559|0;_=a[Z]|0;$=_&1;aa=$&255;kS(Y,e,aa);ab=b+20072|0;ac=c[ab>>2]|0;ad=ac-k|0;c[ab>>2]=ad;return f|0}c[b+19680>>2]=0;l=b+17552|0;pA(b+19668|0,l,f);S=b+19580|0;V=b+19612|0;P=b+19560|0;U=b+19564|0;X=b+19576|0;W=b+19568|0;R=b+19660|0;T=0;do{t=b+19580+(T<<2)|0;M=c[t>>2]|0;if((M|0)!=-1){c[t>>2]=M-k;f2[c[b+19616+(T>>1<<2)>>2]&1023](S);M=c[V>>2]|0;c[P>>2]=M;t=(c[U>>2]|0)>>>0<=M>>>0|0;c[X>>2]=t;c[W>>2]=c[b+19560+(t<<2)>>2];t=c[R>>2]|0;c[t+28>>2]=M;O=(c[t+24>>2]|0)>>>0<M>>>0?6:7;c[t+96>>2]=O;M=c[t+92>>2]|0;h=(c[t+(M<<2)>>2]|0)>>>0<(c[t+(O<<2)>>2]|0)>>>0?M:O;c[t+76>>2]=h;O=c[t+72>>2]|0;M=(c[t+(O<<2)>>2]|0)>>>0<(c[t+(h<<2)>>2]|0)>>>0?O:h;c[t+64>>2]=M;h=c[t+68>>2]|0;O=(c[t+(M<<2)>>2]|0)>>>0<(c[t+(h<<2)>>2]|0)>>>0?M:h;c[t+60>>2]=O;c[t+36>>2]=c[t+(O<<2)>>2]}T=T+1|0;}while((T|0)<8);T=c[l>>2]|0;c[U>>2]=T;U=(c[P>>2]|0)>>>0>=T>>>0|0;c[X>>2]=U;c[W>>2]=c[b+19560+(U<<2)>>2];Y=b+19692|0;Z=b+17559|0;_=a[Z]|0;$=_&1;aa=$&255;kS(Y,e,aa);ab=b+20072|0;ac=c[ab>>2]|0;ad=ac-k|0;c[ab>>2]=ad;return f|0}function kK(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[b+16908>>2]|0)!=-1){kO(b,f)}L5778:do{switch(e&127|0){case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:case 58:case 59:case 60:case 61:case 62:case 63:{kS(b+19692|0,f,a[b+17559|0]&1);if((a[b+19974|0]&1)==0){g=e&15}else{do{if((a[b+19975|0]&1)==0){if((c[b+19948>>2]|0)==(c[b+19964>>2]|0)){break}else{h=255}return h|0}}while(0);g=(d[b+19971|0]|0)>>>1}h=d[b+19904+g|0]|0;return h|0};case 65:{h=d[b+321|0]|(oX(b+17268|0,d[b+325|0]|0,f)|0);return h|0};case 68:{if((a[b+19362|0]|0)>-1){h=0;return h|0}i=b+17552|0;if((c[i>>2]|0)>>>0<=f>>>0){oQ(b+17268|0,f)}j=a[b+17558|0]|0;if(j<<24>>24==-103){h=0;return h|0}h=(((c[i>>2]|0)-f|0)>>>0<5)+(j&255)|0;return h|0};case 105:{j=a[b+360|0]|0;if(!((a[b+19379|0]&1)!=0&(oT(b+17268|0,f)|0))){h=255;return h|0}h=d[(j&63)+(b+19432)|0]|0;return h|0};case 107:{j=a[b+362|0]|0;if(!((a[b+19379|0]&1)!=0&(oT(b+17268|0,f)|0))){h=255;return h|0}h=d[(j&63)+(b+19496)|0]|0;return h|0};case 15:{kM(b,f);a[b+271|0]=c[b+17020>>2]&255;break};case 5:{a[b+261|0]=(oM(b+17256|0,f)|0)&255;break};case 4:{j=b+16904|0;i=c[j>>2]|0;k=(f-i|0)>>>8;l=b+260|0;a[l]=(d[l]|0)+k&255;c[j>>2]=(k<<8)+i;break};case 0:{i=c[b+16900>>2]|0;if((i|0)==0){m=255;n=255}else{k=f5[c[(c[i>>2]|0)+8>>2]&255](i)|0;m=k&15^255;n=k>>>4&15^255}k=b+256|0;i=a[k]|15;j=i&255;if((j&16|0)==0){o=j&n&255}else{o=i}i=o&255;if((i&32|0)==0){p=i&m&255}else{p=o}a[k]=p;break};case 38:{k=b+294|0;if((a[k]|0)<0){kS(b+19692|0,f,a[b+17559|0]&1);a[k]=a[b+19805|0]&1|a[b+19901|0]<<1&2|a[b+19974|0]<<2&4|a[b+20065|0]<<3|-16;break L5778}else{a[k]=112;break L5778}break};default:{}}}while(0);h=d[b+(e-65024)|0]|0;return h|0}
function wC(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0;b=i;i=i+448|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;l=b+112|0;m=b+128|0;n=b+144|0;o=b+160|0;p=b+176|0;q=b+192|0;r=b+208|0;s=b+224|0;t=b+240|0;u=b+256|0;v=b+272|0;w=b+288|0;x=b+304|0;y=b+320|0;z=b+336|0;A=b+352|0;B=b+368|0;C=b+384|0;D=b+400|0;E=b+416|0;F=b+432|0;if((a[741344]|0)!=0){G=c[141564]|0;i=b;return G|0}if((cR(741344)|0)==0){G=c[141564]|0;i=b;return G|0}do{if((a[741352]|0)==0){if((cR(741352)|0)==0){break}c[141611]=0;c[141610]=73888;a[566576]=1;c[141613]=566464;c[141612]=566464;c[141614]=566576;H=28;J=566464;do{if((J|0)==0){K=0}else{c[J>>2]=0;K=c[141613]|0}J=K+4|0;c[141613]=J;H=H-1|0;}while((H|0)!=0);a[566584]=2;a[566585]=67;a[566586]=0;H=c[141612]|0;if((H|0)!=(J|0)){c[141613]=K+(-((K+(-H|0)|0)>>>2)<<2)}c[141603]=0;c[141602]=73592;if((c[185090]|0)!=-1){c[F>>2]=740360;c[F+4>>2]=210;c[F+8>>2]=0;st(740360,F)}H=c[185091]|0;L=H-1|0;I=c[141603]|0,c[141603]=I+1,I;M=c[141613]|0;N=c[141612]|0;O=M-N>>2;do{if(O>>>0>L>>>0){P=N}else{if(O>>>0<H>>>0){x0(566448,H-O|0);P=c[141612]|0;break}if(O>>>0<=H>>>0){P=N;break}Q=N+(H<<2)|0;if((Q|0)==(M|0)){P=N;break}c[141613]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);P=N}}while(0);N=c[P+(L<<2)>>2]|0;if((N|0)==0){R=P}else{M=N+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){f2[c[(c[N>>2]|0)+8>>2]&1023](N|0)}R=c[141612]|0}c[R+(L<<2)>>2]=566408;c[141601]=0;c[141600]=73552;if((c[185088]|0)!=-1){c[E>>2]=740352;c[E+4>>2]=210;c[E+8>>2]=0;st(740352,E)}N=c[185089]|0;M=N-1|0;I=c[141601]|0,c[141601]=I+1,I;H=c[141613]|0;O=c[141612]|0;J=H-O>>2;do{if(J>>>0>M>>>0){S=O}else{if(J>>>0<N>>>0){x0(566448,N-J|0);S=c[141612]|0;break}if(J>>>0<=N>>>0){S=O;break}Q=O+(N<<2)|0;if((Q|0)==(H|0)){S=O;break}c[141613]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);S=O}}while(0);O=c[S+(M<<2)>>2]|0;if((O|0)==0){T=S}else{H=O+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){f2[c[(c[O>>2]|0)+8>>2]&1023](O|0)}T=c[141612]|0}c[T+(M<<2)>>2]=566400;c[141653]=0;c[141652]=74e3;c[141654]=0;a[566620]=0;c[141654]=c[(cD()|0)>>2];if((c[185170]|0)!=-1){c[D>>2]=740680;c[D+4>>2]=210;c[D+8>>2]=0;st(740680,D)}O=c[185171]|0;H=O-1|0;I=c[141653]|0,c[141653]=I+1,I;N=c[141613]|0;J=c[141612]|0;L=N-J>>2;do{if(L>>>0>H>>>0){U=J}else{if(L>>>0<O>>>0){x0(566448,O-L|0);U=c[141612]|0;break}if(L>>>0<=O>>>0){U=J;break}Q=J+(O<<2)|0;if((Q|0)==(N|0)){U=J;break}c[141613]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);U=J}}while(0);J=c[U+(H<<2)>>2]|0;if((J|0)==0){V=U}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){f2[c[(c[J>>2]|0)+8>>2]&1023](J|0)}V=c[141612]|0}c[V+(H<<2)>>2]=566608;c[141651]=0;c[141650]=73920;if((c[185168]|0)!=-1){c[C>>2]=740672;c[C+4>>2]=210;c[C+8>>2]=0;st(740672,C)}J=c[185169]|0;N=J-1|0;I=c[141651]|0,c[141651]=I+1,I;O=c[141613]|0;L=c[141612]|0;M=O-L>>2;do{if(M>>>0>N>>>0){W=L}else{if(M>>>0<J>>>0){x0(566448,J-M|0);W=c[141612]|0;break}if(M>>>0<=J>>>0){W=L;break}Q=L+(J<<2)|0;if((Q|0)==(O|0)){W=L;break}c[141613]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);W=L}}while(0);L=c[W+(N<<2)>>2]|0;if((L|0)==0){X=W}else{O=L+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){f2[c[(c[L>>2]|0)+8>>2]&1023](L|0)}X=c[141612]|0}c[X+(N<<2)>>2]=566600;c[141605]=0;c[141604]=73688;if((c[185094]|0)!=-1){c[B>>2]=740376;c[B+4>>2]=210;c[B+8>>2]=0;st(740376,B)}L=c[185095]|0;O=L-1|0;I=c[141605]|0,c[141605]=I+1,I;J=c[141613]|0;M=c[141612]|0;H=J-M>>2;do{if(H>>>0>O>>>0){Y=M}else{if(H>>>0<L>>>0){x0(566448,L-H|0);Y=c[141612]|0;break}if(H>>>0<=L>>>0){Y=M;break}Q=M+(L<<2)|0;if((Q|0)==(J|0)){Y=M;break}c[141613]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);Y=M}}while(0);M=c[Y+(O<<2)>>2]|0;if((M|0)==0){Z=Y}else{J=M+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f2[c[(c[M>>2]|0)+8>>2]&1023](M|0)}Z=c[141612]|0}c[Z+(O<<2)>>2]=566416;c[13871]=0;c[13870]=73632;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);c[13872]=c[141570];if((c[185092]|0)!=-1){c[A>>2]=740368;c[A+4>>2]=210;c[A+8>>2]=0;st(740368,A)}O=c[185093]|0;M=O-1|0;I=c[13871]|0,c[13871]=I+1,I;J=c[141613]|0;L=c[141612]|0;H=J-L>>2;do{if(H>>>0>M>>>0){_=L}else{if(H>>>0<O>>>0){x0(566448,O-H|0);_=c[141612]|0;break}if(H>>>0<=O>>>0){_=L;break}N=L+(O<<2)|0;if((N|0)==(J|0)){_=L;break}c[141613]=J+(~((J-4+(-N|0)|0)>>>2)<<2);_=L}}while(0);L=c[_+(M<<2)>>2]|0;if((L|0)==0){$=_}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f2[c[(c[L>>2]|0)+8>>2]&1023](L|0)}$=c[141612]|0}c[$+(M<<2)>>2]=55480;c[141607]=0;c[141606]=73744;if((c[185096]|0)!=-1){c[z>>2]=740384;c[z+4>>2]=210;c[z+8>>2]=0;st(740384,z)}L=c[185097]|0;J=L-1|0;I=c[141607]|0,c[141607]=I+1,I;O=c[141613]|0;H=c[141612]|0;N=O-H>>2;do{if(N>>>0>J>>>0){aa=H}else{if(N>>>0<L>>>0){x0(566448,L-N|0);aa=c[141612]|0;break}if(N>>>0<=L>>>0){aa=H;break}Q=H+(L<<2)|0;if((Q|0)==(O|0)){aa=H;break}c[141613]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);aa=H}}while(0);H=c[aa+(J<<2)>>2]|0;if((H|0)==0){ab=aa}else{O=H+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){f2[c[(c[H>>2]|0)+8>>2]&1023](H|0)}ab=c[141612]|0}c[ab+(J<<2)>>2]=566424;c[141609]=0;c[141608]=73800;if((c[185098]|0)!=-1){c[y>>2]=740392;c[y+4>>2]=210;c[y+8>>2]=0;st(740392,y)}H=c[185099]|0;O=H-1|0;I=c[141609]|0,c[141609]=I+1,I;L=c[141613]|0;N=c[141612]|0;M=L-N>>2;do{if(M>>>0>O>>>0){ac=N}else{if(M>>>0<H>>>0){x0(566448,H-M|0);ac=c[141612]|0;break}if(M>>>0<=H>>>0){ac=N;break}Q=N+(H<<2)|0;if((Q|0)==(L|0)){ac=N;break}c[141613]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);ac=N}}while(0);N=c[ac+(O<<2)>>2]|0;if((N|0)==0){ad=ac}else{L=N+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f2[c[(c[N>>2]|0)+8>>2]&1023](N|0)}ad=c[141612]|0}c[ad+(O<<2)>>2]=566432;c[141583]=0;c[141582]=73096;a[566336]=46;a[566337]=44;yB(566340,0,12);if((c[185074]|0)!=-1){c[x>>2]=740296;c[x+4>>2]=210;c[x+8>>2]=0;st(740296,x)}N=c[185075]|0;L=N-1|0;I=c[141583]|0,c[141583]=I+1,I;H=c[141613]|0;M=c[141612]|0;J=H-M>>2;do{if(J>>>0>L>>>0){ae=M}else{if(J>>>0<N>>>0){x0(566448,N-J|0);ae=c[141612]|0;break}if(J>>>0<=N>>>0){ae=M;break}Q=M+(N<<2)|0;if((Q|0)==(H|0)){ae=M;break}c[141613]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);ae=M}}while(0);M=c[ae+(L<<2)>>2]|0;if((M|0)==0){af=ae}else{H=M+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){f2[c[(c[M>>2]|0)+8>>2]&1023](M|0)}af=c[141612]|0}c[af+(L<<2)>>2]=566328;c[13863]=0;c[13862]=73048;c[13864]=46;c[13865]=44;yB(55464,0,12);if((c[185072]|0)!=-1){c[w>>2]=740288;c[w+4>>2]=210;c[w+8>>2]=0;st(740288,w)}M=c[185073]|0;H=M-1|0;I=c[13863]|0,c[13863]=I+1,I;N=c[141613]|0;J=c[141612]|0;O=N-J>>2;do{if(O>>>0>H>>>0){ag=J}else{if(O>>>0<M>>>0){x0(566448,M-O|0);ag=c[141612]|0;break}if(O>>>0<=M>>>0){ag=J;break}Q=J+(M<<2)|0;if((Q|0)==(N|0)){ag=J;break}c[141613]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);ag=J}}while(0);J=c[ag+(H<<2)>>2]|0;if((J|0)==0){ah=ag}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){f2[c[(c[J>>2]|0)+8>>2]&1023](J|0)}ah=c[141612]|0}c[ah+(H<<2)>>2]=55448;c[141599]=0;c[141598]=73480;if((c[185086]|0)!=-1){c[v>>2]=740344;c[v+4>>2]=210;c[v+8>>2]=0;st(740344,v)}J=c[185087]|0;N=J-1|0;I=c[141599]|0,c[141599]=I+1,I;M=c[141613]|0;O=c[141612]|0;L=M-O>>2;do{if(L>>>0>N>>>0){ai=O}else{if(L>>>0<J>>>0){x0(566448,J-L|0);ai=c[141612]|0;break}if(L>>>0<=J>>>0){ai=O;break}Q=O+(J<<2)|0;if((Q|0)==(M|0)){ai=O;break}c[141613]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);ai=O}}while(0);O=c[ai+(N<<2)>>2]|0;if((O|0)==0){aj=ai}else{M=O+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){f2[c[(c[O>>2]|0)+8>>2]&1023](O|0)}aj=c[141612]|0}c[aj+(N<<2)>>2]=566392;c[141597]=0;c[141596]=73408;if((c[185084]|0)!=-1){c[u>>2]=740336;c[u+4>>2]=210;c[u+8>>2]=0;st(740336,u)}O=c[185085]|0;M=O-1|0;I=c[141597]|0,c[141597]=I+1,I;J=c[141613]|0;L=c[141612]|0;H=J-L>>2;do{if(H>>>0>M>>>0){ak=L}else{if(H>>>0<O>>>0){x0(566448,O-H|0);ak=c[141612]|0;break}if(H>>>0<=O>>>0){ak=L;break}Q=L+(O<<2)|0;if((Q|0)==(J|0)){ak=L;break}c[141613]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);ak=L}}while(0);L=c[ak+(M<<2)>>2]|0;if((L|0)==0){al=ak}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f2[c[(c[L>>2]|0)+8>>2]&1023](L|0)}al=c[141612]|0}c[al+(M<<2)>>2]=566384;c[141595]=0;c[141594]=73344;if((c[185082]|0)!=-1){c[t>>2]=740328;c[t+4>>2]=210;c[t+8>>2]=0;st(740328,t)}L=c[185083]|0;J=L-1|0;I=c[141595]|0,c[141595]=I+1,I;O=c[141613]|0;H=c[141612]|0;N=O-H>>2;do{if(N>>>0>J>>>0){am=H}else{if(N>>>0<L>>>0){x0(566448,L-N|0);am=c[141612]|0;break}if(N>>>0<=L>>>0){am=H;break}Q=H+(L<<2)|0;if((Q|0)==(O|0)){am=H;break}c[141613]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);am=H}}while(0);H=c[am+(J<<2)>>2]|0;if((H|0)==0){an=am}else{O=H+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){f2[c[(c[H>>2]|0)+8>>2]&1023](H|0)}an=c[141612]|0}c[an+(J<<2)>>2]=566376;c[141593]=0;c[141592]=73280;if((c[185080]|0)!=-1){c[s>>2]=740320;c[s+4>>2]=210;c[s+8>>2]=0;st(740320,s)}H=c[185081]|0;O=H-1|0;I=c[141593]|0,c[141593]=I+1,I;L=c[141613]|0;N=c[141612]|0;M=L-N>>2;do{if(M>>>0>O>>>0){ao=N}else{if(M>>>0<H>>>0){x0(566448,H-M|0);ao=c[141612]|0;break}if(M>>>0<=H>>>0){ao=N;break}Q=N+(H<<2)|0;if((Q|0)==(L|0)){ao=N;break}c[141613]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);ao=N}}while(0);N=c[ao+(O<<2)>>2]|0;if((N|0)==0){ap=ao}else{L=N+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f2[c[(c[N>>2]|0)+8>>2]&1023](N|0)}ap=c[141612]|0}c[ap+(O<<2)>>2]=566368;c[141663]=0;c[141662]=75192;if((c[185290]|0)!=-1){c[r>>2]=741160;c[r+4>>2]=210;c[r+8>>2]=0;st(741160,r)}N=c[185291]|0;L=N-1|0;I=c[141663]|0,c[141663]=I+1,I;H=c[141613]|0;M=c[141612]|0;J=H-M>>2;do{if(J>>>0>L>>>0){aq=M}else{if(J>>>0<N>>>0){x0(566448,N-J|0);aq=c[141612]|0;break}if(J>>>0<=N>>>0){aq=M;break}Q=M+(N<<2)|0;if((Q|0)==(H|0)){aq=M;break}c[141613]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);aq=M}}while(0);M=c[aq+(L<<2)>>2]|0;if((M|0)==0){ar=aq}else{H=M+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){f2[c[(c[M>>2]|0)+8>>2]&1023](M|0)}ar=c[141612]|0}c[ar+(L<<2)>>2]=566648;c[141661]=0;c[141660]=75128;if((c[185288]|0)!=-1){c[q>>2]=741152;c[q+4>>2]=210;c[q+8>>2]=0;st(741152,q)}M=c[185289]|0;H=M-1|0;I=c[141661]|0,c[141661]=I+1,I;N=c[141613]|0;J=c[141612]|0;O=N-J>>2;do{if(O>>>0>H>>>0){as=J}else{if(O>>>0<M>>>0){x0(566448,M-O|0);as=c[141612]|0;break}if(O>>>0<=M>>>0){as=J;break}Q=J+(M<<2)|0;if((Q|0)==(N|0)){as=J;break}c[141613]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);as=J}}while(0);J=c[as+(H<<2)>>2]|0;if((J|0)==0){at=as}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){f2[c[(c[J>>2]|0)+8>>2]&1023](J|0)}at=c[141612]|0}c[at+(H<<2)>>2]=566640;c[141659]=0;c[141658]=75064;if((c[185286]|0)!=-1){c[p>>2]=741144;c[p+4>>2]=210;c[p+8>>2]=0;st(741144,p)}J=c[185287]|0;N=J-1|0;I=c[141659]|0,c[141659]=I+1,I;M=c[141613]|0;O=c[141612]|0;L=M-O>>2;do{if(L>>>0>N>>>0){au=O}else{if(L>>>0<J>>>0){x0(566448,J-L|0);au=c[141612]|0;break}if(L>>>0<=J>>>0){au=O;break}Q=O+(J<<2)|0;if((Q|0)==(M|0)){au=O;break}c[141613]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);au=O}}while(0);O=c[au+(N<<2)>>2]|0;if((O|0)==0){av=au}else{M=O+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){f2[c[(c[O>>2]|0)+8>>2]&1023](O|0)}av=c[141612]|0}c[av+(N<<2)>>2]=566632;c[141657]=0;c[141656]=75e3;if((c[185284]|0)!=-1){c[o>>2]=741136;c[o+4>>2]=210;c[o+8>>2]=0;st(741136,o)}O=c[185285]|0;M=O-1|0;I=c[141657]|0,c[141657]=I+1,I;J=c[141613]|0;L=c[141612]|0;H=J-L>>2;do{if(H>>>0>M>>>0){aw=L}else{if(H>>>0<O>>>0){x0(566448,O-H|0);aw=c[141612]|0;break}if(H>>>0<=O>>>0){aw=L;break}Q=L+(O<<2)|0;if((Q|0)==(J|0)){aw=L;break}c[141613]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);aw=L}}while(0);L=c[aw+(M<<2)>>2]|0;if((L|0)==0){ax=aw}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f2[c[(c[L>>2]|0)+8>>2]&1023](L|0)}ax=c[141612]|0}c[ax+(M<<2)>>2]=566624;c[141581]=0;c[141580]=72752;if((c[185062]|0)!=-1){c[n>>2]=740248;c[n+4>>2]=210;c[n+8>>2]=0;st(740248,n)}L=c[185063]|0;J=L-1|0;I=c[141581]|0,c[141581]=I+1,I;O=c[141613]|0;H=c[141612]|0;N=O-H>>2;do{if(N>>>0>J>>>0){ay=H}else{if(N>>>0<L>>>0){x0(566448,L-N|0);ay=c[141612]|0;break}if(N>>>0<=L>>>0){ay=H;break}Q=H+(L<<2)|0;if((Q|0)==(O|0)){ay=H;break}c[141613]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);ay=H}}while(0);H=c[ay+(J<<2)>>2]|0;if((H|0)==0){az=ay}else{O=H+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){f2[c[(c[H>>2]|0)+8>>2]&1023](H|0)}az=c[141612]|0}c[az+(J<<2)>>2]=566320;c[141579]=0;c[141578]=72712;if((c[185060]|0)!=-1){c[m>>2]=740240;c[m+4>>2]=210;c[m+8>>2]=0;st(740240,m)}H=c[185061]|0;O=H-1|0;I=c[141579]|0,c[141579]=I+1,I;L=c[141613]|0;N=c[141612]|0;M=L-N>>2;do{if(M>>>0>O>>>0){aA=N}else{if(M>>>0<H>>>0){x0(566448,H-M|0);aA=c[141612]|0;break}if(M>>>0<=H>>>0){aA=N;break}Q=N+(H<<2)|0;if((Q|0)==(L|0)){aA=N;break}c[141613]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);aA=N}}while(0);N=c[aA+(O<<2)>>2]|0;if((N|0)==0){aB=aA}else{L=N+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f2[c[(c[N>>2]|0)+8>>2]&1023](N|0)}aB=c[141612]|0}c[aB+(O<<2)>>2]=566312;c[141577]=0;c[141576]=72672;if((c[185058]|0)!=-1){c[l>>2]=740232;c[l+4>>2]=210;c[l+8>>2]=0;st(740232,l)}N=c[185059]|0;L=N-1|0;I=c[141577]|0,c[141577]=I+1,I;H=c[141613]|0;M=c[141612]|0;J=H-M>>2;do{if(J>>>0>L>>>0){aC=M}else{if(J>>>0<N>>>0){x0(566448,N-J|0);aC=c[141612]|0;break}if(J>>>0<=N>>>0){aC=M;break}Q=M+(N<<2)|0;if((Q|0)==(H|0)){aC=M;break}c[141613]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);aC=M}}while(0);M=c[aC+(L<<2)>>2]|0;if((M|0)==0){aD=aC}else{H=M+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){f2[c[(c[M>>2]|0)+8>>2]&1023](M|0)}aD=c[141612]|0}c[aD+(L<<2)>>2]=566304;c[141575]=0;c[141574]=72632;if((c[185056]|0)!=-1){c[k>>2]=740224;c[k+4>>2]=210;c[k+8>>2]=0;st(740224,k)}M=c[185057]|0;H=M-1|0;I=c[141575]|0,c[141575]=I+1,I;N=c[141613]|0;J=c[141612]|0;O=N-J>>2;do{if(O>>>0>H>>>0){aE=J}else{if(O>>>0<M>>>0){x0(566448,M-O|0);aE=c[141612]|0;break}if(O>>>0<=M>>>0){aE=J;break}Q=J+(M<<2)|0;if((Q|0)==(N|0)){aE=J;break}c[141613]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);aE=J}}while(0);J=c[aE+(H<<2)>>2]|0;if((J|0)==0){aF=aE}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){f2[c[(c[J>>2]|0)+8>>2]&1023](J|0)}aF=c[141612]|0}c[aF+(H<<2)>>2]=566296;c[13859]=0;c[13858]=72952;c[13860]=73e3;if((c[185070]|0)!=-1){c[j>>2]=740280;c[j+4>>2]=210;c[j+8>>2]=0;st(740280,j)}J=c[185071]|0;N=J-1|0;I=c[13859]|0,c[13859]=I+1,I;M=c[141613]|0;O=c[141612]|0;L=M-O>>2;do{if(L>>>0>N>>>0){aG=O}else{if(L>>>0<J>>>0){x0(566448,J-L|0);aG=c[141612]|0;break}if(L>>>0<=J>>>0){aG=O;break}Q=O+(J<<2)|0;if((Q|0)==(M|0)){aG=O;break}c[141613]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);aG=O}}while(0);O=c[aG+(N<<2)>>2]|0;if((O|0)==0){aH=aG}else{M=O+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){f2[c[(c[O>>2]|0)+8>>2]&1023](O|0)}aH=c[141612]|0}c[aH+(N<<2)>>2]=55432;c[13855]=0;c[13854]=72856;c[13856]=72904;if((c[185068]|0)!=-1){c[h>>2]=740272;c[h+4>>2]=210;c[h+8>>2]=0;st(740272,h)}O=c[185069]|0;M=O-1|0;I=c[13855]|0,c[13855]=I+1,I;J=c[141613]|0;L=c[141612]|0;H=J-L>>2;do{if(H>>>0>M>>>0){aI=L}else{if(H>>>0<O>>>0){x0(566448,O-H|0);aI=c[141612]|0;break}if(H>>>0<=O>>>0){aI=L;break}Q=L+(O<<2)|0;if((Q|0)==(J|0)){aI=L;break}c[141613]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);aI=L}}while(0);L=c[aI+(M<<2)>>2]|0;if((L|0)==0){aJ=aI}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f2[c[(c[L>>2]|0)+8>>2]&1023](L|0)}aJ=c[141612]|0}c[aJ+(M<<2)>>2]=55416;c[13851]=0;c[13850]=73856;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);c[13852]=c[141570];c[13850]=72824;if((c[185066]|0)!=-1){c[g>>2]=740264;c[g+4>>2]=210;c[g+8>>2]=0;st(740264,g)}M=c[185067]|0;L=M-1|0;I=c[13851]|0,c[13851]=I+1,I;J=c[141613]|0;O=c[141612]|0;H=J-O>>2;do{if(H>>>0>L>>>0){aK=O}else{if(H>>>0<M>>>0){x0(566448,M-H|0);aK=c[141612]|0;break}if(H>>>0<=M>>>0){aK=O;break}N=O+(M<<2)|0;if((N|0)==(J|0)){aK=O;break}c[141613]=J+(~((J-4+(-N|0)|0)>>>2)<<2);aK=O}}while(0);O=c[aK+(L<<2)>>2]|0;if((O|0)==0){aL=aK}else{J=O+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f2[c[(c[O>>2]|0)+8>>2]&1023](O|0)}aL=c[141612]|0}c[aL+(L<<2)>>2]=55400;c[13847]=0;c[13846]=73856;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);c[13848]=c[141570];c[13846]=72792;if((c[185064]|0)!=-1){c[f>>2]=740256;c[f+4>>2]=210;c[f+8>>2]=0;st(740256,f)}L=c[185065]|0;O=L-1|0;I=c[13847]|0,c[13847]=I+1,I;J=c[141613]|0;M=c[141612]|0;H=J-M>>2;do{if(H>>>0>O>>>0){aM=M}else{if(H>>>0<L>>>0){x0(566448,L-H|0);aM=c[141612]|0;break}if(H>>>0<=L>>>0){aM=M;break}N=M+(L<<2)|0;if((N|0)==(J|0)){aM=M;break}c[141613]=J+(~((J-4+(-N|0)|0)>>>2)<<2);aM=M}}while(0);M=c[aM+(O<<2)>>2]|0;if((M|0)==0){aN=aM}else{J=M+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f2[c[(c[M>>2]|0)+8>>2]&1023](M|0)}aN=c[141612]|0}c[aN+(O<<2)>>2]=55384;c[141591]=0;c[141590]=73184;if((c[185078]|0)!=-1){c[e>>2]=740312;c[e+4>>2]=210;c[e+8>>2]=0;st(740312,e)}M=c[185079]|0;J=M-1|0;I=c[141591]|0,c[141591]=I+1,I;L=c[141613]|0;H=c[141612]|0;N=L-H>>2;do{if(N>>>0>J>>>0){aO=H}else{if(N>>>0<M>>>0){x0(566448,M-N|0);aO=c[141612]|0;break}if(N>>>0<=M>>>0){aO=H;break}Q=H+(M<<2)|0;if((Q|0)==(L|0)){aO=H;break}c[141613]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);aO=H}}while(0);H=c[aO+(J<<2)>>2]|0;if((H|0)==0){aP=aO}else{L=H+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f2[c[(c[H>>2]|0)+8>>2]&1023](H|0)}aP=c[141612]|0}c[aP+(J<<2)>>2]=566360;c[141589]=0;c[141588]=73144;if((c[185076]|0)!=-1){c[d>>2]=740304;c[d+4>>2]=210;c[d+8>>2]=0;st(740304,d)}H=c[185077]|0;L=H-1|0;I=c[141589]|0,c[141589]=I+1,I;M=c[141613]|0;N=c[141612]|0;O=M-N>>2;do{if(O>>>0>L>>>0){aQ=N}else{if(O>>>0<H>>>0){x0(566448,H-O|0);aQ=c[141612]|0;break}if(O>>>0<=H>>>0){aQ=N;break}Q=N+(H<<2)|0;if((Q|0)==(M|0)){aQ=N;break}c[141613]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);aQ=N}}while(0);N=c[aQ+(L<<2)>>2]|0;if((N|0)==0){aR=aQ}else{M=N+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){f2[c[(c[N>>2]|0)+8>>2]&1023](N|0)}aR=c[141612]|0}c[aR+(L<<2)>>2]=566352;c[141566]=566440}}while(0);aR=c[141566]|0;c[141568]=aR;aQ=aR+4|0;I=c[aQ>>2]|0,c[aQ>>2]=I+1,I;c[141564]=566272;G=c[141564]|0;i=b;return G|0}function wD(a,b){a=a|0;b=b|0;return b|0}function wE(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[f>>2]=d;c[i>>2]=g;return 3}function wF(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[f>>2]=d;c[i>>2]=g;return 3}function wG(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;return 3}function wH(a){a=a|0;return 1}function wI(a){a=a|0;return 1}function wJ(a){a=a|0;return 1}function wK(a,b){a=a|0;b=b|0;return b<<24>>24|0}function wL(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b&255:c)|0}function wM(a,b,c){a=a|0;b=b|0;c=c|0;return(b<<24>>24>-1?b:c)|0}function wN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b=d-c|0;return(b>>>0<e>>>0?b:e)|0}function wO(a){a=a|0;c[a+4>>2]=(I=c[185100]|0,c[185100]=I+1,I)+1;return}function wP(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((d|0)==(e|0)){g=d;return g|0}else{h=d;i=f}while(1){c[i>>2]=a[h]|0;f=h+1|0;if((f|0)==(e|0)){g=e;break}else{h=f;i=i+4|0}}return g|0}function wQ(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((d|0)==(e|0)){h=d;return h|0}b=(e-4+(-d|0)|0)>>>2;i=d;j=g;while(1){g=c[i>>2]|0;a[j]=g>>>0<128?g&255:f;g=i+4|0;if((g|0)==(e|0)){break}else{i=g;j=j+1|0}}h=d+(b+1<<2)|0;return h|0}function wR(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((c|0)==(d|0)){f=c;return f|0}else{g=c;h=e}while(1){a[h]=a[g]|0;e=g+1|0;if((e|0)==(d|0)){f=d;break}else{g=e;h=h+1|0}}return f|0}function wS(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((c|0)==(d|0)){g=c;return g|0}else{h=c;i=f}while(1){f=a[h]|0;a[i]=f<<24>>24>-1?f:e;f=h+1|0;if((f|0)==(d|0)){g=d;break}else{h=f;i=i+1|0}}return g|0}function wT(a){a=a|0;if((a|0)==0){return}yt(a);return}function wU(a){a=a|0;if((a|0)==0){return}f2[c[(c[a>>2]|0)+4>>2]&1023](a);return}function wV(a){a=a|0;if((a|0)==0){return}yt(a);return}function wW(b){b=b|0;var d=0;c[b>>2]=74e3;d=c[b+8>>2]|0;do{if((d|0)!=0){if((a[b+12|0]&1)!=0){yt(d)}if((b|0)!=0){break}return}}while(0);yt(b);return}function wX(b){b=b|0;var d=0;c[b>>2]=74e3;d=c[b+8>>2]|0;if((d|0)==0){return}if((a[b+12|0]&1)==0){return}yt(d);return}function wY(a){a=a|0;if((a|0)==0){return}yt(a);return}function wZ(a,d,e){a=a|0;d=d|0;e=e|0;var f=0;if(e>>>0>=128){f=0;return f|0}f=(b[(c[(cD()|0)>>2]|0)+(e<<1)>>1]&d)<<16>>16!=0;return f|0}function w_(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((d|0)==(e|0)){g=d;return g|0}else{h=d;i=f}while(1){f=c[h>>2]|0;if(f>>>0<128){j=b[(c[(cD()|0)>>2]|0)+(f<<1)>>1]|0}else{j=0}b[i>>1]=j;f=h+4|0;if((f|0)==(e|0)){g=e;break}else{h=f;i=i+2|0}}return g|0}function w$(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((e|0)==(f|0)){g=e;return g|0}else{h=e}while(1){e=c[h>>2]|0;if(e>>>0<128){if((b[(c[(cD()|0)>>2]|0)+(e<<1)>>1]&d)<<16>>16!=0){g=h;i=3561;break}}e=h+4|0;if((e|0)==(f|0)){g=f;i=3559;break}else{h=e}}if((i|0)==3559){return g|0}else if((i|0)==3561){return g|0}return 0}function w0(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=e;while(1){if((a|0)==(f|0)){g=f;h=3571;break}e=c[a>>2]|0;if(e>>>0>=128){g=a;h=3570;break}if((b[(c[(cD()|0)>>2]|0)+(e<<1)>>1]&d)<<16>>16==0){g=a;h=3569;break}else{a=a+4|0}}if((h|0)==3570){return g|0}else if((h|0)==3569){return g|0}else if((h|0)==3571){return g|0}return 0}function w1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>=128){d=b;return d|0}d=c[(c[(fq()|0)>>2]|0)+(b<<2)>>2]|0;return d|0}function w2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==(d|0)){e=b;return e|0}else{f=b}while(1){b=c[f>>2]|0;if(b>>>0<128){g=c[(c[(fq()|0)>>2]|0)+(b<<2)>>2]|0}else{g=b}c[f>>2]=g;b=f+4|0;if((b|0)==(d|0)){e=d;break}else{f=b}}return e|0}function w3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>=128){d=b;return d|0}d=c[(c[(fw()|0)>>2]|0)+(b<<2)>>2]|0;return d|0}function w4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==(d|0)){e=b;return e|0}else{f=b}while(1){b=c[f>>2]|0;if(b>>>0<128){g=c[(c[(fw()|0)>>2]|0)+(b<<2)>>2]|0}else{g=b}c[f>>2]=g;b=f+4|0;if((b|0)==(d|0)){e=d;break}else{f=b}}return e|0}function w5(a,b){a=a|0;b=b|0;var d=0;if(b<<24>>24<=-1){d=b;return d|0}d=c[(c[(fq()|0)>>2]|0)+((b&255)<<2)>>2]&255;return d|0}function w6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==(e|0)){f=d;return f|0}else{g=d}while(1){d=a[g]|0;if(d<<24>>24>-1){h=c[(c[(fq()|0)>>2]|0)+(d<<24>>24<<2)>>2]&255}else{h=d}a[g]=h;d=g+1|0;if((d|0)==(e|0)){f=e;break}else{g=d}}return f|0}function w7(a,b){a=a|0;b=b|0;var d=0;if(b<<24>>24<=-1){d=b;return d|0}d=c[(c[(fw()|0)>>2]|0)+(b<<24>>24<<2)>>2]&255;return d|0}function w8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==(e|0)){f=d;return f|0}else{g=d}while(1){d=a[g]|0;if(d<<24>>24>-1){h=c[(c[(fw()|0)>>2]|0)+(d<<24>>24<<2)>>2]&255}else{h=d}a[g]=h;d=g+1|0;if((d|0)==(e|0)){f=e;break}else{g=d}}return f|0}function w9(b){b=b|0;var d=0,e=0;c[b>>2]=73632;d=b+8|0;e=c[d>>2]|0;do{if((a[741360]|0)==0){if((cR(741360)|0)==0){break}c[141570]=bN(1,42344,0)|0}}while(0);if((e|0)!=(c[141570]|0)){cF(c[d>>2]|0)}if((b|0)==0){return}yt(b);return}function xa(a){a=a|0;return 0}function xb(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;d=i;i=i+264|0;l=d|0;m=d+8|0;n=e;while(1){if((n|0)==(f|0)){o=f;break}if((c[n>>2]|0)==0){o=n;break}else{n=n+4|0}}c[k>>2]=h;c[g>>2]=e;L4159:do{if((e|0)==(f|0)|(h|0)==(j|0)){p=e}else{n=j;q=b+8|0;r=m|0;s=l|0;t=h;u=e;v=o;while(1){w=v-u>>2;x=eE(c[q>>2]|0)|0;y=c[g>>2]|0;z=(t|0)!=0;A=z?n-t|0:256;B=z?t:r;L4163:do{if((y|0)==0|(A|0)==0){C=0;D=w;E=A;F=B;G=y}else{H=A;I=w;J=0;K=B;L=y;while(1){M=I>>>0>=H>>>0;if(!(M|I>>>0>32)){C=J;D=I;E=H;F=K;G=L;break L4163}N=M?H:I;M=I-N|0;L4167:do{if((K|0)==0){O=c[L>>2]|0;if((O|0)==0){P=0;Q=L;break}else{R=0;S=L;T=O}while(1){if(T>>>0>127){O=ye(s,T)|0;if((O|0)==-1){C=-1;D=M;E=0;F=K;G=L;break L4163}else{U=O}}else{U=1}O=U+R|0;V=S+4|0;W=c[V>>2]|0;if((W|0)==0){X=O;Y=L;Z=3681;break}else{R=O;S=V;T=W}}}else{L4175:do{if(N>>>0>3){W=N;V=K;O=L;while(1){_=c[O>>2]|0;if((_|0)==0){$=W;aa=V;ab=O;Z=3671;break L4175}if(_>>>0>127){ac=ye(V,_)|0;if((ac|0)==-1){C=-1;D=M;E=0;F=K;G=O;break L4163}ad=V+ac|0;ae=W-ac|0;af=O}else{a[V]=_&255;ad=V+1|0;ae=W-1|0;af=O}_=af+4|0;if(ae>>>0>3){W=ae;V=ad;O=_}else{ag=ae;ah=ad;ai=_;Z=3665;break}}}else{ag=N;ah=K;ai=L;Z=3665}}while(0);if((Z|0)==3665){Z=0;if((ag|0)==0){aj=0}else{$=ag;aa=ah;ab=ai;Z=3671}}L4186:do{if((Z|0)==3671){while(1){Z=0;O=c[ab>>2]|0;if((O|0)==0){Z=3679;break}if(O>>>0>127){V=ye(s,O)|0;if((V|0)==-1){C=-1;D=M;E=0;F=K;G=ab;break L4163}if(V>>>0>$>>>0){Z=3675;break}W=c[ab>>2]|0;ye(aa,W)|0;ak=aa+V|0;al=$-V|0;am=ab}else{a[aa]=O&255;ak=aa+1|0;al=$-1|0;am=ab}if((al|0)==0){aj=0;break L4186}else{$=al;aa=ak;ab=am+4|0;Z=3671}}if((Z|0)==3679){Z=0;a[aa]=0;aj=$;break}else if((Z|0)==3675){Z=0;X=N-$|0;Y=ab;Z=3681;break L4167}}}while(0);X=N-aj|0;Y=0;Z=3681}}while(0);if((Z|0)==3681){Z=0;if((X|0)==-1){C=-1;D=M;E=0;F=K;G=Y;break L4163}else{P=X;Q=Y}}if((K|0)==(r|0)){an=r;ao=H}else{an=K+P|0;ao=H-P|0}N=P+J|0;if((Q|0)==0|(ao|0)==0){C=N;D=M;E=ao;F=an;G=Q;break}else{H=ao;I=M;J=N;K=an;L=Q}}}}while(0);L4207:do{if((G|0)==0){ap=C;aq=0}else{if((E|0)==0|(D|0)==0){ap=C;aq=G;break}else{ar=E;as=D;at=C;au=F;av=G}while(1){aw=ye(au,c[av>>2]|0)|0;if((aw+1|0)>>>0<2){break}y=av+4|0;B=as-1|0;w=at+1|0;if((ar|0)==(aw|0)|(B|0)==0){ap=w;aq=y;break L4207}else{ar=ar-aw|0;as=B;at=w;au=au+aw|0;av=y}}y=(aw|0)==0;ap=y?at:-1;aq=y?0:av}}while(0);if(z){c[g>>2]=aq}if((x|0)!=0){eE(x|0)|0}if((ap|0)==(-1|0)){Z=3696;break}else if((ap|0)==0){ax=1;Z=3719;break}y=(c[k>>2]|0)+ap|0;c[k>>2]=y;if((y|0)==(j|0)){Z=3715;break}if((v|0)==(f|0)){ay=f;az=y;aA=c[g>>2]|0}else{y=eE(c[q>>2]|0)|0;if((y|0)!=0){eE(y|0)|0}y=c[k>>2]|0;if((y|0)==(j|0)){ax=1;Z=3718;break}c[k>>2]=y+1;a[y]=0;y=(c[g>>2]|0)+4|0;c[g>>2]=y;w=y;while(1){if((w|0)==(f|0)){aB=f;break}if((c[w>>2]|0)==0){aB=w;break}else{w=w+4|0}}ay=aB;az=c[k>>2]|0;aA=y}if((aA|0)==(f|0)|(az|0)==(j|0)){p=aA;break L4159}else{t=az;u=aA;v=ay}}if((Z|0)==3696){c[k>>2]=t;L4236:do{if((u|0)==(c[g>>2]|0)){aC=u}else{v=u;r=t;while(1){s=c[v>>2]|0;n=eE(c[q>>2]|0)|0;w=ye(r,s)|0;if((n|0)!=0){eE(n|0)|0}if((w|0)==-1){aC=v;break L4236}n=(c[k>>2]|0)+w|0;c[k>>2]=n;w=v+4|0;if((w|0)==(c[g>>2]|0)){aC=w;break}else{v=w;r=n}}}}while(0);c[g>>2]=aC;ax=2;i=d;return ax|0}else if((Z|0)==3715){p=c[g>>2]|0;break}else if((Z|0)==3718){i=d;return ax|0}else if((Z|0)==3719){i=d;return ax|0}}}while(0);ax=(p|0)!=(f|0)|0;i=d;return ax|0}function xc(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;l=i;i=i+1040|0;m=l|0;n=l+1024|0;o=l+1032|0;p=o;q=e;while(1){if((q|0)==(f|0)){r=f;break}if((a[q]|0)==0){r=q;break}else{q=q+1|0}}c[k>>2]=h;c[g>>2]=e;L4255:do{if((e|0)==(f|0)|(h|0)==(j|0)){s=e}else{q=d;t=j;u=b+8|0;v=m|0;w=d|0;x=h;y=e;z=r;while(1){A=c[q+4>>2]|0;c[o>>2]=c[q>>2];c[o+4>>2]=A;B=z;A=B-y|0;C=eE(c[u>>2]|0)|0;D=c[g>>2]|0;c[n>>2]=D;E=(x|0)!=0;F=E?t-x>>2:256;G=E?x:v;L4259:do{if((D|0)==0|(F|0)==0){H=0;I=A;J=F;K=G;L=D}else{M=F;N=A;O=0;P=G;Q=D;while(1){R=N>>>2;S=R>>>0>=M>>>0;if(!(S|N>>>0>131)){H=O;I=N;J=M;K=P;L=Q;break L4259}T=S?M:R;U=N-T|0;R=yd(P,n,T,d)|0;if((R|0)==-1){break}if((P|0)==(v|0)){V=v;W=M}else{V=P+(R<<2)|0;W=M-R|0}T=R+O|0;R=c[n>>2]|0;if((R|0)==0|(W|0)==0){H=T;I=U;J=W;K=V;L=R;break L4259}else{M=W;N=U;O=T;P=V;Q=R}}H=-1;I=U;J=0;K=P;L=c[n>>2]|0}}while(0);L4269:do{if((L|0)==0){X=H;Y=0}else{if((J|0)==0|(I|0)==0){X=H;Y=L;break}else{Z=J;_=I;$=H;aa=K;ab=L}while(1){ac=x6(aa,ab,_,d)|0;if((ac+2|0)>>>0<3){break}D=ab+ac|0;c[n>>2]=D;G=Z-1|0;A=$+1|0;if((G|0)==0|(_|0)==(ac|0)){X=A;Y=D;break L4269}else{Z=G;_=_-ac|0;$=A;aa=aa+4|0;ab=D}}if((ac|0)==0){c[n>>2]=0;X=$;Y=0;break}else if((ac|0)==(-1|0)){X=-1;Y=ab;break}else{c[w>>2]=0;X=$;Y=ab;break}}}while(0);if(E){c[g>>2]=Y}if((C|0)!=0){eE(C|0)|0}if((X|0)==0){ad=2;ae=3777;break}else if((X|0)==(-1|0)){ae=3747;break}P=(c[k>>2]|0)+(X<<2)|0;c[k>>2]=P;if((P|0)==(j|0)){ae=3769;break}D=c[g>>2]|0;if((z|0)==(f|0)){af=f;ag=P;ah=D}else{A=eE(c[u>>2]|0)|0;G=x6(P,D,1,d)|0;if((A|0)!=0){eE(A|0)|0}if((G|0)!=0){ad=2;ae=3774;break}c[k>>2]=(c[k>>2]|0)+4;G=(c[g>>2]|0)+1|0;c[g>>2]=G;A=G;while(1){if((A|0)==(f|0)){ai=f;break}if((a[A]|0)==0){ai=A;break}else{A=A+1|0}}af=ai;ag=c[k>>2]|0;ah=G}if((ah|0)==(f|0)|(ag|0)==(j|0)){s=ah;break L4255}else{x=ag;y=ah;z=af}}if((ae|0)==3769){s=c[g>>2]|0;break}else if((ae|0)==3777){i=l;return ad|0}else if((ae|0)==3774){i=l;return ad|0}else if((ae|0)==3747){c[k>>2]=x;L4303:do{if((y|0)==(c[g>>2]|0)){aj=y}else{z=x;w=y;while(1){v=eE(c[u>>2]|0)|0;t=x6(z,w,B-w|0,p)|0;if((v|0)!=0){eE(v|0)|0}if((t|0)==0){ak=w+1|0}else if((t|0)==(-2|0)){ae=3754;break}else if((t|0)==(-1|0)){ae=3753;break}else{ak=w+t|0}t=(c[k>>2]|0)+4|0;c[k>>2]=t;if((ak|0)==(c[g>>2]|0)){aj=ak;break L4303}else{z=t;w=ak}}if((ae|0)==3754){c[g>>2]=w;ad=1;i=l;return ad|0}else if((ae|0)==3753){c[g>>2]=w;ad=2;i=l;return ad|0}}}while(0);c[g>>2]=aj;ad=(aj|0)!=(f|0)|0;i=l;return ad|0}}}while(0);ad=(s|0)!=(f|0)|0;i=l;return ad|0}function xd(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;d=eE(c[a+8>>2]|0)|0;if((d|0)==0){return 0}eE(d|0)|0;return 0}function xe(a){a=a|0;var b=0,d=0,e=0;b=a+8|0;a=eE(c[b>>2]|0)|0;if((a|0)!=0){eE(a|0)|0}a=c[b>>2]|0;if((a|0)==0){return 1}b=eE(a|0)|0;a=dz()|0;if((b|0)==0){d=(a|0)==1;e=d&1;return e|0}eE(b|0)|0;d=(a|0)==1;e=d&1;return e|0}function xf(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)==0|(d|0)==(e|0)){g=0;return g|0}h=e;i=a+8|0;a=(b|0)!=0?b:278192;b=d;d=0;j=0;while(1){k=eE(c[i>>2]|0)|0;l=x6(0,b,h-b|0,a)|0;if((k|0)!=0){eE(k|0)|0}if((l|0)==0){m=1;n=b+1|0}else if((l|0)==(-1|0)|(l|0)==(-2|0)){g=d;o=3815;break}else{m=l;n=b+l|0}l=m+d|0;k=j+1|0;if(k>>>0>=f>>>0|(n|0)==(e|0)){g=l;o=3813;break}else{b=n;d=l;j=k}}if((o|0)==3813){return g|0}else if((o|0)==3815){return g|0}return 0}function xg(a){a=a|0;var b=0,d=0,e=0;b=c[a+8>>2]|0;do{if((b|0)==0){d=1}else{a=eE(b|0)|0;e=dz()|0;if((a|0)==0){d=e;break}eE(a|0)|0;d=e}}while(0);return d|0}function xh(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;return 3}function xi(a){a=a|0;return 0}function xj(a){a=a|0;return 0}function xk(a){a=a|0;return 4}function xl(d,f,g,h,i,j,k,l){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=h;L4369:do{if(g>>>0<h>>>0){d=k;m=j;n=g;while(1){o=b[n>>1]|0;p=o&65535;do{if((o&65535)<128){if((d-m|0)<1){q=1;r=m;s=n;break L4369}a[m]=o&255;t=m+1|0;u=n}else{if((o&65535)<2048){if((d-m|0)<2){q=1;r=m;s=n;break L4369}a[m]=(p>>>6|192)&255;a[m+1|0]=(p&63|128)&255;t=m+2|0;u=n;break}if((o&65535)<55296){if((d-m|0)<3){q=1;r=m;s=n;break L4369}a[m]=(p>>>12|224)&255;a[m+1|0]=(p>>>6&63|128)&255;a[m+2|0]=(p&63|128)&255;t=m+3|0;u=n;break}if((o&65535)>=56320){if((o&65535)<57344){q=2;r=m;s=n;break L4369}if((d-m|0)<3){q=1;r=m;s=n;break L4369}a[m]=(p>>>12|224)&255;a[m+1|0]=(p>>>6&63|128)&255;a[m+2|0]=(p&63|128)&255;t=m+3|0;u=n;break}if((f-n|0)<4){q=1;r=m;s=n;break L4369}v=n+2|0;w=e[v>>1]|0;if((w&64512|0)!=56320){q=2;r=m;s=n;break L4369}if((d-m|0)<4){q=1;r=m;s=n;break L4369}x=p&960;if(((x<<10)+65536|0)>>>0>1114111){q=2;r=m;s=n;break L4369}y=(x>>>6)+1|0;a[m]=(y>>>2|240)&255;a[m+1|0]=(p>>>2&15|y<<4&48|128)&255;a[m+2|0]=(p<<4&48|w>>>6&15|128)&255;a[m+3|0]=(w&63|128)&255;t=m+4|0;u=v}}while(0);p=u+2|0;if(p>>>0<h>>>0){m=t;n=p}else{q=0;r=t;s=p;break}}}else{q=0;r=j;s=g}}while(0);c[i>>2]=g+(s-g>>1<<1);c[l>>2]=j+(r-j);return q|0}function xm(e,f,g,h,i,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;L4397:do{if(g>>>0<h>>>0){f=h;e=k;m=j;n=g;while(1){if(m>>>0>=k>>>0){o=m;p=n;q=3884;break L4397}r=a[n]|0;s=r&255;do{if(r<<24>>24>-1){b[m>>1]=r&255;t=m;u=n+1|0}else{if((r&255)<194){v=2;w=m;x=n;break L4397}if((r&255)<224){if((f-n|0)<2){v=1;w=m;x=n;break L4397}y=d[n+1|0]|0;if((y&192|0)!=128){v=2;w=m;x=n;break L4397}b[m>>1]=(y&63|s<<6&1984)&65535;t=m;u=n+2|0;break}if((r&255)<240){if((f-n|0)<3){v=1;w=m;x=n;break L4397}y=a[n+1|0]|0;z=a[n+2|0]|0;if((s|0)==237){if((y&-32)<<24>>24!=-128){v=2;w=m;x=n;break L4397}}else if((s|0)==224){if((y&-32)<<24>>24!=-96){v=2;w=m;x=n;break L4397}}else{if((y&-64)<<24>>24!=-128){v=2;w=m;x=n;break L4397}}A=z&255;if((A&192|0)!=128){v=2;w=m;x=n;break L4397}b[m>>1]=((y&255)<<6&4032|s<<12|A&63)&65535;t=m;u=n+3|0;break}if((r&255)>=245){v=2;w=m;x=n;break L4397}if((f-n|0)<4){v=1;w=m;x=n;break L4397}A=a[n+1|0]|0;y=a[n+2|0]|0;z=a[n+3|0]|0;if((s|0)==240){if((A+112&255)>=48){v=2;w=m;x=n;break L4397}}else if((s|0)==244){if((A&-16)<<24>>24!=-128){v=2;w=m;x=n;break L4397}}else{if((A&-64)<<24>>24!=-128){v=2;w=m;x=n;break L4397}}B=y&255;if((B&192|0)!=128){v=2;w=m;x=n;break L4397}y=z&255;if((y&192|0)!=128){v=2;w=m;x=n;break L4397}if((e-m|0)<4){v=1;w=m;x=n;break L4397}z=s&7;C=A&255;if((C<<12&196608|z<<18)>>>0>1114111){v=2;w=m;x=n;break L4397}b[m>>1]=(C<<2&60|B>>>4&3|((C>>>4&3|z<<2)<<6)+16320|55296)&65535;z=m+2|0;b[z>>1]=(B<<6&960|y&63|56320)&65535;t=z;u=n+4|0}}while(0);s=t+2|0;if(u>>>0<h>>>0){m=s;n=u}else{o=s;p=u;q=3884;break}}}else{o=j;p=g;q=3884}}while(0);if((q|0)==3884){v=p>>>0<h>>>0|0;w=o;x=p}c[i>>2]=g+(x-g);c[l>>2]=j+(w-j>>1<<1);return v|0}function xn(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;L4437:do{if(d>>>0<e>>>0&(f|0)!=0){c=e;b=0;g=d;L4439:while(1){h=a[g]|0;i=h&255;do{if(h<<24>>24>-1){j=g+1|0;k=b}else{if((h&255)<194){l=g;break L4437}if((h&255)<224){if((c-g|0)<2){l=g;break L4437}if((a[g+1|0]&-64)<<24>>24!=-128){l=g;break L4437}j=g+2|0;k=b;break}if((h&255)<240){m=g;if((c-m|0)<3){l=g;break L4437}n=a[g+1|0]|0;o=a[g+2|0]|0;if((i|0)==224){if((n&-32)<<24>>24!=-96){p=3899;break L4439}}else if((i|0)==237){if((n&-32)<<24>>24!=-128){p=3901;break L4439}}else{if((n&-64)<<24>>24!=-128){p=3903;break L4439}}if((o&-64)<<24>>24!=-128){l=g;break L4437}j=g+3|0;k=b;break}if((h&255)>=245){l=g;break L4437}q=g;if((c-q|0)<4){l=g;break L4437}if((f-b|0)>>>0<2){l=g;break L4437}o=a[g+1|0]|0;n=a[g+2|0]|0;r=a[g+3|0]|0;if((i|0)==244){if((o&-16)<<24>>24!=-128){p=3913;break L4439}}else if((i|0)==240){if((o+112&255)>=48){p=3911;break L4439}}else{if((o&-64)<<24>>24!=-128){p=3915;break L4439}}if((n&-64)<<24>>24!=-128){l=g;break L4437}if((r&-64)<<24>>24!=-128){l=g;break L4437}if(((o&255)<<12&196608|i<<18&1835008)>>>0>1114111){l=g;break L4437}j=g+4|0;k=b+1|0}}while(0);i=k+1|0;if(j>>>0<e>>>0&i>>>0<f>>>0){b=i;g=j}else{l=j;break L4437}}if((p|0)==3915){s=q-d|0;return s|0}else if((p|0)==3911){s=q-d|0;return s|0}else if((p|0)==3899){s=m-d|0;return s|0}else if((p|0)==3901){s=m-d|0;return s|0}else if((p|0)==3913){s=q-d|0;return s|0}else if((p|0)==3903){s=m-d|0;return s|0}}else{l=d}}while(0);s=l-d|0;return s|0}function xo(b,d,e,f,g,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;L4488:do{if(e>>>0<f>>>0){d=i;b=h;k=e;while(1){l=c[k>>2]|0;if((l&-2048|0)==55296|l>>>0>1114111){m=2;n=b;o=k;break L4488}do{if(l>>>0<128){if((d-b|0)<1){m=1;n=b;o=k;break L4488}a[b]=l&255;p=b+1|0}else{if(l>>>0<2048){if((d-b|0)<2){m=1;n=b;o=k;break L4488}a[b]=(l>>>6|192)&255;a[b+1|0]=(l&63|128)&255;p=b+2|0;break}q=d-b|0;if(l>>>0<65536){if((q|0)<3){m=1;n=b;o=k;break L4488}a[b]=(l>>>12|224)&255;a[b+1|0]=(l>>>6&63|128)&255;a[b+2|0]=(l&63|128)&255;p=b+3|0;break}else{if((q|0)<4){m=1;n=b;o=k;break L4488}a[b]=(l>>>18|240)&255;a[b+1|0]=(l>>>12&63|128)&255;a[b+2|0]=(l>>>6&63|128)&255;a[b+3|0]=(l&63|128)&255;p=b+4|0;break}}}while(0);l=k+4|0;if(l>>>0<f>>>0){b=p;k=l}else{m=0;n=p;o=l;break}}}else{m=0;n=h;o=e}}while(0);c[g>>2]=e+(o-e>>2<<2);c[j>>2]=h+(n-h);return m|0}function xp(a){a=a|0;if((a|0)==0){return}yt(a);return}function xq(a){a=a|0;if((a|0)==0){return}yt(a);return}function xr(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;return 3}function xs(a){a=a|0;return 0}function xt(a){a=a|0;return 0}function xu(a){a=a|0;return 4}function xv(b,e,f,g,h,i,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;L4523:do{if(f>>>0<g>>>0){e=g;b=i;l=f;while(1){if(b>>>0>=j>>>0){m=b;n=l;o=3989;break L4523}p=a[l]|0;q=p&255;do{if(p<<24>>24>-1){c[b>>2]=q;r=l+1|0}else{if((p&255)<194){s=2;t=b;u=l;break L4523}if((p&255)<224){if((e-l|0)<2){s=1;t=b;u=l;break L4523}v=d[l+1|0]|0;if((v&192|0)!=128){s=2;t=b;u=l;break L4523}c[b>>2]=v&63|q<<6&1984;r=l+2|0;break}if((p&255)<240){if((e-l|0)<3){s=1;t=b;u=l;break L4523}v=a[l+1|0]|0;w=a[l+2|0]|0;if((q|0)==224){if((v&-32)<<24>>24!=-96){s=2;t=b;u=l;break L4523}}else if((q|0)==237){if((v&-32)<<24>>24!=-128){s=2;t=b;u=l;break L4523}}else{if((v&-64)<<24>>24!=-128){s=2;t=b;u=l;break L4523}}x=w&255;if((x&192|0)!=128){s=2;t=b;u=l;break L4523}c[b>>2]=(v&255)<<6&4032|q<<12&61440|x&63;r=l+3|0;break}if((p&255)>=245){s=2;t=b;u=l;break L4523}if((e-l|0)<4){s=1;t=b;u=l;break L4523}x=a[l+1|0]|0;v=a[l+2|0]|0;w=a[l+3|0]|0;if((q|0)==240){if((x+112&255)>=48){s=2;t=b;u=l;break L4523}}else if((q|0)==244){if((x&-16)<<24>>24!=-128){s=2;t=b;u=l;break L4523}}else{if((x&-64)<<24>>24!=-128){s=2;t=b;u=l;break L4523}}y=v&255;if((y&192|0)!=128){s=2;t=b;u=l;break L4523}v=w&255;if((v&192|0)!=128){s=2;t=b;u=l;break L4523}w=(x&255)<<12&258048|q<<18&1835008|y<<6&4032|v&63;if(w>>>0>1114111){s=2;t=b;u=l;break L4523}c[b>>2]=w;r=l+4|0}}while(0);q=b+4|0;if(r>>>0<g>>>0){b=q;l=r}else{m=q;n=r;o=3989;break}}}else{m=i;n=f;o=3989}}while(0);if((o|0)==3989){s=n>>>0<g>>>0|0;t=m;u=n}c[h>>2]=f+(u-f);c[k>>2]=i+(t-i>>2<<2);return s|0}function xw(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;L4562:do{if(d>>>0<e>>>0&(f|0)!=0){c=e;b=1;g=d;L4564:while(1){h=a[g]|0;i=h&255;do{if(h<<24>>24>-1){j=g+1|0}else{if((h&255)<194){k=g;break L4562}if((h&255)<224){if((c-g|0)<2){k=g;break L4562}if((a[g+1|0]&-64)<<24>>24!=-128){k=g;break L4562}j=g+2|0;break}if((h&255)<240){l=g;if((c-l|0)<3){k=g;break L4562}m=a[g+1|0]|0;n=a[g+2|0]|0;if((i|0)==224){if((m&-32)<<24>>24!=-96){o=4004;break L4564}}else if((i|0)==237){if((m&-32)<<24>>24!=-128){o=4006;break L4564}}else{if((m&-64)<<24>>24!=-128){o=4008;break L4564}}if((n&-64)<<24>>24!=-128){k=g;break L4562}j=g+3|0;break}if((h&255)>=245){k=g;break L4562}p=g;if((c-p|0)<4){k=g;break L4562}n=a[g+1|0]|0;m=a[g+2|0]|0;q=a[g+3|0]|0;if((i|0)==244){if((n&-16)<<24>>24!=-128){o=4017;break L4564}}else if((i|0)==240){if((n+112&255)>=48){o=4015;break L4564}}else{if((n&-64)<<24>>24!=-128){o=4019;break L4564}}if((m&-64)<<24>>24!=-128){k=g;break L4562}if((q&-64)<<24>>24!=-128){k=g;break L4562}if(((n&255)<<12&196608|i<<18&1835008)>>>0>1114111){k=g;break L4562}j=g+4|0}}while(0);if(!(j>>>0<e>>>0&b>>>0<f>>>0)){k=j;break L4562}b=b+1|0;g=j}if((o|0)==4015){r=p-d|0;return r|0}else if((o|0)==4017){r=p-d|0;return r|0}else if((o|0)==4008){r=l-d|0;return r|0}else if((o|0)==4019){r=p-d|0;return r|0}else if((o|0)==4004){r=l-d|0;return r|0}else if((o|0)==4006){r=l-d|0;return r|0}}else{k=d}}while(0);r=k-d|0;return r|0}function xx(b){b=b|0;return a[b+8|0]|0}function xy(a){a=a|0;return c[a+8>>2]|0}function xz(b){b=b|0;return a[b+9|0]|0}function xA(a){a=a|0;return c[a+12>>2]|0}function xB(b,c){b=b|0;c=c|0;c=b;a[b]=8;b=c+1|0;C=1702195828;a[b]=C&255;C=C>>8;a[b+1|0]=C&255;C=C>>8;a[b+2|0]=C&255;C=C>>8;a[b+3|0]=C&255;a[c+5|0]=0;return}function xC(a){a=a|0;if((a|0)==0){return}yt(a);return}function xD(a){a=a|0;if((a|0)==0){return}yt(a);return}function xE(b){b=b|0;var d=0;c[b>>2]=73096;do{if((a[b+12|0]&1)!=0){d=c[b+20>>2]|0;if((d|0)!=0){yt(d)}if((b|0)!=0){break}return}}while(0);yt(b);return}function xF(b){b=b|0;var d=0;c[b>>2]=73096;if((a[b+12|0]&1)==0){return}d=c[b+20>>2]|0;if((d|0)==0){return}yt(d);return}function xG(b){b=b|0;var d=0;c[b>>2]=73048;do{if((a[b+16|0]&1)!=0){d=c[b+24>>2]|0;if((d|0)!=0){yt(d)}if((b|0)!=0){break}return}}while(0);yt(b);return}function xH(b){b=b|0;var d=0;c[b>>2]=73048;if((a[b+16|0]&1)==0){return}d=c[b+24>>2]|0;if((d|0)==0){return}yt(d);return}function xI(b,c){b=b|0;c=c|0;c=b;a[b]=10;b=c+1|0;a[b]=a[31792]|0;a[b+1|0]=a[31793|0]|0;a[b+2|0]=a[31794|0]|0;a[b+3|0]=a[31795|0]|0;a[b+4|0]=a[31796|0]|0;a[c+6|0]=0;return}function xJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d+12|0;if((a[e]&1)==0){f=b;c[f>>2]=c[e>>2];c[f+4>>2]=c[e+4>>2];c[f+8>>2]=c[e+8>>2];return}e=c[d+20>>2]|0;f=c[d+16>>2]|0;if((f|0)==-1){su()}do{if(f>>>0<11){a[b]=f<<1&255;g=b+1|0}else{d=f+16&-16;h=(d|0)==0?1:d;while(1){i=ys(h)|0;if((i|0)!=0){j=4098;break}k=(I=c[185320]|0,c[185320]=I+0,I);if((k|0)==0){break}gs[k&63]()}if((j|0)==4098){c[b+8>>2]=i;c[b>>2]=d|1;c[b+4>>2]=f;g=i;break}h=ff(4)|0;c[h>>2]=72440;dr(h|0,79056,316)}}while(0);yE(g|0,e|0,f)|0;a[g+f|0]=0;return}function xK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d+16|0;if((a[e]&1)==0){f=b;c[f>>2]=c[e>>2];c[f+4>>2]=c[e+4>>2];c[f+8>>2]=c[e+8>>2];return}e=c[d+24>>2]|0;f=c[d+20>>2]|0;if((f|0)==-1){su()}do{if(f>>>0<11){a[b]=f<<1&255;g=b+1|0}else{d=f+16&-16;h=(d|0)==0?1:d;while(1){i=ys(h)|0;if((i|0)!=0){j=4120;break}k=(I=c[185320]|0,c[185320]=I+0,I);if((k|0)==0){break}gs[k&63]()}if((j|0)==4120){c[b+8>>2]=i;c[b>>2]=d|1;c[b+4>>2]=f;g=i;break}h=ff(4)|0;c[h>>2]=72440;dr(h|0,79056,316)}}while(0);yE(g|0,e|0,f)|0;a[g+f|0]=0;return}function xL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;while(1){d=ys(32)|0;if((d|0)!=0){break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){e=4133;break}gs[b&63]()}if((e|0)==4133){e=ff(4)|0;c[e>>2]=72440;dr(e|0,79056,316)}e=d;c[a+8>>2]=e;c[a>>2]=9;c[a+4>>2]=4;a=32416;b=4;f=e;while(1){e=b-1|0;c[f>>2]=c[a>>2];if((e|0)==0){break}else{a=a+4|0;b=e;f=f+4|0}}c[d+16>>2]=0;return}function xM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;while(1){d=ys(32)|0;if((d|0)!=0){break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){e=4147;break}gs[b&63]()}if((e|0)==4147){e=ff(4)|0;c[e>>2]=72440;dr(e|0,79056,316)}e=d;c[a+8>>2]=e;c[a>>2]=9;c[a+4>>2]=5;a=31392;b=5;f=e;while(1){e=b-1|0;c[f>>2]=c[a>>2];if((e|0)==0){break}else{a=a+4|0;b=e;f=f+4|0}}c[d+20>>2]=0;return}function xN(b){b=b|0;var d=0;if((a[741440]|0)!=0){d=c[141688]|0;return d|0}if((cR(741440)|0)==0){d=c[141688]|0;return d|0}do{if((a[741328]|0)==0){if((cR(741328)|0)==0){break}yB(565800,0,168);ep(532,0,r|0)|0}}while(0);sr(565800,49344);sr(565812,49048);sr(565824,48744);sr(565836,48520);sr(565848,48416);sr(565860,48320);sr(565872,48168);sr(565884,48016);sr(565896,47944);sr(565908,47872);sr(565920,47720);sr(565932,47448);sr(565944,47368);sr(565956,47280);c[141688]=565800;d=c[141688]|0;return d|0}function xO(b){b=b|0;var d=0;if((a[741384]|0)!=0){d=c[141666]|0;return d|0}if((cR(741384)|0)==0){d=c[141666]|0;return d|0}do{if((a[741304]|0)==0){if((cR(741304)|0)==0){break}yB(565056,0,168);ep(318,0,r|0)|0}}while(0);sB(565056,53440,6);sB(565068,53240,6);sB(565080,53072,7);sB(565092,52624,9);sB(565104,52392,8);sB(565116,52032,6);sB(565128,51432,8);sB(565140,51152,3);sB(565152,50776,3);sB(565164,50528,3);sB(565176,50416,3);sB(565188,50112,3);sB(565200,49912,3);sB(565212,49712,3);c[141666]=565056;d=c[141666]|0;return d|0}function xP(b){b=b|0;var d=0;if((a[741432]|0)!=0){d=c[141686]|0;return d|0}if((cR(741432)|0)==0){d=c[141686]|0;return d|0}do{if((a[741320]|0)==0){if((cR(741320)|0)==0){break}yB(565512,0,288);ep(396,0,r|0)|0}}while(0);sr(565512,14392);sr(565524,14144);sr(565536,13752);sr(565548,13576);sr(565560,13456);sr(565572,13296);sr(565584,13160);sr(565596,12872);sr(565608,12688);sr(565620,12472);sr(565632,11960);sr(565644,11760);sr(565656,11576);sr(565668,11392);sr(565680,11296);sr(565692,11152);sr(565704,13456);sr(565716,11008);sr(565728,10872);sr(565740,54960);sr(565752,54720);sr(565764,54200);sr(565776,54040);sr(565788,53816);c[141686]=565512;d=c[141686]|0;return d|0}function xQ(b){b=b|0;var d=0;if((a[741376]|0)!=0){d=c[141664]|0;return d|0}if((cR(741376)|0)==0){d=c[141664]|0;return d|0}do{if((a[741296]|0)==0){if((cR(741296)|0)==0){break}yB(564768,0,288);ep(272,0,r|0)|0}}while(0);sB(564768,20312,7);sB(564780,20112,8);sB(564792,19992,5);sB(564804,19848,5);sB(564816,16512,3);sB(564828,19176,4);sB(564840,18960,4);sB(564852,18760,6);sB(564864,18520,9);sB(564876,18368,7);sB(564888,18144,8);sB(564900,17952,8);sB(564912,17680,3);sB(564924,17448,3);sB(564936,17256,3);sB(564948,16760,3);sB(564960,16512,3);sB(564972,16192,3);sB(564984,16e3,3);sB(564996,15856,3);sB(565008,15680,3);sB(565020,15560,3);sB(565032,15360,3);sB(565044,15152,3);c[141664]=564768;d=c[141664]|0;return d|0}function xR(b){b=b|0;var d=0;if((a[741448]|0)!=0){d=c[141690]|0;return d|0}if((cR(741448)|0)==0){d=c[141690]|0;return d|0}do{if((a[741336]|0)==0){if((cR(741336)|0)==0){break}yB(565968,0,288);ep(270,0,r|0)|0}}while(0);sr(565968,20680);sr(565980,20520);c[141690]=565968;d=c[141690]|0;return d|0}function xS(b){b=b|0;var d=0;if((a[741392]|0)!=0){d=c[141668]|0;return d|0}if((cR(741392)|0)==0){d=c[141668]|0;return d|0}do{if((a[741312]|0)==0){if((cR(741312)|0)==0){break}yB(565224,0,288);ep(284,0,r|0)|0}}while(0);sB(565224,22024,2);sB(565236,21344,2);c[141668]=565224;d=c[141668]|0;return d|0}function xT(b){b=b|0;var c=0;if((a[741456]|0)!=0){return 566768}if((cR(741456)|0)==0){return 566768}a[566768]=16;b=566769;c=b|0;C=623865125;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;c=b+4|0;C=2032480100;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;a[566777]=0;ep(534,566768,r|0)|0;return 566768}function xU(b){b=b|0;var c=0;if((a[741480]|0)!=0){return 566816}if((cR(741480)|0)==0){return 566816}a[566816]=16;b=566817;c=b|0;C=624576549;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;c=b+4|0;C=1394948685;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;a[566825]=0;ep(534,566816,r|0)|0;return 566816}function xV(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[741400]|0)!=0){return 566680}if((cR(741400)|0)==0){return 566680}while(1){d=ys(48)|0;if((d|0)!=0){break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){e=4323;break}gs[b&63]()}if((e|0)==4323){e=ff(4)|0;c[e>>2]=72440;dr(e|0,79056,316);return 0}e=d;c[141672]=e;c[141670]=13;c[141671]=8;b=30024;f=8;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+32>>2]=0;ep(402,566680,r|0)|0;return 566680}function xW(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[741424]|0)!=0){return 566728}if((cR(741424)|0)==0){return 566728}while(1){d=ys(48)|0;if((d|0)!=0){break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){e=4344;break}gs[b&63]()}if((e|0)==4344){e=ff(4)|0;c[e>>2]=72440;dr(e|0,79056,316);return 0}e=d;c[141684]=e;c[141682]=13;c[141683]=8;b=28864;f=8;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+32>>2]=0;ep(402,566728,r|0)|0;return 566728}function xX(b){b=b|0;var d=0,e=0;if((a[741472]|0)!=0){return 566800}if((cR(741472)|0)==0){return 566800}while(1){d=ys(32)|0;if((d|0)!=0){e=4367;break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){e=4365;break}gs[b&63]()}if((e|0)==4365){b=ff(4)|0;c[b>>2]=72440;dr(b|0,79056,316);return 0}else if((e|0)==4367){c[141702]=d;c[141700]=33;c[141701]=20;yE(d|0,28496,20)|0;a[d+20|0]=0;ep(534,566800,r|0)|0;return 566800}return 0}function xY(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[741416]|0)!=0){return 566712}if((cR(741416)|0)==0){return 566712}while(1){d=ys(96)|0;if((d|0)!=0){break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){e=4384;break}gs[b&63]()}if((e|0)==4384){e=ff(4)|0;c[e>>2]=72440;dr(e|0,79056,316);return 0}e=d;c[141680]=e;c[141678]=25;c[141679]=20;b=28072;f=20;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+80>>2]=0;ep(402,566712,r|0)|0;return 566712}function xZ(b){b=b|0;do{if((a[565500]&1)!=0){b=c[141377]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565488]&1)!=0){b=c[141374]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565476]&1)!=0){b=c[141371]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565464]&1)!=0){b=c[141368]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565452]&1)!=0){b=c[141365]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565440]&1)!=0){b=c[141362]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565428]&1)!=0){b=c[141359]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565416]&1)!=0){b=c[141356]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565404]&1)!=0){b=c[141353]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565392]&1)!=0){b=c[141350]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565380]&1)!=0){b=c[141347]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565368]&1)!=0){b=c[141344]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565356]&1)!=0){b=c[141341]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565344]&1)!=0){b=c[141338]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565332]&1)!=0){b=c[141335]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565320]&1)!=0){b=c[141332]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565308]&1)!=0){b=c[141329]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565296]&1)!=0){b=c[141326]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565284]&1)!=0){b=c[141323]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565272]&1)!=0){b=c[141320]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565260]&1)!=0){b=c[141317]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565248]&1)!=0){b=c[141314]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565236]&1)!=0){b=c[141311]|0;if((b|0)==0){break}yt(b)}}while(0);if((a[565224]&1)==0){return}b=c[141308]|0;if((b|0)==0){return}yt(b);return}function x_(b){b=b|0;var d=0,e=0;if((a[741464]|0)!=0){return 566784}if((cR(741464)|0)==0){return 566784}while(1){d=ys(16)|0;if((d|0)!=0){e=4483;break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){e=4481;break}gs[b&63]()}if((e|0)==4483){c[141698]=d;c[141696]=17;c[141697]=11;yE(d|0,27696,11)|0;a[d+11|0]=0;ep(534,566784,r|0)|0;return 566784}else if((e|0)==4481){e=ff(4)|0;c[e>>2]=72440;dr(e|0,79056,316);return 0}return 0}function x$(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[741408]|0)!=0){return 566696}if((cR(741408)|0)==0){return 566696}while(1){d=ys(48)|0;if((d|0)!=0){break}b=(I=c[185320]|0,c[185320]=I+0,I);if((b|0)==0){e=4500;break}gs[b&63]()}if((e|0)==4500){e=ff(4)|0;c[e>>2]=72440;dr(e|0,79056,316);return 0}e=d;c[141676]=e;c[141674]=13;c[141675]=11;b=27256;f=11;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+44>>2]=0;ep(402,566696,r|0)|0;return 566696}function x0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+8|0;f=b+4|0;g=c[f>>2]|0;h=c[e>>2]|0;i=g;if(h-i>>2>>>0>=d>>>0){j=d;k=g;do{if((k|0)==0){l=0}else{c[k>>2]=0;l=c[f>>2]|0}k=l+4|0;c[f>>2]=k;j=j-1|0;}while((j|0)!=0);return}j=b+16|0;k=b|0;l=c[k>>2]|0;g=i-l>>2;i=g+d|0;if(i>>>0>1073741823){wA()}m=h-l|0;do{if(m>>2>>>0>536870910){n=1073741823;o=4521}else{l=m>>1;h=l>>>0<i>>>0?i:l;if((h|0)==0){p=0;q=0;break}l=b+128|0;if(!((a[l]&1)==0&h>>>0<29)){n=h;o=4521;break}a[l]=1;p=j;q=h}}while(0);do{if((o|0)==4521){i=n<<2;m=(i|0)==0?1:i;while(1){r=ys(m)|0;if((r|0)!=0){o=4532;break}i=(I=c[185320]|0,c[185320]=I+0,I);if((i|0)==0){break}gs[i&63]()}if((o|0)==4532){p=r;q=n;break}m=ff(4)|0;c[m>>2]=72440;dr(m|0,79056,316)}}while(0);n=d;d=p+(g<<2)|0;do{if((d|0)==0){s=0}else{c[d>>2]=0;s=d}d=s+4|0;n=n-1|0;}while((n|0)!=0);n=p+(q<<2)|0;q=c[k>>2]|0;s=(c[f>>2]|0)-q|0;r=p+(g-(s>>2)<<2)|0;g=r;p=q;yE(g|0,p|0,s)|0;c[k>>2]=r;c[f>>2]=d;c[e>>2]=n;if((q|0)==0){return}if((q|0)==(j|0)){a[b+128|0]=0;return}else{yt(p);return}}function x1(b){b=b|0;do{if((a[566244]&1)!=0){b=c[141563]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566232]&1)!=0){b=c[141560]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566220]&1)!=0){b=c[141557]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566208]&1)!=0){b=c[141554]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566196]&1)!=0){b=c[141551]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566184]&1)!=0){b=c[141548]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566172]&1)!=0){b=c[141545]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566160]&1)!=0){b=c[141542]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566148]&1)!=0){b=c[141539]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566136]&1)!=0){b=c[141536]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566124]&1)!=0){b=c[141533]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566112]&1)!=0){b=c[141530]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566100]&1)!=0){b=c[141527]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566088]&1)!=0){b=c[141524]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566076]&1)!=0){b=c[141521]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566064]&1)!=0){b=c[141518]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566052]&1)!=0){b=c[141515]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566040]&1)!=0){b=c[141512]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566028]&1)!=0){b=c[141509]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566016]&1)!=0){b=c[141506]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[566004]&1)!=0){b=c[141503]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565992]&1)!=0){b=c[141500]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565980]&1)!=0){b=c[141497]|0;if((b|0)==0){break}yt(b)}}while(0);if((a[565968]&1)==0){return}b=c[141494]|0;if((b|0)==0){return}yt(b);return}function x2(b){b=b|0;do{if((a[565044]&1)!=0){b=c[141263]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565032]&1)!=0){b=c[141260]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565020]&1)!=0){b=c[141257]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565008]&1)!=0){b=c[141254]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564996]&1)!=0){b=c[141251]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564984]&1)!=0){b=c[141248]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564972]&1)!=0){b=c[141245]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564960]&1)!=0){b=c[141242]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564948]&1)!=0){b=c[141239]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564936]&1)!=0){b=c[141236]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564924]&1)!=0){b=c[141233]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564912]&1)!=0){b=c[141230]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564900]&1)!=0){b=c[141227]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564888]&1)!=0){b=c[141224]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564876]&1)!=0){b=c[141221]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564864]&1)!=0){b=c[141218]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564852]&1)!=0){b=c[141215]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564840]&1)!=0){b=c[141212]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564828]&1)!=0){b=c[141209]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564816]&1)!=0){b=c[141206]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564804]&1)!=0){b=c[141203]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564792]&1)!=0){b=c[141200]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[564780]&1)!=0){b=c[141197]|0;if((b|0)==0){break}yt(b)}}while(0);if((a[564768]&1)==0){return}b=c[141194]|0;if((b|0)==0){return}yt(b);return}function x3(b){b=b|0;do{if((a[565788]&1)!=0){b=c[141449]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565776]&1)!=0){b=c[141446]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565764]&1)!=0){b=c[141443]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565752]&1)!=0){b=c[141440]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565740]&1)!=0){b=c[141437]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565728]&1)!=0){b=c[141434]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565716]&1)!=0){b=c[141431]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565704]&1)!=0){b=c[141428]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565692]&1)!=0){b=c[141425]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565680]&1)!=0){b=c[141422]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565668]&1)!=0){b=c[141419]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565656]&1)!=0){b=c[141416]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565644]&1)!=0){b=c[141413]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565632]&1)!=0){b=c[141410]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565620]&1)!=0){b=c[141407]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565608]&1)!=0){b=c[141404]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565596]&1)!=0){b=c[141401]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565584]&1)!=0){b=c[141398]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565572]&1)!=0){b=c[141395]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565560]&1)!=0){b=c[141392]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565548]&1)!=0){b=c[141389]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565536]&1)!=0){b=c[141386]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565524]&1)!=0){b=c[141383]|0;if((b|0)==0){break}yt(b)}}while(0);if((a[565512]&1)==0){return}b=c[141380]|0;if((b|0)==0){return}yt(b);return}function x4(b){b=b|0;do{if((a[565212]&1)!=0){b=c[141305]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565200]&1)!=0){b=c[141302]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565188]&1)!=0){b=c[141299]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565176]&1)!=0){b=c[141296]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565164]&1)!=0){b=c[141293]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565152]&1)!=0){b=c[141290]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565140]&1)!=0){b=c[141287]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565128]&1)!=0){b=c[141284]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565116]&1)!=0){b=c[141281]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565104]&1)!=0){b=c[141278]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565092]&1)!=0){b=c[141275]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565080]&1)!=0){b=c[141272]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565068]&1)!=0){b=c[141269]|0;if((b|0)==0){break}yt(b)}}while(0);if((a[565056]&1)==0){return}b=c[141266]|0;if((b|0)==0){return}yt(b);return}function x5(b){b=b|0;do{if((a[565956]&1)!=0){b=c[141491]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565944]&1)!=0){b=c[141488]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565932]&1)!=0){b=c[141485]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565920]&1)!=0){b=c[141482]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565908]&1)!=0){b=c[141479]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565896]&1)!=0){b=c[141476]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565884]&1)!=0){b=c[141473]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565872]&1)!=0){b=c[141470]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565860]&1)!=0){b=c[141467]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565848]&1)!=0){b=c[141464]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565836]&1)!=0){b=c[141461]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565824]&1)!=0){b=c[141458]|0;if((b|0)==0){break}yt(b)}}while(0);do{if((a[565812]&1)!=0){b=c[141455]|0;if((b|0)==0){break}yt(b)}}while(0);if((a[565800]&1)==0){return}b=c[141452]|0;if((b|0)==0){return}yt(b);return}function x6(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+8|0;h=g|0;c[h>>2]=b;j=((f|0)==0?278184:f)|0;f=c[j>>2]|0;L5560:do{if((d|0)==0){if((f|0)==0){k=0}else{break}i=g;return k|0}else{if((b|0)==0){l=h;c[h>>2]=l;m=l}else{m=b}if((e|0)==0){k=-2;i=g;return k|0}do{if((f|0)==0){l=a[d]|0;n=l&255;if(l<<24>>24>-1){c[m>>2]=n;k=l<<24>>24!=0|0;i=g;return k|0}else{l=n-194|0;if(l>>>0>50){break L5560}o=d+1|0;q=c[p+(l<<2)>>2]|0;r=e-1|0;break}}else{o=d;q=f;r=e}}while(0);L5578:do{if((r|0)==0){s=q}else{l=a[o]|0;n=(l&255)>>>3;if((n-16|n+(q>>26))>>>0>7){break L5560}else{t=o;u=q;v=r;w=l}while(1){t=t+1|0;u=u<<6|(w&255)-128;v=v-1|0;if((u|0)>=0){break}if((v|0)==0){s=u;break L5578}w=a[t]|0;if(((w&255)-128|0)>>>0>63){break L5560}}c[j>>2]=0;c[m>>2]=u;k=e-v|0;i=g;return k|0}}while(0);c[j>>2]=s;k=-2;i=g;return k|0}}while(0);c[j>>2]=0;c[(er()|0)>>2]=138;k=-1;i=g;return k|0}function x7(a){a=a|0;return}function x8(a){a=a|0;return 34440|0}function x9(a){a=a|0;return}function ya(a){a=a|0;return}function yb(a){a=a|0;return}function yc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0;if((c[d+8>>2]|0)!=(b|0)){return}b=d+16|0;g=c[b>>2]|0;if((g|0)==0){c[b>>2]=e;c[d+24>>2]=f;c[d+36>>2]=1;return}if((g|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;c[d+24>>2]=2;a[d+54|0]=1;return}e=d+24|0;if((c[e>>2]|0)!=2){return}c[e>>2]=f;return}function yd(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0;h=c[e>>2]|0;do{if((g|0)==0){i=4913}else{j=g|0;k=c[j>>2]|0;if((k|0)==0){i=4913;break}if((b|0)==0){l=k;m=h;n=f;i=4924;break}c[j>>2]=0;o=k;q=h;r=b;s=f;i=4944}}while(0);if((i|0)==4913){if((b|0)==0){t=h;u=f;i=4915}else{v=h;w=b;x=f;i=4914}}L5618:while(1){if((i|0)==4944){i=0;h=d[q]|0;g=h>>>3;if((g-16|g+(o>>26))>>>0>7){i=4945;break}g=q+1|0;y=h-128|o<<6;do{if((y|0)<0){h=(d[g]|0)-128|0;if(h>>>0>63){i=4948;break L5618}k=q+2|0;z=h|y<<6;if((z|0)>=0){A=z;B=k;break}h=(d[k]|0)-128|0;if(h>>>0>63){i=4951;break L5618}A=h|z<<6;B=q+3|0}else{A=y;B=g}}while(0);c[r>>2]=A;v=B;w=r+4|0;x=s-1|0;i=4914;continue}else if((i|0)==4924){i=0;g=(d[m]|0)>>>3;if((g-16|g+(l>>26))>>>0>7){i=4925;break}g=m+1|0;do{if((l&33554432|0)==0){C=g}else{if(((d[g]|0)-128|0)>>>0>63){i=4928;break L5618}h=m+2|0;if((l&524288|0)==0){C=h;break}if(((d[h]|0)-128|0)>>>0>63){i=4931;break L5618}C=m+3|0}}while(0);t=C;u=n-1|0;i=4915;continue}else if((i|0)==4915){i=0;g=a[t]|0;do{if(((g&255)-1|0)>>>0<127){if((t&3|0)!=0){D=t;E=u;F=g;break}h=c[t>>2]|0;if(((h-16843009|h)&-2139062144|0)==0){G=u;H=t}else{D=t;E=u;F=h&255;break}do{H=H+4|0;G=G-4|0;I=c[H>>2]|0;}while(((I-16843009|I)&-2139062144|0)==0);D=H;E=G;F=I&255}else{D=t;E=u;F=g}}while(0);g=F&255;if((g-1|0)>>>0<127){t=D+1|0;u=E-1|0;i=4915;continue}h=g-194|0;if(h>>>0>50){J=E;K=b;L=D;M=F;i=4956;break}l=c[p+(h<<2)>>2]|0;m=D+1|0;n=E;i=4924;continue}else if((i|0)==4914){i=0;if((x|0)==0){N=f;i=4967;break}else{O=x;P=w;Q=v}while(1){h=a[Q]|0;do{if(((h&255)-1|0)>>>0<127){if((Q&3|0)==0&O>>>0>3){R=O;S=P;T=Q}else{U=Q;V=P;W=O;X=h;break}while(1){Y=c[T>>2]|0;if(((Y-16843009|Y)&-2139062144|0)!=0){i=4939;break}c[S>>2]=Y&255;c[S+4>>2]=d[T+1|0]|0;c[S+8>>2]=d[T+2|0]|0;Z=T+4|0;_=S+16|0;c[S+12>>2]=d[T+3|0]|0;$=R-4|0;if($>>>0>3){R=$;S=_;T=Z}else{i=4938;break}}if((i|0)==4939){i=0;U=T;V=S;W=R;X=Y&255;break}else if((i|0)==4938){i=0;U=Z;V=_;W=$;X=a[Z]|0;break}}else{U=Q;V=P;W=O;X=h}}while(0);aa=X&255;if((aa-1|0)>>>0>=127){break}c[V>>2]=aa;h=W-1|0;if((h|0)==0){N=f;i=4963;break L5618}else{O=h;P=V+4|0;Q=U+1|0}}h=aa-194|0;if(h>>>0>50){J=W;K=V;L=U;M=X;i=4956;break}o=c[p+(h<<2)>>2]|0;q=U+1|0;r=V;s=W;i=4944;continue}}if((i|0)==4951){ab=z;ac=q-1|0;ad=r;ae=s;i=4954}else if((i|0)==4945){ab=o;ac=q-1|0;ad=r;ae=s;i=4954}else if((i|0)==4931){ab=l;ac=m-1|0;ad=b;ae=n;i=4954}else if((i|0)==4948){ab=y;ac=q-1|0;ad=r;ae=s;i=4954}else if((i|0)==4963){return N|0}else if((i|0)==4967){return N|0}else if((i|0)==4925){ab=l;ac=m-1|0;ad=b;ae=n;i=4954}else if((i|0)==4928){ab=l;ac=m-1|0;ad=b;ae=n;i=4954}do{if((i|0)==4954){if((ab|0)!=0){af=ad;ag=ac;break}J=ae;K=ad;L=ac;M=a[ac]|0;i=4956}}while(0);do{if((i|0)==4956){if(M<<24>>24!=0){af=K;ag=L;break}if((K|0)!=0){c[K>>2]=0;c[e>>2]=0}N=f-J|0;return N|0}}while(0);c[(er()|0)>>2]=138;if((af|0)==0){N=-1;return N|0}c[e>>2]=ag;N=-1;return N|0}function ye(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0){e=1;return e|0}if(d>>>0<128){a[b]=d&255;e=1;return e|0}if(d>>>0<2048){a[b]=(d>>>6|192)&255;a[b+1|0]=(d&63|128)&255;e=2;return e|0}if(d>>>0<55296|(d-57344|0)>>>0<8192){a[b]=(d>>>12|224)&255;a[b+1|0]=(d>>>6&63|128)&255;a[b+2|0]=(d&63|128)&255;e=3;return e|0}if((d-65536|0)>>>0<1048576){a[b]=(d>>>18|240)&255;a[b+1|0]=(d>>>12&63|128)&255;a[b+2|0]=(d>>>6&63|128)&255;a[b+3|0]=(d&63|128)&255;e=4;return e|0}else{c[(er()|0)>>2]=138;e=-1;return e|0}return 0}function yf(a){a=a|0;if((a|0)==0){return}yt(a);return}function yg(a){a=a|0;if((a|0)==0){return}yt(a);return}function yh(a){a=a|0;if((a|0)==0){return}yt(a);return}function yi(a){a=a|0;if((a|0)==0){return}yt(a);return}function yj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+112|0;f=e|0;g=e+56|0;if((a|0)==(b|0)){h=1;i=e;return h|0}if((b|0)==0){h=0;i=e;return h|0}j=b;k=c[b>>2]|0;b=j+(c[k-8>>2]|0)|0;l=c[k-4>>2]|0;k=l;c[f>>2]=80600;c[f+4>>2]=j;c[f+8>>2]=80616;c[f+12>>2]=-1;j=f+16|0;m=f+20|0;n=f+24|0;o=f+28|0;p=f+32|0;q=f+40|0;yB(j|0,0,39);do{if((l|0)==80600){c[f+48>>2]=1;ge[c[(c[20150]|0)+20>>2]&63](k,f,b,b,1,0);r=(c[n>>2]|0)==1?b:0}else{f1[c[(c[l>>2]|0)+24>>2]&15](k,f,b,1,0);s=c[f+36>>2]|0;if((s|0)==0){if((c[q>>2]|0)!=1){r=0;break}if((c[o>>2]|0)!=1){r=0;break}r=(c[p>>2]|0)==1?c[m>>2]|0:0;break}else if((s|0)!=1){r=0;break}if((c[n>>2]|0)!=1){if((c[q>>2]|0)!=0){r=0;break}if((c[o>>2]|0)!=1){r=0;break}if((c[p>>2]|0)!=1){r=0;break}}r=c[j>>2]|0}}while(0);j=r;if((r|0)==0){h=0;i=e;return h|0}yB(g|0,0,56);c[g>>2]=j;c[g+8>>2]=a;c[g+12>>2]=-1;c[g+48>>2]=1;gu[c[(c[r>>2]|0)+28>>2]&127](j,g,c[d>>2]|0,1);if((c[g+24>>2]|0)!=1){h=0;i=e;return h|0}c[d>>2]=c[g+16>>2];h=1;i=e;return h|0}function yk(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0;if((b|0)!=(c[d+8>>2]|0)){g=c[b+8>>2]|0;gu[c[(c[g>>2]|0)+28>>2]&127](g,d,e,f);return}g=d+16|0;b=c[g>>2]|0;if((b|0)==0){c[g>>2]=e;c[d+24>>2]=f;c[d+36>>2]=1;return}if((b|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;c[d+24>>2]=2;a[d+54|0]=1;return}e=d+24|0;if((c[e>>2]|0)!=2){return}c[e>>2]=f;return}function yl(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((b|0)==(c[d+8>>2]|0)){g=d+16|0;h=c[g>>2]|0;if((h|0)==0){c[g>>2]=e;c[d+24>>2]=f;c[d+36>>2]=1;return}if((h|0)!=(e|0)){h=d+36|0;c[h>>2]=(c[h>>2]|0)+1;c[d+24>>2]=2;a[d+54|0]=1;return}h=d+24|0;if((c[h>>2]|0)!=2){return}c[h>>2]=f;return}h=c[b+12>>2]|0;g=b+16+(h<<3)|0;i=c[b+20>>2]|0;j=i>>8;if((i&1|0)==0){k=j}else{k=c[(c[e>>2]|0)+j>>2]|0}j=c[b+16>>2]|0;gu[c[(c[j>>2]|0)+28>>2]&127](j,d,e+k|0,(i&2|0)!=0?f:2);if((h|0)<=1){return}h=d+54|0;i=e;k=b+24|0;while(1){b=c[k+4>>2]|0;j=b>>8;if((b&1|0)==0){l=j}else{l=c[(c[i>>2]|0)+j>>2]|0}j=c[k>>2]|0;gu[c[(c[j>>2]|0)+28>>2]&127](j,d,e+l|0,(b&2|0)!=0?f:2);if((a[h]&1)!=0){m=5063;break}b=k+8|0;if(b>>>0<g>>>0){k=b}else{m=5057;break}}if((m|0)==5063){return}else if((m|0)==5057){return}}function ym(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;if((c[d+8>>2]|0)==(b|0)){if((c[d+4>>2]|0)!=(e|0)){return}g=d+28|0;if((c[g>>2]|0)==1){return}c[g>>2]=f;return}if((c[d>>2]|0)!=(b|0)){return}do{if((c[d+16>>2]|0)!=(e|0)){b=d+20|0;if((c[b>>2]|0)==(e|0)){break}c[d+32>>2]=f;c[b>>2]=e;b=d+40|0;c[b>>2]=(c[b>>2]|0)+1;do{if((c[d+36>>2]|0)==1){if((c[d+24>>2]|0)!=2){break}a[d+54|0]=1}}while(0);c[d+44>>2]=4;return}}while(0);if((f|0)!=1){return}c[d+32>>2]=1;return}function yn(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((c[d+8>>2]|0)!=(b|0)){return}a[d+53|0]=1;if((c[d+4>>2]|0)!=(f|0)){return}a[d+52|0]=1;f=d+16|0;b=c[f>>2]|0;if((b|0)==0){c[f>>2]=e;c[d+24>>2]=g;c[d+36>>2]=1;if(!((c[d+48>>2]|0)==1&(g|0)==1)){return}a[d+54|0]=1;return}if((b|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;a[d+54|0]=1;return}e=d+24|0;b=c[e>>2]|0;if((b|0)==2){c[e>>2]=g;i=g}else{i=b}if(!((c[d+48>>2]|0)==1&(i|0)==1)){return}a[d+54|0]=1;return}function yo(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=b|0;if((h|0)==(c[d+8>>2]|0)){if((c[d+4>>2]|0)!=(e|0)){return}i=d+28|0;if((c[i>>2]|0)==1){return}c[i>>2]=f;return}if((h|0)==(c[d>>2]|0)){do{if((c[d+16>>2]|0)!=(e|0)){h=d+20|0;if((c[h>>2]|0)==(e|0)){break}c[d+32>>2]=f;i=d+44|0;if((c[i>>2]|0)==4){return}j=c[b+12>>2]|0;k=b+16+(j<<3)|0;L5875:do{if((j|0)>0){l=d+52|0;m=d+53|0;n=d+54|0;o=b+8|0;p=d+24|0;q=e;r=0;s=b+16|0;t=0;L5877:while(1){a[l]=0;a[m]=0;u=c[s+4>>2]|0;v=u>>8;if((u&1|0)==0){w=v}else{w=c[(c[q>>2]|0)+v>>2]|0}v=c[s>>2]|0;ge[c[(c[v>>2]|0)+20>>2]&63](v,d,e,e+w|0,2-(u>>>1&1)|0,g);if((a[n]&1)!=0){x=t;y=r;break}do{if((a[m]&1)==0){z=t;A=r}else{if((a[l]&1)==0){if((c[o>>2]&1|0)==0){x=1;y=r;break L5877}else{z=1;A=r;break}}if((c[p>>2]|0)==1){B=5130;break L5875}if((c[o>>2]&2|0)==0){B=5130;break L5875}else{z=1;A=1}}}while(0);u=s+8|0;if(u>>>0<k>>>0){r=A;s=u;t=z}else{x=z;y=A;break}}if(y){C=x;B=5129}else{D=x;B=5126}}else{D=0;B=5126}}while(0);do{if((B|0)==5126){c[h>>2]=e;k=d+40|0;c[k>>2]=(c[k>>2]|0)+1;if((c[d+36>>2]|0)!=1){C=D;B=5129;break}if((c[d+24>>2]|0)!=2){C=D;B=5129;break}a[d+54|0]=1;if(D){B=5130}else{B=5131}}}while(0);if((B|0)==5129){if(C){B=5130}else{B=5131}}if((B|0)==5130){c[i>>2]=3;return}else if((B|0)==5131){c[i>>2]=4;return}}}while(0);if((f|0)!=1){return}c[d+32>>2]=1;return}C=c[b+12>>2]|0;D=b+16+(C<<3)|0;x=c[b+20>>2]|0;y=x>>8;if((x&1|0)==0){E=y}else{E=c[(c[e>>2]|0)+y>>2]|0}y=c[b+16>>2]|0;f1[c[(c[y>>2]|0)+24>>2]&15](y,d,e+E|0,(x&2|0)!=0?f:2,g);x=b+24|0;if((C|0)<=1){return}C=c[b+8>>2]|0;do{if((C&2|0)==0){b=d+36|0;if((c[b>>2]|0)==1){break}if((C&1|0)==0){E=d+54|0;y=e;A=x;while(1){if((a[E]&1)!=0){B=5161;break}if((c[b>>2]|0)==1){B=5162;break}z=c[A+4>>2]|0;w=z>>8;if((z&1|0)==0){F=w}else{F=c[(c[y>>2]|0)+w>>2]|0}w=c[A>>2]|0;f1[c[(c[w>>2]|0)+24>>2]&15](w,d,e+F|0,(z&2|0)!=0?f:2,g);z=A+8|0;if(z>>>0<D>>>0){A=z}else{B=5171;break}}if((B|0)==5161){return}else if((B|0)==5162){return}else if((B|0)==5171){return}}A=d+24|0;y=d+54|0;E=e;i=x;while(1){if((a[y]&1)!=0){B=5173;break}if((c[b>>2]|0)==1){if((c[A>>2]|0)==1){B=5165;break}}z=c[i+4>>2]|0;w=z>>8;if((z&1|0)==0){G=w}else{G=c[(c[E>>2]|0)+w>>2]|0}w=c[i>>2]|0;f1[c[(c[w>>2]|0)+24>>2]&15](w,d,e+G|0,(z&2|0)!=0?f:2,g);z=i+8|0;if(z>>>0<D>>>0){i=z}else{B=5160;break}}if((B|0)==5160){return}else if((B|0)==5165){return}else if((B|0)==5173){return}}}while(0);G=d+54|0;F=e;C=x;while(1){if((a[G]&1)!=0){B=5158;break}x=c[C+4>>2]|0;i=x>>8;if((x&1|0)==0){H=i}else{H=c[(c[F>>2]|0)+i>>2]|0}i=c[C>>2]|0;f1[c[(c[i>>2]|0)+24>>2]&15](i,d,e+H|0,(x&2|0)!=0?f:2,g);x=C+8|0;if(x>>>0<D>>>0){C=x}else{B=5170;break}}if((B|0)==5158){return}else if((B|0)==5170){return}}function yp(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=b|0;if((h|0)==(c[d+8>>2]|0)){if((c[d+4>>2]|0)!=(e|0)){return}i=d+28|0;if((c[i>>2]|0)==1){return}c[i>>2]=f;return}if((h|0)!=(c[d>>2]|0)){h=c[b+8>>2]|0;f1[c[(c[h>>2]|0)+24>>2]&15](h,d,e,f,g);return}do{if((c[d+16>>2]|0)!=(e|0)){h=d+20|0;if((c[h>>2]|0)==(e|0)){break}c[d+32>>2]=f;i=d+44|0;if((c[i>>2]|0)==4){return}j=d+52|0;a[j]=0;k=d+53|0;a[k]=0;l=c[b+8>>2]|0;ge[c[(c[l>>2]|0)+20>>2]&63](l,d,e,e,1,g);if((a[k]&1)==0){m=0;n=5186}else{if((a[j]&1)==0){m=1;n=5186}}L5977:do{if((n|0)==5186){c[h>>2]=e;j=d+40|0;c[j>>2]=(c[j>>2]|0)+1;do{if((c[d+36>>2]|0)==1){if((c[d+24>>2]|0)!=2){n=5189;break}a[d+54|0]=1;if(m){break L5977}}else{n=5189}}while(0);if((n|0)==5189){if(m){break}}c[i>>2]=4;return}}while(0);c[i>>2]=3;return}}while(0);if((f|0)!=1){return}c[d+32>>2]=1;return}function yq(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((b|0)!=(c[d+8>>2]|0)){i=d+52|0;j=a[i]&1;k=d+53|0;l=a[k]&1;m=c[b+12>>2]|0;n=b+16+(m<<3)|0;a[i]=0;a[k]=0;o=c[b+20>>2]|0;p=o>>8;if((o&1|0)==0){q=p}else{q=c[(c[f>>2]|0)+p>>2]|0}p=c[b+16>>2]|0;ge[c[(c[p>>2]|0)+20>>2]&63](p,d,e,f+q|0,(o&2|0)!=0?g:2,h);L5999:do{if((m|0)>1){o=d+24|0;q=b+8|0;p=d+54|0;r=f;s=b+24|0;do{if((a[p]&1)!=0){break L5999}do{if((a[i]&1)==0){if((a[k]&1)==0){break}if((c[q>>2]&1|0)==0){break L5999}}else{if((c[o>>2]|0)==1){break L5999}if((c[q>>2]&2|0)==0){break L5999}}}while(0);a[i]=0;a[k]=0;t=c[s+4>>2]|0;u=t>>8;if((t&1|0)==0){v=u}else{v=c[(c[r>>2]|0)+u>>2]|0}u=c[s>>2]|0;ge[c[(c[u>>2]|0)+20>>2]&63](u,d,e,f+v|0,(t&2|0)!=0?g:2,h);s=s+8|0;}while(s>>>0<n>>>0)}}while(0);a[i]=j;a[k]=l;return}a[d+53|0]=1;if((c[d+4>>2]|0)!=(f|0)){return}a[d+52|0]=1;f=d+16|0;l=c[f>>2]|0;if((l|0)==0){c[f>>2]=e;c[d+24>>2]=g;c[d+36>>2]=1;if(!((c[d+48>>2]|0)==1&(g|0)==1)){return}a[d+54|0]=1;return}if((l|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;a[d+54|0]=1;return}e=d+24|0;l=c[e>>2]|0;if((l|0)==2){c[e>>2]=g;w=g}else{w=l}if(!((c[d+48>>2]|0)==1&(w|0)==1)){return}a[d+54|0]=1;return}function yr(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;if((b|0)!=(c[d+8>>2]|0)){i=c[b+8>>2]|0;ge[c[(c[i>>2]|0)+20>>2]&63](i,d,e,f,g,h);return}a[d+53|0]=1;if((c[d+4>>2]|0)!=(f|0)){return}a[d+52|0]=1;f=d+16|0;h=c[f>>2]|0;if((h|0)==0){c[f>>2]=e;c[d+24>>2]=g;c[d+36>>2]=1;if(!((c[d+48>>2]|0)==1&(g|0)==1)){return}a[d+54|0]=1;return}if((h|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;a[d+54|0]=1;return}e=d+24|0;h=c[e>>2]|0;if((h|0)==2){c[e>>2]=g;j=g}else{j=h}if(!((c[d+48>>2]|0)==1&(j|0)==1)){return}a[d+54|0]=1;return}function ys(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;do{if(a>>>0<245){if(a>>>0<11){b=16}else{b=a+11&-8}d=b>>>3;e=c[141018]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=564112+(h<<2)|0;j=564112+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[141018]=e&~(1<<g)}else{if(l>>>0<(c[141022]|0)>>>0){cq();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{cq();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(b>>>0<=(c[141020]|0)>>>0){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=564112+(p<<2)|0;m=564112+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[141018]=e&~(1<<r)}else{if(l>>>0<(c[141022]|0)>>>0){cq();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{cq();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[141020]|0;if((l|0)!=0){q=c[141023]|0;d=l>>>3;l=d<<1;f=564112+(l<<2)|0;k=c[141018]|0;h=1<<d;do{if((k&h|0)==0){c[141018]=k|h;s=f;t=564112+(l+2<<2)|0}else{d=564112+(l+2<<2)|0;g=c[d>>2]|0;if(g>>>0>=(c[141022]|0)>>>0){s=g;t=d;break}cq();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[141020]=m;c[141023]=e;n=i;return n|0}l=c[141019]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[564376+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[141022]|0;if(r>>>0<i>>>0){cq();return 0}e=r+b|0;m=e;if(r>>>0>=e>>>0){cq();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){cq();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){cq();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){cq();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{cq();return 0}}}while(0);L6141:do{if((e|0)!=0){f=d+28|0;i=564376+(c[f>>2]<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[141019]=c[141019]&~(1<<c[f>>2]);break L6141}else{if(e>>>0<(c[141022]|0)>>>0){cq();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break L6141}}}while(0);if(v>>>0<(c[141022]|0)>>>0){cq();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[141020]|0;if((f|0)!=0){e=c[141023]|0;i=f>>>3;f=i<<1;q=564112+(f<<2)|0;k=c[141018]|0;g=1<<i;do{if((k&g|0)==0){c[141018]=k|g;y=q;z=564112+(f+2<<2)|0}else{i=564112+(f+2<<2)|0;l=c[i>>2]|0;if(l>>>0>=(c[141022]|0)>>>0){y=l;z=i;break}cq();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[141020]=p;c[141023]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231){o=-1;break}f=a+11|0;g=f&-8;k=c[141019]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[564376+(A<<2)>>2]|0;L6189:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break L6189}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=(i|-i)&k;if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[564376+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(J>>>0>=((c[141020]|0)-g|0)>>>0){o=g;break}q=K;m=c[141022]|0;if(q>>>0<m>>>0){cq();return 0}p=q+g|0;k=p;if(q>>>0>=p>>>0){cq();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){cq();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){cq();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){cq();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{cq();return 0}}}while(0);L6239:do{if((e|0)!=0){i=K+28|0;m=564376+(c[i>>2]<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[141019]=c[141019]&~(1<<c[i>>2]);break L6239}else{if(e>>>0<(c[141022]|0)>>>0){cq();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break L6239}}}while(0);if(L>>>0<(c[141022]|0)>>>0){cq();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256){e=i<<1;m=564112+(e<<2)|0;r=c[141018]|0;j=1<<i;do{if((r&j|0)==0){c[141018]=r|j;O=m;P=564112+(e+2<<2)|0}else{i=564112+(e+2<<2)|0;d=c[i>>2]|0;if(d>>>0>=(c[141022]|0)>>>0){O=d;P=i;break}cq();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=564376+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[141019]|0;l=1<<Q;if((m&l|0)==0){c[141019]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=5406;break}else{l=l<<1;m=j}}if((T|0)==5406){if(S>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[141022]|0;if(m>>>0<i>>>0){cq();return 0}if(j>>>0<i>>>0){cq();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[141020]|0;if(o>>>0<=K>>>0){S=K-o|0;J=c[141023]|0;if(S>>>0>15){R=J;c[141023]=R+o;c[141020]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[141020]=0;c[141023]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[141021]|0;if(o>>>0<J>>>0){S=J-o|0;c[141021]=S;J=c[141024]|0;K=J;c[141024]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[21540]|0)==0){J=aX(8)|0;if((J-1&J|0)==0){c[21542]=J;c[21541]=J;c[21543]=-1;c[21544]=-1;c[21545]=0;c[141129]=0;c[21540]=(fp(0)|0)&-16^1431655768;break}else{cq();return 0}}}while(0);J=o+48|0;S=c[21542]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(S>>>0<=o>>>0){n=0;return n|0}O=c[141128]|0;do{if((O|0)!=0){P=c[141126]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);L6331:do{if((c[141129]&4|0)==0){O=c[141024]|0;L6333:do{if((O|0)==0){T=5436}else{L=O;P=564520;while(1){U=P|0;M=c[U>>2]|0;if(M>>>0<=L>>>0){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=5436;break L6333}else{P=M}}if((P|0)==0){T=5436;break}L=R-(c[141021]|0)&Q;if(L>>>0>=2147483647){W=0;break}m=bu(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=5445}}while(0);do{if((T|0)==5436){O=bu(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[21541]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[141126]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647)){W=0;break}m=c[141128]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=bu($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=5445}}while(0);L6353:do{if((T|0)==5445){m=-_|0;if((X|0)!=-1){aa=Y;ab=X;T=5456;break L6331}do{if((Z|0)!=-1&_>>>0<2147483647&_>>>0<J>>>0){g=c[21542]|0;O=K-_+g&-g;if(O>>>0>=2147483647){ac=_;break}if((bu(O|0)|0)==-1){bu(m|0)|0;W=Y;break L6353}else{ac=O+_|0;break}}else{ac=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ac;ab=Z;T=5456;break L6331}}}while(0);c[141129]=c[141129]|4;ad=W;T=5453}else{ad=0;T=5453}}while(0);do{if((T|0)==5453){if(S>>>0>=2147483647){break}W=bu(S|0)|0;Z=bu(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ac=Z-W|0;Z=ac>>>0>(o+40|0)>>>0;Y=Z?W:-1;if((Y|0)!=-1){aa=Z?ac:ad;ab=Y;T=5456}}}while(0);do{if((T|0)==5456){ad=(c[141126]|0)+aa|0;c[141126]=ad;if(ad>>>0>(c[141127]|0)>>>0){c[141127]=ad}ad=c[141024]|0;L6373:do{if((ad|0)==0){S=c[141022]|0;if((S|0)==0|ab>>>0<S>>>0){c[141022]=ab}c[141130]=ab;c[141131]=aa;c[141133]=0;c[141027]=c[21540];c[141026]=-1;S=0;do{Y=S<<1;ac=564112+(Y<<2)|0;c[564112+(Y+3<<2)>>2]=ac;c[564112+(Y+2<<2)>>2]=ac;S=S+1|0;}while(S>>>0<32);S=ab+8|0;if((S&7|0)==0){ae=0}else{ae=-S&7}S=aa-40-ae|0;c[141024]=ab+ae;c[141021]=S;c[ab+(ae+4)>>2]=S|1;c[ab+(aa-36)>>2]=40;c[141025]=c[21544]}else{S=564520;while(1){af=c[S>>2]|0;ag=S+4|0;ah=c[ag>>2]|0;if((ab|0)==(af+ah|0)){T=5468;break}ac=c[S+8>>2]|0;if((ac|0)==0){break}else{S=ac}}do{if((T|0)==5468){if((c[S+12>>2]&8|0)!=0){break}ac=ad;if(!(ac>>>0>=af>>>0&ac>>>0<ab>>>0)){break}c[ag>>2]=ah+aa;ac=c[141024]|0;Y=(c[141021]|0)+aa|0;Z=ac;W=ac+8|0;if((W&7|0)==0){ai=0}else{ai=-W&7}W=Y-ai|0;c[141024]=Z+ai;c[141021]=W;c[Z+(ai+4)>>2]=W|1;c[Z+(Y+4)>>2]=40;c[141025]=c[21544];break L6373}}while(0);if(ab>>>0<(c[141022]|0)>>>0){c[141022]=ab}S=ab+aa|0;Y=564520;while(1){aj=Y|0;if((c[aj>>2]|0)==(S|0)){T=5478;break}Z=c[Y+8>>2]|0;if((Z|0)==0){break}else{Y=Z}}do{if((T|0)==5478){if((c[Y+12>>2]&8|0)!=0){break}c[aj>>2]=ab;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ab+8|0;if((S&7|0)==0){ak=0}else{ak=-S&7}S=ab+(aa+8)|0;if((S&7|0)==0){al=0}else{al=-S&7}S=ab+(al+aa)|0;Z=S;W=ak+o|0;ac=ab+W|0;_=ac;K=S-(ab+ak)-o|0;c[ab+(ak+4)>>2]=o|3;do{if((Z|0)==(c[141024]|0)){J=(c[141021]|0)+K|0;c[141021]=J;c[141024]=_;c[ab+(W+4)>>2]=J|1}else{if((Z|0)==(c[141023]|0)){J=(c[141020]|0)+K|0;c[141020]=J;c[141023]=_;c[ab+(W+4)>>2]=J|1;c[ab+(J+W)>>2]=J;break}J=aa+4|0;X=c[ab+(al+J)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;L6408:do{if(X>>>0<256){U=c[ab+((al|8)+aa)>>2]|0;Q=c[ab+(aa+12+al)>>2]|0;R=564112+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[141022]|0)>>>0){cq();return 0}if((c[U+12>>2]|0)==(Z|0)){break}cq();return 0}}while(0);if((Q|0)==(U|0)){c[141018]=c[141018]&~(1<<V);break}do{if((Q|0)==(R|0)){am=Q+8|0}else{if(Q>>>0<(c[141022]|0)>>>0){cq();return 0}m=Q+8|0;if((c[m>>2]|0)==(Z|0)){am=m;break}cq();return 0}}while(0);c[U+12>>2]=Q;c[am>>2]=U}else{R=S;m=c[ab+((al|24)+aa)>>2]|0;P=c[ab+(aa+12+al)>>2]|0;do{if((P|0)==(R|0)){O=al|16;g=ab+(O+J)|0;L=c[g>>2]|0;if((L|0)==0){e=ab+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){an=0;break}else{ao=O;ap=e}}else{ao=L;ap=g}while(1){g=ao+20|0;L=c[g>>2]|0;if((L|0)!=0){ao=L;ap=g;continue}g=ao+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{ao=L;ap=g}}if(ap>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[ap>>2]=0;an=ao;break}}else{g=c[ab+((al|8)+aa)>>2]|0;if(g>>>0<(c[141022]|0)>>>0){cq();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){cq();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;an=P;break}else{cq();return 0}}}while(0);if((m|0)==0){break}P=ab+(aa+28+al)|0;U=564376+(c[P>>2]<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=an;if((an|0)!=0){break}c[141019]=c[141019]&~(1<<c[P>>2]);break L6408}else{if(m>>>0<(c[141022]|0)>>>0){cq();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=an}else{c[m+20>>2]=an}if((an|0)==0){break L6408}}}while(0);if(an>>>0<(c[141022]|0)>>>0){cq();return 0}c[an+24>>2]=m;R=al|16;P=c[ab+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[an+16>>2]=P;c[P+24>>2]=an;break}}}while(0);P=c[ab+(R+J)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[an+20>>2]=P;c[P+24>>2]=an;break}}}while(0);aq=ab+(($|al)+aa)|0;ar=$+K|0}else{aq=Z;ar=K}J=aq+4|0;c[J>>2]=c[J>>2]&-2;c[ab+(W+4)>>2]=ar|1;c[ab+(ar+W)>>2]=ar;J=ar>>>3;if(ar>>>0<256){V=J<<1;X=564112+(V<<2)|0;P=c[141018]|0;m=1<<J;do{if((P&m|0)==0){c[141018]=P|m;as=X;at=564112+(V+2<<2)|0}else{J=564112+(V+2<<2)|0;U=c[J>>2]|0;if(U>>>0>=(c[141022]|0)>>>0){as=U;at=J;break}cq();return 0}}while(0);c[at>>2]=_;c[as+12>>2]=_;c[ab+(W+8)>>2]=as;c[ab+(W+12)>>2]=X;break}V=ac;m=ar>>>8;do{if((m|0)==0){au=0}else{if(ar>>>0>16777215){au=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;au=ar>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=564376+(au<<2)|0;c[ab+(W+28)>>2]=au;c[ab+(W+20)>>2]=0;c[ab+(W+16)>>2]=0;X=c[141019]|0;Q=1<<au;if((X&Q|0)==0){c[141019]=X|Q;c[m>>2]=V;c[ab+(W+24)>>2]=m;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}if((au|0)==31){av=0}else{av=25-(au>>>1)|0}Q=ar<<av;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ar|0)){break}aw=X+16+(Q>>>31<<2)|0;m=c[aw>>2]|0;if((m|0)==0){T=5551;break}else{Q=Q<<1;X=m}}if((T|0)==5551){if(aw>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[aw>>2]=V;c[ab+(W+24)>>2]=X;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[141022]|0;if(X>>>0<$>>>0){cq();return 0}if(m>>>0<$>>>0){cq();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ab+(W+8)>>2]=m;c[ab+(W+12)>>2]=X;c[ab+(W+24)>>2]=0;break}}}while(0);n=ab+(ak|8)|0;return n|0}}while(0);Y=ad;W=564520;while(1){ax=c[W>>2]|0;if(ax>>>0<=Y>>>0){ay=c[W+4>>2]|0;az=ax+ay|0;if(az>>>0>Y>>>0){break}}W=c[W+8>>2]|0}W=ax+(ay-39)|0;if((W&7|0)==0){aA=0}else{aA=-W&7}W=ax+(ay-47+aA)|0;ac=W>>>0<(ad+16|0)>>>0?Y:W;W=ac+8|0;_=ab+8|0;if((_&7|0)==0){aB=0}else{aB=-_&7}_=aa-40-aB|0;c[141024]=ab+aB;c[141021]=_;c[ab+(aB+4)>>2]=_|1;c[ab+(aa-36)>>2]=40;c[141025]=c[21544];c[ac+4>>2]=27;c[W>>2]=c[141130];c[W+4>>2]=c[564524>>2];c[W+8>>2]=c[564528>>2];c[W+12>>2]=c[564532>>2];c[141130]=ab;c[141131]=aa;c[141133]=0;c[141132]=W;W=ac+28|0;c[W>>2]=7;if((ac+32|0)>>>0<az>>>0){_=W;while(1){W=_+4|0;c[W>>2]=7;if((_+8|0)>>>0<az>>>0){_=W}else{break}}}if((ac|0)==(Y|0)){break}_=ac-ad|0;W=Y+(_+4)|0;c[W>>2]=c[W>>2]&-2;c[ad+4>>2]=_|1;c[Y+_>>2]=_;W=_>>>3;if(_>>>0<256){K=W<<1;Z=564112+(K<<2)|0;S=c[141018]|0;m=1<<W;do{if((S&m|0)==0){c[141018]=S|m;aC=Z;aD=564112+(K+2<<2)|0}else{W=564112+(K+2<<2)|0;Q=c[W>>2]|0;if(Q>>>0>=(c[141022]|0)>>>0){aC=Q;aD=W;break}cq();return 0}}while(0);c[aD>>2]=ad;c[aC+12>>2]=ad;c[ad+8>>2]=aC;c[ad+12>>2]=Z;break}K=ad;m=_>>>8;do{if((m|0)==0){aE=0}else{if(_>>>0>16777215){aE=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;ac=(Y+520192|0)>>>16&4;W=Y<<ac;Y=(W+245760|0)>>>16&2;Q=14-(ac|S|Y)+(W<<Y>>>15)|0;aE=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=564376+(aE<<2)|0;c[ad+28>>2]=aE;c[ad+20>>2]=0;c[ad+16>>2]=0;Z=c[141019]|0;Q=1<<aE;if((Z&Q|0)==0){c[141019]=Z|Q;c[m>>2]=K;c[ad+24>>2]=m;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}if((aE|0)==31){aF=0}else{aF=25-(aE>>>1)|0}Q=_<<aF;Z=c[m>>2]|0;while(1){if((c[Z+4>>2]&-8|0)==(_|0)){break}aG=Z+16+(Q>>>31<<2)|0;m=c[aG>>2]|0;if((m|0)==0){T=5586;break}else{Q=Q<<1;Z=m}}if((T|0)==5586){if(aG>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[aG>>2]=K;c[ad+24>>2]=Z;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}}Q=Z+8|0;_=c[Q>>2]|0;m=c[141022]|0;if(Z>>>0<m>>>0){cq();return 0}if(_>>>0<m>>>0){cq();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[ad+8>>2]=_;c[ad+12>>2]=Z;c[ad+24>>2]=0;break}}}while(0);ad=c[141021]|0;if(ad>>>0<=o>>>0){break}_=ad-o|0;c[141021]=_;ad=c[141024]|0;Q=ad;c[141024]=Q+o;c[Q+(o+4)>>2]=_|1;c[ad+4>>2]=o|3;n=ad+8|0;return n|0}}while(0);c[(er()|0)>>2]=12;n=0;return n|0}function yt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[141022]|0;if(b>>>0<e>>>0){cq()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){cq()}h=f&-8;i=a+(h-8)|0;j=i;L6590:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){cq()}if((n|0)==(c[141023]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[141020]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=564112+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){cq()}if((c[k+12>>2]|0)==(n|0)){break}cq()}}while(0);if((s|0)==(k|0)){c[141018]=c[141018]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){cq()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}cq()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){cq()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){cq()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){cq()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{cq()}}}while(0);if((p|0)==0){q=n;r=o;break}v=a+(l+28)|0;m=564376+(c[v>>2]<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[141019]=c[141019]&~(1<<c[v>>2]);q=n;r=o;break L6590}else{if(p>>>0<(c[141022]|0)>>>0){cq()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break L6590}}}while(0);if(A>>>0<(c[141022]|0)>>>0){cq()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[141022]|0)>>>0){cq()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[141022]|0)>>>0){cq()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(d>>>0>=i>>>0){cq()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){cq()}do{if((e&2|0)==0){if((j|0)==(c[141024]|0)){B=(c[141021]|0)+r|0;c[141021]=B;c[141024]=q;c[q+4>>2]=B|1;if((q|0)!=(c[141023]|0)){return}c[141023]=0;c[141020]=0;return}if((j|0)==(c[141023]|0)){B=(c[141020]|0)+r|0;c[141020]=B;c[141023]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;L6692:do{if(e>>>0<256){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=564112+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[141022]|0)>>>0){cq()}if((c[u+12>>2]|0)==(j|0)){break}cq()}}while(0);if((g|0)==(u|0)){c[141018]=c[141018]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[141022]|0)>>>0){cq()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}cq()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[141022]|0)>>>0){cq()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[141022]|0)>>>0){cq()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){cq()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{cq()}}}while(0);if((f|0)==0){break}t=a+(h+20)|0;u=564376+(c[t>>2]<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[141019]=c[141019]&~(1<<c[t>>2]);break L6692}else{if(f>>>0<(c[141022]|0)>>>0){cq()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break L6692}}}while(0);if(E>>>0<(c[141022]|0)>>>0){cq()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[141022]|0)>>>0){cq()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[141022]|0)>>>0){cq()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[141023]|0)){H=B;break}c[141020]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256){d=r<<1;e=564112+(d<<2)|0;A=c[141018]|0;E=1<<r;do{if((A&E|0)==0){c[141018]=A|E;I=e;J=564112+(d+2<<2)|0}else{r=564112+(d+2<<2)|0;h=c[r>>2]|0;if(h>>>0>=(c[141022]|0)>>>0){I=h;J=r;break}cq()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=564376+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[141019]|0;d=1<<K;do{if((r&d|0)==0){c[141019]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=5763;break}else{A=A<<1;J=E}}if((N|0)==5763){if(M>>>0<(c[141022]|0)>>>0){cq()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[141022]|0;if(J>>>0<E>>>0){cq()}if(B>>>0<E>>>0){cq()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[141026]|0)-1|0;c[141026]=q;if((q|0)==0){O=564528}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[141026]=-1;return}function yu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((a|0)==0){d=ys(b)|0;return d|0}if(b>>>0>4294967231){c[(er()|0)>>2]=12;d=0;return d|0}if(b>>>0<11){e=16}else{e=b+11&-8}f=a-8|0;g=a-4|0;h=c[g>>2]|0;i=h&-8;j=i-8|0;k=a+j|0;l=k;m=c[141022]|0;if(f>>>0<m>>>0){cq();return 0}n=h&3;if(!((n|0)!=1&(j|0)>-8)){cq();return 0}j=i|4;o=a+(j-8)|0;p=c[o>>2]|0;if((p&1|0)==0){cq();return 0}L6828:do{if((n|0)==0){if(e>>>0<256|i>>>0<(e|4)>>>0){break}if((i-e|0)>>>0>c[21542]<<1>>>0|(f|0)==0){break}else{d=a}return d|0}else{do{if(i>>>0<e>>>0){if((l|0)==(c[141024]|0)){q=(c[141021]|0)+i|0;if(q>>>0<=e>>>0){break L6828}r=q-e|0;c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=r|1;c[141024]=a+(e-8);c[141021]=r;break}if((l|0)==(c[141023]|0)){r=(c[141020]|0)+i|0;if(r>>>0<e>>>0){break L6828}q=r-e|0;if(q>>>0>15){c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=q|1;c[a+(r-8)>>2]=q;s=a+(r-4)|0;c[s>>2]=c[s>>2]&-2;t=a+(e-8)|0;u=q}else{c[g>>2]=h&1|r|2;q=a+(r-4)|0;c[q>>2]=c[q>>2]|1;t=0;u=0}c[141020]=u;c[141023]=t;break}if((p&2|0)!=0){break L6828}q=(p&-8)+i|0;if(q>>>0<e>>>0){break L6828}r=q-e|0;s=p>>>3;L6852:do{if(p>>>0<256){v=c[a+i>>2]|0;w=c[a+j>>2]|0;x=564112+(s<<1<<2)|0;do{if((v|0)!=(x|0)){if(v>>>0<m>>>0){cq();return 0}if((c[v+12>>2]|0)==(l|0)){break}cq();return 0}}while(0);if((w|0)==(v|0)){c[141018]=c[141018]&~(1<<s);break}do{if((w|0)==(x|0)){y=w+8|0}else{if(w>>>0<m>>>0){cq();return 0}z=w+8|0;if((c[z>>2]|0)==(l|0)){y=z;break}cq();return 0}}while(0);c[v+12>>2]=w;c[y>>2]=v}else{x=k;z=c[a+(i+16)>>2]|0;A=c[a+j>>2]|0;do{if((A|0)==(x|0)){B=a+(i+12)|0;C=c[B>>2]|0;if((C|0)==0){D=a+(i+8)|0;E=c[D>>2]|0;if((E|0)==0){F=0;break}else{G=E;H=D}}else{G=C;H=B}while(1){B=G+20|0;C=c[B>>2]|0;if((C|0)!=0){G=C;H=B;continue}B=G+16|0;C=c[B>>2]|0;if((C|0)==0){break}else{G=C;H=B}}if(H>>>0<m>>>0){cq();return 0}else{c[H>>2]=0;F=G;break}}else{B=c[a+i>>2]|0;if(B>>>0<m>>>0){cq();return 0}C=B+12|0;if((c[C>>2]|0)!=(x|0)){cq();return 0}D=A+8|0;if((c[D>>2]|0)==(x|0)){c[C>>2]=A;c[D>>2]=B;F=A;break}else{cq();return 0}}}while(0);if((z|0)==0){break}A=a+(i+20)|0;v=564376+(c[A>>2]<<2)|0;do{if((x|0)==(c[v>>2]|0)){c[v>>2]=F;if((F|0)!=0){break}c[141019]=c[141019]&~(1<<c[A>>2]);break L6852}else{if(z>>>0<(c[141022]|0)>>>0){cq();return 0}w=z+16|0;if((c[w>>2]|0)==(x|0)){c[w>>2]=F}else{c[z+20>>2]=F}if((F|0)==0){break L6852}}}while(0);if(F>>>0<(c[141022]|0)>>>0){cq();return 0}c[F+24>>2]=z;x=c[a+(i+8)>>2]|0;do{if((x|0)!=0){if(x>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[F+16>>2]=x;c[x+24>>2]=F;break}}}while(0);x=c[a+(i+12)>>2]|0;if((x|0)==0){break}if(x>>>0<(c[141022]|0)>>>0){cq();return 0}else{c[F+20>>2]=x;c[x+24>>2]=F;break}}}while(0);if(r>>>0>=16){c[g>>2]=c[g>>2]&1|e|2;c[a+((e|4)-8)>>2]=r|3;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;yy(a+(e-8)|0,r);break}c[g>>2]=q|c[g>>2]&1|2;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;d=a;return d|0}else{s=i-e|0;if(s>>>0<=15){break}c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=s|3;c[o>>2]=c[o>>2]|1;yy(a+(e-8)|0,s);d=a;return d|0}}while(0);if((f|0)==0){break}else{d=a}return d|0}}while(0);f=ys(b)|0;if((f|0)==0){d=0;return d|0}e=c[g>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;e=g>>>0<b>>>0?g:b;yE(f|0,a|0,e)|0;yt(a);d=f;return d|0}function yv(a){a=a|0;return}function yw(a){a=a|0;return 29240|0}function yx(a){a=a|0;if((a|0)==0){return}yt(a);return}function yy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;L6941:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[141022]|0;if(i>>>0<l>>>0){cq()}if((j|0)==(c[141023]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[141020]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=564112+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){cq()}if((c[p+12>>2]|0)==(j|0)){break}cq()}}while(0);if((q|0)==(p|0)){c[141018]=c[141018]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){cq()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}cq()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){cq()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){cq()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){cq()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{cq()}}}while(0);if((m|0)==0){n=j;o=k;break}t=d+(28-h)|0;l=564376+(c[t>>2]<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[141019]=c[141019]&~(1<<c[t>>2]);n=j;o=k;break L6941}else{if(m>>>0<(c[141022]|0)>>>0){cq()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break L6941}}}while(0);if(y>>>0<(c[141022]|0)>>>0){cq()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[141022]|0)>>>0){cq()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[141022]|0)>>>0){cq()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[141022]|0;if(e>>>0<a>>>0){cq()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[141024]|0)){A=(c[141021]|0)+o|0;c[141021]=A;c[141024]=n;c[n+4>>2]=A|1;if((n|0)!=(c[141023]|0)){return}c[141023]=0;c[141020]=0;return}if((f|0)==(c[141023]|0)){A=(c[141020]|0)+o|0;c[141020]=A;c[141023]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;L7040:do{if(z>>>0<256){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=564112+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){cq()}if((c[g+12>>2]|0)==(f|0)){break}cq()}}while(0);if((t|0)==(g|0)){c[141018]=c[141018]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){cq()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}cq()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){cq()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){cq()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){cq()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{cq()}}}while(0);if((m|0)==0){break}l=d+(b+28)|0;g=564376+(c[l>>2]<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[141019]=c[141019]&~(1<<c[l>>2]);break L7040}else{if(m>>>0<(c[141022]|0)>>>0){cq()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break L7040}}}while(0);if(C>>>0<(c[141022]|0)>>>0){cq()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[141022]|0)>>>0){cq()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[141022]|0)>>>0){cq()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[141023]|0)){F=A;break}c[141020]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256){z=o<<1;y=564112+(z<<2)|0;C=c[141018]|0;b=1<<o;do{if((C&b|0)==0){c[141018]=C|b;G=y;H=564112+(z+2<<2)|0}else{o=564112+(z+2<<2)|0;d=c[o>>2]|0;if(d>>>0>=(c[141022]|0)>>>0){G=d;H=o;break}cq()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=564376+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[141019]|0;z=1<<I;if((o&z|0)==0){c[141019]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=6036;break}else{I=I<<1;J=G}}if((L|0)==6036){if(K>>>0<(c[141022]|0)>>>0){cq()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[141022]|0;if(J>>>0<I>>>0){cq()}if(L>>>0<I>>>0){cq()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function yz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0,P=0,Q=0.0,R=0.0,S=0.0;e=b;while(1){f=e+1|0;if((bp(a[e]|0)|0)==0){break}else{e=f}}g=a[e]|0;if((g<<24>>24|0)==43){i=f;j=0}else if((g<<24>>24|0)==45){i=f;j=1}else{i=e;j=0}e=-1;f=0;g=i;while(1){k=a[g]|0;if(((k<<24>>24)-48|0)>>>0<10){l=e}else{if(k<<24>>24!=46|(e|0)>-1){break}else{l=f}}e=l;f=f+1|0;g=g+1|0}l=g+(-f|0)|0;i=(e|0)<0;m=((i^1)<<31>>31)+f|0;n=(m|0)>18;o=(n?-18:-m|0)+(i?f:e)|0;e=n?18:m;do{if((e|0)==0){p=b;q=0.0}else{if((e|0)>9){m=l;n=e;f=0;while(1){i=a[m]|0;r=m+1|0;if(i<<24>>24==46){s=a[r]|0;t=m+2|0}else{s=i;t=r}u=(f*10|0)-48+(s<<24>>24)|0;r=n-1|0;if((r|0)>9){m=t;n=r;f=u}else{break}}v=+(u|0)*1.0e9;w=9;x=t;y=6084}else{if((e|0)>0){v=0.0;w=e;x=l;y=6084}else{z=0.0;A=0.0}}if((y|0)==6084){f=x;n=w;m=0;while(1){r=a[f]|0;i=f+1|0;if(r<<24>>24==46){B=a[i]|0;C=f+2|0}else{B=r;C=i}D=(m*10|0)-48+(B<<24>>24)|0;i=n-1|0;if((i|0)>0){f=C;n=i;m=D}else{break}}z=+(D|0);A=v}E=A+z;do{if((k<<24>>24|0)==69|(k<<24>>24|0)==101){m=g+1|0;n=a[m]|0;if((n<<24>>24|0)==45){F=g+2|0;G=1}else if((n<<24>>24|0)==43){F=g+2|0;G=0}else{F=m;G=0}m=a[F]|0;if(((m<<24>>24)-48|0)>>>0<10){H=F;I=0;J=m}else{K=0;L=F;M=G;break}while(1){m=(J<<24>>24)-48+(I*10|0)|0;n=H+1|0;f=a[n]|0;if(((f<<24>>24)-48|0)>>>0<10){H=n;I=m;J=f}else{K=m;L=n;M=G;break}}}else{K=0;L=g;M=0}}while(0);n=o+((M|0)==0?K:-K|0)|0;m=(n|0)<0?-n|0:n;if((m|0)>511){c[(er()|0)>>2]=34;N=1.0;O=5832;P=511;y=6101}else{if((m|0)==0){Q=1.0}else{N=1.0;O=5832;P=m;y=6101}}if((y|0)==6101){while(1){y=0;if((P&1|0)==0){R=N}else{R=N*+h[O>>3]}m=P>>1;if((m|0)==0){Q=R;break}else{N=R;O=O+8|0;P=m;y=6101}}}if((n|0)>-1){p=L;q=E*Q;break}else{p=L;q=E/Q;break}}}while(0);if((d|0)!=0){c[d>>2]=p}if((j|0)==0){S=q;return+S}S=-0.0-q;return+S}function yA(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function yB(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+e|0;if((e|0)>=20){d=d&255;e=b&3;g=d|d<<8|d<<16|d<<24;h=f&~3;if(e){e=b+4-e|0;while((b|0)<(e|0)){a[b]=d;b=b+1|0}}while((b|0)<(h|0)){c[b>>2]=g;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}}function yC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;z=z+1|0;c[a>>2]=z;while((e|0)<40){if((c[d+(e<<2)>>2]|0)==0){c[d+(e<<2)>>2]=z;c[d+((e<<2)+4)>>2]=b;c[d+((e<<2)+8)>>2]=0;return 0}e=e+2|0}c5(116);c5(111);c5(111);c5(32);c5(109);c5(97);c5(110);c5(121);c5(32);c5(115);c5(101);c5(116);c5(106);c5(109);c5(112);c5(115);c5(32);c5(105);c5(110);c5(32);c5(97);c5(32);c5(102);c5(117);c5(110);c5(99);c5(116);c5(105);c5(111);c5(110);c5(32);c5(99);c5(97);c5(108);c5(108);c5(44);c5(32);c5(98);c5(117);c5(105);c5(108);c5(100);c5(32);c5(119);c5(105);c5(116);c5(104);c5(32);c5(97);c5(32);c5(104);c5(105);c5(103);c5(104);c5(101);c5(114);c5(32);c5(118);c5(97);c5(108);c5(117);c5(101);c5(32);c5(102);c5(111);c5(114);c5(32);c5(77);c5(65);c5(88);c5(95);c5(83);c5(69);c5(84);c5(74);c5(77);c5(80);c5(83);c5(10);ah(0);return 0}function yD(a,b){a=a|0;b=b|0;var d=0,e=0;while((d|0)<20){e=c[b+(d<<2)>>2]|0;if((e|0)==0)break;if((e|0)==(a|0)){return c[b+((d<<2)+4)>>2]|0}d=d+2|0}return 0}function yE(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function yF(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function yG(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;while(e>>>0<d>>>0){f=yF(a[b+e|0]|0)|0;g=yF(a[c+e|0]|0)|0;if((f|0)==(g|0)&(f|0)==0)return 0;if((f|0)==0)return-1;if((g|0)==0)return 1;if((f|0)==(g|0)){e=e+1|0;continue}else{return(f>>>0>g>>>0?1:-1)|0}}return 0}function yH(a,b){a=a|0;b=b|0;return yG(a,b,-1)|0}function yI(b,c,d){b=b|0;c=c|0;d=d|0;if((c|0)<(b|0)&(b|0)<(c+d|0)){c=c+d|0;b=b+d|0;while((d|0)>0){b=b-1|0;c=c-1|0;d=d-1|0;a[b]=a[c]|0}}else{yE(b,c,d)|0}}function yJ(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;while((e|0)<(c|0)){f=d[a+e|0]|0;g=d[b+e|0]|0;if((f|0)!=(g|0))return((f|0)>(g|0)?1:-1)|0;e=e+1|0}return 0}function yK(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;while((e|0)<(d|0)){a[b+e|0]=f?0:a[c+e|0]|0;f=f?1:(a[c+e|0]|0)==0;e=e+1|0}return b|0}function yL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(K=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function yM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(K=e,a-c>>>0|0)|0}function yN(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){K=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}K=a<<c-32;return 0}function yO(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){K=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}K=0;return b>>>c-32|0}function yP(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){K=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}K=(b|0)<0?-1:0;return b>>c-32|0}function yQ(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function yR(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function yS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ag(d,c)|0;f=a>>>16;a=(e>>>16)+(ag(d,f)|0)|0;d=b>>>16;b=ag(d,c)|0;return(K=(a>>>16)+(ag(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function yT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=yM(e^a,f^b,e,f)|0;b=K;a=g^e;e=h^f;f=yM((yY(i,b,yM(g^c,h^d,g,h)|0,K,0)|0)^a,K^e,a,e)|0;return(K=K,f)|0}function yU(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=yM(h^a,j^b,h,j)|0;b=K;a=yM(k^d,l^e,k,l)|0;yY(m,b,a,K,g)|0;a=yM(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=K;i=f;return(K=j,a)|0}function yV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=yS(e,a)|0;f=K;return(K=(ag(b,a)|0)+(ag(d,e)|0)+f|f&0,c|0|0)|0}function yW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=yY(a,b,c,d,0)|0;return(K=K,e)|0}function yX(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;yY(a,b,d,e,g)|0;i=f;return(K=c[g+4>>2]|0,c[g>>2]|0)|0}function yY(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(K=n,o)|0}else{if(!m){n=0;o=0;return(K=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(K=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(K=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(K=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((yR(l|0)|0)>>>0);return(K=n,o)|0}p=(yQ(l|0)|0)-(yQ(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(K=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(K=n,o)|0}else{if(!m){r=(yQ(l|0)|0)-(yQ(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(K=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(K=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(yQ(j|0)|0)+33-(yQ(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(K=n,o)|0}else{p=yR(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(K=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;F=0;G=0}else{g=d|0|0;d=k|e&0;e=yL(g,d,-1,-1)|0;k=K;i=w;w=v;v=u;u=t;t=s;s=0;while(1){H=w>>>31|i<<1;I=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;yM(e,k,j,a)|0;b=K;h=b>>31|((b|0)<0?-1:0)<<1;J=h&1;L=yM(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=K;b=t-1|0;if((b|0)==0){break}else{i=H;w=I;v=M;u=L;t=b;s=J}}B=H;C=I;D=M;E=L;F=0;G=J}J=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(J|0)>>>31|(B|C)<<1|(C<<1|J>>>31)&0|F;o=(J<<1|0>>>31)&-2|G;return(K=n,o)|0}function yZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;fd(a|0,b|0,c|0,d|0,e|0)}function y_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;d_(a|0,b|0,c|0,d|0,e|0)}function y$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dK(a|0,b|0,c|0,d|0,e|0)}function y0(a,b){a=a|0;b=+b;bS(a|0,+b)}function y1(a){a=a|0;bD(a|0)}function y2(a){a=a|0;dt(a|0)}function y3(a){a=a|0;ds(a|0)}function y4(a){a=a|0;fN(a|0)}function y5(a){a=a|0;cz(a|0)}function y6(a){a=a|0;c8(a|0)}function y7(a){a=a|0;dS(a|0)}function y8(a){a=a|0;b4(a|0)}function y9(a){a=a|0;dN(a|0)}function za(a){a=a|0;fC(a|0)}function zb(a){a=a|0;cA(a|0)}function zc(a){a=a|0;eG(a|0)}function zd(a){a=a|0;de(a|0)}function ze(a){a=a|0;fM(a|0)}function zf(a){a=a|0;dI(a|0)}function zg(a){a=a|0;da(a|0)}function zh(a){a=a|0;fX(a|0)}function zi(a){a=a|0;e1(a|0)}function zj(a){a=a|0;bK(a|0)}function zk(a){a=a|0;bi(a|0)}function zl(a){a=a|0;bO(a|0)}function zm(a){a=a|0;bA(a|0)}function zn(a){a=a|0;bo(a|0)}function zo(a){a=a|0;by(a|0)}function zp(a){a=a|0;eL(a|0)}function zq(a,b){a=a|0;b=b|0;bX(a|0,b|0)}function zr(a,b){a=a|0;b=b|0;cG(a|0,b|0)}function zs(a,b){a=a|0;b=b|0;dq(a|0,b|0)}function zt(a,b){a=a|0;b=b|0;fP(a|0,b|0)}function zu(a,b){a=a|0;b=b|0;dX(a|0,b|0)}function zv(a,b){a=a|0;b=b|0;cU(a|0,b|0)}function zw(a,b){a=a|0;b=b|0;dc(a|0,b|0)}function zx(a,b){a=a|0;b=b|0;cf(a|0,b|0)}function zy(a,b){a=a|0;b=b|0;fY(a|0,b|0)}function zz(a,b){a=a|0;b=b|0;ce(a|0,b|0)}function zA(a,b){a=a|0;b=b|0;bM(a|0,b|0)}function zB(a,b){a=a|0;b=b|0;et(a|0,b|0)}function zC(a,b){a=a|0;b=b|0;cm(a|0,b|0)}function zD(a,b){a=a|0;b=b|0;em(a|0,b|0)}function zE(a,b){a=a|0;b=b|0;cs(a|0,b|0)}function zF(a,b){a=a|0;b=b|0;a6(a|0,b|0)}function zG(a,b){a=a|0;b=b|0;ei(a|0,b|0)}function zH(a,b){a=a|0;b=b|0;fO(a|0,b|0)}function zI(a,b){a=a|0;b=b|0;fh(a|0,b|0)}function zJ(a,b){a=a|0;b=b|0;fc(a|0,b|0)}function zK(a,b){a=a|0;b=b|0;c2(a|0,b|0)}function zL(a,b){a=a|0;b=b|0;fa(a|0,b|0)}function zM(a,b){a=a|0;b=b|0;fT(a|0,b|0)}function zN(a,b){a=a|0;b=b|0;eD(a|0,b|0)}function zO(a,b){a=a|0;b=b|0;dx(a|0,b|0)}function zP(a,b){a=a|0;b=b|0;br(a|0,b|0)}function zQ(a,b){a=a|0;b=b|0;fl(a|0,b|0)}function zR(a,b){a=a|0;b=b|0;dg(a|0,b|0)}function zS(a,b){a=a|0;b=b|0;b3(a|0,b|0)}function zT(a,b){a=a|0;b=b|0;b_(a|0,b|0)}function zU(a,b){a=a|0;b=b|0;eh(a|0,b|0)}function zV(a,b){a=a|0;b=b|0;dl(a|0,b|0)}function zW(a,b){a=a|0;b=b|0;fV(a|0,b|0)}function zX(a){a=a|0;return ew(a|0)|0}function zY(a){a=a|0;return c5(a|0)|0}function zZ(a){a=a|0;return cK(a|0)|0}function z_(a){a=a|0;return a7(a|0)|0}function z$(a){a=a|0;return dW(a|0)|0}function z0(a){a=a|0;return cn(a|0)|0}function z1(a){a=a|0;return bY(a|0)|0}function z2(a){a=a|0;return cv(a|0)|0}function z3(a){a=a|0;return bH(a|0)|0}function z4(a){a=a|0;return bd(a|0)|0}function z5(a){a=a|0;return d7(a|0)|0}function z6(a){a=a|0;return a_(a|0)|0}function z7(a){a=a|0;return eQ(a|0)|0}function z8(a){a=a|0;return cJ(a|0)|0}function z9(a){a=a|0;return dJ(a|0)|0}function Aa(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;dZ(a|0,+b,+c,+d,+e)}function Ab(a,b,c){a=a|0;b=b|0;c=c|0;return df(a|0,b|0,c|0)|0}function Ac(a,b,c){a=a|0;b=b|0;c=c|0;return a4(a|0,b|0,c|0)|0}function Ad(a,b,c){a=a|0;b=b|0;c=c|0;return b0(a|0,b|0,c|0)|0}function Ae(a,b,c){a=a|0;b=b|0;c=c|0;return eS(a|0,b|0,c|0)|0}function Af(a,b,c){a=a|0;b=b|0;c=c|0;return bb(a|0,b|0,c|0)|0}function Ag(a,b,c){a=a|0;b=b|0;c=c|0;return eO(a|0,b|0,c|0)|0}function Ah(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;el(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function Ai(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;e5(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function Aj(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;fD(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function Ak(a){a=+a;return+bZ(+a)}function Al(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;bQ(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function Am(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;eK(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function An(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;eI(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function Ao(a,b){a=a|0;b=b|0;return fk(a|0,b|0)|0}function Ap(a,b){a=a|0;b=b|0;return dw(a|0,b|0)|0}function Aq(a,b){a=a|0;b=b|0;return dA(a|0,b|0)|0}function Ar(a,b){a=a|0;b=b|0;return d6(a|0,b|0)|0}function As(a,b){a=a|0;b=b|0;return db(a|0,b|0)|0}function At(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;cd(a|0,b|0,c|0,d|0,e|0,f|0)}function Au(){return+bk()}function Av(){return ed()|0}function Aw(){return fi()|0}function Ax(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return be(a|0,b|0,c|0,d|0)|0}function Ay(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return b5(a|0,b|0,c|0,d|0)|0}function Az(a,b,c){a=a|0;b=b|0;c=c|0;ef(a|0,b|0,c|0)}function AA(a,b,c){a=a|0;b=b|0;c=c|0;b6(a|0,b|0,c|0)}function AB(a,b,c){a=a|0;b=b|0;c=c|0;bC(a|0,b|0,c|0)}function AC(a,b,c){a=a|0;b=b|0;c=c|0;dC(a|0,b|0,c|0)}function AD(a,b,c){a=a|0;b=b|0;c=c|0;a0(a|0,b|0,c|0)}function AE(a,b,c){a=a|0;b=b|0;c=c|0;c6(a|0,b|0,c|0)}function AF(a,b,c){a=a|0;b=b|0;c=c|0;ek(a|0,b|0,c|0)}function AG(a,b,c){a=a|0;b=b|0;c=c|0;bF(a|0,b|0,c|0)}function AH(a,b,c){a=a|0;b=b|0;c=c|0;c3(a|0,b|0,c|0)}function AI(a,b,c){a=a|0;b=b|0;c=c|0;a9(a|0,b|0,c|0)}function AJ(a,b,c){a=a|0;b=b|0;c=c|0;eg(a|0,b|0,c|0)}function AK(a,b,c){a=a|0;b=b|0;c=c|0;dh(a|0,b|0,c|0)}function AL(a,b,c){a=a|0;b=b|0;c=c|0;cp(a|0,b|0,c|0)}function AM(a,b,c){a=a|0;b=b|0;c=c|0;bn(a|0,b|0,c|0)}function AN(a,b,c){a=a|0;b=b|0;c=c|0;bB(a|0,b|0,c|0)}function AO(a,b,c){a=a|0;b=b|0;c=c|0;b8(a|0,b|0,c|0)}function AP(a,b,c){a=a|0;b=b|0;c=c|0;bj(a|0,b|0,c|0)}function AQ(a,b,c){a=a|0;b=b|0;c=c|0;cu(a|0,b|0,c|0)}function AR(a,b,c){a=a|0;b=b|0;c=c|0;ee(a|0,b|0,c|0)}function AS(a,b,c){a=a|0;b=b|0;c=c|0;e8(a|0,b|0,c|0)}function AT(a,b,c){a=a|0;b=b|0;c=c|0;fx(a|0,b|0,c|0)}function AU(a,b,c){a=a|0;b=b|0;c=c|0;a2(a|0,b|0,c|0)}function AV(a,b,c){a=a|0;b=b|0;c=c|0;fL(a|0,b|0,c|0)}function AW(a,b,c){a=a|0;b=b|0;c=c|0;fI(a|0,b|0,c|0)}function AX(a,b,c){a=a|0;b=b|0;c=c|0;dV(a|0,b|0,c|0)}function AY(a,b,c){a=a|0;b=b|0;c=c|0;fs(a|0,b|0,c|0)}function AZ(a,b,c){a=a|0;b=b|0;c=c|0;bV(a|0,b|0,c|0)}function A_(a,b,c){a=a|0;b=b|0;c=c|0;cS(a|0,b|0,c|0)}function A$(a,b,c){a=a|0;b=b|0;c=c|0;dU(a|0,b|0,c|0)}function A0(){fb()}function A1(){cT()}function A2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d$(a|0,b|0,c|0,d|0)}function A3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fB(a|0,b|0,c|0,d|0)}function A4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;en(a|0,b|0,c|0,d|0)}function A5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fn(a|0,b|0,c|0,d|0)}function A6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;e0(a|0,b|0,c|0,d|0)}function A7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;aW(a|0,b|0,c|0,d|0)}function A8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d2(a|0,b|0,c|0,d|0)}function A9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cX(a|0,b|0,c|0,d|0)}function Ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ej(a|0,b|0,c|0,d|0)}function Bb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eN(a|0,b|0,c|0,d|0)}function Bc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cI(a|0,b|0,c|0,d|0)}function Bd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;e2(a|0,b|0,c|0,d|0)}function Be(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cC(a|0,b|0,c|0,d|0)}function Bf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d5(a|0,b|0,c|0,d|0)}function Bg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bv(a|0,b|0,c|0,d|0)}function Bh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eT(a|0,b|0,c|0,d|0)}function Bi(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ca(a|0,b|0,c|0,d|0)}function Bj(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eF(a|0,b|0,c|0,d|0)}function Bk(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d4(a|0,b|0,c|0,d|0)}function Bl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cl(a|0,b|0,c|0,d|0)}function Bm(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cY(a|0,b|0,c|0,d|0)}function Bn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eP(a|0,b|0,c|0,d|0)}function Bo(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dk(a|0,b|0,c|0,d|0)}function Bp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eJ(a|0,b|0,c|0,d|0)}function Bq(a,b,c){a=a|0;b=+b;c=+c;dP(a|0,+b,+c)}function Br(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;bt(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function Bs(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;dG(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function Bt(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;cW(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function Bu(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;cQ(a|0,+b,+c,+d)}function Bv(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return f$[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0)|0}function Bw(a,b,c){a=a|0;b=b|0;c=+c;f0[a&7](b|0,+c)}function Bx(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;f1[a&15](b|0,c|0,d|0,e|0,f|0)}function By(a,b){a=a|0;b=b|0;f2[a&1023](b|0)}function Bz(a,b,c){a=a|0;b=b|0;c=c|0;f3[a&1023](b|0,c|0)}function BA(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return f4[a&15](b|0,c|0,d|0,e|0,f|0,g|0)|0}function BB(a,b){a=a|0;b=b|0;return f5[a&255](b|0)|0}function BC(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;f6[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)}function BD(a,b,c,d,e,f){a=a|0;b=b|0;c=+c;d=+d;e=+e;f=+f;f7[a&7](b|0,+c,+d,+e,+f)}function BE(a,b){a=a|0;b=+b;return f8[a&3](+b)|0}function BF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return f9[a&31](b|0,c|0,d|0,e|0,f|0)|0}function BG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ga[a&127](b|0,c|0,d|0)|0}function BH(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;gb[a&15](b|0,c|0,d|0,e|0,f|0,+g)}function BI(a,b,c,d){a=a|0;b=b|0;c=+c;d=+d;gc[a&3](b|0,+c,+d)}function BJ(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=+d;e=+e;gd[a&3](b|0,+c,+d,+e)}function BK(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ge[a&63](b|0,c|0,d|0,e|0,f|0,g|0)}function BL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;return gf[a&3](b|0,c|0,+d)|0}function BM(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;gg[a&31](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function BN(a,b,c){a=a|0;b=b|0;c=+c;return gh[a&3](b|0,+c)|0}function BO(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;gi[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function BP(a,b){a=a|0;b=+b;return+gj[a&3](+b)}function BQ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;gk[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)}function BR(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;gl[a&7](b|0,c|0,d|0,e|0,f|0,g|0,+h)}function BS(a,b,c){a=a|0;b=b|0;c=c|0;return gm[a&127](b|0,c|0)|0}function BT(a,b,c){a=a|0;b=b|0;c=c|0;return+gn[a&7](b|0,c|0)}function BU(a){a=a|0;return+go[a&3]()}function BV(a){a=a|0;return gp[a&31]()|0}function BW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return gq[a&31](b|0,c|0,d|0,e|0)|0}function BX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gr[a&127](b|0,c|0,d|0)}function BY(a){a=a|0;gs[a&63]()}function BZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;return gt[a&31](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)|0}function B_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;gu[a&127](b|0,c|0,d|0,e|0)}function B$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ah(0);return 0}function B0(a,b){a=a|0;b=+b;ah(1)}function B1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ah(2)}function B2(a){a=a|0;ah(3)}function B3(a,b){a=a|0;b=b|0;ah(4)}function B4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ah(5);return 0}function B5(a){a=a|0;ah(6);return 0}function B6(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;ah(7)}function B7(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;ah(8)}function B8(a){a=+a;ah(9);return 0}function B9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ah(10);return 0}function Ca(a,b,c){a=a|0;b=b|0;c=c|0;ah(11);return 0}function Cb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;ah(12)}function Cc(a,b,c){a=a|0;b=+b;c=+c;ah(13)}function Cd(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;ah(14)}function Ce(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ah(15)}function Cf(a,b,c){a=a|0;b=b|0;c=+c;ah(16);return 0}function Cg(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ah(17)}function Ch(a,b){a=a|0;b=+b;ah(18);return 0}function Ci(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ah(19)}function Cj(a){a=+a;ah(20);return 0.0}function Ck(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ah(21)}function Cl(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;ah(22)}function Cm(a,b){a=a|0;b=b|0;ah(23);return 0}function Cn(a,b){a=a|0;b=b|0;ah(24);return 0.0}function Co(){ah(25);return 0.0}function Cp(){ah(26);return 0}function Cq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ah(27);return 0}function Cr(a,b,c){a=a|0;b=b|0;c=c|0;ah(28)}function Cs(){ah(29)}function Ct(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ah(30);return 0}function Cu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ah(31)}
// EMSCRIPTEN_END_FUNCS
var f$=[B$,B$,j2,B$];var f0=[B0,B0,jN,B0,y0,B0,B0,B0];var f1=[B1,B1,yZ,B1,ym,B1,kb,B1,yp,B1,y_,B1,y$,B1,yo,B1];var f2=[B2,B2,y1,B2,ws,B2,kB,B2,tF,B2,wp,B2,y2,B2,po,B2,kD,B2,pK,B2,r3,B2,rT,B2,ur,B2,sg,B2,rN,B2,ii,B2,t8,B2,kI,B2,sl,B2,kk,B2,pH,B2,y3,B2,tr,B2,tA,B2,kW,B2,qg,B2,h1,B2,rK,B2,pC,B2,wT,B2,hO,B2,wW,B2,qe,B2,h5,B2,g2,B2,u1,B2,t7,B2,y4,B2,sk,B2,y5,B2,tj,B2,pj,B2,hB,B2,p4,B2,wn,B2,q2,B2,wU,B2,q7,B2,iB,B2,pi,B2,y6,B2,uF,B2,s8,B2,y7,B2,p_,B2,ps,B2,vK,B2,jf,B2,wB,B2,hN,B2,y8,B2,o1,B2,y9,B2,qv,B2,q5,B2,wY,B2,za,B2,ya,B2,kZ,B2,hA,B2,zb,B2,qK,B2,xE,B2,tq,B2,zc,B2,j_,B2,qa,B2,sj,B2,qp,B2,pr,B2,tt,B2,vc,B2,o2,B2,xH,B2,pk,B2,wV,B2,kz,B2,yt,B2,uV,B2,wi,B2,xD,B2,zd,B2,tb,B2,qH,B2,rl,B2,qI,B2,jb,B2,tE,B2,vS,B2,iu,B2,qJ,B2,sh,B2,ij,B2,pv,B2,oF,B2,wO,B2,o_,B2,xF,B2,pt,B2,rk,B2,qz,B2,q4,B2,re,B2,hM,B2,kU,B2,pl,B2,o9,B2,vk,B2,s7,B2,jX,B2,ze,B2,th,B2,vQ,B2,u4,B2,oZ,B2,tB,B2,vG,B2,yx,B2,uq,B2,hc,B2,qE,B2,o$,B2,rB,B2,kC,B2,qi,B2,x1,B2,x2,B2,wx,B2,tk,B2,s2,B2,zf,B2,p2,B2,xZ,B2,w9,B2,xp,B2,zg,B2,pX,B2,p8,B2,pn,B2,pb,B2,jI,B2,pp,B2,tz,B2,v1,B2,r_,B2,vO,B2,tl,B2,hQ,B2,yv,B2,x4,B2,yb,B2,zh,B2,id,B2,xq,B2,rY,B2,kT,B2,qr,B2,qk,B2,zi,B2,vR,B2,o3,B2,yf,B2,vX,B2,wh,B2,qG,B2,vC,B2,uG,B2,qc,B2,o4,B2,jB,B2,tD,B2,v4,B2,kV,B2,o0,B2,pT,B2,rG,B2,sn,B2,rP,B2,pu,B2,yh,B2,pM,B2,wb,B2,v5,B2,zj,B2,xG,B2,uT,B2,tu,B2,sI,B2,x3,B2,pG,B2,yg,B2,sx,B2,rS,B2,rA,B2,x7,B2,sJ,B2,yi,B2,qP,B2,pY,B2,tg,B2,q1,B2,zk,B2,q6,B2,so,B2,o6,B2,qn,B2,s6,B2,q3,B2,pq,B2,qB,B2,rZ,B2,kE,B2,pI,B2,iq,B2,pm,B2,ti,B2,h4,B2,pJ,B2,pD,B2,zl,B2,kX,B2,i4,B2,ts,B2,q8,B2,td,B2,sN,B2,tf,B2,s9,B2,r4,B2,zm,B2,p6,B2,tC,B2,vo,B2,vg,B2,wz,B2,wa,B2,tc,B2,s1,B2,rJ,B2,te,B2,zn,B2,xC,B2,zo,B2,hP,B2,pR,B2,p0,B2,qD,B2,pV,B2,pw,B2,wo,B2,o5,B2,rO,B2,x9,B2,vT,B2,pF,B2,vW,B2,x5,B2,sp,B2,wX,B2,si,B2,ta,B2,zp,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2];var f3=[B3,B3,lt,B3,l6,B3,nP,B3,le,B3,of,B3,j$,B3,hL,B3,ng,B3,jM,B3,m2,B3,jE,B3,og,B3,mi,B3,xI,B3,or,B3,lB,B3,ie,B3,mm,B3,mA,B3,na,B3,oh,B3,mu,B3,nx,B3,v0,B3,ne,B3,n6,B3,n4,B3,nB,B3,mc,B3,ll,B3,os,B3,l0,B3,mR,B3,qL,B3,nT,B3,li,B3,zq,B3,oE,B3,zr,B3,nW,B3,pg,B3,xL,B3,mZ,B3,mJ,B3,ln,B3,lJ,B3,nj,B3,oB,B3,xK,B3,ly,B3,lA,B3,lL,B3,nU,B3,xJ,B3,oi,B3,kc,B3,l1,B3,vw,B3,ml,B3,nG,B3,ox,B3,zs,B3,zt,B3,oz,B3,lC,B3,l7,B3,mW,B3,mY,B3,zu,B3,lR,B3,mP,B3,mv,B3,no,B3,oa,B3,pe,B3,nJ,B3,ni,B3,k9,B3,vu,B3,lq,B3,n2,B3,lN,B3,lZ,B3,ov,B3,zv,B3,zw,B3,oD,B3,r$,B3,mj,B3,np,B3,lF,B3,wr,B3,oq,B3,lP,B3,lu,B3,zx,B3,nA,B3,ms,B3,sR,B3,vx,B3,zy,B3,j4,B3,iA,B3,jx,B3,rw,B3,lb,B3,mb,B3,nz,B3,vY,B3,nh,B3,o8,B3,nQ,B3,lK,B3,m6,B3,mI,B3,mQ,B3,ot,B3,zz,B3,lQ,B3,lD,B3,lI,B3,m1,B3,vz,B3,vF,B3,n5,B3,lT,B3,ld,B3,zA,B3,zB,B3,pa,B3,mp,B3,l$,B3,zC,B3,zD,B3,vD,B3,v_,B3,zE,B3,jS,B3,on,B3,k7,B3,jR,B3,n8,B3,zF,B3,m4,B3,lM,B3,zG,B3,nC,B3,lE,B3,m3,B3,ph,B3,lm,B3,lH,B3,mL,B3,r9,B3,mn,B3,mf,B3,zH,B3,n7,B3,nu,B3,lx,B3,nw,B3,m0,B3,l3,B3,ok,B3,nO,B3,lY,B3,nq,B3,lU,B3,vZ,B3,nv,B3,nZ,B3,g8,B3,n0,B3,nX,B3,zI,B3,zJ,B3,km,B3,my,B3,mB,B3,nE,B3,zK,B3,nF,B3,ny,B3,zL,B3,oA,B3,mo,B3,zM,B3,lf,B3,lG,B3,n1,B3,k0,B3,nV,B3,m5,B3,ow,B3,lg,B3,zN,B3,vI,B3,zO,B3,nl,B3,mq,B3,pf,B3,zP,B3,jv,B3,vP,B3,lX,B3,zQ,B3,vH,B3,oj,B3,nK,B3,nt,B3,mU,B3,i3,B3,ru,B3,zR,B3,lr,B3,lW,B3,xM,B3,vv,B3,mN,B3,nr,B3,l5,B3,xB,B3,vt,B3,nn,B3,m$,B3,mD,B3,nR,B3,r0,B3,lh,B3,jF,B3,nL,B3,ls,B3,lO,B3,l9,B3,mg,B3,lj,B3,ob,B3,od,B3,zS,B3,lk,B3,lo,B3,md,B3,nd,B3,ns,B3,nM,B3,lc,B3,op,B3,m7,B3,mO,B3,jO,B3,rq,B3,sC,B3,oe,B3,k8,B3,nf,B3,ww,B3,ou,B3,nD,B3,sa,B3,vL,B3,ma,B3,lz,B3,mK,B3,lp,B3,vy,B3,mH,B3,vs,B3,k6,B3,hv,B3,nH,B3,oo,B3,l2,B3,vr,B3,om,B3,mX,B3,mS,B3,nb,B3,n$,B3,m8,B3,l4,B3,vE,B3,l8,B3,mE,B3,pB,B3,n3,B3,nN,B3,ja,B3,vM,B3,lS,B3,n_,B3,mx,B3,nk,B3,py,B3,oc,B3,mV,B3,nc,B3,vN,B3,lv,B3,mh,B3,zT,B3,zU,B3,g6,B3,vJ,B3,me,B3,l_,B3,mt,B3,o7,B3,mr,B3,n9,B3,mk,B3,mF,B3,ol,B3,nm,B3,ju,B3,nI,B3,oC,B3,lw,B3,zV,B3,pE,B3,lV,B3,mM,B3,v$,B3,zW,B3,pd,B3,m9,B3,mG,B3,mz,B3,mC,B3,m_,B3,oy,B3,nY,B3,jd,B3,nS,B3,mw,B3,mT,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3,B3];var f4=[B4,B4,ig,B4,il,B4,ik,B4,im,B4,jt,B4,B4,B4,B4,B4];var f5=[B5,B5,qZ,B5,x$,B5,is,B5,iD,B5,iC,B5,sO,B5,jy,B5,xQ,B5,rF,B5,s$,B5,xY,B5,vh,B5,xe,B5,r5,B5,xk,B5,k3,B5,uU,B5,xO,B5,hZ,B5,s4,B5,ys,B5,sV,B5,x_,B5,xV,B5,jc,B5,xs,B5,rv,B5,x8,B5,io,B5,sd,B5,qU,B5,xA,B5,rH,B5,zX,B5,xx,B5,xT,B5,sT,B5,zY,B5,hS,B5,xy,B5,hs,B5,sE,B5,vV,B5,xU,B5,jw,B5,zZ,B5,iy,B5,rQ,B5,h_,B5,ko,B5,i9,B5,j1,B5,vi,B5,jz,B5,xW,B5,z_,B5,ke,B5,z$,B5,z0,B5,xu,B5,xS,B5,vp,B5,xN,B5,rt,B5,yA,B5,z1,B5,z2,B5,z3,B5,rU,B5,xt,B5,tp,B5,vf,B5,rs,B5,z4,B5,he,B5,z5,B5,rV,B5,z6,B5,xz,B5,sF,B5,rr,B5,r1,B5,hH,B5,xa,B5,q_,B5,k4,B5,vj,B5,wJ,B5,kn,B5,wI,B5,yw,B5,sU,B5,vd,B5,xP,B5,wH,B5,ve,B5,rf,B5,vl,B5,xj,B5,vn,B5,hg,B5,vm,B5,xR,B5,z7,B5,vq,B5,sc,B5,u2,B5,ki,B5,z8,B5,ra,B5,xX,B5,z9,B5,kd,B5,xg,B5,iz,B5,xi,B5,r6,B5,i8,B5,B5,B5,B5,B5,B5,B5,B5,B5,B5,B5,B5,B5,B5,B5,B5,B5,B5,B5];var f6=[B6,B6,kj,B6];var f7=[B7,B7,jK,B7,jL,B7,Aa,B7];var f8=[B8,B8,je,B8];var f9=[B9,B9,xh,B9,xf,B9,xw,B9,wQ,B9,tv,B9,xn,B9,wN,B9,wG,B9,tx,B9,wS,B9,xr,B9,xd,B9,B9,B9,B9,B9,B9,B9];var ga=[Ca,Ca,qV,Ca,wZ,Ca,p7,Ca,qx,Ca,Ab,Ca,j9,Ca,p3,Ca,w4,Ca,i7,Ca,p$,Ca,qd,Ca,k1,Ca,Ac,Ca,pN,Ca,iw,Ca,pS,Ca,ql,Ca,yj,Ca,wq,Ca,qf,Ca,tw,Ca,qo,Ca,w6,Ca,wL,Ca,p1,Ca,ty,Ca,jA,Ca,Ad,Ca,j3,Ca,s0,Ca,s_,Ca,qb,Ca,hV,Ca,sS,Ca,wt,Ca,hl,Ca,ix,Ca,pU,Ca,wM,Ca,p9,Ca,i6,Ca,p5,Ca,Ae,Ca,js,Ca,pW,Ca,qq,Ca,w2,Ca,qs,Ca,s3,Ca,sm,Ca,sf,Ca,Af,Ca,w8,Ca,qw,Ca,qj,Ca,sD,Ca,qh,Ca,Ag,Ca,qy,Ca,s5,Ca,qA,Ca,Ca,Ca,Ca,Ca];var gb=[Cb,Cb,uR,Cb,uP,Cb,jP,Cb,uB,Cb,uE,Cb,Cb,Cb,Cb,Cb];var gc=[Cc,Cc,Bq,Cc];var gd=[Cd,Cd,Bu,Cd];var ge=[Ce,Ce,iN,Ce,iJ,Ce,yn,Ce,iQ,Ce,uN,Ce,uH,Ce,yr,Ce,uS,Ce,wv,Ce,sY,Ce,iI,Ce,iM,Ce,k_,Ce,yq,Ce,At,Ce,iT,Ce,uI,Ce,iP,Ce,ut,Ce,uz,Ce,uu,Ce,q9,Ce,uJ,Ce,iL,Ce,iH,Ce,sG,Ce,iO,Ce,wy,Ce,iK,Ce,Ce,Ce,Ce,Ce];var gf=[Cf,Cf,jY,Cf];var gg=[Cg,Cg,Br,Cg,vU,Cg,vB,Cg,Bs,Cg,v2,Cg,v8,Cg,v7,Cg,wc,Cg,Bt,Cg,Cg,Cg,Cg,Cg,Cg,Cg,Cg,Cg,Cg,Cg,Cg,Cg];var gh=[Ch,Ch,i1,Ch];var gi=[Ci,Ci,u$,Ci,u5,Ci,uW,Ci,u8,Ci,wu,Ci,uO,Ci,uK,Ci,wj,Ci,va,Ci,u_,Ci,u9,Ci,Ah,Ci,Ai,Ci,Aj,Ci,us,Ci,uZ,Ci,t0,Ci,ui,Ci,u6,Ci,uA,Ci,uy,Ci,uj,Ci,uk,Ci,ug,Ci,uh,Ci,t9,Ci,ue,Ci,ub,Ci,up,Ci,uo,Ci,um,Ci,tV,Ci,uX,Ci,tZ,Ci,tR,Ci,tT,Ci,tX,Ci,tN,Ci,t5,Ci,t3,Ci,tK,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci];var gj=[Cj,Cj,Ak,Cj];var gk=[Ck,Ck,iV,Ck,Al,Ck,Am,Ck,vb,Ck,u0,Ck,An,Ck,Ck,Ck];var gl=[Cl,Cl,wk,Cl,we,Cl,Cl,Cl];var gm=[Cm,Cm,ih,Cm,w5,Cm,r7,Cm,hb,Cm,Ao,Cm,Ap,Cm,hX,Cm,wK,Cm,hC,Cm,sW,Cm,qR,Cm,Aq,Cm,wD,Cm,hi,Cm,hj,Cm,jH,Cm,jG,Cm,rW,Cm,r2,Cm,w1,Cm,rd,Cm,hY,Cm,yu,Cm,kh,Cm,k2,Cm,w7,Cm,gS,Cm,rh,Cm,qT,Cm,sX,Cm,w3,Cm,Ar,Cm,h8,Cm,hG,Cm,hJ,Cm,rb,Cm,gO,Cm,sQ,Cm,k5,Cm,As,Cm,sP,Cm,rR,Cm,yH,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm];var gn=[Cn,Cn,rL,Cn,j6,Cn,rC,Cn];var go=[Co,Co,Au,Co];var gp=[Cp,Cp,iY,Cp,Av,Cp,hW,Cp,qQ,Cp,qX,Cp,qY,Cp,ic,Cp,kg,Cp,Aw,Cp,hr,Cp,hK,Cp,kl,Cp,j5,Cp,j7,Cp,hU,Cp];var gq=[Cq,Cq,g9,Cq,rM,Cq,Ax,Cq,w_,Cq,rz,Cq,Ay,Cq,w$,Cq,wR,Cq,rD,Cq,jT,Cq,ro,Cq,wP,Cq,w0,Cq,Cq,Cq,Cq,Cq];var gr=[Cr,Cr,Az,Cr,jZ,Cr,jJ,Cr,AA,Cr,AB,Cr,AC,Cr,AD,Cr,ir,Cr,AE,Cr,AF,Cr,AG,Cr,ri,Cr,AH,Cr,AI,Cr,AJ,Cr,AK,Cr,AL,Cr,AM,Cr,AN,Cr,rj,Cr,yI,Cr,AO,Cr,AP,Cr,AQ,Cr,AR,Cr,AS,Cr,AT,Cr,h0,Cr,AU,Cr,jQ,Cr,hu,Cr,iR,Cr,AV,Cr,AW,Cr,se,Cr,ho,Cr,qN,Cr,AX,Cr,AY,Cr,tH,Cr,hF,Cr,iU,Cr,AZ,Cr,A_,Cr,A$,Cr,i2,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr,Cr];var gs=[Cs,Cs,hR,Cs,hy,Cs,ha,Cs,A0,Cs,h3,Cs,kf,Cs,qO,Cs,h2,Cs,qM,Cs,qW,Cs,g$,Cs,ka,Cs,hT,Cs,h$,Cs,gU,Cs,hx,Cs,qS,Cs,j0,Cs,hz,Cs,qF,Cs,gV,Cs,gX,Cs,jC,Cs,j8,Cs,h6,Cs,A1,Cs,g3,Cs,gN,Cs,q0,Cs,jD,Cs,Cs,Cs];var gt=[Ct,Ct,wE,Ct,xc,Ct,xm,Ct,wF,Ct,xo,Ct,xv,Ct,xb,Ct,xl,Ct,Ct,Ct,Ct,Ct,Ct,Ct,Ct,Ct,Ct,Ct,Ct,Ct,Ct,Ct];var gu=[Cu,Cu,A2,Cu,A3,Cu,rc,Cu,A4,Cu,gR,Cu,A5,Cu,A6,Cu,A7,Cu,A8,Cu,A9,Cu,Ba,Cu,Bb,Cu,Bc,Cu,yk,Cu,Bd,Cu,sH,Cu,Be,Cu,Bf,Cu,Bg,Cu,Bh,Cu,Bi,Cu,yc,Cu,Bj,Cu,sZ,Cu,Bk,Cu,Bl,Cu,k$,Cu,tJ,Cu,Bm,Cu,Bn,Cu,yl,Cu,Bo,Cu,Bp,Cu,tI,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu,Cu];return{__GLOBAL__I_a419:rg,_memcmp:yJ,_strncasecmp:yG,_free:yt,_main:gM,_realloc:yu,_strncpy:yK,_memmove:yI,_tolower:yF,_saveSetjmp:yC,_memset:yB,_malloc:ys,__GLOBAL__I_a72:oP,_memcpy:yE,_strlen:yA,_strcasecmp:yH,__GLOBAL__I_a2219:sb,_testSetjmp:yD,runPostSets:gL,stackAlloc:gv,stackSave:gw,stackRestore:gx,setThrew:gy,setTempRet0:gB,setTempRet1:gC,setTempRet2:gD,setTempRet3:gE,setTempRet4:gF,setTempRet5:gG,setTempRet6:gH,setTempRet7:gI,setTempRet8:gJ,setTempRet9:gK,dynCall_iiiiiiii:Bv,dynCall_vif:Bw,dynCall_viiiii:Bx,dynCall_vi:By,dynCall_vii:Bz,dynCall_iiiiiii:BA,dynCall_ii:BB,dynCall_viiiiiiiiiii:BC,dynCall_viffff:BD,dynCall_if:BE,dynCall_iiiiii:BF,dynCall_iiii:BG,dynCall_viiiiif:BH,dynCall_viff:BI,dynCall_vifff:BJ,dynCall_viiiiii:BK,dynCall_iiif:BL,dynCall_viiiiiiii:BM,dynCall_iif:BN,dynCall_viiiiiii:BO,dynCall_ff:BP,dynCall_viiiiiiiii:BQ,dynCall_viiiiiif:BR,dynCall_iii:BS,dynCall_fii:BT,dynCall_f:BU,dynCall_i:BV,dynCall_iiiii:BW,dynCall_viii:BX,dynCall_v:BY,dynCall_iiiiiiiii:BZ,dynCall_viiii:B_}})
// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_vif": invoke_vif, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_ii": invoke_ii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_viffff": invoke_viffff, "invoke_if": invoke_if, "invoke_iiiiii": invoke_iiiiii, "invoke_iiii": invoke_iiii, "invoke_viiiiif": invoke_viiiiif, "invoke_viff": invoke_viff, "invoke_vifff": invoke_vifff, "invoke_viiiiii": invoke_viiiiii, "invoke_iiif": invoke_iiif, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_iif": invoke_iif, "invoke_viiiiiii": invoke_viiiiiii, "invoke_ff": invoke_ff, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_viiiiiif": invoke_viiiiiif, "invoke_iii": invoke_iii, "invoke_fii": invoke_fii, "invoke_f": invoke_f, "invoke_i": invoke_i, "invoke_iiiii": invoke_iiiii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_iiiiiiiii": invoke_iiiiiiiii, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_RWebInputDestroy": _RWebInputDestroy, "_RWebAudioStop": _RWebAudioStop, "_glClearColor": _glClearColor, "_sysconf": _sysconf, "__scanString": __scanString, "_pthread_mutex_unlock": _pthread_mutex_unlock, "_fclose": _fclose, "_RWebAudioInit": _RWebAudioInit, "_glGetVertexAttribPointerv": _glGetVertexAttribPointerv, "_pthread_mutex_lock": _pthread_mutex_lock, "_glGetRenderbufferParameteriv": _glGetRenderbufferParameteriv, "_eglDestroySurface": _eglDestroySurface, "_strtoul": _strtoul, "_strtoull": _strtoull, "_glBindTexture": _glBindTexture, "_fflush": _fflush, "_isxdigit": _isxdigit, "_glGetUniformiv": _glGetUniformiv, "_fabsf": _fabsf, "_strtol": _strtol, "_fputc": _fputc, "_glGetString": _glGetString, "_fwrite": _fwrite, "_gluUnProject": _gluUnProject, "_send": _send, "_fputs": _fputs, "_glLineWidth": _glLineWidth, "_glUniform2fv": _glUniform2fv, "_emscripten_get_now": _emscripten_get_now, "_asprintf": _asprintf, "_eglCreateContext": _eglCreateContext, "_glBindAttribLocation": _glBindAttribLocation, "_glCompileShader": _glCompileShader, "_isspace": _isspace, "_localtime": _localtime, "_glDeleteTextures": _glDeleteTextures, "_eglBindAPI": _eglBindAPI, "_glCompressedTexImage2D": _glCompressedTexImage2D, "_sbrk": _sbrk, "_glStencilFuncSeparate": _glStencilFuncSeparate, "_read": _read, "_RWebAudioBufferSize": _RWebAudioBufferSize, "_glDeleteShader": _glDeleteShader, "_RWebInputInit": _RWebInputInit, "_glClearDepthf": _glClearDepthf, "_glUniform4iv": _glUniform4iv, "_glGetTexParameteriv": _glGetTexParameteriv, "_glClearStencil": _glClearStencil, "_glLoadIdentity": _glLoadIdentity, "_glUniform1fv": _glUniform1fv, "___cxa_guard_abort": ___cxa_guard_abort, "_glIsShader": _glIsShader, "__Z7catopenPKci": __Z7catopenPKci, "_strstr": _strstr, "_glSampleCoverage": _glSampleCoverage, "_fsync": _fsync, "_glGenTextures": _glGenTextures, "_newlocale": _newlocale, "_glDepthFunc": _glDepthFunc, "_remove": _remove, "_glCompressedTexSubImage2D": _glCompressedTexSubImage2D, "_pthread_cond_wait": _pthread_cond_wait, "_glUniform1f": _glUniform1f, "_opendir": _opendir, "___resumeException": ___resumeException, "_glGetTexParameterfv": _glGetTexParameterfv, "_RWebAudioWrite": _RWebAudioWrite, "_glStencilMaskSeparate": _glStencilMaskSeparate, "_glCreateShader": _glCreateShader, "_round": _round, "_glUniform1i": _glUniform1i, "___cxa_end_catch": ___cxa_end_catch, "_strncmp": _strncmp, "_cosf": _cosf, "_vsscanf": _vsscanf, "_glDeleteRenderbuffers": _glDeleteRenderbuffers, "_glLinkProgram": _glLinkProgram, "_snprintf": _snprintf, "_glUniform2i": _glUniform2i, "_fgetc": _fgetc, "_glStencilFunc": _glStencilFunc, "_strerror_r": _strerror_r, "_glShaderSource": _glShaderSource, "_ceilf": _ceilf, "_readdir": _readdir, "_glVertexAttribPointer": _glVertexAttribPointer, "_glHint": _glHint, "_glBindBuffer": _glBindBuffer, "_llvm_umul_with_overflow_i32": _llvm_umul_with_overflow_i32, "_glVertexPointer": _glVertexPointer, "_fgets": _fgets, "_close": _close, "_getgid": _getgid, "_glGetAttachedShaders": _glGetAttachedShaders, "_glBindFramebuffer": _glBindFramebuffer, "_glIsFramebuffer": _glIsFramebuffer, "_strchr": _strchr, "_glUniform4fv": _glUniform4fv, "_abort": _abort, "___setErrNo": ___setErrNo, "_glDeleteFramebuffers": _glDeleteFramebuffers, "_eglTerminate": _eglTerminate, "_glGetVertexAttribfv": _glGetVertexAttribfv, "_glIsBuffer": _glIsBuffer, "_emscripten_GetProcAddress": _emscripten_GetProcAddress, "_eglGetProcAddress": _eglGetProcAddress, "_ftell": _ftell, "_glDeleteProgram": _glDeleteProgram, "_exit": _exit, "_sprintf": _sprintf, "_glRenderbufferStorage": _glRenderbufferStorage, "___ctype_b_loc": ___ctype_b_loc, "_strrchr": _strrchr, "_freelocale": _freelocale, "_glAttachShader": _glAttachShader, "_RWebInputPoll": _RWebInputPoll, "_glUniform3i": _glUniform3i, "_glIsProgram": _glIsProgram, "_glCheckFramebufferStatus": _glCheckFramebufferStatus, "__isLeapYear": __isLeapYear, "_gluProject": _gluProject, "___cxa_find_matching_catch": ___cxa_find_matching_catch, "_llvm_uadd_with_overflow_i32": _llvm_uadd_with_overflow_i32, "_localtime_r": _localtime_r, "_glUniform3f": _glUniform3f, "___cxa_guard_acquire": ___cxa_guard_acquire, "_glGetBufferParameteriv": _glGetBufferParameteriv, "_glFlush": _glFlush, "_glBlendEquationSeparate": _glBlendEquationSeparate, "_emscripten_get_canvas_size": _emscripten_get_canvas_size, "_glCopyTexImage2D": _glCopyTexImage2D, "_glDrawElements": _glDrawElements, "_glColorMask": _glColorMask, "_sinf": _sinf, "_gluLookAt": _gluLookAt, "_eglInitialize": _eglInitialize, "_recv": _recv, "__parseInt64": __parseInt64, "_glVertexAttrib1fv": _glVertexAttrib1fv, "_glUniform2iv": _glUniform2iv, "__ZSt18uncaught_exceptionv": __ZSt18uncaught_exceptionv, "_putchar": _putchar, "_glUniform1iv": _glUniform1iv, "___cxa_call_unexpected": ___cxa_call_unexpected, "_glActiveTexture": _glActiveTexture, "_glMatrixMode": _glMatrixMode, "_glBlendEquation": _glBlendEquation, "_strcmp": _strcmp, "_glVertexAttrib1f": _glVertexAttrib1f, "_RWebAudioWriteAvail": _RWebAudioWriteAvail, "_glGenerateMipmap": _glGenerateMipmap, "_memchr": _memchr, "_glDetachShader": _glDetachShader, "_glGetShaderiv": _glGetShaderiv, "__exit": __exit, "_strftime": _strftime, "_glVertexAttrib3f": _glVertexAttrib3f, "_glGenRenderbuffers": _glGenRenderbuffers, "_tzset": _tzset, "_RWebAudioSampleRate": _RWebAudioSampleRate, "_glGetShaderPrecisionFormat": _glGetShaderPrecisionFormat, "_glVertexAttrib4fv": _glVertexAttrib4fv, "___cxa_throw": ___cxa_throw, "_glDepthMask": _glDepthMask, "_glDisableVertexAttribArray": _glDisableVertexAttribArray, "_glBegin": _glBegin, "_llvm_eh_exception": _llvm_eh_exception, "_printf": _printf, "_glBindRenderbuffer": _glBindRenderbuffer, "_pread": _pread, "___locale_mb_cur_max": ___locale_mb_cur_max, "_fopen": _fopen, "_open": _open, "_glDrawArrays": _glDrawArrays, "_usleep": _usleep, "_llvm_pow_f32": _llvm_pow_f32, "__arraySum": __arraySum, "_glCopyTexSubImage2D": _glCopyTexSubImage2D, "_sqrtf": _sqrtf, "_glDisable": _glDisable, "_puts": _puts, "_glUniform4i": _glUniform4i, "___assert_func": ___assert_func, "_nanosleep": _nanosleep, "_glClear": _glClear, "_qsort": _qsort, "_glUniform2f": _glUniform2f, "_eglDestroyContext": _eglDestroyContext, "_isalpha": _isalpha, "_glEnableVertexAttribArray": _glEnableVertexAttribArray, "_rmdir": _rmdir, "_glUniform3fv": _glUniform3fv, "_glStencilOp": _glStencilOp, "_strdup": _strdup, "_glDepthRange": _glDepthRange, "___cxa_free_exception": ___cxa_free_exception, "_glUniform4f": _glUniform4f, "_glFramebufferTexture2D": _glFramebufferTexture2D, "_glUniformMatrix2fv": _glUniformMatrix2fv, "_glGenVertexArrays": _glGenVertexArrays, "_eglMakeCurrent": _eglMakeCurrent, "_glUniformMatrix3fv": _glUniformMatrix3fv, "_glutCreateWindow": _glutCreateWindow, "_glBufferData": _glBufferData, "_glBlendColor": _glBlendColor, "_glGetUniformLocation": _glGetUniformLocation, "_glIsEnabled": _glIsEnabled, "__formatString": __formatString, "_pthread_cond_broadcast": _pthread_cond_broadcast, "__Z8catcloseP8_nl_catd": __Z8catcloseP8_nl_catd, "_getenv": _getenv, "___cxa_does_inherit": ___cxa_does_inherit, "_glGetError": _glGetError, "_glGetVertexAttribiv": _glGetVertexAttribiv, "_glTexParameteriv": _glTexParameteriv, "_glGetProgramiv": _glGetProgramiv, "_glVertexAttrib3fv": _glVertexAttrib3fv, "_glGetFloatv": _glGetFloatv, "_glBufferSubData": _glBufferSubData, "_glUniform3iv": _glUniform3iv, "_glReadPixels": _glReadPixels, "_glGenFramebuffers": _glGenFramebuffers, "_glFramebufferRenderbuffer": _glFramebufferRenderbuffer, "_emscripten_procAddressTable": _emscripten_procAddressTable, "_atexit": _atexit, "_ceil": _ceil, "___errno_location": ___errno_location, "_strerror": _strerror, "_glGetIntegerv": _glGetIntegerv, "_RWebAudioFree": _RWebAudioFree, "_llvm_lifetime_start": _llvm_lifetime_start, "_glIsRenderbuffer": _glIsRenderbuffer, "_llvm_bswap_i32": _llvm_bswap_i32, "_vsnprintf": _vsnprintf, "__parseInt": __parseInt, "___cxa_guard_release": ___cxa_guard_release, "_ungetc": _ungetc, "_RWebAudioSetNonblockState": _RWebAudioSetNonblockState, "_glVertexAttrib2fv": _glVertexAttrib2fv, "_uselocale": _uselocale, "_glGetFramebufferAttachmentParameteriv": _glGetFramebufferAttachmentParameteriv, "_glUseProgram": _glUseProgram, "_sscanf": _sscanf, "_glTexImage2D": _glTexImage2D, "_glGetProgramInfoLog": _glGetProgramInfoLog, "_glTexSubImage2D": _glTexSubImage2D, "_glStencilMask": _glStencilMask, "_fread": _fread, "_glStencilOpSeparate": _glStencilOpSeparate, "_strtok_r": _strtok_r, "_glGetShaderInfoLog": _glGetShaderInfoLog, "_glIsTexture": _glIsTexture, "_eglCreateWindowSurface": _eglCreateWindowSurface, "_fprintf": _fprintf, "_glGetShaderSource": _glGetShaderSource, "_gluPerspective": _gluPerspective, "_strtoll": _strtoll, "_isdigit": _isdigit, "_eglChooseConfig": _eglChooseConfig, "___buildEnvironment": ___buildEnvironment, "_feof": _feof, "__addDays": __addDays, "___cxa_rethrow": ___cxa_rethrow, "_glScissor": _glScissor, "_glEnable": _glEnable, "_glBlendFuncSeparate": _glBlendFuncSeparate, "_floor": _floor, "__reallyNegative": __reallyNegative, "_glGetActiveAttrib": _glGetActiveAttrib, "_fseek": _fseek, "_sqrt": _sqrt, "_glTexParameterfv": _glTexParameterfv, "_write": _write, "_glGenBuffers": _glGenBuffers, "_glFinish": _glFinish, "_glGetAttribLocation": _glGetAttribLocation, "_glVertexAttrib4f": _glVertexAttrib4f, "_rewind": _rewind, "___cxa_allocate_exception": ___cxa_allocate_exception, "_sin": _sin, "_glBlendFunc": _glBlendFunc, "_glCreateProgram": _glCreateProgram, "_realpath": _realpath, "_stat": _stat, "_longjmp": _longjmp, "_vasprintf": _vasprintf, "_glViewport": _glViewport, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_time": _time, "___ctype_toupper_loc": ___ctype_toupper_loc, "___cxa_begin_catch": ___cxa_begin_catch, "_glVertexAttrib2f": _glVertexAttrib2f, "_closedir": _closedir, "_isgraph": _isgraph, "_readlink": _readlink, "___ctype_tolower_loc": ___ctype_tolower_loc, "_glGetUniformfv": _glGetUniformfv, "_llvm_va_end": _llvm_va_end, "_unlink": _unlink, "_gluOrtho2D": _gluOrtho2D, "_glUniformMatrix4fv": _glUniformMatrix4fv, "_glClearDepth": _glClearDepth, "_glGetActiveUniform": _glGetActiveUniform, "_glutDestroyWindow": _glutDestroyWindow, "_pwrite": _pwrite, "__isFloat": __isFloat, "_fabs": _fabs, "_glTexParameterf": _glTexParameterf, "__ZSt9terminatev": __ZSt9terminatev, "_RWebAudioStart": _RWebAudioStart, "_glTexParameteri": _glTexParameteri, "_glFrontFace": _glFrontFace, "_glCullFace": _glCullFace, "_glDepthRangef": _glDepthRangef, "_glDeleteBuffers": _glDeleteBuffers, "_eglGetDisplay": _eglGetDisplay, "_emscripten_set_canvas_size": _emscripten_set_canvas_size, "___cxa_is_number_type": ___cxa_is_number_type, "_glGetBooleanv": _glGetBooleanv, "_eglQuerySurface": _eglQuerySurface, "_glPixelStorei": _glPixelStorei, "_readdir_r": _readdir_r, "_glValidateProgram": _glValidateProgram, "_glPolygonOffset": _glPolygonOffset, "__Z7catgetsP8_nl_catdiiPKc": __Z7catgetsP8_nl_catdiiPKc, "___gxx_personality_v0": ___gxx_personality_v0, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "__ZTVN10__cxxabiv117__class_type_infoE": __ZTVN10__cxxabiv117__class_type_infoE, "___fsmu8": ___fsmu8, "_stdout": _stdout, "___dso_handle": ___dso_handle, "_stdin": _stdin, "_stderr": _stderr, "__ZTVN10__cxxabiv120__si_class_type_infoE": __ZTVN10__cxxabiv120__si_class_type_infoE }, buffer);
var __GLOBAL__I_a419 = Module["__GLOBAL__I_a419"] = asm["__GLOBAL__I_a419"];
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var _strncasecmp = Module["_strncasecmp"] = asm["_strncasecmp"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _strncpy = Module["_strncpy"] = asm["_strncpy"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var __GLOBAL__I_a72 = Module["__GLOBAL__I_a72"] = asm["__GLOBAL__I_a72"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _strcasecmp = Module["_strcasecmp"] = asm["_strcasecmp"];
var __GLOBAL__I_a2219 = Module["__GLOBAL__I_a2219"] = asm["__GLOBAL__I_a2219"];
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_vif = Module["dynCall_vif"] = asm["dynCall_vif"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_viffff = Module["dynCall_viffff"] = asm["dynCall_viffff"];
var dynCall_if = Module["dynCall_if"] = asm["dynCall_if"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiiif = Module["dynCall_viiiiif"] = asm["dynCall_viiiiif"];
var dynCall_viff = Module["dynCall_viff"] = asm["dynCall_viff"];
var dynCall_vifff = Module["dynCall_vifff"] = asm["dynCall_vifff"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_iiif = Module["dynCall_iiif"] = asm["dynCall_iiif"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_iif = Module["dynCall_iif"] = asm["dynCall_iif"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_ff = Module["dynCall_ff"] = asm["dynCall_ff"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_viiiiiif = Module["dynCall_viiiiiif"] = asm["dynCall_viiiiiif"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_fii = Module["dynCall_fii"] = asm["dynCall_fii"];
var dynCall_f = Module["dynCall_f"] = asm["dynCall_f"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiiiiiii = Module["dynCall_iiiiiiiii"] = asm["dynCall_iiiiiiiii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };
// TODO: strip out parts of this we do not need
//======= begin closure i64 code =======
// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */
var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };
  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.
    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };
  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.
  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};
  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };
  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };
  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };
  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };
  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.
  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;
  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);
  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);
  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };
  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };
  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (this.isZero()) {
      return '0';
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }
    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };
  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };
  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };
  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };
  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };
  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };
  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };
  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };
  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };
  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };
  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };
  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);
      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };
  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };
  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };
  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };
  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };
  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };
  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };
  //======= begin jsbn =======
  var navigator = { appName: 'Modern Browser' }; // polyfill a little
  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/
  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */
  // Basic JavaScript BN library - subset useful for RSA encryption.
  // Bits per digit
  var dbits;
  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);
  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }
  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }
  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.
  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;
  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }
  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }
  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }
  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }
  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }
  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }
  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }
  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }
  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }
  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }
  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }
  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }
  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }
  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }
  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }
  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }
  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }
  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }
  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }
  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }
  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }
  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }
  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }
  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }
  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }
  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  // jsbn2 stuff
  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }
  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }
  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }
  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }
  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }
  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  //======= end jsbn =======
  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();
//======= end closure i64 code =======
// === Auto-generated postamble setup entry stuff ===
function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;
var initialStackTop;
var preloadStartTime = null;
Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
    Module.printErr('preload time: ' + (Date.now() - preloadStartTime) + ' ms');
  }
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);
  initialStackTop = STACKTOP;
  try {
    var ret = Module['_main'](argc, argv, 0);
    // if we're not running an evented main loop, it's time to exit
    if (!Module['noExitRuntime']) {
      exit(ret);
    }
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      throw e;
    }
  }
}
function run(args) {
  args = args || Module['arguments'];
  if (preloadStartTime === null) preloadStartTime = Date.now();
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }
  preRun();
  if (runDependencies > 0) {
    // a preRun added a dependency, run will be called later
    return;
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    calledRun = true;
    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }
    postRun();
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;
function exit(status) {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;
  // exit the runtime
  exitRuntime();
  // throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;
function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }
  ABORT = true;
  EXITSTATUS = 1;
  throw 'abort() at ' + (new Error().stack);
}
Module['abort'] = Module.abort = abort;
// {{PRE_RUN_ADDITIONS}}
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run();
// {{POST_RUN_ADDITIONS}}
// {{MODULE_ADDITIONS}}
