// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = eval('(function() { try { return Module || {} } catch(e) { return {} } })()');
// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function(filename) { return Module['read'](filename, true) };
  Module['load'] = function(f) {
    globalEval(read(f));
  };
  Module['arguments'] = process['argv'].slice(2);
  module.exports = Module;
}
else if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function() { throw 'no read() available (jsc?)' };
  }
  Module['readBinary'] = function(f) {
    return read(f, 'binary');
  };
  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  this['Module'] = Module;
}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  if (ENVIRONMENT_IS_WEB) {
    Module['print'] = function(x) {
      console.log(x);
    };
    Module['printErr'] = function(x) {
      console.log(x);
    };
    this['Module'] = Module;
  } else if (ENVIRONMENT_IS_WORKER) {
    // We can do very little here...
    var TRY_USE_DUMP = false;
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];
// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (type == 'i64' || type == 'double' || vararg) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    var index = 0;
    type.flatIndexes = type.fields.map(function(field) {
      index++;
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        if (field[1] === '0') {
          // this is [0 x something]. When inside another structure like here, it must be at the end,
          // and it adds no size
          // XXX this happens in java-nbody for example... assert(index === type.fields.length, 'zero-length in the middle!');
          size = 0;
          alignSize = type.alignSize || QUANTUM_SIZE;
        } else {
          size = Types.types[field].flatSize;
          alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
        }
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2 + 2*i;
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;
      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }
      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          Math.floor((codePoint - 0x10000) / 0x400) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+7)>>3)<<3); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+7)>>3)<<3); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = ((((DYNAMICTOP)+7)>>3)<<3); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>(0))))+((+(((high)>>>(0))))*(+(4294967296)))) : ((+(((low)>>>(0))))+((+(((high)|(0))))*(+(4294967296))))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = Module['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value, or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 67108864;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited
var runtimeInitialized = false;
function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}
function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;
function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;
function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;
function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;
function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math['imul']) Math['imul'] = function(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledInit = false, calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
function loadMemoryInitializer(filename) {
  function applyData(data) {
    HEAPU8.set(data, STATIC_BASE);
  }
  // always do this asynchronously, to keep shell and web as similar as possible
  addOnPreRun(function() {
    if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
      applyData(Module['readBinary'](filename));
    } else {
      Browser.asyncLoad(filename, function(data) {
        applyData(data);
      }, function(data) {
        throw 'could not load memory initializer ' + filename;
      });
    }
  });
}
// === Body ===
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 14587240;
/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } });
var _stdout;
var _stderr;
var _stdout = _stdout=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stderr = _stderr=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([68,0,0,0,68,0,0,0,68,0,0,0,68,0,0,0,160,0,0,0,56,0,0,0,116,0,0,0,68,0,0,0,76,0,0,0,78,0,0,0,80,0,0,0,178,0,0,0,82,0,0,0,68,0,0,0,84,0,0,0,92,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,87,65,86,69,102,109,116,32,16,0,0,0,1,0,2,0,68,172,0,0,16,177,2,0,4,0,16,0,100,97,116,97,6,0,0,0,6,0,0,0,204,0,0,0,222,0,0,0,218,0,0,0,18,0,0,0,102,0,0,0,120,232,10,0,208,9,0,0,242,4,0,0,4,0,0,0,100,0,0,0,42,0,0,0,82,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,218,0,242,0,234,0,2,1,218,0,242,0,6,1,10,1,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,128,149,26,0,64,158,26,0,206,218,239,1,136,39,75,80,44,6,41,21,214,48,218,62,153,25,209,37,212,31,4,79,174,33,254,23,226,22,7,5,0,29,207,13,209,123,181,9,148,122,0,0,0,0,0,0,242,39,0,0,166,17,1,0,92,43,0,0,244,48,0,0,156,48,0,0,147,46,0,0,75,39,0,0,183,39,0,0,154,39,0,0,224,53,0,0,117,45,0,0,243,9,0,0,217,9,0,0,16,15,0,0,132,3,0,0,0,0,0,0,46,21,33,4,252,30,25,21,236,24,192,25,230,22,49,23,102,21,238,22,17,26,213,25,29,25,132,19,113,19,25,22,136,14,4,23,68,12,191,12,207,24,67,20,177,12,184,5,60,6,214,6,215,6,199,25,226,17,85,20,14,6,35,7,24,9,66,5,33,6,77,6,31,28,64,19,120,6,245,9,83,7,61,15,58,7,95,9,236,7,188,6,25,19,215,56,160,4,84,8,173,2,95,12,218,46,0,0,24,38,0,0,135,39,0,0,218,37,0,0,95,37,0,0,239,56,0,0,215,36,0,0,27,34,0,0,237,38,0,0,35,38,0,0,244,37,0,0,247,49,0,0,67,2,0,0,239,2,0,0,190,3,0,0,118,2,0,0,90,35,0,0,28,4,0,0,57,3,0,0,233,35,0,0,2,4,0,0,217,56,0,0,106,38,0,0,46,41,0,0,163,6,0,0,0,7,0,0,245,6,0,0,199,14,0,0,236,11,0,0,0,0,0,0,218,46,0,0,14,38,0,0,152,39,0,0,213,37,0,0,81,37,0,0,252,56,0,0,214,36,0,0,17,34,0,0,247,38,0,0,36,38,0,0,232,37,0,0,252,49,0,0,73,2,0,0,242,2,0,0,183,3,0,0,112,2,0,0,87,35,0,0,44,4,0,0,49,3,0,0,231,35,0,0,0,4,0,0,226,56,0,0,80,40,0,0,179,33,0,0,211,14,0,0,231,11,0,0,202,8,0,0,166,89,0,0,222,63,0,0,68,97,0,0,51,54,0,0,238,77,0,0,232,53,0,0,15,60,0,0,248,67,0,0,204,66,0,0,253,12,0,0,169,26,0,0,187,98,0,0,0,0,0,0,0,0,0,0,72,38,207,94,189,82,190,123,137,210,94,71,170,242,207,251,10,214,112,230,103,37,247,194,89,206,255,255,0,0,8,12,16,48,1,60,2,3,5,15,4,51,21,63,1,1,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,0,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,13,0,0,0,15,0,0,0,17,0,0,0,19,0,0,0,23,0,0,0,27,0,0,0,31,0,0,0,35,0,0,0,43,0,0,0,51,0,0,0,59,0,0,0,67,0,0,0,83,0,0,0,99,0,0,0,115,0,0,0,131,0,0,0,163,0,0,0,195,0,0,0,227,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,13,0,0,0,17,0,0,0,25,0,0,0,33,0,0,0,49,0,0,0,65,0,0,0,97,0,0,0,129,0,0,0,193,0,0,0,1,1,0,0,129,1,0,0,1,2,0,0,1,3,0,0,1,4,0,0,1,6,0,0,1,8,0,0,1,12,0,0,1,16,0,0,1,24,0,0,1,32,0,0,1,48,0,0,1,64,0,0,1,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,32,202,10,0,0,0,0,0,72,167,10,0,1,0,0,0,216,198,10,0,2,0,0,0,112,197,10,0,3,0,0,0,32,196,10,0,4,0,0,0,136,194,10,0,5,0,0,0,120,193,10,0,6,0,0,0,200,191,10,0,7,0,0,0,72,190,10,0,8,0,0,0,216,167,10,0,9,0,0,0,192,184,10,0,10,0,0,0,88,255,10,0,11,0,0,0,208,182,10,0,12,0,0,0,184,181,10,0,13,0,0,0,224,180,10,0,14,0,0,0,168,179,10,0,15,0,0,0,208,178,10,0,16,0,0,0,192,177,10,0,17,0,0,0,56,177,10,0,18,0,0,0,96,175,10,0,19,0,0,0,0,173,10,0,20,0,0,0,80,171,10,0,21,0,0,0,128,169,10,0,22,0,0,0,216,168,10,0,23,0,0,0,152,168,10,0,24,0,0,0,80,168,10,0,25,0,0,0,224,167,10,0,26,0,0,0,80,167,10,0,27,0,0,0,240,166,10,0,28,0,0,0,48,166,10,0,29,0,0,0,160,164,10,0,30,0,0,0,224,163,10,0,31,0,0,0,48,163,10,0,32,0,0,0,144,162,10,0,33,0,0,0,32,162,10,0,34,0,0,0,144,161,10,0,35,0,0,0,248,160,10,0,36,0,0,0,32,160,10,0,37,0,0,0,104,159,10,0,38,0,0,0,200,158,10,0,39,0,0,0,40,157,10,0,40,0,0,0,32,156,10,0,41,0,0,0,0,155,10,0,42,0,0,0,40,154,10,0,43,0,0,0,184,153,10,0,44,0,0,0,56,153,10,0,45,0,0,0,224,152,10,0,46,0,0,0,48,152,10,0,47,0,0,0,128,151,10,0,48,0,0,0,240,150,10,0,49,0,0,0,224,148,10,0,50,0,0,0,240,147,10,0,51,0,0,0,168,146,10,0,52,0,0,0,0,146,10,0,53,0,0,0,112,145,10,0,54,0,0,0,224,144,10,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,63,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,153,153,153,153,153,201,63,0,0,0,0,0,0,0,0,102,102,102,102,102,102,230,63,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,0,97,1,0,0,0,0,128,63,0,0,128,63,0,0,128,63,218,172,42,63,0,0,0,0,22,0,0,0,0,0,128,191,76,166,170,62,0,0,128,63,0,0,128,63,76,166,170,62,154,0,0,0,0,0,128,63,0,0,0,0,218,172,42,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,153,153,153,153,153,201,63,0,0,0,0,0,0,0,0,154,153,153,153,153,153,201,63,154,153,153,153,153,153,201,191,154,153,153,153,153,153,201,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,1,0,0,32,1,0,0,64,1,0,0,96,1,0,0,128,1,0,0,160,1,0,0,192,1,0,0,224,3,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,80,0,0,0,88,0,0,0,96,0,0,0,104,0,0,0,112,0,0,0,120,0,0,0,2,0,0,0,228,0,0,0,10,0,0,0,120,10,11,0,6,7,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,255,1,255,2,255,3,78,111,114,109,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,56,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,55,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,6,64,64,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,255,255,99,248,64,64,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,255,255,251,68,64,64,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,38,35,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,36,132,252,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,16,233,50,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,148,128,129,64,111,0,0,0,0,0,0,12,0,240,0,12,0,240,0,12,0,240,0,12,0,240,0,0,0,64,0,4,0,64,0,8,0,64,0,12,0,64,0,0,0,1,0,0,0,0,0,0,0,0,0,114,0,0,0,142,0,0,0,185,78,139,93,96,127,0,0,0,0,0,0,7,0,240,0,7,0,240,0,7,0,240,0,255,255,255,0,1,0,96,0,3,0,96,0,5,0,96,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,114,0,0,0,24,1,0,0,255,0,52,93,96,127,0,0,0,0,0,0,7,0,240,0,7,0,240,0,7,0,240,0,255,255,255,0,1,0,96,0,3,0,96,0,5,0,96,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,114,0,0,0,24,1,0,0,4,4,64,27,96,127,0,0,0,0,0,0,7,0,240,0,7,0,240,0,7,0,240,0,255,255,255,0,1,0,96,0,3,0,96,0,5,0,96,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,114,0,0,0,24,1,0,0,249,71,229,23,96,127,0,0,0,0,0,0,7,0,240,0,7,0,240,0,7,0,240,0,255,255,255,0,1,0,96,0,3,0,96,0,5,0,96,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,114,0,0,0,24,1,0,0,0,0,124,80,96,127,0,0,0,0,0,0,7,0,240,0,7,0,240,0,7,0,240,0,255,255,255,0,1,0,96,0,3,0,96,0,5,0,96,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,114,0,0,0,24,1,0,0,0,0,110,125,96,127,0,0,0,0,0,0,7,0,240,0,7,0,240,0,7,0,240,0,255,255,255,0,1,0,96,0,3,0,96,0,5,0,96,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,114,0,0,0,24,1,0,0,0,0,248,111,96,127,0,0,0,0,0,0,7,0,240,0,7,0,240,0,7,0,240,0,255,255,255,0,1,0,96,0,3,0,96,0,5,0,96,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,114,0,0,0,24,1,0,0,0,0,60,132,112,127,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,24,1,0,0,0,0,240,194,64,64,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,0,0,0,230,0,0,0,255,255,155,29,64,64,0,0,0,0,0,0,253,255,255,0,253,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,4,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,214,0,0,0,0,0,200,142,64,64,0,0,0,0,0,0,253,255,255,0,253,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,4,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,214,0,0,0,32,32,156,237,64,64,0,0,0,0,0,0,253,255,255,0,253,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,4,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,214,0,0,0,185,48,42,28,64,64,0,0,0,0,0,0,253,255,255,0,253,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,4,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,214,0,0,0,1,96,17,2,64,64,0,0,0,0,0,0,253,255,255,0,253,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,4,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,214,0,0,0,255,255,152,93,64,64,0,0,0,0,0,0,253,255,255,0,253,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,4,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,214,0,0,0,50,51,43,135,64,64,0,0,0,0,0,0,253,255,255,0,253,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,4,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,214,0,0,0,151,166,151,166,64,64,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,0,0,0,4,129,23,5,64,64,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,1,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,0,0,0,0,0,94,156,64,64,0,0,171,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,70,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,55,112,64,64,0,0,144,211,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,0,16,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,149,59,64,64,0,0,144,211,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,0,16,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,196,157,64,64,0,0,144,211,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,0,16,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,68,12,129,186,64,64,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,136,0,0,0,0,0,0,0,64,251,237,75,64,64,0,0,0,170,0,240,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,2,0,64,0,0,0,0,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,136,0,0,0,0,0,0,0,255,255,3,9,64,64,0,0,0,0,201,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,4,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,0,0,0,0,0,0,0,0,0,205,22,64,64,0,0,85,15,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,2,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,97,237,64,64,0,0,85,15,170,240,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,2,0,64,0,4,0,64,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,40,26,64,64,0,0,85,15,170,240,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,2,0,64,0,4,0,64,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,67,88,64,64,0,0,85,15,170,240,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,2,0,64,0,4,0,64,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,136,34,64,64,0,0,85,15,201,24,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,2,0,64,0,4,0,64,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,128,0,186,61,64,64,0,0,85,15,201,24,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,2,0,64,0,4,0,64,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,255,255,114,212,64,64,0,0,99,152,201,24,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,2,0,64,0,4,0,64,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,217,248,64,64,0,0,99,152,201,24,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,2,0,64,0,4,0,64,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,255,25,64,64,0,0,99,152,201,24,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,2,0,64,0,4,0,64,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,91,12,64,64,0,0,99,152,201,240,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,64,0,2,0,64,0,4,0,64,0,6,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,160,208,72,79,0,0,0,0,170,240,255,255,255,0,255,255,255,0,0,0,252,0,0,0,252,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,14,157,64,64,0,0,12,0,201,240,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,48,161,0,0,0,0,0,4,0,64,0,6,0,64,0,0,0,0,0,114,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,90,198,90,198,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,48,161,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,150,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,48,161,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,116,4,0,0,0,0,10,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,48,161,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,235,180,0,0,0,0,28,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,48,161,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,2,0,0,0,0,0,1,31,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,48,161,0,2,48,161,0,62,48,161,0,0,0,0,0,0,0,0,0,52,0,0,0,214,0,0,0,0,0,0,0,0,0,0,0,252,214,177,30,0,0,0,0,0,1,31,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,48,161,0,2,48,161,0,62,48,161,0,0,0,0,0,0,0,0,0,52,0,0,0,214,0,0,0,0,0,0,0,0,0,0,0,252,214,25,99,0,0,0,0,20,1,31,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,48,161,0,2,48,161,0,62,48,161,0,0,0,0,0,0,0,0,0,114,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,127,127,173,42,0,0,0,0,40,1,31,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,48,161,0,2,48,161,0,62,48,161,0,0,0,0,0,0,0,0,0,114,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,209,249,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,1,0,0,0,0,0,0,0,0,0,0,255,255,50,54,32,32,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,46,1,0,0,0,0,0,0,1,0,0,0,5,0,0,0,2,0,0,0,1,1,0,0,4,1,0,0,4,2,0,0,4,3,0,0,4,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,3,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,128,149,26,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,9,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,0,250,10,0,232,123,218,0,168,23,11,0,240,123,218,0,112,231,10,0,168,123,218,0,128,202,10,0,120,123,218,0,104,185,10,0,152,123,218,0,128,173,10,0,88,123,218,0,232,164,10,0,208,123,218,0,104,157,10,0,104,123,218,0,64,149,10,0,96,123,218,0,200,140,10,0,24,124,218,0,144,37,11,0,40,124,218,0,208,28,11,0,32,124,218,0,232,20,11,0,224,123,218,0,8,15,11,0,48,124,218,0,40,11,11,0,248,123,218,0,144,5,11,0,216,123,218,0,56,0,11,0,160,123,218,0,72,252,10,0,8,124,218,0,24,248,10,0,0,124,218,0,128,244,10,0,16,124,218,0,152,240,10,0,200,123,218,0,176,235,10,0,112,123,218,0,88,229,10,0,128,123,218,0,240,223,10,0,144,123,218,0,136,219,10,0,192,123,218,0,64,217,10,0,136,123,218,0,16,214,10,0,184,123,218,0,104,211,10,0,176,123,218,0,0,0,0,0,0,0,0,0,248,224,10,0,144,19,11,0,96,228,10,0,32,201,10,0,64,184,10,0,200,171,10,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,6,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,8,5,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,56,4,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,72,3,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,248,2,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,144,2,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,56,2,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,8,2,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,216,1,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,144,1,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,128,0,11,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,240,255,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,168,255,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,8,255,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,128,254,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,88,254,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,16,254,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,216,253,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,168,253,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,96,253,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,120,252,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,232,251,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,80,251,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,192,250,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,144,250,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,0,6,11,0,122,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,8,5,11,0,97,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,56,4,11,0,47,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,72,3,11,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,248,2,11,0,17,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,144,2,11,0,18,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,56,2,11,0,20,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,8,2,11,0,19,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,216,1,11,0,120,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,144,1,11,0,115,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,128,0,11,0,113,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,240,255,10,0,119,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,168,255,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,8,255,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,128,254,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,88,254,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,16,254,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,216,253,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,168,253,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,96,253,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,120,252,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,232,251,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,80,251,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,192,250,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,144,250,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,25,0,0,0,112,250,10,0,32,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,26,0,0,0,56,250,10,0,108,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,27,0,0,0,192,7,11,0,29,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,28,0,0,0,56,8,11,0,27,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,29,0,0,0,152,249,10,0,102,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,30,0,0,0,136,248,10,0,27,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,31,0,0,0,208,247,10,0,32,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,32,0,0,0,120,247,10,0,31,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,33,0,0,0,72,37,11,0,114,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,34,0,0,0,144,246,10,0,111,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,35,0,0,0,96,246,10,0,112,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,36,0,0,0,24,246,10,0,107,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,37,0,0,0,224,245,10,0,104,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,38,0,0,0,168,245,10,0,109,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,39,0,0,0,96,245,10,0,110,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,40,0,0,0,224,244,10,0,121,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,41,0,0,0,48,244,10,0,116,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,42,0,0,0,192,243,10,0,117,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,43,0,0,0,32,243,10,0,33,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,44,0,0,0,224,242,10,0,99,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,45,0,0,0,88,136,10,0,34,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,46,0,0,0,144,242,10,0,105,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,47,0,0,0,120,242,10,0,101,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,48,0,0,0,48,242,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,49,0,0,0,248,241,10,0,14,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,50,0,0,0,248,240,10,0,13,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,51,0,0,0,96,240,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,52,0,0,0,248,239,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,53,0,0,0,88,239,10,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,54,0,0,0,224,30,11,0,36,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,55,0,0,0,224,238,10,0,26,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,128,0,0,0,0,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,60,0,0,0,72,0,0,0,92,0,0,0,70,0,0,0,26,0,0,0,28,0,0,0,84,0,0,0,24,0,0,0,14,0,0,0,22,0,0,0,86,0,0,0,37,0,0,0,20,1,0,0,39,0,0,0,19,1,0,0,38,0,0,0,17,1,0,0,40,0,0,0,18,1,0,0,13,0,0,0,13,0,0,0,9,0,0,0,9,0,0,0,45,0,0,0,21,1,0,0,46,0,0,0,127,0,0,0,16,0,0,0,47,1,0,0,16,0,0,0,48,1,0,0,17,0,0,0,50,1,0,0,35,0,0,0,23,1,0,0,36,0,0,0,22,1,0,0,34,0,0,0,25,1,0,0,33,0,0,0,24,1,0,0,18,0,0,0,52,1,0,0,32,0,0,0,32,0,0,0,27,0,0,0,27,0,0,0,8,0,0,0,8,0,0,0,13,0,0,0,15,1,0,0,107,0,0,0,14,1,0,0,109,0,0,0,13,1,0,0,106,0,0,0,12,1,0,0,111,0,0,0,11,1,0,0,192,0,0,0,96,0,0,0,19,0,0,0,19,0,0,0,96,0,0,0,0,1,0,0,97,0,0,0,1,1,0,0,98,0,0,0,2,1,0,0,99,0,0,0,3,1,0,0,100,0,0,0,4,1,0,0,101,0,0,0,5,1,0,0,102,0,0,0,6,1,0,0,103,0,0,0,7,1,0,0,104,0,0,0,8,1,0,0,105,0,0,0,9,1,0,0,48,0,0,0,48,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,50,0,0,0,51,0,0,0,51,0,0,0,52,0,0,0,52,0,0,0,53,0,0,0,53,0,0,0,54,0,0,0,54,0,0,0,55,0,0,0,55,0,0,0,56,0,0,0,56,0,0,0,57,0,0,0,57,0,0,0].concat([112,0,0,0,26,1,0,0,113,0,0,0,27,1,0,0,114,0,0,0,28,1,0,0,115,0,0,0,29,1,0,0,116,0,0,0,30,1,0,0,117,0,0,0,31,1,0,0,118,0,0,0,32,1,0,0,119,0,0,0,33,1,0,0,120,0,0,0,34,1,0,0,121,0,0,0,35,1,0,0,122,0,0,0,36,1,0,0,123,0,0,0,37,1,0,0,65,0,0,0,97,0,0,0,66,0,0,0,98,0,0,0,67,0,0,0,99,0,0,0,68,0,0,0,100,0,0,0,69,0,0,0,101,0,0,0,70,0,0,0,102,0,0,0,71,0,0,0,103,0,0,0,72,0,0,0,104,0,0,0,73,0,0,0,105,0,0,0,74,0,0,0,106,0,0,0,75,0,0,0,107,0,0,0,76,0,0,0,108,0,0,0,77,0,0,0,109,0,0,0,78,0,0,0,110,0,0,0,79,0,0,0,111,0,0,0,80,0,0,0,112,0,0,0,81,0,0,0,113,0,0,0,82,0,0,0,114,0,0,0,83,0,0,0,115,0,0,0,84,0,0,0,116,0,0,0,85,0,0,0,117,0,0,0,86,0,0,0,118,0,0,0,87,0,0,0,119,0,0,0,88,0,0,0,120,0,0,0,89,0,0,0,121,0,0,0,90,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,72,254,10,0,96,250,10,0,144,16,11,0,24,17,11,0,208,238,10,0,104,232,10,0,152,226,10,0,176,221,10,0,248,217,10,0,128,215,10,0,88,16,11,0,32,16,11,0,160,15,11,0,216,14,11,0,112,14,11,0,40,14,11,0,0,0,0,0,0,0,36,64,0,0,0,0,0,0,89,64,0,0,0,0,0,136,195,64,0,0,0,0,132,215,151,65,0,128,224,55,121,195,65,67,23,110,5,181,181,184,147,70,245,249,63,233,3,79,56,77,50,29,48,249,72,119,130,90,60,191,115,127,221,79,21,117,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,137,80,78,71,13,10,26,10,74,0,51,66,32,74,111,121,112,97,100,0,0,0,0,0,54,0,54,66,32,74,111,121,112,97,100,0,0,0,0,0,75,0,75,101,121,98,111,97,114,100,0,0,0,0,0,0,80,0,80,114,105,110,116,101,114,0,0,0,0,0,0,0,66,0,67,111,110,116,114,111,108,32,66,97,108,108,0,0,70,0,70,108,111,112,112,121,32,68,114,105,118,101,0,0,76,0,65,99,116,105,118,97,116,111,114,0,0,0,0,0,52,0,84,101,97,109,32,80,108,97,121,101,114,0,0,0,48,0,77,83,32,74,111,121,112,97,100,0,0,0,0,0,82,0,82,83,50,51,50,67,32,83,101,114,105,97,108,0,84,0,84,97,98,108,101,116,0,0,0,0,0,0,0,0,86,0,80,97,100,100,108,101,0,0,0,0,0,0,0,0,67,0,67,68,45,82,79,77,0,0,0,0,0,0,0,0,77,0,77,101,103,97,32,77,111,117,115,101,0,0,0,0,71,0,77,101,110,97,99,101,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,3,3,3,3,3,3,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,1,2,4,6,8,10,12,14,16,18,20,20,24,24,30,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,153,153,153,153,153,201,63,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,153,153,153,153,153,201,63,0,0,0,0,0,0,0,0,102,102,102,102,102,102,230,63,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,0,21,0,0,0,0,0,128,63,205,204,204,61,102,102,102,63,102,102,102,63,205,204,204,61,21,0,0,0,0,0,128,191,205,204,204,61,102,102,102,63,102,102,102,63,205,204,204,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,153,153,153,153,153,201,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,153,153,153,153,153,201,191,154,153,153,153,153,153,201,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,0,0,128,192,224,240,248,252,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,192,0,0,0,224,0,0,0,240,0,0,0,248,0,0,0,252,0,0,0,254,0,0,0,255,0,0,128,255,0,0,192,255,0,0,224,255,0,0,240,255,0,0,248,255,0,0,252,255,0,0,254,255,0,0,255,255,0,128,255,255,0,192,255,255,0,224,255,255,0,240,255,255,0,248,255,255,0,252,255,255,0,254,255,255,0,255,255,255,128,255,255,255,192,255,255,255,224,255,255,255,240,255,255,255,248,255,255,255,252,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,128,0,192,0,224,0,240,0,248,0,252,0,254,0,255,128,255,192,255,224,255,240,255,248,255,252,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,50,4,0,0,50,4,0,0,50,4,0,0,50,4,0,0,50,4,0,0,50,4,0,0,50,4,0,0,50,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,98,29,0,0,98,29,0,0,98,29,0,0,98,29,0,0,98,29,0,0,98,29,0,0,98,29,0,0,98,29,0,0,240,22,0,0,240,22,0,0,240,22,0,0,240,22,0,0,240,22,0,0,240,22,0,0,240,22,0,0,82,3,0,0,70,34,0,0,70,34,0,0,70,34,0,0,70,34,0,0,70,34,0,0,70,34,0,0,70,34,0,0,110,14,0,0,224,20,0,0,224,20,0,0,224,20,0,0,224,20,0,0,224,20,0,0,224,20,0,0,224,20,0,0,224,20,0,0,174,0,0,0,174,0,0,0,174,0,0,0,174,0,0,0,174,0,0,0,174,0,0,0,174,0,0,0,174,0,0,0,226,31,0,0,232,17,0,0,128,22,0,0,128,22,0,0,248,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,246,28,0,0,246,28,0,0,246,28,0,0,246,28,0,0,246,28,0,0,246,28,0,0,246,28,0,0,246,28,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,216,10,0,0,216,10,0,0,216,10,0,0,216,10,0,0,216,10,0,0,216,10,0,0,216,10,0,0,216,10,0,0,146,23,0,0,146,23,0,0,146,23,0,0,146,23,0,0,146,23,0,0,146,23,0,0,146,23,0,0,146,23,0,0,86,16,0,0,86,16,0,0,86,16,0,0,86,16,0,0,86,16,0,0,86,16,0,0,86,16,0,0,86,16,0,0,138,20,0,0,138,20,0,0,138,20,0,0,138,20,0,0,138,20,0,0,138,20,0,0,138,20,0,0,138,20,0,0,254,11,0,0,254,11,0,0,254,11,0,0,254,11,0,0,254,11,0,0,254,11,0,0,254,11,0,0,254,11,0,0,40,1,0,0,56,15,0,0,128,22,0,0,128,22,0,0,76,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,254,6,0,0,254,6,0,0,254,6,0,0,254,6,0,0,254,6,0,0,254,6,0,0,254,6,0,0,254,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,132,17,0,0,132,17,0,0,132,17,0,0,132,17,0,0,132,17,0,0,132,17,0,0,132,17,0,0,132,17,0,0,28,10,0,0,28,10,0,0,28,10,0,0,28,10,0,0,28,10,0,0,28,10,0,0,28,10,0,0,28,10,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,226,1,0,0,226,1,0,0,226,1,0,0,226,1,0,0,226,1,0,0,226,1,0,0,226,1,0,0,226,1,0,0,160,26,0,0,160,26,0,0,160,26,0,0,160,26,0,0,160,26,0,0,160,26,0,0,160,26,0,0,160,26,0,0,98,15,0,0,136,33,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,192,13,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,102,11,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,180,23,0,0,74,3,0,0,184,16,0,0,176,20,0,0,20,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,214,21,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,198,14,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,218,6,0,0,48,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,94,16,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,180,18,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,176,2,0,0,236,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,132,13,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,100,15,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,26,10,0,0,250,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,144,11,0,0,144,11,0,0,144,11,0,0,144,11,0,0,144,11,0,0,144,11,0,0,144,11,0,0,144,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,15,0,0,90,15,0,0,90,15,0,0,90,15,0,0,90,15,0,0,90,15,0,0,90,15,0,0,90,15,0,0,64,32,0,0,64,32,0,0,64,32,0,0,64,32,0,0,64,32,0,0,64,32,0,0,64,32,0,0,142,28,0,0,44,5,0,0,44,5,0,0,44,5,0,0,44,5,0,0,44,5,0,0,44,5,0,0,44,5,0,0,198,8,0,0,20,19,0,0,20,19,0,0,20,19,0,0,20,19,0,0,20,19,0,0,20,19,0,0,20,19,0,0,20,19,0,0,126,7,0,0,126,7,0,0,126,7,0,0,126,7,0,0,126,7,0,0,126,7,0,0,126,7,0,0,126,7,0,0,110,16,0,0,60,12,0,0,128,22,0,0,128,22,0,0,186,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,232,1,0,0,232,1,0,0,232,1,0,0,232,1,0,0,232,1,0,0,232,1,0,0,232,1,0,0,232,1,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,11,0,0,164,11,0,0,164,11,0,0,164,11,0,0,164,11,0,0,164,11,0,0,164,11,0,0,164,11,0,0,36,26,0,0,36,26,0,0,36,26,0,0,36,26,0,0,36,26,0,0,36,26,0,0,36,26,0,0,36,26,0,0,16,19,0,0,16,19,0,0,16,19,0,0,16,19,0,0,16,19,0,0,16,19,0,0,16,19,0,0,16,19,0,0,156,2,0,0,156,2,0,0,156,2,0,0,156,2,0,0,156,2,0,0,156,2,0,0,156,2,0,0,156,2,0,0,66,30,0,0,66,30,0,0,66,30,0,0,66,30,0,0,66,30,0,0,66,30,0,0,66,30,0,0,66,30,0,0,44,18,0,0,170,1,0,0,128,22,0,0,128,22,0,0,128,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,92,17,0,0,92,17,0,0,92,17,0,0,92,17,0,0,92,17,0,0,92,17,0,0,92,17,0,0,92,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,140,17,0,0,140,17,0,0,140,17,0,0,140,17,0,0,140,17,0,0,140,17,0,0,140,17,0,0,140,17,0,0,130,15,0,0,130,15,0,0,130,15,0,0,130,15,0,0,130,15,0,0,130,15,0,0,130,15,0,0,130,15,0,0,200,10,0,0,200,10,0,0,200,10,0,0,200,10,0,0,200,10,0,0,200,10,0,0,200,10,0,0,200,10,0,0,64,24,0,0,64,24,0,0,64,24,0,0,64,24,0,0,64,24,0,0,64,24,0,0,64,24,0,0,64,24,0,0,114,13,0,0,114,13,0,0,114,13,0,0,114,13,0,0,114,13,0,0,114,13,0,0,114,13,0,0,114,13,0,0,60,14,0,0,108,1,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,192,13,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,102,11,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,180,23,0,0,74,3,0,0,184,16,0,0,176,20,0,0,20,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,214,21,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,198,14,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,218,6,0,0,48,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,94,16,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,180,18,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,176,2,0,0,236,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,132,13,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,100,15,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,26,10,0,0,250,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,182,26,0,0,182,26,0,0,182,26,0,0,182,26,0,0,182,26,0,0,182,26,0,0,182,26,0,0,182,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,170,30,0,0,170,30,0,0,170,30,0,0,170,30,0,0,170,30,0,0,170,30,0,0,170,30,0,0,170,30,0,0,10,31,0,0,10,31,0,0,10,31,0,0,10,31,0,0,10,31,0,0,10,31,0,0,10,31,0,0,2,1,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,128,1,0,0,100,32,0,0,100,32,0,0,100,32,0,0,100,32,0,0,100,32,0,0,100,32,0,0,100,32,0,0,100,32,0,0,18,2,0,0,18,2,0,0,18,2,0,0,18,2,0,0,18,2,0,0,18,2,0,0,18,2,0,0,18,2,0,0,60,9,0,0,232,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,14,24,0,0,14,24,0,0,14,24,0,0,14,24,0,0,14,24,0,0,14,24,0,0,14,24,0,0,14,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,178,11,0,0,178,11,0,0,178,11,0,0,178,11,0,0,178,11,0,0,178,11,0,0,178,11,0,0,178,11,0,0,50,17,0,0,50,17,0,0,50,17,0,0,50,17,0,0,50,17,0,0,50,17,0,0,50,17,0,0,50,17,0,0,144,12,0,0,144,12,0,0,144,12,0,0,144,12,0,0,144,12,0,0,144,12,0,0,144,12,0,0,144,12,0,0,210,29,0,0,210,29,0,0,210,29,0,0,210,29,0,0,210,29,0,0,210,29,0,0,210,29,0,0,210,29,0,0,124,11,0,0,124,11,0,0,124,11,0,0,124,11,0,0,124,11,0,0,124,11,0,0,124,11,0,0,124,11,0,0,68,21,0,0,150,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,242,16,0,0,242,16,0,0,242,16,0,0,242,16,0,0,242,16,0,0,242,16,0,0,242,16,0,0,242,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,36,23,0,0,36,23,0,0,36,23,0,0,36,23,0,0,36,23,0,0,36,23,0,0,36,23,0,0,36,23,0,0,62,29,0,0,62,29,0,0,62,29,0,0,62,29,0,0,62,29,0,0,62,29,0,0,62,29,0,0,62,29,0,0,204,8,0,0,204,8,0,0,204,8,0,0,204,8,0,0,204,8,0,0,204,8,0,0,204,8,0,0,204,8,0,0,10,13,0,0,10,13,0,0,10,13,0,0,10,13,0,0,10,13,0,0,10,13,0,0,10,13,0,0,10,13,0,0,164,34,0,0,164,34,0,0,164,34,0,0,164,34,0,0,164,34,0,0,164,34,0,0,164,34,0,0,164,34,0,0,36,6,0,0,150,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,192,13,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,102,11,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,180,23,0,0,74,3,0,0,184,16,0,0,176,20,0,0,20,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,214,21,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,198,14,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,218,6,0,0,48,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,94,16,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,180,18,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,176,2,0,0,236,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,132,13,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,100,15,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,26,10,0,0,250,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,12,0,0,214,12,0,0,214,12,0,0,214,12,0,0,214,12,0,0,214,12,0,0,214,12,0,0,214,12,0,0,78,23,0,0,78,23,0,0,78,23,0,0,78,23,0,0,78,23,0,0,78,23,0,0,78,23,0,0,224,21,0,0,32,8,0,0,32,8,0,0,32,8,0,0,32,8,0,0,32,8,0,0,32,8,0,0,32,8,0,0,248,2,0,0,234,6,0,0,234,6,0,0,234,6,0,0,234,6,0,0,234,6,0,0,234,6,0,0,234,6,0,0,234,6,0,0,222,0,0,0,222,0,0,0,222,0,0,0,222,0,0,0,222,0,0,0,222,0,0,0,222,0,0,0,222,0,0,0,170,12,0,0,34,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,204,29,0,0,204,29,0,0,204,29,0,0,204,29,0,0,204,29,0,0,204,29,0,0,204,29,0,0,204,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,156,22,0,0,156,22,0,0,156,22,0,0,156,22,0,0,156,22,0,0,156,22,0,0,156,22,0,0,156,22,0,0,160,32,0,0,160,32,0,0,160,32,0,0,160,32,0,0,160,32,0,0,160,32,0,0,160,32,0,0,160,32,0,0,172,11,0,0,172,11,0,0,172,11,0,0,172,11,0,0,172,11,0,0,172,11,0,0,172,11,0,0,172,11,0,0,254,9,0,0,254,9,0,0,254,9,0,0,254,9,0,0,254,9,0,0,254,9,0,0,254,9,0,0,254,9,0,0,180,11,0,0,180,11,0,0,180,11,0,0,180,11,0,0,180,11,0,0,180,11,0,0,180,11,0,0,180,11,0,0,24,30,0,0,148,12,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,254,19,0,0,254,19,0,0,254,19,0,0,254,19,0,0,254,19,0,0,254,19,0,0,254,19,0,0,254,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,182,16,0,0,182,16,0,0,182,16,0,0,182,16,0,0,182,16,0,0,182,16,0,0,182,16,0,0,182,16,0,0,68,14,0,0,68,14,0,0,68,14,0,0,68,14,0,0,68,14,0,0,68,14,0,0,68,14,0,0,68,14,0,0,166,7,0,0,166,7,0,0,166,7,0,0,166,7,0,0,166,7,0,0,166,7,0,0,166,7,0,0,166,7,0,0,232,26,0,0,232,26,0,0,232,26,0,0,232,26,0,0,232,26,0,0,232,26,0,0,232,26,0,0,232,26,0,0,82,29,0,0,82,29,0,0,82,29,0,0,82,29,0,0,82,29,0,0,82,29,0,0,82,29,0,0,82,29,0,0,88,32,0,0,74,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,192,13,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,102,11,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,180,23,0,0,74,3,0,0,184,16,0,0,176,20,0,0,20,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,214,21,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,198,14,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,218,6,0,0,48,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,94,16,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,180,18,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,176,2,0,0,236,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,132,13,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,100,15,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,26,10,0,0,250,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,166,28,0,0,166,28,0,0,166,28,0,0,166,28,0,0,166,28,0,0,166,28,0,0,166,28,0,0,166,28,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,25,0,0,136,25,0,0,136,25,0,0,136,25,0,0,136,25,0,0,136,25,0,0,136,25,0,0,136,25,0,0,100,1,0,0,100,1,0,0,100,1,0,0,100,1,0,0,100,1,0,0,100,1,0,0,100,1,0,0,4,7,0,0,84,17,0,0,84,17,0,0,84,17,0,0,84,17,0,0,84,17,0,0,84,17,0,0,84,17,0,0,16,4,0,0,184,36,0,0,184,36,0,0,184,36,0,0,184,36,0,0,184,36,0,0,184,36,0,0,184,36,0,0,184,36,0,0,126,30,0,0,126,30,0,0,126,30,0,0,126,30,0,0,126,30,0,0,126,30,0,0,126,30,0,0,126,30,0,0,114,20,0,0,104,32,0,0,168,34,0,0,104,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,118,15,0,0,118,15,0,0,118,15,0,0,118,15,0,0,118,15,0,0,118,15,0,0,118,15,0,0,118,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0])
.concat([196,2,0,0,196,2,0,0,196,2,0,0,196,2,0,0,196,2,0,0,196,2,0,0,196,2,0,0,196,2,0,0,186,34,0,0,186,34,0,0,186,34,0,0,186,34,0,0,186,34,0,0,186,34,0,0,186,34,0,0,134,7,0,0,102,9,0,0,102,9,0,0,102,9,0,0,102,9,0,0,102,9,0,0,102,9,0,0,102,9,0,0,160,12,0,0,212,7,0,0,212,7,0,0,212,7,0,0,212,7,0,0,212,7,0,0,212,7,0,0,212,7,0,0,212,7,0,0,62,6,0,0,62,6,0,0,62,6,0,0,62,6,0,0,62,6,0,0,62,6,0,0,62,6,0,0,62,6,0,0,96,2,0,0,80,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,40,3,0,0,40,3,0,0,40,3,0,0,40,3,0,0,40,3,0,0,40,3,0,0,40,3,0,0,40,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,36,9,0,0,36,9,0,0,36,9,0,0,36,9,0,0,36,9,0,0,36,9,0,0,36,9,0,0,36,9,0,0,118,31,0,0,118,31,0,0,118,31,0,0,118,31,0,0,118,31,0,0,118,31,0,0,118,31,0,0,50,10,0,0,10,3,0,0,10,3,0,0,10,3,0,0,10,3,0,0,10,3,0,0,10,3,0,0,10,3,0,0,114,5,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,186,16,0,0,186,16,0,0,186,16,0,0,186,16,0,0,186,16,0,0,186,16,0,0,186,16,0,0,186,16,0,0,102,12,0,0,158,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,178,0,0,0,178,0,0,0,178,0,0,0,178,0,0,0,178,0,0,0,178,0,0,0,178,0,0,0,178,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,34,10,0,0,34,10,0,0,34,10,0,0,34,10,0,0,34,10,0,0,34,10,0,0,34,10,0,0,34,10,0,0,168,36,0,0,168,36,0,0,168,36,0,0,168,36,0,0,168,36,0,0,168,36,0,0,168,36,0,0,48,26,0,0,80,18,0,0,80,18,0,0,80,18,0,0,80,18,0,0,80,18,0,0,80,18,0,0,80,18,0,0,172,33,0,0,72,18,0,0,72,18,0,0,72,18,0,0,72,18,0,0,72,18,0,0,72,18,0,0,72,18,0,0,72,18,0,0,22,34,0,0,22,34,0,0,22,34,0,0,22,34,0,0,22,34,0,0,22,34,0,0,22,34,0,0,22,34,0,0,128,0,0,0,152,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,192,13,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,102,11,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,180,23,0,0,74,3,0,0,184,16,0,0,176,20,0,0,20,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,214,21,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,198,14,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,218,6,0,0,48,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,94,16,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,180,18,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,176,2,0,0,236,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,132,13,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,100,15,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,26,10,0,0,250,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,7,0,0,44,7,0,0,44,7,0,0,44,7,0,0,44,7,0,0,44,7,0,0,44,7,0,0,44,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,76,6,0,0,76,6,0,0,76,6,0,0,76,6,0,0,76,6,0,0,76,6,0,0,76,6,0,0,76,6,0,0,170,10,0,0,170,10,0,0,170,10,0,0,170,10,0,0,170,10,0,0,170,10,0,0,170,10,0,0,14,15,0,0,38,27,0,0,38,27,0,0,38,27,0,0,38,27,0,0,38,27,0,0,38,27,0,0,38,27,0,0,154,11,0,0,32,18,0,0,32,18,0,0,32,18,0,0,32,18,0,0,32,18,0,0,32,18,0,0,32,18,0,0,32,18,0,0,242,22,0,0,242,22,0,0,242,22,0,0,242,22,0,0,242,22,0,0,242,22,0,0,242,22,0,0,242,22,0,0,238,6,0,0,200,34,0,0,128,22,0,0,128,22,0,0,230,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,226,32,0,0,226,32,0,0,226,32,0,0,226,32,0,0,226,32,0,0,226,32,0,0,226,32,0,0,226,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,6,0,0,206,6,0,0,206,6,0,0,206,6,0,0,206,6,0,0,206,6,0,0,206,6,0,0,206,6,0,0,214,32,0,0,214,32,0,0,214,32,0,0,214,32,0,0,214,32,0,0,214,32,0,0,214,32,0,0,214,32,0,0,188,26,0,0,188,26,0,0,188,26,0,0,188,26,0,0,188,26,0,0,188,26,0,0,188,26,0,0,188,26,0,0,138,26,0,0,138,26,0,0,138,26,0,0,138,26,0,0,138,26,0,0,138,26,0,0,138,26,0,0,138,26,0,0,224,28,0,0,224,28,0,0,224,28,0,0,224,28,0,0,224,28,0,0,224,28,0,0,224,28,0,0,224,28,0,0,158,4,0,0,92,20,0,0,128,22,0,0,128,22,0,0,234,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,226,22,0,0,226,22,0,0,226,22,0,0,226,22,0,0,226,22,0,0,226,22,0,0,226,22,0,0,226,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,54,8,0,0,54,8,0,0,54,8,0,0,54,8,0,0,54,8,0,0,54,8,0,0,54,8,0,0,54,8,0,0,250,29,0,0,250,29,0,0,250,29,0,0,250,29,0,0,250,29,0,0,250,29,0,0,250,29,0,0,250,29,0,0,240,29,0,0,240,29,0,0,240,29,0,0,240,29,0,0,240,29,0,0,240,29,0,0,240,29,0,0,240,29,0,0,188,5,0,0,188,5,0,0,188,5,0,0,188,5,0,0,188,5,0,0,188,5,0,0,188,5,0,0,188,5,0,0,106,32,0,0,228,13,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,192,13,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,102,11,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,180,23,0,0,74,3,0,0,184,16,0,0,176,20,0,0,20,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,214,21,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,198,14,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,218,6,0,0,48,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,94,16,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,180,18,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,176,2,0,0,236,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,132,13,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,100,15,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,26,10,0,0,250,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,130,22,0,0,130,22,0,0,130,22,0,0,130,22,0,0,130,22,0,0,130,22,0,0,130,22,0,0,130,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,2,28,0,0,2,28,0,0,2,28,0,0,2,28,0,0,2,28,0,0,2,28,0,0,2,28,0,0,2,28,0,0,140,29,0,0,140,29,0,0,140,29,0,0,140,29,0,0,140,29,0,0,140,29,0,0,140,29,0,0,212,13,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,166,4,0,0,240,11,0,0,240,11,0,0,240,11,0,0,240,11,0,0,240,11,0,0,240,11,0,0,240,11,0,0,240,11,0,0,84,16,0,0,84,16,0,0,84,16,0,0,84,16,0,0,84,16,0,0,84,16,0,0,84,16,0,0,84,16,0,0,12,0,0,0,160,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,216,18,0,0,216,18,0,0,216,18,0,0,216,18,0,0,216,18,0,0,216,18,0,0,216,18,0,0,216,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,14,0,0,136,14,0,0,136,14,0,0,136,14,0,0,136,14,0,0,136,14,0,0,136,14,0,0,136,14,0,0,130,8,0,0,130,8,0,0,130,8,0,0,130,8,0,0,130,8,0,0,130,8,0,0,130,8,0,0,130,8,0,0,76,11,0,0,76,11,0,0,76,11,0,0,76,11,0,0,76,11,0,0,76,11,0,0,76,11,0,0,76,11,0,0,226,15,0,0,226,15,0,0,226,15,0,0,226,15,0,0,226,15,0,0,226,15,0,0,226,15,0,0,226,15,0,0,162,10,0,0,162,10,0,0,162,10,0,0,162,10,0,0,162,10,0,0,162,10,0,0,162,10,0,0,162,10,0,0,4,6,0,0,68,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,24,19,0,0,24,19,0,0,24,19,0,0,24,19,0,0,24,19,0,0,24,19,0,0,24,19,0,0,24,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,182,18,0,0,182,18,0,0,182,18,0,0,182,18,0,0,182,18,0,0,182,18,0,0,182,18,0,0,182,18,0,0,26,29,0,0,26,29,0,0,26,29,0,0,26,29,0,0,26,29,0,0,26,29,0,0,26,29,0,0,26,29,0,0,184,4,0,0,184,4,0,0,184,4,0,0,184,4,0,0,184,4,0,0,184,4,0,0,184,4,0,0,184,4,0,0,92,0,0,0,92,0,0,0,92,0,0,0,92,0,0,0,92,0,0,0,92,0,0,0,92,0,0,0,92,0,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,214,36,0,0,206,13,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,192,13,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,102,11,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,180,23,0,0,74,3,0,0,184,16,0,0,176,20,0,0,20,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,214,21,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,198,14,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,218,6,0,0,48,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,94,16,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,180,18,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,176,2,0,0,236,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,132,13,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,100,15,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,26,10,0,0,250,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,150,0,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,110,28,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,200,6,0,0,192,13,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,144,19,0,0,102,11,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,18,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,96,7,0,0,180,23,0,0,74,3,0,0,184,16,0,0,176,20,0,0,20,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,170,6,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,18,20,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,248,25,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,38,13,0,0,214,21,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,250,35,0,0,198,14,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,124,7,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,168,8,0,0,218,6,0,0,48,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,134,13,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,50,30,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,66,29,0,0,94,16,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,216,2,0,0,180,18,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,20,17,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,158,22,0,0,176,2,0,0,236,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,214,10,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,166,23,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,76,3,0,0,132,13,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,94,28,0,0,100,15,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,168,25,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,26,10,0,0,250,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,218,26,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,142,33,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,36,5,0,0,168,6,0,0,116,13,0,0,222,29,0,0,16,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,70,32,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,62,30,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,12,14,0,0,202,18,0,0,168,30,0,0,202,14,0,0,196,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,252,3,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,184,6,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,196,4,0,0,146,11,0,0,136,29,0,0,198,1,0,0,54,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,152,21,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,130,16,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,254,10,0,0,228,0,0,0,0,16,0,0,46,32,0,0,174,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,104,3,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,230,26,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,110,10,0,0,52,4,0,0,210,10,0,0,178,21,0,0,42,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,118,36,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,102,0,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,230,34,0,0,58,14,0,0,158,16,0,0,138,29,0,0,60,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,4,0,0,68,4,0,0,68,4,0,0,68,4,0,0,68,4,0,0,68,4,0,0,68,4,0,0,68,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,15,0,0,124,15,0,0,124,15,0,0,124,15,0,0,124,15,0,0,124,15,0,0,124,15,0,0,124,15,0,0,126,17,0,0,126,17,0,0,126,17,0,0,126,17,0,0,126,17,0,0,126,17,0,0,126,17,0,0,248,21,0,0,98,1,0,0,98,1,0,0,98,1,0,0,98,1,0,0,98,1,0,0,98,1,0,0,98,1,0,0,170,11,0,0,212,20,0,0,212,20,0,0,212,20,0,0,212,20,0,0,212,20,0,0,212,20,0,0,212,20,0,0,212,20,0,0,116,5,0,0,116,5,0,0,116,5,0,0,116,5,0,0,116,5,0,0,116,5,0,0,116,5,0,0,116,5,0,0,176,22,0,0,58,20,0,0,148,32,0,0,136,31,0,0,80,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,218,26,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,142,33,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,36,5,0,0,168,6,0,0,116,13,0,0,222,29,0,0,16,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0])
.concat([128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,70,32,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,62,30,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,12,14,0,0,202,18,0,0,168,30,0,0,202,14,0,0,196,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,252,3,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,184,6,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,196,4,0,0,146,11,0,0,136,29,0,0,198,1,0,0,54,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,152,21,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,130,16,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,254,10,0,0,228,0,0,0,0,16,0,0,46,32,0,0,174,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,104,3,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,230,26,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,110,10,0,0,52,4,0,0,210,10,0,0,178,21,0,0,42,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,118,36,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,102,0,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,230,34,0,0,58,14,0,0,158,16,0,0,138,29,0,0,60,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,174,19,0,0,174,19,0,0,174,19,0,0,174,19,0,0,174,19,0,0,174,19,0,0,174,19,0,0,174,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,56,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,232,2,0,0,232,2,0,0,232,2,0,0,232,2,0,0,232,2,0,0,232,2,0,0,232,2,0,0,102,26,0,0,14,19,0,0,14,19,0,0,14,19,0,0,14,19,0,0,14,19,0,0,14,19,0,0,14,19,0,0,128,32,0,0,230,30,0,0,230,30,0,0,230,30,0,0,230,30,0,0,230,30,0,0,230,30,0,0,230,30,0,0,230,30,0,0,196,8,0,0,196,8,0,0,196,8,0,0,196,8,0,0,196,8,0,0,196,8,0,0,196,8,0,0,196,8,0,0,96,1,0,0,88,29,0,0,38,35,0,0,170,9,0,0,188,30,0,0,128,22,0,0,128,22,0,0,128,22,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,218,26,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,142,33,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,36,5,0,0,168,6,0,0,116,13,0,0,222,29,0,0,16,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,70,32,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,62,30,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,12,14,0,0,202,18,0,0,168,30,0,0,202,14,0,0,196,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,252,3,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,184,6,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,196,4,0,0,146,11,0,0,136,29,0,0,198,1,0,0,54,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,152,21,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,130,16,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,254,10,0,0,228,0,0,0,0,16,0,0,46,32,0,0,174,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,104,3,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,230,26,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,110,10,0,0,52,4,0,0,210,10,0,0,178,21,0,0,42,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,118,36,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,102,0,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,230,34,0,0,58,14,0,0,158,16,0,0,138,29,0,0,60,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,218,26,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,142,33,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,36,5,0,0,168,6,0,0,116,13,0,0,222,29,0,0,16,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,70,32,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,62,30,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,12,14,0,0,202,18,0,0,168,30,0,0,202,14,0,0,196,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,252,3,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,184,6,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,196,4,0,0,146,11,0,0,136,29,0,0,198,1,0,0,54,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,152,21,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,130,16,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,254,10,0,0,228,0,0,0,0,16,0,0,46,32,0,0,174,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,104,3,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,230,26,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,110,10,0,0,52,4,0,0,210,10,0,0,178,21,0,0,42,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,118,36,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,102,0,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,230,34,0,0,58,14,0,0,158,16,0,0,138,29,0,0,60,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,218,26,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,142,33,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,36,5,0,0,168,6,0,0,116,13,0,0,222,29,0,0,16,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,70,32,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,62,30,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,12,14,0,0,202,18,0,0,168,30,0,0,202,14,0,0,196,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,252,3,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,184,6,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,196,4,0,0,146,11,0,0,136,29,0,0,198,1,0,0,54,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,152,21,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,130,16,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,254,10,0,0,228,0,0,0,0,16,0,0,46,32,0,0,174,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,104,3,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,230,26,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,110,10,0,0,52,4,0,0,210,10,0,0,178,21,0,0,42,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,118,36,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,102,0,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,230,34,0,0,58,14,0,0,158,16,0,0,138,29,0,0,60,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,218,26,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,142,33,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,36,5,0,0,168,6,0,0,116,13,0,0,222,29,0,0,16,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,70,32,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,62,30,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,12,14,0,0,202,18,0,0,168,30,0,0,202,14,0,0,196,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,252,3,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,184,6,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,196,4,0,0,146,11,0,0,136,29,0,0,198,1,0,0,54,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,152,21,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,130,16,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,254,10,0,0,228,0,0,0,0,16,0,0,46,32,0,0,174,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,104,3,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,230,26,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,110,10,0,0,52,4,0,0,210,10,0,0,178,21,0,0,42,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,118,36,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,102,0,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,230,34,0,0,58,14,0,0,158,16,0,0,138,29,0,0,60,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,218,26,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,142,33,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,36,5,0,0,168,6,0,0,116,13,0,0,222,29,0,0,16,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0])
.concat([128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,70,32,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,62,30,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,12,14,0,0,202,18,0,0,168,30,0,0,202,14,0,0,196,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,28,12,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,218,5,0,0,252,3,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,46,21,0,0,184,6,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,54,9,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,102,7,0,0,196,4,0,0,146,11,0,0,136,29,0,0,198,1,0,0,54,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,190,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,100,13,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,164,5,0,0,152,21,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,234,35,0,0,130,16,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,62,8,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,118,9,0,0,254,10,0,0,228,0,0,0,0,16,0,0,46,32,0,0,174,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,104,3,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,230,26,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,110,10,0,0,52,4,0,0,210,10,0,0,178,21,0,0,42,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,118,36,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,102,0,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,230,34,0,0,58,14,0,0,158,16,0,0,138,29,0,0,60,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,144,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,158,15,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,26,25,0,0,218,26,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,142,33,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,126,13,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,232,18,0,0,36,5,0,0,168,6,0,0,116,13,0,0,222,29,0,0,16,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,160,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,6,21,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,236,4,0,0,70,32,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,216,9,0,0,62,30,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,200,4,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,66,0,0,0,12,14,0,0,202,18,0,0,168,30,0,0,202,14,0,0,196,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,116,24,0,0,116,24,0,0,116,24,0,0,116,24,0,0,116,24,0,0,116,24,0,0,116,24,0,0,116,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,218,31,0,0,218,31,0,0,218,31,0,0,218,31,0,0,218,31,0,0,218,31,0,0,218,31,0,0,218,31,0,0,128,9,0,0,128,9,0,0,128,9,0,0,128,9,0,0,128,9,0,0,128,9,0,0,128,9,0,0,12,32,0,0,106,16,0,0,106,16,0,0,106,16,0,0,106,16,0,0,106,16,0,0,106,16,0,0,106,16,0,0,16,5,0,0,26,19,0,0,26,19,0,0,26,19,0,0,26,19,0,0,26,19,0,0,26,19,0,0,26,19,0,0,26,19,0,0,110,5,0,0,110,5,0,0,110,5,0,0,110,5,0,0,110,5,0,0,110,5,0,0,110,5,0,0,110,5,0,0,48,6,0,0,40,20,0,0,166,20,0,0,86,8,0,0,214,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,16,3,0,0,16,3,0,0,16,3,0,0,16,3,0,0,16,3,0,0,16,3,0,0,16,3,0,0,16,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,9,0,0,220,9,0,0,220,9,0,0,220,9,0,0,220,9,0,0,220,9,0,0,220,9,0,0,220,9,0,0,148,34,0,0,148,34,0,0,148,34,0,0,148,34,0,0,148,34,0,0,148,34,0,0,148,34,0,0,32,23,0,0,144,22,0,0,144,22,0,0,144,22,0,0,144,22,0,0,144,22,0,0,144,22,0,0,144,22,0,0,16,20,0,0,70,27,0,0,70,27,0,0,70,27,0,0,70,27,0,0,70,27,0,0,70,27,0,0,70,27,0,0,70,27,0,0,106,15,0,0,106,15,0,0,106,15,0,0,106,15,0,0,106,15,0,0,106,15,0,0,106,15,0,0,106,15,0,0,252,29,0,0,84,5,0,0,26,35,0,0,172,20,0,0,22,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,62,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,124,1,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,196,29,0,0,104,3,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,246,5,0,0,230,26,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,58,18,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,26,22,0,0,110,10,0,0,52,4,0,0,210,10,0,0,178,21,0,0,42,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,110,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,186,15,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,118,36,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,36,16,0,0,102,0,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,226,19,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,34,12,0,0,230,34,0,0,58,14,0,0,158,16,0,0,138,29,0,0,60,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,136,16,0,0,248,14,0,0,216,16,0,0,2,5,0,0,98,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,4,20,0,0,226,0,0,0,146,21,0,0,32,25,0,0,190,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,66,24,0,0,156,9,0,0,38,28,0,0,68,15,0,0,252,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,50,0,0,0,64,22,0,0,126,18,0,0,140,19,0,0,166,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,162,28,0,0,212,33,0,0,164,17,0,0,112,22,0,0,90,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,22,6,0,0,212,12,0,0,90,29,0,0,48,3,0,0,244,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,108,8,0,0,16,8,0,0,70,29,0,0,10,0,0,0,220,13,0,0,128,22,0,0,128,22,0,0,128,22,0,0,142,7,0,0,142,7,0,0,142,7,0,0,142,7,0,0,142,7,0,0,142,7,0,0,142,7,0,0,142,7,0,0,150,33,0,0,150,33,0,0,150,33,0,0,150,33,0,0,150,33,0,0,150,33,0,0,150,33,0,0,150,33,0,0,74,17,0,0,74,17,0,0,74,17,0,0,74,17,0,0,74,17,0,0,74,17,0,0,74,17,0,0,74,17,0,0,14,27,0,0,14,27,0,0,14,27,0,0,14,27,0,0,14,27,0,0,14,27,0,0,14,27,0,0,14,27,0,0,158,10,0,0,158,10,0,0,158,10,0,0,158,10,0,0,158,10,0,0,158,10,0,0,158,10,0,0,158,10,0,0,40,35,0,0,40,35,0,0,40,35,0,0,40,35,0,0,40,35,0,0,40,35,0,0,40,35,0,0,40,35,0,0,4,11,0,0,4,11,0,0,4,11,0,0,4,11,0,0,4,11,0,0,4,11,0,0,4,11,0,0,4,11,0,0,8,22,0,0,190,13,0,0,234,20,0,0,46,15,0,0,242,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,136,16,0,0,248,14,0,0,216,16,0,0,2,5,0,0,98,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,4,20,0,0,226,0,0,0,146,21,0,0,32,25,0,0,190,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,66,24,0,0,156,9,0,0,38,28,0,0,68,15,0,0,252,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,50,0,0,0,64,22,0,0,126,18,0,0,140,19,0,0,166,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,162,28,0,0,212,33,0,0,164,17,0,0,112,22,0,0,90,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,22,6,0,0,212,12,0,0,90,29,0,0,48,3,0,0,244,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,108,8,0,0,16,8,0,0,70,29,0,0,10,0,0,0,220,13,0,0,128,22,0,0,128,22,0,0,128,22,0,0,116,29,0,0,116,29,0,0,116,29,0,0,116,29,0,0,116,29,0,0,116,29,0,0,116,29,0,0,116,29,0,0,242,29,0,0,242,29,0,0,242,29,0,0,242,29,0,0,242,29,0,0,242,29,0,0,242,29,0,0,242,29,0,0,54,21,0,0,54,21,0,0,54,21,0,0,54,21,0,0,54,21,0,0,54,21,0,0,54,21,0,0,54,21,0,0,46,0,0,0,46,0,0,0,46,0,0,0,46,0,0,0,46,0,0,0,46,0,0,0,46,0,0,0,46,0,0,0,132,22,0,0,132,22,0,0,132,22,0,0,132,22,0,0,132,22,0,0,132,22,0,0,132,22,0,0,132,22,0,0,126,34,0,0,126,34,0,0,126,34,0,0,126,34,0,0,126,34,0,0,126,34,0,0,126,34,0,0,126,34,0,0,106,18,0,0,106,18,0,0,106,18,0,0,106,18,0,0,106,18,0,0,106,18,0,0,106,18,0,0,106,18,0,0,108,9,0,0,132,1,0,0,146,30,0,0,178,5,0,0,174,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,136,16,0,0,248,14,0,0,216,16,0,0,2,5,0,0,98,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,4,20,0,0,226,0,0,0,146,21,0,0,32,25,0,0,190,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,66,24,0,0,156,9,0,0,38,28,0,0,68,15,0,0,252,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,50,0,0,0,64,22,0,0,126,18,0,0,140,19,0,0,166,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,162,28,0,0,212,33,0,0,164,17,0,0,112,22,0,0,90,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,22,6,0,0,212,12,0,0,90,29,0,0,48,3,0,0,244,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,108,8,0,0,16,8,0,0,70,29,0,0,10,0,0,0,220,13,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,136,16,0,0,248,14,0,0,216,16,0,0,2,5,0,0,98,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0])
.concat([244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,4,20,0,0,226,0,0,0,146,21,0,0,32,25,0,0,190,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,66,24,0,0,156,9,0,0,38,28,0,0,68,15,0,0,252,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,50,0,0,0,64,22,0,0,126,18,0,0,140,19,0,0,166,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,162,28,0,0,212,33,0,0,164,17,0,0,112,22,0,0,90,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,22,6,0,0,212,12,0,0,90,29,0,0,48,3,0,0,244,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,108,8,0,0,16,8,0,0,70,29,0,0,10,0,0,0,220,13,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,136,16,0,0,248,14,0,0,216,16,0,0,2,5,0,0,98,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,4,20,0,0,226,0,0,0,146,21,0,0,32,25,0,0,190,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,66,24,0,0,156,9,0,0,38,28,0,0,68,15,0,0,252,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,50,0,0,0,64,22,0,0,126,18,0,0,140,19,0,0,166,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,162,28,0,0,212,33,0,0,164,17,0,0,112,22,0,0,90,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,22,6,0,0,212,12,0,0,90,29,0,0,48,3,0,0,244,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,108,8,0,0,16,8,0,0,70,29,0,0,10,0,0,0,220,13,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,136,16,0,0,248,14,0,0,216,16,0,0,2,5,0,0,98,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,4,20,0,0,226,0,0,0,146,21,0,0,32,25,0,0,190,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,66,24,0,0,156,9,0,0,38,28,0,0,68,15,0,0,252,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,50,0,0,0,64,22,0,0,126,18,0,0,140,19,0,0,166,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,162,28,0,0,212,33,0,0,164,17,0,0,112,22,0,0,90,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,22,6,0,0,212,12,0,0,90,29,0,0,48,3,0,0,244,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,108,8,0,0,16,8,0,0,70,29,0,0,10,0,0,0,220,13,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,136,16,0,0,248,14,0,0,216,16,0,0,2,5,0,0,98,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,4,20,0,0,226,0,0,0,146,21,0,0,32,25,0,0,190,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,66,24,0,0,156,9,0,0,38,28,0,0,68,15,0,0,252,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,50,0,0,0,64,22,0,0,126,18,0,0,140,19,0,0,166,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,162,28,0,0,212,33,0,0,164,17,0,0,112,22,0,0,90,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,22,6,0,0,212,12,0,0,90,29,0,0,48,3,0,0,244,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,108,8,0,0,16,8,0,0,70,29,0,0,10,0,0,0,220,13,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,80,13,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,192,16,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,164,23,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,8,12,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,66,20,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,12,11,0,0,136,16,0,0,248,14,0,0,216,16,0,0,2,5,0,0,98,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,244,2,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,32,15,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,244,23,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,16,18,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,112,20,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,144,10,0,0,4,20,0,0,226,0,0,0,146,21,0,0,32,25,0,0,190,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,60,23,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,196,26,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,128,11,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,46,8,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,172,25,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,16,22,0,0,66,24,0,0,156,9,0,0,38,28,0,0,68,15,0,0,252,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,32,34,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,82,23,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,176,15,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,92,6,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,28,2,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,216,35,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,50,0,0,0,64,22,0,0,126,18,0,0,140,19,0,0,166,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,100,22,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,62,24,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,108,26,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,126,25,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,208,7,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,36,29,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,114,8,0,0,162,28,0,0,212,33,0,0,164,17,0,0,112,22,0,0,90,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,162,32,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,66,10,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,30,7,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,64,19,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,252,31,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,104,16,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,98,34,0,0,22,6,0,0,212,12,0,0,90,29,0,0,48,3,0,0,244,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,28,16,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,160,14,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,200,16,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,118,16,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,150,35,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,252,11,0,0,108,8,0,0,16,8,0,0,70,29,0,0,10,0,0,0,220,13,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,120,29,0,0,238,14,0,0,248,24,0,0,226,26,0,0,186,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0])
.concat([132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,14,23,0,0,162,15,0,0,130,11,0,0,146,31,0,0,176,30,0,0,128,22,0,0,128,22,0,0,128,22,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,250,6,0,0,130,27,0,0,56,30,0,0,164,7,0,0,212,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,68,3,0,0,142,20,0,0,178,7,0,0,36,4,0,0,214,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,90,4,0,0,24,9,0,0,50,9,0,0,122,31,0,0,192,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,144,32,0,0,152,29,0,0,30,30,0,0,188,8,0,0,218,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,6,19,0,0,244,16,0,0,88,16,0,0,180,6,0,0,84,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,2,17,0,0,2,17,0,0,2,17,0,0,2,17,0,0,2,17,0,0,2,17,0,0,2,17,0,0,2,17,0,0,132,23,0,0,132,23,0,0,132,23,0,0,132,23,0,0,132,23,0,0,132,23,0,0,132,23,0,0,132,23,0,0,46,24,0,0,46,24,0,0,46,24,0,0,46,24,0,0,46,24,0,0,46,24,0,0,46,24,0,0,46,24,0,0,132,5,0,0,132,5,0,0,132,5,0,0,132,5,0,0,132,5,0,0,132,5,0,0,132,5,0,0,132,5,0,0,32,35,0,0,32,35,0,0,32,35,0,0,32,35,0,0,32,35,0,0,32,35,0,0,32,35,0,0,32,35,0,0,22,36,0,0,22,36,0,0,22,36,0,0,22,36,0,0,22,36,0,0,22,36,0,0,22,36,0,0,22,36,0,0,220,15,0,0,120,11,0,0,210,9,0,0,192,3,0,0,200,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,120,29,0,0,238,14,0,0,248,24,0,0,226,26,0,0,186,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,14,23,0,0,162,15,0,0,130,11,0,0,146,31,0,0,176,30,0,0,128,22,0,0,128,22,0,0,128,22,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,250,6,0,0,130,27,0,0,56,30,0,0,164,7,0,0,212,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,68,3,0,0,142,20,0,0,178,7,0,0,36,4,0,0,214,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,90,4,0,0,24,9,0,0,50,9,0,0,122,31,0,0,192,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,144,32,0,0,152,29,0,0,30,30,0,0,188,8,0,0,218,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,6,19,0,0,244,16,0,0,88,16,0,0,180,6,0,0,84,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,78,21,0,0,78,21,0,0,78,21,0,0,78,21,0,0,78,21,0,0,78,21,0,0,78,21,0,0,78,21,0,0,186,9,0,0,186,9,0,0,186,9,0,0,186,9,0,0,186,9,0,0,186,9,0,0,186,9,0,0,186,9,0,0,52,30,0,0,52,30,0,0,52,30,0,0,52,30,0,0,52,30,0,0,52,30,0,0,52,30,0,0,52,30,0,0,8,8,0,0,8,8,0,0,8,8,0,0,8,8,0,0,8,8,0,0,8,8,0,0,8,8,0,0,8,8,0,0,176,26,0,0,176,26,0,0,176,26,0,0,176,26,0,0,176,26,0,0,176,26,0,0,176,26,0,0,176,26,0,0,176,8,0,0,176,8,0,0,176,8,0,0,176,8,0,0,176,8,0,0,176,8,0,0,176,8,0,0,176,8,0,0,44,24,0,0,44,24,0,0,44,24,0,0,44,24,0,0,44,24,0,0,44,24,0,0,44,24,0,0,44,24,0,0,122,6,0,0,176,19,0,0,106,28,0,0,226,2,0,0,72,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,120,29,0,0,238,14,0,0,248,24,0,0,226,26,0,0,186,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,14,23,0,0,162,15,0,0,130,11,0,0,146,31,0,0,176,30,0,0,128,22,0,0,128,22,0,0,128,22,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,250,6,0,0,130,27,0,0,56,30,0,0,164,7,0,0,212,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,68,3,0,0,142,20,0,0,178,7,0,0,36,4,0,0,214,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,90,4,0,0,24,9,0,0,50,9,0,0,122,31,0,0,192,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,144,32,0,0,152,29,0,0,30,30,0,0,188,8,0,0,218,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,6,19,0,0,244,16,0,0,88,16,0,0,180,6,0,0,84,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,120,29,0,0,238,14,0,0,248,24,0,0,226,26,0,0,186,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,14,23,0,0,162,15,0,0,130,11,0,0,146,31,0,0,176,30,0,0,128,22,0,0,128,22,0,0,128,22,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,250,6,0,0,130,27,0,0,56,30,0,0,164,7,0,0,212,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,68,3,0,0,142,20,0,0,178,7,0,0,36,4,0,0,214,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,90,4,0,0,24,9,0,0,50,9,0,0,122,31,0,0,192,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,144,32,0,0,152,29,0,0,30,30,0,0,188,8,0,0,218,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,6,19,0,0,244,16,0,0,88,16,0,0,180,6,0,0,84,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,120,29,0,0,238,14,0,0,248,24,0,0,226,26,0,0,186,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,14,23,0,0,162,15,0,0,130,11,0,0,146,31,0,0,176,30,0,0,128,22,0,0,128,22,0,0,128,22,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,250,6,0,0,130,27,0,0,56,30,0,0,164,7,0,0,212,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,68,3,0,0,142,20,0,0,178,7,0,0,36,4,0,0,214,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,90,4,0,0,24,9,0,0,50,9,0,0,122,31,0,0,192,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,144,32,0,0,152,29,0,0,30,30,0,0,188,8,0,0,218,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,6,19,0,0,244,16,0,0,88,16,0,0,180,6,0,0,84,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,120,29,0,0,238,14,0,0,248,24,0,0,226,26,0,0,186,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0])
.concat([132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,14,23,0,0,162,15,0,0,130,11,0,0,146,31,0,0,176,30,0,0,128,22,0,0,128,22,0,0,128,22,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,250,6,0,0,130,27,0,0,56,30,0,0,164,7,0,0,212,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,68,3,0,0,142,20,0,0,178,7,0,0,36,4,0,0,214,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,90,4,0,0,24,9,0,0,50,9,0,0,122,31,0,0,192,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,144,32,0,0,152,29,0,0,30,30,0,0,188,8,0,0,218,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,6,19,0,0,244,16,0,0,88,16,0,0,180,6,0,0,84,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,120,29,0,0,238,14,0,0,248,24,0,0,226,26,0,0,186,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,14,23,0,0,162,15,0,0,130,11,0,0,146,31,0,0,176,30,0,0,128,22,0,0,128,22,0,0,128,22,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,250,6,0,0,130,27,0,0,56,30,0,0,164,7,0,0,212,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,68,3,0,0,142,20,0,0,178,7,0,0,36,4,0,0,214,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,90,4,0,0,24,9,0,0,50,9,0,0,122,31,0,0,192,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,144,32,0,0,152,29,0,0,30,30,0,0,188,8,0,0,218,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,6,19,0,0,244,16,0,0,88,16,0,0,180,6,0,0,84,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,58,3,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,128,3,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,208,23,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,172,36,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,2,6,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,106,1,0,0,120,29,0,0,238,14,0,0,248,24,0,0,226,26,0,0,186,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,196,15,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,248,26,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,132,27,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,16,21,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,168,28,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,88,14,0,0,14,23,0,0,162,15,0,0,130,11,0,0,146,31,0,0,176,30,0,0,128,22,0,0,128,22,0,0,128,22,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,66,19,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,226,13,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,202,6,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,134,20,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,136,3,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,240,12,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,242,1,0,0,250,6,0,0,130,27,0,0,56,30,0,0,164,7,0,0,212,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,54,36,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,142,30,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,106,17,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,228,1,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,176,6,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,68,3,0,0,142,20,0,0,178,7,0,0,36,4,0,0,214,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,6,10,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,192,4,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,50,19,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,12,23,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,200,13,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,22,27,0,0,90,4,0,0,24,9,0,0,50,9,0,0,122,31,0,0,192,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,68,24,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,234,4,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,124,6,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,168,16,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,132,12,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,246,15,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,8,13,0,0,144,32,0,0,152,29,0,0,30,30,0,0,188,8,0,0,218,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,54,2,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,206,32,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,158,5,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,186,8,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,54,19,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,92,16,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,6,19,0,0,244,16,0,0,88,16,0,0,180,6,0,0,84,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,248,20,0,0,248,20,0,0,248,20,0,0,248,20,0,0,248,20,0,0,248,20,0,0,248,20,0,0,248,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,56,9,0,0,56,9,0,0,56,9,0,0,56,9,0,0,56,9,0,0,56,9,0,0,56,9,0,0,56,9,0,0,16,32,0,0,16,32,0,0,16,32,0,0,16,32,0,0,16,32,0,0,16,32,0,0,16,32,0,0,0,35,0,0,160,22,0,0,160,22,0,0,160,22,0,0,160,22,0,0,160,22,0,0,160,22,0,0,160,22,0,0,80,5,0,0,136,1,0,0,136,1,0,0,136,1,0,0,136,1,0,0,136,1,0,0,136,1,0,0,136,1,0,0,136,1,0,0,18,19,0,0,18,19,0,0,18,19,0,0,18,19,0,0,18,19,0,0,18,19,0,0,18,19,0,0,18,19,0,0,18,4,0,0,100,30,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,19,0,0,164,19,0,0,164,19,0,0,164,19,0,0,164,19,0,0,164,19,0,0,164,19,0,0,164,19,0,0,70,24,0,0,70,24,0,0,70,24,0,0,70,24,0,0,70,24,0,0,70,24,0,0,70,24,0,0,70,24,0,0,18,22,0,0,18,22,0,0,18,22,0,0,18,22,0,0,18,22,0,0,18,22,0,0,18,22,0,0,18,22,0,0,196,22,0,0,196,22,0,0,196,22,0,0,196,22,0,0,196,22,0,0,196,22,0,0,196,22,0,0,196,22,0,0,30,5,0,0,30,5,0,0,30,5,0,0,30,5,0,0,30,5,0,0,30,5,0,0,30,5,0,0,30,5,0,0,248,4,0,0,6,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,20,0,0,192,20,0,0,192,20,0,0,192,20,0,0,192,20,0,0,192,20,0,0,192,20,0,0,192,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,70,8,0,0,70,8,0,0,70,8,0,0,70,8,0,0,70,8,0,0,70,8,0,0,70,8,0,0,70,8,0,0,208,3,0,0,208,3,0,0,208,3,0,0,208,3,0,0,208,3,0,0,208,3,0,0,208,3,0,0,208,3,0,0,248,16,0,0,248,16,0,0,248,16,0,0,248,16,0,0,248,16,0,0,248,16,0,0,248,16,0,0,248,16,0,0,180,10,0,0,180,10,0,0,180,10,0,0,180,10,0,0,180,10,0,0,180,10,0,0,180,10,0,0,180,10,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,84,10,0,0,148,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,78,34,0,0,78,34,0,0,78,34,0,0,78,34,0,0,78,34,0,0,78,34,0,0,78,34,0,0,78,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,36,0,0,68,36,0,0,68,36,0,0,68,36,0,0,68,36,0,0,68,36,0,0,68,36,0,0,68,36,0,0,76,35,0,0,76,35,0,0,76,35,0,0,76,35,0,0,76,35,0,0,76,35,0,0,76,35,0,0,76,35,0,0,36,13,0,0,36,13,0,0,36,13,0,0,36,13,0,0,36,13,0,0,36,13,0,0,36,13,0,0,36,13,0,0,44,30,0,0,44,30,0,0,44,30,0,0,44,30,0,0,44,30,0,0,44,30,0,0,44,30,0,0,44,30,0,0,20,25,0,0,20,25,0,0,20,25,0,0,20,25,0,0,20,25,0,0,20,25,0,0,20,25,0,0,20,25,0,0,130,10,0,0,74,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,92,31,0,0,174,4,0,0,14,11,0,0,238,19,0,0,52,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,68,20,0,0,140,4,0,0,204,16,0,0,172,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,14,0,0,236,14,0,0,236,14,0,0,236,14,0,0,236,14,0,0,236,14,0,0,236,14,0,0,236,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,94,2,0,0,94,2,0,0,94,2,0,0,94,2,0,0,94,2,0,0,94,2,0,0,94,2,0,0,94,2,0,0,90,11,0,0,90,11,0,0,90,11,0,0,90,11,0,0,90,11,0,0,90,11,0,0,90,11,0,0,30,16,0,0,0,21,0,0,0,21,0,0,0,21,0,0,0,21,0,0,0,21,0,0,0,21,0,0,0,21,0,0,54,28,0,0,32,6,0,0,32,6,0,0,32,6,0,0,32,6,0,0,32,6,0,0,32,6,0,0,32,6,0,0,32,6,0,0,164,15,0,0,164,15,0,0,164,15,0,0,164,15,0,0,164,15,0,0,164,15,0,0,164,15,0,0,164,15,0,0,26,9,0,0,220,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,9,0,0,136,9,0,0,136,9,0,0,136,9,0,0,136,9,0,0,136,9,0,0,136,9,0,0,136,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,248,8,0,0,248,8,0,0,248,8,0,0,248,8,0,0,248,8,0,0,248,8,0,0,248,8,0,0,248,8,0,0,114,11,0,0,114,11,0,0,114,11,0,0,114,11,0,0,114,11,0,0,114,11,0,0,114,11,0,0,114,11,0,0,162,7,0,0,162,7,0,0,162,7,0,0,162,7,0,0,162,7,0,0,162,7,0,0,162,7,0,0,162,7,0,0,54,33,0,0,54,33,0,0,54,33,0,0,54,33,0,0,54,33,0,0,54,33,0,0,54,33,0,0,54,33,0,0,178,2,0,0,178,2,0,0,178,2,0,0,178,2,0,0,178,2,0,0,178,2,0,0,178,2,0,0,178,2,0,0,4,8,0,0,194,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,7,0,0,90,7,0,0,90,7,0,0,90,7,0,0,90,7,0,0,90,7,0,0,90,7,0,0,90,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,188,28,0,0,188,28,0,0,188,28,0,0,188,28,0,0,188,28,0,0,188,28,0,0,188,28,0,0,188,28,0,0,24,11,0,0,24,11,0,0,24,11,0,0,24,11,0,0,24,11,0,0,24,11,0,0,24,11,0,0,24,11,0,0,222,1,0,0,222,1,0,0,222,1,0,0,222,1,0,0,222,1,0,0,222,1,0,0,222,1,0,0,222,1,0,0,48,9,0,0,48,9,0,0,48,9,0,0,48,9,0,0,48,9,0,0,48,9,0,0,48,9,0,0,48,9,0,0,236,3,0,0,236,3,0,0,236,3,0,0,236,3,0,0,236,3,0,0,236,3,0,0,236,3,0,0,236,3,0,0,250,9,0,0,36,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,92,31,0,0,174,4,0,0,14,11,0,0,238,19,0,0,52,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,68,20,0,0,140,4,0,0,204,16,0,0,172,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,224,4,0,0,224,4,0,0,224,4,0,0,224,4,0,0,224,4,0,0,224,4,0,0,224,4,0,0,224,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,18,0,0,128,18,0,0,128,18,0,0,128,18,0,0,128,18,0,0,128,18,0,0,128,18,0,0,128,18,0,0,60,36,0,0,60,36,0,0,60,36,0,0,60,36,0,0,60,36,0,0,60,36,0,0,60,36,0,0,18,17,0,0,130,7,0,0,130,7,0,0,130,7,0,0,130,7,0,0,130,7,0,0,130,7,0,0,130,7,0,0,86,5,0,0,126,23,0,0,126,23,0,0,126,23,0,0,126,23,0,0,126,23,0,0,126,23,0,0,126,23,0,0,126,23,0,0,224,10,0,0,224,10,0,0,224,10,0,0,224,10,0,0,224,10,0,0,224,10,0,0,224,10,0,0,224,10,0,0,50,13,0,0,56,1,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,112,4,0,0,112,4,0,0,112,4,0,0,112,4,0,0,112,4,0,0,112,4,0,0,112,4,0,0,112,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0])
.concat([174,26,0,0,174,26,0,0,174,26,0,0,174,26,0,0,174,26,0,0,174,26,0,0,174,26,0,0,174,26,0,0,190,22,0,0,190,22,0,0,190,22,0,0,190,22,0,0,190,22,0,0,190,22,0,0,190,22,0,0,190,22,0,0,206,9,0,0,206,9,0,0,206,9,0,0,206,9,0,0,206,9,0,0,206,9,0,0,206,9,0,0,206,9,0,0,34,31,0,0,34,31,0,0,34,31,0,0,34,31,0,0,34,31,0,0,34,31,0,0,34,31,0,0,34,31,0,0,102,36,0,0,102,36,0,0,102,36,0,0,102,36,0,0,102,36,0,0,102,36,0,0,102,36,0,0,102,36,0,0,210,13,0,0,98,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,240,21,0,0,240,21,0,0,240,21,0,0,240,21,0,0,240,21,0,0,240,21,0,0,240,21,0,0,240,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,144,4,0,0,144,4,0,0,144,4,0,0,144,4,0,0,144,4,0,0,144,4,0,0,144,4,0,0,144,4,0,0,52,7,0,0,52,7,0,0,52,7,0,0,52,7,0,0,52,7,0,0,52,7,0,0,52,7,0,0,52,7,0,0,104,30,0,0,104,30,0,0,104,30,0,0,104,30,0,0,104,30,0,0,104,30,0,0,104,30,0,0,104,30,0,0,48,24,0,0,48,24,0,0,48,24,0,0,48,24,0,0,48,24,0,0,48,24,0,0,48,24,0,0,48,24,0,0,172,16,0,0,226,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,38,9,0,0,38,9,0,0,38,9,0,0,38,9,0,0,38,9,0,0,38,9,0,0,38,9,0,0,38,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,142,32,0,0,142,32,0,0,142,32,0,0,142,32,0,0,142,32,0,0,142,32,0,0,142,32,0,0,142,32,0,0,72,19,0,0,72,19,0,0,72,19,0,0,72,19,0,0,72,19,0,0,72,19,0,0,72,19,0,0,72,19,0,0,70,11,0,0,70,11,0,0,70,11,0,0,70,11,0,0,70,11,0,0,70,11,0,0,70,11,0,0,70,11,0,0,138,18,0,0,138,18,0,0,138,18,0,0,138,18,0,0,138,18,0,0,138,18,0,0,138,18,0,0,138,18,0,0,26,5,0,0,26,5,0,0,26,5,0,0,26,5,0,0,26,5,0,0,26,5,0,0,26,5,0,0,26,5,0,0,48,28,0,0,238,31,0,0,42,3,0,0,108,11,0,0,6,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,92,31,0,0,174,4,0,0,14,11,0,0,238,19,0,0,52,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,68,20,0,0,140,4,0,0,204,16,0,0,172,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,3,0,0,30,3,0,0,30,3,0,0,30,3,0,0,30,3,0,0,30,3,0,0,30,3,0,0,30,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,144,3,0,0,144,3,0,0,144,3,0,0,144,3,0,0,144,3,0,0,144,3,0,0,144,3,0,0,144,3,0,0,194,13,0,0,194,13,0,0,194,13,0,0,194,13,0,0,194,13,0,0,194,13,0,0,194,13,0,0,152,2,0,0,118,22,0,0,118,22,0,0,118,22,0,0,118,22,0,0,118,22,0,0,118,22,0,0,118,22,0,0,90,6,0,0,142,5,0,0,142,5,0,0,142,5,0,0,142,5,0,0,142,5,0,0,142,5,0,0,142,5,0,0,142,5,0,0,228,32,0,0,228,32,0,0,228,32,0,0,228,32,0,0,228,32,0,0,228,32,0,0,228,32,0,0,228,32,0,0,102,25,0,0,90,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,148,3,0,0,148,3,0,0,148,3,0,0,148,3,0,0,148,3,0,0,148,3,0,0,148,3,0,0,148,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,240,0,0,0,240,0,0,0,240,0,0,0,240,0,0,0,240,0,0,0,240,0,0,0,240,0,0,0,240,0,0,0,180,15,0,0,180,15,0,0,180,15,0,0,180,15,0,0,180,15,0,0,180,15,0,0,180,15,0,0,180,15,0,0,76,17,0,0,76,17,0,0,76,17,0,0,76,17,0,0,76,17,0,0,76,17,0,0,76,17,0,0,76,17,0,0,212,36,0,0,212,36,0,0,212,36,0,0,212,36,0,0,212,36,0,0,212,36,0,0,212,36,0,0,212,36,0,0,184,21,0,0,184,21,0,0,184,21,0,0,184,21,0,0,184,21,0,0,184,21,0,0,184,21,0,0,184,21,0,0,134,34,0,0,34,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,12,0,0,238,12,0,0,238,12,0,0,238,12,0,0,238,12,0,0,238,12,0,0,238,12,0,0,238,12,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,114,18,0,0,114,18,0,0,114,18,0,0,114,18,0,0,114,18,0,0,114,18,0,0,114,18,0,0,114,18,0,0,228,8,0,0,228,8,0,0,228,8,0,0,228,8,0,0,228,8,0,0,228,8,0,0,228,8,0,0,228,8,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,194,26,0,0,194,26,0,0,194,26,0,0,194,26,0,0,194,26,0,0,194,26,0,0,194,26,0,0,194,26,0,0,142,11,0,0,142,11,0,0,142,11,0,0,142,11,0,0,142,11,0,0,142,11,0,0,142,11,0,0,142,11,0,0,224,12,0,0,94,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,138,24,0,0,138,24,0,0,138,24,0,0,138,24,0,0,138,24,0,0,138,24,0,0,138,24,0,0,138,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,6,0,0,236,6,0,0,236,6,0,0,236,6,0,0,236,6,0,0,236,6,0,0,236,6,0,0,236,6,0,0,226,14,0,0,226,14,0,0,226,14,0,0,226,14,0,0,226,14,0,0,226,14,0,0,226,14,0,0,226,14,0,0,58,24,0,0,58,24,0,0,58,24,0,0,58,24,0,0,58,24,0,0,58,24,0,0,58,24,0,0,58,24,0,0,222,28,0,0,222,28,0,0,222,28,0,0,222,28,0,0,222,28,0,0,222,28,0,0,222,28,0,0,222,28,0,0,10,23,0,0,10,23,0,0,10,23,0,0,10,23,0,0,10,23,0,0,10,23,0,0,10,23,0,0,10,23,0,0,132,21,0,0,84,6,0,0,6,27,0,0,188,10,0,0,88,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,92,31,0,0,174,4,0,0,14,11,0,0,238,19,0,0,52,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,68,20,0,0,140,4,0,0,204,16,0,0,172,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,158,0,0,0,158,0,0,0,158,0,0,0,158,0,0,0,158,0,0,0,158,0,0,0,158,0,0,0,158,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,42,28,0,0,42,28,0,0,42,28,0,0,42,28,0,0,42,28,0,0,42,28,0,0,42,28,0,0,42,28,0,0,60,21,0,0,60,21,0,0,60,21,0,0,60,21,0,0,60,21,0,0,60,21,0,0,60,21,0,0,132,20,0,0,114,1,0,0,114,1,0,0,114,1,0,0,114,1,0,0,114,1,0,0,114,1,0,0,114,1,0,0,206,15,0,0,162,11,0,0,162,11,0,0,162,11,0,0,162,11,0,0,162,11,0,0,162,11,0,0,162,11,0,0,162,11,0,0,82,7,0,0,82,7,0,0,82,7,0,0,82,7,0,0,82,7,0,0,82,7,0,0,82,7,0,0,82,7,0,0,224,5,0,0,86,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,10,0,0,68,10,0,0,68,10,0,0,68,10,0,0,68,10,0,0,68,10,0,0,68,10,0,0,68,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,3,0,0,124,3,0,0,124,3,0,0,124,3,0,0,124,3,0,0,124,3,0,0,124,3,0,0,124,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,150,21,0,0,150,21,0,0,150,21,0,0,150,21,0,0,150,21,0,0,150,21,0,0,150,21,0,0,150,21,0,0,156,24,0,0,28,15,0,0,176,9,0,0,98,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,240,32,0,0,240,32,0,0,240,32,0,0,240,32,0,0,240,32,0,0,240,32,0,0,240,32,0,0,240,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,106,2,0,0,106,2,0,0,106,2,0,0,106,2,0,0,106,2,0,0,106,2,0,0,106,2,0,0,106,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,170,34,0,0,170,34,0,0,170,34,0,0,170,34,0,0,170,34,0,0,170,34,0,0,170,34,0,0,170,34,0,0,116,0,0,0,116,0,0,0,116,0,0,0,116,0,0,0,116,0,0,0,116,0,0,0,116,0,0,0,116,0,0,0,122,7,0,0,122,7,0,0,122,7,0,0,122,7,0,0,122,7,0,0,122,7,0,0,122,7,0,0,122,7,0,0,148,35,0,0,18,28,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,0,29,0,0,0,29,0,0,0,29,0,0,0,29,0,0,0,29,0,0,0,29,0,0,0,29,0,0,0,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,12,0,0,72,12,0,0,72,12,0,0,72,12,0,0,72,12,0,0,72,12,0,0,72,12,0,0,72,12,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,3,0,0,90,3,0,0,90,3,0,0,90,3,0,0,90,3,0,0,90,3,0,0,90,3,0,0,90,3,0,0,64,2,0,0,64,2,0,0,64,2,0,0,64,2,0,0,64,2,0,0,64,2,0,0,64,2,0,0,64,2,0,0,124,8,0,0,124,8,0,0,124,8,0,0,124,8,0,0,124,8,0,0,124,8,0,0,124,8,0,0,124,8,0,0,24,25,0,0,28,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,92,31,0,0,174,4,0,0,14,11,0,0,238,19,0,0,52,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,68,20,0,0,140,4,0,0,204,16,0,0,172,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,14,0,0,72,14,0,0,72,14,0,0,72,14,0,0,72,14,0,0,72,14,0,0,72,14,0,0,72,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,234,7,0,0,234,7,0,0,234,7,0,0,234,7,0,0,234,7,0,0,234,7,0,0,234,7,0,0,234,7,0,0,64,27,0,0,64,27,0,0,64,27,0,0,64,27,0,0,64,27,0,0,64,27,0,0,64,27,0,0,126,24,0,0,156,16,0,0,156,16,0,0,156,16,0,0,156,16,0,0,156,16,0,0,156,16,0,0,156,16,0,0,208,31,0,0,240,27,0,0,240,27,0,0,240,27,0,0,240,27,0,0,240,27,0,0,240,27,0,0,240,27,0,0,240,27,0,0,234,5,0,0,234,5,0,0,234,5,0,0,234,5,0,0,234,5,0,0,234,5,0,0,234,5,0,0,234,5,0,0,104,15,0,0,228,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,152,22,0,0,152,22,0,0,152,22,0,0,152,22,0,0,152,22,0,0,152,22,0,0,152,22,0,0,152,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,80,29,0,0,80,29,0,0,80,29,0,0,80,29,0,0,80,29,0,0,80,29,0,0,80,29,0,0,80,29,0,0,74,33,0,0,74,33,0,0,74,33,0,0,74,33,0,0,74,33,0,0,74,33,0,0,74,33,0,0,74,33,0,0,140,27,0,0,140,27,0,0,140,27,0,0,140,27,0,0,140,27,0,0,140,27,0,0,140,27,0,0,140,27,0,0,144,14,0,0,144,14,0,0,144,14,0,0,144,14,0,0,144,14,0,0,144,14,0,0,144,14,0,0,144,14,0,0,30,8,0,0,168,12,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,234,24,0,0,234,24,0,0,234,24,0,0,234,24,0,0,234,24,0,0,234,24,0,0,234,24,0,0,234,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,68,34,0,0,68,34,0,0,68,34,0,0,68,34,0,0,68,34,0,0,68,34,0,0,68,34,0,0,68,34,0,0,56,14,0,0,56,14,0,0,56,14,0,0,56,14,0,0,56,14,0,0,56,14,0,0,56,14,0,0,56,14,0,0,208,20,0,0,208,20,0,0,208,20,0,0,208,20,0,0,208,20,0,0,208,20,0,0,208,20,0,0,208,20,0,0,204,26,0,0,204,26,0,0,204,26,0,0,204,26,0,0,204,26,0,0,204,26,0,0,204,26,0,0,204,26,0,0,164,8,0,0,164,8,0,0,164,8,0,0,164,8,0,0,164,8,0,0,164,8,0,0,164,8,0,0,164,8,0,0,56,35,0,0,172,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,172,4,0,0,172,4,0,0,172,4,0,0,172,4,0,0,172,4,0,0,172,4,0,0,172,4,0,0,172,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,35,0,0,54,35,0,0,54,35,0,0,54,35,0,0,54,35,0,0,54,35,0,0,54,35,0,0,54,35,0,0,58,35,0,0,58,35,0,0,58,35,0,0,58,35,0,0,58,35,0,0,58,35,0,0,58,35,0,0,88,8,0,0,60,24,0,0,60,24,0,0,60,24,0,0,60,24,0,0,60,24,0,0,60,24,0,0,60,24,0,0,34,1,0,0,142,26,0,0,142,26,0,0,142,26,0,0,142,26,0,0,142,26,0,0,142,26,0,0,142,26,0,0,142,26,0,0,160,29,0,0,160,29,0,0,160,29,0,0,160,29,0,0,160,29,0,0,160,29,0,0,160,29,0,0,160,29,0,0,150,23,0,0,206,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,92,31,0,0,174,4,0,0,14,11,0,0,238,19,0,0,52,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,68,20,0,0,140,4,0,0,204,16,0,0,172,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,232,7,0,0,232,7,0,0,232,7,0,0,232,7,0,0,232,7,0,0,232,7,0,0,232,7,0,0,232,7,0,0,248,31,0,0,248,31,0,0,248,31,0,0,248,31,0,0,248,31,0,0,248,31,0,0,248,31,0,0,248,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,142,34,0,0,142,34,0,0,142,34,0,0,142,34,0,0,142,34,0,0,142,34,0,0,142,34,0,0,142,34,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,90,9,0,0,194,19,0,0,36,35,0,0,2,12,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,62,34,0,0,62,34,0,0,62,34,0,0,62,34,0,0,62,34,0,0,62,34,0,0,62,34,0,0,62,34,0,0,250,0,0,0,250,0,0,0,250,0,0,0,250,0,0,0,250,0,0,0,250,0,0,0,250,0,0,0,250,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,114,7,0,0,114,7,0,0,114,7,0,0,114,7,0,0,114,7,0,0,114,7,0,0,114,7,0,0,114,7,0,0,198,13,0,0,198,13,0,0,198,13,0,0,198,13,0,0,198,13,0,0,198,13,0,0,198,13,0,0,198,13,0,0,78,24,0,0,66,22,0,0,102,23,0,0,72,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,92,31,0,0,174,4,0,0,14,11,0,0,238,19,0,0,52,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,68,20,0,0,140,4,0,0,204,16,0,0,172,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0,28,26,0,0])
.concat([36,11,0,0,36,11,0,0,36,11,0,0,36,11,0,0,36,11,0,0,36,11,0,0,36,11,0,0,220,28,0,0,6,24,0,0,6,24,0,0,6,24,0,0,6,24,0,0,6,24,0,0,6,24,0,0,6,24,0,0,10,9,0,0,52,21,0,0,52,21,0,0,52,21,0,0,52,21,0,0,52,21,0,0,52,21,0,0,52,21,0,0,52,21,0,0,94,13,0,0,94,13,0,0,94,13,0,0,94,13,0,0,94,13,0,0,94,13,0,0,94,13,0,0,94,13,0,0,46,28,0,0,82,2,0,0,220,6,0,0,240,8,0,0,128,22,0,0,218,23,0,0,210,0,0,0,32,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,208,25,0,0,208,25,0,0,208,25,0,0,208,25,0,0,208,25,0,0,208,25,0,0,208,25,0,0,208,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,182,3,0,0,182,3,0,0,182,3,0,0,182,3,0,0,182,3,0,0,182,3,0,0,182,3,0,0,182,3,0,0,242,14,0,0,242,14,0,0,242,14,0,0,242,14,0,0,242,14,0,0,242,14,0,0,242,14,0,0,242,14,0,0,20,35,0,0,70,30,0,0,144,2,0,0,146,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,166,29,0,0,166,29,0,0,166,29,0,0,166,29,0,0,166,29,0,0,166,29,0,0,166,29,0,0,166,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,29,0,0,236,29,0,0,236,29,0,0,236,29,0,0,236,29,0,0,236,29,0,0,236,29,0,0,236,29,0,0,36,15,0,0,36,15,0,0,36,15,0,0,36,15,0,0,36,15,0,0,36,15,0,0,36,15,0,0,36,15,0,0,42,6,0,0,200,9,0,0,116,27,0,0,208,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,154,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,136,12,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,188,17,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,146,18,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,202,25,0,0,92,31,0,0,174,4,0,0,14,11,0,0,238,19,0,0,52,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,44,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,132,36,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,10,22,0,0,68,20,0,0,140,4,0,0,204,16,0,0,172,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,32,24,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,78,2,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,194,10,0,0,2,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,240,23,0,0,118,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,244,12,0,0,240,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,108,15,0,0,108,15,0,0,108,15,0,0,108,15,0,0,108,15,0,0,108,15,0,0,108,15,0,0,108,15,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,70,13,0,0,70,13,0,0,70,13,0,0,70,13,0,0,70,13,0,0,70,13,0,0,70,13,0,0,70,13,0,0,234,18,0,0,234,18,0,0,234,18,0,0,234,18,0,0,234,18,0,0,234,18,0,0,234,18,0,0,88,4,0,0,100,26,0,0,100,26,0,0,100,26,0,0,100,26,0,0,100,26,0,0,100,26,0,0,100,26,0,0,74,10,0,0,230,28,0,0,230,28,0,0,230,28,0,0,230,28,0,0,230,28,0,0,230,28,0,0,230,28,0,0,230,28,0,0,130,19,0,0,130,19,0,0,130,19,0,0,130,19,0,0,130,19,0,0,130,19,0,0,130,19,0,0,130,19,0,0,230,17,0,0,170,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,132,7,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,182,31,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,28,5,0,0,48,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,86,11,0,0,46,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,164,12,0,0,188,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,23,0,0,220,23,0,0,220,23,0,0,220,23,0,0,220,23,0,0,220,23,0,0,220,23,0,0,220,23,0,0,216,25,0,0,216,25,0,0,216,25,0,0,216,25,0,0,216,25,0,0,216,25,0,0,216,25,0,0,216,25,0,0,234,31,0,0,234,31,0,0,234,31,0,0,234,31,0,0,234,31,0,0,234,31,0,0,234,31,0,0,234,31,0,0,142,4,0,0,142,4,0,0,142,4,0,0,142,4,0,0,142,4,0,0,142,4,0,0,142,4,0,0,232,16,0,0,172,6,0,0,172,6,0,0,172,6,0,0,172,6,0,0,172,6,0,0,172,6,0,0,172,6,0,0,152,15,0,0,128,25,0,0,128,25,0,0,128,25,0,0,128,25,0,0,128,25,0,0,128,25,0,0,128,25,0,0,128,25,0,0,60,0,0,0,60,0,0,0,60,0,0,0,60,0,0,0,60,0,0,0,60,0,0,0,60,0,0,0,60,0,0,0,138,23,0,0,180,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,32,24,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,78,2,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,194,10,0,0,2,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,240,23,0,0,118,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,244,12,0,0,240,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,21,0,0,238,21,0,0,238,21,0,0,238,21,0,0,238,21,0,0,238,21,0,0,238,21,0,0,238,21,0,0,34,24,0,0,34,24,0,0,34,24,0,0,34,24,0,0,34,24,0,0,34,24,0,0,34,24,0,0,34,24,0,0,192,10,0,0,192,10,0,0,192,10,0,0,192,10,0,0,192,10,0,0,192,10,0,0,192,10,0,0,192,10,0,0,208,28,0,0,208,28,0,0,208,28,0,0,208,28,0,0,208,28,0,0,208,28,0,0,208,28,0,0,0,32,0,0,22,21,0,0,22,21,0,0,22,21,0,0,22,21,0,0,22,21,0,0,22,21,0,0,22,21,0,0,220,1,0,0,220,20,0,0,220,20,0,0,220,20,0,0,220,20,0,0,220,20,0,0,220,20,0,0,220,20,0,0,220,20,0,0,240,16,0,0,240,16,0,0,240,16,0,0,240,16,0,0,240,16,0,0,240,16,0,0,240,16,0,0,240,16,0,0,240,2,0,0,56,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,132,7,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,182,31,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,28,5,0,0,48,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,86,11,0,0,46,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,164,12,0,0,188,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,34,0,0,220,34,0,0,220,34,0,0,220,34,0,0,220,34,0,0,220,34,0,0,220,34,0,0,220,34,0,0,52,8,0,0,52,8,0,0,52,8,0,0,52,8,0,0,52,8,0,0,52,8,0,0,52,8,0,0,52,8,0,0,6,12,0,0,6,12,0,0,6,12,0,0,6,12,0,0,6,12,0,0,6,12,0,0,6,12,0,0,6,12,0,0,250,28,0,0,250,28,0,0,250,28,0,0,250,28,0,0,250,28,0,0,250,28,0,0,250,28,0,0,254,33,0,0,12,8,0,0,12,8,0,0,12,8,0,0,12,8,0,0,12,8,0,0,12,8,0,0,12,8,0,0,76,0,0,0,148,30,0,0,148,30,0,0,148,30,0,0,148,30,0,0,148,30,0,0,148,30,0,0,148,30,0,0,148,30,0,0,148,13,0,0,148,13,0,0,148,13,0,0,148,13,0,0,148,13,0,0,148,13,0,0,148,13,0,0,148,13,0,0,154,29,0,0,32,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,32,24,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,78,2,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,194,10,0,0,2,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,240,23,0,0,118,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,244,12,0,0,240,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,108,3,0,0,108,3,0,0,108,3,0,0,108,3,0,0,108,3,0,0,108,3,0,0,108,3,0,0,108,3,0,0,132,26,0,0,132,26,0,0,132,26,0,0,132,26,0,0,132,26,0,0,132,26,0,0,132,26,0,0,132,26,0,0,70,23,0,0,70,23,0,0,70,23,0,0,70,23,0,0,70,23,0,0,70,23,0,0,70,23,0,0,70,23,0,0,184,8,0,0,184,8,0,0,184,8,0,0,184,8,0,0,184,8,0,0,184,8,0,0,184,8,0,0,210,11,0,0,98,26,0,0,98,26,0,0,98,26,0,0,98,26,0,0,98,26,0,0,98,26,0,0,98,26,0,0,168,11,0,0,182,19,0,0,182,19,0,0,182,19,0,0,182,19,0,0,182,19,0,0,182,19,0,0,182,19,0,0,182,19,0,0,246,13,0,0,246,13,0,0,246,13,0,0,246,13,0,0,246,13,0,0,246,13,0,0,246,13,0,0,246,13,0,0,14,30,0,0,210,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,132,7,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,182,31,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,28,5,0,0,48,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,86,11,0,0,46,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,164,12,0,0,188,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,36,25,0,0,36,25,0,0,36,25,0,0,36,25,0,0,36,25,0,0,36,25,0,0,36,25,0,0,36,25,0,0,56,5,0,0,56,5,0,0,56,5,0,0,56,5,0,0,56,5,0,0,56,5,0,0,56,5,0,0,56,5,0,0,222,22,0,0,222,22,0,0,222,22,0,0,222,22,0,0,222,22,0,0,222,22,0,0,222,22,0,0,222,22,0,0,98,10,0,0,98,10,0,0,98,10,0,0,98,10,0,0,98,10,0,0,98,10,0,0,98,10,0,0,48,29,0,0,186,24,0,0,186,24,0,0,186,24,0,0,186,24,0,0,186,24,0,0,186,24,0,0,186,24,0,0,86,21,0,0,26,17,0,0,26,17,0,0,26,17,0,0,26,17,0,0,26,17,0,0,26,17,0,0,26,17,0,0,26,17,0,0,20,4,0,0,20,4,0,0,20,4,0,0,20,4,0,0,20,4,0,0,20,4,0,0,20,4,0,0,20,4,0,0,180,25,0,0,184,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,32,24,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,78,2,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,194,10,0,0,2,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,240,23,0,0,118,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,244,12,0,0,240,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,32,13,0,0,32,13,0,0,32,13,0,0,32,13,0,0,32,13,0,0,32,13,0,0,32,13,0,0,32,13,0,0,114,16,0,0,114,16,0,0,114,16,0,0,114,16,0,0,114,16,0,0,114,16,0,0,114,16,0,0,114,16,0,0,188,15,0,0,188,15,0,0,188,15,0,0,188,15,0,0,188,15,0,0,188,15,0,0,188,15,0,0,188,15,0,0,186,29,0,0,186,29,0,0,186,29,0,0,186,29,0,0,186,29,0,0,186,29,0,0,186,29,0,0,20,5,0,0,116,31,0,0,116,31,0,0,116,31,0,0,116,31,0,0,116,31,0,0,116,31,0,0,116,31,0,0,182,5,0,0,200,12,0,0,200,12,0,0,200,12,0,0,200,12,0,0,200,12,0,0,200,12,0,0,200,12,0,0,200,12,0,0,10,16,0,0,10,16,0,0,10,16,0,0,10,16,0,0,10,16,0,0,10,16,0,0,10,16,0,0,10,16,0,0,138,28,0,0,188,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,132,7,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,182,31,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,28,5,0,0,48,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,86,11,0,0,46,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,164,12,0,0,188,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,178,20,0,0,178,20,0,0,178,20,0,0,178,20,0,0,178,20,0,0,178,20,0,0,178,20,0,0,178,20,0,0,14,13,0,0,14,13,0,0,14,13,0,0,14,13,0,0,14,13,0,0,14,13,0,0,14,13,0,0,14,13,0,0,150,22,0,0,150,22,0,0,150,22,0,0,150,22,0,0,150,22,0,0,150,22,0,0,150,22,0,0,150,22,0,0,54,20,0,0,54,20,0,0,54,20,0,0,54,20,0,0,54,20,0,0,54,20,0,0,54,20,0,0,212,21,0,0,186,17,0,0,186,17,0,0,186,17,0,0,186,17,0,0,186,17,0,0,186,17,0,0,186,17,0,0,76,12,0,0,94,35,0,0,94,35,0,0,94,35,0,0,94,35,0,0,94,35,0,0,94,35,0,0,94,35,0,0,94,35,0,0,64,5,0,0,64,5,0,0,64,5,0,0,64,5,0,0,64,5,0,0,64,5,0,0,64,5,0,0,64,5,0,0,234,17,0,0,58,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,32,24,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,78,2,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,194,10,0,0,2,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0])
.concat([94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,240,23,0,0,118,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,244,12,0,0,240,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,10,0,0,100,10,0,0,100,10,0,0,100,10,0,0,100,10,0,0,100,10,0,0,100,10,0,0,100,10,0,0,216,20,0,0,216,20,0,0,216,20,0,0,216,20,0,0,216,20,0,0,216,20,0,0,216,20,0,0,216,20,0,0,174,3,0,0,174,3,0,0,174,3,0,0,174,3,0,0,174,3,0,0,174,3,0,0,174,3,0,0,174,3,0,0,38,3,0,0,38,3,0,0,38,3,0,0,38,3,0,0,38,3,0,0,38,3,0,0,38,3,0,0,210,1,0,0,112,25,0,0,112,25,0,0,112,25,0,0,112,25,0,0,112,25,0,0,112,25,0,0,112,25,0,0,214,25,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,232,0,0,0,232,0,0,0,232,0,0,0,232,0,0,0,232,0,0,0,232,0,0,0,232,0,0,0,232,0,0,0,78,7,0,0,94,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,132,7,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,182,31,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,28,5,0,0,48,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,86,11,0,0,46,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,164,12,0,0,188,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,158,34,0,0,158,34,0,0,158,34,0,0,158,34,0,0,158,34,0,0,158,34,0,0,158,34,0,0,158,34,0,0,88,7,0,0,88,7,0,0,88,7,0,0,88,7,0,0,88,7,0,0,88,7,0,0,88,7,0,0,88,7,0,0,98,3,0,0,98,3,0,0,98,3,0,0,98,3,0,0,98,3,0,0,98,3,0,0,98,3,0,0,98,3,0,0,40,27,0,0,40,27,0,0,40,27,0,0,40,27,0,0,40,27,0,0,40,27,0,0,40,27,0,0,62,13,0,0,210,2,0,0,210,2,0,0,210,2,0,0,210,2,0,0,210,2,0,0,210,2,0,0,210,2,0,0,12,6,0,0,174,6,0,0,174,6,0,0,174,6,0,0,174,6,0,0,174,6,0,0,174,6,0,0,174,6,0,0,174,6,0,0,86,27,0,0,86,27,0,0,86,27,0,0,86,27,0,0,86,27,0,0,86,27,0,0,86,27,0,0,86,27,0,0,182,23,0,0,66,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,32,24,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,78,2,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,194,10,0,0,2,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,240,23,0,0,118,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,244,12,0,0,240,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,24,0,0,214,24,0,0,214,24,0,0,214,24,0,0,214,24,0,0,214,24,0,0,214,24,0,0,214,24,0,0,244,18,0,0,244,18,0,0,244,18,0,0,244,18,0,0,244,18,0,0,244,18,0,0,244,18,0,0,244,18,0,0,142,22,0,0,142,22,0,0,142,22,0,0,142,22,0,0,142,22,0,0,142,22,0,0,142,22,0,0,142,22,0,0,100,16,0,0,100,16,0,0,100,16,0,0,100,16,0,0,100,16,0,0,100,16,0,0,100,16,0,0,182,9,0,0,90,17,0,0,90,17,0,0,90,17,0,0,90,17,0,0,90,17,0,0,90,17,0,0,90,17,0,0,140,36,0,0,246,21,0,0,246,21,0,0,246,21,0,0,246,21,0,0,246,21,0,0,246,21,0,0,246,21,0,0,246,21,0,0,156,21,0,0,156,21,0,0,156,21,0,0,156,21,0,0,156,21,0,0,156,21,0,0,156,21,0,0,156,21,0,0,38,10,0,0,248,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,132,7,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,182,31,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,28,5,0,0,48,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,86,11,0,0,46,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,164,12,0,0,188,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,216,19,0,0,216,19,0,0,216,19,0,0,216,19,0,0,216,19,0,0,216,19,0,0,216,19,0,0,216,19,0,0,26,28,0,0,26,28,0,0,26,28,0,0,26,28,0,0,26,28,0,0,26,28,0,0,26,28,0,0,26,28,0,0,236,24,0,0,236,24,0,0,236,24,0,0,236,24,0,0,236,24,0,0,236,24,0,0,236,24,0,0,236,24,0,0,230,9,0,0,230,9,0,0,230,9,0,0,230,9,0,0,230,9,0,0,230,9,0,0,230,9,0,0,182,6,0,0,146,24,0,0,146,24,0,0,146,24,0,0,146,24,0,0,146,24,0,0,146,24,0,0,146,24,0,0,144,18,0,0,26,6,0,0,26,6,0,0,26,6,0,0,26,6,0,0,26,6,0,0,26,6,0,0,26,6,0,0,26,6,0,0,28,22,0,0,28,22,0,0,28,22,0,0,28,22,0,0,28,22,0,0,28,22,0,0,28,22,0,0,28,22,0,0,200,3,0,0,88,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,32,24,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,78,2,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,194,10,0,0,2,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,240,23,0,0,118,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,244,12,0,0,240,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,120,5,0,0,120,5,0,0,120,5,0,0,120,5,0,0,120,5,0,0,120,5,0,0,120,5,0,0,120,5,0,0,222,35,0,0,222,35,0,0,222,35,0,0,222,35,0,0,222,35,0,0,222,35,0,0,222,35,0,0,222,35,0,0,104,35,0,0,104,35,0,0,104,35,0,0,104,35,0,0,104,35,0,0,104,35,0,0,104,35,0,0,104,35,0,0,184,14,0,0,184,14,0,0,184,14,0,0,184,14,0,0,184,14,0,0,184,14,0,0,184,14,0,0,140,11,0,0,252,6,0,0,252,6,0,0,252,6,0,0,252,6,0,0,252,6,0,0,252,6,0,0,252,6,0,0,134,29,0,0,160,4,0,0,160,4,0,0,160,4,0,0,160,4,0,0,160,4,0,0,160,4,0,0,160,4,0,0,160,4,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,18,35,0,0,86,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,132,7,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,182,31,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,28,5,0,0,48,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,86,11,0,0,46,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,164,12,0,0,188,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,176,24,0,0,176,24,0,0,176,24,0,0,176,24,0,0,176,24,0,0,176,24,0,0,176,24,0,0,176,24,0,0,44,29,0,0,44,29,0,0,44,29,0,0,44,29,0,0,44,29,0,0,44,29,0,0,44,29,0,0,44,29,0,0,52,15,0,0,52,15,0,0,52,15,0,0,52,15,0,0,52,15,0,0,52,15,0,0,52,15,0,0,52,15,0,0,244,9,0,0,244,9,0,0,244,9,0,0,244,9,0,0,244,9,0,0,244,9,0,0,244,9,0,0,208,8,0,0,24,3,0,0,24,3,0,0,24,3,0,0,24,3,0,0,24,3,0,0,24,3,0,0,24,3,0,0,184,35,0,0,194,8,0,0,194,8,0,0,194,8,0,0,194,8,0,0,194,8,0,0,194,8,0,0,194,8,0,0,194,8,0,0,36,31,0,0,36,31,0,0,36,31,0,0,36,31,0,0,36,31,0,0,36,31,0,0,36,31,0,0,36,31,0,0,46,4,0,0,202,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,10,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,156,34,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,178,9,0,0,32,24,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,144,5,0,0,78,2,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,134,5,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,194,10,0,0,2,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,172,10,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,192,2,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,94,22,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,88,13,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,166,12,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,214,23,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,254,5,0,0,240,23,0,0,118,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,154,9,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,34,21,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,30,6,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,78,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,124,18,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,152,33,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,80,4,0,0,244,12,0,0,240,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,34,0,0,72,34,0,0,72,34,0,0,72,34,0,0,72,34,0,0,72,34,0,0,72,34,0,0,72,34,0,0,106,25,0,0,106,25,0,0,106,25,0,0,106,25,0,0,106,25,0,0,106,25,0,0,106,25,0,0,106,25,0,0,8,29,0,0,8,29,0,0,8,29,0,0,8,29,0,0,8,29,0,0,8,29,0,0,8,29,0,0,8,29,0,0,226,24,0,0,226,24,0,0,226,24,0,0,226,24,0,0,226,24,0,0,226,24,0,0,226,24,0,0,226,20,0,0,106,3,0,0,106,3,0,0,106,3,0,0,106,3,0,0,106,3,0,0,106,3,0,0,106,3,0,0,96,32,0,0,92,14,0,0,92,14,0,0,92,14,0,0,92,14,0,0,92,14,0,0,92,14,0,0,92,14,0,0,92,14,0,0,20,15,0,0,20,15,0,0,20,15,0,0,20,15,0,0,20,15,0,0,20,15,0,0,20,15,0,0,20,15,0,0,232,21,0,0,190,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,134,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,160,6,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,62,36,0,0,132,7,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,46,27,0,0,182,31,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,230,4,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,148,14,0,0,28,5,0,0,48,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,70,18,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,244,0,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,18,13,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,228,20,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,240,31,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,16,7,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,26,16,0,0,86,11,0,0,46,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,202,29,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,80,24,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,242,0,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,136,17,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,6,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,230,18,0,0,164,12,0,0,188,3,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,142,12,0,0,142,12,0,0,142,12,0,0,142,12,0,0,142,12,0,0,142,12,0,0,142,12,0,0,142,12,0,0,38,5,0,0,38,5,0,0,38,5,0,0,38,5,0,0,38,5,0,0,38,5,0,0,38,5,0,0,38,5,0,0,162,18,0,0,162,18,0,0,162,18,0,0,162,18,0,0,162,18,0,0,162,18,0,0,162,18,0,0,162,18,0,0,82,26,0,0,82,26,0,0,82,26,0,0,82,26,0,0,82,26,0,0,82,26,0,0,82,26,0,0,136,20,0,0,218,13,0,0,218,13,0,0,218,13,0,0,218,13,0,0,218,13,0,0,218,13,0,0,218,13,0,0,180,30,0,0,244,7,0,0,244,7,0,0,244,7,0,0,244,7,0,0,244,7,0,0,244,7,0,0,244,7,0,0,244,7,0,0,64,14,0,0,64,14,0,0,64,14,0,0,64,14,0,0,64,14,0,0,64,14,0,0,64,14,0,0,64,14,0,0,10,15,0,0,158,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,110,34,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,240,24,0,0,158,35,0,0,146,35,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,168,7,0,0,146,27,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0])
.concat([216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,216,12,0,0,228,23,0,0,70,20,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,164,26,0,0,122,29,0,0,26,2,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,100,20,0,0,148,24,0,0,54,25,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,78,4,0,0,102,10,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,232,22,0,0,80,17,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,170,21,0,0,168,4,0,0,200,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,24,5,0,0,148,10,0,0,164,22,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,228,34,0,0,148,8,0,0,234,10,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,238,24,0,0,140,22,0,0,42,27,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,140,21,0,0,190,24,0,0,48,30,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0])
.concat([178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,178,16,0,0,108,36,0,0,86,4,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,60,20,0,0,14,20,0,0,188,16,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,248,33,0,0,8,10,0,0,102,15,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,42,32,0,0,120,14,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0])
.concat([78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,78,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,208,35,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,6,13,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,56,21,0,0,50,7,0,0,92,32,0,0,246,12,0,0,170,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0])
.concat([24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,34,36,0,0,86,13,0,0,18,31,0,0,30,13,0,0,78,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,186,36,0,0,166,9,0,0,60,19,0,0,22,29,0,0,52,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,144,1,0,0,188,23,0,0,118,11,0,0,116,20,0,0,68,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,80,31,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,162,2,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,160,2,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,110,22,0,0,218,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,214,9,0,0,186,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,122,9,0,0,190,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,64,25,0,0,102,21,0,0,178,4,0,0,90,23,0,0,42,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,208,35,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,6,13,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,56,21,0,0,50,7,0,0,92,32,0,0,246,12,0,0,170,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,34,36,0,0,86,13,0,0,18,31,0,0,30,13,0,0,78,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,186,36,0,0,166,9,0,0,60,19,0,0,22,29,0,0,52,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,144,1,0,0,188,23,0,0,118,11,0,0,116,20,0,0,68,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,80,31,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,162,2,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,160,2,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,110,22,0,0,218,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,214,9,0,0,186,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,122,9,0,0,190,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,64,25,0,0,102,21,0,0,178,4,0,0,90,23,0,0,42,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,208,35,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,6,13,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,56,21,0,0,50,7,0,0,92,32,0,0,246,12,0,0,170,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,34,36,0,0,86,13,0,0,18,31,0,0,30,13,0,0,78,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,186,36,0,0,166,9,0,0,60,19,0,0,22,29,0,0,52,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,144,1,0,0,188,23,0,0,118,11,0,0,116,20,0,0,68,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,80,31,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,162,2,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,160,2,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,110,22,0,0,218,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,214,9,0,0,186,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,122,9,0,0,190,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,64,25,0,0,102,21,0,0,178,4,0,0,90,23,0,0,42,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,208,35,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,6,13,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,56,21,0,0,50,7,0,0,92,32,0,0,246,12,0,0,170,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,34,36,0,0,86,13,0,0,18,31,0,0,30,13,0,0,78,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,186,36,0,0,166,9,0,0,60,19,0,0,22,29,0,0,52,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,144,1,0,0,188,23,0,0,118,11,0,0,116,20,0,0,68,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,80,31,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,162,2,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,160,2,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,110,22,0,0,218,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,214,9,0,0,186,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,122,9,0,0,190,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,64,25,0,0,102,21,0,0,178,4,0,0,90,23,0,0,42,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,208,35,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,6,13,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,56,21,0,0,50,7,0,0,92,32,0,0,246,12,0,0,170,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,34,36,0,0,86,13,0,0,18,31,0,0,30,13,0,0,78,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,186,36,0,0,166,9,0,0,60,19,0,0,22,29,0,0,52,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,144,1,0,0,188,23,0,0,118,11,0,0,116,20,0,0,68,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,80,31,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,162,2,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,160,2,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,110,22,0,0,218,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,214,9,0,0,186,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,122,9,0,0,190,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,64,25,0,0,102,21,0,0,178,4,0,0,90,23,0,0,42,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,208,35,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,6,13,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,56,21,0,0,50,7,0,0,92,32,0,0,246,12,0,0,170,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0])
.concat([24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,34,36,0,0,86,13,0,0,18,31,0,0,30,13,0,0,78,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,186,36,0,0,166,9,0,0,60,19,0,0,22,29,0,0,52,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,144,1,0,0,188,23,0,0,118,11,0,0,116,20,0,0,68,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,80,31,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,162,2,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,160,2,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,110,22,0,0,218,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,214,9,0,0,186,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,122,9,0,0,190,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,64,25,0,0,102,21,0,0,178,4,0,0,90,23,0,0,42,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,208,35,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,6,13,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,56,21,0,0,50,7,0,0,92,32,0,0,246,12,0,0,170,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,34,36,0,0,86,13,0,0,18,31,0,0,30,13,0,0,78,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,186,36,0,0,166,9,0,0,60,19,0,0,22,29,0,0,52,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,144,1,0,0,188,23,0,0,118,11,0,0,116,20,0,0,68,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,120,25,0,0,80,31,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,162,2,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,160,2,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,110,22,0,0,218,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,214,9,0,0,186,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,122,9,0,0,190,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,64,25,0,0,102,21,0,0,178,4,0,0,90,23,0,0,42,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,76,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,190,16,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,138,22,0,0,208,35,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,220,7,0,0,6,13,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,196,14,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,80,25,0,0,56,21,0,0,50,7,0,0,92,32,0,0,246,12,0,0,170,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,134,15,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,24,17,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,132,8,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,206,17,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,12,34,0,0,34,36,0,0,86,13,0,0,18,31,0,0,30,13,0,0,78,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,250,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,188,14,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,178,10,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,58,29,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,36,20,0,0,186,36,0,0,166,9,0,0,60,19,0,0,22,29,0,0,52,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,200,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,204,15,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,212,26,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,172,31,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,206,25,0,0,144,1,0,0,188,23,0,0,118,11,0,0,116,20,0,0,68,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,88,33,0,0,4,12,0,0,4,12,0,0,4,12,0,0,4,12,0,0,4,12,0,0,4,12,0,0,4,12,0,0,176,7,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,222,8,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,192,9,0,0,162,2,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,250,3,0,0,160,2,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,210,20,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,188,7,0,0,110,22,0,0,218,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,92,34,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,76,26,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,246,29,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,78,13,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,214,9,0,0,186,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,238,26,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,28,11,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,30,19,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,24,27,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,134,21,0,0,122,9,0,0,190,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,60,33,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,52,18,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,32,7,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,100,5,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,102,6,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,126,22,0,0,64,25,0,0,102,21,0,0,178,4,0,0,90,23,0,0,42,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,138,31,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,244,28,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,134,25,0,0,52,29,0,0,184,13,0,0,208,27,0,0,218,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,52,19,0,0,198,21,0,0,210,15,0,0,236,33,0,0,74,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,144,36,0,0,202,5,0,0,132,2,0,0,186,13,0,0,14,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,12,15,0,0,252,2,0,0,138,5,0,0,44,21,0,0,210,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,46,33,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,144,34,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,140,18,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,70,17,0,0,156,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,90,14,0,0,58,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,252,16,0,0,230,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,60,22,0,0,186,26,0,0,216,17,0,0,108,7,0,0,222,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,138,31,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,244,28,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,134,25,0,0,52,29,0,0,184,13,0,0,208,27,0,0,218,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,52,19,0,0,198,21,0,0,210,15,0,0,236,33,0,0,74,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,144,36,0,0,202,5,0,0,132,2,0,0,186,13,0,0,14,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,12,15,0,0,252,2,0,0,138,5,0,0,44,21,0,0,210,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,46,33,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,144,34,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,140,18,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,70,17,0,0,156,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,90,14,0,0,58,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,252,16,0,0,230,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,60,22,0,0,186,26,0,0,216,17,0,0,108,7,0,0,222,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,138,31,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,244,28,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,134,25,0,0,52,29,0,0,184,13,0,0,208,27,0,0,218,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0])
.concat([68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,52,19,0,0,198,21,0,0,210,15,0,0,236,33,0,0,74,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,144,36,0,0,202,5,0,0,132,2,0,0,186,13,0,0,14,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,12,15,0,0,252,2,0,0,138,5,0,0,44,21,0,0,210,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,46,33,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,144,34,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,140,18,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,70,17,0,0,156,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,90,14,0,0,58,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,252,16,0,0,230,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,60,22,0,0,186,26,0,0,216,17,0,0,108,7,0,0,222,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,138,31,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,244,28,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,134,25,0,0,52,29,0,0,184,13,0,0,208,27,0,0,218,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,52,19,0,0,198,21,0,0,210,15,0,0,236,33,0,0,74,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,144,36,0,0,202,5,0,0,132,2,0,0,186,13,0,0,14,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,12,15,0,0,252,2,0,0,138,5,0,0,44,21,0,0,210,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,46,33,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,144,34,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,140,18,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,70,17,0,0,156,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,90,14,0,0,58,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,252,16,0,0,230,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,60,22,0,0,186,26,0,0,216,17,0,0,108,7,0,0,222,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,138,31,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,244,28,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,134,25,0,0,52,29,0,0,184,13,0,0,208,27,0,0,218,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,52,19,0,0,198,21,0,0,210,15,0,0,236,33,0,0,74,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,144,36,0,0,202,5,0,0,132,2,0,0,186,13,0,0,14,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,12,15,0,0,252,2,0,0,138,5,0,0,44,21,0,0,210,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,46,33,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,144,34,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,140,18,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,70,17,0,0,156,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,90,14,0,0,58,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,252,16,0,0,230,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,60,22,0,0,186,26,0,0,216,17,0,0,108,7,0,0,222,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,138,31,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,244,28,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,134,25,0,0,52,29,0,0,184,13,0,0,208,27,0,0,218,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,52,19,0,0,198,21,0,0,210,15,0,0,236,33,0,0,74,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,144,36,0,0,202,5,0,0,132,2,0,0,186,13,0,0,14,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,12,15,0,0,252,2,0,0,138,5,0,0,44,21,0,0,210,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,46,33,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,144,34,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,140,18,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,70,17,0,0,156,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,90,14,0,0,58,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,252,16,0,0,230,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,60,22,0,0,186,26,0,0,216,17,0,0,108,7,0,0,222,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,138,31,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,244,28,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,134,25,0,0,52,29,0,0,184,13,0,0,208,27,0,0,218,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,52,19,0,0,198,21,0,0,210,15,0,0,236,33,0,0,74,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,144,36,0,0,202,5,0,0,132,2,0,0,186,13,0,0,14,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,12,15,0,0,252,2,0,0,138,5,0,0,44,21,0,0,210,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,62,18,0,0,46,33,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,144,34,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,140,18,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,70,17,0,0,156,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,90,14,0,0,58,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,252,16,0,0,230,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,60,22,0,0,186,26,0,0,216,17,0,0,108,7,0,0,222,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,164,0,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,246,16,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,170,17,0,0,138,31,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,204,23,0,0,244,28,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,134,25,0,0,52,29,0,0,184,13,0,0,208,27,0,0,218,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,30,31,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0,236,19,0,0])
.concat([68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,68,17,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,156,15,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,172,29,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,106,26,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,228,11,0,0,52,19,0,0,198,21,0,0,210,15,0,0,236,33,0,0,74,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,220,4,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,236,8,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,14,21,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,134,3,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,22,16,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,150,24,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,16,31,0,0,144,36,0,0,202,5,0,0,132,2,0,0,186,13,0,0,14,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,238,4,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,48,10,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,78,15,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,34,30,0,0,12,15,0,0,252,2,0,0,138,5,0,0,44,21,0,0,210,6,0,0,128,22,0,0,128,22,0,0,128,22,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,100,2,0,0,252,18,0,0,252,18,0,0,252,18,0,0,252,18,0,0,252,18,0,0,252,18,0,0,252,18,0,0,176,21,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,222,12,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,98,31,0,0,144,34,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,144,33,0,0,140,18,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,108,20,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,192,30,0,0,70,17,0,0,156,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,50,32,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,174,29,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,14,18,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,218,25,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,228,31,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,234,16,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,178,22,0,0,90,14,0,0,58,25,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,90,31,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,112,29,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,72,33,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,206,14,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,152,19,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,200,20,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,184,29,0,0,252,16,0,0,230,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,248,29,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,68,13,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,58,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,246,17,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,174,33,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,214,16,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,168,14,0,0,60,22,0,0,186,26,0,0,216,17,0,0,108,7,0,0,222,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0])
.concat([128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,128,29,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,186,31,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,252,0,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,160,11,0,0,118,1,0,0,252,17,0,0,212,0,0,0,136,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,246,31,0,0,104,12,0,0,242,24,0,0,206,2,0,0,112,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,142,2,0,0,130,5,0,0,152,7,0,0,0,19,0,0,32,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,36,24,0,0,44,22,0,0,96,24,0,0,214,13,0,0,32,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,56,36,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,12,10,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,2,19,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,236,9,0,0,220,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,158,23,0,0,120,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,62,14,0,0,44,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,100,6,0,0,184,17,0,0,248,7,0,0,100,34,0,0,68,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,186,31,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,252,0,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,160,11,0,0,118,1,0,0,252,17,0,0,212,0,0,0,136,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0])
.concat([74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,246,31,0,0,104,12,0,0,242,24,0,0,206,2,0,0,112,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,142,2,0,0,130,5,0,0,152,7,0,0,0,19,0,0,32,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,36,24,0,0,44,22,0,0,96,24,0,0,214,13,0,0,32,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,56,36,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,12,10,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,2,19,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,236,9,0,0,220,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,158,23,0,0,120,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,62,14,0,0,44,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,100,6,0,0,184,17,0,0,248,7,0,0,100,34,0,0,68,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,186,31,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,252,0,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,160,11,0,0,118,1,0,0,252,17,0,0,212,0,0,0,136,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,246,31,0,0,104,12,0,0,242,24,0,0,206,2,0,0,112,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,142,2,0,0,130,5,0,0,152,7,0,0,0,19,0,0,32,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,36,24,0,0,44,22,0,0,96,24,0,0,214,13,0,0,32,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,56,36,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,12,10,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,2,19,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,236,9,0,0,220,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,158,23,0,0,120,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,62,14,0,0,44,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,100,6,0,0,184,17,0,0,248,7,0,0,100,34,0,0,68,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,186,31,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,252,0,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,160,11,0,0,118,1,0,0,252,17,0,0,212,0,0,0,136,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,246,31,0,0,104,12,0,0,242,24,0,0,206,2,0,0,112,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,142,2,0,0,130,5,0,0,152,7,0,0,0,19,0,0,32,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,36,24,0,0,44,22,0,0,96,24,0,0,214,13,0,0,32,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,56,36,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,12,10,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,2,19,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,236,9,0,0,220,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,158,23,0,0,120,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,62,14,0,0,44,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,100,6,0,0,184,17,0,0,248,7,0,0,100,34,0,0,68,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,186,31,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,252,0,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,160,11,0,0,118,1,0,0,252,17,0,0,212,0,0,0,136,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,246,31,0,0,104,12,0,0,242,24,0,0,206,2,0,0,112,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,142,2,0,0,130,5,0,0,152,7,0,0,0,19,0,0,32,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,36,24,0,0,44,22,0,0,96,24,0,0,214,13,0,0,32,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,56,36,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,12,10,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,2,19,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,236,9,0,0,220,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,158,23,0,0,120,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,62,14,0,0,44,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,100,6,0,0,184,17,0,0,248,7,0,0,100,34,0,0,68,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,186,31,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,252,0,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,160,11,0,0,118,1,0,0,252,17,0,0,212,0,0,0,136,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,246,31,0,0,104,12,0,0,242,24,0,0,206,2,0,0,112,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,142,2,0,0,130,5,0,0,152,7,0,0,0,19,0,0,32,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,36,24,0,0,44,22,0,0,96,24,0,0,214,13,0,0,32,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,56,36,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,12,10,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,2,19,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,236,9,0,0,220,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,158,23,0,0,120,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,62,14,0,0,44,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,100,6,0,0,184,17,0,0,248,7,0,0,100,34,0,0,68,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,186,31,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,252,0,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,160,11,0,0,118,1,0,0,252,17,0,0,212,0,0,0,136,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0])
.concat([74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,246,31,0,0,104,12,0,0,242,24,0,0,206,2,0,0,112,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,142,2,0,0,130,5,0,0,152,7,0,0,0,19,0,0,32,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,36,24,0,0,44,22,0,0,96,24,0,0,214,13,0,0,32,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,56,36,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,12,10,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,2,19,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,236,9,0,0,220,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,158,23,0,0,120,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,62,14,0,0,44,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,100,6,0,0,184,17,0,0,248,7,0,0,100,34,0,0,68,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,168,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,238,10,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,186,31,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,222,23,0,0,252,0,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,116,15,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,218,24,0,0,160,11,0,0,118,1,0,0,252,17,0,0,212,0,0,0,136,19,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,134,11,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,168,2,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,74,15,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,42,2,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,126,6,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,26,18,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,82,6,0,0,246,31,0,0,104,12,0,0,242,24,0,0,206,2,0,0,112,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,206,20,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,66,13,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,8,19,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,20,11,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,180,29,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,38,6,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,230,12,0,0,142,2,0,0,130,5,0,0,152,7,0,0,0,19,0,0,32,14,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,72,32,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,54,24,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,116,7,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,212,23,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,118,20,0,0,36,24,0,0,44,22,0,0,96,24,0,0,214,13,0,0,32,29,0,0,128,22,0,0,128,22,0,0,128,22,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,150,5,0,0,132,10,0,0,132,10,0,0,132,10,0,0,132,10,0,0,132,10,0,0,132,10,0,0,132,10,0,0,110,8,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,246,2,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,4,21,0,0,12,10,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,36,30,0,0,2,19,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,140,32,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,142,36,0,0,236,9,0,0,220,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,10,24,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,54,15,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,136,36,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,40,31,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,128,15,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,184,9,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,238,34,0,0,158,23,0,0,120,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,124,36,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,50,5,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,170,32,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,176,27,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,58,28,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,34,3,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,14,7,0,0,62,14,0,0,44,16,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,236,16,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,166,34,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,150,28,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,4,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,252,13,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,6,5,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,74,4,0,0,100,6,0,0,184,17,0,0,248,7,0,0,100,34,0,0,68,8,0,0,128,22,0,0,128,22,0,0,128,22,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,190,32,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,214,34,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,154,22,0,0,116,30,0,0,152,10,0,0,2,30,0,0,10,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,92,11,0,0,166,3,0,0,22,31,0,0,90,27,0,0,94,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,242,27,0,0,52,9,0,0,194,9,0,0,236,10,0,0,56,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,220,33,0,0,158,17,0,0,80,27,0,0,120,13,0,0,134,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,218,10,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,134,24,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,108,31,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,154,32,0,0,144,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,98,5,0,0,86,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,148,15,0,0,156,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,28,0,0,26,3,0,0,208,0,0,0,56,3,0,0,4,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,190,32,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,214,34,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,154,22,0,0,116,30,0,0,152,10,0,0,2,30,0,0,10,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,92,11,0,0,166,3,0,0,22,31,0,0,90,27,0,0,94,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,242,27,0,0,52,9,0,0,194,9,0,0,236,10,0,0,56,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,220,33,0,0,158,17,0,0,80,27,0,0,120,13,0,0,134,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,218,10,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,134,24,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,108,31,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,154,32,0,0,144,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,98,5,0,0,86,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,148,15,0,0,156,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,28,0,0,26,3,0,0,208,0,0,0,56,3,0,0,4,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,190,32,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,214,34,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,154,22,0,0,116,30,0,0,152,10,0,0,2,30,0,0,10,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,92,11,0,0,166,3,0,0,22,31,0,0,90,27,0,0,94,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,242,27,0,0,52,9,0,0,194,9,0,0,236,10,0,0,56,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,220,33,0,0,158,17,0,0,80,27,0,0,120,13,0,0,134,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,218,10,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,134,24,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,108,31,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,154,32,0,0,144,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,98,5,0,0,86,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,148,15,0,0,156,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,28,0,0,26,3,0,0,208,0,0,0,56,3,0,0,4,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,190,32,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,214,34,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,154,22,0,0,116,30,0,0,152,10,0,0,2,30,0,0,10,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0])
.concat([206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,92,11,0,0,166,3,0,0,22,31,0,0,90,27,0,0,94,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,242,27,0,0,52,9,0,0,194,9,0,0,236,10,0,0,56,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,220,33,0,0,158,17,0,0,80,27,0,0,120,13,0,0,134,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,218,10,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,134,24,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,108,31,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,154,32,0,0,144,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,98,5,0,0,86,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,148,15,0,0,156,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,28,0,0,26,3,0,0,208,0,0,0,56,3,0,0,4,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,190,32,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,214,34,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,154,22,0,0,116,30,0,0,152,10,0,0,2,30,0,0,10,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,92,11,0,0,166,3,0,0,22,31,0,0,90,27,0,0,94,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,242,27,0,0,52,9,0,0,194,9,0,0,236,10,0,0,56,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,220,33,0,0,158,17,0,0,80,27,0,0,120,13,0,0,134,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,218,10,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,134,24,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,108,31,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,154,32,0,0,144,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,98,5,0,0,86,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,148,15,0,0,156,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,28,0,0,26,3,0,0,208,0,0,0,56,3,0,0,4,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,190,32,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,214,34,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,154,22,0,0,116,30,0,0,152,10,0,0,2,30,0,0,10,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,92,11,0,0,166,3,0,0,22,31,0,0,90,27,0,0,94,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,242,27,0,0,52,9,0,0,194,9,0,0,236,10,0,0,56,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,220,33,0,0,158,17,0,0,80,27,0,0,120,13,0,0,134,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,218,10,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,134,24,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,108,31,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,154,32,0,0,144,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,98,5,0,0,86,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,148,15,0,0,156,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,28,0,0,26,3,0,0,208,0,0,0,56,3,0,0,4,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,190,32,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,214,34,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,154,22,0,0,116,30,0,0,152,10,0,0,2,30,0,0,10,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,92,11,0,0,166,3,0,0,22,31,0,0,90,27,0,0,94,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,242,27,0,0,52,9,0,0,194,9,0,0,236,10,0,0,56,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,220,33,0,0,158,17,0,0,80,27,0,0,120,13,0,0,134,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,248,19,0,0,218,10,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,134,24,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,108,31,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,154,32,0,0,144,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,98,5,0,0,86,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,148,15,0,0,156,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,28,0,0,26,3,0,0,208,0,0,0,56,3,0,0,4,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,46,9,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,214,31,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,190,32,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,30,10,0,0,214,34,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,52,32,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,154,22,0,0,116,30,0,0,152,10,0,0,2,30,0,0,10,21,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,72,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,206,36,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,212,5,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,56,17,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,150,7,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,142,17,0,0,92,11,0,0,166,3,0,0,22,31,0,0,90,27,0,0,94,23,0,0,128,22,0,0,128,22,0,0,128,22,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,176,11,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,118,29,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,32,20,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,184,10,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,218,14,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,156,10,0,0,242,27,0,0,52,9,0,0,194,9,0,0,236,10,0,0,56,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,40,5,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,226,9,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,134,12,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,208,26,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,192,28,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,120,23,0,0,220,33,0,0,158,17,0,0,80,27,0,0,120,13,0,0,134,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,126,8,0,0,204,10,0,0,204,10,0,0,204,10,0,0,204,10,0,0,204,10,0,0,204,10,0,0,204,10,0,0,226,5,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,226,28,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,16,10,0,0,134,24,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,2,14,0,0,108,31,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,68,26,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,38,31,0,0,154,32,0,0,144,31,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,194,16,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,198,10,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,156,8,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,136,10,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,226,8,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,160,36,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,192,21,0,0,98,5,0,0,86,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,30,18,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,36,32,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,54,31,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,232,30,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,40,23,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,22,7,0,0,148,15,0,0,156,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,192,32,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,212,31,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,74,13,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,56,24,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,196,20,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,16,0,0,56,28,0,0,26,3,0,0,208,0,0,0,56,3,0,0,4,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,154,19,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,108,35,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,104,24,0,0,8,20,0,0,100,31,0,0,204,5,0,0,228,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0])
.concat([30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,98,9,0,0,154,1,0,0,72,10,0,0,94,31,0,0,250,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,70,15,0,0,54,3,0,0,64,20,0,0,130,12,0,0,120,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,218,12,0,0,154,10,0,0,0,27,0,0,250,14,0,0,110,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,248,10,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,120,15,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,6,31,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,166,10,0,0,82,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,210,7,0,0,10,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,10,8,0,0,252,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,72,29,0,0,68,2,0,0,158,9,0,0,214,14,0,0,204,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,154,19,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,108,35,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,104,24,0,0,8,20,0,0,100,31,0,0,204,5,0,0,228,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,98,9,0,0,154,1,0,0,72,10,0,0,94,31,0,0,250,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,70,15,0,0,54,3,0,0,64,20,0,0,130,12,0,0,120,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,218,12,0,0,154,10,0,0,0,27,0,0,250,14,0,0,110,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,248,10,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,120,15,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,6,31,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,166,10,0,0,82,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,210,7,0,0,10,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,10,8,0,0,252,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,72,29,0,0,68,2,0,0,158,9,0,0,214,14,0,0,204,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,154,19,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,108,35,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,104,24,0,0,8,20,0,0,100,31,0,0,204,5,0,0,228,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,98,9,0,0,154,1,0,0,72,10,0,0,94,31,0,0,250,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,70,15,0,0,54,3,0,0,64,20,0,0,130,12,0,0,120,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,218,12,0,0,154,10,0,0,0,27,0,0,250,14,0,0,110,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,248,10,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,120,15,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,6,31,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,166,10,0,0,82,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,210,7,0,0,10,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,10,8,0,0,252,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,72,29,0,0,68,2,0,0,158,9,0,0,214,14,0,0,204,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,154,19,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,108,35,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,104,24,0,0,8,20,0,0,100,31,0,0,204,5,0,0,228,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,98,9,0,0,154,1,0,0,72,10,0,0,94,31,0,0,250,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,70,15,0,0,54,3,0,0,64,20,0,0,130,12,0,0,120,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,218,12,0,0,154,10,0,0,0,27,0,0,250,14,0,0,110,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,248,10,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,120,15,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,6,31,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,166,10,0,0,82,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,210,7,0,0,10,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,10,8,0,0,252,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,72,29,0,0,68,2,0,0,158,9,0,0,214,14,0,0,204,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,154,19,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,108,35,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,104,24,0,0,8,20,0,0,100,31,0,0,204,5,0,0,228,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,98,9,0,0,154,1,0,0,72,10,0,0,94,31,0,0,250,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,70,15,0,0,54,3,0,0,64,20,0,0,130,12,0,0,120,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,218,12,0,0,154,10,0,0,0,27,0,0,250,14,0,0,110,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,248,10,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,120,15,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,6,31,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,166,10,0,0,82,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,210,7,0,0,10,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,10,8,0,0,252,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,72,29,0,0,68,2,0,0,158,9,0,0,214,14,0,0,204,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,154,19,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,108,35,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,104,24,0,0,8,20,0,0,100,31,0,0,204,5,0,0,228,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0])
.concat([30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,98,9,0,0,154,1,0,0,72,10,0,0,94,31,0,0,250,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,70,15,0,0,54,3,0,0,64,20,0,0,130,12,0,0,120,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,218,12,0,0,154,10,0,0,0,27,0,0,250,14,0,0,110,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,248,10,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,120,15,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,6,31,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,166,10,0,0,82,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,210,7,0,0,10,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,10,8,0,0,252,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,72,29,0,0,68,2,0,0,158,9,0,0,214,14,0,0,204,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,154,19,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,108,35,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,104,24,0,0,8,20,0,0,100,31,0,0,204,5,0,0,228,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,98,9,0,0,154,1,0,0,72,10,0,0,94,31,0,0,250,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,70,15,0,0,54,3,0,0,64,20,0,0,130,12,0,0,120,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,218,12,0,0,154,10,0,0,0,27,0,0,250,14,0,0,110,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,2,31,0,0,248,10,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,120,15,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,6,31,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,166,10,0,0,82,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,210,7,0,0,10,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,10,8,0,0,252,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,72,29,0,0,68,2,0,0,158,9,0,0,214,14,0,0,204,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,48,17,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,230,7,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,156,26,0,0,154,19,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,224,35,0,0,108,35,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,96,23,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,120,20,0,0,104,24,0,0,8,20,0,0,100,31,0,0,204,5,0,0,228,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,72,36,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,30,28,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,134,6,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,104,22,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,122,13,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,52,27,0,0,98,9,0,0,154,1,0,0,72,10,0,0,94,31,0,0,250,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,128,2,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,120,8,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,92,18,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,246,9,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,10,4,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,82,36,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,44,25,0,0,70,15,0,0,54,3,0,0,64,20,0,0,130,12,0,0,120,36,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,58,23,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,242,7,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,100,23,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,176,16,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,184,12,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,10,17,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,122,22,0,0,218,12,0,0,154,10,0,0,0,27,0,0,250,14,0,0,110,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,200,15,0,0,74,31,0,0,74,31,0,0,74,31,0,0,74,31,0,0,74,31,0,0,74,31,0,0,74,31,0,0,8,21,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,100,8,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,202,10,0,0,120,15,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,104,27,0,0,6,31,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,148,29,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,166,10,0,0,82,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,146,8,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,124,14,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,236,34,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,64,26,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,182,10,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,92,12,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,66,2,0,0,210,7,0,0,10,10,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,54,13,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,238,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,86,28,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,118,13,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,180,20,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,132,11,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,166,30,0,0,10,8,0,0,252,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,78,12,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,34,15,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,244,29,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,172,27,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,130,33,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,138,13,0,0,72,29,0,0,68,2,0,0,158,9,0,0,214,14,0,0,204,7,0,0,128,22,0,0,128,22,0,0,128,22,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,214,28,0,0,214,28,0,0,214,28,0,0,214,28,0,0,214,28,0,0,214,28,0,0,214,28,0,0,214,28,0,0,170,16,0,0,170,16,0,0,170,16,0,0,170,16,0,0,170,16,0,0,170,16,0,0,170,16,0,0,170,16,0,0,48,20,0,0,48,20,0,0,48,20,0,0,48,20,0,0,48,20,0,0,48,20,0,0,48,20,0,0,48,20,0,0,142,23,0,0,142,23,0,0,142,23,0,0,142,23,0,0,142,23,0,0,142,23,0,0,142,23,0,0,142,23,0,0,152,4,0,0,152,4,0,0,152,4,0,0,152,4,0,0,152,4,0,0,152,4,0,0,152,4,0,0,152,4,0,0,176,14,0,0,224,18,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,222,13,0,0,222,13,0,0,222,13,0,0,222,13,0,0,222,13,0,0,222,13,0,0,222,13,0,0,222,13,0,0,210,23,0,0,210,23,0,0,210,23,0,0,210,23,0,0,210,23,0,0,210,23,0,0,210,23,0,0,210,23,0,0,142,14,0,0,142,14,0,0,142,14,0,0,142,14,0,0,142,14,0,0,142,14,0,0,142,14,0,0,142,14,0,0,102,3,0,0,102,3,0,0,102,3,0,0,102,3,0,0,102,3,0,0,102,3,0,0,102,3,0,0,102,3,0,0,6,35,0,0,6,35,0,0,6,35,0,0,6,35,0,0,6,35,0,0,6,35,0,0,6,35,0,0,6,35,0,0,114,17,0,0,182,27,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,84,11,0,0,84,11,0,0,84,11,0,0,84,11,0,0,84,11,0,0,84,11,0,0,84,11,0,0,84,11,0,0,80,10,0,0,80,10,0,0,80,10,0,0,80,10,0,0,80,10,0,0,80,10,0,0,80,10,0,0,80,10,0,0,122,25,0,0,122,25,0,0,122,25,0,0,122,25,0,0,122,25,0,0,122,25,0,0,122,25,0,0,122,25,0,0,148,26,0,0,148,26,0,0,148,26,0,0,148,26,0,0,148,26,0,0,148,26,0,0,148,26,0,0,148,26,0,0,46,20,0,0,46,20,0,0,46,20,0,0,46,20,0,0,46,20,0,0,46,20,0,0,46,20,0,0,46,20,0,0,58,21,0,0,222,20,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,134,0,0,0,134,0,0,0,134,0,0,0,134,0,0,0,134,0,0,0,134,0,0,0,134,0,0,0,134,0,0,0,250,11,0,0,250,11,0,0,250,11,0,0,250,11,0,0,250,11,0,0,250,11,0,0,250,11,0,0,250,11,0,0,82,8,0,0,82,8,0,0,82,8,0,0,82,8,0,0,82,8,0,0,82,8,0,0,82,8,0,0,82,8,0,0,112,24,0,0,112,24,0,0,112,24,0,0,112,24,0,0,112,24,0,0,112,24,0,0,112,24,0,0,112,24,0,0,174,31,0,0,174,31,0,0,174,31,0,0,174,31,0,0,174,31,0,0,174,31,0,0,174,31,0,0,174,31,0,0,60,15,0,0,154,4,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0])
.concat([72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,180,34,0,0,180,34,0,0,180,34,0,0,180,34,0,0,180,34,0,0,180,34,0,0,180,34,0,0,180,34,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,106,34,0,0,106,34,0,0,106,34,0,0,106,34,0,0,106,34,0,0,106,34,0,0,106,34,0,0,106,34,0,0,202,16,0,0,202,16,0,0,202,16,0,0,202,16,0,0,202,16,0,0,202,16,0,0,202,16,0,0,202,16,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,34,0,0,48,15,0,0,242,2,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,228,35,0,0,228,35,0,0,228,35,0,0,228,35,0,0,228,35,0,0,228,35,0,0,228,35,0,0,228,35,0,0,138,33,0,0,138,33,0,0,138,33,0,0,138,33,0,0,138,33,0,0,138,33,0,0,138,33,0,0,138,33,0,0,178,18,0,0,178,18,0,0,178,18,0,0,178,18,0,0,178,18,0,0,178,18,0,0,178,18,0,0,178,18,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,168,35,0,0,222,26,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,180,9,0,0,180,9,0,0,180,9,0,0,180,9,0,0,180,9,0,0,180,9,0,0,180,9,0,0,180,9,0,0,34,29,0,0,34,29,0,0,34,29,0,0,34,29,0,0,34,29,0,0,34,29,0,0,34,29,0,0,34,29,0,0,192,26,0,0,192,26,0,0,192,26,0,0,192,26,0,0,192,26,0,0,192,26,0,0,192,26,0,0,192,26,0,0,80,2,0,0,80,2,0,0,80,2,0,0,80,2,0,0,80,2,0,0,80,2,0,0,80,2,0,0,80,2,0,0,116,23,0,0,116,23,0,0,116,23,0,0,116,23,0,0,116,23,0,0,116,23,0,0,116,23,0,0,116,23,0,0,150,29,0,0,4,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,216,4,0,0,216,4,0,0,216,4,0,0,216,4,0,0,216,4,0,0,216,4,0,0,216,4,0,0,216,4,0,0,124,0,0,0,124,0,0,0,124,0,0,0,124,0,0,0,124,0,0,0,124,0,0,0,124,0,0,0,124,0,0,0,76,14,0,0,76,14,0,0,76,14,0,0,76,14,0,0,76,14,0,0,76,14,0,0,76,14,0,0,76,14,0,0,130,9,0,0,130,9,0,0,130,9,0,0,130,9,0,0,130,9,0,0,130,9,0,0,130,9,0,0,130,9,0,0,8,24,0,0,8,24,0,0,8,24,0,0,8,24,0,0,8,24,0,0,8,24,0,0,8,24,0,0,8,24,0,0,0,13,0,0,116,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,210,25,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,214,1,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,182,15,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,52,22,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,172,0,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,10,11,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,82,15,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,120,27,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,26,32,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0,84,34,0,0])
.concat([72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,72,6,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,98,12,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,170,18,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,126,0,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,160,34,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,166,11,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,210,36,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,90,24,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,18,11,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,252,19,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,226,25,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,2,35,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,52,24,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,58,0,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,66,28,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,26,7,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,82,14,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,44,8,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,196,35,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,208,22,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,30,34,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,64,3,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,78,5,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,160,19,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,94,18,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,130,26,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,8,1,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,146,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,208,34,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,238,2,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,242,32,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,138,36,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,230,2,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,92,10,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,182,7,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,46,13,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,136,34,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,128,22,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0])
.concat([224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,224,16,0,0,230,23,0,0,230,23,0,0,230,23,0,0,230,23,0,0,230,23,0,0,230,23,0,0,230,23,0,0,230,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,114,23,0,0,114,23,0,0,114,23,0,0,114,23,0,0,114,23,0,0,114,23,0,0,114,23,0,0,114,23,0,0,136,24,0,0,136,24,0,0,136,24,0,0,136,24,0,0,136,24,0,0,136,24,0,0,136,24,0,0,212,14,0,0,46,1,0,0,46,1,0,0,46,1,0,0,46,1,0,0,46,1,0,0,46,1,0,0,46,1,0,0,54,5,0,0,218,9,0,0,218,9,0,0,218,9,0,0,218,9,0,0,218,9,0,0,218,9,0,0,218,9,0,0,218,9,0,0,234,1,0,0,234,1,0,0,234,1,0,0,234,1,0,0,234,1,0,0,234,1,0,0,234,1,0,0,234,1,0,0,66,23,0,0,238,30,0,0,206,0,0,0,206,0,0,0,114,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,26,0,0,178,26,0,0,178,26,0,0,178,26,0,0,178,26,0,0,178,26,0,0,178,26,0,0,178,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,232,8,0,0,232,8,0,0,232,8,0,0,232,8,0,0,232,8,0,0,232,8,0,0,232,8,0,0,232,8,0,0,234,22,0,0,234,22,0,0,234,22,0,0,234,22,0,0,234,22,0,0,234,22,0,0,234,22,0,0,234,22,0,0,162,6,0,0,162,6,0,0,162,6,0,0,162,6,0,0,162,6,0,0,162,6,0,0,162,6,0,0,162,6,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,168,29,0,0,168,29,0,0,168,29,0,0,168,29,0,0,168,29,0,0,168,29,0,0,168,29,0,0,168,29,0,0,210,8,0,0,238,8,0,0,206,0,0,0,206,0,0,0,134,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,116,17,0,0,116,17,0,0,116,17,0,0,116,17,0,0,116,17,0,0,116,17,0,0,116,17,0,0,116,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,27,0,0,18,27,0,0,18,27,0,0,18,27,0,0,18,27,0,0,18,27,0,0,18,27,0,0,18,27,0,0,98,35,0,0,98,35,0,0,98,35,0,0,98,35,0,0,98,35,0,0,98,35,0,0,98,35,0,0,98,35,0,0,144,23,0,0,144,23,0,0,144,23,0,0,144,23,0,0,144,23,0,0,144,23,0,0,144,23,0,0,144,23,0,0,168,32,0,0,168,32,0,0,168,32,0,0,168,32,0,0,168,32,0,0,168,32,0,0,168,32,0,0,168,32,0,0,8,7,0,0,8,7,0,0,8,7,0,0,8,7,0,0,8,7,0,0,8,7,0,0,8,7,0,0,8,7,0,0,234,27,0,0,206,27,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,26,23,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,176,23,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,20,0,0,114,14,0,0,42,0,0,0,88,24,0,0,92,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,12,35,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,8,11,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,26,31,0,0,32,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,36,1,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,102,8,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,54,1,0,0,76,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,34,25,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,216,33,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,242,10,0,0,226,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,108,13,0,0,108,13,0,0,108,13,0,0,108,13,0,0,108,13,0,0,108,13,0,0,108,13,0,0,108,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,122,17,0,0,122,17,0,0,122,17,0,0,122,17,0,0,122,17,0,0,122,17,0,0,122,17,0,0,122,17,0,0,160,10,0,0,160,10,0,0,160,10,0,0,160,10,0,0,160,10,0,0,160,10,0,0,160,10,0,0,58,26,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,118,23,0,0,4,26,0,0,4,26,0,0,4,26,0,0,4,26,0,0,4,26,0,0,4,26,0,0,4,26,0,0,4,26,0,0,186,28,0,0,186,28,0,0,186,28,0,0,186,28,0,0,186,28,0,0,186,28,0,0,186,28,0,0,186,28,0,0,150,17,0,0,128,17,0,0,206,0,0,0,206,0,0,0,116,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,11,0,0,224,11,0,0,224,11,0,0,224,11,0,0,224,11,0,0,224,11,0,0,224,11,0,0,224,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0])
.concat([72,31,0,0,72,31,0,0,72,31,0,0,72,31,0,0,72,31,0,0,72,31,0,0,72,31,0,0,72,31,0,0,80,34,0,0,80,34,0,0,80,34,0,0,80,34,0,0,80,34,0,0,80,34,0,0,80,34,0,0,80,34,0,0,248,6,0,0,248,6,0,0,248,6,0,0,248,6,0,0,248,6,0,0,248,6,0,0,248,6,0,0,248,6,0,0,98,27,0,0,98,27,0,0,98,27,0,0,98,27,0,0,98,27,0,0,98,27,0,0,98,27,0,0,98,27,0,0,226,29,0,0,226,29,0,0,226,29,0,0,226,29,0,0,226,29,0,0,226,29,0,0,226,29,0,0,226,29,0,0,96,20,0,0,86,9,0,0,206,0,0,0,206,0,0,0,100,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,102,4,0,0,102,4,0,0,102,4,0,0,102,4,0,0,102,4,0,0,102,4,0,0,102,4,0,0,102,4,0,0,184,11,0,0,184,11,0,0,184,11,0,0,184,11,0,0,184,11,0,0,184,11,0,0,184,11,0,0,184,11,0,0,32,2,0,0,32,2,0,0,32,2,0,0,32,2,0,0,32,2,0,0,32,2,0,0,32,2,0,0,32,2,0,0,194,32,0,0,194,32,0,0,194,32,0,0,194,32,0,0,194,32,0,0,194,32,0,0,194,32,0,0,194,32,0,0,58,13,0,0,58,13,0,0,58,13,0,0,58,13,0,0,58,13,0,0,58,13,0,0,58,13,0,0,58,13,0,0,106,4,0,0,96,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,26,23,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,176,23,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,20,0,0,114,14,0,0,42,0,0,0,88,24,0,0,92,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,12,35,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,8,11,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,26,31,0,0,32,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,36,1,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,102,8,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,54,1,0,0,76,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,34,25,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,216,33,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,242,10,0,0,226,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,26,0,0,198,26,0,0,198,26,0,0,198,26,0,0,198,26,0,0,198,26,0,0,198,26,0,0,198,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,4,30,0,0,4,30,0,0,4,30,0,0,4,30,0,0,4,30,0,0,4,30,0,0,4,30,0,0,4,30,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,124,25,0,0,236,0,0,0,236,0,0,0,236,0,0,0,236,0,0,0,236,0,0,0,236,0,0,0,236,0,0,0,166,22,0,0,136,13,0,0,136,13,0,0,136,13,0,0,136,13,0,0,136,13,0,0,136,13,0,0,136,13,0,0,136,13,0,0,160,13,0,0,160,13,0,0,160,13,0,0,160,13,0,0,160,13,0,0,160,13,0,0,160,13,0,0,160,13,0,0,128,27,0,0,0,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,31,0,0,110,31,0,0,110,31,0,0,110,31,0,0,110,31,0,0,110,31,0,0,110,31,0,0,110,31,0,0,226,4,0,0,226,4,0,0,226,4,0,0,226,4,0,0,226,4,0,0,226,4,0,0,226,4,0,0,226,4,0,0,32,11,0,0,32,11,0,0,32,11,0,0,32,11,0,0,32,11,0,0,32,11,0,0,32,11,0,0,32,11,0,0,146,17,0,0,146,17,0,0,146,17,0,0,146,17,0,0,146,17,0,0,146,17,0,0,146,17,0,0,146,17,0,0,204,14,0,0,204,14,0,0,204,14,0,0,204,14,0,0,204,14,0,0,204,14,0,0,204,14,0,0,204,14,0,0,100,0,0,0,104,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,74,8,0,0,74,8,0,0,74,8,0,0,74,8,0,0,74,8,0,0,74,8,0,0,74,8,0,0,74,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,210,28,0,0,210,28,0,0,210,28,0,0,210,28,0,0,210,28,0,0,210,28,0,0,210,28,0,0,210,28,0,0,52,31,0,0,52,31,0,0,52,31,0,0,52,31,0,0,52,31,0,0,52,31,0,0,52,31,0,0,52,31,0,0,128,31,0,0,128,31,0,0,128,31,0,0,128,31,0,0,128,31,0,0,128,31,0,0,128,31,0,0,128,31,0,0,46,16,0,0,46,16,0,0,46,16,0,0,46,16,0,0,46,16,0,0,46,16,0,0,46,16,0,0,46,16,0,0,90,13,0,0,90,13,0,0,90,13,0,0,90,13,0,0,90,13,0,0,90,13,0,0,90,13,0,0,90,13,0,0,200,28,0,0,204,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,26,23,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,176,23,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,20,0,0,114,14,0,0,42,0,0,0,88,24,0,0,92,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,12,35,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,8,11,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,26,31,0,0,32,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,36,1,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,102,8,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,54,1,0,0,76,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,34,25,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,216,33,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,242,10,0,0,226,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,248,28,0,0,248,28,0,0,248,28,0,0,248,28,0,0,248,28,0,0,248,28,0,0,248,28,0,0,248,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,120,34,0,0,120,34,0,0,120,34,0,0,120,34,0,0,120,34,0,0,120,34,0,0,120,34,0,0,120,34,0,0,16,17,0,0,16,17,0,0,16,17,0,0,16,17,0,0,16,17,0,0,16,17,0,0,16,17,0,0,196,25,0,0,150,32,0,0,150,32,0,0,150,32,0,0,150,32,0,0,150,32,0,0,150,32,0,0,150,32,0,0,144,21,0,0,154,0,0,0,154,0,0,0,154,0,0,0,154,0,0,0,154,0,0,0,154,0,0,0,154,0,0,0,154,0,0,0,152,13,0,0,152,13,0,0,152,13,0,0,152,13,0,0,152,13,0,0,152,13,0,0,152,13,0,0,152,13,0,0,18,30,0,0,32,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,66,14,0,0,66,14,0,0,66,14,0,0,66,14,0,0,66,14,0,0,66,14,0,0,66,14,0,0,66,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,6,11,0,0,6,11,0,0,6,11,0,0,6,11,0,0,6,11,0,0,6,11,0,0,6,11,0,0,6,11,0,0,92,2,0,0,92,2,0,0,92,2,0,0,92,2,0,0,92,2,0,0,92,2,0,0,92,2,0,0,92,2,0,0,64,13,0,0,64,13,0,0,64,13,0,0,64,13,0,0,64,13,0,0,64,13,0,0,64,13,0,0,64,13,0,0,6,33,0,0,6,33,0,0,6,33,0,0,6,33,0,0,6,33,0,0,6,33,0,0,6,33,0,0,6,33,0,0,28,25,0,0,28,25,0,0,28,25,0,0,28,25,0,0,28,25,0,0,28,25,0,0,28,25,0,0,28,25,0,0,154,3,0,0,132,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,35,0,0,140,35,0,0,140,35,0,0,140,35,0,0,140,35,0,0,140,35,0,0,140,35,0,0,140,35,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,134,1,0,0,134,1,0,0,134,1,0,0,134,1,0,0,134,1,0,0,134,1,0,0,134,1,0,0,134,1,0,0,182,8,0,0,182,8,0,0,182,8,0,0,182,8,0,0,182,8,0,0,182,8,0,0,182,8,0,0,182,8,0,0,192,8,0,0,192,8,0,0,192,8,0,0,192,8,0,0,192,8,0,0,192,8,0,0,192,8,0,0,192,8,0,0,118,14,0,0,118,14,0,0,118,14,0,0,118,14,0,0,118,14,0,0,118,14,0,0,118,14,0,0,118,14,0,0,218,21,0,0,218,21,0,0,218,21,0,0,218,21,0,0,218,21,0,0,218,21,0,0,218,21,0,0,218,21,0,0,136,7,0,0,130,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,26,23,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,176,23,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,20,0,0,114,14,0,0,42,0,0,0,88,24,0,0,92,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,12,35,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,8,11,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,26,31,0,0,32,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,36,1,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,102,8,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,54,1,0,0,76,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,34,25,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,216,33,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,242,10,0,0,226,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,25,0,0,38,25,0,0,38,25,0,0,38,25,0,0,38,25,0,0,38,25,0,0,38,25,0,0,38,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,204,9,0,0,204,9,0,0,204,9,0,0,204,9,0,0,204,9,0,0,204,9,0,0,204,9,0,0,204,9,0,0,146,32,0,0,146,32,0,0,146,32,0,0,146,32,0,0,146,32,0,0,146,32,0,0,146,32,0,0,80,6,0,0,172,23,0,0,172,23,0,0,172,23,0,0,172,23,0,0,172,23,0,0,172,23,0,0,172,23,0,0,4,14,0,0,154,18,0,0,154,18,0,0,154,18,0,0,154,18,0,0,154,18,0,0,154,18,0,0,154,18,0,0,154,18,0,0,14,34,0,0,14,34,0,0,14,34,0,0,14,34,0,0,14,34,0,0,14,34,0,0,14,34,0,0,14,34,0,0,40,26,0,0,22,26,0,0,12,22,0,0,222,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,35,0,0,34,35,0,0,34,35,0,0,34,35,0,0,34,35,0,0,34,35,0,0,34,35,0,0,34,35,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,144,8,0,0,144,8,0,0,144,8,0,0,144,8,0,0,144,8,0,0,144,8,0,0,144,8,0,0,144,8,0,0,106,13,0,0,106,13,0,0,106,13,0,0,106,13,0,0,106,13,0,0,106,13,0,0,106,13,0,0,72,0,0,0,70,1,0,0,70,1,0,0,70,1,0,0,70,1,0,0,70,1,0,0,70,1,0,0,70,1,0,0,164,3,0,0,62,33,0,0,62,33,0,0,62,33,0,0,62,33,0,0,62,33,0,0,62,33,0,0,62,33,0,0,62,33,0,0,118,3,0,0,118,3,0,0,118,3,0,0,118,3,0,0,118,3,0,0,118,3,0,0,118,3,0,0,118,3,0,0,106,20,0,0,150,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,98,32,0,0,98,32,0,0,98,32,0,0,98,32,0,0,98,32,0,0,98,32,0,0,98,32,0,0,98,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,6,0,0,104,6,0,0,104,6,0,0,104,6,0,0,104,6,0,0,104,6,0,0,104,6,0,0,104,6,0,0,188,13,0,0,188,13,0,0,188,13,0,0,188,13,0,0,188,13,0,0,188,13,0,0,188,13,0,0,44,23,0,0,62,32,0,0,62,32,0,0,62,32,0,0,62,32,0,0,62,32,0,0,62,32,0,0,62,32,0,0,244,13,0,0,16,35,0,0,16,35,0,0,16,35,0,0,16,35,0,0,16,35,0,0,16,35,0,0,16,35,0,0,16,35,0,0,60,3,0,0,60,3,0,0,60,3,0,0,60,3,0,0,60,3,0,0,60,3,0,0,60,3,0,0,60,3,0,0,78,6,0,0,106,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,186,7,0,0,186,7,0,0,186,7,0,0,186,7,0,0,186,7,0,0,186,7,0,0,186,7,0,0,186,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,214,15,0,0,214,15,0,0,214,15,0,0,214,15,0,0,214,15,0,0,214,15,0,0,214,15,0,0,214,15,0,0,140,9,0,0,140,9,0,0,140,9,0,0,140,9,0,0,140,9,0,0,140,9,0,0,140,9,0,0,126,32,0,0,152,9,0,0,152,9,0,0,152,9,0,0,152,9,0,0,152,9,0,0,152,9,0,0,152,9,0,0,156,3,0,0,212,3,0,0,212,3,0,0,212,3,0,0,212,3,0,0,212,3,0,0,212,3,0,0,212,3,0,0,212,3,0,0,246,30,0,0,246,30,0,0,246,30,0,0,246,30,0,0,246,30,0,0,246,30,0,0,246,30,0,0,246,30,0,0,240,15,0,0,222,15,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,26,23,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,176,23,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,20,0,0,114,14,0,0,42,0,0,0,88,24,0,0,92,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,12,35,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,8,11,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,26,31,0,0,32,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,36,1,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,102,8,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,54,1,0,0,76,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,34,25,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,216,33,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,242,10,0,0,226,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,252,23,0,0,252,23,0,0,252,23,0,0,252,23,0,0,252,23,0,0,252,23,0,0,252,23,0,0,252,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,14,0,0,112,14,0,0,112,14,0,0,112,14,0,0,112,14,0,0,112,14,0,0,112,14,0,0,112,14,0,0,42,22,0,0,42,22,0,0,42,22,0,0,42,22,0,0,42,22,0,0,42,22,0,0,42,22,0,0,16,15,0,0,20,22,0,0,20,22,0,0,20,22,0,0,20,22,0,0,20,22,0,0,20,22,0,0,20,22,0,0,106,29,0,0,40,10,0,0,40,10,0,0,40,10,0,0,40,10,0,0,40,10,0,0,40,10,0,0,40,10,0,0,40,10,0,0,82,35,0,0,82,35,0,0,82,35,0,0,82,35,0,0,82,35,0,0,82,35,0,0,82,35,0,0,82,35,0,0,134,14,0,0,116,14,0,0,206,0,0,0,206,0,0,0,88,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,122,8,0,0,122,8,0,0,122,8,0,0,122,8,0,0,122,8,0,0,122,8,0,0,122,8,0,0,122,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,112,19,0,0,112,19,0,0,112,19,0,0,112,19,0,0,112,19,0,0,112,19,0,0,112,19,0,0,112,19,0,0,110,32,0,0,110,32,0,0,110,32,0,0,110,32,0,0,110,32,0,0,110,32,0,0,110,32,0,0,110,32,0,0,116,25,0,0,116,25,0,0,116,25,0,0,116,25,0,0,116,25,0,0,116,25,0,0,116,25,0,0,116,25,0,0,134,33,0,0,134,33,0,0,134,33,0,0,134,33,0,0,134,33,0,0,134,33,0,0,134,33,0,0,134,33,0,0,238,16,0,0,4,17,0,0,206,0,0,0,206,0,0,0,190,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,14,0,0,182,14,0,0,182,14,0,0,182,14,0,0,182,14,0,0,182,14,0,0,182,14,0,0,182,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,200,26,0,0,200,26,0,0,200,26,0,0,200,26,0,0,200,26,0,0,200,26,0,0,200,26,0,0,200,26,0,0,180,12,0,0,180,12,0,0,180,12,0,0,180,12,0,0,180,12,0,0,180,12,0,0,180,12,0,0,180,12,0,0,178,12,0,0,178,12,0,0,178,12,0,0,178,12,0,0,178,12,0,0,178,12,0,0,178,12,0,0,178,12,0,0,160,18,0,0,160,18,0,0,160,18,0,0,160,18,0,0,160,18,0,0,160,18,0,0,160,18,0,0,160,18,0,0,94,3,0,0,94,3,0,0,94,3,0,0,94,3,0,0,94,3,0,0,94,3,0,0,94,3,0,0,94,3,0,0,66,26,0,0,106,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,26,23,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,176,23,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,20,0,0,114,14,0,0,42,0,0,0,88,24,0,0,92,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,12,35,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,8,11,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,26,31,0,0,32,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,36,1,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,102,8,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,54,1,0,0,76,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,34,25,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,216,33,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,242,10,0,0,226,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,248,12,0,0,248,12,0,0,248,12,0,0,248,12,0,0,248,12,0,0,248,12,0,0,248,12,0,0,248,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,232,9,0,0,232,9,0,0,232,9,0,0,232,9,0,0,232,9,0,0,232,9,0,0,232,9,0,0,232,9,0,0,132,15,0,0,132,15,0,0,132,15,0,0,132,15,0,0,132,15,0,0,132,15,0,0,132,15,0,0,222,34,0,0,138,15,0,0,138,15,0,0,138,15,0,0,138,15,0,0,138,15,0,0,138,15,0,0,138,15,0,0,26,11,0,0,160,9,0,0,160,9,0,0,160,9,0,0,160,9,0,0,160,9,0,0,160,9,0,0,160,9,0,0,160,9,0,0,44,2,0,0,44,2,0,0,44,2,0,0,44,2,0,0,44,2,0,0,44,2,0,0,44,2,0,0,44,2,0,0,228,17,0,0,200,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,218,20,0,0,218,20,0,0,218,20,0,0,218,20,0,0,218,20,0,0,218,20,0,0,218,20,0,0,218,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0])
.concat([164,10,0,0,164,10,0,0,164,10,0,0,164,10,0,0,164,10,0,0,164,10,0,0,164,10,0,0,164,10,0,0,230,11,0,0,230,11,0,0,230,11,0,0,230,11,0,0,230,11,0,0,230,11,0,0,230,11,0,0,230,11,0,0,154,2,0,0,154,2,0,0,154,2,0,0,154,2,0,0,154,2,0,0,154,2,0,0,154,2,0,0,154,2,0,0,182,17,0,0,182,17,0,0,182,17,0,0,182,17,0,0,182,17,0,0,182,17,0,0,182,17,0,0,182,17,0,0,142,31,0,0,142,31,0,0,142,31,0,0,142,31,0,0,142,31,0,0,142,31,0,0,142,31,0,0,142,31,0,0,150,10,0,0,146,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,16,11,0,0,16,11,0,0,16,11,0,0,16,11,0,0,16,11,0,0,16,11,0,0,16,11,0,0,16,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,20,7,0,0,20,7,0,0,20,7,0,0,20,7,0,0,20,7,0,0,20,7,0,0,20,7,0,0,20,7,0,0,142,9,0,0,142,9,0,0,142,9,0,0,142,9,0,0,142,9,0,0,142,9,0,0,142,9,0,0,142,9,0,0,148,9,0,0,148,9,0,0,148,9,0,0,148,9,0,0,148,9,0,0,148,9,0,0,148,9,0,0,148,9,0,0,6,14,0,0,6,14,0,0,6,14,0,0,6,14,0,0,6,14,0,0,6,14,0,0,6,14,0,0,6,14,0,0,68,23,0,0,68,23,0,0,68,23,0,0,68,23,0,0,68,23,0,0,68,23,0,0,68,23,0,0,68,23,0,0,2,7,0,0,24,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,26,23,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,176,23,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,20,0,0,114,14,0,0,42,0,0,0,88,24,0,0,92,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,12,35,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,8,11,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,26,31,0,0,32,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,36,1,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,102,8,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,54,1,0,0,76,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,34,25,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,216,33,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,242,10,0,0,226,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,146,9,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,194,18,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,78,14,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,12,13,0,0,26,23,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,20,13,0,0,176,23,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,66,8,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,20,0,0,114,14,0,0,42,0,0,0,88,24,0,0,92,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,46,22,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,136,21,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,28,31,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,16,2,0,0,12,35,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,30,2,0,0,8,11,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,202,23,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,192,15,0,0,26,31,0,0,32,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,250,18,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,46,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,36,7,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,162,3,0,0,36,1,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,178,3,0,0,102,8,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,204,31,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,162,22,0,0,54,1,0,0,76,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,146,6,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,132,35,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,248,15,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,118,8,0,0,34,25,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,86,15,0,0,216,33,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,8,4,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,56,27,0,0,242,10,0,0,226,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,78,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,244,27,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,234,8,0,0,202,8,0,0,118,17,0,0,126,4,0,0,60,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,176,5,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,172,15,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,166,25,0,0,40,7,0,0,16,26,0,0,166,2,0,0,154,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,192,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,216,26,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,12,24,0,0,188,2,0,0,174,2,0,0,252,21,0,0,152,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,188,20,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,52,35,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,24,26,0,0,38,26,0,0,90,18,0,0,118,26,0,0,38,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,132,16,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,52,3,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,50,31,0,0,68,5,0,0,26,21,0,0,240,13,0,0,244,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,174,22,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,50,25,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,178,34,0,0,24,34,0,0,84,9,0,0,76,4,0,0,172,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,148,22,0,0,148,22,0,0,148,22,0,0,148,22,0,0,148,22,0,0,148,22,0,0,148,22,0,0,148,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,248,13,0,0,248,13,0,0,248,13,0,0,248,13,0,0,248,13,0,0,248,13,0,0,248,13,0,0,248,13,0,0,88,15,0,0,88,15,0,0,88,15,0,0,88,15,0,0,88,15,0,0,88,15,0,0,88,15,0,0,58,11,0,0,62,19,0,0,62,19,0,0,62,19,0,0,62,19,0,0,62,19,0,0,62,19,0,0,62,19,0,0,186,14,0,0,64,21,0,0,64,21,0,0,64,21,0,0,64,21,0,0,64,21,0,0,64,21,0,0,64,21,0,0,64,21,0,0,254,34,0,0,254,34,0,0,254,34,0,0,254,34,0,0,254,34,0,0,254,34,0,0,254,34,0,0,254,34,0,0,216,13,0,0,242,13,0,0,248,30,0,0,208,33,0,0,130,24,0,0,206,0,0,0,206,0,0,0,206,0,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,78,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,244,27,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,234,8,0,0,202,8,0,0,118,17,0,0,126,4,0,0,60,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,176,5,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,172,15,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,166,25,0,0,40,7,0,0,16,26,0,0,166,2,0,0,154,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,192,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,216,26,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,12,24,0,0,188,2,0,0,174,2,0,0,252,21,0,0,152,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,188,20,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,52,35,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,24,26,0,0,38,26,0,0,90,18,0,0,118,26,0,0,38,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,132,16,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,52,3,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,50,31,0,0,68,5,0,0,26,21,0,0,240,13,0,0,244,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,174,22,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,50,25,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,178,34,0,0,24,34,0,0,84,9,0,0,76,4,0,0,172,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,11,0,0,88,11,0,0,88,11,0,0,88,11,0,0,88,11,0,0,88,11,0,0,88,11,0,0,88,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,248,18,0,0,248,18,0,0,248,18,0,0,248,18,0,0,248,18,0,0,248,18,0,0,248,18,0,0,248,18,0,0,154,16,0,0,154,16,0,0,154,16,0,0,154,16,0,0,154,16,0,0,154,16,0,0,154,16,0,0,8,33,0,0,162,16,0,0,162,16,0,0,162,16,0,0,162,16,0,0,162,16,0,0,162,16,0,0,162,16,0,0,34,9,0,0,20,29,0,0,20,29,0,0,20,29,0,0,20,29,0,0,20,29,0,0,20,29,0,0,20,29,0,0,20,29,0,0,96,35,0,0,96,35,0,0,96,35,0,0,96,35,0,0,96,35,0,0,96,35,0,0,96,35,0,0,96,35,0,0,12,19,0,0,246,18,0,0,216,21,0,0,192,29,0,0,2,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,78,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,244,27,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,234,8,0,0,202,8,0,0,118,17,0,0,126,4,0,0,60,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,176,5,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,172,15,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,166,25,0,0,40,7,0,0,16,26,0,0,166,2,0,0,154,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,192,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,216,26,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,12,24,0,0,188,2,0,0,174,2,0,0,252,21,0,0,152,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,188,20,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,52,35,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,24,26,0,0,38,26,0,0,90,18,0,0,118,26,0,0,38,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,132,16,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,52,3,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,50,31,0,0,68,5,0,0,26,21,0,0,240,13,0,0,244,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,174,22,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,50,25,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,178,34,0,0,24,34,0,0,84,9,0,0,76,4,0,0,172,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,78,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,244,27,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,234,8,0,0,202,8,0,0,118,17,0,0,126,4,0,0,60,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0])
.concat([206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,176,5,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,172,15,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,166,25,0,0,40,7,0,0,16,26,0,0,166,2,0,0,154,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,192,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,216,26,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,12,24,0,0,188,2,0,0,174,2,0,0,252,21,0,0,152,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,188,20,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,52,35,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,24,26,0,0,38,26,0,0,90,18,0,0,118,26,0,0,38,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,132,16,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,52,3,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,50,31,0,0,68,5,0,0,26,21,0,0,240,13,0,0,244,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,174,22,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,50,25,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,178,34,0,0,24,34,0,0,84,9,0,0,76,4,0,0,172,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,78,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,244,27,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,234,8,0,0,202,8,0,0,118,17,0,0,126,4,0,0,60,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,176,5,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,172,15,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,166,25,0,0,40,7,0,0,16,26,0,0,166,2,0,0,154,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,192,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,216,26,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,12,24,0,0,188,2,0,0,174,2,0,0,252,21,0,0,152,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,188,20,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,52,35,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,24,26,0,0,38,26,0,0,90,18,0,0,118,26,0,0,38,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,132,16,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,52,3,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,50,31,0,0,68,5,0,0,26,21,0,0,240,13,0,0,244,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,174,22,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,50,25,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,178,34,0,0,24,34,0,0,84,9,0,0,76,4,0,0,172,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,78,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,244,27,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,234,8,0,0,202,8,0,0,118,17,0,0,126,4,0,0,60,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,176,5,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,172,15,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,166,25,0,0,40,7,0,0,16,26,0,0,166,2,0,0,154,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,192,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,216,26,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,12,24,0,0,188,2,0,0,174,2,0,0,252,21,0,0,152,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,188,20,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,52,35,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,24,26,0,0,38,26,0,0,90,18,0,0,118,26,0,0,38,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,132,16,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,52,3,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,50,31,0,0,68,5,0,0,26,21,0,0,240,13,0,0,244,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,174,22,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,50,25,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,178,34,0,0,24,34,0,0,84,9,0,0,76,4,0,0,172,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,78,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,244,27,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,234,8,0,0,202,8,0,0,118,17,0,0,126,4,0,0,60,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,176,5,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,172,15,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,166,25,0,0,40,7,0,0,16,26,0,0,166,2,0,0,154,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,58,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,140,20,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,26,33,0,0,192,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,230,31,0,0,216,26,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,2,8,0,0,12,24,0,0,188,2,0,0,174,2,0,0,252,21,0,0,152,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,32,26,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,224,34,0,0,188,20,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,140,24,0,0,52,35,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,140,12,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,188,9,0,0,24,26,0,0,38,26,0,0,90,18,0,0,118,26,0,0,38,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,132,16,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,52,3,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,50,31,0,0,68,5,0,0,26,21,0,0,240,13,0,0,244,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,174,22,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,50,25,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,178,34,0,0,24,34,0,0,84,9,0,0,76,4,0,0,172,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,206,8,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,244,10,0,0,78,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,252,8,0,0,244,27,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,244,15,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,174,20,0,0,234,8,0,0,202,8,0,0,118,17,0,0,126,4,0,0,60,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,172,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,252,10,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,68,11,0,0,176,5,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,106,36,0,0,172,15,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,220,32,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,48,4,0,0,166,25,0,0,40,7,0,0,16,26,0,0,166,2,0,0,154,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,58,8,0,0,58,8,0,0,58,8,0,0,58,8,0,0,58,8,0,0,58,8,0,0,58,8,0,0,58,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,248,35,0,0,248,35,0,0,248,35,0,0,248,35,0,0,248,35,0,0,248,35,0,0,248,35,0,0,248,35,0,0,20,8,0,0,20,8,0,0,20,8,0,0,20,8,0,0,20,8,0,0,20,8,0,0,20,8,0,0,210,22,0,0,14,8,0,0,14,8,0,0,14,8,0,0,14,8,0,0,14,8,0,0,14,8,0,0,14,8,0,0,42,16,0,0,236,13,0,0,236,13,0,0,236,13,0,0,236,13,0,0,236,13,0,0,236,13,0,0,236,13,0,0,236,13,0,0,112,26,0,0,112,26,0,0,112,26,0,0,112,26,0,0,112,26,0,0,112,26,0,0,112,26,0,0,112,26,0,0,198,5,0,0,208,5,0,0,18,14,0,0,72,2,0,0,110,36,0,0,206,0,0,0,206,0,0,0,206,0,0,0,66,21,0,0,66,21,0,0,66,21,0,0,66,21,0,0,66,21,0,0,66,21,0,0,66,21,0,0,66,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,204,36,0,0,204,36,0,0,204,36,0,0,204,36,0,0,204,36,0,0,204,36,0,0,204,36,0,0,204,36,0,0,108,34,0,0,108,34,0,0,108,34,0,0,108,34,0,0,108,34,0,0,108,34,0,0,108,34,0,0,78,30,0,0,70,0,0,0,70,0,0,0,70,0,0,0,70,0,0,0,70,0,0,0,70,0,0,0,70,0,0,0,10,27,0,0,170,22,0,0,170,22,0,0,170,22,0,0,170,22,0,0,170,22,0,0,170,22,0,0,170,22,0,0,170,22,0,0,194,14,0,0,194,14,0,0,194,14,0,0,194,14,0,0,194,14,0,0,194,14,0,0,194,14,0,0,194,14,0,0,192,36,0,0,200,36,0,0,62,20,0,0,50,33,0,0,64,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,8,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,60,5,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,156,12,0,0,132,16,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,150,12,0,0,52,3,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,104,8,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,48,21,0,0,50,31,0,0,68,5,0,0,26,21,0,0,240,13,0,0,244,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,182,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,246,33,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,254,18,0,0,174,22,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,240,18,0,0,50,25,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,100,12,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,210,27,0,0,178,34,0,0,24,34,0,0,84,9,0,0,76,4,0,0,172,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,210,33,0,0,84,18,0,0,116,2,0,0,60,11,0,0,106,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0])
.concat([84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,96,10,0,0,78,10,0,0,172,1,0,0,130,13,0,0,22,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,194,1,0,0,56,33,0,0,170,7,0,0,80,36,0,0,152,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,4,1,0,0,64,0,0,0,152,11,0,0,22,10,0,0,96,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,8,26,0,0,186,23,0,0,78,19,0,0,72,24,0,0,108,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,102,16,0,0,122,16,0,0,104,26,0,0,96,27,0,0,202,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,194,33,0,0,68,22,0,0,132,28,0,0,176,10,0,0,234,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,17,0,0,254,17,0,0,254,17,0,0,254,17,0,0,254,17,0,0,254,17,0,0,254,17,0,0,254,17,0,0,4,18,0,0,4,18,0,0,4,18,0,0,4,18,0,0,4,18,0,0,4,18,0,0,4,18,0,0,4,18,0,0,230,19,0,0,230,19,0,0,230,19,0,0,230,19,0,0,230,19,0,0,230,19,0,0,230,19,0,0,230,19,0,0,176,31,0,0,176,31,0,0,176,31,0,0,176,31,0,0,176,31,0,0,176,31,0,0,176,31,0,0,176,31,0,0,184,31,0,0,184,31,0,0,184,31,0,0,184,31,0,0,184,31,0,0,184,31,0,0,184,31,0,0,184,31,0,0,126,10,0,0,126,10,0,0,126,10,0,0,126,10,0,0,126,10,0,0,126,10,0,0,126,10,0,0,126,10,0,0,44,13,0,0,44,13,0,0,44,13,0,0,44,13,0,0,44,13,0,0,44,13,0,0,44,13,0,0,44,13,0,0,240,33,0,0,188,19,0,0,226,33,0,0,120,0,0,0,248,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,210,33,0,0,84,18,0,0,116,2,0,0,60,11,0,0,106,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,96,10,0,0,78,10,0,0,172,1,0,0,130,13,0,0,22,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,194,1,0,0,56,33,0,0,170,7,0,0,80,36,0,0,152,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,4,1,0,0,64,0,0,0,152,11,0,0,22,10,0,0,96,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,8,26,0,0,186,23,0,0,78,19,0,0,72,24,0,0,108,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,102,16,0,0,122,16,0,0,104,26,0,0,96,27,0,0,202,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,194,33,0,0,68,22,0,0,132,28,0,0,176,10,0,0,234,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,94,0,0,0,94,0,0,0,94,0,0,0,94,0,0,0,94,0,0,0,94,0,0,0,94,0,0,0,94,0,0,0,90,0,0,0,90,0,0,0,90,0,0,0,90,0,0,0,90,0,0,0,90,0,0,0,90,0,0,0,90,0,0,0,10,1,0,0,10,1,0,0,10,1,0,0,10,1,0,0,10,1,0,0,10,1,0,0,10,1,0,0,10,1,0,0,126,3,0,0,126,3,0,0,126,3,0,0,126,3,0,0,126,3,0,0,126,3,0,0,126,3,0,0,126,3,0,0,114,3,0,0,114,3,0,0,114,3,0,0,114,3,0,0,114,3,0,0,114,3,0,0,114,3,0,0,114,3,0,0,46,2,0,0,46,2,0,0,46,2,0,0,46,2,0,0,46,2,0,0,46,2,0,0,46,2,0,0,46,2,0,0,88,21,0,0,88,21,0,0,88,21,0,0,88,21,0,0,88,21,0,0,88,21,0,0,88,21,0,0,88,21,0,0,24,1,0,0,14,1,0,0,136,26,0,0,8,35,0,0,98,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,210,33,0,0,84,18,0,0,116,2,0,0,60,11,0,0,106,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,96,10,0,0,78,10,0,0,172,1,0,0,130,13,0,0,22,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,194,1,0,0,56,33,0,0,170,7,0,0,80,36,0,0,152,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,4,1,0,0,64,0,0,0,152,11,0,0,22,10,0,0,96,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,8,26,0,0,186,23,0,0,78,19,0,0,72,24,0,0,108,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,102,16,0,0,122,16,0,0,104,26,0,0,96,27,0,0,202,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,194,33,0,0,68,22,0,0,132,28,0,0,176,10,0,0,234,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,210,33,0,0,84,18,0,0,116,2,0,0,60,11,0,0,106,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,96,10,0,0,78,10,0,0,172,1,0,0,130,13,0,0,22,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,194,1,0,0,56,33,0,0,170,7,0,0,80,36,0,0,152,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,4,1,0,0,64,0,0,0,152,11,0,0,22,10,0,0,96,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,8,26,0,0,186,23,0,0,78,19,0,0,72,24,0,0,108,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,102,16,0,0,122,16,0,0,104,26,0,0,96,27,0,0,202,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,194,33,0,0,68,22,0,0,132,28,0,0,176,10,0,0,234,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,210,33,0,0,84,18,0,0,116,2,0,0,60,11,0,0,106,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,96,10,0,0,78,10,0,0,172,1,0,0,130,13,0,0,22,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,194,1,0,0,56,33,0,0,170,7,0,0,80,36,0,0,152,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,4,1,0,0,64,0,0,0,152,11,0,0,22,10,0,0,96,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,8,26,0,0,186,23,0,0,78,19,0,0,72,24,0,0,108,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,102,16,0,0,122,16,0,0,104,26,0,0,96,27,0,0,202,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,194,33,0,0,68,22,0,0,132,28,0,0,176,10,0,0,234,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,210,33,0,0,84,18,0,0,116,2,0,0,60,11,0,0,106,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0])
.concat([84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,96,10,0,0,78,10,0,0,172,1,0,0,130,13,0,0,22,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,194,1,0,0,56,33,0,0,170,7,0,0,80,36,0,0,152,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,4,1,0,0,64,0,0,0,152,11,0,0,22,10,0,0,96,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,8,26,0,0,186,23,0,0,78,19,0,0,72,24,0,0,108,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,102,16,0,0,122,16,0,0,104,26,0,0,96,27,0,0,202,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,194,33,0,0,68,22,0,0,132,28,0,0,176,10,0,0,234,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,210,33,0,0,84,18,0,0,116,2,0,0,60,11,0,0,106,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,96,10,0,0,78,10,0,0,172,1,0,0,130,13,0,0,22,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,194,1,0,0,56,33,0,0,170,7,0,0,80,36,0,0,152,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,4,1,0,0,64,0,0,0,152,11,0,0,22,10,0,0,96,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,8,26,0,0,186,23,0,0,78,19,0,0,72,24,0,0,108,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,102,16,0,0,122,16,0,0,104,26,0,0,96,27,0,0,202,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,194,33,0,0,68,22,0,0,132,28,0,0,176,10,0,0,234,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,110,7,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,132,9,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,76,15,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,230,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,236,22,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,254,28,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,188,31,0,0,210,33,0,0,84,18,0,0,116,2,0,0,60,11,0,0,106,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,54,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,28,30,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,84,28,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,20,12,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,226,7,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,206,23,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,12,31,0,0,96,10,0,0,78,10,0,0,172,1,0,0,130,13,0,0,22,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,50,27,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,138,16,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,58,15,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,244,22,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,234,30,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,150,19,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,166,16,0,0,194,1,0,0,56,33,0,0,170,7,0,0,80,36,0,0,152,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,90,35,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,106,22,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,182,2,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,122,23,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,24,16,0,0,4,1,0,0,64,0,0,0,152,11,0,0,22,10,0,0,96,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,112,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,120,2,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,102,32,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,224,29,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,66,33,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,212,8,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,190,34,0,0,8,26,0,0,186,23,0,0,78,19,0,0,72,24,0,0,108,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,192,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,198,7,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,124,16,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,226,18,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,100,4,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,228,24,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,102,16,0,0,122,16,0,0,104,26,0,0,96,27,0,0,202,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,168,3,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,2,26,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,250,25,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,34,5,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,44,17,0,0,194,33,0,0,68,22,0,0,132,28,0,0,176,10,0,0,234,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,152,0,0,0,2,4,0,0,76,27,0,0,106,35,0,0,110,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,174,23,0,0,152,23,0,0,2,24,0,0,52,33,0,0,14,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,34,18,0,0,146,0,0,0,122,24,0,0,222,21,0,0,42,24,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,170,35,0,0,214,5,0,0,222,4,0,0,64,7,0,0,150,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,174,9,0,0,164,9,0,0,64,29,0,0,154,20,0,0,254,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,16,13,0,0,214,0,0,0,42,25,0,0,232,12,0,0,126,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,144,15,0,0,100,25,0,0,108,6,0,0,114,30,0,0,202,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,208,21,0,0,208,21,0,0,208,21,0,0,208,21,0,0,208,21,0,0,208,21,0,0,208,21,0,0,208,21,0,0,24,21,0,0,24,21,0,0,24,21,0,0,24,21,0,0,24,21,0,0,24,21,0,0,24,21,0,0,24,21,0,0,156,0,0,0,156,0,0,0,156,0,0,0,156,0,0,0,156,0,0,0,156,0,0,0,156,0,0,0,156,0,0,0,104,13,0,0,104,13,0,0,104,13,0,0,104,13,0,0,104,13,0,0,104,13,0,0,104,13,0,0,104,13,0,0,98,13,0,0,98,13,0,0,98,13,0,0,98,13,0,0,98,13,0,0,98,13,0,0,98,13,0,0,98,13,0,0,192,34,0,0,192,34,0,0,192,34,0,0,192,34,0,0,192,34,0,0,192,34,0,0,192,34,0,0,192,34,0,0,180,26,0,0,180,26,0,0,180,26,0,0,180,26,0,0,180,26,0,0,180,26,0,0,180,26,0,0,180,26,0,0,202,0,0,0,0,6,0,0,130,34,0,0,196,9,0,0,36,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,152,0,0,0,2,4,0,0,76,27,0,0,106,35,0,0,110,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,174,23,0,0,152,23,0,0,2,24,0,0,52,33,0,0,14,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,34,18,0,0,146,0,0,0,122,24,0,0,222,21,0,0,42,24,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,170,35,0,0,214,5,0,0,222,4,0,0,64,7,0,0,150,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,174,9,0,0,164,9,0,0,64,29,0,0,154,20,0,0,254,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,16,13,0,0,214,0,0,0,42,25,0,0,232,12,0,0,126,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,144,15,0,0,100,25,0,0,108,6,0,0,114,30,0,0,202,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,76,8,0,0,76,8,0,0,76,8,0,0,76,8,0,0,76,8,0,0,76,8,0,0,76,8,0,0,76,8,0,0,150,4,0,0,150,4,0,0,150,4,0,0,150,4,0,0,150,4,0,0,150,4,0,0,150,4,0,0,150,4,0,0,136,32,0,0,136,32,0,0,136,32,0,0,136,32,0,0,136,32,0,0,136,32,0,0,136,32,0,0,136,32,0,0,216,24,0,0,216,24,0,0,216,24,0,0,216,24,0,0,216,24,0,0,216,24,0,0,216,24,0,0,216,24,0,0,220,24,0,0,220,24,0,0,220,24,0,0,220,24,0,0,220,24,0,0,220,24,0,0,220,24,0,0,220,24,0,0,2,3,0,0,2,3,0,0,2,3,0,0,2,3,0,0,2,3,0,0,2,3,0,0,2,3,0,0,2,3,0,0,110,20,0,0,110,20,0,0,110,20,0,0,110,20,0,0,110,20,0,0,110,20,0,0,110,20,0,0,110,20,0,0,124,32,0,0,132,32,0,0,80,11,0,0,224,9,0,0,138,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,152,0,0,0,2,4,0,0,76,27,0,0,106,35,0,0,110,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0])
.concat([156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,174,23,0,0,152,23,0,0,2,24,0,0,52,33,0,0,14,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,34,18,0,0,146,0,0,0,122,24,0,0,222,21,0,0,42,24,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,170,35,0,0,214,5,0,0,222,4,0,0,64,7,0,0,150,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,174,9,0,0,164,9,0,0,64,29,0,0,154,20,0,0,254,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,16,13,0,0,214,0,0,0,42,25,0,0,232,12,0,0,126,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,144,15,0,0,100,25,0,0,108,6,0,0,114,30,0,0,202,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,152,0,0,0,2,4,0,0,76,27,0,0,106,35,0,0,110,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,174,23,0,0,152,23,0,0,2,24,0,0,52,33,0,0,14,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,34,18,0,0,146,0,0,0,122,24,0,0,222,21,0,0,42,24,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,170,35,0,0,214,5,0,0,222,4,0,0,64,7,0,0,150,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,174,9,0,0,164,9,0,0,64,29,0,0,154,20,0,0,254,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,16,13,0,0,214,0,0,0,42,25,0,0,232,12,0,0,126,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,144,15,0,0,100,25,0,0,108,6,0,0,114,30,0,0,202,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,152,0,0,0,2,4,0,0,76,27,0,0,106,35,0,0,110,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,174,23,0,0,152,23,0,0,2,24,0,0,52,33,0,0,14,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,34,18,0,0,146,0,0,0,122,24,0,0,222,21,0,0,42,24,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,170,35,0,0,214,5,0,0,222,4,0,0,64,7,0,0,150,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,174,9,0,0,164,9,0,0,64,29,0,0,154,20,0,0,254,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,16,13,0,0,214,0,0,0,42,25,0,0,232,12,0,0,126,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,144,15,0,0,100,25,0,0,108,6,0,0,114,30,0,0,202,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,152,0,0,0,2,4,0,0,76,27,0,0,106,35,0,0,110,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,174,23,0,0,152,23,0,0,2,24,0,0,52,33,0,0,14,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,34,18,0,0,146,0,0,0,122,24,0,0,222,21,0,0,42,24,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,170,35,0,0,214,5,0,0,222,4,0,0,64,7,0,0,150,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,174,9,0,0,164,9,0,0,64,29,0,0,154,20,0,0,254,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,16,13,0,0,214,0,0,0,42,25,0,0,232,12,0,0,126,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,144,15,0,0,100,25,0,0,108,6,0,0,114,30,0,0,202,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,152,0,0,0,2,4,0,0,76,27,0,0,106,35,0,0,110,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,174,23,0,0,152,23,0,0,2,24,0,0,52,33,0,0,14,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,34,18,0,0,146,0,0,0,122,24,0,0,222,21,0,0,42,24,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,170,35,0,0,214,5,0,0,222,4,0,0,64,7,0,0,150,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,174,9,0,0,164,9,0,0,64,29,0,0,154,20,0,0,254,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,16,13,0,0,214,0,0,0,42,25,0,0,232,12,0,0,126,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,144,15,0,0,100,25,0,0,108,6,0,0,114,30,0,0,202,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,156,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,152,6,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,24,4,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,238,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,250,7,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,42,30,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,164,16,0,0,152,0,0,0,2,4,0,0,76,27,0,0,106,35,0,0,110,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,20,31,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0,236,32,0,0])
.concat([156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,156,23,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,20,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,40,21,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,74,32,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,48,18,0,0,174,23,0,0,152,23,0,0,2,24,0,0,52,33,0,0,14,31,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,38,24,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,214,35,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,46,18,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,180,8,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,242,25,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,26,26,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,208,19,0,0,34,18,0,0,146,0,0,0,122,24,0,0,222,21,0,0,42,24,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,112,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,104,10,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,206,5,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,24,13,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,18,8,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,68,29,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,254,21,0,0,170,35,0,0,214,5,0,0,222,4,0,0,64,7,0,0,150,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,186,30,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,168,20,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,162,9,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,80,8,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,224,32,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,24,23,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,130,31,0,0,174,9,0,0,164,9,0,0,64,29,0,0,154,20,0,0,254,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,130,2,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,118,12,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,4,13,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,178,6,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,82,21,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,10,35,0,0,16,13,0,0,214,0,0,0,42,25,0,0,232,12,0,0,126,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,198,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,190,20,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,96,25,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,176,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,196,17,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,134,22,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,14,25,0,0,144,15,0,0,100,25,0,0,108,6,0,0,114,30,0,0,202,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,98,25,0,0,98,25,0,0,98,25,0,0,98,25,0,0,98,25,0,0,98,25,0,0,98,25,0,0,98,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,126,9,0,0,126,9,0,0,126,9,0,0,126,9,0,0,126,9,0,0,126,9,0,0,126,9,0,0,126,9,0,0,216,30,0,0,216,30,0,0,216,30,0,0,216,30,0,0,216,30,0,0,216,30,0,0,216,30,0,0,252,7,0,0,236,30,0,0,236,30,0,0,236,30,0,0,236,30,0,0,236,30,0,0,236,30,0,0,236,30,0,0,170,36,0,0,192,24,0,0,192,24,0,0,192,24,0,0,192,24,0,0,192,24,0,0,192,24,0,0,192,24,0,0,192,24,0,0,104,17,0,0,104,17,0,0,104,17,0,0,104,17,0,0,104,17,0,0,104,17,0,0,104,17,0,0,104,17,0,0,228,9,0,0,196,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,28,0,0,88,28,0,0,88,28,0,0,88,28,0,0,88,28,0,0,88,28,0,0,88,28,0,0,88,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,10,0,0,206,10,0,0,206,10,0,0,206,10,0,0,206,10,0,0,206,10,0,0,206,10,0,0,206,10,0,0,112,3,0,0,112,3,0,0,112,3,0,0,112,3,0,0,112,3,0,0,112,3,0,0,112,3,0,0,112,3,0,0,148,27,0,0,148,27,0,0,148,27,0,0,148,27,0,0,148,27,0,0,148,27,0,0,148,27,0,0,148,27,0,0,188,33,0,0,188,33,0,0,188,33,0,0,188,33,0,0,188,33,0,0,188,33,0,0,188,33,0,0,188,33,0,0,102,24,0,0,102,24,0,0,102,24,0,0,102,24,0,0,102,24,0,0,102,24,0,0,102,24,0,0,102,24,0,0,220,19,0,0,2,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,22,18,0,0,22,18,0,0,22,18,0,0,22,18,0,0,22,18,0,0,22,18,0,0,22,18,0,0,22,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,230,15,0,0,230,15,0,0,230,15,0,0,230,15,0,0,230,15,0,0,230,15,0,0,230,15,0,0,230,15,0,0,114,36,0,0,114,36,0,0,114,36,0,0,114,36,0,0,114,36,0,0,114,36,0,0,114,36,0,0,114,36,0,0,180,35,0,0,180,35,0,0,180,35,0,0,180,35,0,0,180,35,0,0,180,35,0,0,180,35,0,0,180,35,0,0,98,22,0,0,98,22,0,0,98,22,0,0,98,22,0,0,98,22,0,0,98,22,0,0,98,22,0,0,98,22,0,0,20,2,0,0,232,35,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,72,35,0,0,72,35,0,0,72,35,0,0,72,35,0,0,72,35,0,0,72,35,0,0,72,35,0,0,72,35,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,17,0,0,198,17,0,0,198,17,0,0,198,17,0,0,198,17,0,0,198,17,0,0,198,17,0,0,198,17,0,0,94,10,0,0,94,10,0,0,94,10,0,0,94,10,0,0,94,10,0,0,94,10,0,0,94,10,0,0,94,10,0,0,124,31,0,0,124,31,0,0,124,31,0,0,124,31,0,0,124,31,0,0,124,31,0,0,124,31,0,0,124,31,0,0,180,4,0,0,180,4,0,0,180,4,0,0,180,4,0,0,180,4,0,0,180,4,0,0,180,4,0,0,180,4,0,0,150,11,0,0,150,11,0,0,150,11,0,0,150,11,0,0,150,11,0,0,150,11,0,0,150,11,0,0,150,11,0,0,236,17,0,0,202,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,232,31,0,0,62,17,0,0,70,36,0,0,156,5,0,0,116,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,166,19,0,0,132,19,0,0,22,8,0,0,140,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,124,5,0,0,124,5,0,0,124,5,0,0,124,5,0,0,124,5,0,0,124,5,0,0,124,5,0,0,124,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,74,22,0,0,74,22,0,0,74,22,0,0,74,22,0,0,74,22,0,0,74,22,0,0,74,22,0,0,74,22,0,0,246,19,0,0,246,19,0,0,246,19,0,0,246,19,0,0,246,19,0,0,246,19,0,0,246,19,0,0,112,16,0,0,250,19,0,0,250,19,0,0,250,19,0,0,250,19,0,0,250,19,0,0,250,19,0,0,250,19,0,0,158,32,0,0,38,15,0,0,38,15,0,0,38,15,0,0,38,15,0,0,38,15,0,0,38,15,0,0,38,15,0,0,38,15,0,0,64,6,0,0,64,6,0,0,64,6,0,0,64,6,0,0,64,6,0,0,64,6,0,0,64,6,0,0,64,6,0,0,108,22,0,0,72,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,242,6,0,0,242,6,0,0,242,6,0,0,242,6,0,0,242,6,0,0,242,6,0,0,242,6,0,0,242,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,126,11,0,0,126,11,0,0,126,11,0,0,126,11,0,0,126,11,0,0,126,11,0,0,126,11,0,0,126,11,0,0,134,35,0,0,134,35,0,0,134,35,0,0,134,35,0,0,134,35,0,0,134,35,0,0,134,35,0,0,134,35,0,0,42,29,0,0,42,29,0,0,42,29,0,0,42,29,0,0,42,29,0,0,42,29,0,0,42,29,0,0,42,29,0,0,152,3,0,0,152,3,0,0,152,3,0,0,152,3,0,0,152,3,0,0,152,3,0,0,152,3,0,0,152,3,0,0,180,16,0,0,180,16,0,0,180,16,0,0,180,16,0,0,180,16,0,0,180,16,0,0,180,16,0,0,180,16,0,0,2,18,0,0,38,33,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,240,35,0,0,240,35,0,0,240,35,0,0,240,35,0,0,240,35,0,0,240,35,0,0,240,35,0,0,240,35,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,194,34,0,0,194,34,0,0,194,34,0,0,194,34,0,0,194,34,0,0,194,34,0,0,194,34,0,0,194,34,0,0,102,2,0,0,102,2,0,0,102,2,0,0,102,2,0,0,102,2,0,0,102,2,0,0,102,2,0,0,102,2,0,0,96,0,0,0,96,0,0,0,96,0,0,0,96,0,0,0,96,0,0,0,96,0,0,0,96,0,0,0,96,0,0,0,10,6,0,0,10,6,0,0,10,6,0,0,10,6,0,0,10,6,0,0,10,6,0,0,10,6,0,0,10,6,0,0,182,13,0,0,182,13,0,0,182,13,0,0,182,13,0,0,182,13,0,0,182,13,0,0,182,13,0,0,182,13,0,0,174,34,0,0,202,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,232,31,0,0,62,17,0,0,70,36,0,0,156,5,0,0,116,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,166,19,0,0,132,19,0,0,22,8,0,0,140,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,122,3,0,0,122,3,0,0,122,3,0,0,122,3,0,0,122,3,0,0,122,3,0,0,122,3,0,0,122,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,7,0,0,224,7,0,0,224,7,0,0,224,7,0,0,224,7,0,0,224,7,0,0,224,7,0,0,224,7,0,0,88,10,0,0,88,10,0,0,88,10,0,0,88,10,0,0,88,10,0,0,88,10,0,0,88,10,0,0,138,10,0,0,70,10,0,0,70,10,0,0,70,10,0,0,70,10,0,0,70,10,0,0,70,10,0,0,70,10,0,0,158,13,0,0,32,16,0,0,32,16,0,0,32,16,0,0,32,16,0,0,32,16,0,0,32,16,0,0,32,16,0,0,32,16,0,0,164,29,0,0,164,29,0,0,164,29,0,0,164,29,0,0,164,29,0,0,164,29,0,0,164,29,0,0,164,29,0,0,222,7,0,0,228,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,23,0,0,238,23,0,0,238,23,0,0,238,23,0,0,238,23,0,0,238,23,0,0,238,23,0,0,238,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,6,3,0,0,6,3,0,0,6,3,0,0,6,3,0,0,6,3,0,0,6,3,0,0,6,3,0,0,6,3,0,0,116,11,0,0,116,11,0,0,116,11,0,0,116,11,0,0,116,11,0,0,116,11,0,0,116,11,0,0,116,11,0,0,122,11,0,0,122,11,0,0,122,11,0,0,122,11,0,0,122,11,0,0,122,11,0,0,122,11,0,0,122,11,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,28,19,0,0,28,19,0,0,28,19,0,0,28,19,0,0,28,19,0,0,28,19,0,0,28,19,0,0,28,19,0,0,204,13,0,0,180,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,2,13,0,0,2,13,0,0,2,13,0,0,2,13,0,0,2,13,0,0,2,13,0,0,2,13,0,0,2,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,208,11,0,0,208,11,0,0,208,11,0,0,208,11,0,0,208,11,0,0,208,11,0,0,208,11,0,0,208,11,0,0,24,18,0,0,24,18,0,0,24,18,0,0,24,18,0,0,24,18,0,0,24,18,0,0,24,18,0,0,24,18,0,0,38,18,0,0,38,18,0,0,38,18,0,0,38,18,0,0,38,18,0,0,38,18,0,0,38,18,0,0,38,18,0,0,222,18,0,0,222,18,0,0,222,18,0,0,222,18,0,0,222,18,0,0,222,18,0,0,222,18,0,0,222,18,0,0,172,32,0,0,172,32,0,0,172,32,0,0,172,32,0,0,172,32,0,0,172,32,0,0,172,32,0,0,172,32,0,0,174,11,0,0,202,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,234,15,0,0,234,15,0,0,234,15,0,0,234,15,0,0,234,15,0,0,234,15,0,0,234,15,0,0,234,15,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,188,12,0,0,188,12,0,0,188,12,0,0,188,12,0,0,188,12,0,0,188,12,0,0,188,12,0,0,188,12,0,0,108,10,0,0,108,10,0,0,108,10,0,0,108,10,0,0,108,10,0,0,108,10,0,0,108,10,0,0,108,10,0,0,90,10,0,0,90,10,0,0,90,10,0,0,90,10,0,0,90,10,0,0,90,10,0,0,90,10,0,0,90,10,0,0,30,25,0,0,30,25,0,0,30,25,0,0,30,25,0,0,30,25,0,0,30,25,0,0,30,25,0,0,30,25,0,0,140,33,0,0,140,33,0,0,140,33,0,0,140,33,0,0,140,33,0,0,140,33,0,0,140,33,0,0,140,33,0,0,190,12,0,0,182,12,0,0,2,21,0,0,148,33,0,0,174,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,232,31,0,0,62,17,0,0,70,36,0,0,156,5,0,0,116,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,166,19,0,0,132,19,0,0,22,8,0,0,140,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,18,0,0,190,18,0,0,190,18,0,0,190,18,0,0,190,18,0,0,190,18,0,0,190,18,0,0,190,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,25,0,0,178,25,0,0,178,25,0,0,178,25,0,0,178,25,0,0,178,25,0,0,178,25,0,0,178,25,0,0,48,32,0,0,48,32,0,0,48,32,0,0,48,32,0,0,48,32,0,0,48,32,0,0,48,32,0,0,166,18,0,0,60,32,0,0,60,32,0,0,60,32,0,0,60,32,0,0,60,32,0,0,60,32,0,0,60,32,0,0,188,24,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,94,21,0,0,94,21,0,0,94,21,0,0,94,21,0,0,94,21,0,0,94,21,0,0,94,21,0,0,94,21,0,0,138,25,0,0,174,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,164,28,0,0,164,28,0,0,164,28,0,0,164,28,0,0,164,28,0,0,164,28,0,0,164,28,0,0,164,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,126,20,0,0,126,20,0,0,126,20,0,0,126,20,0,0,126,20,0,0,126,20,0,0,126,20,0,0,126,20,0,0,242,19,0,0,242,19,0,0,242,19,0,0,242,19,0,0,242,19,0,0,242,19,0,0,242,19,0,0,242,19,0,0,224,22,0,0,224,22,0,0,224,22,0,0,224,22,0,0,224,22,0,0,224,22,0,0,224,22,0,0,224,22,0,0,48,8,0,0,48,8,0,0,48,8,0,0,48,8,0,0,48,8,0,0,48,8,0,0,48,8,0,0,48,8,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,130,20,0,0,96,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,124,22,0,0,124,22,0,0,124,22,0,0,124,22,0,0,124,22,0,0,124,22,0,0,124,22,0,0,124,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,26,0,0,34,26,0,0,34,26,0,0,34,26,0,0,34,26,0,0,34,26,0,0,34,26,0,0,34,26,0,0,98,24,0,0,98,24,0,0,98,24,0,0,98,24,0,0,98,24,0,0,98,24,0,0,98,24,0,0,98,24,0,0,252,28,0,0,252,28,0,0,252,28,0,0,252,28,0,0,252,28,0,0,252,28,0,0,252,28,0,0,252,28,0,0,138,12,0,0,138,12,0,0,138,12,0,0,138,12,0,0,138,12,0,0,138,12,0,0,138,12,0,0,138,12,0,0,190,9,0,0,190,9,0,0,190,9,0,0,190,9,0,0,190,9,0,0,190,9,0,0,190,9,0,0,190,9,0,0,20,26,0,0,252,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,32,0,0,34,32,0,0,34,32,0,0,34,32,0,0,34,32,0,0,34,32,0,0,34,32,0,0,34,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,15,0,0,146,15,0,0,146,15,0,0,146,15,0,0,146,15,0,0,146,15,0,0,146,15,0,0,146,15,0,0,38,23,0,0,38,23,0,0,38,23,0,0,38,23,0,0,38,23,0,0,38,23,0,0,38,23,0,0,38,23,0,0,30,23,0,0,30,23,0,0,30,23,0,0,30,23,0,0,30,23,0,0,30,23,0,0,30,23,0,0,30,23,0,0,56,29,0,0,56,29,0,0,56,29,0,0,56,29,0,0,56,29,0,0,56,29,0,0,56,29,0,0,56,29,0,0,216,1,0,0,216,1,0,0,216,1,0,0,216,1,0,0,216,1,0,0,216,1,0,0,216,1,0,0,216,1,0,0,110,15,0,0,142,15,0,0,92,35,0,0,182,11,0,0,36,36,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,232,31,0,0,62,17,0,0,70,36,0,0,156,5,0,0,116,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,166,19,0,0,132,19,0,0,22,8,0,0,140,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,84,14,0,0,84,14,0,0,84,14,0,0,84,14,0,0,84,14,0,0,84,14,0,0,84,14,0,0,84,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,86,19,0,0,86,19,0,0,86,19,0,0,86,19,0,0,86,19,0,0,86,19,0,0,86,19,0,0,86,19,0,0,26,27,0,0,26,27,0,0,26,27,0,0,26,27,0,0,26,27,0,0,26,27,0,0,26,27,0,0,42,21,0,0,16,27,0,0,16,27,0,0,16,27,0,0,16,27,0,0,16,27,0,0,16,27,0,0,16,27,0,0,182,29,0,0,96,29,0,0,96,29,0,0,96,29,0,0,96,29,0,0,96,29,0,0,96,29,0,0,96,29,0,0,96,29,0,0,212,35,0,0,212,35,0,0,212,35,0,0,212,35,0,0,212,35,0,0,212,35,0,0,212,35,0,0,212,35,0,0,58,19,0,0,80,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,118,18,0,0,118,18,0,0,118,18,0,0,118,18,0,0,118,18,0,0,118,18,0,0,118,18,0,0,118,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0])
.concat([76,25,0,0,76,25,0,0,76,25,0,0,76,25,0,0,76,25,0,0,76,25,0,0,76,25,0,0,76,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,12,18,0,0,12,18,0,0,12,18,0,0,12,18,0,0,12,18,0,0,12,18,0,0,12,18,0,0,12,18,0,0,254,4,0,0,254,4,0,0,254,4,0,0,254,4,0,0,254,4,0,0,254,4,0,0,254,4,0,0,254,4,0,0,74,25,0,0,78,25,0,0,110,30,0,0,236,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,18,0,0,18,18,0,0,18,18,0,0,18,18,0,0,18,18,0,0,18,18,0,0,18,18,0,0,18,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,36,10,0,0,36,10,0,0,36,10,0,0,36,10,0,0,36,10,0,0,36,10,0,0,36,10,0,0,36,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,33,0,0,238,33,0,0,238,33,0,0,238,33,0,0,238,33,0,0,238,33,0,0,238,33,0,0,238,33,0,0,88,3,0,0,88,3,0,0,88,3,0,0,88,3,0,0,88,3,0,0,88,3,0,0,88,3,0,0,88,3,0,0,22,32,0,0,22,32,0,0,22,32,0,0,22,32,0,0,22,32,0,0,22,32,0,0,22,32,0,0,22,32,0,0,46,10,0,0,32,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,23,0,0,88,23,0,0,88,23,0,0,88,23,0,0,88,23,0,0,88,23,0,0,88,23,0,0,88,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,35,0,0,174,35,0,0,174,35,0,0,174,35,0,0,174,35,0,0,174,35,0,0,174,35,0,0,174,35,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,92,3,0,0,92,3,0,0,92,3,0,0,92,3,0,0,92,3,0,0,92,3,0,0,92,3,0,0,92,3,0,0,54,0,0,0,54,0,0,0,54,0,0,0,54,0,0,0,54,0,0,0,54,0,0,0,54,0,0,0,54,0,0,0,22,19,0,0,22,19,0,0,22,19,0,0,22,19,0,0,22,19,0,0,22,19,0,0,22,19,0,0,22,19,0,0,26,13,0,0,222,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,232,31,0,0,62,17,0,0,70,36,0,0,156,5,0,0,116,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,166,19,0,0,132,19,0,0,22,8,0,0,140,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,1,0,0,174,1,0,0,174,1,0,0,174,1,0,0,174,1,0,0,174,1,0,0,174,1,0,0,174,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,118,25,0,0,118,25,0,0,118,25,0,0,118,25,0,0,118,25,0,0,118,25,0,0,118,25,0,0,118,25,0,0,16,30,0,0,16,30,0,0,16,30,0,0,16,30,0,0,16,30,0,0,16,30,0,0,16,30,0,0,190,29,0,0,10,30,0,0,10,30,0,0,10,30,0,0,10,30,0,0,10,30,0,0,10,30,0,0,10,30,0,0,104,21,0,0,64,36,0,0,64,36,0,0,64,36,0,0,64,36,0,0,64,36,0,0,64,36,0,0,64,36,0,0,64,36,0,0,146,2,0,0,146,2,0,0,146,2,0,0,146,2,0,0,146,2,0,0,146,2,0,0,146,2,0,0,146,2,0,0,76,22,0,0,146,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,40,32,0,0,40,32,0,0,40,32,0,0,40,32,0,0,40,32,0,0,40,32,0,0,40,32,0,0,40,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,168,10,0,0,168,10,0,0,168,10,0,0,168,10,0,0,168,10,0,0,168,10,0,0,168,10,0,0,168,10,0,0,30,36,0,0,30,36,0,0,30,36,0,0,30,36,0,0,30,36,0,0,30,36,0,0,30,36,0,0,30,36,0,0,116,8,0,0,116,8,0,0,116,8,0,0,116,8,0,0,116,8,0,0,116,8,0,0,116,8,0,0,116,8,0,0,60,34,0,0,60,34,0,0,60,34,0,0,60,34,0,0,60,34,0,0,60,34,0,0,60,34,0,0,60,34,0,0,188,25,0,0,188,25,0,0,188,25,0,0,188,25,0,0,188,25,0,0,188,25,0,0,188,25,0,0,188,25,0,0,146,10,0,0,124,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,44,32,0,0,44,32,0,0,44,32,0,0,44,32,0,0,44,32,0,0,44,32,0,0,44,32,0,0,44,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,236,15,0,0,236,15,0,0,236,15,0,0,236,15,0,0,236,15,0,0,236,15,0,0,236,15,0,0,236,15,0,0,60,18,0,0,60,18,0,0,60,18,0,0,60,18,0,0,60,18,0,0,60,18,0,0,60,18,0,0,60,18,0,0,74,18,0,0,74,18,0,0,74,18,0,0,74,18,0,0,74,18,0,0,74,18,0,0,74,18,0,0,74,18,0,0,240,3,0,0,240,3,0,0,240,3,0,0,240,3,0,0,240,3,0,0,240,3,0,0,240,3,0,0,240,3,0,0,236,21,0,0,236,21,0,0,236,21,0,0,236,21,0,0,236,21,0,0,236,21,0,0,236,21,0,0,236,21,0,0,224,15,0,0,92,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,28,0,0,174,28,0,0,174,28,0,0,174,28,0,0,174,28,0,0,174,28,0,0,174,28,0,0,174,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,84,24,0,0,84,24,0,0,84,24,0,0,84,24,0,0,84,24,0,0,84,24,0,0,84,24,0,0,84,24,0,0,108,32,0,0,108,32,0,0,108,32,0,0,108,32,0,0,108,32,0,0,108,32,0,0,108,32,0,0,106,31,0,0,76,10,0,0,76,10,0,0,76,10,0,0,76,10,0,0,76,10,0,0,76,10,0,0,76,10,0,0,118,32,0,0,114,26,0,0,114,26,0,0,114,26,0,0,114,26,0,0,114,26,0,0,114,26,0,0,114,26,0,0,114,26,0,0,46,19,0,0,46,19,0,0,46,19,0,0,46,19,0,0,46,19,0,0,46,19,0,0,46,19,0,0,46,19,0,0,80,3,0,0,70,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,232,31,0,0,62,17,0,0,70,36,0,0,156,5,0,0,116,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,166,19,0,0,132,19,0,0,22,8,0,0,140,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,8,27,0,0,8,27,0,0,8,27,0,0,8,27,0,0,8,27,0,0,8,27,0,0,8,27,0,0,8,27,0,0,86,35,0,0,86,35,0,0,86,35,0,0,86,35,0,0,86,35,0,0,86,35,0,0,86,35,0,0,86,35,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,146,25,0,0,146,25,0,0,146,25,0,0,146,25,0,0,146,25,0,0,146,25,0,0,146,25,0,0,146,25,0,0,74,6,0,0,74,6,0,0,74,6,0,0,74,6,0,0,74,6,0,0,74,6,0,0,74,6,0,0,74,6,0,0,246,26,0,0,12,27,0,0,4,34,0,0,130,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,12,0,0,174,12,0,0,174,12,0,0,174,12,0,0,174,12,0,0,174,12,0,0,174,12,0,0,174,12,0,0,14,10,0,0,14,10,0,0,14,10,0,0,14,10,0,0,14,10,0,0,14,10,0,0,14,10,0,0,14,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,200,24,0,0,200,24,0,0,200,24,0,0,200,24,0,0,200,24,0,0,200,24,0,0,200,24,0,0,200,24,0,0,246,14,0,0,246,14,0,0,246,14,0,0,246,14,0,0,246,14,0,0,246,14,0,0,246,14,0,0,246,14,0,0,82,11,0,0,78,11,0,0,206,7,0,0,218,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,232,31,0,0,62,17,0,0,70,36,0,0,156,5,0,0,116,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,166,19,0,0,132,19,0,0,22,8,0,0,140,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,60,25,0,0,64,9,0,0,64,9,0,0,64,9,0,0,64,9,0,0,64,9,0,0,64,9,0,0,64,9,0,0,6,17,0,0,78,27,0,0,78,27,0,0,78,27,0,0,78,27,0,0,78,27,0,0,78,27,0,0,78,27,0,0,56,8,0,0,84,13,0,0,84,13,0,0,84,13,0,0,84,13,0,0,84,13,0,0,84,13,0,0,84,13,0,0,84,13,0,0,56,20,0,0,56,20,0,0,56,20,0,0,56,20,0,0,56,20,0,0,56,20,0,0,56,20,0,0,56,20,0,0,144,29,0,0,228,33,0,0,218,7,0,0,102,20,0,0,206,0,0,0,214,7,0,0,120,1,0,0,234,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,124,24,0,0,124,24,0,0,124,24,0,0,124,24,0,0,124,24,0,0,124,24,0,0,124,24,0,0,124,24,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,32,0,0,238,32,0,0,238,32,0,0,238,32,0,0,238,32,0,0,238,32,0,0,238,32,0,0,238,32,0,0,150,9,0,0,150,9,0,0,150,9,0,0,150,9,0,0,150,9,0,0,150,9,0,0,150,9,0,0,150,9,0,0,152,24,0,0,132,24,0,0,194,0,0,0,28,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,23,0,0,170,23,0,0,170,23,0,0,170,23,0,0,170,23,0,0,170,23,0,0,170,23,0,0,170,23,0,0,78,16,0,0,78,16,0,0,78,16,0,0,78,16,0,0,78,16,0,0,78,16,0,0,78,16,0,0,78,16,0,0,136,0,0,0,106,0,0,0,114,22,0,0,86,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,198,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,72,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,78,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,54,17,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,82,32,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,230,33,0,0,232,31,0,0,62,17,0,0,70,36,0,0,156,5,0,0,116,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,138,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,64,33,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,46,17,0,0,166,19,0,0,132,19,0,0,22,8,0,0,140,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,70,25,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,86,30,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,8,17,0,0,72,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,244,20,0,0,238,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,190,17,0,0,156,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,106,8,0,0,106,8,0,0,106,8,0,0,106,8,0,0,106,8,0,0,106,8,0,0,106,8,0,0,106,8,0,0,88,9,0,0,88,9,0,0,88,9,0,0,88,9,0,0,88,9,0,0,88,9,0,0,88,9,0,0,88,9,0,0,224,30,0,0,224,30,0,0,224,30,0,0,224,30,0,0,224,30,0,0,224,30,0,0,224,30,0,0,224,30,0,0,200,1,0,0,200,1,0,0,200,1,0,0,200,1,0,0,200,1,0,0,200,1,0,0,200,1,0,0,154,15,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,212,28,0,0,154,24,0,0,154,24,0,0,154,24,0,0,154,24,0,0,154,24,0,0,154,24,0,0,154,24,0,0,154,24,0,0,34,14,0,0,34,14,0,0,34,14,0,0,34,14,0,0,34,14,0,0,34,14,0,0,34,14,0,0,34,14,0,0,72,4,0,0,0,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,200,29,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,158,21,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,172,19,0,0,242,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,18,26,0,0,30,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,134,26,0,0,166,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,218,33,0,0,218,33,0,0,218,33,0,0,218,33,0,0,218,33,0,0,218,33,0,0,218,33,0,0,218,33,0,0,216,6,0,0,216,6,0,0,216,6,0,0,216,6,0,0,216,6,0,0,216,6,0,0,216,6,0,0,216,6,0,0,78,35,0,0,78,35,0,0,78,35,0,0,78,35,0,0,78,35,0,0,78,35,0,0,78,35,0,0,78,35,0,0,8,14,0,0,8,14,0,0,8,14,0,0,8,14,0,0,8,14,0,0,8,14,0,0,8,14,0,0,36,27,0,0,18,34,0,0,18,34,0,0,18,34,0,0,18,34,0,0,18,34,0,0,18,34,0,0,18,34,0,0,210,35,0,0,200,25,0,0,200,25,0,0,200,25,0,0,200,25,0,0,200,25,0,0,200,25,0,0,200,25,0,0,200,25,0,0,76,34,0,0,76,34,0,0,76,34,0,0,76,34,0,0,76,34,0,0,76,34,0,0,76,34,0,0,76,34,0,0,194,36,0,0,250,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,70,25,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,86,30,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,8,17,0,0,72,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0])
.concat([242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,244,20,0,0,238,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,190,17,0,0,156,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,34,0,0,88,34,0,0,88,34,0,0,88,34,0,0,88,34,0,0,88,34,0,0,88,34,0,0,88,34,0,0,240,26,0,0,240,26,0,0,240,26,0,0,240,26,0,0,240,26,0,0,240,26,0,0,240,26,0,0,240,26,0,0,152,18,0,0,152,18,0,0,152,18,0,0,152,18,0,0,152,18,0,0,152,18,0,0,152,18,0,0,152,18,0,0,134,10,0,0,134,10,0,0,134,10,0,0,134,10,0,0,134,10,0,0,134,10,0,0,134,10,0,0,174,30,0,0,218,19,0,0,218,19,0,0,218,19,0,0,218,19,0,0,218,19,0,0,218,19,0,0,218,19,0,0,172,3,0,0,236,25,0,0,236,25,0,0,236,25,0,0,236,25,0,0,236,25,0,0,236,25,0,0,236,25,0,0,236,25,0,0,180,2,0,0,180,2,0,0,180,2,0,0,180,2,0,0,180,2,0,0,180,2,0,0,180,2,0,0,180,2,0,0,148,18,0,0,158,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,200,29,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,158,21,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,172,19,0,0,242,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,18,26,0,0,30,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,134,26,0,0,166,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,30,0,0,254,30,0,0,254,30,0,0,254,30,0,0,254,30,0,0,254,30,0,0,254,30,0,0,254,30,0,0,2,29,0,0,2,29,0,0,2,29,0,0,2,29,0,0,2,29,0,0,2,29,0,0,2,29,0,0,2,29,0,0,172,2,0,0,172,2,0,0,172,2,0,0,172,2,0,0,172,2,0,0,172,2,0,0,172,2,0,0,172,2,0,0,62,2,0,0,62,2,0,0,62,2,0,0,62,2,0,0,62,2,0,0,62,2,0,0,62,2,0,0,8,28,0,0,178,24,0,0,178,24,0,0,178,24,0,0,178,24,0,0,178,24,0,0,178,24,0,0,178,24,0,0,22,30,0,0,234,9,0,0,234,9,0,0,234,9,0,0,234,9,0,0,234,9,0,0,234,9,0,0,234,9,0,0,234,9,0,0,38,7,0,0,38,7,0,0,38,7,0,0,38,7,0,0,38,7,0,0,38,7,0,0,38,7,0,0,38,7,0,0,54,22,0,0,62,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,70,25,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,86,30,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,8,17,0,0,72,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,244,20,0,0,238,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,190,17,0,0,156,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,204,12,0,0,204,12,0,0,204,12,0,0,204,12,0,0,204,12,0,0,204,12,0,0,204,12,0,0,204,12,0,0,86,36,0,0,86,36,0,0,86,36,0,0,86,36,0,0,86,36,0,0,86,36,0,0,86,36,0,0,86,36,0,0,32,21,0,0,32,21,0,0,32,21,0,0,32,21,0,0,32,21,0,0,32,21,0,0,32,21,0,0,32,21,0,0,40,13,0,0,40,13,0,0,40,13,0,0,40,13,0,0,40,13,0,0,40,13,0,0,40,13,0,0,184,23,0,0,42,13,0,0,42,13,0,0,42,13,0,0,42,13,0,0,42,13,0,0,42,13,0,0,42,13,0,0,202,27,0,0,70,7,0,0,70,7,0,0,70,7,0,0,70,7,0,0,70,7,0,0,70,7,0,0,70,7,0,0,70,7,0,0,146,36,0,0,146,36,0,0,146,36,0,0,146,36,0,0,146,36,0,0,146,36,0,0,146,36,0,0,146,36,0,0,170,15,0,0,150,15,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,200,29,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,158,21,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,172,19,0,0,242,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,18,26,0,0,30,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,134,26,0,0,166,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,31,0,0,254,31,0,0,254,31,0,0,254,31,0,0,254,31,0,0,254,31,0,0,254,31,0,0,254,31,0,0,108,29,0,0,108,29,0,0,108,29,0,0,108,29,0,0,108,29,0,0,108,29,0,0,108,29,0,0,108,29,0,0,120,17,0,0,120,17,0,0,120,17,0,0,120,17,0,0,120,17,0,0,120,17,0,0,120,17,0,0,120,17,0,0,90,21,0,0,90,21,0,0,90,21,0,0,90,21,0,0,90,21,0,0,90,21,0,0,90,21,0,0,228,29,0,0,92,21,0,0,92,21,0,0,92,21,0,0,92,21,0,0,92,21,0,0,92,21,0,0,92,21,0,0,16,6,0,0,186,6,0,0,186,6,0,0,186,6,0,0,186,6,0,0,186,6,0,0,186,6,0,0,186,6,0,0,186,6,0,0,154,34,0,0,154,34,0,0,154,34,0,0,154,34,0,0,154,34,0,0,154,34,0,0,154,34,0,0,154,34,0,0,150,13,0,0,156,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,70,25,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,86,30,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,8,17,0,0,72,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,244,20,0,0,238,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,190,17,0,0,156,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,196,28,0,0,196,28,0,0,196,28,0,0,196,28,0,0,196,28,0,0,196,28,0,0,196,28,0,0,196,28,0,0,254,23,0,0,254,23,0,0,254,23,0,0,254,23,0,0,254,23,0,0,254,23,0,0,254,23,0,0,254,23,0,0,116,26,0,0,116,26,0,0,116,26,0,0,116,26,0,0,116,26,0,0,116,26,0,0,116,26,0,0,112,21,0,0,50,28,0,0,50,28,0,0,50,28,0,0,50,28,0,0,50,28,0,0,50,28,0,0,50,28,0,0,250,12,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,228,19,0,0,228,19,0,0,228,19,0,0,228,19,0,0,228,19,0,0,228,19,0,0,228,19,0,0,228,19,0,0,62,4,0,0,26,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,200,29,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,158,21,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,172,19,0,0,242,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,18,26,0,0,30,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,134,26,0,0,166,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,8,0,0,60,8,0,0,60,8,0,0,60,8,0,0,60,8,0,0,60,8,0,0,60,8,0,0,60,8,0,0,84,19,0,0,84,19,0,0,84,19,0,0,84,19,0,0,84,19,0,0,84,19,0,0,84,19,0,0,84,19,0,0,170,14,0,0,170,14,0,0,170,14,0,0,170,14,0,0,170,14,0,0,170,14,0,0,170,14,0,0,170,14,0,0,110,13,0,0,110,13,0,0,110,13,0,0,110,13,0,0,110,13,0,0,110,13,0,0,110,13,0,0,140,31,0,0,96,13,0,0,96,13,0,0,96,13,0,0,96,13,0,0,96,13,0,0,96,13,0,0,96,13,0,0,184,2,0,0,148,7,0,0,148,7,0,0,148,7,0,0,148,7,0,0,148,7,0,0,148,7,0,0,148,7,0,0,148,7,0,0,78,31,0,0,78,31,0,0,78,31,0,0,78,31,0,0,78,31,0,0,78,31,0,0,78,31,0,0,78,31,0,0,180,14,0,0,166,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,70,25,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,86,30,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,8,17,0,0,72,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,244,20,0,0,238,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,190,17,0,0,156,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,4,19,0,0,4,19,0,0,4,19,0,0,4,19,0,0,4,19,0,0,4,19,0,0,4,19,0,0,4,19,0,0,90,5,0,0,90,5,0,0,90,5,0,0,90,5,0,0,90,5,0,0,90,5,0,0,90,5,0,0,90,5,0,0,240,20,0,0,240,20,0,0,240,20,0,0,240,20,0,0,240,20,0,0,240,20,0,0,240,20,0,0,240,20,0,0,80,26,0,0,80,26,0,0,80,26,0,0,80,26,0,0,80,26,0,0,80,26,0,0,80,26,0,0,252,15,0,0,212,25,0,0,212,25,0,0,212,25,0,0,212,25,0,0,212,25,0,0,212,25,0,0,212,25,0,0,12,3,0,0,144,9,0,0,144,9,0,0,144,9,0,0,144,9,0,0,144,9,0,0,144,9,0,0,144,9,0,0,144,9,0,0,232,4,0,0,232,4,0,0,232,4,0,0,232,4,0,0,232,4,0,0,232,4,0,0,232,4,0,0,232,4,0,0,166,21,0,0,236,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,200,29,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,158,21,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,172,19,0,0,242,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,18,26,0,0,30,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,134,26,0,0,166,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,38,16,0,0,38,16,0,0,38,16,0,0,38,16,0,0,38,16,0,0,38,16,0,0,38,16,0,0,38,16,0,0,250,4,0,0,250,4,0,0,250,4,0,0,250,4,0,0,250,4,0,0,250,4,0,0,250,4,0,0,250,4,0,0,2,22,0,0,2,22,0,0,2,22,0,0,2,22,0,0,2,22,0,0,2,22,0,0,2,22,0,0,2,22,0,0,74,14,0,0,74,14,0,0,74,14,0,0,74,14,0,0,74,14,0,0,74,14,0,0,74,14,0,0,22,22,0,0,70,14,0,0,70,14,0,0,70,14,0,0,70,14,0,0,70,14,0,0,70,14,0,0,70,14,0,0,34,19,0,0,84,32,0,0,84,32,0,0,84,32,0,0,84,32,0,0,84,32,0,0,84,32,0,0,84,32,0,0,84,32,0,0,242,5,0,0,242,5,0,0,242,5,0,0,242,5,0,0,242,5,0,0,242,5,0,0,242,5,0,0,242,5,0,0,234,21,0,0,250,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,70,25,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,86,30,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,8,17,0,0,72,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,244,20,0,0,238,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,190,17,0,0,156,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,248,11,0,0,248,11,0,0,248,11,0,0,248,11,0,0,248,11,0,0,248,11,0,0,248,11,0,0,248,11,0,0,40,9,0,0,40,9,0,0,40,9,0,0,40,9,0,0,40,9,0,0,40,9,0,0,40,9,0,0,40,9,0,0,16,36,0,0,16,36,0,0,16,36,0,0,16,36,0,0,16,36,0,0,16,36,0,0,16,36,0,0,16,36,0,0,164,6,0,0,164,6,0,0,164,6,0,0,164,6,0,0,164,6,0,0,164,6,0,0,164,6,0,0,142,29,0,0,166,6,0,0,166,6,0,0,166,6,0,0,166,6,0,0,166,6,0,0,166,6,0,0,166,6,0,0,122,2,0,0,96,6,0,0,96,6,0,0,96,6,0,0,96,6,0,0,96,6,0,0,96,6,0,0,96,6,0,0,96,6,0,0,62,15,0,0,62,15,0,0,62,15,0,0,62,15,0,0,62,15,0,0,62,15,0,0,62,15,0,0,62,15,0,0,242,31,0,0,58,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,200,29,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,158,21,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,172,19,0,0,242,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,18,26,0,0,30,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,134,26,0,0,166,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,208,36,0,0,208,36,0,0,208,36,0,0,208,36,0,0,208,36,0,0,208,36,0,0,208,36,0,0,208,36,0,0,252,34,0,0,252,34,0,0,252,34,0,0,252,34,0,0,252,34,0,0,252,34,0,0,252,34,0,0,252,34,0,0,102,29,0,0,102,29,0,0,102,29,0,0,102,29,0,0,102,29,0,0,102,29,0,0,102,29,0,0,102,29,0,0,208,29,0,0,208,29,0,0,208,29,0,0,208,29,0,0,208,29,0,0,208,29,0,0,208,29,0,0,172,7,0,0,4,29,0,0,4,29,0,0,4,29,0,0,4,29,0,0,4,29,0,0,4,29,0,0,4,29,0,0,142,8,0,0,254,12,0,0,254,12,0,0,254,12,0,0,254,12,0,0,254,12,0,0,254,12,0,0,254,12,0,0,254,12,0,0,72,5,0,0,72,5,0,0,72,5,0,0,72,5,0,0,72,5,0,0,72,5,0,0,72,5,0,0,72,5,0,0,50,21,0,0,74,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,70,25,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,86,30,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,8,17,0,0,72,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0])
.concat([242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,244,20,0,0,238,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,190,17,0,0,156,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,52,26,0,0,52,26,0,0,52,26,0,0,52,26,0,0,52,26,0,0,52,26,0,0,52,26,0,0,52,26,0,0,248,23,0,0,248,23,0,0,248,23,0,0,248,23,0,0,248,23,0,0,248,23,0,0,248,23,0,0,248,23,0,0,238,15,0,0,238,15,0,0,238,15,0,0,238,15,0,0,238,15,0,0,238,15,0,0,238,15,0,0,238,15,0,0,124,13,0,0,124,13,0,0,124,13,0,0,124,13,0,0,124,13,0,0,124,13,0,0,124,13,0,0,0,4,0,0,112,13,0,0,112,13,0,0,112,13,0,0,112,13,0,0,112,13,0,0,112,13,0,0,112,13,0,0,158,11,0,0,52,17,0,0,52,17,0,0,52,17,0,0,52,17,0,0,52,17,0,0,52,17,0,0,52,17,0,0,52,17,0,0,130,0,0,0,130,0,0,0,130,0,0,0,130,0,0,0,130,0,0,0,130,0,0,0,130,0,0,0,130,0,0,0,218,15,0,0,136,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,200,29,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,158,21,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,172,19,0,0,242,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,18,26,0,0,30,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,134,26,0,0,166,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,29,0,0,60,29,0,0,60,29,0,0,60,29,0,0,60,29,0,0,60,29,0,0,60,29,0,0,60,29,0,0,34,13,0,0,34,13,0,0,34,13,0,0,34,13,0,0,34,13,0,0,34,13,0,0,34,13,0,0,34,13,0,0,242,9,0,0,242,9,0,0,242,9,0,0,242,9,0,0,242,9,0,0,242,9,0,0,242,9,0,0,242,9,0,0,120,32,0,0,120,32,0,0,120,32,0,0,120,32,0,0,120,32,0,0,120,32,0,0,120,32,0,0,196,11,0,0,100,17,0,0,100,17,0,0,100,17,0,0,100,17,0,0,100,17,0,0,100,17,0,0,100,17,0,0,40,15,0,0,58,22,0,0,58,22,0,0,58,22,0,0,58,22,0,0,58,22,0,0,58,22,0,0,58,22,0,0,58,22,0,0,36,18,0,0,36,18,0,0,36,18,0,0,36,18,0,0,36,18,0,0,36,18,0,0,36,18,0,0,36,18,0,0,54,27,0,0,238,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,6,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,34,17,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,158,19,0,0,70,25,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,162,19,0,0,86,30,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,164,25,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,138,17,0,0,8,17,0,0,72,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,110,25,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,148,6,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,242,20,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,120,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,108,18,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,162,12,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,242,33,0,0,244,20,0,0,238,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,210,21,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,166,15,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,160,17,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,72,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,68,25,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,128,13,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,26,34,0,0,190,17,0,0,156,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,172,30,0,0,172,30,0,0,172,30,0,0,172,30,0,0,172,30,0,0,172,30,0,0,172,30,0,0,172,30,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,216,15,0,0,216,15,0,0,216,15,0,0,216,15,0,0,216,15,0,0,216,15,0,0,216,15,0,0,216,15,0,0,20,10,0,0,20,10,0,0,20,10,0,0,20,10,0,0,20,10,0,0,20,10,0,0,20,10,0,0,28,13,0,0,222,24,0,0,222,24,0,0,222,24,0,0,222,24,0,0,222,24,0,0,222,24,0,0,222,24,0,0,22,0,0,0,86,31,0,0,86,31,0,0,86,31,0,0,86,31,0,0,86,31,0,0,86,31,0,0,86,31,0,0,86,31,0,0,104,28,0,0,104,28,0,0,104,28,0,0,104,28,0,0,104,28,0,0,104,28,0,0,104,28,0,0,104,28,0,0,196,7,0,0,180,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,174,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,150,27,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,48,35,0,0,200,29,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,46,35,0,0,158,21,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,230,6,0,0,172,19,0,0,242,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,202,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,208,13,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,84,23,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,130,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,154,28,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,146,12,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,132,34,0,0,18,26,0,0,30,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,18,7,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,238,18,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,128,20,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,18,29,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,166,17,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,252,12,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,228,5,0,0,134,26,0,0,166,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,24,32,0,0,24,32,0,0,24,32,0,0,24,32,0,0,24,32,0,0,24,32,0,0,24,32,0,0,24,32,0,0,212,16,0,0,212,16,0,0,212,16,0,0,212,16,0,0,212,16,0,0,212,16,0,0,212,16,0,0,212,16,0,0,50,26,0,0,50,26,0,0,50,26,0,0,50,26,0,0,50,26,0,0,50,26,0,0,50,26,0,0,50,26,0,0,122,18,0,0,122,18,0,0,122,18,0,0,122,18,0,0,122,18,0,0,122,18,0,0,122,18,0,0,254,2,0,0,112,18,0,0,112,18,0,0,112,18,0,0,112,18,0,0,112,18,0,0,112,18,0,0,112,18,0,0,252,5,0,0,126,16,0,0,126,16,0,0,126,16,0,0,126,16,0,0,126,16,0,0,126,16,0,0,126,16,0,0,126,16,0,0,250,23,0,0,250,23,0,0,250,23,0,0,250,23,0,0,250,23,0,0,250,23,0,0,250,23,0,0,250,23,0,0,96,26,0,0,54,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,7,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,226,30,0,0,114,12,0,0,4,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,94,5,0,0,210,5,0,0,208,14,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,56,18,0,0,202,9,0,0,108,25,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,50,18,0,0,170,0,0,0,68,0,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,84,7,0,0,30,11,0,0,238,0,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,56,19,0,0,240,5,0,0,168,19,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0])
.concat([184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,184,26,0,0,232,32,0,0,162,33,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,114,9,0,0,30,14,0,0,42,26,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,122,32,0,0,232,20,0,0,112,0,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,14,32,0,0,38,32,0,0,52,2,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,150,34,0,0,138,9,0,0,98,20,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,196,36,0,0,236,26,0,0,72,11,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,6,28,0,0,36,2,0,0,158,20,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,24,35,0,0,134,27,0,0,14,0,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,144,27,0,0,196,31,0,0,4,22,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,190,4,0,0,208,16,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0])
.concat([18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0])
.concat([18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,18,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,4,31,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,242,26,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,48,27,0,0,66,27,0,0,26,12,0,0,234,19,0,0,96,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,28,3,0,0,154,6,0,0,210,32,0,0,200,8,0,0,148,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,29,0,0,6,29,0,0,92,13,0,0,182,20,0,0,192,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,56,22,0,0,106,21,0,0,196,23,0,0,38,22,0,0,186,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,36,19,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,168,23,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,186,18,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,52,13,0,0,72,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,224,19,0,0,240,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,210,34,0,0,216,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,70,33,0,0,44,33,0,0,32,19,0,0,96,15,0,0,126,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,4,31,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,242,26,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,48,27,0,0,66,27,0,0,26,12,0,0,234,19,0,0,96,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,28,3,0,0,154,6,0,0,210,32,0,0,200,8,0,0,148,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,29,0,0,6,29,0,0,92,13,0,0,182,20,0,0,192,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,56,22,0,0,106,21,0,0,196,23,0,0,38,22,0,0,186,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,36,19,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,168,23,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,186,18,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,52,13,0,0,72,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,224,19,0,0,240,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,210,34,0,0,216,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,70,33,0,0,44,33,0,0,32,19,0,0,96,15,0,0,126,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,4,31,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,242,26,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,48,27,0,0,66,27,0,0,26,12,0,0,234,19,0,0,96,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0])
.concat([150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,28,3,0,0,154,6,0,0,210,32,0,0,200,8,0,0,148,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,29,0,0,6,29,0,0,92,13,0,0,182,20,0,0,192,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,56,22,0,0,106,21,0,0,196,23,0,0,38,22,0,0,186,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,36,19,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,168,23,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,186,18,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,52,13,0,0,72,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,224,19,0,0,240,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,210,34,0,0,216,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,70,33,0,0,44,33,0,0,32,19,0,0,96,15,0,0,126,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,4,31,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,242,26,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,48,27,0,0,66,27,0,0,26,12,0,0,234,19,0,0,96,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,28,3,0,0,154,6,0,0,210,32,0,0,200,8,0,0,148,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,29,0,0,6,29,0,0,92,13,0,0,182,20,0,0,192,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,56,22,0,0,106,21,0,0,196,23,0,0,38,22,0,0,186,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,36,19,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,168,23,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,186,18,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,52,13,0,0,72,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,224,19,0,0,240,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,210,34,0,0,216,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,70,33,0,0,44,33,0,0,32,19,0,0,96,15,0,0,126,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,4,31,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,242,26,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,48,27,0,0,66,27,0,0,26,12,0,0,234,19,0,0,96,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,28,3,0,0,154,6,0,0,210,32,0,0,200,8,0,0,148,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,29,0,0,6,29,0,0,92,13,0,0,182,20,0,0,192,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,56,22,0,0,106,21,0,0,196,23,0,0,38,22,0,0,186,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,36,19,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,168,23,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,186,18,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,52,13,0,0,72,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,224,19,0,0,240,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,210,34,0,0,216,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,70,33,0,0,44,33,0,0,32,19,0,0,96,15,0,0,126,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,4,31,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,242,26,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,48,27,0,0,66,27,0,0,26,12,0,0,234,19,0,0,96,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,28,3,0,0,154,6,0,0,210,32,0,0,200,8,0,0,148,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,29,0,0,6,29,0,0,92,13,0,0,182,20,0,0,192,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,56,22,0,0,106,21,0,0,196,23,0,0,38,22,0,0,186,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,36,19,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,168,23,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,186,18,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,52,13,0,0,72,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,224,19,0,0,240,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,210,34,0,0,216,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,70,33,0,0,44,33,0,0,32,19,0,0,96,15,0,0,126,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,4,31,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,242,26,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,48,27,0,0,66,27,0,0,26,12,0,0,234,19,0,0,96,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,28,3,0,0,154,6,0,0,210,32,0,0,200,8,0,0,148,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,29,0,0,6,29,0,0,92,13,0,0,182,20,0,0,192,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,56,22,0,0,106,21,0,0,196,23,0,0,38,22,0,0,186,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,6,8,0,0,36,19,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,168,23,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,186,18,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,52,13,0,0,72,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,224,19,0,0,240,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,210,34,0,0,216,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,70,33,0,0,44,33,0,0,32,19,0,0,96,15,0,0,126,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,238,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,60,27,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,208,24,0,0,4,31,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,224,24,0,0,242,26,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,4,3,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,48,27,0,0,66,27,0,0,26,12,0,0,234,19,0,0,96,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,104,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0])
.concat([150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,150,6,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,176,12,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,246,10,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,22,11,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,58,27,0,0,28,3,0,0,154,6,0,0,210,32,0,0,200,8,0,0,148,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,250,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,10,29,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,120,31,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,182,4,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,138,0,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,8,0,0,28,29,0,0,6,29,0,0,92,13,0,0,182,20,0,0,192,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,86,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,100,24,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,214,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,232,19,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,194,4,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,40,2,0,0,56,22,0,0,106,21,0,0,196,23,0,0,38,22,0,0,186,12,0,0,206,0,0,0,206,0,0,0,206,0,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,126,27,0,0,126,27,0,0,126,27,0,0,126,27,0,0,126,27,0,0,126,27,0,0,126,27,0,0,28,23,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,76,13,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,230,20,0,0,168,23,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,120,16,0,0,186,18,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,198,25,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,86,34,0,0,52,13,0,0,72,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,244,19,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,116,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,122,12,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,108,28,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,150,36,0,0,224,19,0,0,240,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,218,34,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,86,29,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,48,5,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,76,18,0,0,210,34,0,0,216,34,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,140,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,48,33,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,44,11,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,46,31,0,0,70,33,0,0,44,33,0,0,32,19,0,0,96,15,0,0,126,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,254,29,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,94,8,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,134,36,0,0,194,22,0,0,18,3,0,0,100,27,0,0,24,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,178,1,0,0,112,8,0,0,18,16,0,0,108,16,0,0,240,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,28,34,0,0,48,22,0,0,122,27,0,0,126,28,0,0,198,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,26,0,0,0,2,0,0,0,214,26,0,0,146,29,0,0,222,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,220,21,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,68,32,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,224,26,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,34,11,0,0,50,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,156,4,0,0,146,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,198,23,0,0,194,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,158,26,0,0,74,26,0,0,56,25,0,0,86,14,0,0,254,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,254,29,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,94,8,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,134,36,0,0,194,22,0,0,18,3,0,0,100,27,0,0,24,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,178,1,0,0,112,8,0,0,18,16,0,0,108,16,0,0,240,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,28,34,0,0,48,22,0,0,122,27,0,0,126,28,0,0,198,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,26,0,0,0,2,0,0,0,214,26,0,0,146,29,0,0,222,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,220,21,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,68,32,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,224,26,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,34,11,0,0,50,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,156,4,0,0,146,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,198,23,0,0,194,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,158,26,0,0,74,26,0,0,56,25,0,0,86,14,0,0,254,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,254,29,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,94,8,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,134,36,0,0,194,22,0,0,18,3,0,0,100,27,0,0,24,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,178,1,0,0,112,8,0,0,18,16,0,0,108,16,0,0,240,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,28,34,0,0,48,22,0,0,122,27,0,0,126,28,0,0,198,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,26,0,0,0,2,0,0,0,214,26,0,0,146,29,0,0,222,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,220,21,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,68,32,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,224,26,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,34,11,0,0,50,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,156,4,0,0,146,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,198,23,0,0,194,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,158,26,0,0,74,26,0,0,56,25,0,0,86,14,0,0,254,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,254,29,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,94,8,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,134,36,0,0,194,22,0,0,18,3,0,0,100,27,0,0,24,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,178,1,0,0,112,8,0,0,18,16,0,0,108,16,0,0,240,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,28,34,0,0,48,22,0,0,122,27,0,0,126,28,0,0,198,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,26,0,0,0,2,0,0,0,214,26,0,0,146,29,0,0,222,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,220,21,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,68,32,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,224,26,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,34,11,0,0,50,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,156,4,0,0,146,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,198,23,0,0,194,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,158,26,0,0,74,26,0,0,56,25,0,0,86,14,0,0,254,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,254,29,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,94,8,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,134,36,0,0,194,22,0,0,18,3,0,0,100,27,0,0,24,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0])
.concat([150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,178,1,0,0,112,8,0,0,18,16,0,0,108,16,0,0,240,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,28,34,0,0,48,22,0,0,122,27,0,0,126,28,0,0,198,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,26,0,0,0,2,0,0,0,214,26,0,0,146,29,0,0,222,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,220,21,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,68,32,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,224,26,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,34,11,0,0,50,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,156,4,0,0,146,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,198,23,0,0,194,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,158,26,0,0,74,26,0,0,56,25,0,0,86,14,0,0,254,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,254,29,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,94,8,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,134,36,0,0,194,22,0,0,18,3,0,0,100,27,0,0,24,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,178,1,0,0,112,8,0,0,18,16,0,0,108,16,0,0,240,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,28,34,0,0,48,22,0,0,122,27,0,0,126,28,0,0,198,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,26,0,0,0,2,0,0,0,214,26,0,0,146,29,0,0,222,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,220,21,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,68,32,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,224,26,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,34,11,0,0,50,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,156,4,0,0,146,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,198,23,0,0,194,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,158,26,0,0,74,26,0,0,56,25,0,0,86,14,0,0,254,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,254,29,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,94,8,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,134,36,0,0,194,22,0,0,18,3,0,0,100,27,0,0,24,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,178,1,0,0,112,8,0,0,18,16,0,0,108,16,0,0,240,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,28,34,0,0,48,22,0,0,122,27,0,0,126,28,0,0,198,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,26,0,0,0,2,0,0,0,214,26,0,0,146,29,0,0,222,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,58,12,0,0,220,21,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,68,32,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,224,26,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,34,11,0,0,50,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,156,4,0,0,146,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,198,23,0,0,194,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,158,26,0,0,74,26,0,0,56,25,0,0,86,14,0,0,254,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,182,21,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,136,27,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,90,16,0,0,254,29,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,14,26,0,0,94,8,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,160,21,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,38,11,0,0,134,36,0,0,194,22,0,0,18,3,0,0,100,27,0,0,24,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,254,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,246,7,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,150,1,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,226,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,236,35,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,130,32,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,60,17,0,0,178,1,0,0,112,8,0,0,18,16,0,0,108,16,0,0,240,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,54,23,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,212,9,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,50,22,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,214,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,216,29,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,134,31,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,240,1,0,0,28,34,0,0,48,22,0,0,122,27,0,0,126,28,0,0,198,9,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,224,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,232,6,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,52,0,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,72,30,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,212,11,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,74,24,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,228,15,0,0,26,0,0,0,2,0,0,0,214,26,0,0,146,29,0,0,222,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,94,1,0,0,44,19,0,0,44,19,0,0,44,19,0,0,44,19,0,0,44,19,0,0,44,19,0,0,44,19,0,0,220,26,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,40,11,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,68,32,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,124,12,0,0,224,26,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,198,34,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,244,31,0,0,34,11,0,0,50,11,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,190,5,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,170,3,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,250,26,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,70,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,60,2,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,62,27,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,212,24,0,0,156,4,0,0,146,4,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,104,2,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,22,4,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,202,26,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,70,21,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,110,18,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,184,27,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,92,7,0,0,198,23,0,0,194,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,170,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,176,33,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,86,10,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,220,12,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,8,3,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,248,34,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,102,13,0,0,158,26,0,0,74,26,0,0,56,25,0,0,86,14,0,0,254,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0])
.concat([90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0])
.concat([90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,90,22,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,98,19,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,102,27,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,208,15,0,0,184,15,0,0,242,21,0,0,66,18,0,0,228,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,240,9,0,0,134,16,0,0,112,30,0,0,142,10,0,0,194,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,194,3,0,0,180,3,0,0,192,12,0,0,52,25,0,0,228,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,38,30,0,0,182,35,0,0,156,32,0,0,250,2,0,0,116,36,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,120,7,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,48,13,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,12,21,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,126,1,0,0,110,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,190,6,0,0,208,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,128,23,0,0,134,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,162,1,0,0,176,1,0,0,88,17,0,0,176,35,0,0,244,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,98,19,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,102,27,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,208,15,0,0,184,15,0,0,242,21,0,0,66,18,0,0,228,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,240,9,0,0,134,16,0,0,112,30,0,0,142,10,0,0,194,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,194,3,0,0,180,3,0,0,192,12,0,0,52,25,0,0,228,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,38,30,0,0,182,35,0,0,156,32,0,0,250,2,0,0,116,36,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,120,7,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,48,13,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,12,21,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,126,1,0,0,110,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,190,6,0,0,208,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,128,23,0,0,134,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,162,1,0,0,176,1,0,0,88,17,0,0,176,35,0,0,244,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,98,19,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,102,27,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,208,15,0,0,184,15,0,0,242,21,0,0,66,18,0,0,228,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,240,9,0,0,134,16,0,0,112,30,0,0,142,10,0,0,194,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,194,3,0,0,180,3,0,0,192,12,0,0,52,25,0,0,228,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,38,30,0,0,182,35,0,0,156,32,0,0,250,2,0,0,116,36,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,120,7,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,48,13,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,12,21,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,126,1,0,0,110,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,190,6,0,0,208,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,128,23,0,0,134,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,162,1,0,0,176,1,0,0,88,17,0,0,176,35,0,0,244,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,98,19,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,102,27,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,208,15,0,0,184,15,0,0,242,21,0,0,66,18,0,0,228,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0])
.concat([244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,240,9,0,0,134,16,0,0,112,30,0,0,142,10,0,0,194,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,194,3,0,0,180,3,0,0,192,12,0,0,52,25,0,0,228,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,38,30,0,0,182,35,0,0,156,32,0,0,250,2,0,0,116,36,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,120,7,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,48,13,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,12,21,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,126,1,0,0,110,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,190,6,0,0,208,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,128,23,0,0,134,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,162,1,0,0,176,1,0,0,88,17,0,0,176,35,0,0,244,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,98,19,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,102,27,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,208,15,0,0,184,15,0,0,242,21,0,0,66,18,0,0,228,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,240,9,0,0,134,16,0,0,112,30,0,0,142,10,0,0,194,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,194,3,0,0,180,3,0,0,192,12,0,0,52,25,0,0,228,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,38,30,0,0,182,35,0,0,156,32,0,0,250,2,0,0,116,36,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,120,7,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,48,13,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,12,21,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,126,1,0,0,110,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,190,6,0,0,208,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,128,23,0,0,134,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,162,1,0,0,176,1,0,0,88,17,0,0,176,35,0,0,244,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,98,19,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,102,27,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,208,15,0,0,184,15,0,0,242,21,0,0,66,18,0,0,228,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,240,9,0,0,134,16,0,0,112,30,0,0,142,10,0,0,194,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,194,3,0,0,180,3,0,0,192,12,0,0,52,25,0,0,228,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,38,30,0,0,182,35,0,0,156,32,0,0,250,2,0,0,116,36,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,120,7,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,48,13,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,12,21,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,126,1,0,0,110,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,190,6,0,0,208,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,128,23,0,0,134,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,162,1,0,0,176,1,0,0,88,17,0,0,176,35,0,0,244,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,98,19,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,102,27,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,208,15,0,0,184,15,0,0,242,21,0,0,66,18,0,0,228,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,240,9,0,0,134,16,0,0,112,30,0,0,142,10,0,0,194,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,194,3,0,0,180,3,0,0,192,12,0,0,52,25,0,0,228,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,38,30,0,0,182,35,0,0,156,32,0,0,250,2,0,0,116,36,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,194,20,0,0,120,7,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,48,13,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,12,21,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,126,1,0,0,110,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,190,6,0,0,208,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,128,23,0,0,134,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,162,1,0,0,176,1,0,0,88,17,0,0,176,35,0,0,244,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,178,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,190,15,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,34,8,0,0,98,19,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,42,8,0,0,102,27,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,180,36,0,0,208,15,0,0,184,15,0,0,242,21,0,0,66,18,0,0,228,26,0,0,206,0,0,0,206,0,0,0,206,0,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,198,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,202,28,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,244,5,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,14,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,16,14,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,134,9,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,222,32,0,0,240,9,0,0,134,16,0,0,112,30,0,0,142,10,0,0,194,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,102,18,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,196,16,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,242,23,0,0,194,3,0,0,180,3,0,0,192,12,0,0,52,25,0,0,228,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,128,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,126,36,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,178,35,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,162,21,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,40,28,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,12,7,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,230,14,0,0,38,30,0,0,182,35,0,0,156,32,0,0,250,2,0,0,116,36,0,0,206,0,0,0,206,0,0,0,206,0,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,138,7,0,0,32,5,0,0,32,5,0,0,32,5,0,0,32,5,0,0,32,5,0,0,32,5,0,0,32,5,0,0,182,25,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,104,1,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,188,36,0,0,48,13,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,160,30,0,0,12,21,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,124,9,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,18,32,0,0,126,1,0,0,110,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,136,22,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,160,20,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,212,6,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,184,18,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,20,14,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,182,36,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,246,22,0,0,190,6,0,0,208,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,226,12,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,254,25,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,220,29,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,34,22,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,192,23,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,74,0,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,44,3,0,0,128,23,0,0,134,23,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,240,6,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,82,10,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,230,8,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,248,3,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,34,23,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,108,19,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,138,21,0,0,162,1,0,0,176,1,0,0,88,17,0,0,176,35,0,0,244,6,0,0,206,0,0,0,206,0,0,0,206,0,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,208,10,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,224,23,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,100,7,0,0,24,29,0,0,190,14,0,0,176,36,0,0,82,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0])
.concat([102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,192,17,0,0,154,17,0,0,230,21,0,0,126,15,0,0,230,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,170,4,0,0,188,4,0,0,58,33,0,0,232,5,0,0,178,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,212,15,0,0,148,23,0,0,54,11,0,0,64,18,0,0,168,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,74,11,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,114,25,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,2,2,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,30,29,0,0,244,33,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,166,5,0,0,174,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,104,20,0,0,94,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,10,32,0,0,66,9,0,0,50,35,0,0,88,1,0,0,170,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,208,10,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,224,23,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,100,7,0,0,24,29,0,0,190,14,0,0,176,36,0,0,82,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,192,17,0,0,154,17,0,0,230,21,0,0,126,15,0,0,230,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,170,4,0,0,188,4,0,0,58,33,0,0,232,5,0,0,178,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,212,15,0,0,148,23,0,0,54,11,0,0,64,18,0,0,168,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,74,11,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,114,25,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,2,2,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,30,29,0,0,244,33,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,166,5,0,0,174,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,104,20,0,0,94,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,10,32,0,0,66,9,0,0,50,35,0,0,88,1,0,0,170,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,208,10,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,224,23,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,100,7,0,0,24,29,0,0,190,14,0,0,176,36,0,0,82,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,192,17,0,0,154,17,0,0,230,21,0,0,126,15,0,0,230,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,170,4,0,0,188,4,0,0,58,33,0,0,232,5,0,0,178,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,212,15,0,0,148,23,0,0,54,11,0,0,64,18,0,0,168,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,74,11,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,114,25,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,2,2,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,30,29,0,0,244,33,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,166,5,0,0,174,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,104,20,0,0,94,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,10,32,0,0,66,9,0,0,50,35,0,0,88,1,0,0,170,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,208,10,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,224,23,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,100,7,0,0,24,29,0,0,190,14,0,0,176,36,0,0,82,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,192,17,0,0,154,17,0,0,230,21,0,0,126,15,0,0,230,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,170,4,0,0,188,4,0,0,58,33,0,0,232,5,0,0,178,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,212,15,0,0,148,23,0,0,54,11,0,0,64,18,0,0,168,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,74,11,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,114,25,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,2,2,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,30,29,0,0,244,33,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,166,5,0,0,174,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,104,20,0,0,94,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,10,32,0,0,66,9,0,0,50,35,0,0,88,1,0,0,170,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,208,10,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,224,23,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,100,7,0,0,24,29,0,0,190,14,0,0,176,36,0,0,82,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,192,17,0,0,154,17,0,0,230,21,0,0,126,15,0,0,230,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,170,4,0,0,188,4,0,0,58,33,0,0,232,5,0,0,178,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,212,15,0,0,148,23,0,0,54,11,0,0,64,18,0,0,168,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,74,11,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,114,25,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,2,2,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,30,29,0,0,244,33,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,166,5,0,0,174,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,104,20,0,0,94,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,10,32,0,0,66,9,0,0,50,35,0,0,88,1,0,0,170,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,208,10,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,224,23,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,100,7,0,0,24,29,0,0,190,14,0,0,176,36,0,0,82,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0])
.concat([102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,192,17,0,0,154,17,0,0,230,21,0,0,126,15,0,0,230,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,170,4,0,0,188,4,0,0,58,33,0,0,232,5,0,0,178,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,212,15,0,0,148,23,0,0,54,11,0,0,64,18,0,0,168,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,74,11,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,114,25,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,2,2,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,30,29,0,0,244,33,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,166,5,0,0,174,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,104,20,0,0,94,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,10,32,0,0,66,9,0,0,50,35,0,0,88,1,0,0,170,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,208,10,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,224,23,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,100,7,0,0,24,29,0,0,190,14,0,0,176,36,0,0,82,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,192,17,0,0,154,17,0,0,230,21,0,0,126,15,0,0,230,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,170,4,0,0,188,4,0,0,58,33,0,0,232,5,0,0,178,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,212,15,0,0,148,23,0,0,54,11,0,0,64,18,0,0,168,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,108,23,0,0,74,11,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,114,25,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,2,2,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,30,29,0,0,244,33,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,166,5,0,0,174,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,104,20,0,0,94,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,10,32,0,0,66,9,0,0,50,35,0,0,88,1,0,0,170,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,66,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,112,11,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,240,14,0,0,208,10,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,252,14,0,0,224,23,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,142,0,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,34,28,0,0,100,7,0,0,24,29,0,0,190,14,0,0,176,36,0,0,82,17,0,0,206,0,0,0,206,0,0,0,206,0,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,212,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,102,34,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,62,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,56,10,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,46,26,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,8,2,0,0,192,17,0,0,154,17,0,0,230,21,0,0,126,15,0,0,230,10,0,0,206,0,0,0,206,0,0,0,206,0,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,140,16,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,64,28,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,82,13,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,122,5,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,40,29,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,198,31,0,0,170,4,0,0,188,4,0,0,58,33,0,0,232,5,0,0,178,14,0,0,206,0,0,0,206,0,0,0,206,0,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,178,23,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,98,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,96,8,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,124,23,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,212,15,0,0,148,23,0,0,54,11,0,0,64,18,0,0,168,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,22,25,0,0,140,23,0,0,140,23,0,0,140,23,0,0,140,23,0,0,140,23,0,0,140,23,0,0,140,23,0,0,238,13,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,12,29,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,154,26,0,0,114,25,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,228,12,0,0,2,2,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,124,20,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,26,8,0,0,30,29,0,0,244,33,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,112,7,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,24,31,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,172,5,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,236,7,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,128,12,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,40,30,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,84,27,0,0,166,5,0,0,174,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,118,7,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,236,12,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,188,22,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,28,27,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,246,6,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,184,25,0,0,104,20,0,0,94,20,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,254,13,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,62,9,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,138,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,136,11,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,112,17,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,66,32,0,0,10,32,0,0,66,9,0,0,50,35,0,0,88,1,0,0,170,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,50,3,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,190,10,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,58,34,0,0,94,34,0,0,138,6,0,0,2,27,0,0,188,29,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,130,23,0,0,146,13,0,0,100,11,0,0,42,36,0,0,6,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,90,2,0,0,76,2,0,0,206,34,0,0,234,26,0,0,236,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,142,21,0,0,174,21,0,0,0,24,0,0,210,16,0,0,86,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,232,33,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,188,32,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,140,7,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,196,18,0,0,168,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,60,1,0,0,48,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,204,27,0,0,236,27,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,88,18,0,0,246,1,0,0,140,15,0,0,172,12,0,0,46,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,50,3,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,190,10,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,58,34,0,0,94,34,0,0,138,6,0,0,2,27,0,0,188,29,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,130,23,0,0,146,13,0,0,100,11,0,0,42,36,0,0,6,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,90,2,0,0,76,2,0,0,206,34,0,0,234,26,0,0,236,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,142,21,0,0,174,21,0,0,0,24,0,0,210,16,0,0,86,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,232,33,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,188,32,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,140,7,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,196,18,0,0,168,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,60,1,0,0,48,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,204,27,0,0,236,27,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,88,18,0,0,246,1,0,0,140,15,0,0,172,12,0,0,46,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,50,3,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,190,10,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,58,34,0,0,94,34,0,0,138,6,0,0,2,27,0,0,188,29,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0])
.concat([142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,130,23,0,0,146,13,0,0,100,11,0,0,42,36,0,0,6,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,90,2,0,0,76,2,0,0,206,34,0,0,234,26,0,0,236,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,142,21,0,0,174,21,0,0,0,24,0,0,210,16,0,0,86,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,232,33,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,188,32,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,140,7,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,196,18,0,0,168,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,60,1,0,0,48,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,204,27,0,0,236,27,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,88,18,0,0,246,1,0,0,140,15,0,0,172,12,0,0,46,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,50,3,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,190,10,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,58,34,0,0,94,34,0,0,138,6,0,0,2,27,0,0,188,29,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,130,23,0,0,146,13,0,0,100,11,0,0,42,36,0,0,6,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,90,2,0,0,76,2,0,0,206,34,0,0,234,26,0,0,236,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,142,21,0,0,174,21,0,0,0,24,0,0,210,16,0,0,86,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,232,33,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,188,32,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,140,7,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,196,18,0,0,168,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,60,1,0,0,48,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,204,27,0,0,236,27,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,88,18,0,0,246,1,0,0,140,15,0,0,172,12,0,0,46,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,50,3,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,190,10,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,58,34,0,0,94,34,0,0,138,6,0,0,2,27,0,0,188,29,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,130,23,0,0,146,13,0,0,100,11,0,0,42,36,0,0,6,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,90,2,0,0,76,2,0,0,206,34,0,0,234,26,0,0,236,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,142,21,0,0,174,21,0,0,0,24,0,0,210,16,0,0,86,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,232,33,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,188,32,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,140,7,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,196,18,0,0,168,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,60,1,0,0,48,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,204,27,0,0,236,27,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,88,18,0,0,246,1,0,0,140,15,0,0,172,12,0,0,46,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,50,3,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,190,10,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,58,34,0,0,94,34,0,0,138,6,0,0,2,27,0,0,188,29,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,130,23,0,0,146,13,0,0,100,11,0,0,42,36,0,0,6,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,90,2,0,0,76,2,0,0,206,34,0,0,234,26,0,0,236,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,142,21,0,0,174,21,0,0,0,24,0,0,210,16,0,0,86,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,232,33,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,188,32,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,140,7,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,196,18,0,0,168,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,60,1,0,0,48,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,204,27,0,0,236,27,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,88,18,0,0,246,1,0,0,140,15,0,0,172,12,0,0,46,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,50,3,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,190,10,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,58,34,0,0,94,34,0,0,138,6,0,0,2,27,0,0,188,29,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,130,23,0,0,146,13,0,0,100,11,0,0,42,36,0,0,6,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,90,2,0,0,76,2,0,0,206,34,0,0,234,26,0,0,236,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,142,21,0,0,174,21,0,0,0,24,0,0,210,16,0,0,86,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,254,3,0,0,232,33,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,188,32,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,140,7,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,196,18,0,0,168,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,60,1,0,0,48,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,204,27,0,0,236,27,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,88,18,0,0,246,1,0,0,140,15,0,0,172,12,0,0,46,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,220,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,236,18,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,104,7,0,0,50,3,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,236,31,0,0,190,10,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,224,25,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,226,17,0,0,58,34,0,0,94,34,0,0,138,6,0,0,2,27,0,0,188,29,0,0,206,0,0,0,206,0,0,0,206,0,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,10,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0,6,20,0,0])
.concat([142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,142,13,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,240,10,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,30,21,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,204,1,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,162,34,0,0,130,23,0,0,146,13,0,0,100,11,0,0,42,36,0,0,6,22,0,0,206,0,0,0,206,0,0,0,206,0,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,238,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,84,2,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,132,31,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,44,9,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,250,16,0,0,90,2,0,0,76,2,0,0,206,34,0,0,234,26,0,0,236,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,96,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,100,3,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,180,21,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,206,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,100,29,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,98,14,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,142,21,0,0,174,21,0,0,0,24,0,0,210,16,0,0,86,3,0,0,206,0,0,0,206,0,0,0,206,0,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,190,28,0,0,148,36,0,0,148,36,0,0,148,36,0,0,148,36,0,0,148,36,0,0,148,36,0,0,148,36,0,0,170,5,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,174,18,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,120,26,0,0,188,32,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,126,26,0,0,140,7,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,140,10,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,22,35,0,0,196,18,0,0,168,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,46,11,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,200,31,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,110,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,148,21,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,140,25,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,114,31,0,0,60,1,0,0,48,7,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,230,32,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,158,8,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,232,27,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,58,30,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,234,34,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,24,14,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,28,7,0,0,204,27,0,0,236,27,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,68,30,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,246,34,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,250,1,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,140,0,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,66,3,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,168,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,194,17,0,0,88,18,0,0,246,1,0,0,140,15,0,0,172,12,0,0,46,30,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,160,3,0,0,160,3,0,0,160,3,0,0,160,3,0,0,160,3,0,0,160,3,0,0,160,3,0,0,160,3,0,0,88,19,0,0,88,19,0,0,88,19,0,0,88,19,0,0,88,19,0,0,88,19,0,0,88,19,0,0,88,19,0,0,174,27,0,0,174,27,0,0,174,27,0,0,174,27,0,0,174,27,0,0,174,27,0,0,174,27,0,0,174,27,0,0,42,33,0,0,42,33,0,0,42,33,0,0,42,33,0,0,42,33,0,0,42,33,0,0,42,33,0,0,42,33,0,0,92,19,0,0,92,19,0,0,92,19,0,0,92,19,0,0,92,19,0,0,92,19,0,0,92,19,0,0,92,19,0,0,130,3,0,0,228,28,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,222,9,0,0,222,9,0,0,222,9,0,0,222,9,0,0,222,9,0,0,222,9,0,0,222,9,0,0,222,9,0,0,182,32,0,0,182,32,0,0,182,32,0,0,182,32,0,0,182,32,0,0,182,32,0,0,182,32,0,0,182,32,0,0,216,32,0,0,216,32,0,0,216,32,0,0,216,32,0,0,216,32,0,0,216,32,0,0,216,32,0,0,216,32,0,0,142,18,0,0,142,18,0,0,142,18,0,0,142,18,0,0,142,18,0,0,142,18,0,0,142,18,0,0,142,18,0,0,106,11,0,0,106,11,0,0,106,11,0,0,106,11,0,0,106,11,0,0,106,11,0,0,106,11,0,0,106,11,0,0,112,32,0,0,80,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,172,18,0,0,172,18,0,0,172,18,0,0,172,18,0,0,172,18,0,0,172,18,0,0,172,18,0,0,172,18,0,0,106,12,0,0,106,12,0,0,106,12,0,0,106,12,0,0,106,12,0,0,106,12,0,0,106,12,0,0,106,12,0,0,96,12,0,0,96,12,0,0,96,12,0,0,96,12,0,0,96,12,0,0,96,12,0,0,96,12,0,0,96,12,0,0,32,27,0,0,32,27,0,0,32,27,0,0,32,27,0,0,32,27,0,0,32,27,0,0,32,27,0,0,32,27,0,0,12,4,0,0,12,4,0,0,12,4,0,0,12,4,0,0,12,4,0,0,12,4,0,0,12,4,0,0,12,4,0,0,198,18,0,0,176,18,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,90,32,0,0,90,32,0,0,90,32,0,0,90,32,0,0,90,32,0,0,90,32,0,0,90,32,0,0,90,32,0,0,158,24,0,0,158,24,0,0,158,24,0,0,158,24,0,0,158,24,0,0,158,24,0,0,158,24,0,0,158,24,0,0,144,24,0,0,144,24,0,0,144,24,0,0,144,24,0,0,144,24,0,0,144,24,0,0,144,24,0,0,144,24,0,0,196,19,0,0,196,19,0,0,196,19,0,0,196,19,0,0,196,19,0,0,196,19,0,0,196,19,0,0,196,19,0,0,156,11,0,0,156,11,0,0,156,11,0,0,156,11,0,0,156,11,0,0,156,11,0,0,156,11,0,0,156,11,0,0,94,32,0,0,86,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,236,5,0,0,236,5,0,0,236,5,0,0,236,5,0,0,236,5,0,0,236,5,0,0,236,5,0,0,236,5,0,0,40,8,0,0,40,8,0,0,40,8,0,0,40,8,0,0,40,8,0,0,40,8,0,0,40,8,0,0,40,8,0,0,36,8,0,0,36,8,0,0,36,8,0,0,36,8,0,0,36,8,0,0,36,8,0,0,36,8,0,0,36,8,0,0,94,29,0,0,94,29,0,0,94,29,0,0,94,29,0,0,94,29,0,0,94,29,0,0,94,29,0,0,94,29,0,0,140,26,0,0,140,26,0,0,140,26,0,0,140,26,0,0,140,26,0,0,140,26,0,0,140,26,0,0,140,26,0,0,190,36,0,0,230,5,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,34,6,0,0,34,6,0,0,34,6,0,0,34,6,0,0,34,6,0,0,34,6,0,0,34,6,0,0,34,6,0,0,218,11,0,0,218,11,0,0,218,11,0,0,218,11,0,0,218,11,0,0,218,11,0,0,218,11,0,0,218,11,0,0,234,11,0,0,234,11,0,0,234,11,0,0,234,11,0,0,234,11,0,0,234,11,0,0,234,11,0,0,234,11,0,0,212,27,0,0,212,27,0,0,212,27,0,0,212,27,0,0,212,27,0,0,212,27,0,0,212,27,0,0,212,27,0,0,230,35,0,0,230,35,0,0,230,35,0,0,230,35,0,0,230,35,0,0,230,35,0,0,230,35,0,0,230,35,0,0,68,19,0,0,76,19,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,224,1,0,0,224,1,0,0,224,1,0,0,224,1,0,0,224,1,0,0,224,1,0,0,224,1,0,0,224,1,0,0,88,31,0,0,88,31,0,0,88,31,0,0,88,31,0,0,88,31,0,0,88,31,0,0,88,31,0,0,88,31,0,0,76,31,0,0,76,31,0,0,76,31,0,0,76,31,0,0,76,31,0,0,76,31,0,0,76,31,0,0,76,31,0,0,46,25,0,0,46,25,0,0,46,25,0,0,46,25,0,0,46,25,0,0,46,25,0,0,46,25,0,0,46,25,0,0,10,18,0,0,10,18,0,0,10,18,0,0,10,18,0,0,10,18,0,0,10,18,0,0,10,18,0,0,10,18,0,0,94,12,0,0,48,2,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,134,8,0,0,134,8,0,0,134,8,0,0,134,8,0,0,134,8,0,0,134,8,0,0,134,8,0,0,134,8,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,62,1,0,0,62,1,0,0,62,1,0,0,62,1,0,0,62,1,0,0,62,1,0,0,62,1,0,0,62,1,0,0,4,32,0,0,4,32,0,0,4,32,0,0,4,32,0,0,4,32,0,0,4,32,0,0,4,32,0,0,4,32,0,0,92,29,0,0,92,29,0,0,92,29,0,0,92,29,0,0,92,29,0,0,92,29,0,0,92,29,0,0,92,29,0,0,172,8,0,0,140,8,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0])
.concat([14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,68,33,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,146,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,134,19,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,46,6,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,8,32,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,148,19,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,90,8,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,100,21,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,6,34,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,14,17,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,64,15,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,98,21,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,12,17,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,66,15,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,204,11,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,154,12,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,94,24,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,130,25,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,100,35,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,214,33,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,92,24,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,132,25,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,170,28,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,108,17,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,82,24,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,76,29,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,112,36,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,110,17,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,120,22,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,206,16,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,10,34,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,50,16,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,198,2,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,20,20,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,8,34,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,52,16,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,60,13,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,22,20,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,234,32,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,170,26,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,46,36,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,190,23,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,194,7,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,172,26,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,140,13,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,252,32,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0])
.concat([92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0])
.concat([92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,92,15,0,0,160,0,16,0,200,0,200,0,136,0,152,0,160,0,136,0,136,0,136,0,16,0,16,0,16,0,16,0,16,0,176,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,176,0,176,0,176,0,176,0,176,0,176,0,176,0,176,0,136,0,136,0,136,0,136,0,136,0,136,0,136,0,136,0,136,0,136,0,136,0,136,0,136,0,136,0,136,0,136,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,24,1,28,0,94,1,94,1,238,0,10,1,24,1,238,0,238,0,238,0,28,0,28,0,28,0,28,0,28,0,52,1,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,52,1,52,1,52,1,52,1,52,1,52,1,52,1,52,1,238,0,238,0,238,0,238,0,238,0,238,0,238,0,238,0,238,0,238,0,238,0,238,0,238,0,238,0,238,0,238,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,28,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,80,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,80,0,0,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,136,136,136,136,136,136,136,136,128,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,64,64,64,64,64,64,64,64,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,40,40,40,40,40,40,40,40,64,64,64,64,64,64,64,64,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,80,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,80,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,136,136,136,136,136,136,136,136,128,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,64,64,64,64,64,64,64,64,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,40,40,40,40,40,40,40,40,64,64,64,64,64,64,64,64,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,0,0,0,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,136,136,136,136,136,136,136,136,128,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,64,64,64,64,64,64,64,64,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,40,40,40,40,40,40,40,40,64,64,64,64,64,64,64,64,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,0,0,0,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,136,136,136,136,136,136,136,136,128,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,64,64,64,64,64,64,64,64,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,40,40,40,40,40,40,40,40,64,64,64,64,64,64,64,64,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,40,40,40,40,40,40,40,40,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,0,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,0,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,0,0,0,0,24,24,24,24,24,24,24,24,64,64,64,64,64,64,64,64,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,40,40,40,40,40,40,40,40,64,64,64,64,64,64,64,64,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,80,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,0,0,80,0,0,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,136,136,136,136,136,136,136,136,128,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,64,64,64,64,64,64,64,64,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,40,40,40,40,40,40,40,40,64,64,64,64,64,64,64,64,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,64,64,64,64,64,64,64,64,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,40,40,40,40,40,40,40,40,64,64,64,64,64,64,64,64,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,64,64,64,64,64,64,64,64,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,40,40,40,40,40,40,40,40,64,64,64,64,64,64,64,64,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,96,96,96,96,96,96,96,96,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0])
.concat([48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,112,128,112,120,96,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,120,136,120,128,104,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,112,128,112,120,96,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,112,128,112,120,96,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,120,136,120,128,104,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,136,136,136,136,136,136,136,136,128,144,128,136,112,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,112,128,112,120,96,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,120,136,120,128,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,112,128,112,120,96,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,120,136,120,128,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,112,128,112,120,96,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,120,136,120,128,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,112,128,112,120,96,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,120,136,120,128,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,112,128,112,120,96,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,120,136,120,128,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,112,128,112,120,96,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,112,112,112,112,112,112,112,112,120,120,120,120,120,120,120,120,128,128,128,128,128,128,128,128,120,136,120,128,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,96,104,80,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0])
.concat([48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,88,96,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,40,40,40,40,40,40,40,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,32,48,32,48,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,40,40,40,40,40,40,40,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,32,48,32,48,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,40,40,40,40,40,40,40,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,32,48,32,48,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,80,96,80,88,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,40,40,40,40,40,40,40,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,32,48,32,48,0,0,0,0,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,80,80,80,80,80,80,80,80,64,80,64,80,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,40,40,40,40,40,40,40,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,32,48,32,48,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,88,104,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,40,40,40,40,40,40,40,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,32,48,32,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,40,40,40,40,40,40,40,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,32,48,32,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,64,64,64,64,64,64,64,64,48,48,48,48,48,48,48,48,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,16,16,80,0,64,16,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,72,72,72,72,72,72,72,88,88,88,88,88,88,88,88,72,80,72,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,40,40,40,40,40,40,40,56,56,56,56,56,56,56,56,40,48,40,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,40,40,40,40,40,40,40,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,32,48,32,48,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,24,24,24,24,24,24,24,24,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40])
.concat([40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,56,72,56,64,40,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,56,72,56,64,40,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,56,72,56,64,40,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0])
.concat([16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,56,72,56,64,40,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,56,72,56,64,40,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,56,72,56,64,40,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,56,72,56,64,40,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,56,72,56,64,40,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,56,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,24,24,24,24,24,24,24,24,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,32,48,32,40,16,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0])
.concat([16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,48,64,48,56,32,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,64,72,48,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,16,16,16,16,16,16,16,16,72,72,72,72,72,72,72,72,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,32,32,32,32,32,32,32,32,120,120,120,120,120,120,120,120,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,88,88,88,88,88,88,88,88,96,96,96,96,96,96,96,96,104,104,104,104,104,104,104,104,96,112,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,80,80,80,80,80,80,80,80,72,88,72,80,64,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,56,56,56,56,56,56,56,64,64,64,64,64,64,64,64,72,72,72,72,72,72,72,72,64,80,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,140,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,140,0,0,0,112,112,112,112,112,112,112,112,0,0,0,0,0,0,0,0,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,238,238,238,238,238,238,238,238,224,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,112,112,112,112,112,112,112,112,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,70,70,70,70,70,70,70,70,112,112,112,112,112,112,112,112,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,140,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,140,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,238,238,238,238,238,238,238,238,224,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,112,112,112,112,112,112,112,112,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,70,70,70,70,70,70,70,70,112,112,112,112,112,112,112,112,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,0,0,0,0,112,112,112,112,112,112,112,112,0,0,0,0,0,0,0,0,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,238,238,238,238,238,238,238,238,224,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,112,112,112,112,112,112,112,112,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0])
.concat([56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,70,70,70,70,70,70,70,70,112,112,112,112,112,112,112,112,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,0,0,0,0,112,112,112,112,112,112,112,112,0,0,0,0,0,0,0,0,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,238,238,238,238,238,238,238,238,224,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,112,112,112,112,112,112,112,112,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,70,70,70,70,70,70,70,70,112,112,112,112,112,112,112,112,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,70,70,70,70,70,70,70,70,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,0,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,0,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,0,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,0,0,0,0,42,42,42,42,42,42,42,42,112,112,112,112,112,112,112,112,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,70,70,70,70,70,70,70,70,112,112,112,112,112,112,112,112,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,140,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,0,0,140,0,0,0,112,112,112,112,112,112,112,112,0,0,0,0,0,0,0,0,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,238,238,238,238,238,238,238,238,224,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,112,112,112,112,112,112,112,112,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,70,70,70,70,70,70,70,70,112,112,112,112,112,112,112,112,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,112,112,112,112,112,112,112,112,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,70,70,70,70,70,70,70,70,112,112,112,112,112,112,112,112,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,112,112,112,112,112,112,112,112,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,70,70,70,70,70,70,70,70,112,112,112,112,112,112,112,112,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,168,168,168,168,168,168,168,168,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,112,112,112,112,112,112,112,112,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,0,0,0,0,0,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,196,224,196,210,168,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,210,238,210,224,182,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,196,224,196,210,168,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,196,224,196,210,168,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,210,238,210,224,182,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,238,238,238,238,238,238,238,238,224,252,224,238,196,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,196,224,196,210,168,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,210,238,210,224,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,196,224,196,210,168,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,210,238,210,224,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,196,224,196,210,168,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,210,238,210,224,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,196,224,196,210,168,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,210,238,210,224,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0])
.concat([112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,196,224,196,210,168,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,210,238,210,224,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,196,224,196,210,168,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,182,196,196,196,196,196,196,196,196,210,210,210,210,210,210,210,210,224,224,224,224,224,224,224,224,210,238,210,224,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,168,182,140,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,154,168,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,42,42,42,42,42,42,42,42,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,70,70,70,70,70,70,70,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,56,84,56,84,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,70,70,70,70,70,70,70,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,56,84,56,84,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,70,70,70,70,70,70,70,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,56,84,56,84,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,140,168,140,154,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,70,70,70,70,70,70,70,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,56,84,56,84,0,0,0,0,42,42,42,42,42,42,42,42,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,140,140,140,140,140,140,140,140,112,140,112,140,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,70,70,70,70,70,70,70,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,56,84,56,84,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,154,182,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,70,70,70,70,70,70,70,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,56,84,56,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,70,70,70,70,70,70,70,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,56,84,56,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,112,112,112,112,112,112,112,112,84,84,84,84,84,84,84,84,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,28,28,140,0,112,28,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,126,126,126,126,126,126,126,154,154,154,154,154,154,154,154,126,140,126,154,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,70,70,70,70,70,70,70,98,98,98,98,98,98,98,98,70,84,70,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,70,70,70,70,70,70,70,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,56,84,56,84,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,42,42,42,42,42,42,42,42,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0])
.concat([28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28])
.concat([28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,98,126,98,112,70,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,98,126,98,112,70,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,98,126,98,112,70,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,98,126,98,112,70,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,98,126,98,112,70,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,98,126,98,112,70,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,98,126,98,112,70,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,98,126,98,112,70,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,98,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0])
.concat([42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,42,42,42,42,42,42,42,42,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,56,84,56,70,28,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,28,28,28,28,28,28,28,28,0,0,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,70,70,70,70,70,70,70,70,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,84,112,84,98,56,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,112,126,84,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,28,28,28,28,28,28,28,28,126,126,126,126,126,126,126,126,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,56,56,56,56,56,56,56,56,210,210,210,210,210,210,210,210,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,154,154,154,154,154,154,154,154,168,168,168,168,168,168,168,168,182,182,182,182,182,182,182,182,168,196,0,0,0,0,0,0,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,140,140,140,140,140,140,140,140,126,154,126,140,112,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,98,98,98,98,98,98,98,98,112,112,112,112,112,112,112,112,126,126,126,126,126,126,126,126,112,140,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28])
.concat([28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,0,1,2,3,4,5,6,7,8,9,16,17,18,19,20,21,22,23,24,25,32,33,34,35,36,37,38,39,40,41,48,49,50,51,52,53,54,55,56,57,64,65,66,67,68,69,70,71,72,73,80,81,82,83,84,85,86,87,88,89,96,97,98,99,100,101,102,103,104,105,112,113,114,115,116,117,118,119,120,121,128,129,130,131,132,133,134,135,136,137,144,145,146,147,148,149,150,151,152,153,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,0,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,0,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,2,9,2,0,3,1,3,2,3,3,3,4,3,5,3,6,3,7,3,8,3,9,3,0,4,1,4,2,4,3,4,4,4,5,4,6,4,7,4,8,4,9,4,0,5,1,5,2,5,3,5,4,5,5,5,6,5,7,5,8,5,9,5,0,6,1,6,2,6,3,6,4,6,5,6,6,6,7,6,8,6,9,6,0,7,1,7,2,7,3,7,4,7,5,7,6,7,7,7,8,7,9,7,0,8,1,8,2,8,3,8,4,8,5,8,6,8,7,8,8,8,9,8,0,9,1,9,2,9,3,9,4,9,5,9,6,9,7,9,8,9,9,9,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,102,105,108,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,0,0,0,77,0,0,0,71,0,0,0,67,0,0,0,62,0,0,0,44,0,0,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,255,0,0,0,2,1,0,255,254,255,0,1,3,1,0,255,253,255,0,1,4,2,0,254,252,254,0,2,5,2,0,254,251,254,0,2,6,3,0,253,250,253,0,3,7,3,0,253,249,253,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,1,1,2,2,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,1,1,1,0,0,1,1,2,2,2,3,0,0,2,3,4,4,5,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,1,1,1,1,0,0,0,1,1,1,1,2,0,0,1,1,2,2,2,3,0,0,2,3,4,4,5,6,0,0,4,6,8,8,10,12,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,1,1,1,2,2,0,0,1,1,2,2,3,3,0,0,1,2,2,2,3,4,0,0,2,3,4,4,5,6,0,0,4,6,8,8,10,12,0,0,8,12,16,16,20,24,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,0,0,0,2,2,2,4,4,0,0,2,2,4,4,6,6,0,0,2,4,4,4,6,8,0,0,4,6,8,8,10,12,0,0,8,12,16,16,20,24,0,0,16,24,32,32,40,48,0,0,0,0,0,0,0,0,0,0,0,0,4,4,4,4,0,0,0,4,4,4,8,8,0,0,4,4,8,8,12,12,0,0,4,8,8,8,12,16,0,0,8,12,16,16,20,24,0,0,16,24,32,32,40,48,0,0,32,48,64,64,80,96,8,3,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,17,17,17,17,18,18,18,18,19,19,19,19,20,20,20,20,21,21,21,21,22,22,22,22,23,23,23,23,24,24,24,24,25,25,25,25,26,26,26,25,25,25,25,24,24,24,24,23,23,23,23,22,22,22,22,21,21,21,21,20,20,20,20,19,19,19,19,18,18,18,18,17,17,17,17,16,16,16,16,15,15,15,15,14,14,14,14,13,13,13,13,12,12,12,12,11,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,3,3,3,3,2,2,2,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,10,0,0,0,14,0,0,0,16,0,0,0,20,0,0,0,22,0,0,0,24,0,0,0,26,0,0,0,28,0,0,0,30,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,16,0,0,0,22,0,0,0,26,0,0,0,30,0,0,0,32,0,0,0,36,0,0,0,38,0,0,0,40,0,0,0,42,0,0,0,44,0,0,0,46,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,26,0,0,0,32,0,0,0,38,0,0,0,42,0,0,0,46,0,0,0,48,0,0,0,52,0,0,0,54,0,0,0,56,0,0,0,58,0,0,0,60,0,0,0,62,0,0,0,64,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,42,0,0,0,48,0,0,0,54,0,0,0,58,0,0,0,62,0,0,0,64,0,0,0,68,0,0,0,70,0,0,0,72,0,0,0,74,0,0,0,76,0,0,0,78,0,0,0,80,0,0,0,0,0,0,0,32,0,0,0,48,0,0,0,58,0,0,0,64,0,0,0,70,0,0,0,74,0,0,0,78,0,0,0,80,0,0,0,84,0,0,0,86,0,0,0,88,0,0,0,90,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,0,0,0,0,48,0,0,0,64,0,0,0,74,0,0,0,80,0,0,0,86,0,0,0,90,0,0,0,94,0,0,0,96,0,0,0,100,0,0,0,102,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,110,0,0,0,112,0,0,0,0,1,2,2,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,0,0,0,0,0,0,0,0,128,149,26,0,64,158,26,0,0,167,26,0,192,175,26,0,128,184,26,0,64,193,26,0,0,202,26,0,192,210,26,0,90,0,0,0,184,0,0,0,2,0,0,0,22,0,0,0,162,0,0,0,0,0,0,0,200,35,11,0,86,0,0,0,120,193,10,0,20,1,0,0,200,191,10,0,19,1,0,0,32,196,10,0,17,1,0,0,136,194,10,0,18,1,0,0,232,26,11,0,13,0,0,0,176,25,11,0,15,1,0,0,88,25,11,0,9,0,0,0,120,24,11,0,21,1,0,0,160,23,11,0,127,0,0,0,0,23,11,0,23,1,0,0,152,22,11,0,22,1,0,0,40,22,11,0,47,1,0,0,208,20,11,0,48,1,0,0,32,20,11,0,50,1,0,0,136,18,11,0,52,1,0,0,0,18,11,0,32,0,0,0,184,17,11,0,27,0,0,0,64,17,11,0,14,1,0,0,224,16,11,0,13,1,0,0,120,16,11,0,14,1,0,0,72,16,11,0,13,1,0,0,24,16,11,0,26,1,0,0,240,14,11,0,27,1,0,0,128,14,11,0,28,1,0,0,56,14,11,0,29,1,0,0,224,13,11,0,30,1,0,0,176,13,11,0,31,1,0,0,88,13,11,0,32,1,0,0,32,13,11,0,33,1,0,0,240,12,11,0,34,1,0,0,176,12,11,0,35,1,0,0,96,12,11,0,36,1,0,0,8,11,11,0,37,1,0,0,88,10,11,0,48,0,0,0,216,9,11,0,49,0,0,0,120,9,11,0,50,0,0,0,8,9,11,0,51,0,0,0,88,8,11,0,52,0,0,0,8,8,11,0,53,0,0,0,104,7,11,0,54,0,0,0,16,7,11,0,55,0,0,0,184,6,11,0,56,0,0,0,120,5,11,0,57,0,0,0,192,4,11,0,24,1,0,0,192,3,11,0,25,1,0,0,64,3,11,0,0,1,0,0,240,2,11,0,1,1,0,0,88,2,11,0,2,1,0,0,80,2,11,0,3,1,0,0,32,2,11,0,4,1,0,0,240,1,11,0,5,1,0,0,168,1,11,0,6,1,0,0,120,1,11,0,7,1,0,0,32,0,11,0,8,1,0,0,192,255,10,0,9,1,0,0,80,255,10,0,46,0,0,0,192,254,10,0,45,1,0,0,112,254,10,0,44,1,0,0,32,254,10,0,8,0,0,0,248,253,10,0,12,1,0,0,184,253,10,0,11,1,0,0,112,253,10,0,60,1,0,0,56,253,10,0,46,1,0,0,40,252,10,0,96,0,0,0,104,251,10,0,96,0,0,0,0,251,10,0,19,0,0,0,168,250,10,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,32,202,10,0,40,209,10,0,0,0,0,0,1,0,0,0,0,0,0,0,72,167,10,0,48,178,10,0,1,0,0,0,1,0,0,0,0,0,0,0,216,198,10,0,48,160,10,0,2,0,0,0,1,0,0,0,0,0,0,0,112,197,10,0,216,143,10,0,3,0,0,0,1,0,0,0,0,0,0,0,32,196,10,0,152,33,11,0,4,0,0,0,1,0,0,0,0,0,0,0,136,194,10,0,128,16,11,0,5,0,0,0,1,0,0,0,0,0,0,0,120,193,10,0,176,7,11,0,6,0,0,0,1,0,0,0,0,0,0,0,200,191,10,0,232,253,10,0,7,0,0,0,1,0,0,0,0,0,0,0,72,190,10,0,232,245,10,0,8,0,0,0,1,0,0,0,0,0,0,0,216,167,10,0,96,238,10,0,9,0,0,0,1,0,0,0,0,0,0,0,192,184,10,0,208,225,10,0,10,0,0,0,1,0,0,0,0,0,0,0,88,255,10,0,208,217,10,0,11,0,0,0,1,0,0,0,0,0,0,0,208,182,10,0,16,212,10,0,12,0,0,0,1,0,0,0,0,0,0,0,184,181,10,0,240,208,10,0,13,0,0,0,1,0,0,0,0,0,0,0,224,180,10,0,184,205,10,0,14,0,0,0,1,0,0,0,0,0,0,0,168,179,10,0,120,200,10,0,15,0,0,0,1,0,0,0,0,0,0,0,208,178,10,0,120,197,10,0,16,0,0,0,1,0,0,0,0,0,0,0,192,177,10,0,168,194,10,0,17,0,0,0,1,0,0,0,0,0,0,0,56,177,10,0,8,192,10,0,18,0,0,0,1,0,0,0,0,0,0,0,96,175,10,0,16,189,10,0,19,0,0,0,1,0,0,0,0,0,0,0,0,173,10,0,0,184,10,0,20,0,0,0,1,0,0,0,0,0,0,0,80,171,10,0,0,182,10,0,21,0,0,0,1,0,0,0,0,0,0,0,128,169,10,0,208,179,10,0,22,0,0,0,1,0,0,0,0,0,0,0,216,168,10,0,216,177,10,0,23,0,0,0,1,0,0,0,0,0,0,0,152,168,10,0,224,175,10,0,24,0,0,0,1,0,0,0,1,0,0,0,80,168,10,0,104,171,10,0,25,0,0,0,1,0,0,0,2,0,0,0,224,167,10,0,16,169,10,0,26,0,0,0,1,0,0,0,1,0,0,0,80,167,10,0,112,168,10,0,27,0,0,0,1,0,0,0,1,0,0,0,240,166,10,0,120,167,10,0,28,0,0,0,1,0,0,0,2,0,0,0,48,166,10,0,176,166,10,0,29,0,0,0,1,0,0,0,2,0,0,0,160,164,10,0,160,4,11,0,30,0,0,0,1,0,0,0,2,0,0,0,224,163,10,0,200,162,10,0,31,0,0,0,1,0,0,0,2,0,0,0,48,163,10,0,184,161,10,0,32,0,0,0,1,0,0,0,1,0,0,0,144,162,10,0,72,37,11,0,33,0,0,0,1,0,0,0,2,0,0,0,32,162,10,0,0,159,10,0,34,0,0,0,1,0,0,0,2,0,0,0,144,161,10,0,96,156,10,0,35,0,0,0,1,0,0,0,2,0,0,0,248,160,10,0,80,154,10,0,36,0,0,0,1,0,0,0,2,0,0,0,32,160,10,0,88,153,10,0,37,0,0,0,1,0,0,0,2,0,0,0,104,159,10,0,96,152,10,0,38,0,0,0,1,0,0,0,2,0,0,0,200,158,10,0,56,151,10,0,39,0,0,0,1,0,0,0,2,0,0,0,40,157,10,0,24,148,10,0,40,0,0,0,1,0,0,0,2,0,0,0,32,156,10,0,40,146,10,0,41,0,0,0,1,0,0,0,2,0,0,0,0,155,10,0,0,145,10,0,42,0,0,0,1,0,0,0,2,0,0,0,40,154,10,0,176,143,10,0,43,0,0,0,1,0,0,0,2,0,0,0,184,153,10,0,120,142,10,0,44,0,0,0,1,0,0,0,2,0,0,0,56,153,10,0,184,139,10,0,45,0,0,0,1,0,0,0,2,0,0,0,224,152,10,0,88,138,10,0,46,0,0,0,1,0,0,0,2,0,0,0,48,152,10,0,96,137,10,0,47,0,0,0,1,0,0,0,2,0,0,0,128,151,10,0,168,136,10,0,48,0,0,0,1,0,0,0,2,0,0,0,240,150,10,0,200,39,11,0,49,0,0,0,1,0,0,0,2,0,0,0,224,148,10,0,192,36,11,0,50,0,0,0,1,0,0,0,2,0,0,0,240,147,10,0,184,35,11,0,51,0,0,0,1,0,0,0,2,0,0,0,168,146,10,0,104,34,11,0,52,0,0,0,1,0,0,0,2,0,0,0,0,146,10,0,224,32,11,0,53,0,0,0,1,0,0,0,2,0,0,0,112,145,10,0,224,30,11,0,54,0,0,0,1,0,0,0,1,0,0,0,224,144,10,0,120,27,11,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,248,255,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,0,0,0,0,0,120,121,218,0,184,206,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,22,0,0,0,64,0,0,0,208,252,10,0,0,0,0,0,62,0,0,0,6,0,0,0,70,0,0,0,122,0,0,0,2,0,0,0,52,0,0,0,70,0,0,0,210,0,0,0,0,0,0,0,68,0,0,0,8,0,0,0,2,0,0,0,4,0,0,0,246,0,0,0,2,0,0,0,82,0,0,0,232,10,0,0,2,0,0,0,54,0,0,0,94,0,0,0,44,0,0,0,216,0,0,0,42,0,0,0,204,0,0,0,182,0,0,0,98,0,0,0,2,0,0,0,152,48,0,0,2,0,0,0,56,48,0,0,0,0,0,0,36,48,0,0,8,0,0,0,35,48,0,0,8,0,0,0,34,48,0,0,8,0,0,0,33,48,0,0,8,0,0,0,51,48,0,0,4,0,0,0,56,48,0,0,0,0,0,0,82,0,0,0,206,35,0,0,4,0,0,0,124,0,0,0,26,0,0,0,202,0,0,0,2,0,0,0,190,31,0,0,2,0,0,0,6,0,0,0,64,0,0,0,0,14,0,0,10,0,0,0,156,0,0,0,66,0,0,0,2,0,0,0,0,0,0,0,24,252,10,0,141,97,250,71,0,1,7,16,129,128,0,0,155,53,103,255,0,0,7,16,33,128,0,0,81,151,117,50,0,1,7,16,32,0,0,0,52,196,186,35,0,0,7,17,64,128,0,0,131,104,171,23,0,0,7,0,32,0,0,0,111,128,232,97,0,0,7,0,32,0,0,0,226,37,85,68,0,0,7,33,32,0,0,0,222,238,240,131,0,0,7,33,32,0,0,0,245,88,82,160,0,0,7,33,32,0,0,0,217,94,150,6,0,0,7,33,32,0,0,0,74,232,239,119,0,0,7,33,32,0,0,0,204,243,154,248,0,0,7,33,32,0,0,0,76,195,149,145,0,0,7,33,32,0,0,0,109,192,22,227,0,0,7,34,32,0,0,0,94,250,119,10,0,0,7,33,32,0,0,0,92,42,127,166,0,0,7,20,32,0,0,0,119,158,183,137,0,0,7,21,32,0,0,0,163,152,251,24,0,0,7,21,32,0,0,0,65,53,208,151,0,0,7,21,32,0,0,0,255,240,194,103,0,0,7,21,32,0,0,0,213,73,41,25,0,0,7,32,32,0,0,0,160,39,167,159,0,0,7,22,65,128,0,0,113,25,72,251,0,0,7,22,65,128,0,0,128,41,130,41,0,0,7,19,33,192,0,0,75,81,19,136,0,0,7,19,33,192,0,0,225,74,102,185,0,0,7,19,33,192,0,0,70,206,119,165,0,0,7,19,33,192,0,0,111,58,92,234,0,0,7,19,33,128,0,0,156,12,20,170,0,0,7,19,65,128,0,0,43,34,136,200,0,0,7,19,65,128,0,0,251,189,197,118,0,0,7,19,65,128,0,0,91,98,170,108,0,0,7,19,64,128,0,0,204,13,47,21,0,0,7,19,64,128,0,0,247,199,83,94,0,0,7,19,64,128,0,0,112,241,167,217,0,0,7,19,64,128,0,0,246,36,197,247,0,0,7,19,64,128,0,0,92,137,232,219,0,0,7,19,64,128,0,0,238,107,117,193,0,0,7,19,64,128,0,0,87,16,152,114,0,0,7,19,64,128,0,0,109,205,235,54,0,0,7,18,64,128,0,0,214,13,141,61,0,0,7,18,64,128,0,0,215,207,56,187,0,0,7,18,64,128,0,0,56,138,138,87,0,0,7,18,64,128,0,0,27,102,74,221,0,0,7,1,16,0,0,0,195,72,86,206,0,0,7,2,16,0,0,0,161,151,51,34,0,0,7,2,16,0,0,0,136,40,29,40,0,0,7,2,16,0,0,0,120,95,109,48,0,0,7,2,16,0,0,0,204,71,224,41,0,0,7,2,16,0,0,0,99,17,189,92,0,0,7,2,16,0,0,0,213,102,113,46,0,0,7,2,16,0,0,0,240,180,80,197,0,0,7,2,16,0,0,0,60,70,135,252,0,0,7,2,16,0,0,0,148,20,252,105,0,0,7,3,16,0,0,0,63,238,196,255,0,0,7,3,16,0,0,0,207,108,54,46,0,0,7,3,16,0,0,0,207,18,172,170,0,0,7,3,16,0,0,0,41,211,237,210,0,0,7,3,16,0,0,0,90,186,222,113,0,0,7,16,64,0,0,0,95,78,221,201,0,0,7,16,32,0,0,0,223,199,28,189,0,0,7,16,17,0,0,0,197,154,48,109,0,0,7,16,17,0,0,0,227,61,191,8,0,0,7,0,17,0,0,0,118,107,59,100,0,0,7,0,17,0,0,0,56,15,66,114,0,0,7,16,33,192,0,0,211,193,72,45,0,0,7,16,33,192,0,0,241,123,187,28,0,0,7,16,33,192,0,0,81,169,16,27,0,0,7,16,33,192,0,0,98,93,226,192,0,0,7,16,33,192,0,0,148,2,197,69,0,0,7,16,33,192,0,0,54,249,219,201,0,0,7,16,33,192,0,0,21,182,71,0,0,0,7,16,33,192,0,0,92,20,46,244,0,0,7,16,33,192,0,0,86,23,149,159,0,0,7,16,33,192,0,0,24,105,23,248,0,0,7,16,33,192,0,0,29,88,117,21,0,0,7,16,33,192,0,0,158,242,179,150,0,0,7,16,33,192,0,0,44,146,59,91,0,0,7,16,33,192,0,0,202,191,242,214,0,0,7,16,33,192,0,0,82,55,29,202,0,0,7,16,33,192,0,0,201,201,207,133,0,0,7,16,33,192,0,0,125,132,42,51,0,0,7,16,33,192,0,0,214,15,132,89,0,0,7,16,65,128,0,0,58,251,118,156,0,0,7,16,65,128,0,0,239,29,56,200,0,0,7,16,65,128,0,0,169,149,142,218,0,0,7,16,65,128,0,0,110,36,147,29,0,0,7,16,65,128,0,0,175,199,249,162,0,0,7,16,65,128,0,0,157,184,234,1,0,0,7,16,65,128,0,0,0,236,55,240,0,0,7,16,65,128,0,0,185,137,247,229,0,0,7,16,65,128,0,0,99,40,29,49,0,0,7,16,65,128,0,0,214,88,240,69,0,0,7,16,65,128,0,0,150,25,32,86,0,0,7,16,65,128,0,0,244,190,219,16,0,0,7,16,65,128,0,0,155,182,66,153,0,0,7,16,65,0,0,0,61,30,184,123,0,0,7,16,65,0,0,0,207,70,142,111,0,0,7,16,65,0,0,0,63,215,130,51,0,0,7,16,65,0,0,0,191,194,213,107,1,1,7,16,33,128,0,0,28,32,205,142,1,1,7,16,33,128,0,0,129,108,249,251,1,1,7,16,33,128,0,0,72,252,213,88,1,1,7,16,33,128,0,0,11,4,184,49,1,1,7,16,33,128,0,0,210,138,212,171,1,1,7,16,33,128,0,0,203,19,239,163,1,1,7,16,33,128,0,0,71,65,167,187,1,1,7,16,33,128,0,0,218,61,244,214,1,1,7,16,33,128,0,0,176,98,21,135,1,1,7,16,32,0,0,0,249,72,105,21,1,1,7,16,32,0,0,0,187,207,229,251,1,0,8,16,33,128,0,0,137,182,155,231,1,0,8,16,33,128,0,0,121,110,27,134,0,0,8,16,33,128,0,0,42,77,199,95,0,0,8,16,33,128,0,0,97,165,103,225,0,0,8,16,33,128,0,0,133,51,233,145,0,0,8,16,33,128,0,0,44,132,234,232,0,0,8,16,33,128,0,0,46,92,33,232,0,0,8,16,33,128,0,0,232,170,92,32,0,0,8,16,33,128,0,0,55,63,40,35,0,0,8,16,33,128,0,0,19,112,90,218,0,0,8,16,33,128,0,0,127,142,172,121,0,1,8,16,33,128,0,0,34,16,5,75,0,0,8,16,33,128,0,0,245,207,8,169,0,0,8,16,33,128,0,0,45,118,89,83,0,0,8,16,33,128,0,0,55,86,169,12,0,0,8,16,33,128,0,0,51,181,219,249,0,1,9,16,32,0,0,0,208,66,250,166,0,1,9,16,32,0,0,0,173,127,188,41,0,1,9,16,32,0,0,0,212,23,89,49,0,0,9,16,32,0,0,0,31,226,183,12,0,0,10,16,33,128,0,0,152,73,46,228,0,0,10,16,33,128,0,0,191,72,201,65,0,0,10,16,33,128,0,0,142,31,149,28,0,1,7,16,33,128,0,0,213,150,56,193,0,1,7,16,33,128,0,0,151,233,191,92,0,1,7,16,33,128,0,0,152,254,162,187,0,1,7,16,33,128,0,0,179,78,97,255,0,1,7,16,33,128,0,0,17,207,132,48,0,1,7,16,33,128,0,0,167,9,96,172,0,1,7,16,33,128,0,0,87,39,133,164,0,1,7,16,33,128,0,0,165,111,31,184,0,1,7,16,33,128,0,0,128,110,255,60,0,1,7,16,33,128,0,0,109,46,246,231,0,1,7,16,33,128,0,0,36,117,142,144,0,1,7,16,33,128,0,0,243,137,93,165,0,1,7,16,33,128,0,0,249,65,177,184,0,1,7,16,33,128,0,0,173,137,152,210,0,1,7,16,33,128,0,0,216,53,172,164,0,1,7,16,33,128,0,0,32,117,130,108,0,1,7,16,33,128,0,0,7,244,144,24,0,1,7,16,33,128,0,0,245,166,70,183,0,1,7,16,33,128,0,0,78,252,160,145,0,1,7,16,33,128,0,0,37,19,101,72,0,1,7,16,33,128,0,0,195,253,171,93,0,1,7,16,33,128,0,0,254,118,19,165,0,1,7,16,33,128,0,0,74,174,228,152,0,1,7,16,33,128,0,0,46,211,110,81,0,1,7,16,33,128,0,0,8,27,81,232,0,1,7,16,33,128,0,0,110,59,51,14,0,1,7,16,33,128,0,0,170,89,26,48,0,1,7,16,33,128,0,0,11,124,214,1,0,1,7,16,33,128,0,0,210,216,137,85,0,1,7,16,33,128,0,0,108,230,48,224,0,1,7,16,33,128,0,0,117,152,126,249,0,1,7,16,33,128,0,0,217,239,119,64,0,1,7,16,33,128,0,0,176,182,84,187,0,1,7,16,33,128,0,0,238,71,252,66,0,1,7,16,33,128,0,0,27,235,71,197,0,1,7,16,33,128,0,0,236,40,139,154,0,1,7,16,33,128,0,0,195,126,182,170,0,1,7,16,33,128,0,0,78,172,111,12,0,1,7,16,33,128,0,0,231,202,82,71,0,1,7,16,33,128,0,0,147,11,57,26,0,1,7,16,33,128,0,0,75,14,146,174,0,1,7,16,33,128,0,0,190,20,189,81,0,1,7,16,33,128,0,0,187,169,204,34,0,1,7,16,33,128,0,0,200,96,45,181,0,1,7,16,33,128,0,0,23,133,159,222,0,1,7,16,33,128,0,0,97,177,176,223,0,1,7,16,33,128,0,0,118,22,158,103,0,1,7,16,33,128,0,0,193,240,190,140,0,1,7,16,33,128,0,0,201,59,46,47,0,1,7,16,33,128,0,0,19,74,212,72,0,1,7,0,32,0,0,0,91,22,196,216,0,1,7,16,32,0,0,0,249,29,193,76,0,1,7,16,32,0,0,0,102,228,33,228,0,1,7,16,32,0,0,0,250,184,205,43,0,1,7,16,32,0,0,0,85,36,189,86,0,1,7,16,32,0,0,0,66,251,34,199,0,1,7,16,32,0,0,0,233,112,188,122,0,1,7,16,32,0,0,0,31,189,134,101,0,1,7,16,32,0,0,0,145,188,71,72,0,1,7,16,32,0,0,0,217,246,253,185,0,1,7,16,32,0,0,0,158,0,90,149,0,1,7,16,32,0,0,0,83,83,234,5,0,1,7,16,32,0,0,0,228,50,29,209,0,1,7,16,32,0,0,0,69,111,125,170,0,1,7,16,32,0,0,0,173,17,4,191,0,1,7,16,32,0,0,0,82,19,162,33,0,1,7,16,32,0,0,0,6,145,95,91,0,1,7,16,32,0,0,0,92,125,162,190,0,1,7,16,32,0,0,0,106,211,5,102,0,1,7,16,32,0,0,0,187,241,255,225,0,1,7,16,32,0,0,0,73,85,100,17,0,1,7,16,32,0,0,0,203,248,14,126,0,1,7,16,32,0,0,0,48,106,218,177,0,1,7,16,32,0,0,0,44,171,50,129,0,1,7,16,32,0,0,0,177,25,206,192,0,1,7,16,32,0,0,0,131,31,48,7,0,1,7,16,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,27,11,0,104,145,10,0,96,14,11,0,0,0,0,0,37,48,50,100,46,119,97,118,0,0,0,0,0,0,0,0,32,37,48,50,100,46,119,97,118,0,0,0,0,0,0,0,45,37,48,50,100,46,119,97,118,0,0,0,0,0,0,0,95,37,48,50,100,46,119,97,118,0,0,0,0,0,0,0,32,45,32,37,48,50,100,46,119,97,118,0,0,0,0,0,37,100,46,119,97,118,0,0,0,0,0,0,0,0,0,0,32,37,100,46,119,97,118,0,0,0,0,0,0,0,0,0,45,37,100,46,119,97,118,0,0,0,0,0,0,0,0,0,95,37,100,46,119,97,118,0,0,0,0,0,0,0,0,0,32,45,32,37,100,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,13,13,13,12,12,12,12,11,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,3,3,3,3,2,2,2,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,3,3,3,3,2,2,2,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,32,40,48,56,64,72,80,88,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,0,0,0,0,16,16,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,32,40,48,56,64,72,80,88,96,104,112,120,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,0,1,0,1,0,1,0,1,0,1,0,1,1,1,0,1,0,1,1,1,0,1,1,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,2,1,2,1,2,1,2,1,2,1,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,4,2,2,2,4,2,4,2,4,2,4,2,4,2,4,4,4,2,4,4,4,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,8,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,1,0,1,0,1,1,1,0,1,1,1])
.concat([0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,2,1,2,1,2,1,2,1,2,1,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,4,2,2,2,4,2,4,2,4,2,4,2,4,2,4,4,4,2,4,4,4,4,4,4,4,4,4,4,4,4,4,4,8,4,4,4,8,4,8,4,8,4,8,4,8,4,8,8,8,4,8,8,8,8,8,8,8,8,8,8,8,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,4,4,4,5,5,6,6,7,8,8,8,8,1,1,1,1,2,2,2,2,2,3,3,3,4,4,4,5,5,6,6,7,8,8,9,10,11,12,13,14,16,16,16,16,2,2,2,2,2,3,3,3,4,4,4,5,5,6,6,7,8,8,9,10,11,12,13,14,16,17,19,20,22,22,22,22,16,18,167,205,0,0,0,0,146,0,0,0,146,0,0,0,146,0,0,0,146,0,0,0,88,0,0,0,140,0,0,0,88,0,0,0,88,0,0,0,94,0,0,0,94,0,0,0,94,0,0,0,94,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,106,188,116,63,219,249,30,63,150,67,139,190,203,161,37,191,164,112,141,191,35,219,217,63,84,45,48,56,49,51,50,54,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,0,255,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,1,1,0,84,45,56,49,48,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,0,255,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,1,1,0,84,45,48,56,49,50,55,54,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,0,255,0,0,0,1,0,32,0,1,0,32,0,0,0,32,0,0,0,0,0,84,45,56,49,52,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,1,255,1,0,0,1,0,32,0,1,0,32,0,0,0,32,0,0,0,0,0,84,45,48,56,49,53,56,54,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,7,255,7,0,0,1,0,32,0,1,0,32,0,0,0,32,0,0,0,0,0,84,45,56,49,53,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,255,31,255,31,0,0,1,0,32,0,1,0,32,0,0,0,32,0,0,0,0,0,84,45,56,49,52,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,255,31,255,31,0,0,1,0,32,0,1,0,32,0,0,0,32,0,0,0,0,0,84,45,53,48,49,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,7,7,6,0,84,45,53,48,51,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,7,7,6,0,84,45,53,48,52,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,7,7,6,0,84,45,53,48,53,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,7,7,6,0,84,45,53,48,54,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,7,7,6,0,84,45,49,50,48,52,54,0,0,0,0,0,0,0,0,0,35,173,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,84,45,49,50,48,53,51,0,0,0,0,0,0,0,0,0,128,234,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,77,75,45,49,50,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,77,75,45,49,50,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,71,45,53,53,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,80,82,45,49,57,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,71,45,52,48,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,48,48,48,48,49,50,49,49,45,48,48,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,48,48,48,48,52,48,55,54,45,48,48,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,71,45,52,53,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,48,48,48,53,52,53,48,51,45,48,48,0,0,0,0,0,0,0,0,0,7,0,127,0,127,0,0,0,1,0,32,0,1,0,32,0,1,0,32,0,0,0,1,0,84,45,49,50,48,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,3,255,3,0,0,0,0,48,0,1,0,56,0,0,0,48,0,0,7,1,0,48,48,48,48,48,48,48,48,45,48,48,0,0,0,0,0,224,206,0,0,8,0,255,3,255,3,0,0,0,0,48,0,1,0,56,0,0,0,48,0,0,7,1,0,84,45,49,50,48,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,7,255,7,0,0,0,0,48,0,1,0,56,0,0,0,48,0,0,7,1,0,48,48,48,48,48,48,48,48,45,48,48,0,0,0,0,0,65,44,0,0,8,0,255,7,255,7,0,0,0,0,48,0,1,0,56,0,0,0,48,0,0,7,1,0,84,45,49,50,48,49,52,54,45,53,48,0,0,0,0,0,0,0,0,0,16,0,255,31,255,31,0,0,0,0,48,0,1,0,56,0,0,0,48,0,0,7,1,0,165,165,165,165,165,165,165,165,165,165,165,165,165,165,165,165,166,166,166,166,166,166,166,166,166,166,166,166,166,166,166,166,167,167,167,167,167,167,167,167,167,167,167,167,167,167,167,167,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,168,169,169,169,169,169,169,169,169,169,169,169,169,169,169,169,169,170,170,170,170,170,170,170,170,170,170,170,170,170,170,170,170,171,171,171,171,171,171,171,171,171,171,171,171,171,171,171,171,172,172,172,172,172,172,172,172,172,172,172,172,172,172,172,172,173,173,173,173,173,173,173,173,173,173,173,173,173,173,173,173,174,174,174,174,174,174,174,174,174,174,174,174,174,174,174,174,175,175,175,175,175,175,175,175,175,175,175,175,175,175,175,175,176,176,176,176,176,176,176,176,176,176,176,176,176,176,176,176,177,177,177,177,177,177,177,177,177,177,177,177,177,177,177,177,178,178,178,178,178,178,178,178,178,178,178,178,178,178,178,178,179,179,179,179,179,179,179,179,179,179,179,179,179,179,179,179,180,180,180,180,180,180,180,180,180,180,180,180,180,180,180,180,181,181,181,181,181,181,181,181,181,181,181,181,181,181,181,181,182,182,182,182,182,182,182,182,228,228,228,228,228,228,228,228,229,229,229,229,229,229,229,229,229,229,229,229,229,229,229,229,230,230,230,230,230,230,230,230,230,230,230,230,230,230,230,230,230,231,231,231,231,231,231,231,231,231,231,231,231,231,231,231,231,231,231,231,231,232,232,232,232,232,232,232,232,232,232,232,232,232,232,232,232,232,232,232,232,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,234,234,234,234,234,234,234,234,234,234,234,234,234,234,234,234,234,234,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,243,243,243,243,243,243,243,243,243,243,243,243,243,243,243,243,243,243,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,248,248,248,248,248,248,248,248,248,248,248,248,248,248,248,248,249,249,249,249,249,249,249,249,249,249,249,249,249,249,249,249,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,36,36,36,36,36,36,36,36,36,36,36,36,36,36,36,36,37,37,37,37,37,37,37,37,37,37,37,37,37,37,37,37,38,38,38,38,38,38,38,38,38,38,38,38,38,38,38,38,39,39,39,39,39,39,39,39,39,39,39,39,39,39,39,39,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,41,41,41,41,41,41,41,41,41,41,41,41,41,41,41,41,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,44,44,44,44,44,44,44,44,44,44,44,44,44,44,44,44,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,46,46,46,46,46,46,46,46,46,46,46,46,46,46,46,46,47,47,47,47,47,47,47,47,47,47,47,47,47,47,47,47,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,49,49,49,49,49,49,49,49,49,49,49,49,49,49,49,49,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,51,51,51,51,51,51,51,51,51,51,51,51,51,51,51,51,52,52,52,52,52,52,52,52,52,52,52,52,52,52,52,52,53,53,53,53,53,53,53,53,53,53,53,53,53,53,53,53,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,55,55,55,55,55,55,55,55,55,55,55,55,55,55,55,55,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,57,57,57,57,57,57,57,57,57,57,57,57,57,57,57,57,58,58,58,58,58,58,58,58,58,58,58,58,58,58,58,58,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,60,60,60,60,60,60,60,60,60,60,60,60,60,60,60,60,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,62,62,62,62,62,62,62,62,62,62,62,62,62,62,62,62,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,65,65,65,65,65,65,65,65,65,65,65,65,65,65,65,65,66,66,66,66,66,66,66,66,66,66,66,66,66,66,66,66,67,67,67,67,67,67,67,67,67,67,67,67,67,67,67,67,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,69,69,69,69,69,69,69,69,69,69,69,69,69,69,69,69,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,71,71,71,71,71,71,71,71,71,71,71,71,71,71,71,71,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,73,73,73,73,73,73,73,73,73,73,73,73,73,73,73,73,74,74,74,74,74,74,74,74,74,74,74,74,74,74,74,74,75,75,75,75,75,75,75,75,75,75,75,75,75,75,75,75,76,76,76,76,76,76,76,76,76,76,76,76,76,76,76,76,77,77,77,77,77,77,77,77,77,77,77,77,77,77,77,77,78,78,78,78,78,78,78,78,78,78,78,78,78,78,78,78,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,81,81,81,81,81,81,81,81,81,81,81,81,81,81,81,81,82,82,82,82,82,82,82,82,82,82,82,82,82,82,82,82,83,83,83,83,83,83,83,83,83,83,83,83,83,83,83,83,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,86,86,86,86,86,86,86,86,86,86,86,86,86,86,86,86,87,87,87,87,87,87,87,87,87,87,87,87,87,87,87,87,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,89,89,89,89,89,89,89,89,89,89,89,89,89,89,89,89,90,90,90,90,90,90,90,90,90,90,90,90,90,90,90,90,91,91,91,91,91,91,91,91,91,91,91,91,91,91,91,91,92,92,92,92,92,92,92,92,92,92,92,92,92,92,92,92,93,93,93,93,93,93,93,93,93,93,93,93,93,93,93,93,94,94,94,94,94,94,94,94,94,94,94,94,94,94,94,94,95,95,95,95,95,95,95,95,95,95,95,95,95,95,95,95,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,97,97,97,97,97,97,97,97,97,97,97,97,97,97,97,97,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,100,100,100,100,100,100,100,100,100,100,100,100,100,100,100,100,101,101,101,101,101,101,101,101,101,101,101,101,101,101,101,101,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,103,103,103,103,103,103,103,103,103,103,103,103,103,103,103,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,105,105,105,105,105,105,105,105,105,105,105,105,105,105,105,105,106,106,106,106,106,106,106,106,106,106,106,106,106,106,106,106,107,107,107,107,107,107,107,107,107,107,107,107,107,107,107,107,108,108,108,108,108,108,108,108,108,108,108,108,108,108,108,108,109,109,109,109,109,109,109,109,109,109,109,109,109,109,109,109,110,110,110,110,110,110,110,110,110,110,110,110,110,110,110,110,111,111,111,111,111,111,111,111,111,111,111,111,111,111,111,111,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,113,113,113,113,113,113,113,113,113,113,113,113,113,113,113,113,114,114,114,114,114,114,114,114,114,114,114,114,114,114,114,114,115,115,115,115,115,115,115,115,115,115,115,115,115,115,115,115,116,116,116,116,116,116,116,116,116,116,116,116,116,116,116,116,117,117,117,117,117,117,117,117,117,117,117,117,117,117,117,117,118,118,118,118,118,118,118,118,118,118,118,118,118,118,118,118,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,120,120,120,120,120,120,120,120,120,120,120,120,120,120,120,121,121,121,121,121,121,121,121,121,121,121,121,121,121,121,121,122,122,122,122,122,122,122,122,122,122,122,122,122,122,122,122,123,123,123,123,123,123,123,123,123,123,123,123,123,123,123,123,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,125,125,125,125,125,125,125,125,125,125,125,125,125,125,125,125,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,130,130,130,130,130,130,130,130,130,130,130,130,130,130,130,130,131,131,131,131,131,131,131,131,131,131,131,131,131,131,131,131,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,133,133,133,133,133,133,133,133,133,133,133,133,133,133,133,133,134,134,134,134,134,134,134,134,134,134,134,134,134,134,134,134,135,135,135,135,135,135,135,135,135,135,135,135,135,135,135,135,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,137,137,137,137,137,137,137,137,137,137,137,137,137,137,137,137,138,138,138,138,138,138,138,138,138,138,138,138,138,138,138,138,139,139,139,139,139,139,139,139,139,139,139,139,139,139,139,139,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,141,141,141,141,141,141,141,141,141,141,141,141,141,141,141,141,142,142,142,142,142,142,142,142,142,142,142,142,142,142,142,142,143,143,143,143,143,143,143,143,143,143,143,143,143,143,143,143,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,145,145,145,145,145,145,145,145,145,145,145,145,145,145,145,145,146,146,146,146,146,146,146,146,146,146,146,146,146,146,146,146,147,147,147,147,147,147,147,147,147,147,147,147,147,147,147,147,148,148,148,148,148,148,148,148,148,148,148,148,148,148,148,148,149,149,149,149,149,149,149,149,149,149,149,149,149,149,149,149,150,150,150,150,150,150,150,150,150,150,150,150,150,150,150,150,151,151,151,151,151,151,151,151,151,151,151,151,151,151,151,151,152,152,152,152,152,152,152,152,152,152,152,152,152,152,152,152,153,153,153,153,153,153,153,153,153,153,153,153,153,153,153,153,154,154,154,154,154,154,154,154,154,154,154,154,154,154,154,154,155,155,155,155,155,155,155,155,155,155,155,155,155,155,155,155,156,156,156,156,156,156,156,156,156,156,156,156,156,156,156,156,157,157,157,157,157,157,157,157,157,157,157,157,157,157,157,157,158,158,158,158,158,158,158,158,158,158,158,158,158,158,158,158,159,159,159,159,159,159,159,159,159,159,159,159,159,159,159,159,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,161,161,161,161,161,161,161,161,161,161,161,161,161,161,161,161,162,162,162,162,162,162,162,162,162,162,162,162,162,162,162,162,163,163,163,163,163,163,163,163,163,163,163,163,163,163,163,163,164,164,164,164,164,164,164,164,164,164,164,164,164,164,164,164,0,0,0,0,133,133,133,133,133,133,133,133,133,133,134,134,134,134,134,134,134,134,134,134,134,134,134,134,134,134,134,134,134,134,135,135,135,135,135,135,135,135,135,135,135,135,135,135,135,135,135,135,135,135,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,137,137,137,137,137,137,137,137,137,137,137,137,137,137,137,137,137,137,137,137,138,138,138,138,138,138,138,138,138,138,138,138,138,138,138,138,138,138,138,138,139,139,139,139,139,139,139,139,139,139,139,139,139,139,139,139,139,139,139,139,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,140,141,141,141,141,141,141,141,141,141,141,141,141,141,141,141,141,141,141,141,141,142,142,142,142,142,142,142,142,142,142,142,142,142,142,142,142,142,142,142,142,143,143,143,143,143,143,143,143,143,143,143,143,143,143,143,143,143,143,143,143,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,145,145,145,145,145,145,145,145,145,145,145,145,145,145,145,145,145,145,145,145,146,146,146,146,146,146,146,146,146,146,146,146,146,146,146,146,146,146,146,146,147,147,147,147,147,147,147,147,147,147,147,147,147,147,147,147,147,147,147,147,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,233,234,234,234,234,234,234,234,234,234,234,234,234,234,234,234,234,234,234,234,234,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,235,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,236,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,237,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,239,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,241,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,242,243,243,243,243,243,243,243,243,243,243,243,243,243,243,243,243,243,243,243,243,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,244,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,245,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,246,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,248,248,248,248,248,248,248,248,248,248,248,248,248,248,248,248,248,248,248,248,249,249,249,249,249,249,249,249,249,249,249,249,249,249,249,249,249,249,249,249,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,250,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,36,36,36,36,36,36,36,36,36,36,36,36,36,36,36,36,36,36,36,36,37,37,37,37,37,37,37,37,37,37,37,37,37,37,37,37,37,37,37,37,38,38,38,38,38,38,38,38,38,38,38,38,38,38,38,38,38,38,38,38,39,39,39,39,39,39,39,39,39,39,39,39,39,39,39,39,39,39,39,39,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,41,41,41,41,41,41,41,41,41,41,41,41,41,41,41,41,41,41,41,41,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,44,44,44,44,44,44,44,44,44,44,44,44,44,44,44,44,44,44,44,44,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,46,46,46,46,46,46,46,46,46,46,46,46,46,46,46,46,46,46,46,46,47,47,47,47,47,47,47,47,47,47,47,47,47,47,47,47,47,47,47,47,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,49,49,49,49,49,49,49,49,49,49,49,49,49,49,49,49,49,49,49,49,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,51,51,51,51,51,51,51,51,51,51,51,51,51,51,51,51,51,51,51,51,52,52,52,52,52,52,52,52,52,52,52,52,52,52,52,52,52,52,52,52,53,53,53,53,53,53,53,53,53,53,53,53,53,53,53,53,53,53,53,53,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,55,55,55,55,55,55,55,55,55,55,55,55,55,55,55,55,55,55,55,55,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,56,57,57,57,57,57,57,57,57,57,57,57,57,57,57,57,57,57,57,57,57,58,58,58,58,58,58,58,58,58,58,58,58,58,58,58,58,58,58,58,58,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,60,60,60,60,60,60,60,60,60,60,60,60,60,60,60,60,60,60,60,60,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,62,62,62,62,62,62,62,62,62,62,62,62,62,62,62,62,62,62,62,62,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,65,65,65,65,65,65,65,65,65,65,65,65,65,65,65,65,65,65,65,65,66,66,66,66,66,66,66,66,66,66,66,66,66,66,66,66,66,66,66,66,67,67,67,67,67,67,67,67,67,67,67,67,67,67,67,67,67,67,67,67,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,69,69,69,69,69,69,69,69,69,69,69,69,69,69,69,69,69,69,69,69,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,70,71,71,71,71,71,71,71,71,71,71,71,71,71,71,71,71,71,71,71,71,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,72,73,73,73,73,73,73,73,73,73,73,73,73,73,73,73,73,73,73,73,73,74,74,74,74,74,74,74,74,74,74,74,74,74,74,74,74,74,74,74,74,75,75,75,75,75,75,75,75,75,75,75,75,75,75,75,75,75,75,75,75,76,76,76,76,76,76,76,76,76,76,76,76,76,76,76,76,76,76,76,76,77,77,77,77,77,77,77,77,77,77,77,77,77,77,77,77,77,77,77,77,78,78,78,78,78,78,78,78,78,78,78,78,78,78,78,78,78,78,78,78,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,81,81,81,81,81,81,81,81,81,81,81,81,81,81,81,81,81,81,81,81,82,82,82,82,82,82,82,82,82,82,82,82,82,82,82,82,82,82,82,82,83,83,83,83,83,83,83,83,83,83,83,83,83,83,83,83,83,83,83,83,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,84,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,86,86,86,86,86,86,86,86,86,86,86,86,86,86,86,86,86,86,86,86,87,87,87,87,87,87,87,87,87,87,87,87,87,87,87,87,87,87,87,87,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,89,89,89,89,89,89,89,89,89,89,89,89,89,89,89,89,89,89,89,89,90,90,90,90,90,90,90,90,90,90,90,90,90,90,90,90,90,90,90,90,91,91,91,91,91,91,91,91,91,91,91,91,91,91,91,91,91,91,91,91,92,92,92,92,92,92,92,92,92,92,92,92,92,92,92,92,92,92,92,92,93,93,93,93,93,93,93,93,93,93,93,93,93,93,93,93,93,93,93,93,94,94,94,94,94,94,94,94,94,94,94,94,94,94,94,94,94,94,94,94,95,95,95,95,95,95,95,95,95,95,95,95,95,95,95,95,95,95,95,95,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,97,97,97,97,97,97,97,97,97,97,97,97,97,97,97,97,97,97,97,97,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,98,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,100,100,100,100,100,100,100,100,100,100,100,100,100,100,100,100,100,100,100,100,101,101,101,101,101,101,101,101,101,101,101,101,101,101,101,101,101,101,101,101,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,103,103,103,103,103,103,103,103,103,103,103,103,103,103,103,103,103,103,103,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,104,105,105,105,105,105,105,105,105,105,105,105,105,105,105,105,105,105,105,105,105,106,106,106,106,106,106,106,106,106,106,106,106,106,106,106,106,106,106,106,106,107,107,107,107,107,107,107,107,107,107,107,107,107,107,107,107,107,107,107,107,108,108,108,108,108,108,108,108,108,108,108,108,108,108,108,108,108,108,108,108,109,109,109,109,109,109,109,109,109,109,109,109,109,109,109,109,109,109,109,109,110,110,110,110,110,110,110,110,110,110,110,110,110,110,110,110,110,110,110,110,111,111,111,111,111,111,111,111,111,111,111,111,111,111,111,111,111,111,111,111,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,113,113,113,113,113,113,113,113,113,113,113,113,113,113,113,113,113,113,113,113,114,114,114,114,114,114,114,114,114,114,114,114,114,114,114,114,114,114,114,114,115,115,115,115,115,115,115,115,115,115,115,115,115,115,115,115,115,115,115,115,116,116,116,116,116,116,116,116,116,116,116,116,116,116,116,116,116,116,116,116,117,117,117,117,117,117,117,117,117,117,117,117,117,117,117,117,117,117,117,117,118,118,118,118,118,118,118,118,118,118,118,118,118,118,118,118,118,118,118,118,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,120,120,120,120,120,120,120,120,120,120,120,120,120,120,120,120,120,120,120,121,121,121,121,121,121,121,121,121,121,121,121,121,121,121,121,121,121,121,121,122,122,122,122,122,122,122,122,122,122,122,122,122,122,122,122,122,122,122,122,123,123,123,123,123,123,123,123,123,123,123,123,123,123,123,123,123,123,123,123,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,125,125,125,125,125,125,125,125,125,125,125,125,125,125,125,125,125,125,125,125,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,130,130,130,130,130,130,130,130,130,130,130,130,130,130,130,130,130,130,130,130,131,131,131,131,131,131,131,131,131,131,131,131,131,131,131,131,131,131,131,131,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,133,133,133,133,133,133,133,133,133,133,0,0,0,0,0,0,0,0,100,16,183,29,200,32,110,59,172,48,217,38,144,65,220,118,244,81,107,107,88,97,178,77,60,113,5,80,32,131,184,237,68,147,15,240,232,163,214,214,140,179,97,203,176,194,100,155,212,210,211,134,120,226,10,160,28,242,189,189,0,0,0,0,255,0,0,0,85,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,15,31,15,63,0,0,0,0,120,202,10,0,2,0,0,0,96,185,10,0,3,0,0,0,120,173,10,0,5,0,0,0,224,164,10,0,4,0,0,0,128,149,26,0,64,158,26,0,0,167,26,0,192,175,26,0,128,184,26,0,64,193,26,0,0,202,26,0,192,210,26,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,44,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,89,1,120,0,210,0,165,0,150,0,120,0,120,0,165,0,120,0,120,0,225,0,165,0,150,0,120,0,120,0,165,0,120,0,180,0,210,0,165,0,150,0,120,0,120,0,165,0,120,0,240,0,225,0,165,0,150,0,120,0,120,0,165,0,120,0,165,0,210,0,44,1,150,0,135,0,135,0,180,0,120,0,165,0,225,0,44,1,150,0,135,0,135,0,180,0,120,0,165,0,210,0,255,0,150,0,89,1,89,1,29,1,120,0,165,0,225,0,255,0,150,0,120,0,120,0,165,0,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,135,0,135,0,135,0,135,0,135,0,135,0,29,1,135,0,135,0,135,0,135,0,135,0,135,0,135,0,29,1,135,0,29,1,29,1,29,1,29,1,29,1,29,1,120,0,29,1,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,120,0,120,0,120,0,120,0,135,0,135,0,29,1,120,0,135,0,210,0,210,0,210,0,210,0,225,0,165,0,225,0,135,0,210,0,210,0,0,0,210,0,59,1,165,0,225,0,135,0,210,0,210,0,225,0,210,0,225,0,165,0,225,0,135,0,120,0,210,0,225,0,210,0,60,0,165,0,225,0,135,0,210,0,210,0,89,1,210,0,225,0,165,0,225,0,135,0,120,0,210,0,120,0,210,0,60,0,165,0,225,0,135,0,210,0,210,0,120,0,210,0,225,0,165,0,225,0,135,0,150,0,210,0,120,0,210,0,60,0,165,0,225,0,60,0,150,0,105,0,90,0,60,0,60,0,105,0,60,0,60,0,165,0,105,0,90,0,60,0,60,0,105,0,60,0,120,0,150,0,105,0,90,0,60,0,60,0,105,0,60,0,180,0,165,0,105,0,90,0,60,0,60,0,105,0,60,0,105,0,150,0,240,0,90,0,60,0,60,0,105,0,60,0,105,0,165,0,240,0,90,0,60,0,60,0,105,0,60,0,105,0,150,0,195,0,90,0,165,0,165,0,150,0,60,0,105,0,165,0,195,0,90,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,105,0,105,0,105,0,105,0,105,0,105,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,60,0,60,0,60,0,60,0,60,0,60,0,105,0,60,0,75,0,150,0,150,0,150,0,150,0,165,0,105,0,165,0,75,0,150,0,150,0,0,0,150,0,255,0,105,0,165,0,75,0,150,0,150,0,165,0,150,0,165,0,105,0,165,0,75,0,60,0,150,0,165,0,150,0,0,0,105,0,165,0,75,0,150,0,150,0,29,1,150,0,165,0,105,0,165,0,75,0,60,0,150,0,60,0,150,0,0,0,105,0,165,0,75,0,150,0,150,0,60,0,150,0,165,0,105,0,165,0,75,0,90,0,150,0,60,0,150,0,0,0,105,0,165,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0])
.concat([120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,180,0,180,0,225,0,44,1,120,0,210,0,120,0,135,0,180,0,180,0,225,0,44,1,120,0,210,0,120,0,135,0,180,0,180,0,225,0,44,1,120,0,210,0,120,0,135,0,180,0,180,0,225,0,44,1,120,0,210,0,120,0,135,0,180,0,180,0,225,0,44,1,120,0,210,0,120,0,14,1,180,0,180,0,225,0,44,1,120,0,210,0,120,0,14,1,180,0,180,0,225,0,44,1,120,0,210,0,120,0,120,0,180,0,180,0,225,0,44,1,120,0,210,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,240,0,240,0,240,0,240,0,120,0,120,0,120,0,120,0,240,0,240,0,240,0,240,0,120,0,120,0,120,0,120,0,240,0,240,0,240,0,240,0,120,0,120,0,120,0,120,0,240,0,240,0,240,0,240,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,180,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,180,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,180,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,180,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,180,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,180,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,180,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,180,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,120,0,120,0,120,0,120,0,120,0,120,0,225,0,120,0,95,95,95,95,95,95,95,95,95,95,95,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,69,71,65,95,67,68,95,82,79,77,0,1,0,0,0,82,65,77,95,67,65,82,84,82,73,68,71,69,95,95,95,43,0,141,255,94,1,24,254,112,4,110,252,229,22,30,82,44,0,138,255,92,1,39,254,52,4,225,252,154,20,9,82,45,0,135,255,88,1,58,254,243,3,91,253,98,18,200,81,46,0,134,255,80,1,81,254,174,3,219,253,60,16,93,81,47,0,133,255,71,1,108,254,100,3,94,254,45,14,199,80,47,0,134,255,60,1,137,254,24,3,227,254,52,12,8,80,47,0,136,255,47,1,168,254,202,2,105,255,84,10,32,79,46,0,139,255,33,1,202,254,122,2,239,255,140,8,17,78,46,0,142,255,17,1,237,254,41,2,117,0,222,6,219,76,44,0,148,255,255,0,19,255,215,1,247,0,76,5,127,75,43,0,153,255,237,0,57,255,134,1,117,1,213,3,0,74,42,0,158,255,218,0,96,255,54,1,239,1,121,2,95,72,40,0,165,255,198,0,135,255,231,0,99,2,58,1,158,70,38,0,172,255,178,0,175,255,153,0,210,2,22,0,191,68,36,0,180,255,157,0,213,255,80,0,56,3,15,255,196,66,34,0,188,255,135,0,253,255,8,0,151,3,36,254,174,64,32,0,195,255,115,0,34,0,196,255,238,3,85,253,129,62,29,0,204,255,94,0,70,0,133,255,59,4,162,252,62,60,27,0,212,255,73,0,106,0,72,255,128,4,9,252,232,57,25,0,220,255,53,0,139,0,17,255,187,4,138,251,130,55,22,0,229,255,34,0,170,0,222,254,237,4,36,251,14,53,20,0,236,255,16,0,199,0,177,254,21,5,214,250,142,50,18,0,244,255,253,255,226,0,137,254,51,5,160,250,5,48,15,0,252,255,237,255,250,0,102,254,71,5,128,250,118,45,13,0,3,0,221,255,16,1,73,254,81,5,117,250,227,42,11,0,9,0,207,255,36,1,48,254,82,5,126,250,79,40,9,0,16,0,193,255,53,1,29,254,74,5,153,250,188,37,7,0,22,0,181,255,66,1,16,254,57,5,197,250,45,35,6,0,26,0,171,255,77,1,8,254,32,5,0,251,163,32,4,0,31,0,162,255,85,1,5,254,254,4,75,251,33,30,3,0,35,0,154,255,91,1,6,254,214,4,161,251,170,27,1,0,40,0,146,255,94,1,13,254,166,4,3,252,64,25,0,0,43,0,141,255,94,1,24,254,112,4,110,252,229,22,2,0,0,0,26,0,0,0,58,0,0,0,40,0,0,0,52,0,0,0,168,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,16,66,8,32,0,0,74,41,0,0,0,0,0,0,168,175,212,87,0,0,128,248,226,232,35,0,0,0,136,170,168,138,0,0,192,164,100,82,116,0,0,132,16,0,0,0,0,0,136,8,33,132,32,8,0,130,32,132,16,34,2,0,0,144,234,42,1,0,0,0,16,242,9,1,0,0,0,0,0,0,32,2,0,0,0,240,1,0,0,0,0,0,0,0,32,0,0,16,34,68,136,16,1,0,192,197,88,99,116,0,0,128,24,66,8,113,0,0,192,69,200,68,248,0,0,192,69,200,96,116,0,0,0,49,149,62,66,0,0,224,135,240,96,116,0,0,128,137,240,98,116,0,0,224,67,132,8,17,0,0,192,197,232,98,116,0,0,192,197,232,33,50,0,0,0,0,2,0,1,0,0,0,0,2,0,17,0,0,0,64,54,24,4,0,0,0,128,15,62,0,0,0,0,4,131,77,0,0,0,192,69,136,8,32,0,0,192,135,214,122,240,0,0,128,16,165,92,140,0,0,224,197,248,98,124,0,0,192,197,16,66,116,0,0,224,164,24,99,58,0,0,224,135,240,66,248,0,0,224,135,240,66,8,0,0,192,197,144,99,244,0,0,32,198,248,99,140,0,0,192,17,66,8,113,0,0,128,67,8,33,124,0,0,32,166,50,74,138,0,0,32,132,16,66,248,0,0,32,198,189,107,141,0,0,96,206,90,107,206,0,0,192,197,24,99,116,0,0,224,197,248,66,8,0,0,192,197,24,99,246,0,0,224,197,248,98,140,0,0,192,197,224,96,116,0,0,224,19,66,8,33,0,0,32,198,24,99,116,0,0,32,198,168,20,33,0,0,32,214,90,149,82,0,0,32,70,69,84,140,0,0,32,198,232,8,33,0,0,224,67,68,68,248,0,0,78,8,33,132,16,14,0,33,8,65,8,66,16,0,14,33,132,16,66,14,0,128,168,8,0,0,0,0,0,0,0,0,0,31,0,128,32,0,0,0,0,0,0,0,7,125,244,0,0,33,132,23,99,124,0,0,0,0,31,66,240,0,0,16,66,31,99,244,0,0,0,0,23,127,240,0,0,92,136,39,132,16,0,0,0,0,23,99,244,208,1,33,132,23,99,140,0,0,128,0,67,8,33,0,0,0,1,134,16,66,232,0,66,8,169,140,146,0,0,134,16,66,8,33,0,0,0,128,85,107,173,0,0,0,128,23,99,140,0,0,0,0,23,99,116,0,0,0,128,23,99,124,33,0,0,0,31,99,244,16,2,0,128,54,67,8,0,0,0,0,31,28,124,0,0,64,8,39,132,224,0,0,0,128,24,99,244,0,0,0,128,24,149,34,0,0,0,128,88,171,82,0,0,0,128,168,136,138,0,0,0,128,24,99,244,208,1,0,128,143,136,248,0,0,136,16,34,8,33,8,0,132,16,66,8,33,4,0,130,16,130,8,33,2,0,0,0,96,50,0,0,0,0,0,0,0,0,0,0,63,132,16,66,8,225,3,0,0,0,0,0,0,0,0,0,0,0,64,4,0,152,16,71,8,33,68,0,0,0,0,0,80,10,0,0,0,0,0,168,0,0,132,124,66,8,33,4,0,132,124,242,9,33,4,0,68,1,0,0,0,0,0,0,72,69,84,2,0,0,138,0,31,62,124,0,0,0,0,68,4,65,0,0,192,166,148,83,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,32,0,0,0,0,0,8,17,0,0,0,0,0,74,81,0,0,0,0,0,148,42,0,0,0,0,0,0,0,192,24,0,0,0,0,0,0,62,0,0,0,0,0,0,62,0,0,0,0,0,64,21,0,0,0,0,128,175,149,2,0,0,138,0,31,28,124,0,0,0,0,130,32,34,0,0,0,0,155,114,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,10,196,24,29,33,0,0,0,0,0,0,0,0,0,128,0,66,8,33,0,0,0,32,174,20,71,0,0,152,16,79,68,248,0,0,0,4,47,165,15,0,0,32,70,71,62,33,0,0,132,16,2,8,33,4,0,152,16,23,163,35,100,0,64,1,0,0,0,0,0,192,135,86,90,240,0,0,4,49,197,0,0,0,0,0,0,34,147,36,0,0,0,0,224,33,132,0,0,0,0,0,0,0,0,0,192,135,84,74,240,0,0,224,3,0,0,0,0,0,128,56,2,0,0,0,0,0,16,242,9,249,0,0,6,17,225,0,0,0,0,6,25,100,0,0,0,0,136,0,0,0,0,0,0,0,0,41,165,116,34,0,192,223,107,41,165,148,2,0,0,64,0,0,0,0,0,0,0,0,96,136,0,196,16,226,0,0,0,0,68,41,2,0,0,0,0,0,128,36,137,76,0,0,48,166,68,168,22,1,0,48,166,68,137,148,1,0,81,46,85,168,22,1,0,128,0,130,96,116,0,0,130,0,226,92,140,0,0,68,0,226,92,140,0,0,68,1,226,92,140,0,0,84,1,226,92,140,0,0,64,1,226,92,140,0,0,196,17,226,92,140,0,0,128,59,231,83,202,0,0,192,197,16,66,116,68,0,130,128,31,94,248,0,0,68,128,31,94,248,0,0,68,129,31,94,248,0,0,64,129,31,94,248,0,0,130,0,71,8,113,0,0,68,0,71,8,113,0,0,68,1,71,8,113,0,0,64,1,71,8,113,0,0,192,73,241,132,116,0,0,84,129,89,107,206,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,84,1,23,99,116,0,0,64,1,23,99,116,0,0,0,68,69,84,4,0,0,0,48,169,173,108,0,0,130,128,24,99,116,0,0,68,128,24,99,116,0,0,68,129,24,99,116,0,0,64,129,24,99,116,0,0,136,196,24,29,33,0,0,64,8,39,165,19,2,0,192,73,233,164,116,1,0,130,0,7,125,244,0,0,68,0,7,125,244,0,0,68,1,7,125,244,0,0,84,1,7,125,244,0,0,64,1,7,125,244,0,0,196,17,7,125,244,0,0,0,0,139,124,178,0,0,0,0,31,66,240,68,0,130,0,23,127,240,0,0,68,0,23,127,240,0,0,68,1,23,127,240,0,0,64,1,23,127,240,0,0,130,0,67,8,33,0,0,68,0,67,8,33,0,0,68,1,67,8,33,0,0,64,1,67,8,33,0,0,192,34,232,99,116,0,0,84,129,23,99,140,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,170,0,23,99,116,0,0,64,1,23,99,116,0,0,0,16,240,1,1,0,0,0,48,169,173,108,0,0,130,128,24,99,244,0,0,68,128,24,99,244,0,0,68,129,24,99,244,0,0,64,129,24,99,244,0,0,68,128,24,99,244,208,1,32,132,23,99,124,33,0,64,129,24,99,244,208,1,0,0,0,0,16,0,0,0,8,0,0,0,32,0,0,0,9,0,0,0,0,2,0,0,1,0,0,0,64,0,0,0,3,0,0,0,128,0,0,0,10,0,0,0,0,4,0,0,11,0,0,0,0,1,0,0,4,0,0,0,1,0,0,0,5,0,0,0,2,0,0,0,6,0,0,0,4,0,0,0,7,0,0,0,8,0,0,0,2,0,0,0,0,8,0,0,112,246,10,0,40,246,10,0,0,246,10,0,184,245,10,0,112,245,10,0,56,245,10,0,88,244,10,0,208,243,10,0,10,0,0,0,34,0,0,0,64,0,0,0,86,0,0,0,44,1,0,0,62,0,0,0,90,0,0,0,200,26,11,0,104,0,0,0,42,0,0,0,12,0,0,0,14,0,0,0,88,0,0,0,134,0,0,0,102,0,0,0,188,0,0,0,4,0,0,0,40,10,11,0,0,0,0,0,0,0,0,0,168,133,10,0,208,133,10,0,0,0,0,0,16,16,16,16,32,32,32,32,48,48,48,48,64,64,64,64,80,80,80,80,96,96,96,96,112,112,112,112,52,58,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,169,170,63,49,54,58,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,142,227,63,49,54,58,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,205,204,204,63,49,54,58,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,137,136,136,63,67,111,110,102,105,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,113,117,97,114,101,32,112,105,120,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,111,114,101,32,112,114,111,118,105,100,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,117,115,116,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,110,112,117,116,95,100,101,98,117,103,95,101,110,97,98,108,101,0,0,0,0,0,0,77,117,116,101,32,65,117,100,105,111,0,0,0,0,0,0,115,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,109,111,118,105,101,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,69,110,97,98,108,101,32,104,111,116,107,101,121,115,0,0,105,110,112,117,116,95,100,117,116,121,95,99,121,99,108,101,0,0,0,0,0,0,0,0,68,105,115,107,32,73,109,97,103,101,32,65,112,112,101,110,100,0,0,0,0,0,0,0,115,99,97,108,101,95,121,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,117,110,109,117,116,101,32,97,117,100,105,111,46,10,0,0,0,105,110,112,117,116,95,116,117,114,98,111,95,112,101,114,105,111,100,0,0,0,0,0,0,68,105,115,107,32,73,110,100,101,120,0,0,0,0,0,0,115,99,97,108,101,95,120,0,65,117,100,105,111,32,117,110,109,117,116,101,100,46,0,0,83,108,111,119,32,109,111,116,105,111,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,82,79,84,65,84,73,79,78,58,32,37,117,10,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,115,105,122,101,0,0,0,0,0,0,0,69,115,116,105,109,97,116,101,100,32,77,111,110,105,116,111,114,32,70,80,83,0,0,0,115,99,97,108,101,0,0,0,65,117,100,105,111,32,109,117,116,101,100,46,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,112,97,116,104,0,0,0,0,0,0,0,67,114,111,112,32,79,118,101,114,115,99,97,110,32,40,114,101,108,111,97,100,41,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,88,77,76,58,32,73,110,118,97,108,105,100,32,112,114,111,112,101,114,116,121,32,102,111,114,32,102,105,108,116,101,114,46,10,0,0,86,111,108,117,109,101,58,32,37,46,49,102,32,100,66,0,78,101,116,112,108,97,121,32,102,108,105,112,32,112,108,97,121,101,114,115,0,0,0,0,115,116,100,105,110,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,61,61,61,10,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,89,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,76,73,78,69,65,82,46,10,0,0,0,0,0,0,0,83,79,78,73,67,32,84,72,69,32,72,69,68,71,69,72,79,71,32,50,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,100,106,117,115,116,105,110,103,32,97,115,112,101,99,116,32,114,97,116,105,111,32,116,111,32,37,46,50,102,10,0,0,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,112,111,114,116,0,0,0,0,0,0,0,0,83,85,80,69,82,32,83,84,82,69,69,84,32,70,73,71,72,84,69,82,50,0,0,0,82,101,116,114,111,65,114,99,104,45,37,109,37,100,45,37,72,37,77,37,83,46,0,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,88,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,78,69,65,82,69,83,84,46,10,0,0,0,0,0,0,65,117,100,105,111,32,109,117,116,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,84,82,65,67,75,32,37,48,50,100,32,65,85,68,73,79,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,69,82,82,79,82,32,45,32,70,105,108,101,32,105,115,32,116,111,111,32,108,97,114,103,101,46,10,0,0,0,0,0,86,83,121,110,99,32,83,119,97,112,32,73,110,116,101,114,118,97,108,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,76,85,84,32,102,105,108,116,101,114,32,116,121,112,101,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,98,32,109,111,117,115,101,32,115,116,97,116,101,58,32,37,115,46,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,40,37,100,41,0,0,0,0,103,108,67,111,112,121,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,105,110,32,118,101,99,52,32,99,111,108,111,114,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,72,87,32,114,101,110,100,101,114,32,70,66,79,32,35,37,117,44,32,101,114,114,111,114,58,32,48,120,37,117,46,10,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,108,111,97,100,0,0,0,0,0,115,116,121,108,101,0,0,0,66,108,97,99,107,32,70,114,97,109,101,32,73,110,115,101,114,116,105,111,110,0,0,0,111,118,101,114,108,97,121,37,117,95,110,97,109,101,0,0,110,101,97,114,101,115,116,0,60,33,45,45,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,117,109,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,0,0,0,0,68,83,80,32,99,111,110,102,105,103,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,115,97,118,101,0,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,32,70,114,97,109,101,115,0,0,0,0,108,105,110,101,97,114,0,0,82,101,116,114,111,65,114,99,104,58,32,85,110,112,97,117,115,101,100,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,105,110,100,101,120,0,0,0,0,84,77,82,32,83,69,71,65,0,0,0,0,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,102,105,108,101,110,97,109,101,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,97,117,115,101,100,46,10,0,0,0,0,0,84,97,107,101,32,115,99,114,101,101,110,115,104,111,116,0,98,108,111,99,107,95,115,114,97,109,95,111,118,101,114,119,114,105,116,101,0,0,0,0,83,116,97,114,116,32,98,117,116,116,111,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,77,111,118,105,101,32,102,111,114,109,97,116,32,115,101,101,109,115,32,116,111,32,104,97,118,101,32,97,32,100,105,102,102,101,114,101,110,116,32,115,101,114,105,97,108,105,122,101,114,32,118,101,114,115,105,111,110,46,32,87,105,108,108,32,109,111,115,116,32,108,105,107,101,108,121,32,102,97,105,108,46,10,0,0,86,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,73,68,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,82,101,97,99,104,101,100,32,101,110,100,32,111,102,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,0,0,0,99,104,101,97,116,95,115,101,116,116,105,110,103,115,95,112,97,116,104,0,0,0,0,0,82,111,116,97,116,105,111,110,0,0,0,0,0,0,0,0,102,105,108,116,101,114,0,0,109,101,110,117,95,116,111,103,103,108,101,0,0,0,0,0,82,101,119,105,110,100,105,110,103,46,0,0,0,0,0,0,67,104,101,97,116,32,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,77,69,83,83,65,71,69,58,32,37,115,10,0,0,0,0,0,99,104,101,97,116,95,100,97,116,97,98,97,115,101,95,112,97,116,104,0,0,0,0,0,84,111,103,103,108,101,32,70,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,103,114,97,98,95,109,111,117,115,101,95,116,111,103,103,108,101,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,46,0,0,0,0,97,117,116,111,115,97,118,101,95,105,110,116,101,114,118,97,108,0,0,0,0,0,0,0,67,117,115,116,111,109,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,84,111,111,32,109,97,110,121,32,116,101,120,116,117,114,101,32,105,109,97,103,101,115,46,32,73,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,100,105,115,107,95,110,101,120,116,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,32,114,101,119,105,110,100,46,0,0,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,45,0,0,0,112,97,117,115,101,95,110,111,110,97,99,116,105,118,101,0,37,102,0,0,0,0,0,0,65,115,112,101,99,116,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,65,77,32,97,100,100,114,101,115,115,32,115,112,101,99,105,102,105,99,101,100,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,100,105,115,107,95,101,106,101,99,116,95,116,111,103,103,108,101,0,0,0,0,0,0,0,84,45,49,49,51,48,49,54,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,10,0,0,0,0,0,0,0,37,115,32,124,124,32,70,80,83,58,32,37,54,46,49,102,32,124,124,32,70,114,97,109,101,115,58,32,37,100,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,117,100,105,111,32,114,97,116,101,32,99,111,110,116,114,111,108,32,119,97,115,32,100,101,115,105,114,101,100,44,32,98,117,116,32,100,114,105,118,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,101,101,100,101,100,32,102,101,97,116,117,114,101,115,46,10,0,0,0,0,0,0,0,102,97,115,116,102,111,114,119,97,114,100,95,114,97,116,105,111,0,0,0,0,0,0,0,102,105,108,101,95,112,97,116,104,46,99,0,0,0,0,0,73,110,116,101,103,101,114,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,105,110,112,117,116,32,115,108,111,116,32,102,111,114,32,105,109,112,111,114,116,46,10,0,0,0,0,111,118,101,114,108,97,121,95,110,101,120,116,0,0,0,0,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,43,0,0,0,66,73,78,65,82,89,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,115,108,111,119,109,111,116,105,111,110,95,114,97,116,105,111,0,0,0,0,0,0,0,0,69,82,82,79,82,32,45,32,37,115,46,10,0,0,0,0,83,104,97,100,101,114,32,79,112,116,105,111,110,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,118,111,108,117,109,101,95,100,111,119,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,71,71,32,73,110,116,101,114,110,97,116,105,111,110,97,108,0,0,0,0,0,0,0,0,103,108,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,79,69,83,95,112,97,99,107,101,100,95,100,101,112,116,104,95,115,116,101,110,99,105,108,0,0,0,0,0,0,0,0,114,101,119,105,110,100,95,103,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,71,76,83,76,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,83,99,97,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,110,102,105,103,32,107,101,121,58,32,37,115,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,111,114,32,73,68,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,118,111,108,117,109,101,95,117,112,0,0,0,0,0,0,0,61,34,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,80,114,101,118,105,111,117,115,32,115,104,97,100,101,114,0,114,101,119,105,110,100,95,98,117,102,102,101,114,95,115,105,122,101,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,70,105,108,116,101,114,0,0,0,0,0,0,0,101,113,117,97,108,0,0,0,101,110,97,98,108,101,95,104,111,116,107,101,121,0,0,0,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,97,118,101,32,115,116,97,116,101,115,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,114,101,119,105,110,100,95,101,110,97,98,108,101,0,0,0,83,104,97,100,101,114,32,35,37,117,0,0,0,0,0,0,109,97,115,107,0,0,0,0,115,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,0,0,78,101,120,116,32,115,104,97,100,101,114,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,115,99,97,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,115,116,97,116,101,32,102,114,111,109,32,109,111,118,105,101,46,10,0,0,0,83,104,97,100,101,114,32,80,97,115,115,101,115,0,0,0,105,110,112,117,116,95,115,108,111,116,0,0,0,0,0,0,110,101,116,112,108,97,121,95,102,108,105,112,95,112,108,97,121,101,114,115,0,0,0,0,37,115,46,98,115,118,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,111,112,97,99,105,116,121,0,0,0,76,111,97,100,32,83,104,97,100,101,114,32,80,114,101,115,101,116,0,0,0,0,0,0,119,114,97,109,0,0,0,0,97,117,100,105,111,95,109,117,116,101,0,0,0,0,0,0,37,115,37,117,46,98,115,118,0,0,0,0,0,0,0,0,82,101,115,101,116,32,103,97,109,101,0,0,0,0,0,0,46,114,101,116,114,111,97,114,99,104,45,99,111,114,101,45,111,112,116,105,111,110,115,46,99,102,103,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,0,0,0,68,101,102,97,117,108,116,32,70,105,108,116,101,114,0,0,115,101,109,97,110,116,105,99,0,0,0,0,0,0,0,0,100,115,112,95,99,111,110,102,105,103,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,0,111,118,101,114,108,97,121,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,65,112,112,108,121,32,83,104,97,100,101,114,32,67,104,97,110,103,101,115,0,0,0,0,105,100,0,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,70,114,97,109,101,97,100,118,97,110,99,101,0,0,0,0,114,103,117,105,95,98,114,111,119,115,101,114,95,100,105,114,101,99,116,111,114,121,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,101,110,100,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,37,115,32,40,37,100,44,32,37,100,32,58,32,37,52,117,120,37,52,117,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,111,111,32,109,97,110,121,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,115,32,46,46,46,10,0,0,0,0,0,99,104,101,97,116,95,116,111,103,103,108,101,0,0,0,0,83,79,78,73,67,32,38,32,75,78,85,67,75,76,69,83,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,108,121,32,115,104,97,100,101,114,46,10,0,0,0,0,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,110,32,101,120,105,115,116,105,110,103,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,84,45,49,50,48,48,57,54,0,0,0,0,0,0,0,0,83,101,116,32,66,111,116,116,111,109,45,82,105,103,104,116,32,67,111,114,110,101,114,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,80,121,116,104,111,110,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,109,105,110,117,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,0,80,97,117,115,101,32,116,111,103,103,108,101,0,0,0,0,73,78,68,69,88,32,49,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,100,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,0,0,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,67,68,32,66,73,79,83,58,32,37,115,0,0,0,0,0,0,83,101,116,32,85,112,112,101,114,45,76,101,102,116,32,67,111,114,110,101,114,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,108,97,110,103,117,97,103,101,32,105,115,32,110,111,116,32,80,121,116,104,111,110,46,10,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,112,108,117,115,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,58,32,34,37,115,34,46,0,0,0,0,0,0,0,71,71,32,69,120,112,111,114,116,0,0,0,0,0,0,0,103,108,84,101,120,73,109,97,103,101,51,68,79,69,83,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,116,97,116,101,32,116,114,97,99,107,101,114,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,77,97,120,32,116,101,120,116,117,114,101,32,115,105,122,101,58,32,37,100,32,112,120,44,32,114,101,110,100,101,114,98,117,102,102,101,114,32,115,105,122,101,58,32,37,117,32,112,120,46,10,0,0,0,0,99,111,114,101,95,111,112,116,105,111,110,115,95,112,97,116,104,0,0,0,0,0,0,0,78,47,65,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,66,105,116,32,100,101,112,116,104,32,111,102,32,84,71,65,32,105,109,97,103,101,32,105,115,32,119,114,111,110,103,46,32,79,110,108,121,32,51,50,45,98,105,116,32,97,110,100,32,50,52,45,98,105,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,37,115,32,40,37,52,117,120,37,52,117,44,32,37,117,32,120,32,37,117,32,115,99,97,108,101,41,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,111,118,101,114,108,97,121,0,0,0,0,0,0,0,99,108,97,115,115,0,0,0,115,104,97,100,101,114,95,112,114,101,118,0,0,0,0,0,32,10,9,12,11,13,0,0,82,101,116,114,111,65,114,99,104,58,32,9,9,37,115,10,0,0,0,0,0,0,0,0,46,99,103,112,0,0,0,0,77,111,118,105,101,32,114,101,99,111,114,100,32,116,111,103,103,108,101,0,0,0,0,0,108,105,98,114,101,116,114,111,95,112,97,116,104,0,0,0,83,101,116,32,115,99,97,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,97,108,114,101,97,100,121,32,105,109,112,111,114,116,101,100,46,10,0,0,115,104,97,100,101,114,95,110,101,120,116,0,0,0,0,0,46,99,103,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,117,115,101,115,32,116,104,114,101,97,100,101,100,32,97,117,100,105,111,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,0,105,110,112,117,116,95,106,111,121,112,97,100,95,100,114,105,118,101,114,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,101,116,116,105,110,103,32,82,71,85])
.concat([73,32,67,71,80,32,102,97,105,108,101,100,46,10,0,0,63,63,63,0,0,0,0,0,114,101,115,101,116,0,0,0,46,115,104,97,100,101,114,0,83,101,108,101,99,116,32,98,117,116,116,111,110,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,82,67,51,50,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,82,79,77,32,102,105,108,101,32,97,110,100,32,115,97,118,101,100,32,82,79,77,32,99,104,101,99,107,115,117,109,32,105,110,32,114,101,112,108,97,121,32,102,105,108,101,32,104,101,97,100,101,114,59,32,114,101,112,108,97,121,32,104,105,103,104,108,121,32,108,105,107,101,108,121,32,116,111,32,100,101,115,121,110,99,32,111,110,32,112,108,97,121,98,97,99,107,46,10,0,78,47,65,32,40,115,116,111,99,107,41,0,0,0,0,0,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,0,102,114,97,109,101,95,97,100,118,97,110,99,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,111,116,32,105,110,118,97,108,105,100,32,100,105,115,107,32,105,110,100,101,120,32,102,114,111,109,32,108,105,98,114,101,116,114,111,46,10,0,0,0,0,0,97,117,100,105,111,95,100,115,112,95,112,108,117,103,105,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,0,114,101,112,101,97,116,0,0,112,97,117,115,101,95,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,66,83,82,77,58,32,37,115,10,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,45,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,86,65,82,73,65,66,76,69,83,46,10,0,0,0,0,0,0,97,117,100,105,111,95,100,114,105,118,101,114,0,0,0,0,37,115,32,40,37,115,41,0,99,108,97,109,112,95,116,111,95,101,100,103,101,0,0,0,109,111,118,105,101,95,114,101,99,111,114,100,95,116,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,83,82,77,58,32,37,115,10,0,0,0,0,118,105,100,101,111,95,103,108,95,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,60,85,115,101,32,116,104,105,115,32,100,105,114,101,99,116,111,114,121,62,0,0,0,0,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,0,114,101,119,105,110,100,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,83,117,102,97,109,105,32,116,117,114,98,111,32,65,47,66,32,82,65,77,46,10,0,0,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,43,0,0,0,0,0,0,0,0,118,105,100,101,111,95,100,114,105,118,101,114,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,101,110,100,105,110,103,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,0,37,115,124,122,105,112,0,0,97,98,115,111,108,117,116,101,0,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,100,101,99,114,101,97,115,101,0,0,0,0,0,48,48,52,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,83,82,77,58,32,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,114,101,115,97,109,112,108,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,97,117,100,105,111,95,118,111,108,117,109,101,0,0,0,0,84,45,49,50,48,48,54,54,0,0,0,0,0,0,0,0,99,102,103,0,0,0,0,0,118,105,101,119,112,111,114,116,0,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,105,110,99,114,101,97,115,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,32,37,115,10,0,0,0,0,73,78,68,69,88,32,48,49,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,32,98,117,102,102,101,114,46,10,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,95,100,101,108,116,97,0,0,0,0,0,0,0,0,114,98,0,0,0,0,0,0,99,103,124,103,108,115,108,0,115,111,117,114,99,101,0,0,101,120,105,116,95,101,109,117,108,97,116,111,114,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,66,83,88,32,40,80,41,82,65,77,46,10,0,0,71,71,32,74,97,112,97,110,0,0,0,0,0,0,0,0,80,76,84,69,0,0,0,0,103,108,71,101,116,66,117,102,102,101,114,80,111,105,110,116,101,114,118,79,69,83,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,76,85,84,115,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,32,72,87,32,114,101,110,100,101,114,32,40,37,117,32,120,32,37,117,41,46,10,0,0,0,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,84,71,65,32,112,105,120,101,108,115,46,10,0,0,0,0,115,104,97,100,101,114,0,0,99,103,112,124,103,108,115,108,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,111,118,101,114,108,97,121,32,99,97,108,108,101,100,58,32,34,37,115,34,46,10,0,0,0,0,115,99,97,108,101,95,37,115,37,117,0,0,0,0,0,0,116,111,103,103,108,101,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,67,104,101,97,116,58,32,35,37,117,32,91,37,115,93,58,32,37,115,0,0,0,0,0,60,47,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,80,111,115,115,105,98,108,101,32,118,97,108,117,101,115,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,71,97,109,101,98,111,121,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,116,111,103,103,108,101,0,0,0,0,0,0,0,97,117,100,105,111,95,115,121,110,99,0,0,0,0,0,0,47,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,95,37,115,37,117,0,115,97,118,101,95,115,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,84,67,58,32,37,115,10,0,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,0,0,0,0,0,97,117,100,105,111,95,108,97,116,101,110,99,121,0,0,0,37,99,32,37,45,42,46,42,115,32,37,45,42,115,0,0,121,0,0,0,0,0,0,0,108,111,97,100,95,115,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,37,115,10,0,0,0,0,0,83,97,118,101,32,115,116,97,116,101,0,0,0,0,0,0,97,117,100,105,111,95,100,101,118,105,99,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,118,105,101,32,102,105,108,101,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,66,83,86,49,32,102,105,108,101,46,10,0,0,0,0,0,0,120,0,0,0,0,0,0,0,104,111,108,100,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,114,101,103,117,108,97,114,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,97,117,100,105,111,95,98,108,111,99,107,95,102,114,97,109,101,115,0,0,0,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,37,117,0,0,0,0,0,116,111,103,103,108,101,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,102,97,105,108,101,100,0,0,76,111,97,100,32,115,116,97,116,101,0,0,0,0,0,0,97,117,100,105,111,95,111,117,116,95,114,97,116,101,0,0,63,0,0,0,0,0,0,0,114,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,115,117,99,99,101,101,100,101,100,0,0,0,0,0,0,0,97,117,100,105,111,95,101,110,97,98,108,101,0,0,0,0,85,110,107,110,111,119,110,0,112,121,116,104,111,110,0,0,114,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,117,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,32,37,115,46,10,0,70,97,115,116,32,102,111,114,119,97,114,100,32,104,111,108,100,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,37,117,95,106,111,121,112,97,100,95,105,110,100,101,120,0,0,0,0,0,44,0,0,0,0,0,0,0,102,97,108,115,101,0,0,0,83,117,112,101,114,83,99,111,112,101,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,95,112,114,101,118,105,111,117,115,0,0,0,0,0,114,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,48,48,49,0,0,0,0,0,46,97,117,116,111,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,110,101,116,112,108,97,121,95,99,108,105,101,110,116,95,115,119,97,112,95,105,110,112,117,116,0,0,0,0,0,0,0,84,45,49,50,51,52,53,54,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,100,105,114,101,99,116,111,114,121,58,32,34,37,115,34,10,0,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,0,74,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,99,97,112,116,117,114,101,95,112,114,101,118,105,111,117,115,0,0,0,0,0,0,0,0,114,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,45,118,0,0,0,0,0,0,70,97,115,116,32,102,111,114,119,97,114,100,32,116,111,103,103,108,101,0,0,0,0,0,83,69,71,65,68,73,83,67,83,89,83,84,69,77,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,105,110,112,117,116,95,97,120,105,115,95,116,104,114,101,115,104,111,108,100,0,0,0,0,71,97,109,101,32,71,101,97,114,32,101,120,116,101,110,100,101,100,32,115,99,114,101,101,110,59,32,100,105,115,97,98,108,101,100,124,101,110,97,98,108,101,100,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,74,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,95,99,111,117,110,116,0,0,0,0,0,0,0,0,108,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,45,99,0,0,0,0,0,0,83,77,83,32,69,120,112,111,114,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,105,108,101,32,67,82,67,32,100,105,102,102,101,114,115,32,102,114,111,109,32,90,73,80,32,67,82,67,46,32,70,105,108,101,58,32,48,120,37,120,44,32,90,73,80,58,32,48,120,37,120,46,10,0,0,0,0,0,0,73,69,78,68,0,0,0,0,103,108,85,110,109,97,112,66,117,102,102,101,114,79,69,83,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,83,76,32,115,116,111,99,107,32,112,114,111,103,114,97,109,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,37,117,32,116,101,120,116,117,114,101,115,46,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,101,100,32,84,71,65,58,32,40,37,117,120,37,117,32,64,32,37,117,32,98,112,112,41,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,0,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,0,0,0,77,111,117,115,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,111,108,118,101,32,110,101,120,116,32,116,97,114,103,101,116,115,46,10,0,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,0,0,0,0,0,0,108,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,110,121,32,99,104,101,97,116,115,32,105,110,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,93,93,62,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,67,117,114,114,101,110,116,32,118,97,108,117,101,58,32,37,115,10,0,0,45,83,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,100,105,114,0,0,0,0,0,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,66,79,32,116,101,120,116,117,114,101,115,32,101,120,99,101,101,100,101,100,32,109,97,120,105,109,117,109,32,115,105,122,101,32,111,102,32,71,80,85,32,40,37,117,120,37,117,41,46,32,82,101,115,105,122,105,110,103,32,116,111,32,102,105,116,46,10,0,0,0,0,0,0,0,0,77,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,99,97,112,116,117,114,101,0,108,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,45,115,0,0,0,0,0,0,118,105,100,101,111,95,103,112,117,95,115,99,114,101,101,110,115,104,111,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,66,79,32,112,97,115,115,32,35,37,100,32,105,115,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,46,10,0,0,0,0,0,74,111,121,112,97,100,32,119,47,32,65,110,97,108,111,103,0,0,0,0,0,0,0,0,37,115,95,101,113,117,97,108,0,0,0,0,0,0,0,0,108,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,45,45,109,101,110,117,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,85,78,83,85,80,80,79,82,84,69,68,32,40,35,37,117,41,46,10,0,0,118,105,100,101,111,95,103,112,117,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,89,32,98,117,116,116,111,110,32,40,108,101,102,116,41,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,109,111,118,105,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,32,101,120,116,101,110,115,105,111,110,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,0,0,74,111,121,112,97,100,0,0,37,115,95,109,97,115,107,0,116,117,114,98,111,0,0,0,82,101,116,114,111,65,114,99,104,58,32,78,111,32,82,79,77,44,32,115,116,97,114,116,105,110,103,32,100,117,109,109,121,32,99,111,114,101,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,46,10,0,0,0,0,0,118,105,100,101,111,95,112,111,115,116,95,102,105,108,116,101,114,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,104,97,100,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,0,0,0,0,0,0,0,0,78,111,110,101,0,0,0,0,37,115,95,105,110,112,117,116,95,115,108,111,116,0,0,0,114,51,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,82,79,77,58,32,37,115,46,10,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,95,69,83,67,65,80,69,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,37,115,10,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,99,111,108,111,114,0,0,0,0,0,46,98,114,97,109,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,118,101,114,115,105,111,110,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,117,112,32,102,114,97,109,101,32,98,117,102,102,101,114,32,111,98,106,101,99,116,115,46,32,77,117,108,116,105,45,112,97,115,115,32,115,104,97,100,105,110,103,32,119,105,108,108,32,110,111,116,32,119,111,114,107,46,10,0,0,37,115,95,119,114,97,109,0,108,51,0,0,0,0,0,0,114,101,116,114,111,97,114,99,104,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,83,69,84,95,76,73,66,82,69,84,82,79,95,80,65,84,72,46,10,0,0,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,104,101,105,103,104,116,0,0,46,97,114,97,109,0,0,0,35,118,101,114,115,105,111,110,32,37,117,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,0,0,0,78,47,65,32,40,112,111,114,116,32,35,37,117,41,0,0,37,115,95,115,101,109,97,110,116,105,99,0,0,0,0,0,114,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,70,82,65,77,69,95,84,73,77,69,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,119,105,100,116,104,0,0,0,115,101,116,116,105,110,103,115,46,99,0,0,0,0,0,0,46,112,114,97,109,0,0,0,49,48,49,49,45,48,48,0,35,118,101,114,115,105,111,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,35,37,100,0,0,0,0,0,108,50,0,0,0,0,0,0,83,70,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,109,111,118,105,110,103,32,116,101,109,112,111,97,114,121,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,110,111,0,0,0,0,0,0,100,114,105,118,101,114,46,99,0,0,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,121,0,0,0,0,0,0,0,88,88,88,88,88,88,88,88,0,0,0,0,0,0,0,0,46,114,116,99,0,0,0,0,46,46,0,0,0,0,0,0,84,45,55,48,48,57,54,32,45,48,48,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,98,105,110,100,32,65,80,73,32,37,115,32,116,111,32,99,111,110,116,101,120,116,32,37,115,46,10,0,0,0,0,0,0,37,46,50,102,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,65,77,32,119,105,108,108,32,110,111,116,32,98,101,32,115,97,118,101,100,46,10,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,0,32,66,73,78,65,82,89,0,121,101,115,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,120,0,0,0,0,0,0,0,103,103,95,101,120,116,114,97,0,0,0,0,0,0,0,0,71,69,78,80,76,85,83,45,71,88,32,49,46,55,46,52,0,0,0,0,0,0,0,0,84,45,49,50,48,49,48,54,45,48,48,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,105,110,107,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,0,0,0,0,0,79,112,101,110,71,76,32,69,83,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,107,105,112,112,105,110,103,32,83,82,65,77,32,108,111,97,100,46,10,0,83,77,83,32,74,97,112,97,110,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,97,110,121,32,82,79,77,83,32,116,104,97,116,32,109,97,116,99,104,101,100,32,118,97,108,105,100,32,101,120,116,101,110,115,105,111,110,115,32,102,111,114,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,73,68,65,84,0,0,0,0,103,108,77,97,112,66,117,102,102,101,114,79,69,83,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,99,111,110,116,101,120,116,32,105,115,32,117,115,101,100,44,32,98,117,116,32,115,104,97,100,101,114,32,105,115,32,110,111,116,32,109,111,100,101,114,110,46,32,67,97,110,110,111,116,32,117,115,101,32,105,116,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,68,105,109,101,110,115,105,111,110,115,58,32,37,117,120,37,117,10,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,83,85,80,80,79,82,84,95,78,79,95,71,65,77,69,58,32,37,115,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,109,117,108,116,105,112,97,115,115,32,115,104,97,100,101,114,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,68,73,83,75,32,65,80,80,69,78,68,32,37,115,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,71,65,32,105,109,97,103,101,32,105,115,32,110,111,116,32,117,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,46,46,46,32,67,97,110,110,111,116,32,114,101,99,111,118,101,114,32,115,97,118,101,32,102,105,108,101,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,88,77,76,32,115,104,97,100,101,114,58,32,37,115,10,0,0,0,0,0,0,101,110,97,98,108,101,100,0,84,45,54,57,48,52,54,45,53,48,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,105,110,103,32,71,76,83,76,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,46,10,51,50,45,98,105,116,32,112,97,116,104,32,119,105,108,108,32,114,101,113,117,105,114,101,32,99,111,110,118,101,114,115,105,111,110,46,10,0,0,0,60,82,79,77,32,100,105,114,62,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,103,114,97,98,32,99,104,101,97,116,115,46,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,0,0,60,33,91,67,68,65,84,65,91,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,75,101,121,58,32,37,115,10,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,10,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,117,110,107,110,111,119,110,32,99,111,110,116,101,120,116,46,10,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,120,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,99,99,101,101,100,101,100,32,105,110,32,115,97,118,105,110,103,32,82,65,77,32,100,97,116,97,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,51,0,0,0,0,0,0,0,84,45,52,53,48,51,51,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,32,102,111,117,110,100,32,102,111,114,32,71,76,69,83,46,10,0,0,0,0,60,100,101,102,97,117,108,116,62,0,0,0,0,0,0,0,105,109,112,111,114,116,115,0,97,0,0,0,0,0,0,0,84,45,50,54,48,49,51,0,61,61,61,32,66,117,105,108,100,32,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,32,99,111,110,116,101,120,116,44,32,98,117,116,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,79,112,101,110,71,76,69,83,50,46,32,67,97,110,110,111,116,32,117,115,101,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,99,97,108,101,0,0,0,0,0,0,0,0,102,105,110,100,95,97,117,100,105,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,37,89,45,37,109,45,37,100,45,37,72,45,37,77,45,37,83,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,85,83,65,0,0,0,0,0,35,100,101,102,105,110,101,32,70,82,65,71,77,69,78,84,10,0,0,0,0,0,0,0,66,71,82,65,56,56,56,56,0,0,0,0,0,0,0,0,37,46,51,102,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,95,99,108,97,115,115,0,0,0,0,0,114,105,103,104,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,116,97,108,32,101,114,114,111,114,32,114,101,99,101,105,118,101,100,32,105,110,58,32,34,37,115,34,10,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,69,83,50,32,99,111,110,116,101,120,116,46,10,0,0,0,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,101,110,97,98,108,101,0,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,97,117,100,105,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,37,115,47,82,101,116,114,111,65,114,99,104,45,114,101,99,111,118,101,114,121,45,0,0,49,0,0,0,0,0,0,0,117,115,97,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,112,108,97,121,98,97,99,107,46,10,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,104,97,100,101,114,44,32,102,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,0,0,0,108,101,102,116,0,0,0,0,90,73,80,124,122,105,112,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,110,111,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,105,122,101,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,97,117,100,105,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,48,0,0,0,0,0,0,0,74,65,80,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,0,0,37,46,51,102,32,72,122,32,40,37,46,49,102,37,37,32,100,101,118,44,32,37,117,32,115,97,109,112,108,101,115,41,0,0,0,0,0,0,0,0,37,115,95,119,114,97,112,95,109,111,100,101,0,0,0,0,100,111,119,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,58,32,37,115,32,37,115,0,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,72,87,95,82,69,78,68,69,82,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,86,65,82,73,65,66,76,69,32,37,115,58,10,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,112,97,116,104,0,102,105,110,100,95,118,105,100,101,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,79,77,32,105,115,32,117,115,101,100,44,32,98,117,116,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,104,105,115,46,10,0,0,114,103,98,0,0,0,0,0,106,97,112,0,0,0,0,0,35,100,101,102,105,110,101,32,86,69,82,84,69,88,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,118,97,108,105,100,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,32,67,111,110,116,105,110,117,105,110,103,32,119,105,116,104,111,117,116,32,115,104,97,100,101,114,115,46,10,0,0,0,0,0,0,0,37,46,49,102,120,0,0,0,37,115,95,108,105,110,101,97,114,0,0,0,0,0,0,0,117,112,0,0,0,0,0,0,83,101,116,116,105,110,103,32,114,101,102,114,101,115,104,32,114,97,116,101,32,116,111,58,32,37,46,51,102,32,72,122,46,0,0,0,0,0,0,0,118,48,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,68,73,83,75,95,67,79,78,84,82,79,76,95,73,78,84,69,82,70,65,67,69,46,10,0,118,105,100,101,111,95,97,108,108,111,119,95,114,111,116,97,116,101,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,118,105,100,101,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,32,105,110,32,34,37,115,34,10,0,0,0,0,0,0,0,0,115,118,105,100,101,111,0,0,69,85,82,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,118,101,114,116,101,120,32,115,104,97,100,101,114,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,10,0,0,0,0,37,117,0,0,0,0,0,0,116,101,120,116,117,114,101,115,0,0,0,0,0,0,0,0,115,116,97,114,116,0,0,0,84,117,114,98,111,32,101,110,97,98,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,75,69,89,66,79,65,82,68,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,101,110,97,98,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,118,105,100,101,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,116,99,104,32,37,115,58,32,69,114,114,111,114,32,35,37,117,10,0,0,0,0,0,99,111,109,112,111,115,105,116,101,0,0,0,0,0,0,0,101,117,114,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,71,76,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,78,111,116,32,108,111,97,100,105,110,103,32,97,110,121,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,59,0,0,0,0,0,0,0,115,101,108,101,99,116,0,0,84,45,53,48,50,56,54,0,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,82,101,116,114,111,80,97,100,44,32,80,108,97,121,101,114,32,37,117,44,32,66,117,116,116,111,110,32,34,37,115,34,32,61,62,32,34,37,115,34,10,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,0,0,0,0,48,48,48,48,48,48,48,48,0,0,0,0,0,0,0,0,102,105,110,100,95,105,110,112,117,116,95,100,114,105,118,101,114,40,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,112,97,116,99,104,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,40,37,115,41,46,10,0,0,0,0,0,0,46,0,0,0,0,0,0,0,109,111,110,111,99,104,114,111,109,101,0,0,0,0,0,0,71,85,78,32,70,73,71,72,84,69,82,83,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,71,76,83,76,32,115,104,97,100,101,114,58])
.concat([32,37,115,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,110,32,115,112,101,99,105,102,105,101,100,32,71,76,32,101,114,114,111,114,46,10,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,37,117,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,100,105,115,107,32,37,117,32,111,102,32,37,117,46,0,0,0,0,82,51,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,70,73,76,69,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,73,78,80,85,84,95,68,69,83,67,82,73,80,84,79,82,83,58,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,68,105,100,110,39,116,32,114,101,97,100,32,119,104,111,108,101,32,102,105,108,101,46,10,0,0,0,0,118,105,100,101,111,95,114,101,102,114,101,115,104,95,114,97,116,101,0,0,0,0,0,0,9,37,115,10,0,0,0,0,79,118,101,114,115,99,97,110,32,109,111,100,101,59,32,48,124,49,124,50,124,51,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,112,97,116,99,104,101,100,32,82,79,77,32,46,46,46,10,0,0,0,0,0,100,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,83,78,65,84,67,72,69,82,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,79,117,116,32,111,102,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,119,114,97,112,95,109,111,100,101,37,117,0,0,0,0,0,98,0,0,0,0,0,0,0,82,101,109,111,118,101,100,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,45,37,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,79,70,70,83,69,84,58,32,37,117,44,32,67,83,73,90,69,58,32,37,117,44,32,83,73,90,69,58,32,37,117,46,10,0,0,0,0,73,72,68,82,0,0,0,0,103,108,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,83,116,111,99,107,32,71,76,83,76,32,115,104,97,100,101,114,115,32,119,105,108,108,32,98,101,32,117,115,101,100,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,65,116,116,101,109,112,116,101,100,32,116,111,32,114,101,45,105,110,105,116,105,97,108,105,122,101,32,100,114,105,118,101,114,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,67,97,110,110,111,116,32,102,105,110,100,32,115,104,97,100,101,114,32,99,111,114,101,32,102,111,114,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,0,0,0,67,79,82,69,32,83,69,76,69,67,84,73,79,78,32,37,115,0,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,95,97,117,116,111,0,99,103,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,65,118,97,105,108,97,98,108,101,32,105,110,112,117,116,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,37,115,32,102,105,108,101,32,105,110,32,34,37,115,34,44,32,97,116,116,101,109,112,116,105,110,103,32,116,111,32,112,97,116,99,104,32,46,46,46,10,0,0,0,0,0,0,119,98,0,0,0,0,0,0,76,69,84,72,65,76,32,69,78,70,79,82,67,69,82,83,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,111,112,101,114,97,116,105,111,110,46,10,0,0,0,0,79,70,70,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,111,118,101,114,108,97,121,115,32,118,97,114,105,97,98,108,101,32,110,111,116,32,100,101,102,105,110,101,100,32,105,110,32,99,111,110,102,105,103,46,10,0,0,102,105,108,116,101,114,95,108,105,110,101,97,114,37,117,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,115,97,116,117,114,97,116,101,95,112,99,116,0,0,0,115,104,97,50,53,54,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,105,109,97,103,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,60,47,37,115,62,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,68,101,115,99,114,105,112,116,105,111,110,58,32,37,115,10,0,0,0,0,83,101,116,116,105,110,103,32,100,105,115,107,32,37,117,32,111,102,32,37,117,32,105,110,32,116,114,97,121,46,0,0,76,51,32,98,117,116,116,111,110,32,40,108,101,102,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,0,97,115,112,101,99,116,95,114,97,116,105,111,95,105,110,100,101,120,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,105,110,112,117,116,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,32,118,97,108,105,100,32,82,79,77,32,112,97,116,99,104,46,10,0,0,0,0,0,70,114,111,110,116,101,110,100,32,115,117,112,112,111,114,116,115,32,82,71,66,53,54,53,32,45,32,119,105,108,108,32,117,115,101,32,116,104,97,116,32,105,110,115,116,101,97,100,32,111,102,32,88,82,71,66,49,53,53,53,46,10,0,0,87,72,79,32,83,72,79,84,32,74,79,72,78,78,89,32,82,79,67,75,63,0,0,0,114,117,98,121,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,79,78,0,0,0,0,0,0,115,104,97,100,101,114,37,117,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,65,110,97,108,111,103,32,104,105,116,98,111,120,32,116,121,112,101,32,109,117,115,116,32,98,101,32,34,114,97,100,105,97,108,34,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,37,115,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,32,46,46,46,10,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,32,97,117,100,105,111,32,105,110,112,117,116,32,114,97,116,101,32,116,111,58,32,37,46,50,102,32,72,122,46,10,0,0,0,73,80,83,0,0,0,0,0,83,101,103,97,32,67,68,32,82,65,77,32,67,65,82,84,32,105,115,32,108,111,99,97,116,101,100,32,97,116,58,32,37,115,10,0,0,0,0,0,77,65,68,32,68,79,71,32,77,67,67,82,69,69,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,101,110,117,109,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,88,77,76,32,115,104,97,100,101,114,32,46,46,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,72,105,116,98,111,120,32,116,121,112,101,32,40,37,115,41,32,105,115,32,105,110,118,97,108,105,100,46,32,85,115,101,32,34,114,97,100,105,97,108,34,32,111,114,32,34,114,101,99,116,34,46,10,0,0,0,99,108,111,115,101,0,0,0,82,50,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,118,105,100,101,111,95,99,114,111,112,95,111,118,101,114,115,99,97,110,0,0,0,0,0,66,32,98,117,116,116,111,110,32,40,100,111,119,110,41,0,37,117,58,37,117,32,40,49,58,49,32,80,65,82,41,0,82,101,116,114,111,65,114,99,104,58,32,71,97,109,101,32,70,80,83,32,62,32,77,111,110,105,116,111,114,32,70,80,83,46,32,67,97,110,110,111,116,32,114,101,108,121,32,111,110,32,86,83,121,110,99,46,10,0,0,0,0,0,0,0,66,80,83,0,0,0,0,0,83,101,103,97,32,67,68,32,74,80,32,66,82,65,77,32,105,115,32,108,111,99,97,116,101,100,32,97,116,58,32,37,115,10,0,0,0,0,0,0,77,65,68,32,68,79,71,32,73,73,32,84,72,69,32,76,79,83,84,32,71,79,76,68,0,0,0,0,0,0,0,0,84,101,120,116,117,114,101,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,76,111,97,100,101,100,32,37,117,32,112,114,111,103,114,97,109,40,115,41,46,10,0,0,0,78,101,97,114,101,115,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,110,111,114,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,105,110,32,88,77,76,32,102,105,108,101,46,10,0,0,0,0,0,0,114,101,99,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,97,100,106,117,115,116,101,100,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,116,111,32,37,117,32,77,105,66,10,0,0,0,0,0,101,106,101,99,116,0,0,0,118,105,100,101,111,95,115,99,97,108,101,95,105,110,116,101,103,101,114,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,84,105,109,105,110,103,115,32,100,101,118,105,97,116,101,32,116,111,111,32,109,117,99,104,46,32,87,105,108,108,32,110,111,116,32,97,100,106,117,115,116,46,32,40,68,105,115,112,108,97,121,32,61,32,37,46,50,102,32,72,122,44,32,71,97,109,101,32,61,32,37,46,50,102,32,72,122,41,10,0,0,0,0,0,0,85,80,83,0,0,0,0,0,83,101,103,97,32,67,68,32,85,83,32,66,82,65,77,32,105,115,32,108,111,99,97,116,101,100,32,97,116,58,32,37,115,10,0,0,0,0,0,0,67,82,73,77,69,32,80,65,84,82,79,76,0,0,0,0,103,108,71,101,116,80,111,105,110,116,101,114,118,0,0,0,37,115,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,105,110,105,116,32,102,97,105,108,101,100,46,10,0,76,105,110,101,97,114,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,114,97,100,105,97,108,0,0,70,97,105,108,101,100,32,116,111,32,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,76,50,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,67,65,78,95,68,85,80,69,58,32,116,114,117,101,10,0,0,118,105,100,101,111,95,102,111,114,99,101,95,97,115,112,101,99,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,117,100,105,111,32,98,97,99,107,101,110,100,32,102,97,105,108,101,100,32,116,111,32,119,114,105,116,101,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,115,111,117,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,109,111,117,110,116,32,111,102,32,116,105,109,101,32,115,112,101,110,116,32,99,108,111,115,101,32,116,111,32,117,110,100,101,114,114,117,110,58,32,37,46,50,102,32,37,37,46,32,67,108,111,115,101,32,116,111,32,98,108,111,99,107,105,110,103,58,32,37,46,50,102,32,37,37,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,115,99,111,112,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,101,118,101,114,97,108,32,112,97,116,99,104,101,115,32,97,114,101,32,101,120,112,108,105,99,105,116,108,121,32,100,101,102,105,110,101,100,44,32,105,103,110,111,114,105,110,103,32,97,108,108,32,46,46,46,10,0,0,0,83,101,103,97,32,67,68,32,69,85,32,66,82,65,77,32,105,115,32,108,111,99,97,116,101,100,32,97,116,58,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,77,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,67,79,82,80,83,69,32,75,73,76,76,69,82,0,0,0,103,108,71,101,116,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,80,114,101,118,37,117,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,10,0,0,37,115,0,0,0,0,0,0,115,99,114,105,112,116,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,110,101,120,116,95,116,97,114,103,101,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,115,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,67,108,111,115,101,100,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,109,111,117,115,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,115,99,111,110,110,101,99,116,105,110,103,32,100,101,118,105,99,101,32,102,114,111,109,32,112,111,114,116,32,37,117,46,10,0,0,88,32,40,117,112,41,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,99,111,110,102,105,103,32,102,105,108,101,46,32,85,115,105,110,103,32,115,121,115,116,101,109,32,100,101,102,97,117,108,116,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,99,111,110,102,105,103,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,118,105,100,101,111,95,115,109,111,111,116,104,0,0,0,0,46,99,102,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,97,117,100,105,111,32,98,117,102,102,101,114,32,115,97,116,117,114,97,116,105,111,110,58,32,37,46,50,102,32,37,37,44,32,115,116,97,110,100,97,114,100,32,100,101,118,105,97,116,105,111,110,32,40,112,101,114,99,101,110,116,97,103,101,32,112,111,105,110,116,115,41,58,32,37,46,50,102,32,37,37,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,82,67,51,50,58,32,48,120,37,120,44,32,83,72,65,50,53,54,58,32,37,115,10,0,0,0,0,0,83,101,103,97,32,67,68,32,74,80,32,66,73,79,83,32,115,104,111,117,108,100,32,98,101,32,108,111,99,97,116,101,100,32,97,116,58,32,37,115,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,66,79,68,89,32,67,79,85,78,84,0,0,0,0,0,0,103,108,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,0,0,0,80,114,101,118,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,114,115,105,111,110,58,32,37,115,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,111,114,116,32,118,97,108,117,101,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,46,120,109,108,0,0,0,0,46,105,112,115,0,0,0,0,69,106,101,99,116,101,100,0,46,98,112,115,0,0,0,0,82,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,46,117,112,115,0,0,0,0,65,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,102,97,109,105,32,84,117,114,98,111,32,83,82,65,77,32,112,97,116,104,115,32,119,105,108,108,32,98,101,32,105,110,102,101,114,114,101,100,32,102,114,111,109,32,116,104,101,105,114,32,114,101,115,112,101,99,116,105,118,101,32,112,97,116,104,115,32,116,111,32,97,118,111,105,100,32,99,111,110,102,108,105,99,116,115,46,10,0,0,0,118,105,100,101,111,95,116,104,114,101,97,100,101,100,0,0,46,112,115,114,109,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,115,104,97,100,101,114,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,103,97,109,101,46,10,0,0,0,0,0,0,83,101,103,97,32,67,68,32,85,83,32,66,73,79,83,32,115,104,111,117,108,100,32,98,101,32,108,111,99,97,116,101,100,32,97,116,58,32,37,115,10,0,0,0,0,0,0,0,9,45,68,47,45,45,100,101,116,97,99,104,58,32,68,101,116,97,99,104,32,82,101,116,114,111,65,114,99,104,32,102,114,111,109,32,116,104,101,32,114,117,110,110,105,110,103,32,99,111,110,115,111,108,101,46,32,78,111,116,32,114,101,108,101,118,97,110,116,32,102,111,114,32,97,108,108,32,112,108,97,116,102,111,114,109,115,46,10,0,0,0,0,0,0,0,84,50,32,59,32,84,72,69,32,65,82,67,65,68,69,32,71,65,77,69,0,0,0,0,103,108,71,101,116,79,98,106,101,99,116,76,97,98,101,108,0,0,0,0,0,0,0,0,80,97,115,115,37,117,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,110,100,111,114,58,32,37,115,44,32,82,101,110,100,101,114,101,114,58,32,37,115,46,10,0,0,0,0,0,102,114,111,110,116,101,110,100,47,109,101,110,117,47,46,46,47,46,46,47,103,102,120,47,46,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,105,109,112,111,114,116,0,0,82,101,116,114,111,65,114,99,104,58,32,91,67,111,110,102,105,103,93,58,32,81,117,101,114,121,105,110,103,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,97,110,97,108,111,103,95,114,105,103,104,116,0,0,0,0,9,45,88,47,45,45,120,109,108,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,116,111,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,46,0,0,0,0,65,67,76,68,48,48,55,0,9,45,45,110,111,45,112,97,116,99,104,58,32,68,105,115,97,98,108,101,115,32,97,108,108,32,102,111,114,109,115,32,111,102,32,114,111,109,32,112,97,116,99,104,105,110,103,46,0,0,0,0,0,0,0,0,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,0,0,9,45,45,105,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,73,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,9,45,45,98,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,66,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,9,45,85,47,45,45,117,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,85,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,0,9,45,118,47,45,45,118,101,114,98,111,115,101,58,32,86,101,114,98,111,115,101,32,108,111,103,103,105,110,103,46,0,9,9,68,111,32,110,111,116,101,32,116,104,97,116,32,110,111,108,111,97,100,45,115,97,118,101,32,105,109,112,108,105,101,115,32,116,104,97,116,32,115,97,118,101,32,102,105,108,101,115,32,119,105,108,108,32,98,101,32,100,101,108,101,116,101,100,32,97,110,100,32,111,118,101,114,119,114,105,116,116,101,110,46,0,0,0,0,0,118,105,100,101,111,95,115,119,97,112,95,105,110,116,101,114,118,97,108,0,0,0,0,0,32,10,9,12,13,11,0,0,86,105,114,116,117,97,32,82,97,99,105,110,103,0,0,0,9,9,123,110,111,44,125,108,111,97,100,45,123,110,111,44,125,115,97,118,101,32,100,101,115,99,114,105,98,101,115,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,108,111,97,100,101,100,44,32,97,110,100,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,115,97,118,101,100,46,0,0,115,104,97,100,101,114,124,99,103,124,99,103,112,124,103,108,115,108,124,103,108,115,108,112,0,0,0,0,0,0,0,0,9,45,77,47,45,45,115,114,97,109,45,109,111,100,101,58,32,84,97,107,101,115,32,97,110,32,97,114,103,117,109,101,110,116,32,116,101,108,108,105,110,103,32,104,111,119,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,104,97,110,100,108,101,100,32,105,110,32,116,104,101,32,115,101,115,115,105,111,110,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,0,0,83,101,103,97,32,67,68,32,69,85,32,66,73,79,83,32,115,104,111,117,108,100,32,98,101,32,108,111,99,97,116,101,100,32,97,116,58,32,37,115,10,0,0,0,0,0,0,0,9,45,82,47,45,45,98,115,118,114,101,99,111,114,100,58,32,83,116,97,114,116,32,114,101,99,111,114,100,105,110,103,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,32,102,114,111,109,32,116,104,101,32,98,101,103,105,110,110,105,110,103,46,0,0,0,77,69,78,65,67,69,82,0,103,108,79,98,106,101,99,116,76,97,98,101,108,0,0,0,80,97,115,115,80,114,101,118,37,117,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,101,116,101,99,116,105,110,103,32,115,99,114,101,101,110,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,46,10,0,0,48,46,57,46,57,46,51,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,101,120,116,117,114,101,32,105,109,97,103,101,32,102,97,105,108,101,100,32,116,111,32,108,111,97,100,46,10,0,0,0,0,0,97,110,97,108,111,103,95,108,101,102,116,0,0,0,0,0,9,45,80,47,45,45,98,115,118,112,108,97,121,58,32,80,108,97,121,98,97,99,107,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,46,0,0,0,0,0,0,0,98,108,97,114,103,103,95,110,116,115,99,95,102,105,108,116,101,114,0,0,0,0,0,0,9,45,52,47,45,45,109,117,108,116,105,116,97,112,58,32,67,111,110,110,101,99,116,32,97,32,83,78,69,83,32,109,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,65,112,112,101,110,100,101,100,32,100,105,115,107,58,32,37,115,0,0,0,0,0,0,0,9,45,74,47,45,45,106,117,115,116,105,102,105,101,114,115,58,32,68,97,105,115,121,32,99,104,97,105,110,32,116,119,111,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,115,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,76,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,0,46,67,85,69,0,0,0,0,9,45,106,47,45,45,106,117,115,116,105,102,105,101,114,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,9,45,112,47,45,45,115,99,111,112,101,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,83,117,112,101,114,83,99,111,112,101,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,9,45,109,47,45,45,109,111,117,115,101,58,32,67,111,110,110,101,99,116,32,97,32,109,111,117,115,101,32,105,110,116,111,32,112,111,114,116,32,111,102,32,116,104,101,32,100,101,118,105,99,101,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,0,0,0,9,45,65,47,45,45,100,117,97,108,97,110,97,108,111,103,58,32,67,111,110,110,101,99,116,32,97,32,68,117,97,108,65,110,97,108,111,103,32,99,111,110,116,114,111,108,108,101,114,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,118,105,100,101,111,95,98,108,97,99,107,95,102,114,97,109,101,95,105,110,115,101,114,116,105,111,110,0,0,0,0,0,34,0,0,0,0,0,0,0,9,45,78,47,45,45,110,111,100,101,118,105,99,101,58,32,68,105,115,99,111,110,110,101,99,116,115,32,99,111,110,116,114,111,108,108,101,114,32,100,101,118,105,99,101,32,99,111,110,110,101,99,116,101,100,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,48,82,71,66,49,53,53,53,32,112,105,120,101,108,32,102,111,114,109,97,116,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,97,110,100,32,119,105,108,108,32,98,101,32,115,108,111,119,101,114,46,32,70,111,114,32,49,53,47,49,54,45,98,105,116,44,32,82,71,66,53,54,53,32,102,111,114,109,97,116,32,105,115,32,112,114,101,102,101,114,114,101,100,46,10,0,0,0,0,0,0,0,0,111,118,101,114,115,99,97,110,0,0,0,0,0,0,0,0,9,45,45,115,117,102,97,109,105,66,58,32,80,97,116,104,32,116,111,32,66,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,108,111,97,100,105,110,103,32,115,107,105,112,112,101,100,46,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,119,105,108,108,32,108,111,97,100,32,105,116,32,111,110,32,105,116,115,32,111,119,110,46,10,0,0,0,0,0,0,0,0,9,45,45,115,117,102,97,109,105,65,58,32,80,97,116,104,32,116,111,32,65,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,32,76,111,97,100,32,83,117,102,97,109,105,32,98,97,115,101,32,99,97,114,116,32,97,115,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,37,115,37,99,99,97,114,116,46,98,114,109,0,0,0,0,103,108,80,111,112,68,101,98,117,103,71,114,111,117,112,0,79,114,105,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,10,0,0,0,0,0,0,0,0,37,115,32,45,32,37,115,32,37,115,0,0,0,0,0,0,46,46,46,0,0,0,0,0,116,101,120,116,117,114,101,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,79,118,101,114,108,97,121,32,100,101,115,99,32,105,115,32,105,110,118,97,108,105,100,46,32,82,101,113,117,105,114,101,115,32,97,116,32,108,101,97,115,116,32,54,32,116,111,107,101,110,115,46,10,0,0,0,9,45,66,47,45,45,98,115,120,115,108,111,116,58,32,80,97,116,104,32,116,111,32,66,83,88,32,115,108,111,116,116,101,100,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,9,45,98,47,45,45,98,115,120,58,32,80,97,116,104,32,116,111,32,66,83,88,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,82,101,115,101,116,46,0,0,9,45,103,47,45,45,103,97,109,101,98,111,121,58,32,80,97,116,104,32,116,111,32,71,97,109,101,98,111,121,32,82,79,77,46,32,76,111,97,100,32,83,117,112,101,114,71,97,109,101,66,111,121,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,37,48,50,120,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,90,73,80,32,101,120,116,114,97,99,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,108,105,110,101,58,32,37,100,46,10,0,0,0,0,0,0,0,0,9,9,77,117,108,116,105,112,108,101,32,99,111,110,102,105,103,115,32,97,114,101,32,100,101,108,105,109,105,116,101,100,32,98,121,32,39,44,39,46,0,0,0,0,0,0,0,0,103,108,71,101,116,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,71,76,83,76,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,46,46,46,10,0,0,0,9,45,45,97,112,112,101,110,100,99,111,110,102,105,103,58,32,69,120,116,114,97,32,99,111,110,102,105,103,32,102,105,108,101,115,32,97,114,101,32,108,111,97,100,101,100,32,105,110,44,32,97,110,100,32,116,97,107,101,32,112,114,105,111,114,105,116,121,32,111,118,101,114,32,99,111,110,102,105,103,32,115,101,108,101,99,116,101,100,32,105,110,32,45,99,32,40,111,114,32,100,101,102,97,117,108,116,41,46,0,0,0,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,0,103,108,0,0,0,0,0,0,37,115,10,37,115,10,37,115,10,0,0,0,0,0,0,0,9,45,99,47,45,45,99,111,110,102,105,103,58,32,80,97,116,104,32,102,111,114,32,99,111,110,102,105,103,32,102,105,108,101,46,10,9,9,66,121,32,100,101,102,97,117,108,116,32,108,111,111,107,115,32,102,111,114,32,99,111,110,102,105,103,32,105,110,32,36,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,36,72,79,77,69,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,97,110,100,32,36,72,79,77,69,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,46,0,0,0,0,0,9,45,83,47,45,45,115,97,118,101,115,116,97,116,101,58,32,80,97,116,104,32,116,111,32,117,115,101,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,115,46,32,73,102,32,110,111,116,32,115,101,108,101,99,116,101,100,44,32,42,46,115,116,97,116,101,32,119,105,108,108,32,98,101,32,97,115,115,117,109,101,100,46,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,46,10,0,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,95,102,114,97,109,101,115,0,0,82,101,116,114,111,65,114,99,104,58,32,83,73,78,67,32,112,97,114,97,109,115,32,40,37,117,32,112,104,97,115,101,32,98,105,116,115,44,32,37,117,32,116,97,112,115,41,46,10,0,0,0,0,0,0,0,33,33,33,32,35,105,110,99,108,117,100,101,32,100,101,112,116,104,32,101,120,99,101,101,100,101,100,32,102,111,114,32,99,111,110,102,105,103,46,32,77,105,103,104,116,32,98,101,32,97,32,99,121,99,108,101,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,80,78,71,93,58,32,85,115,105,110,103,32,82,80,78,71,32,108,111,97,100,101,114,46,10,0,0,9,45,102,47,45,45,102,117,108,108,115,99,114,101,101,110,58,32,83,116,97,114,116,32,82,101,116,114,111,65,114,99,104,32,105,110,32,102,117,108,108,115,99,114,101,101,110,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,99,111,110,102,105,103,32,115,101,116,116,105,110,103,115,46,0,0,9,45,115,47,45,45,115,97,118,101,58,32,80,97,116,104,32,102,111,114,32,115,97,118,101,32,102,105,108,101,32,40,42,46,115,114,109,41,46,0,71,45,54,48,49,51,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,101,101,100,32,116,111,32,100,101,102,105,110,101,32,97,116,32,108,101,97,115,116,32,49,32,115,104,97,100,101,114,46,10,0,37,115,37,99,115,99,100,95,74,46,98,114,109,0,0,0,9,45,45,102,101,97,116,117,114,101,115,58,32,80,114,105,110,116,115,32,97,118,97,105,108,97,98,108,101,32,102,101,97,116,117,114,101,115,32,99,111,109,112,105,108,101,100,32,105,110,116,111,32,82,101,116,114,111,65,114,99,104,46,0,103,108,80,117,115,104,68,101,98,117,103,71,114,111,117,112,0,0,0,0,0,0,0,0,70,114,97,109,101,68,105,114,101,99,116,105,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,99,114,101,97,116,105,110,103,32,70,66,79,32,116,101,120,116,117,114,101,32,35,37,100,58,32,37,117,120,37,117,10,0,0,0,71,65,77,69,32,40,37,115,41,32,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,71,85,73,93,58,32,79,112,101,110,105,110,103,32,104,105,115,116,111,114,121,58,32,37,115,46,10,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,88,77,76,32,115,104,97,100,101,114,32,97,116,116,114,105,98,117,116,101,115,32,100,111,32,110,111,116,32,99,111,109,112,108,121,32,119,105,116,104,32,115,112,101,99,105,102,105,99,97,116,105,111,110,115,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,111,118,101,114,108,97,121,32,100,101,115,99,46,10,0,0,99,97,114,116,114,105,100,103,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,9,9,73,102,32,110,111,32,97,114,103,117,109,101,110,116,115,32,97,114,101,32,112,97,115,115,101,100,32,116,111,32,82,101,116,114,111,65,114,99,104,44,32,105,116,32,105,115,32,101,113,117,105,118,97,108,101,110,116,32,116,111,32,117,115,105,110,103,32,45,45,109,101,110,117,32,97,115,32,111,110,108,121,32,97,114,103,117,109,101,110,116,46,0,0,0,47,62,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,114,101,32,111,112,116,105,111,110,58,10,0,0,0,0,0,0,0,0,9,45,45,109,101,110,117,58,32,68,111,32,110,111,116,32,114,101,113,117,105,114,101,32,82,79,77,32,111,114,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,116,111,32,98,101,32,108,111,97,100,101,100,44,32,115,116,97,114,116,115,32,100,105,114,101,99,116,108,121,32,105,110,32,109,101,110,117,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,115,101,116,116,105,110,103,32,103,97,109,101,46,10,0,0,0,0,0,9,45,104,47,45,45,104,101,108,112,58,32,83,104,111,119,32,116,104,105,115,32,104,101,108,112,32,109,101,115,115,97,103,101,46,0,0,0,0,0,88,32,98,117,116,116,111,110,32,40,116,111,112,41,0,0,85,115,97,103,101,58,32,114,101,116,114,111,97,114,99,104,32,91,114,111,109,32,102,105,108,101,93,32,91,111,112,116,105,111,110,115,46,46,46,93,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,114,111,110,116,101,110,100,32,102,111,114,32,108,105,98,114,101,116,114,111,32,45,45,32,118,48,46,57,46,57,46,51,32,45,45,0,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,0,77,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,83,99,114,105,112,116,32,115,117,112,112,111,114,116,32,105,110,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,68,105,115,107,32,83,119,97,112,32,78,101,120,116,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,0,105,110,99,108,117,100,101,32,0,0,0,0,0,0,0,0,80,121,116,104,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,109,111,110,105,116,111,114,32,72,122,58,32,37,46,54,102,32,72,122,46,32,40,37,46,51,102,32,37,37,32,102,114,97,109,101,32,116,105,109,101,32,100,101,118,105,97,116,105,111,110,44,32,98,97,115,101,100,32,111,110,32,37,117,32,108,97,115,116,32,115,97,109,112,108,101,115,41,46,10,0,0,0,0,0,0,68,105,115,107,32,69,106,101,99,116,32,84,111,103,103,108])
.concat([101,0,0,0,0,0,0,0,80,101,101,114,45,116,111,45,112,101,101,114,32,110,101,116,112,108,97,121,0,0,0,0,77,75,45,52,52,49,48,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,46,10,0,0,78,101,120,116,32,79,118,101,114,108,97,121,0,0,0,0,37,115,37,99,115,99,100,95,85,46,98,114,109,0,0,0,78,101,116,112,108,97,121,0,87,79,78,68,69,82,32,76,73,66,82,65,82,89,0,0,103,108,71,101,116,68,101,98,117,103,77,101,115,115,97,103,101,76,111,103,0,0,0,0,70,114,97,109,101,67,111,117,110,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,105,110,105,116,32,70,66,79,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,86,111,108,117,109,101,32,68,111,119,110,0,0,0,0,0,78,111,32,67,111,114,101,0,46,114,101,116,114,111,97,114,99,104,45,103,97,109,101,45,104,105,115,116,111,114,121,46,116,120,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,100,101,114,110,32,71,76,83,76,32,119,97,115,32,99,104,111,115,101,110,32,97,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,119,97,115,32,110,111,116,32,112,114,111,118,105,100,101,100,46,32,84,104,105,115,32,105,115,32,97,110,32,101,114,114,111,114,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,107,101,121,58,32,37,115,46,10,0,0,0,84,84,70,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,119,105,116,104,32,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,85,112,0,0,0,0,0,0,0,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,69,110,97,98,108,101,32,72,111,116,107,101,121,0,0,0,79,110,45,116,104,101,45,102,108,121,32,114,101,99,111,114,100,105,110,103,32,111,102,32,103,97,109,101,112,108,97,121,32,119,105,116,104,32,108,105,98,97,118,99,111,100,101,99,0,0,0,0,0,0,0,0,83,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,70,70,109,112,101,103,0,0,78,101,116,112,108,97,121,32,70,108,105,112,32,80,108,97,121,101,114,115,0,0,0,0,68,121,110,97,109,105,99,32,114,117,110,45,116,105,109,101,32,108,111,97,100,105,110,103,32,111,102,32,108,105,98,114,101,116,114,111,32,108,105,98,114,97,114,121,0,0,0,0,68,121,110,97,109,105,99,0,68,83,80,32,67,111,110,102,105,103,0,0,0,0,0,0,79,112,101,110,71,76,32,114,101,110,100,101,114,45,116,111,45,116,101,120,116,117,114,101,32,40,109,117,108,116,105,45,112,97,115,115,32,115,104,97,100,101,114,115,41,0,0,0,83,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,118,105,100,101,111,95,118,115,121,110,99,0,0,0,0,0,70,66,79,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,111,101,115,32,110,111,116,32,104,97,118,101,32,101,110,111,117,103,104,32,115,97,109,112,108,101,115,32,102,111,114,32,109,111,110,105,116,111,114,32,114,101,102,114,101,115,104,32,114,97,116,101,32,101,115,116,105,109,97,116,105,111,110,46,32,82,101,113,117,105,114,101,115,32,116,111,32,114,117,110,32,102,111,114,32,97,116,32,108,101,97,115,116,32,37,117,32,102,114,97,109,101,115,46,10,0,0,0,67,104,101,97,116,32,84,111,103,103,108,101,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,56,0,0,0,83,68,76,95,105,109,97,103,101,32,105,109,97,103,101,32,108,111,97,100,105,110,103,0,84,45,49,52,51,48,50,53,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,67,104,101,97,116,32,73,110,100,101,120,32,77,105,110,117,115,0,0,0,0,0,0,0,37,115,37,99,115,99,100,95,69,46,98,114,109,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,55,0,0,0,83,68,76,95,105,109,97,103,101,0,0,0,0,0,0,0,70,76,85,88,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,97,108,108,98,97,99,107,0,0,84,101,120,116,117,114,101,83,105,122,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,69,71,76,32,105,109,97,103,101,46,10,0,67,104,101,97,116,32,73,110,100,101,120,32,80,108,117,115,0,0,0,0,0,0,0,0,83,89,83,84,69,77,32,68,73,82,32,37,115,0,0,0,102,114,97,103,109,101,110,116,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,0,0,0,0,0,0,0,0,43,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,54,0,0,0,108,105,98,120,109,108,50,32,88,77,76,32,112,97,114,115,105,110,103,0,0,0,0,0,80,114,101,118,105,111,117,115,32,83,104,97,100,101,114,0,105,110,112,117,116,95,112,108,97,121,101,114,53,0,0,0,108,105,98,120,109,108,50,0,83,97,118,101,32,115,116,97,116,101,47,109,111,118,105,101,32,115,108,111,116,58,32,37,117,0,0,0,0,0,0,0,78,101,120,116,32,83,104,97,100,101,114,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,52,0,0,0,67,103,32,112,105,120,101,108,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,0,82,101,115,101,116,0,0,0,65,32,98,117,116,116,111,110,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,51,0,0,0,67,103,0,0,0,0,0,0,70,114,97,109,101,32,65,100,118,97,110,99,101,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,50,0,0,0,69,120,116,101,114,110,97,108,32,102,105,108,116,101,114,32,97,110,100,32,112,108,117,103,105,110,32,115,117,112,112,111,114,116,0,0,0,0,0,0,80,97,117,115,101,32,84,111,103,103,108,101,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,49,0,0,0,69,120,116,101,114,110,97,108,0,0,0,0,0,0,0,0,77,111,118,105,101,32,82,101,99,111,114,100,32,84,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,111,117,110,100,32,105,110,118,97,108,105,100,32,104,97,116,32,105,110,32,99,111,110,102,105,103,33,10,0,0,0,0,0,0,0,79,112,101,110,65,76,0,0,118,105,100,101,111,95,100,105,115,97,98,108,101,95,99,111,109,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,80,78,71,32,101,110,99,111,100,101,47,100,101,99,111,100,101,32,97,110,100,32,46,122,105,112,32,101,120,116,114,97,99,116,105,111,110,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,110,105,116,111,114,32,70,80,83,32,101,115,116,105,109,97,116,105,111,110,32,105,115,32,100,105,115,97,98,108,101,100,32,102,111,114,32,116,104,114,101,97,100,101,100,32,118,105,100,101,111,46,10,0,0,0,0,0,0,83,116,97,116,101,32,83,108,111,116,32,77,105,110,117,115,0,0,0,0,0,0,0,0,122,108,105,98,0,0,0,0,84,45,49,49,51,48,52,53,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,82,79,77,32,116,121,112,101,46,10,0,83,116,97,116,101,32,83,108,111,116,32,80,108,117,115,0,37,115,37,99,98,105,111,115,95,67,68,95,74,46,98,105,110,0,0,0,0,0,0,0,105,110,112,117,116,95,100,114,105,118,101,114,0,0,0,0,88,65,117,100,105,111,50,0,66,82,0,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,73,110,115,101,114,116,0,0,0,0,79,117,116,112,117,116,83,105,122,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,34,37,115,34,32,102,111,114,32,114,101,99,111,114,100,105,110,103,46,10,0,0,0,0,0,111,110,0,0,0,0,0,0,81,117,105,116,32,75,101,121,0,0,0,0,0,0,0,0,79,86,69,82,76,65,89,32,68,73,82,32,37,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,109,101,110,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,104,97,100,101,114,32,115,111,117,114,99,101,32,102,105,108,101,32,119,97,115,32,112,114,111,118,105,100,101,100,44,32,98,117,116,32,102,97,105,108,101,100,32,116,111,32,114,101,97,100,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,100,101,115,99,115,32,102,111,114,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,99,111,100,101,0,0,0,0,68,105,114,101,99,116,83,111,117,110,100,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,84,111,103,103,108,101,0,0,0,0,0,0,0,80,117,108,115,101,65,117,100,105,111,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,0,0,0,37,115,95,37,115,95,97,120,105,115,0,0,0,0,0,0,82,111,97,114,65,117,100,105,111,0,0,0,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,84,101,120,116,117,114,101,50,68,79,69,83,0,0,0,0,37,115,95,37,115,95,98,116,110,0,0,0,0,0,0,0,82,83,111,117,110,100,0,0,70,97,115,116,32,70,111,114,119,97,114,100,32,72,111,108,100,0,0,0,0,0,0,0,105,110,112,117,116,0,0,0,74,97,99,107,0,0,0,0,89,32,40,108,101,102,116,41,0,0,0,0,0,0,0,0,70,97,115,116,32,70,111,114,119,97,114,100,0,0,0,0,37,115,95,37,115,0,0,0,79,83,83,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,45,0,0,0,0,0,0,0,0,110,117,108,0,0,0,0,0,97,117,100,105,111,32,100,114,105,118,101,114,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,43,0,0,0,0,0,0,0,0,118,105,100,101,111,95,109,111,110,105,116,111,114,95,105,110,100,101,120,0,0,0,0,0,40,105,110,99,108,117,100,101,100,41,0,0,0,0,0,0,112,97,117,115,101,0,0,0,65,76,83,65,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,45,0,0,0,0,0,0,0,0,98,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0,103,108,115,108,0,0,0,0,88,86,105,100,101,111,32,111,117,116,112,117,116,0,0,0,84,45,49,50,55,48,49,53,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,101,120,116,114,97,99,116,32,82,79,77,32,102,114,111,109,32,122,105,112,112,101,100,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,43,0,0,0,0,0,0,0,0,37,115,37,99,98,105,111,115,95,67,68,95,85,46,98,105,110,0,0,0,0,0,0,0,101,109,115,99,114,105,112,116,101,110,0,0,0,0,0,0,116,105,108,100,101,0,0,0,88,86,105,100,101,111,0,0,83,69,71,65,32,80,73,67,79,0,0,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,111,110,116,114,111,108,0,0,0,73,110,112,117,116,83,105,122,101,0,0,0,0,0,0,0,111,102,102,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,45,0,83,65,86,69,70,73,76,69,32,68,73,82,32,37,115,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,102,97,105,108,101,100,46,10,0,0,0,0,71,76,32,114,97,115,116,101,114,0,0,0,0,0,0,0,115,114,99,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,100,101,115,99,115,46,10,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,115,99,114,111,108,108,95,108,111,99,107,0,0,0,0,0,79,112,101,110,86,71,32,111,117,116,112,117,116,32,115,117,112,112,111,114,116,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,43,0,112,114,105,110,116,95,115,99,114,101,101,110,0,0,0,0,79,112,101,110,86,71,0,0,83,97,118,101,100,32,115,116,97,116,101,32,116,111,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,45,0,100,105,118,105,100,101,0,0,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,43,0,82,105,103,104,116,32,68,45,112,97,100,0,0,0,0,0,109,117,108,116,105,112,108,121,0,0,0,0,0,0,0,0,69,71,76,0,0,0,0,0,84,117,114,98,111,32,69,110,97,98,108,101,0,0,0,0,98,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,75,77,83,47,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,66,32,40,98,111,116,116,111,109,41,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,51,32,66,117,116,116,111,110,0,0,0,0,0,0,110,117,109,108,111,99,107,0,75,77,83,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,51,32,66,117,116,116,111,110,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,114,101,97,116,105,110,103,32,70,66,79,32,37,100,32,64,32,37,117,120,37,117,10,0,0,0,0,0,99,97,112,115,108,111,99,107,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,79,86,69,82,83,67,65,78,58,32,37,117,10,0,0,0,0,79,112,101,110,71,76,32,100,114,105,118,101,114,0,0,0,82,101,116,114,111,80,97,100,32,82,50,32,66,117,116,116,111,110,0,0,0,0,0,0,118,105,100,101,111,95,119,105,110,100,111,119,101,100,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,32,37,115,10,0,0,0,112,101,114,105,111,100,0,0,114,0,0,0,0,0,0,0,79,112,101,110,71,76,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,105,110,105,116,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,50,32,66,117,116,116,111,110,0,0,0,0,0,0,107,101,121,112,97,100,57,0,84,104,114,101,97,100,105,110,103,32,115,117,112,112,111,114,116,0,0,0,0,0,0,0,84,45,57,53,48,51,53,0,122,105,112,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,32,66,117,116,116,111,110,0,0,0,0,0,0,0,37,115,37,99,98,105,111,115,95,67,68,95,69,46,98,105,110,0,0,0,0,0,0,0,107,101,121,112,97,100,56,0,84,104,114,101,97,100,115,0,83,69,71,65,0,0,0,0,103,108,73,115,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,0,0,76,85,84,84,101,120,67,111,111,114,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,32,86,83,121,110,99,32,61,62,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,32,66,117,116,116,111,110,0,0,0,0,0,0,0,83,65,86,69,83,84,65,84,69,32,68,73,82,32,37,115,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,37,115,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,104,97,118,101,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,105,110,32,97,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,110,117,109,98,101,114,32,111,102,32,100,101,115,99,115,32,102,114,111,109,32,99,111,110,102,105,103,32,107,101,121,58,32,37,115,46,10,0,0,0,0,99,104,101,97,116,0,0,0,107,101,121,112,97,100,55,0,83,68,76,32,100,114,105,118,101,114,115,0,0,0,0,0,82,101,116,114,111,80,97,100,32,88,32,66,117,116,116,111,110,0,0,0,0,0,0,0,107,101,121,112,97,100,54,0,83,68,76,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,0,82,101,116,114,111,80,97,100,32,65,32,66,117,116,116,111,110,0,0,0,0,0,0,0,107,101,121,112,97,100,53,0,9,37,115,58,10,9,9,37,115,58,32,37,115,10,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,107,101,121,112,97,100,52,0,70,101,97,116,117,114,101,115,58,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,107,101,121,112,97,100,51,0,107,101,121,112,97,100,50,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,88,82,71,66,56,56,56,56,46,10,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,45,45,109,101,110,117,32,119,97,115,32,117,115,101,100,44,32,98,117,116,32,82,79,77,32,102,105,108,101,32,119,97,115,32,112,97,115,115,101,100,32,97,115,32,119,101,108,108,46,10,0,107,101,121,112,97,100,49,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,114,103,117,109,101,110,116,115,46,10,0,0,107,101,121,112,97,100,48,0,82,101,116,114,111,80,97,100,32,83,116,97,114,116,32,66,117,116,116,111,110,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,32,105,110,32,45,45,115,114,97,109,45,109,111,100,101,46,10,0,0,112,97,103,101,100,111,119,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,112,104,105,99,115,32,100,114,105,118,101,114,32,100,105,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,97,110,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,112,105,99,107,32,97,32,115,117,105,116,97,98,108,101,32,100,114,105,118,101,114,46,10,0,0,0,82,101,116,114,111,80,97,100,32,83,101,108,101,99,116,32,66,117,116,116,111,110,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,114,101,115,111,108,118,101,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,33,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,81,117,105,116,32,82,101,116,114,111,65,114,99,104,0,0,108,111,97,100,45,115,97,118,101,0,0,0,0,0,0,0,112,97,103,101,117,112,0,0,73,78,68,69,88,32,49,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,116,111,32,34,37,115,34,46,10,0,82,101,116,114,111,80,97,100,32,89,32,66,117,116,116,111,110,0,0,0,0,0,0,0,91,103,101,110,112,108,117,115,93,58,32,68,101,102,97,117,108,116,105,110,103,32,115,121,115,116,101,109,32,100,105,114,101,99,116,111,114,121,32,116,111,32,37,115,46,10,0,0,82,101,115,116,97,114,116,32,82,101,116,114,111,65,114,99,104,0,0,0,0,0,0,0,108,111,97,100,45,110,111,115,97,118,101,0,0,0,0,0,110,117,109,57,0,0,0,0,69,83,65,71,71,32,78,69,83,69,83,73,0,0,0,0,103,108,71,101,110,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,0,0,0,67,111,108,111,114,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,51,50,45,98,105,116,32,70,66,79,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,49,54,45,98,105,116,46,10,0,0,0,0,82,101,116,114,111,80,97,100,32,66,32,66,117,116,116,111,110,0,0,0,0,0,0,0,83,72,65,68,69,82,32,68,73,82,32,37,115,0,0,0,82,101,116,114,111,65,114,99,104,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,115,117,99,99,101,101,100,101,100,46,10,0,0,0,118,101,114,116,101,120,0,0,82,101,115,116,97,114,116,32,71,97,109,101,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,115,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,99,104,101,97,116,32,102,111,114,32,103,97,109,101,58,32,34,37,115,34,10,0,0,110,111,108,111,97,100,45,115,97,118,101,0,0,0,0,0,110,117,109,56,0,0,0,0,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,0,82,101,115,117,109,101,32,71,97,109,101,0,0,0,0,0,110,111,108,111,97,100,45,110,111,115,97,118,101,0,0,0,76,111,97,100,101,100,32,115,116,97,116,101,32,102,114,111,109,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,110,117,109,55,0,0,0,0,84,97,107,101,32,83,99,114,101,101,110,115,104,111,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,115,99,111,110,110,101,99,116,32,100,101,118,105,99,101,32,102,114,111,109,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,110,117,109,54,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,0,0,0,0,0,0,0,76,101,102,116,32,68,45,112,97,100,0,0,0,0,0,0,76,111,97,100,32,83,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,109,111,117,115,101,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,110,117,109,53,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,58,32,37,115,46,10,0,0,0,83,97,118,101,32,83,116,97,116,101,0,0,0,0,0,0,112,97,114,115,101,95,105,110,112,117,116,40,41,0,0,0,110,117,109,52,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,82,71,66,53,54,53,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,46,10,0,0,0,0,0,68,105,115,107,32,79,112,116,105,111,110,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,0,110,117,109,51,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,114,111,109,58,32,37,115,46,10,0,0,0,0,83,101,116,116,105,110,103,115,0,0,0,0,0,0,0,0,104,115,58,102,118,83,58,109,58,112,52,106,74,65,58,103,58,98,58,99,58,66,58,89,58,90,58,85,58,68,78,58,88,58,80,58,82,58,77,58,0,0,0,0,0,0,0,0,110,117,109,50,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,121,0,0,0,0,0,0,35,105,110,99,108,117,100,101,32,34,37,115,34,10,0,0,80,97,116,104,32,79,112,116,105,111,110,115,0,0,0,0,102,101,97,116,117,114,101,115,0,0,0,0,0,0,0,0,110,117,109,49,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,111,112,101,110,32,118,105,100,101,111,32,100,114,105,118,101,114,32,46,46,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,47,101,116,99,0,0,0,0,110,117,108,108,0,0,0,0,47,112,114,111,99,47,37,117,47,37,115,0,0,0,0,0,73,110,112,117,116,32,79,112,116,105,111,110,115,0,0,0,100,101,116,97,99,104,0,0,110,117,109,48,0,0,0,0,73,78,68,69,88,32,48,49,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,0,115,105,110,99,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,114,101,99,111,118,101,114,32,46,46,46,10,0,0,37,115,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,0,109,100,124,115,109,100,124,98,105,110,124,99,117,101,124,103,101,110,124,105,115,111,124,115,109,115,124,103,103,124,115,103,0,0,0,0,0,0,0,0,65,117,100,105,111,32,79,112,116,105,111,110,115,0,0,0,120,109,108,0,0,0,0,0,102,49,50,0,0,0,0,0,69,83,65,71,77,32,71,69,32,65,82,68,86,73,32,69,0,0,0,0,0,0,0,0,103,108,68,101,108,101,116,101,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,86,101,114,116,101,120,67,111,111,114,100,0,0,0,0,0,46,116,103,97,0,0,0,0,65,82,77,95,97,114,103,98,56,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,111,107,105,110,103,32,102,111,114,32,99,111,110,102,105,103,32,105,110,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,66,82,79,87,83,69,82,32,68,73,82,32,37,115,0,0,98,105,116,109,97,112,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,76,101,103,97,99,121,32,115,104,97,100,101,114,115,32,97,114,101,32,100,101,112,114,101,99,97,116,101,100,46,10,0,0,0,0,0,0,0,86,105,100,101,111,32,79,112,116,105,111,110,115,0,0,0,111,118,101,114,108,97,121,37,117,95,102,117,108,108,95,115,99,114,101,101,110,0,0,0,110,97,109,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,110,111,45,112,97,116,99,104,0,0,0,0,0,0,0,0,102,49,49,0,0,0,0,0,37,115,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,84,45,53,48,48,56,54,0,67,111,114,101,32,79,112,116,105,111,110,115,0,0,0,0,105,112,115,0,0,0,0,0,102,49,48,0,0,0,0,0,37,115,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,76,111,97,100,32,71,97,109,101,0,0,0,0,0,0,0,98,112,115,0,0,0,0,0,102,57,0,0,0,0,0,0,72,79,77,69,0,0,0,0,76,111,97,100,32,71,97,109,101,32,40,72,105,115,116,111,114,121,41,0,0,0,0,0,117,112,115,0,0,0,0,0,102,56,0,0,0,0,0,0,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,0,114,103,117,105,46,99,103,112,0,0,0,0,0,0,0,0,115,114,97,109,45,109,111,100,101,0,0,0,0,0,0,0,102,55,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,48,82,71,66,49,53,53,53,46,10,0,114,103,117,105,46,103,108,115,108,112,0,0,0,0,0,0,98,115,118,114,101,99,111,114,100,0,0,0,0,0,0,0,102,54,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,46,46,46,10,0,98,115,118,112,108,97,121,0,102,53,0,0,0,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,120,0,0,0,0,0,0,48,48,48,48,52,48,53,52,45,48,49,0,0,0,0,0,71,69,78,80,76,85,83,45,71,88,32,49,46,55,46,49,0,0,0,0,0,0,0,0,82,51,0,0,0,0,0,0,115,117,102,97,109,105,66,0,102,52,0,0,0,0,0,0,105,110,105,116,95,118,105,100,101,111,95,105,110,112,117,116,40,41,0,0,0,0,0,0,48,48,50,0,0,0,0,0,112,97,116,104,47,97,46,111,117,116,0,0,0,0,0,0,76,51,0,0,0,0,0,0,115,117,102,97,109,105,65,0,102,51,0,0,0,0,0,0,73,78,68,69,88,32,48,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,83,82,65,77,46,10,0,0,0,0,0,0,118,49,46,55,46,52,0,0,82,50,0,0,0,0,0,0,109,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,102,50,0,0,0,0,0,0,77,68,88,0,0,0,0,0,3,3,11,0,0,0,0,0,103,108,66,105,110,100,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,84,101,120,67,111,111,114,100,0,0,0,0,0,0,0,0,79,69,83,95,114,103,98,56,95,114,103,98,97,56,0,0,79,86,69,82,76,65,89,32,37,115,0,0,0,0,0,0,73,78,70,79,32,45,32,76,111,97,100,105,110,103,32,37,115,32,46,46,46,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,114,101,112,111,114,116,115,32,97,32,71,76,69,83,50,32,115,116,121,108,101,32,115,104,97,100,101,114,46,10,0,0,76,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,114,101,99,116,32,34,37,115,34,32,105,110,116,111,32,97,116,32,108,101,97,115,116,32,102,111,117,114,32,116,111,107,101,110,115,46,10,0,0,0,115,99,97,108,101,95,121,37,117,0,0,0,0,0,0,0,98,115,120,115,108,111,116,0,102,49,0,0,0,0,0,0,82,0,0,0,0,0,0,0,115,99,97,108,101,95,120,37,117,0,0,0,0,0,0,0,98,115,120,0,0,0,0,0,37,115,37,117,0,0,0,0,107,112,95,109,105,110,117,115,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,115,99,97,108,101,37,117,0,115,97,118,101,115,116,97,116,101,0,0,0,0,0,0,0,107,112,95,112,108,117,115,0,68,111,119,110,32,68,45,112,97,100,0,0,0,0,0,0,83,101,108,101,99,116,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,116,116,114,105,98,117,116,101,46,10,0,0,0,0,0,0,0,0,115,104,97,100,101,114,115,0,100,117,97,108,97,110,97,108,111,103,0,0,0,0,0,0,115,117,98,116,114,97,99,116,0,0,0,0,0,0,0,0,46,99,117,101,0,0,0,0,79,117,116,32,88,32,61,32,37,100,32,61,62,32,73,110,32,88,32,61,32,37,100,10,0,0,0,0,0,0,0,0,83,116,97,114,116,0,0,0,115,99,97,108,101,95,116,121,112,101,95,121,37,117,0,0,106,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,97,100,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,89,83,84,69,77,95,68,73,82,69,67,84,79,82,89,58,32,34,37,115,34,46,10,0,0,0,0,0,105,110,112,117,116,95,100,101,118,105,99,101,95,112,37,117,0,0,0,0,0,0,0,0,89,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,95,120,37,117,0,0,106,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,101,115,99,97,112,101,0,0,105,110,112,117,116,95,100,112,97,100,95,101,109,117,108,97,116,105,111,110,95,112,37,117,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,37,117,0,0,0,0,115,99,111,112,101,0,0,0,115,112,97,99,101,0,0,0,99,117,115,116,111,109,95,98,103,109,95,101,110,97,98,108,101,0,0,0,0,0,0,0,118,105,100,101,111,95,121,115,99,97,108,101,0,0,0,0,66,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,112,97,114,115,101,32,115,104,97,100,101,114,32,115,111,117,114,99,101,32,40,37,115,41,46,10,0,0,0,0,0,0,0,0,110,111,100,101,118,105,99,101,0,0,0,0,0,0,0,0,97,108,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,112,105,120,101,108,32,99,111,110,118,101,114,116,101,114,46,10,0,0,0,115,99,114,101,101,110,95,111,114,105,101,110,116,97,116,105,111,110,0,0,0,0,0,0,109,111,117,115,101,0,0,0,65,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,73,110,118,97,108,105,100,32,119,114,97,112,112,105,110,103,32,116,121,112,101,32,37,115,46,32,86,97,108,105,100,32,111,110,101,115,32,97,114,101,58,32,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,32,40,100,101,102,97,117,108,116,41,44,32,99,108,97,109,112,95,116,111,95,101,100,103,101,44,32,114,101,112,101,97,116,32,97,110,100,32,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,100,101,102,97,117,108,116,46,10,0,0,0,66,108,97,114,103,103,32,78,84,83,67,32,102,105,108,116,101,114,59,32,100,105,115,97,98,108,101,100,124,109,111,110,111,99,104,114,111,109,101,124,99,111,109,112,111,115,105,116,101,124,115,118,105,100,101,111,124,114,103,98,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,32,82,101,119,105,110,100,105,110,103,32,119,105,108,108,32,98,101,32,100,105,115,97,98,108,101,100,46,10,0,0,99,116,114,108,0,0,0,0,73,78,68,69,88,32,48,48,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,0,82,101,116,114,111,65,114,99,104,58,32,66,108,111,99,107,105,110,103,32,83,82,65,77,32,111,118,101,114,119,114,105,116,101,46,10,0,0,0,0,71,101,110,101,115,105,115,32,80,108,117,115,32,71,88,0,82,105,103,104,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,112,97,116,104,32,116,111,32,116,101,120,116,117,114,101,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,97,112,112,101,110,100,99,111,110,102,105,103,0,0,0,0,115,104,105,102,116,0,0,0,83,71,0,0,0,0,0,0,2,3,7,0,0,0,0,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,51,68,79,69,83,0,0,0,0,0,0,0,77,86,80,77,97,116,114,105,120,0,0,0,0,0,0,0,100,111,101,115,110,39,116,32,101,120,105,115,116,0,0,0,115,116,97,116,101,95,115,108,111,116,0,0,0,0,0,0,37,115,46,122,105,112,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,117,110,105,102,111,114,109,32,97,110,100,32,97,116,116,114,105,98,32,112,114,101,102,105,120,58,32,37,115,10,0,0,0,76,101,102,116,0,0,0,0,44,32,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,97,100,100,114,101,115,115,32,97,115,115,105,103,110,101,100,32,116,111,32,115,101,109,97,110,116,105,99,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,32,116,111,32,34,37,115,34,46,32,67,104,101,99,107,32,112,101,114,109,105,115,115,105,111,110,115,46,10,0,0,0,0,63,62,10,0,0,0,0,0,99,111,110,102,105,103,0,0,114,115,104,105,102,116,0,0,115,111,117,110,100,95,109,111,100,101,0,0,0,0,0,0,68,111,119,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,46,10,0,103,97,109,101,98,111,121,0,82,101,116,114,111,65,114,99,104,58,32,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,104,111,109,101,0,0,0,0,99,117,114,114,101,110,116,95,114,101,115,111,108,117,116,105,111,110,95,105,100,0,0,0,85,112,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,46,10,0,0,118,101,114,98,111,115,101,0,101,110,100,0,0,0,0,0,37,48,50,100,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,91,82,80,78,71,93,58,32,69,114,114,111,114,32,105,110,32,108,105,110,101,32,37,100,46,10,0,0,0,0,0,0,68,80,97,100,32,69,109,117,108,97,116,105,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,101,120,116,101,114,110,97,108,32,115,111,117,114,99,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,100,101,108,0,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,79,69,83,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,103,108,115,108,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,37,115,10,0,0,82,101,116,114,111,65,114,99])
.concat([104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,105,110,105,116,32,102,111,110,116,32,114,101,110,100,101,114,101,114,46,10,0,0,0,0,0,0,0,68,101,118,105,99,101,32,84,121,112,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,115,97,118,101,0,0,0,0,105,110,115,101,114,116,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,80,69,82,70,79,82,77,65,78,67,69,95,76,69,86,69,76,58,32,37,117,46,10,0,0,0,0,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,70,66,79,32,116,97,114,103,101,116,115,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,70,66,79,46,10,0,0,119,0,0,0,0,0,0,0,68,101,118,105,99,101,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,104,101,108,112,0,0,0,0,116,97,98,0,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,0,0,0,80,108,97,121,101,114,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,109,101,110,117,0,0,0,0,107,112,95,101,110,116,101,114,0,0,0,0,0,0,0,0,105,110,102,111,95,109,115,103,95,101,110,97,98,108,101,0,118,105,100,101,111,95,120,115,99,97,108,101,0,0,0,0,99,103,112,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,118,101,114,108,97,121,32,105,110,116,101,114,102,97,99,101,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,118,105,100,101,111,32,100,114,105,118,101,114,46,10,0,82,101,116,114,111,65,114,99,104,58,32,83,105,110,99,32,114,101,115,97,109,112,108,101,114,32,91,67,93,10,0,0,46,112,110,103,0,0,0,0,79,118,101,114,108,97,121,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,121,32,97,116,116,114,58,32,37,117,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,114,119,101,98,97,117,100,105,111,0,0,0,0,0,0,0,83,101,112,32,49,51,32,50,48,49,51,0,0,0,0,0,101,110,116,101,114,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,102,117,108,108,115,99,114,101,101,110,10,0,0,116,114,105,112,108,101,95,98,117,102,102,101,114,105,110,103,95,101,110,97,98,108,101,0,83,67,68,33,0,0,0,0,101,120,101,0,0,0,0,0,79,118,101,114,108,97,121,32,79,112,97,99,105,116,121,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,120,32,97,116,116,114,58,32,37,117,10,0,66,117,105,108,116,58,32,37,115,10,0,0,0,0,0,0,82,71,85,73,32,109,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,0,0,0,80,82,69,71,65,80,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,34,115,104,97,100,101,114,115,34,32,112,97,114,97,109,46,10,0,0,0,0,0,0,79,117,116,32,89,32,61,32,37,100,32,61,62,32,73,110,32,89,32,61,32,37,100,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,103,97,109,109,97,95,99,111,114,114,101,99,116,105,111,110,0,0,0,0,0,0,0,0,73,78,70,79,82,77,65,84,73,79,78,32,45,32,37,115,10,0,0,0,0,0,0,0,79,118,101,114,108,97,121,32,80,114,101,115,101,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,32,97,116,116,114,58,32,37,117,10,0,0,0,52,46,50,46,49,32,67,111,109,112,97,116,105,98,108,101,32,67,108,97,110,103,32,51,46,50,32,40,116,97,103,115,47,82,69,76,69,65,83,69,95,51,50,47,102,105,110,97,108,41,0,0,0,0,0,0,71,71,0,0,0,0,0,0,5,5,4,0,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,101,120,105,115,116,115,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,77,69,78,85,32,37,115,0,37,117,120,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,99,111,110,102,105,103,32,102,105,108,101,58,32,37,115,46,10,0,0,0,112,114,101,102,105,120,0,0,83,121,115,116,101,109,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,114,101,99,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,37,117,59,0,0,0,0,0,60,63,120,109,108,0,0,0,100,97,116,97,98,97,115,101,0,0,0,0,0,0,0,0,67,108,97,110,103,47,76,76,86,77,32,40,37,115,41,32,37,117,45,98,105,116,10,0,71,114,97,98,32,109,111,117,115,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,99,111,109,112,97,116,47,99,111,109,112,97,116,46,99,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,99,111,110,102,105,103,46,32,65,115,115,117,109,105,110,103,32,115,121,115,116,101,109,32,100,105,114,101,99,116,111,114,121,32,105,115,32,115,97,109,101,32,102,111,108,100,101,114,32,97,115,32,103,97,109,101,58,32,34,37,115,34,46,10,0,0,0,0,0,79,118,101,114,108,97,121,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,10,67,111,109,112,105,108,101,114,58,32,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,73,110,105,116,105,110,103,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,119,105,116,104,32,115,105,122,101,58,32,37,117,32,77,66,10,0,0,0,0,0,0,98,109,112,0,0,0,0,0,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,83,97,118,101,102,105,108,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,97,32,100,105,102,102,101,114,101,110,116,32,118,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,116,104,97,110,32,116,104,105,115,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,68,105,115,107,32,110,101,120,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,85,115,105,110,103,32,82,88,77,76,32,97,115,32,100,114,111,112,32,105,110,32,102,111,114,32,108,105,98,120,109,108,50,46,32,66,101,104,97,118,105,111,114,32,109,105,103,104,116,32,98,101,32,118,101,114,121,32,98,117,103,103,121,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,85,112,32,68,45,112,97,100,0,0,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,102,114,97,109,101,32,99,111,117,110,116,32,109,111,100,32,97,116,116,114,58,32,37,117,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,65,80,73,58,32,37,117,10,0,0,0,0,46,115,116,97,116,101,0,0,83,104,97,100,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,65,80,73,58,32,37,117,10,0,68,105,115,107,32,101,106,101,99,116,32,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,72,85,84,68,79,87,78,46,10,0,0,0,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,66,114,111,119,115,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,108,97,115,116,32,115,116,97,116,101,32,115,108,111,116,58,32,35,37,117,10,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,0,68,101,98,117,103,32,73,110,102,111,32,77,101,115,115,97,103,101,115,0,0,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,0,59,32,0,0,0,0,0,0,65,117,116,111,45,108,111,97,100,105,110,103,32,115,97,118,101,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,32,37,115,46,0,0,0,0,79,118,101,114,108,97,121,32,110,101,120,116,0,0,0,0,114,119,101,98,105,110,112,117,116,0,0,0,0,0,0,0,46,115,114,109,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,101,110,100,32,61,61,61,10,0,0,0,0,0,37,120,0,0,0,0,0,0,67,111,110,102,105,103,32,83,97,118,101,32,79,110,32,69,120,105,116,0,0,0,0,0,111,117,116,115,99,97,108,101,95,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,97,117,116,111,32,115,97,118,101,115,116,97,116,101,32,105,110,58,32,37,115,10,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,37,117,120,37,117,10,0,0,0,0,0,0,0,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,84,45,53,55,52,48,0,0,46,37,115,0,0,0,0,0,82,101,119,105,110,100,32,71,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,111,117,116,115,99,97,108,101,95,120,0,0,0,0,0,0,86,111,108,117,109,101,32,45,0,0,0,0,0,0,0,0,84,82,65,67,75,32,37,100,32,65,85,68,73,79,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,0,99,111,110,102,105,103,95,115,97,118,101,95,111,110,95,101,120,105,116,0,0,0,0,0,76,111,97,100,105,110,103,32,37,100,32,98,121,116,101,115,32,46,46,46,0,0,0,0,82,101,119,105,110,100,0,0,111,117,116,115,99,97,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,10,0,0,0,0,83,77,83,0,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,81,117,101,114,121,105,110,103,32,71,76,32,101,120,116,101,110,115,105,111,110,58,32,37,115,32,61,62,32,37,115,10,0,0,0,0,0,106,111,121,112,97,100,95,97,117,116,111,99,111,110,102,105,103,95,100,105,114,0,0,0,83,72,65,68,69,82,32,37,115,0,0,0,0,0,0,0,71,76,69,83,50,0,0,0,78,111,32,111,112,116,105,111,110,115,32,97,118,97,105,108,97,98,108,101,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,115,105,122,101,95,121,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,115,97,118,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,46,10,0,0,0,45,45,62,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,43,0,0,0,0,0,0,0,0,105,110,112,117,116,95,97,117,116,111,100,101,116,101,99,116,95,101,110,97,98,108,101,0,82,97,116,101,32,67,111,110,116,114,111,108,32,68,101,108,116,97,0,0,0,0,0,0,115,105,122,101,95,120,0,0,105,110,105,116,95,109,111,118,105,101,40,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,101,114,102,111,114,109,32,105,110,105,116,105,97,108,32,115,101,114,105,97,108,105,122,97,116,105,111,110,32,102,111,114,32,114,101,119,105,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,32,71,80,85,32,114,101,110,100,101,114,105,110,103,32,105,115,32,117,115,101,100,32,97,110,100,32,114,101,97,100,95,118,105,101,119,112,111,114,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,170,25,0,0,52,10,0,0,54,10,0,0,194,25,0,0,42,10,0,0,44,10,0,0,50,36,0,0,84,36,0,0,64,10,0,0,204,0,0,0,120,10,0,0,122,10,0,0,124,10,0,0,114,10,0,0,116,10,0,0,118,10,0,0,252,33,0,0,202,12,0,0,146,5,0,0,198,12,0,0,196,12,0,0,194,12,0,0,40,33,0,0,118,2,0,0,208,12,0,0,206,12,0,0,220,22,0,0,168,22,0,0,136,2,0,0,112,12,0,0,110,12,0,0,108,12,0,0,84,15,0,0,114,29,0,0,80,15,0,0,114,19,0,0,212,29,0,0,94,15,0,0,142,19,0,0,176,29,0,0,72,15,0,0,74,19,0,0,186,21,0,0,164,21,0,0,168,15,0,0,178,15,0,0,228,21,0,0,174,15,0,0,220,17,0,0,218,17,0,0,224,17,0,0,222,17,0,0,244,14,0,0,210,17,0,0,84,35,0,0,214,17,0,0,204,17,0,0,176,25,0,0,20,34,0,0,152,17,0,0,36,34,0,0,2,34,0,0,250,33,0,0,144,17,0,0,24,0,0,0,166,0,0,0,28,0,0,0,30,0,0,0,32,0,0,0,34,0,0,0,36,0,0,0,38,0,0,0,104,0,0,0,110,0,0,0,38,20,0,0,78,0,0,0,80,0,0,0,82,0,0,0,84,0,0,0,86,0,0,0,250,15,0,0,204,2,0,0,202,2,0,0,232,15,0,0,214,2,0,0,12,16,0,0,4,16,0,0,208,2,0,0,194,2,0,0,198,15,0,0,204,34,0,0,114,2,0,0,152,34,0,0,124,2,0,0,74,35,0,0,196,13,0,0,70,5,0,0,222,31,0,0,210,31,0,0,216,31,0,0,202,31,0,0,206,31,0,0,194,31,0,0,62,5,0,0,178,31,0,0,58,5,0,0,34,33,0,0,104,5,0,0,106,5,0,0,244,32,0,0,102,5,0,0,96,5,0,0,144,7,0,0,248,9,0,0,62,26,0,0,146,7,0,0,24,10,0,0,18,10,0,0,156,7,0,0,154,7,0,0,160,7,0,0,158,7,0,0,54,7,0,0,58,7,0,0,56,7,0,0,62,7,0,0,60,7,0,0,66,7,0,0,162,31,0,0,136,5,0,0,166,31,0,0,168,31,0,0,112,5,0,0,156,31,0,0,158,31,0,0,160,31,0,0,148,31,0,0,150,31,0,0,72,7,0,0,150,3,0,0,86,17,0,0,56,31,0,0,58,31,0,0,174,16,0,0,56,34,0,0,54,34,0,0,52,34,0,0,50,34,0,0,48,34,0,0,46,34,0,0,44,34,0,0,42,34,0,0,40,34,0,0,38,34,0,0,122,34,0,0,152,31,0,0,118,34,0,0,116,34,0,0,114,34,0,0,112,34,0,0,130,35,0,0,128,35,0,0,126,35,0,0,124,35,0,0,122,35,0,0,120,35,0,0,118,35,0,0,116,35,0,0,138,35,0,0,136,35,0,0,70,35,0,0,68,35,0,0,66,35,0,0,64,35,0,0,62,35,0,0,60,35,0,0,82,1,0,0,84,1,0,0,76,7,0,0,80,1,0,0,90,1,0,0,92,1,0,0,86,1,0,0,164,18,0,0,66,1,0,0,68,1,0,0,158,1,0,0,152,8,0,0,156,1,0,0,164,1,0,0,166,1,0,0,160,1,0,0,124,34,0,0,228,3,0,0,232,3,0,0,230,3,0,0,222,3,0,0,220,3,0,0,226,3,0,0,224,3,0,0,216,3,0,0,214,3,0,0,142,3,0,0,146,3,0,0,210,24,0,0,138,3,0,0,246,23,0,0,140,3,0,0,80,22,0,0,82,22,0,0,84,22,0,0,86,22,0,0,88,22,0,0,40,25,0,0,48,25,0,0,74,36,0,0,70,22,0,0,150,30,0,0,20,16,0,0,180,22,0,0,74,27,0,0,184,22,0,0,186,22,0,0,92,27,0,0,254,24,0,0,252,24,0,0,250,24,0,0,198,16,0,0,6,25,0,0,4,25,0,0,2,25,0,0,0,25,0,0,246,24,0,0,244,24,0,0,198,24,0,0,196,24,0,0,194,24,0,0,206,24,0,0,204,24,0,0,202,24,0,0,168,27,0,0,170,27,0,0,164,27,0,0,166,27,0,0,160,27,0,0,162,27,0,0,156,27,0,0,158,27,0,0,152,27,0,0,154,27,0,0,16,28,0,0,12,28,0,0,14,28,0,0,176,34,0,0,10,28,0,0,4,28,0,0,2,33,0,0,4,33,0,0,254,32,0,0,0,33,0,0,250,32,0,0,10,14,0,0,246,32,0,0,248,32,0,0,10,33,0,0,12,33,0,0,204,32,0,0,200,32,0,0,202,32,0,0,196,32,0,0,198,32,0,0,210,12,0,0,162,35,0,0,160,35,0,0,166,35,0,0,164,35,0,0,154,35,0,0,152,35,0,0,254,26,0,0,156,35,0,0,14,35,0,0,172,35,0,0,20,36,0,0,26,36,0,0,24,36,0,0,14,36,0,0,12,36,0,0,18,36,0,0,138,1,0,0,140,1,0,0,142,1,0,0,250,30,0,0,146,1,0,0,128,8,0,0,138,8,0,0,152,1,0,0,170,31,0,0,162,8,0,0,34,7,0,0,20,24,0,0,42,7,0,0,78,22,0,0,128,24,0,0,74,1,0,0,158,29,0,0,126,29,0,0,38,4,0,0,78,29,0,0,34,4,0,0,32,4,0,0,30,4,0,0,206,28,0,0,28,4,0,0,16,24,0,0,130,4,0,0,128,4,0,0,144,26,0,0,124,4,0,0,122,4,0,0,120,4,0,0,132,6,0,0,62,3,0,0,128,6,0,0,130,6,0,0,140,6,0,0,142,6,0,0,136,6,0,0,168,26,0,0,140,34,0,0,28,35,0,0,60,6,0,0,56,6,0,0,58,6,0,0,66,6,0,0,68,6,0,0,24,2,0,0,4,9,0,0,2,9,0,0,8,9,0,0,86,18,0,0,12,9,0,0,162,23,0,0,16,9,0,0,14,9,0,0,244,8,0,0,242,8,0,0,110,9,0,0,128,34,0,0,112,9,0,0,182,34,0,0,116,9,0,0,184,20,0,0,18,12,0,0,30,35,0,0,22,12,0,0,24,12,0,0,10,12,0,0,12,12,0,0,14,12,0,0,16,12,0,0,30,12,0,0,32,12,0,0,86,12,0,0,88,12,0,0,90,12,0,0,80,12,0,0,82,12,0,0,84,12,0,0,126,14,0,0,122,15,0,0,122,14,0,0,112,15,0,0,160,15,0,0,132,14,0,0,78,32,0,0,128,14,0,0,140,14,0,0,138,14,0,0,22,14,0,0,204,20,0,0,162,20,0,0,164,30,0,0,28,14,0,0,26,14,0,0,42,17,0,0,244,30,0,0,38,17,0,0,40,17,0,0,126,31,0,0,60,30,0,0,30,17,0,0,32,17,0,0,96,31,0,0,28,17,0,0,208,32,0,0,186,32,0,0,102,17,0,0,96,17,0,0,98,17,0,0,166,32,0,0,164,32,0,0,206,19,0,0,212,19,0,0,210,19,0,0,202,19,0,0,200,19,0,0,224,33,0,0,204,19,0,0,198,19,0,0,146,26,0,0,102,19,0,0,106,19,0,0,104,19,0,0,96,19,0,0,94,19,0,0,100,19,0,0,80,35,0,0,194,11,0,0,200,11,0,0,198,11,0,0,188,11,0,0,186,11,0,0,192,11,0,0,190,11,0,0,36,33,0,0,206,11,0,0,40,6,0,0,104,11,0,0,66,34,0,0,96,11,0,0,94,11,0,0,98,11,0,0,36,14,0,0,38,14,0,0,40,14,0,0,42,14,0,0,44,14,0,0,46,14,0,0,48,14,0,0,50,14,0,0,52,14,0,0,54,14,0,0,72,23,0,0,100,14,0,0,102,14,0,0,104,14,0,0,106,14,0,0,108,14,0,0,178,29,0,0,230,16,0,0,228,16,0,0,226,16,0,0,156,29,0,0,222,16,0,0,220,16,0,0,218,16,0,0,132,29,0,0,124,29,0,0,150,16,0,0,148,16,0,0,146,16,0,0,144,16,0,0,142,16,0,0,94,27,0,0,120,19,0,0,122,19,0,0,116,19,0,0,118,19,0,0,128,19,0,0,84,8,0,0,124,19,0,0,126,19,0,0,64,8,0,0,110,19,0,0,184,19,0,0,178,19,0,0,180,19,0,0,190,19,0,0,192,19,0,0,186,19,0,0,32,22,0,0,30,22,0,0,36,22,0,0,200,23,0,0,40,22,0,0,216,23,0,0,232,23,0,0,226,23,0,0,102,31,0,0,14,22,0,0,196,21,0,0,202,21,0,0,200,21,0,0,206,21,0,0,204,21,0,0,132,33,0,0,168,24,0,0,170,24,0,0,172,24,0,0,174,24,0,0,160,24,0,0,162,24,0,0,164,24,0,0,166,24,0,0,180,24,0,0,98,2,0,0,84,4,0,0,16,25,0,0,18,25,0,0,8,25,0,0,10,25,0,0,12,25,0,0,138,32,0,0,226,21,0,0,198,3,0,0,196,3,0,0,194,21,0,0,184,3,0,0,190,3,0,0,44,27,0,0,204,3,0,0,202,3,0,0,56,23,0,0,244,3,0,0,74,23,0,0,0,22,0,0,234,3,0,0,238,3,0,0,28,1,0,0,30,1,0,0,44,35,0,0,26,1,0,0,20,1,0,0,94,6,0,0,16,1,0,0,18,1,0,0,38,1,0,0,198,36,0,0,190,0,0,0,184,0,0,0,186,0,0,0,180,0,0,0,182,0,0,0,176,0,0,0,178,8,0,0,82,16,0,0,174,8,0,0,70,16,0,0,170,8,0,0,48,16,0,0,166,8,0,0,40,16,0,0,34,16,0,0,160,8,0,0,224,8,0,0,134,17,0,0,220,8,0,0,218,8,0,0,216,8,0,0,214,8,0,0,8,6,0,0,54,29,0,0,198,0,0,0,14,6,0,0,130,29,0,0,162,29,0,0,18,6,0,0,20,6,0,0,8,30,0,0,24,6,0,0,184,5,0,0,186,5,0,0,102,35,0,0,34,2,0,0,192,5,0,0,194,5,0,0,164,13,0,0,162,13,0,0,168,13,0,0,166,13,0,0,172,13,0,0,170,13,0,0,176,13,0,0,174,13,0,0,228,6,0,0,154,13,0,0,52,28,0,0,232,13,0,0,230,13,0,0,236,28,0,0,234,13,0,0,50,29,0,0,56,11,0,0,20,32,0,0,52,11,0,0,6,32,0,0,64,11,0,0,66,11,0,0,28,32,0,0,62,11,0,0,88,35,0,0,42,11,0,0,234,2,0,0,170,29,0,0,222,10,0,0,228,10,0,0,218,29,0,0,194,29,0,0,206,18,0,0,204,18,0,0,116,16,0,0,200,18,0,0,214,18,0,0,212,18,0,0,210,18,0,0,208,18,0,0,220,18,0,0,218,18,0,0,42,19,0,0,40,19,0,0,70,6,0,0,48,19,0,0,86,24,0,0,110,6,0,0,62,16,0,0,64,16,0,0,66,16,0,0,68,16,0,0,54,16,0,0,104,25,0,0,58,16,0,0,60,16,0,0,74,16,0,0,76,16,0,0,50,24,0,0,14,16,0,0,16,16,0,0,6,16,0,0,8,16,0,0,100,9,0,0,26,24,0,0,24,24,0,0,30,24,0,0,28,24,0,0,18,24,0,0,142,35,0,0,22,24,0,0,234,12,0,0,114,35,0,0,110,35,0,0,114,24,0,0,120,24,0,0,118,24,0,0,110,24,0,0,108,24,0,0,82,19,0,0,128,21,0,0,130,21,0,0,124,21,0,0,126,21,0,0,120,21,0,0,122,21,0,0,116,21,0,0,118,21,0,0,136,15,0,0,114,21,0,0,84,21,0,0,80,21,0,0,226,34,0,0,76,21,0,0,130,18,0,0,72,21,0,0,204,22,0,0,206,22,0,0,200,22,0,0,202,22,0,0,124,27,0,0,198,22,0,0,192,22,0,0,12,26,0,0,214,22,0,0,216,22,0,0,198,29,0,0,50,23,0,0,52,23,0,0,46,23,0,0,48,23,0,0,42,23,0,0,212,30,0,0,210,30,0,0,208,30,0,0,206,30,0,0,204,30,0,0,202,30,0,0,200,30,0,0,198,30,0,0,196,0,0,0,40,18,0,0,144,30,0,0,38,21,0,0,122,36,0,0,138,30,0,0,136,30,0,0,134,30,0,0,52,20,0,0,20,28,0,0,22,28,0,0,24,28,0,0,172,21,0,0,28,28,0,0,190,21,0,0,32,28,0,0,206,3,0,0,36,28,0,0,112,28,0,0,114,28,0,0,180,31,0,0,118,28,0,0,120,28,0,0,122,28,0,0,220,31,0,0,252,35,0,0,56,13,0,0,224,31,0,0,250,31,0,0,230,1,0,0,10,36,0,0,2,32,0,0,244,35,0,0,242,35,0,0,120,30,0,0,78,3,0,0,198,6,0,0,96,34,0,0,158,30,0,0,204,35,0,0,94,33,0,0,96,33,0,0,90,33,0,0,92,33,0,0,102,33,0,0,104,33,0,0,98,33,0,0,100,33,0,0,210,14,0,0,82,33,0,0,200,33,0,0,42,18,0,0,196,33,0,0,206,33,0,0,82,18,0,0,30,27,0,0,242,28,0,0,206,4,0,0,204,4,0,0,202,4,0,0,214,4,0,0,212,4,0,0,210,4,0,0,208,4,0,0,38,29,0,0,218,4,0,0,10,5,0,0,12,30,0,0,8,5,0,0,18,5,0,0,218,28,0,0,14,5,0,0,120,6,0,0,20,3,0,0,192,6,0,0,36,3,0,0,112,6,0,0,114,6,0,0,116,6,0,0,118,6,0,0,192,14,0,0,232,14,0,0,50,6,0,0,128,7,0,0,54,6,0,0,204,6,0,0,44,6,0,0,206,1,0,0,30,32,0,0,246,8,0,0,28,18,0,0,232,29,0,0,0,9,0,0,254,8,0,0,34,27,0,0,250,8,0,0,98,18,0,0,6,9,0,0,108,21,0,0,96,9,0,0,94,9,0,0,122,20,0,0,106,9,0,0,104,9,0,0,182,1,0,0,184,1,0,0,20,9,0,0,180,1,0,0,190,1,0,0,192,1,0,0,186,1,0,0,188,1,0,0,62,21,0,0,242,12,0,0,52,1,0,0,48,1,0,0,50,1,0,0,58,1,0,0,150,25,0,0,6,7,0,0,54,4,0,0,142,24,0,0,58,4,0,0,56,4,0,0,184,24,0,0,60,4,0,0,66,4,0,0,64,4,0,0,44,4,0,0,42,4,0,0,92,4,0,0,70,26,0,0,94,4,0,0,144,35,0,0,98,4,0,0,104,4,0,0,14,33,0,0,16,33,0,0,18,33,0,0,20,33,0,0,22,33,0,0,24,33,0,0,50,8,0,0,142,27,0,0,30,33,0,0,32,33,0,0,120,12,0,0,176,32,0,0,178,32,0,0,180,32,0,0,22,13,0,0,184,32,0,0,178,30,0,0,202,35,0,0,200,35,0,0,198,35,0,0,152,30,0,0,194,35,0,0,192,35,0,0,190,35,0,0,188,35,0,0,186,35,0,0,8,36,0,0,6,36,0,0,4,36,0,0,2,36,0,0,0,36,0,0,254,35,0,0,226,27,0,0,228,27,0,0,222,27,0,0,224,27,0,0,218,27,0,0,220,27,0,0,214,27,0,0,216,27,0,0,74,34,0,0,238,27,0,0,118,27,0,0,112,27,0,0,114,27,0,0,108,27,0,0,110,27,0,0,106,27,0,0,128,30,0,0,66,36,0,0,132,30,0,0,130,30,0,0,44,36,0,0,118,30,0,0,124,30,0,0,122,30,0,0,130,36,0,0,140,30,0,0,190,30,0,0,196,30,0,0,194,30,0,0,184,30,0,0,182,30,0,0,24,22,0,0,194,27,0,0,196,27,0,0,198,27,0,0,200,27,0,0,186,27,0,0,188,27,0,0,190,27,0,0,192,27,0,0,178,27,0,0,180,27,0,0,252,27,0,0,254,27,0,0,0,28,0,0,246,27,0,0,248,27,0,0,250,27,0,0,88,30,0,0,112,35,0,0,84,30,0,0,82,30,0,0,96,30,0,0,94,30,0,0,92,30,0,0,90,30,0,0,76,30,0,0,74,30,0,0,234,29,0,0,154,30,0,0,230,29,0,0,218,1,0,0,82,31,0,0,238,29,0,0,80,16,0,0,216,7,0,0,184,7,0,0,128,28,0,0,82,34,0,0,92,8,0,0,96,16,0,0,234,28,0,0,124,33,0,0,122,33,0,0,158,33,0,0,130,17,0,0,154,33,0,0,246,35,0,0,162,17,0,0,164,33,0,0,152,25,0,0,154,25,0,0,148,25,0,0,98,7,0,0,160,25,0,0,162,25,0,0,156,25,0,0,158,25,0,0,10,7,0,0,142,25,0,0,88,25,0,0,82,25,0,0,84,25,0,0,92,25,0,0,94,25,0,0,90,25,0,0,70,28,0,0,68,28,0,0,74,28,0,0,72,28,0,0,78,28,0,0,76,28,0,0,82,28,0,0,80,28,0,0,62,28,0,0,60,28,0,0,172,28,0,0,178,28,0,0,176,28,0,0,182,28,0,0,180,28,0,0,184,28,0,0,4,27,0,0,76,36,0,0,74,20,0,0,76,20,0,0,78,20,0,0,80,20,0,0,82,20,0,0,84,20,0,0,86,20,0,0,88,20,0,0,64,17,0,0,24,20,0,0,26,20,0,0,28,20,0,0,30,20,0,0,46,29,0,0,216,28,0,0,6,23,0,0,4,23,0,0,2,23,0,0,0,23,0,0,254,22,0,0,252,22,0,0,160,28,0,0,248,22,0,0,140,28,0,0,112,23,0,0,110,23,0,0,146,33,0,0,106,23,0,0,104,23,0,0,28,33,0,0,132,18,0,0,30,15,0,0,24,15,0,0,26,15,0,0,104,18,0,0,22,15,0,0,110,29,0,0,18,15,0,0,42,15,0,0,44,15,0,0,228,14,0,0,224,14,0,0,154,23,0,0,220,14,0,0,222,14,0,0,216,14,0,0,182,24,0,0,116,3,0,0,62,31,0,0,60,31,0,0,66,31,0,0,64,31,0,0,70,31,0,0,68,31,0,0,44,31,0,0,42,31,0,0,154,31,0,0,126,5,0,0,220,35,0,0,164,31,0,0,48,36,0,0,148,5,0,0,148,28,0,0,138,27,0,0,144,28,0,0,106,24,0,0,156,28,0,0,158,28,0,0,152,28,0,0,44,28,0,0,134,28,0,0,136,28,0,0,96,28,0,0,90,28,0,0,92,28,0,0,100,28,0,0,102,28,0,0,98,28,0,0,92,36,0,0,242,15,0,0,90,36,0,0,88,36,0,0,100,36,0,0,98,36,0,0,234,33,0,0,94,36,0,0,16,34,0,0,104,36,0,0,156,36,0,0,154,36,0,0,152,36,0,0,164,36,0,0,162,36,0,0,42,35,0,0,186,33,0,0,20,18,0,0,190,33,0,0,192,33,0,0,178,33,0,0,180,33,0,0,182,33,0,0,184,33,0,0,202,33,0,0,204,33,0,0,84,33,0,0,86,33,0,0,2,16,0,0,76,33,0,0,78,33,0,0,80,33,0,0,94,14,0,0,152,20,0,0,40,36,0,0,156,20,0,0,146,20,0,0,144,20,0,0,150,20,0,0,148,20,0,0,178,36,0,0,164,20,0,0,250,20,0,0,254,20,0,0,252,20,0,0,246,20,0,0,84,29,0,0,196,34,0,0,250,17,0,0,52,36,0,0,28,36,0,0,38,36,0,0,242,17,0,0,244,17,0,0,238,17,0,0,240,17,0,0,96,36,0,0,8,18,0,0,212,34,0,0,178,17,0,0,180,17,0,0,174,17,0,0,188,34,0,0,172,17,0,0,246,25,0,0,244,25,0,0,8,31,0,0,240,25,0,0,238,25,0,0,156,30,0,0,234,25,0,0,232,25,0,0,230,25,0,0,228,25,0,0,94,26,0,0,92,26,0,0,90,26,0,0,88,26,0,0,86,26,0,0,84,26,0,0,64,23,0,0,54,32,0,0,20,30,0,0,116,32,0,0,152,32,0,0,174,32,0,0,76,23,0,0,64,30,0,0,80,23,0,0,80,30,0,0,144,25,0,0,232,28,0,0,16,23,0,0,18,23,0,0,20,23,0,0,22,23,0,0,150,14,0,0,222,33,0,0,154,14,0,0,152,14,0,0,158,14,0,0,156,14,0,0,162,14,0,0,254,15,0,0,4,35,0,0,164,14,0,0,254,14,0,0,2,15,0,0,0,15,0,0,6,15,0,0,4,15,0,0,8,15,0,0,40,12,0,0,138,34,0,0,36,12,0,0,38,12,0,0,48,12,0,0,50,12,0,0,44,12,0,0,46,12,0,0,54,12,0,0,56,12,0,0,58,36,0,0,236,11,0,0,238,11,0,0,244,11,0,0,246,11,0,0,242,11,0,0,128,26,0,0,212,32,0,0,118,4,0,0,122,26,0,0,162,26,0,0,132,4,0,0,252,30,0,0,152,26,0,0,108,4,0,0,110,4,0,0,128,10,0,0,14,29,0,0,40,24,0,0,76,24,0,0,40,4,0,0,154,5,0,0,220,11,0,0,188,18,0,0,216,11,0,0,214,11,0,0,218,35,0,0,226,11,0,0,38,19,0,0,222,11,0,0,232,11,0,0,238,35,0,0,68,12,0,0,66,12,0,0,64,12,0,0,74,12,0,0,44,1,0,0,26,30,0,0,76,9,0,0,78,9,0,0,80,9,0,0,82,9,0,0,68,9,0,0,70,9,0,0,72,9,0,0,74,9,0,0,50,20,0,0,92,9,0,0,28,9,0,0,30,9,0,0,32,9,0,0,18,9,0,0,136,18,0,0,22,9,0,0,116,33,0,0,114,33,0,0,120,33,0,0,118,33,0,0,108,33,0,0,106,33,0,0,112,33,0,0,110,33,0,0,128,33,0,0,126,33,0,0,246,4,0,0,168,33,0,0,166,33,0,0,156,33,0,0,124,17,0,0,160,33,0,0,12,20,0,0,228,30,0,0,222,30,0,0,70,19,0,0,218,30,0,0,220,30,0,0,214,30,0,0,6,1,0,0,240,30,0,0,242,30,0,0,162,30,0,0,106,30,0,0,108,30,0,0,102,30,0,0,10,19,0,0,98,30,0,0,14,2,0,0,12,2,0,0,10,2,0,0,198,33,0,0,6,2,0,0,4,2,0,0,196,10,0,0,0,2,0,0,254,1,0,0,252,1,0,0,70,12,0,0,62,12,0,0,52,12,0,0,42,12,0,0,50,2,0,0,204,25,0,0,152,47,138,66,145,68,55,113,207,251,192,181,165,219,181,233,91,194,86,57,241,17,241,89,164,130,63,146,213,94,28,171,152,170,7,216,1,91,131,18,190,133,49,36,195,125,12,85,116,93,190,114,254,177,222,128,167,6,220,155,116,241,155,193,193,105,155,228,134,71,190,239,198,157,193,15,204,161,12,36,111,44,233,45,170,132,116,74,220,169,176,92,218,136,249,118,82,81,62,152,109,198,49,168,200,39,3,176,199,127,89,191,243,11,224,198,71,145,167,213,81,99,202,6,103,41,41,20,133,10,183,39,56,33,27,46,252,109,44,77,19,13,56,83,84,115,10,101,187,10,106,118,46,201,194,129,133,44,114,146,161,232,191,162,75,102,26,168,112,139,75,194,163,81,108,199,25,232,146,209,36,6,153,214,133,53,14,244,112,160,106,16,22,193,164,25,8,108,55,30,76,119,72,39,181,188,176,52,179,12,28,57,74,170,216,78,79,202,156,91,243,111,46,104,238,130,143,116,111,99,165,120,20,120,200,132,8,2,199,140,250,255,190,144,235,108,80,164,247,163,249,190,242,120,113,198,103,230,9,106,133,174,103,187,114,243,110,60,58,245,79,165,127,82,14,81,140,104,5,155,171,217,131,31,25,205,224,91,236,5,181,4,189,3,248,2,91,2,223,1,125,1,47,1,240,0,191,0,152,0,120,0,96,0,76,0,60,0,0,0])
, "i8", ALLOC_NONE, Runtime.GLOBAL_BASE)
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
  function _emscripten_set_canvas_size(width, height) {
      Browser.setCanvasSize(width, height);
    }
  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
      Module['noExitRuntime'] = true;
      Browser.mainLoop.runner = function() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        if (Module['preMainLoop']) {
          Module['preMainLoop']();
        }
        Runtime.dynCall('v', func);
        if (Module['postMainLoop']) {
          Module['postMainLoop']();
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        }
      } else {
        Browser.mainLoop.scheduler = function() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        }
      }
      Browser.mainLoop.scheduler();
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:35,EIDRM:36,ECHRNG:37,EL2NSYNC:38,EL3HLT:39,EL3RST:40,ELNRNG:41,EUNATCH:42,ENOCSI:43,EL2HLT:44,EDEADLK:45,ENOLCK:46,EBADE:50,EBADR:51,EXFULL:52,ENOANO:53,EBADRQC:54,EBADSLT:55,EDEADLOCK:56,EBFONT:57,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:74,EDOTDOT:76,EBADMSG:77,ENOTUNIQ:80,EBADFD:81,EREMCHG:82,ELIBACC:83,ELIBBAD:84,ELIBSCN:85,ELIBMAX:86,ELIBEXEC:87,ENOSYS:88,ENOTEMPTY:90,ENAMETOOLONG:91,ELOOP:92,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:106,EPROTOTYPE:107,ENOTSOCK:108,ENOPROTOOPT:109,ESHUTDOWN:110,ECONNREFUSED:111,EADDRINUSE:112,ECONNABORTED:113,ENETUNREACH:114,ENETDOWN:115,ETIMEDOUT:116,EHOSTDOWN:117,EHOSTUNREACH:118,EINPROGRESS:119,EALREADY:120,EDESTADDRREQ:121,EMSGSIZE:122,EPROTONOSUPPORT:123,ESOCKTNOSUPPORT:124,EADDRNOTAVAIL:125,ENETRESET:126,EISCONN:127,ENOTCONN:128,ETOOMANYREFS:129,EUSERS:131,EDQUOT:132,ESTALE:133,ENOTSUP:134,ENOMEDIUM:135,EILSEQ:138,EOVERFLOW:139,ECANCELED:140,ENOTRECOVERABLE:141,EOWNERDEAD:142,ESTRPIPE:143};
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"No message of desired type",36:"Identifier removed",37:"Channel number out of range",38:"Level 2 not synchronized",39:"Level 3 halted",40:"Level 3 reset",41:"Link number out of range",42:"Protocol driver not attached",43:"No CSI structure available",44:"Level 2 halted",45:"Deadlock condition",46:"No record locks available",50:"Invalid exchange",51:"Invalid request descriptor",52:"Exchange full",53:"No anode",54:"Invalid request code",55:"Invalid slot",56:"File locking deadlock error",57:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",74:"Multihop attempted",76:"Cross mount point (not really error)",77:"Trying to read unreadable message",80:"Given log. name not unique",81:"f.d. invalid for this operation",82:"Remote address changed",83:"Can   access a needed shared lib",84:"Accessing a corrupted shared lib",85:".lib section in a.out corrupted",86:"Attempting to link in too many libs",87:"Attempting to exec a shared library",88:"Function not implemented",90:"Directory not empty",91:"File or path name too long",92:"Too many symbolic links",95:"Operation not supported on transport endpoint",96:"Protocol family not supported",104:"Connection reset by peer",105:"No buffer space available",106:"Address family not supported by protocol family",107:"Protocol wrong type for socket",108:"Socket operation on non-socket",109:"Protocol not available",110:"Can't send after socket shutdown",111:"Connection refused",112:"Address already in use",113:"Connection aborted",114:"Network is unreachable",115:"Network interface is not configured",116:"Connection timed out",117:"Host is down",118:"Host is unreachable",119:"Connection already in progress",120:"Socket already connected",121:"Destination address required",122:"Message too long",123:"Unknown protocol",124:"Socket type not supported",125:"Address not available",126:"Connection reset by network",127:"Socket is already connected",128:"Socket is not connected",129:"Too many references",131:"Too many users",132:"Quota exceeded",133:"Stale file handle",134:"Not supported",135:"No medium (in tape drive)",138:"Illegal byte sequence",139:"Value too large for defined data type",140:"Operation canceled",141:"State not recoverable",142:"Previous owner died",143:"Streams pipe error"};
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value
      return value;
    }
  var VFS=undefined;
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path, ext) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var f = PATH.splitPath(path)[2];
        if (ext && f.substr(-1 * ext.length) === ext) {
          f = f.substr(0, f.length - ext.length);
        }
        return f;
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.filter(function(p, index) {
          if (typeof p !== 'string') {
            throw new TypeError('Arguments to path.join must be strings');
          }
          return p;
        }).join('/'));
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            continue;
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  var MEMFS={CONTENT_OWNING:1,CONTENT_FLEXIBLE:2,CONTENT_FIXED:3,ensureFlexible:function (node) {
        if (node.contentMode !== MEMFS.CONTENT_FLEXIBLE) {
          var contents = node.contents;
          node.contents = Array.prototype.slice.call(contents);
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        }
      },mount:function (mount) {
        return MEMFS.create_node(null, '/', 0040000 | 0777, 0);
      },create_node:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            lookup: MEMFS.node_ops.lookup,
            mknod: MEMFS.node_ops.mknod,
            mknod: MEMFS.node_ops.mknod,
            rename: MEMFS.node_ops.rename,
            unlink: MEMFS.node_ops.unlink,
            rmdir: MEMFS.node_ops.rmdir,
            readdir: MEMFS.node_ops.readdir,
            symlink: MEMFS.node_ops.symlink
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek
          };
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek,
            read: MEMFS.stream_ops.read,
            write: MEMFS.stream_ops.write,
            allocate: MEMFS.stream_ops.allocate,
            mmap: MEMFS.stream_ops.mmap
          };
          node.contents = [];
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            readlink: MEMFS.node_ops.readlink
          };
          node.stream_ops = {};
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = FS.chrdev_stream_ops;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.contents.length;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.ensureFlexible(node);
            var contents = node.contents;
            if (attr.size < contents.length) contents.length = attr.size;
            else while (attr.size > contents.length) contents.push(0);
          }
        },lookup:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.create_node(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.create_node(parent, newname, 0777 | 0120000, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          var node = stream.node;
          node.timestamp = Date.now();
          var contents = node.contents;
          if (length && contents.length === 0 && position === 0 && buffer.subarray) {
            // just replace it with the new data
            assert(buffer.length);
            if (canOwn && buffer.buffer === HEAP8.buffer && offset === 0) {
              node.contents = buffer; // this is a subarray of the heap, and we can own it
              node.contentMode = MEMFS.CONTENT_OWNING;
            } else {
              node.contents = new Uint8Array(buffer.subarray(offset, offset+length));
              node.contentMode = MEMFS.CONTENT_FIXED;
            }
            return length;
          }
          MEMFS.ensureFlexible(node);
          var contents = node.contents;
          while (contents.length < position) contents.push(0);
          for (var i = 0; i < length; i++) {
            contents[position + i] = buffer[offset + i];
          }
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.contents.length;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.ensureFlexible(stream.node);
          var contents = stream.node.contents;
          var limit = offset + length;
          while (limit > contents.length) contents.push(0);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 0x02) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < contents.length) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);var FS={root:null,nodes:[null],devices:[null],streams:[null],nextInode:1,name_table:null,currentPath:"/",initialized:false,ignorePermissions:true,ErrnoError:function ErrnoError(errno) {
          this.errno = errno;
          for (var key in ERRNO_CODES) {
            if (ERRNO_CODES[key] === errno) {
              this.code = key;
              break;
            }
          }
          this.message = ERRNO_MESSAGES[errno];
        },handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + new Error().stack;
        return ___setErrNo(e.errno);
      },hashName:function (parentid, name) {
        var hash = 0;
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.name_table.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.name_table[hash];
        FS.name_table[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.name_table[hash] === node) {
          FS.name_table[hash] = node.name_next;
        } else {
          var current = FS.name_table[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.name_table[hash]; node; node = node.name_next) {
          if (node.parent.id === parent.id && node.name === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        var node = {
          id: FS.nextInode++,
          name: name,
          mode: mode,
          node_ops: {},
          stream_ops: {},
          rdev: rdev,
          parent: null,
          mount: null
        };
        if (!parent) {
          parent = node;  // root node sets parent to itself
        }
        node.parent = parent;
        node.mount = parent.mount;
        // compatibility
        var readMode = 292 | 73;
        var writeMode = 146;
        // NOTE we must use Object.defineProperties instead of individual calls to
        // Object.defineProperty in order to make closure compiler happy
        Object.defineProperties(node, {
          read: {
            get: function() { return (node.mode & readMode) === readMode; },
            set: function(val) { val ? node.mode |= readMode : node.mode &= ~readMode; }
          },
          write: {
            get: function() { return (node.mode & writeMode) === writeMode; },
            set: function(val) { val ? node.mode |= writeMode : node.mode &= ~writeMode; }
          },
          isFolder: {
            get: function() { return FS.isDir(node.mode); },
          },
          isDevice: {
            get: function() { return FS.isChrdev(node.mode); },
          },
        });
        FS.hashAddNode(node);
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return node.mounted;
      },isFile:function (mode) {
        return (mode & 0170000) === 0100000;
      },isDir:function (mode) {
        return (mode & 0170000) === 0040000;
      },isLink:function (mode) {
        return (mode & 0170000) === 0120000;
      },isChrdev:function (mode) {
        return (mode & 0170000) === 0020000;
      },isBlkdev:function (mode) {
        return (mode & 0170000) === 0060000;
      },isFIFO:function (mode) {
        return (mode & 0170000) === 0010000;
      },isSocket:function (mode) {
        return (mode & 0140000) === 0140000;
      },cwd:function () {
        return FS.currentPath;
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.currentPath, path);
        opts = opts || { recurse_count: 0 };
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
        // start at the root
        var current = FS.root;
        var current_path = '/';
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join(current_path, parts[i]);
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            current = current.mount.root;
          }
          // follow symlinks
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            return path ? PATH.join(node.mount.mountpoint, path) : node.mount.mountpoint;
          }
          path = path ? PATH.join(node.name, path) : node.name;
          node = node.parent;
        }
      },flagModes:{"r":0,"rs":8192,"r+":2,"w":1537,"wx":3585,"xw":3585,"w+":1538,"wx+":3586,"xw+":3586,"a":521,"ax":2569,"xa":2569,"a+":522,"ax+":2570,"xa+":2570},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 3;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 1024)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        return FS.nodePermissions(dir, 'x');
      },mayMknod:function (mode) {
        switch (mode & 0170000) {
          case 0100000:
          case 0020000:
          case 0060000:
          case 0010000:
          case 0140000:
            return 0;
          default:
            return ERRNO_CODES.EINVAL;
        }
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.currentPath) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 3) !== 0 ||  // opening for write
              (flags & 1024)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 1;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        // compatibility
        Object.defineProperties(stream, {
          object: {
            get: function() { return stream.node; },
            set: function(val) { stream.node = val; }
          },
          isRead: {
            get: function() { return (stream.flags & 3) !== 1; }
          },
          isWrite: {
            get: function() { return (stream.flags & 3) !== 0; }
          },
          isAppend: {
            get: function() { return (stream.flags & 8); }
          }
        });
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join(parent, part);
          try {
            FS.mkdir(current, 0777);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(path, mode | 146);
          var stream = FS.open(path, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(path, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
              if (!hasByteServing) chunkSize = datalength;
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp', 0777);
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev', 0777);
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', 0666, FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', 0666, FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', 0666, FS.makedev(6, 0));
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm', 0777);
        FS.mkdir('/dev/shm/tmp', 0777);
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=stdin.fd;
        assert(stdin.fd === 1, 'invalid handle for stdin (' + stdin.fd + ')');
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=stdout.fd;
        assert(stdout.fd === 2, 'invalid handle for stdout (' + stdout.fd + ')');
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=stderr.fd;
        assert(stderr.fd === 3, 'invalid handle for stderr (' + stderr.fd + ')');
      },staticInit:function () {
        FS.name_table = new Array(4096);
        FS.root = FS.createNode(null, '/', 0040000 | 0777, 0);
        FS.mount(MEMFS, {}, '/');
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },mount:function (type, opts, mountpoint) {
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          root: null
        };
        var lookup;
        if (mountpoint) {
          lookup = FS.lookupPath(mountpoint, { follow: false });
        }
        // create a root node for the fs
        var root = type.mount(mount);
        root.mount = mount;
        mount.root = root;
        // assign the mount info to the mountpoint's node
        if (lookup) {
          lookup.node.mount = mount;
          lookup.node.mounted = true;
          // compatibility update FS.root if we mount to /
          if (mountpoint === '/') {
            FS.root = mount.root;
          }
        }
        return root;
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode &= 4095;
        mode |= 0100000;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode &= 511 | 0001000;
        mode |= 0040000;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        mode |= 0020000;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
      },readlink:function (path) {
        var lookup = FS.lookupPath(path, { follow: false });
        var link = lookup.node;
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        path = PATH.normalize(path);
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 0666 : mode;
        if ((flags & 512)) {
          mode = (mode & 4095) | 0100000;
        } else {
          mode = 0;
        }
        var node;
        try {
          var lookup = FS.lookupPath(path, {
            follow: !(flags & 0200000)
          });
          node = lookup.node;
          path = lookup.path;
        } catch (e) {
          // ignore
        }
        // perhaps we need to create the node
        if ((flags & 512)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 2048)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~1024;
        }
        // check permissions
        var err = FS.mayOpen(node, flags);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // do truncation if necessary
        if ((flags & 1024)) {
          FS.truncate(node, 0);
        }
        // register the stream with the filesystem
        var stream = FS.createStream({
          path: path,
          node: node,
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        if (stream.flags & 8) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.errnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      }};function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module.print('exit(' + status + ') called');
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }
  var SOCKFS={mount:function (mount) {
        return FS.createNode(null, '/', 0040000 | 0777, 0);
      },nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 0140000, 0);
        node.sock = sock;
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              var url = 'ws://' + addr + ':' + port;
              // the node ws library API is slightly different than the browser's
              var opts = ENVIRONMENT_IS_NODE ? {} : ['binary'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
          var handleOpen = function () {
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
          var handleMessage = function(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
          };
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('error', function() {
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onmessage = function(event) {
              handleMessage(event.data);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (0 /* XXX missing C define POLLRDNORM */ | 1) : 0;
          }
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (0 /* XXX missing C define POLLRDNORM */ | 1);
          }
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 2;
          }
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 1:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODS.EOPNOTSUPP);
          }
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
              // push to queue for accept to pick up
              sock.pending.push(newsock);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
            }
          });
          sock.server.on('closed', function() {
            sock.server = null;
          });
          sock.server.on('error', function() {
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  Module["_strlen"] = _strlen;
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (flagAlwaysSigned) {
                if (currArg < 0) {
                  prefix = '-' + prefix;
                } else {
                  prefix = '+' + prefix;
                }
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (flagAlwaysSigned && currArg >= 0) {
                  argText = '+' + argText;
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }
  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i32=_memset;
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    } 
  Module["_saveSetjmp"] = _saveSetjmp;
  Module["_testSetjmp"] = _testSetjmp;var _setjmp=undefined;
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _remove(path) {
      // int remove(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/remove.html
      var ret = _unlink(path);
      if (ret == -1) ret = _rmdir(path);
      return ret;
    }
  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }
  var ___timespec_struct_layout={__size__:8,tv_sec:0,tv_nsec:4};function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_sec))>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_nsec))>>2)];
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_sec))>>2)]=0
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_nsec))>>2)]=0
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }
  function _strrchr(ptr, chr) {
      var ptr2 = ptr + _strlen(ptr);
      do {
        if (HEAP8[(ptr2)] == chr) return ptr2;
        ptr2--;
      } while (ptr2 >= ptr);
      return 0;
    }
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  var _llvm_pow_f32=Math.pow;
  function _round(x) {
      return (x < 0) ? -Math.round(-x) : Math.round(x);
    }var _roundf=_round;
  function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }
  function _isspace(chr) {
      return (chr == 32) || (chr >= 9 && chr <= 13);
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm["setTempRet0"]((tempDouble=ret,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)),ret>>>0)|0);
      }
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }
  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function _llvm_lifetime_start() {}
  function _llvm_lifetime_end() {}
  var _llvm_memset_p0i8_i64=_memset;
  var ___dirent_struct_layout={__size__:1040,d_ino:0,d_name:4,d_off:1028,d_reclen:1032,d_type:1036};function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStream(stream);
      stream.eof = false;
      return 0;
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStream(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }
  function _rewind(stream) {
      // void rewind(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rewind.html
      _fseek(stream, 0, 0);  // SEEK_SET.
      var streamObj = FS.getStream(stream);
      if (streamObj) streamObj.error = false;
    }
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStream(stream);
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)|0)]=streamObj.ungotten.pop()
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(stream, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return Math.floor(bytesRead / size);
    }
  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      stream = FS.getStream(stream);
      return Number(stream && stream.eof);
    }
  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }function _fgets(s, n, stream) {
      // char *fgets(char *restrict s, int n, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgets.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return 0;
      if (streamObj.error || streamObj.eof) return 0;
      var byte_;
      for (var i = 0; i < n - 1 && byte_ != 10; i++) {
        byte_ = _fgetc(stream);
        if (byte_ == -1) {
          if (streamObj.error || (streamObj.eof && i == 0)) return 0;
          else if (streamObj.eof) break;
        }
        HEAP8[(((s)+(i))|0)]=byte_
      }
      HEAP8[(((s)+(i))|0)]=0
      return s;
    }
  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }
  Module["_tolower"] = _tolower; 
  Module["_strncasecmp"] = _strncasecmp; 
  Module["_strcasecmp"] = _strcasecmp;
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'root';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/emscripten';
        ENV['LANG'] = 'en_US.UTF-8';
        ENV['_'] = './this.program';
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        for (var j = 0; j < line.length; j++) {
          HEAP8[(((poolPtr)+(j))|0)]=line.charCodeAt(j);
        }
        HEAP8[(((poolPtr)+(j))|0)]=0;
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  var ___tm_struct_layout={__size__:44,tm_sec:0,tm_min:4,tm_hour:8,tm_mday:12,tm_mon:16,tm_year:20,tm_wday:24,tm_yday:28,tm_isdst:32,tm_gmtoff:36,tm_zone:40};
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
      var date = {
        tm_sec: HEAP32[(((tm)+(___tm_struct_layout.tm_sec))>>2)],
        tm_min: HEAP32[(((tm)+(___tm_struct_layout.tm_min))>>2)],
        tm_hour: HEAP32[(((tm)+(___tm_struct_layout.tm_hour))>>2)],
        tm_mday: HEAP32[(((tm)+(___tm_struct_layout.tm_mday))>>2)],
        tm_mon: HEAP32[(((tm)+(___tm_struct_layout.tm_mon))>>2)],
        tm_year: HEAP32[(((tm)+(___tm_struct_layout.tm_year))>>2)],
        tm_wday: HEAP32[(((tm)+(___tm_struct_layout.tm_wday))>>2)],
        tm_yday: HEAP32[(((tm)+(___tm_struct_layout.tm_yday))>>2)],
        tm_isdst: HEAP32[(((tm)+(___tm_struct_layout.tm_isdst))>>2)]
      };
      var pattern = Pointer_stringify(format);
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S',                 // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
      var leadingSomething = function(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
      var leadingNulls = function(value, digits) {
        return leadingSomething(value, digits, '0');
      };
      var compareByDay = function(date1, date2) {
        var sgn = function(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
      var getFirstWeekStartDate = function(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
      var getWeekBasedYear = function(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls(Math.floor(year/100),2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ),
          // or by no characters if no timezone is determinable. 
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich). 
          // If tm_isdst is zero, the standard time offset is used. 
          // If tm_isdst is greater than zero, the daylight savings time offset is used. 
          // If tm_isdst is negative, no characters are returned. 
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%Z': function(date) {
          // Replaced by the timezone name or abbreviation, or by no bytes if no timezone information exists. [ tm_isdst]
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }
  var ___tm_current=allocate(4*26, "i8", ALLOC_STATIC);
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);
  var __tzname=allocate(8, "i32*", ALLOC_STATIC);
  var __daylight=allocate(1, "i32*", ALLOC_STATIC);
  var __timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
      HEAP32[((__timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((__daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset())
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((__tzname)>>2)]=winterNamePtr
      HEAP32[(((__tzname)+(4))>>2)]=summerNamePtr
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var offsets = ___tm_struct_layout;
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getDay()
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=start.getTimezoneOffset() * 60
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=dst
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezone
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }
  function _strtok_r(s, delim, lasts) {
      var skip_leading_delim = 1;
      var spanp;
      var c, sc;
      var tok;
      if (s == 0 && (s = getValue(lasts, 'i8*')) == 0) {
        return 0;
      }
      cont: while (1) {
        c = getValue(s++, 'i8');
        for (spanp = delim; (sc = getValue(spanp++, 'i8')) != 0;) {
          if (c == sc) {
            if (skip_leading_delim) {
              continue cont;
            } else {
              setValue(lasts, s, 'i8*');
              setValue(s - 1, 0, 'i8');
              return s - 1;
            }
          }
        }
        break;
      }
      if (c == 0) {
        setValue(lasts, 0, 'i8*');
        return 0;
      }
      tok = s - 1;
      for (;;) {
        c = getValue(s++, 'i8');
        spanp = delim;
        do {
          if ((sc = getValue(spanp++, 'i8')) == c) {
            if (c == 0) {
              s = 0;
            } else {
              setValue(s - 1, 0, 'i8');
            }
            setValue(lasts, s, 'i8*');
            return tok;
          }
        } while (sc != 0);
      }
      abort('strtok_r error!');
    }
  function _qsort(base, num, size, cmp) {
      if (num == 0 || size == 0) return;
      // forward calls to the JavaScript sort method
      // first, sort the items logically
      var keys = [];
      for (var i = 0; i < num; i++) keys.push(i);
      keys.sort(function(a, b) {
        return Module['dynCall_iii'](cmp, base+a*size, base+b*size);
      });
      // apply the sort
      var temp = _malloc(num*size);
      _memcpy(temp, base, num*size);
      for (var i = 0; i < num; i++) {
        if (keys[i] == i) continue; // already in place
        _memcpy(base+i*size, temp+keys[i]*size, size);
      }
      _free(temp);
    }
  function _opendir(dirname) {
      // DIR *opendir(const char *dirname);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/opendir.html
      // NOTE: Calculating absolute path redundantly since we need to associate it
      //       with the opened stream.
      var path = Pointer_stringify(dirname);
      if (!path) {
        ___setErrNo(ERRNO_CODES.ENOENT);
        return 0;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return 0;
      }
      if (!FS.isDir(node.mode)) {
        ___setErrNo(ERRNO_CODES.ENOTDIR);
        return 0;
      }
      var err = _open(dirname, 0, allocate([0, 0, 0, 0], 'i32', ALLOC_STACK));
      // open returns 0 on failure, not -1
      return err === -1 ? 0 : err;
    }
  function _readdir_r(dirp, entry, result) {
      // int readdir_r(DIR *dirp, struct dirent *entry, struct dirent **result);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        return ___setErrNo(ERRNO_CODES.EBADF);
      }
      var entries;
      try {
        entries = FS.readdir(stream.path);
      } catch (e) {
        return FS.handleFSError(e);
      }
      if (stream.position < 0 || stream.position >= entries.length) {
        HEAP32[((result)>>2)]=0
        return 0;
      }
      var id;
      var type;
      var name = entries[stream.position];
      var offset = stream.position + 1;
      if (!name.indexOf('.')) {
        id = 1;
        type = 4;
      } else {
        var child = FS.lookupNode(stream.node, name);
        id = child.id;
        type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
               FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
               FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
               8;                             // DT_REG, regular file.
      }
      HEAP32[(((entry)+(___dirent_struct_layout.d_ino))>>2)]=id
      HEAP32[(((entry)+(___dirent_struct_layout.d_off))>>2)]=offset
      HEAP32[(((entry)+(___dirent_struct_layout.d_reclen))>>2)]=name.length + 1
      for (var i = 0; i < name.length; i++) {
        HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=name.charCodeAt(i)
      }
      HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=0
      HEAP8[(((entry)+(___dirent_struct_layout.d_type))|0)]=type
      HEAP32[((result)>>2)]=entry
      stream.position++;
      return 0;
    }function _readdir(dirp) {
      // struct dirent *readdir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // TODO Is it supposed to be safe to execute multiple readdirs?
      if (!_readdir.entry) _readdir.entry = _malloc(___dirent_struct_layout.__size__);
      if (!_readdir.result) _readdir.result = _malloc(4);
      var err = _readdir_r(dirp, _readdir.entry, _readdir.result);
      if (err) {
        ___setErrNo(err);
        return 0;
      }
      return HEAP32[((_readdir.result)>>2)];
    }
  function _closedir(dirp) {
      // int closedir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/closedir.html
      return _close(dirp);
    }
  var ___stat_struct_layout={__size__:68,st_dev:0,st_ino:4,st_mode:8,st_nlink:12,st_uid:16,st_gid:20,st_rdev:24,st_size:28,st_atime:32,st_spare1:36,st_mtime:40,st_spare2:44,st_ctime:48,st_spare3:52,st_blksize:56,st_blocks:60,st_spare4:64};function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[(((buf)+(___stat_struct_layout.st_dev))>>2)]=stat.dev;
        HEAP32[(((buf)+(___stat_struct_layout.st_ino))>>2)]=stat.ino
        HEAP32[(((buf)+(___stat_struct_layout.st_mode))>>2)]=stat.mode
        HEAP32[(((buf)+(___stat_struct_layout.st_nlink))>>2)]=stat.nlink
        HEAP32[(((buf)+(___stat_struct_layout.st_uid))>>2)]=stat.uid
        HEAP32[(((buf)+(___stat_struct_layout.st_gid))>>2)]=stat.gid
        HEAP32[(((buf)+(___stat_struct_layout.st_rdev))>>2)]=stat.rdev
        HEAP32[(((buf)+(___stat_struct_layout.st_size))>>2)]=stat.size
        HEAP32[(((buf)+(___stat_struct_layout.st_atime))>>2)]=Math.floor(stat.atime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_mtime))>>2)]=Math.floor(stat.mtime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_ctime))>>2)]=Math.floor(stat.ctime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_blksize))>>2)]=4096
        HEAP32[(((buf)+(___stat_struct_layout.st_blocks))>>2)]=stat.blocks
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _realpath(file_name, resolved_name) {
      // char *realpath(const char *restrict file_name, char *restrict resolved_name);
      // http://pubs.opengroup.org/onlinepubs/009604499/functions/realpath.html
      var absolute = FS.analyzePath(Pointer_stringify(file_name));
      if (absolute.error) {
        ___setErrNo(absolute.error);
        return 0;
      } else {
        var size = Math.min(4095, absolute.path.length);  // PATH_MAX - 1.
        for (var i = 0; i < size; i++) {
          HEAP8[(((resolved_name)+(i))|0)]=absolute.path.charCodeAt(i)
        }
        HEAP8[(((resolved_name)+(size))|0)]=0
        return resolved_name;
      }
    }
  function _getgid() {
      // gid_t getgid(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/getgid.html
      // We have just one process/group/user, all with ID 0.
      return 0;
    }var _getpid=_getgid;
  function _readlink(path, buf, bufsize) {
      // ssize_t readlink(const char *restrict path, char *restrict buf, size_t bufsize);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/readlink.html
      path = Pointer_stringify(path);
      var str;
      try {
        str = FS.readlink(path);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      str = str.slice(0, Math.max(0, bufsize - 1));
      writeStringToMemory(str, buf, true);
      return str.length;
    }
  var _sqrt=Math.sqrt;
  var _fabs=Math.abs;
  function ___errno_location() {
      return ___errno_state;
    }var ___errno=___errno_location;
  function __parseInt64(str, endptr, base, min, max, unsign) {
      var isNegative = false;
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      if (HEAP8[(str)] == 45) {
        str++;
        isNegative = true;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var ok = false;
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            ok = true; // we saw an initial zero, perhaps the entire thing is just "0"
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      start = str;
      // Get digits.
      var chr;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          str++;
          ok = true;
        }
      }
      if (!ok) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return ((asm["setTempRet0"](0),0)|0);
      }
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      try {
        var numberString = isNegative ? '-'+Pointer_stringify(start, str - start) : Pointer_stringify(start, str - start);
        i64Math.fromString(numberString, finalBase, min, max, unsign);
      } catch(e) {
        ___setErrNo(ERRNO_CODES.ERANGE); // not quite correct
      }
      return ((asm["setTempRet0"](((HEAP32[(((tempDoublePtr)+(4))>>2)])|0)),((HEAP32[((tempDoublePtr)>>2)])|0))|0);
    }function _strtoull(str, endptr, base) {
      return __parseInt64(str, endptr, base, 0, '18446744073709551615', true);  // ULONG_MAX.
    }
  var _getc=_fgetc;
  function _isgraph(chr) {
      return 0x20 < chr && chr < 0x7F;
    }
  function _llvm_bswap_i32(x) {
      return ((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24);
    }
  function _isalpha(chr) {
      return (chr >= 97 && chr <= 122) ||
             (chr >= 65 && chr <= 90);
    }
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', {
              alpha: false
            });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var x, y;
          if (event.type == 'touchstart' ||
              event.type == 'touchend' ||
              event.type == 'touchmove') {
            var t = event.touches.item(0);
            if (t) {
              x = t.pageX - (window.scrollX + rect.left);
              y = t.pageY - (window.scrollY + rect.top);
            } else {
              return;
            }
          } else {
            x = event.pageX - (window.scrollX + rect.left);
            y = event.pageY - (window.scrollY + rect.top);
          }
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};var RI={temp:null,contexts:[],eventHandler:function (event) {
           var i;
           switch (event.type) {
              case 'mousemove':
                 var x = event['movementX'] || event['mozMovementX'] || event['webkitMovementX'];
                 var y = event['movementY'] || event['mozMovementY'] || event['webkitMovementY'];
                 for (i = 0; i < RI.contexts.length; i++) {
                    var oldX = HEAP32[(((RI.contexts[i].state)+(32))>>2)];
                    var oldY = HEAP32[(((RI.contexts[i].state)+(36))>>2)];
                    x += oldX;
                    y += oldY;
                    HEAP32[(((RI.contexts[i].state)+(32))>>2)]=x;
                    HEAP32[(((RI.contexts[i].state)+(36))>>2)]=y;
                 }
                 break;
              case 'mouseup':
              case 'mousedown':
                 var value;
                 var offset;
                 if (event.button === 0) offset = 40;
                 else if (event.button === 2) offset = 41;
                 else break;
                 if (event.type === 'mouseup') value = 0;
                 else value = 1;
                 for (i = 0; i < RI.contexts.length; i++) {
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 break;
              case 'keyup':
              case 'keydown':
                 var key = event.keyCode;
                 var offset = key >> 3;
                 var bit = 1 << (key & 7);
                 if (offset >= 32) throw 'key code error! bad code: ' + key;
                 for (i = 0; i < RI.contexts.length; i++) {
                    var value = HEAP8[(((RI.contexts[i].state)+(offset))|0)];
                    if (event.type === 'keyup') value &= ~bit;
                    else value |= bit;
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 event.preventDefault();
                 break;
              case 'blur':
              case 'visibilitychange':
                 for (i = 0; i < RI.contexts.length; i++) {
                    _memset(RI.contexts[i].state, 0, 42);
                 }
                 break;
           }
        }};function _RWebInputDestroy(context) {
        if (context === RI.contexts.length) {
           RI.contexts.pop();
           if (RI.contexts.length === 0) {
              document.removeEventListener('keyup', RI.eventHandler, false);
              document.removeEventListener('keydown', RI.eventHandler, false);
              document.removeEventListener('mousemove', RI.eventHandler, false);
              document.removeEventListener('mouseup', RI.eventHandler, false);
              document.removeEventListener('mousedown', RI.eventHandler, false);
              document.removeEventListener('blur', RI.eventHandler, false);
              document.removeEventListener('onvisbilitychange', RI.eventHandler, false);
           }
        }
     }
  function _RWebInputPoll(context) {
        context -= 1;
        var state = RI.contexts[context].state;
        _memcpy(RI.temp, state, 42);
        // reset mouse movements
        HEAP32[(((RI.contexts[context].state)+(32))>>2)]=0;
        HEAP32[(((RI.contexts[context].state)+(36))>>2)]=0;
        return RI.temp;
     }
  function _RWebInputInit(latency) {
        if (RI.contexts.length === 0) {
           document.addEventListener('keyup', RI.eventHandler, false);
           document.addEventListener('keydown', RI.eventHandler, false);
           document.addEventListener('mousemove', RI.eventHandler, false);
           document.addEventListener('mouseup', RI.eventHandler, false);
           document.addEventListener('mousedown', RI.eventHandler, false);
           document.addEventListener('blur', RI.eventHandler, false);
           document.addEventListener('onvisbilitychange', RI.eventHandler, false);
        }
        if (RI.temp === null) RI.temp = _malloc(42);
        var s = _malloc(42);
        _memset(s, 0, 42);
        RI.contexts.push({
           state: s
        });
        return RI.contexts.length;
     }
  function _strstr(ptr1, ptr2) {
      var check = 0, start;
      do {
        if (!check) {
          start = ptr1;
          check = ptr2;
        }
        var curr1 = HEAP8[((ptr1++)|0)];
        var curr2 = HEAP8[((check++)|0)];
        if (curr2 == 0) return start;
        if (curr2 != curr1) {
          // rewind to one character after start, to find ez in eeez
          ptr1 = start + 1;
          check = 0;
        }
      } while (curr1);
      return 0;
    }
  Module["_memmove"] = _memmove;var _llvm_memmove_p0i8_p0i8_i32=_memmove;
  Module["_memcmp"] = _memcmp;
  var RA={BUFFER_SIZE:256,context:null,buffers:[],numBuffers:0,bufIndex:0,bufOffset:0,startTime:0,nonblock:false,currentTimeWorkaround:false,setStartTime:function () {
           if (RA.context.currentTime) {
              RA.startTime = window['performance']['now']() - RA.context.currentTime * 1000;
              var time1 = RA.context.currentTime;
              _usleep(50);
              if (time1 === RA.context.currentTime) {
                 RA.currentTimeWorkaround = true;
                 if (RA.startTime === 0) throw 'startTime is 0';
              }
              Module["resumeMainLoop"]();
           } else window['setTimeout'](RA.setStartTime, 0);
        },getCurrentPerfTime:function () {
           if (!RA.currentTimeWorkaround) return RA.context.currentTime;
           else if (RA.startTime) return (window['performance']['now']() - RA.startTime) / 1000;
           else throw 'getCurrentPerfTime() called before start time set';
        },process:function (queueBuffers) {
           var currentTime = RA.getCurrentPerfTime();
           for (var i = 0; i < RA.bufIndex; i++) {
              if (RA.buffers[i].endTime < currentTime) {
                 var buf = RA.buffers.splice(i, 1);
                 RA.buffers[RA.numBuffers - 1] = buf[0];
                 i--;
                 RA.bufIndex--;
              }
           }
        },fillBuffer:function (buf, samples) {
           var count = 0;
           var leftBuffer = RA.buffers[RA.bufIndex].getChannelData(0);
           var rightBuffer = RA.buffers[RA.bufIndex].getChannelData(1);
           while (samples && RA.bufOffset !== RA.BUFFER_SIZE) {
              leftBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8))>>2)];
              rightBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8 + 4))>>2)];
              RA.bufOffset++;
              count++;
              samples--;
           }
           return count;
        },queueAudio:function () {
           var index = RA.bufIndex;
           var startTime;
           if (RA.bufIndex) startTime = RA.buffers[RA.bufIndex - 1].endTime;
           else startTime = RA.context.currentTime;
           RA.buffers[index].endTime = startTime + RA.buffers[index].duration;
           var bufferSource = RA.context.createBufferSource();
           bufferSource.buffer = RA.buffers[index];
           bufferSource.connect(RA.context.destination);
           bufferSource.start(startTime);
           RA.bufIndex++;
           RA.bufOffset = 0;
        },block:function () {
           do {
              RA.process();
           } while (RA.bufIndex === RA.numBuffers - 1);
        }};function _RWebAudioBufferSize() {
        return RA.numBuffers * RA.BUFFER_SIZE + RA.BUFFER_SIZE;
     }
  function _RWebAudioWriteAvail() {
        RA.process();
        return ((RA.numBuffers - RA.bufIndex) * RA.BUFFER_SIZE - RA.bufOffset) * 8;
     }
  function _RWebAudioFree() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return;
     }
  function _RWebAudioSetNonblockState(state) {
        RA.nonblock = state;
     }
  function _RWebAudioStart() {
        return true;
     }
  function _RWebAudioStop() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return true;
     }
  function _RWebAudioWrite(buf, size) {
        RA.process();
        var samples = size / 8;
        var count = 0;
        while (samples) {
           var fill = RA.fillBuffer(buf, samples);
           samples -= fill;
           count += fill;
           buf += fill * 8;
           if (RA.bufOffset === RA.BUFFER_SIZE) {
              if (RA.bufIndex === RA.numBuffers - 1) {
                 if (RA.nonblock) break;
                 else RA.block();
              }
              RA.queueAudio();
           }
        }
        return count * 8;
     }
  function _RWebAudioInit(latency) {
        var ac = window['AudioContext'] || window['webkitAudioContext'];
        if (!ac) return 0;
        RA.context = new ac();
        RA.numBuffers = ((latency * RA.context.sampleRate) / (1000 * RA.BUFFER_SIZE))|0;
        if (RA.numBuffers < 2) RA.numBuffers = 2;
        for (var i = 0; i < RA.numBuffers; i++) RA.buffers[i] = RA.context.createBuffer(2, RA.BUFFER_SIZE, RA.context.sampleRate);
        RA.nonblock = false;
        RA.startTime = 0;
        // chrome hack to get currentTime running
        RA.context.createGain();
        window['setTimeout'](RA.setStartTime, 0);
        Module["pauseMainLoop"]();
        return 1;
     }
  function _RWebAudioSampleRate() {
        return RA.context.sampleRate;
     }
  var _fabsf=Math.abs;
  var _sin=Math.sin;
  var _ceil=Math.ceil;
  function _emscripten_get_now() {
      if (!_emscripten_get_now.actual) {
        if (ENVIRONMENT_IS_NODE) {
            _emscripten_get_now.actual = function() {
              var t = process['hrtime']();
              return t[0] * 1e3 + t[1] / 1e6;
            }
        } else if (typeof dateNow !== 'undefined') {
          _emscripten_get_now.actual = dateNow;
        } else if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
          _emscripten_get_now.actual = function() { return window['performance']['now'](); };
        } else {
          _emscripten_get_now.actual = Date.now;
        }
      }
      return _emscripten_get_now.actual();
    }
  function _llvm_uadd_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm["setTempRet0"](x+y > 4294967295),(x+y)>>>0)|0);
    }
  var GL={counter:1,buffers:[],programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],currArrayBuffer:0,currElementArrayBuffer:0,byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],uniformTable:{},packAlignment:4,unpackAlignment:4,init:function () {
        Browser.moduleContextCreatedCallbacks.push(GL.initExtensions);
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:16,miniTempBuffer:null,miniTempBufferViews:[0],MAX_TEMP_BUFFER_SIZE:2097152,tempBufferIndexLookup:null,tempVertexBuffers:null,tempIndexBuffers:null,tempQuadIndexBuffer:null,generateTempBuffers:function (quads) {
        GL.tempBufferIndexLookup = new Uint8Array(GL.MAX_TEMP_BUFFER_SIZE+1);
        GL.tempVertexBuffers = [];
        GL.tempIndexBuffers = [];
        var last = -1, curr = -1;
        var size = 1;
        for (var i = 0; i <= GL.MAX_TEMP_BUFFER_SIZE; i++) {
          if (i > size) {
            size <<= 1;
          }
          if (size != last) {
            curr++;
            GL.tempVertexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, GL.tempVertexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, null);
            GL.tempIndexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempIndexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
            last = size;
          }
          GL.tempBufferIndexLookup[i] = curr;
        }
        if (quads) {
          // GL_QUAD indexes can be precalculated
          GL.tempQuadIndexBuffer = Module.ctx.createBuffer();
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempQuadIndexBuffer);
          var numIndexes = GL.MAX_TEMP_BUFFER_SIZE >> 1;
          var quadIndexes = new Uint16Array(numIndexes);
          var i = 0, v = 0;
          while (1) {
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+1;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+3;
            if (i >= numIndexes) break;
            v += 4;
          }
          Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, quadIndexes, Module.ctx.STATIC_DRAW);
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
        }
      },findToken:function (source, token) {
        function isIdentChar(ch) {
          if (ch >= 48 && ch <= 57) // 0-9
            return true;
          if (ch >= 65 && ch <= 90) // A-Z
            return true;
          if (ch >= 97 && ch <= 122) // a-z
            return true;
          return false;
        }
        var i = -1;
        do {
          i = source.indexOf(token, i + 1);
          if (i < 0) {
            break;
          }
          if (i > 0 && isIdentChar(source[i - 1])) {
            continue;
          }
          i += token.length;
          if (i < source.length - 1 && isIdentChar(source[i + 1])) {
            continue;
          }
          return true;
        } while (true);
        return false;
      },getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        // Let's see if we need to enable the standard derivatives extension
        type = Module.ctx.getShaderParameter(GL.shaders[shader], 0x8B4F /* GL_SHADER_TYPE */);
        if (type == 0x8B30 /* GL_FRAGMENT_SHADER */) {
          if (GL.findToken(source, "dFdx") ||
              GL.findToken(source, "dFdy") ||
              GL.findToken(source, "fwidth")) {
            source = "#extension GL_OES_standard_derivatives : enable\n" + source;
            var extension = Module.ctx.getExtension("OES_standard_derivatives");
          }
        }
        return source;
      },computeImageSize:function (width, height, sizePerPixel, alignment) {
        function roundedToNextMultipleOf(x, y) {
          return Math.floor((x + y - 1) / y) * y
        }
        var plainRowSize = width * sizePerPixel;
        var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
        return (height <= 0) ? 0 :
                 ((height - 1) * alignedRowSize + plainRowSize);
      },getTexPixelData:function (type, format, width, height, pixels, internalFormat) {
        var sizePerPixel;
        switch (type) {
          case 0x1401 /* GL_UNSIGNED_BYTE */:
            switch (format) {
              case 0x1906 /* GL_ALPHA */:
              case 0x1909 /* GL_LUMINANCE */:
                sizePerPixel = 1;
                break;
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4;
                break;
              case 0x190A /* GL_LUMINANCE_ALPHA */:
                sizePerPixel = 2;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            break;
          case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
          case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
          case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
            sizePerPixel = 2;
            break;
          case 0x1406 /* GL_FLOAT */:
            assert(GL.floatExt, 'Must have OES_texture_float to use float textures');
            switch (format) {
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3*4;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4*4;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            internalFormat = Module.ctx.RGBA;
            break;
          default:
            throw 'Invalid type (' + type + ')';
        }
        var bytes = GL.computeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
        if (type == 0x1401 /* GL_UNSIGNED_BYTE */) {
          pixels = HEAPU8.subarray((pixels),(pixels+bytes));
        } else if (type == 0x1406 /* GL_FLOAT */) {
          pixels = HEAPF32.subarray((pixels)>>2,(pixels+bytes)>>2);
        } else {
          pixels = HEAPU16.subarray((pixels)>>1,(pixels+bytes)>>1);
        }
        return {
          pixels: pixels,
          internalFormat: internalFormat
        }
      },initExtensions:function () {
        if (GL.initExtensions.done) return;
        GL.initExtensions.done = true;
        if (!Module.useWebGL) return; // an app might link both gl and 2d backends
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }
        GL.maxVertexAttribs = Module.ctx.getParameter(Module.ctx.MAX_VERTEX_ATTRIBS);
        GL.compressionExt = Module.ctx.getExtension('WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('MOZ_WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('WEBKIT_WEBGL_compressed_texture_s3tc');
        GL.anisotropicExt = Module.ctx.getExtension('EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('MOZ_EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('WEBKIT_EXT_texture_filter_anisotropic');
        GL.floatExt = Module.ctx.getExtension('OES_texture_float');
        GL.elementIndexUintExt = Module.ctx.getExtension('OES_element_index_uint');
        GL.standardDerivativesExt = Module.ctx.getExtension('OES_standard_derivatives');
      }};function _glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        Module.ctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }
  function _glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        Module.ctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }
  function _glViewport(x0, x1, x2, x3) { Module.ctx.viewport(x0, x1, x2, x3) }
  function _glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.textures);
        var texture = Module.ctx.createTexture();
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }
  function _glBindTexture(target, texture) {
      Module.ctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }
  function _glTexParameteri(x0, x1, x2) { Module.ctx.texParameteri(x0, x1, x2) }
  function _glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      Module.ctx.pixelStorei(pname, param);
    }
  function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, internalFormat);
        pixels = data.pixels;
        internalFormat = data.internalFormat;
      } else {
        pixels = null;
      }
      Module.ctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels);
    }
  function _glBindFramebuffer(target, framebuffer) {
      Module.ctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
    }
  function _glReadPixels(x, y, width, height, format, type, pixels) {
      assert(type == 0x1401 /* GL_UNSIGNED_BYTE */);
      var sizePerPixel;
      switch (format) {
        case 0x1907 /* GL_RGB */:
          sizePerPixel = 3;
          break;
        case 0x1908 /* GL_RGBA */:
          sizePerPixel = 4;
          break;
        default: throw 'unsupported glReadPixels format';
      }
      var totalSize = width*height*sizePerPixel;
      Module.ctx.readPixels(x, y, width, height, format, type, HEAPU8.subarray(pixels, pixels + totalSize));
    }
  function _glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        Module.ctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }
  function _glGetIntegerv(name_, p) {
      switch(name_) { // Handle a few trivial GLES values
        case 0x8DFA: // GL_SHADER_COMPILER
          HEAP32[((p)>>2)]=1;
          return;
        case 0x8DF9: // GL_NUM_SHADER_BINARY_FORMATS
          HEAP32[((p)>>2)]=0;
          return;
        case 0x86A2: // GL_NUM_COMPRESSED_TEXTURE_FORMATS
          // WebGL doesn't have GL_NUM_COMPRESSED_TEXTURE_FORMATS (it's obsolete since GL_COMPRESSED_TEXTURE_FORMATS returns a JS array that can be queried for length),
          // so implement it ourselves to allow C++ GLES2 code get the length.
          var formats = Module.ctx.getParameter(0x86A3 /*GL_COMPRESSED_TEXTURE_FORMATS*/);
          HEAP32[((p)>>2)]=formats.length;
          return;
      }
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAP8[(p)]=result ? 1 : 0;
          break;
        case "string":
          throw 'Native code calling glGetIntegerv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP32[((p)>>2)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetIntegerv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var id = GL.getNewId(GL.framebuffers);
        var framebuffer = Module.ctx.createFramebuffer();
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }
  function _glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.renderbuffers);
        var renderbuffer = Module.ctx.createRenderbuffer();
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }
  function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      Module.ctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }
  function _glBindRenderbuffer(target, renderbuffer) {
      Module.ctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }
  function _glRenderbufferStorage(x0, x1, x2, x3) { Module.ctx.renderbufferStorage(x0, x1, x2, x3) }
  function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      Module.ctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }
  function _glCheckFramebufferStatus(x0) { return Module.ctx.checkFramebufferStatus(x0) }
  function _glGetString(name_) {
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x1F02 /* GL_VERSION */:
          return allocate(intArrayFromString(Module.ctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
        case 0x1F03 /* GL_EXTENSIONS */:
          return allocate(intArrayFromString(Module.ctx.getSupportedExtensions().join(' ')), 'i8', ALLOC_NORMAL);
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          return allocate(intArrayFromString('OpenGL ES GLSL 1.00 (WebGL)'), 'i8', ALLOC_NORMAL);
        default:
          throw 'Failure: Invalid glGetString value: ' + name_;
      }
    }
  function _glDisable(x0) { Module.ctx.disable(x0) }
  function _glBlendFunc(x0, x1) { Module.ctx.blendFunc(x0, x1) }
  function _glClearColor(x0, x1, x2, x3) { Module.ctx.clearColor(x0, x1, x2, x3) }
  function _glClear(x0) { Module.ctx.clear(x0) }
  function _glDrawArrays(mode, first, count) {
      Module.ctx.drawArrays(mode, first, count);
    }
  function _glEnable(x0) { Module.ctx.enable(x0) }
  function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, -1);
        pixels = data.pixels;
      } else {
        pixels = null;
      }
      Module.ctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels);
    }
  function _glGetError() { return Module.ctx.getError() }
  var _cosf=Math.cos;
  var _sinf=Math.sin;
  function _glGetFloatv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAPF32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAPF32[((p)>>2)]=result ? 1.0 : 0.0;
          break;
        case "string":
            HEAPF32[((p)>>2)]=0;
        case "object":
          if (result === null) {
            throw 'Native code calling glGetFloatv(' + name_ + ') and it returns null';
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAPF32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetFloatv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGetBooleanv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP8[(p)]=result != 0;
          break;
        case "boolean":
          HEAP8[(p)]=result != 0;
          break;
        case "string":
          throw 'Native code calling glGetBooleanv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP8[(p)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP8[(((p)+(i))|0)]=result[i] != 0;
            }
          } else if (result instanceof WebGLBuffer ||
                     result instanceof WebGLProgram ||
                     result instanceof WebGLFramebuffer ||
                     result instanceof WebGLRenderbuffer ||
                     result instanceof WebGLTexture) {
            HEAP8[(p)]=1; // non-zero ID is always 1!
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
            throw 'Unknown object returned from WebGL getParameter';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data);
    }
  function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, data);
    }
  function _glGetTexParameterfv(target, pname, params) {
      HEAPF32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glGetTexParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      Module.ctx.texParameterf(target, pname, param);
    }
  function _glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      Module.ctx.texParameteri(target, pname, param);
    }
  function _glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return Module.ctx.isTexture(texture);
    }
  function _glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.buffers);
        var buffer = Module.ctx.createBuffer();
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }
  function _glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
        Module.ctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }
  function _glGetBufferParameteriv(target, value, data) {
      HEAP32[((data)>>2)]=Module.ctx.getBufferParameter(target, value);
    }
  function _glBufferData(target, size, data, usage) {
      switch (usage) { // fix usages, WebGL only has *_DRAW
        case 0x88E1: // GL_STREAM_READ
        case 0x88E2: // GL_STREAM_COPY
          usage = 0x88E0; // GL_STREAM_DRAW
          break;
        case 0x88E5: // GL_STATIC_READ
        case 0x88E6: // GL_STATIC_COPY
          usage = 0x88E4; // GL_STATIC_DRAW
          break;
        case 0x88E9: // GL_DYNAMIC_READ
        case 0x88EA: // GL_DYNAMIC_COPY
          usage = 0x88E8; // GL_DYNAMIC_DRAW
          break;
      }
      Module.ctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
    }
  function _glBufferSubData(target, offset, size, data) {
      Module.ctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }
  function _glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return Module.ctx.isBuffer(b);
    }
  function _glGetRenderbufferParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.ctx.getRenderbufferParameter(target, pname);
    }
  function _glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return Module.ctx.isRenderbuffer(rb);
    }
  function _glGetUniformfv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformiv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
      var ptable = GL.uniformTable[program];
      if (!ptable) ptable = GL.uniformTable[program] = {};
      var id = ptable[name];
      if (id) return id;
      var loc = Module.ctx.getUniformLocation(GL.programs[program], name);
      if (!loc) return -1;
      id = GL.getNewId(GL.uniforms);
      GL.uniforms[id] = loc;
      ptable[name] = id;
      return id;
    }
  function _glGetVertexAttribfv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribiv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribPointerv(index, pname, pointer) {
      HEAP32[((pointer)>>2)]=Module.ctx.getVertexAttribOffset(index, pname);
    }
  function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveUniform(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glUniform1f(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1f(location, v0);
    }
  function _glUniform2f(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2f(location, v0, v1);
    }
  function _glUniform3f(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3f(location, v0, v1, v2);
    }
  function _glUniform4f(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4f(location, v0, v1, v2, v3);
    }
  function _glUniform1i(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1i(location, v0);
    }
  function _glUniform2i(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2i(location, v0, v1);
    }
  function _glUniform3i(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3i(location, v0, v1, v2);
    }
  function _glUniform4i(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4i(location, v0, v1, v2, v3);
    }
  function _glUniform1iv(location, count, value) {
      location = GL.uniforms[location];
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform1iv(location, value);
    }
  function _glUniform2iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 2;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform2iv(location, value);
    }
  function _glUniform3iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 3;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform3iv(location, value);
    }
  function _glUniform4iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 4;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform4iv(location, value);
    }
  function _glUniform1fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[0];
        view[0] = HEAPF32[((value)>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      Module.ctx.uniform1fv(location, view);
    }
  function _glUniform2fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[1];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      Module.ctx.uniform2fv(location, view);
    }
  function _glUniform3fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[2];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      Module.ctx.uniform3fv(location, view);
    }
  function _glUniform4fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[3];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
        view[3] = HEAPF32[(((value)+(12))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniform4fv(location, view);
    }
  function _glUniformMatrix2fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[3];
        for (var i = 0; i < 4; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniformMatrix2fv(location, transpose, view);
    }
  function _glUniformMatrix3fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[8];
        for (var i = 0; i < 9; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      Module.ctx.uniformMatrix3fv(location, transpose, view);
    }
  function _glUniformMatrix4fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[15];
        for (var i = 0; i < 16; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      Module.ctx.uniformMatrix4fv(location, transpose, view);
    }
  function _glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
      if (target == Module.ctx.ARRAY_BUFFER) {
        GL.currArrayBuffer = buffer;
      } else if (target == Module.ctx.ELEMENT_ARRAY_BUFFER) {
        GL.currElementArrayBuffer = buffer;
      }
      Module.ctx.bindBuffer(target, bufferObj);
    }
  function _glVertexAttrib1fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+4)>>2);
      Module.ctx.vertexAttrib1fv(index, v);
    }
  function _glVertexAttrib2fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+8)>>2);
      Module.ctx.vertexAttrib2fv(index, v);
    }
  function _glVertexAttrib3fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+12)>>2);
      Module.ctx.vertexAttrib3fv(index, v);
    }
  function _glVertexAttrib4fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+16)>>2);
      Module.ctx.vertexAttrib4fv(index, v);
    }
  function _glGetAttribLocation(program, name) {
      program = GL.programs[program];
      name = Pointer_stringify(name);
      return Module.ctx.getAttribLocation(program, name);
    }
  function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveAttrib(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = Module.ctx.createShader(shaderType);
      return id;
    }
  function _glDeleteShader(shader) {
      Module.ctx.deleteShader(GL.shaders[shader]);
      GL.shaders[shader] = null;
    }
  function _glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = Module.ctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        assert(id !== -1, 'shader not bound to local id');
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }
  function _glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
      Module.ctx.shaderSource(GL.shaders[shader], source);
    }
  function _glGetShaderSource(shader, bufSize, length, source) {
      var result = Module.ctx.getShaderSource(GL.shaders[shader]);
      result = result.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(result, source);
      if (length) {
        HEAP32[((length)>>2)]=result.length;
      }
    }
  function _glCompileShader(shader) {
      Module.ctx.compileShader(GL.shaders[shader]);
    }
  function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = Module.ctx.getShaderInfoLog(GL.shaders[shader]);
      // Work around a bug in Chromium which causes getShaderInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glGetShaderiv(shader, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getShaderInfoLog(GL.shaders[shader]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }
  function _glGetProgramiv(program, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getProgramInfoLog(GL.programs[program]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getProgramParameter(GL.programs[program], pname);
      }
    }
  function _glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return Module.ctx.isShader(s);
    }
  function _glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = Module.ctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }
  function _glDeleteProgram(program) {
      var program = GL.programs[program];
      Module.ctx.deleteProgram(program);
      program.name = 0;
      GL.programs[program] = null;
      GL.uniformTable[program] = null;
    }
  function _glAttachShader(program, shader) {
      Module.ctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glDetachShader(program, shader) {
      Module.ctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = Module.ctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }
  function _glLinkProgram(program) {
      Module.ctx.linkProgram(GL.programs[program]);
      GL.uniformTable[program] = {}; // uniforms no longer keep the same names after linking
    }
  function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = Module.ctx.getProgramInfoLog(GL.programs[program]);
      // Work around a bug in Chromium which causes getProgramInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glUseProgram(program) {
      Module.ctx.useProgram(program ? GL.programs[program] : null);
    }
  function _glValidateProgram(program) {
      Module.ctx.validateProgram(GL.programs[program]);
    }
  function _glIsProgram(program) {
      var program = GL.programs[program];
      if (!program) return 0;
      return Module.ctx.isProgram(program);
    }
  function _glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      Module.ctx.bindAttribLocation(GL.programs[program], index, name);
    }
  function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = Module.ctx.getFramebufferAttachmentParameter(target, attachment, pname);
      HEAP32[((params)>>2)]=params;
    }
  function _glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return Module.ctx.isFramebuffer(fb);
    }
  function _glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glGenVertexArrays(){ throw 'Legacy GL function (glGenVertexArrays) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glBegin(){ throw 'Legacy GL function (glBegin) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _gluPerspective(fov, aspect, near, far) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix[GL.immediate.currentMatrix] =
        GL.immediate.matrix.lib.mat4.perspective(fov, aspect, near, far,
                                                 GL.immediate.matrix[GL.immediate.currentMatrix]);
    }
  function _gluLookAt(ex, ey, ez, cx, cy, cz, ux, uy, uz) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix.lib.mat4.lookAt(GL.immediate.matrix[GL.immediate.currentMatrix], [ex, ey, ez],
          [cx, cy, cz], [ux, uy, uz]);
    }
  function _gluProject(objX, objY, objZ, model, proj, view, winX, winY, winZ) {
      // The algorithm for this functions comes from Mesa
      var inVec = new Float32Array(4);
      var outVec = new Float32Array(4);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((model)>>3,(model+128)>>3),
          [objX, objY, objZ, 1.0], outVec);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          outVec, inVec);
      if (inVec[3] == 0.0) {
        return 0 /* GL_FALSE */;
      }
      inVec[0] /= inVec[3];
      inVec[1] /= inVec[3];
      inVec[2] /= inVec[3];
      // Map x, y and z to range 0-1 */
      inVec[0] = inVec[0] * 0.5 + 0.5;
      inVec[1] = inVec[1] * 0.5 + 0.5;
      inVec[2] = inVec[2] * 0.5 + 0.5;
      // Map x, y to viewport
      inVec[0] = inVec[0] * HEAP32[(((view)+(8))>>2)] + HEAP32[((view)>>2)];
      inVec[1] = inVec[1] * HEAP32[(((view)+(12))>>2)] + HEAP32[(((view)+(4))>>2)];
      HEAPF64[((winX)>>3)]=inVec[0];
      HEAPF64[((winY)>>3)]=inVec[1];
      HEAPF64[((winZ)>>3)]=inVec[2];
      return 1 /* GL_TRUE */;
    }
  function _gluUnProject(winX, winY, winZ, model, proj, view, objX, objY, objZ) {
      var result = GL.immediate.matrix.lib.mat4.unproject([winX, winY, winZ],
          HEAPF64.subarray((model)>>3,(model+128)>>3),
          HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          HEAP32.subarray((view)>>2,(view+16)>>2));
      if (result === null) {
        return 0 /* GL_FALSE */;
      }
      HEAPF64[((objX)>>3)]=result[0];
      HEAPF64[((objY)>>3)]=result[1];
      HEAPF64[((objZ)>>3)]=result[2];
      return 1 /* GL_TRUE */;
    }
  function _gluOrtho2D(left, right, bottom, top) {
      _glOrtho(left, right, bottom, top, -1, 1);
    }
  function _glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      Module.ctx.vertexAttribPointer(index, size, type, normalized, stride, ptr);
    }
  function _glEnableVertexAttribArray(index) {
      Module.ctx.enableVertexAttribArray(index);
    }
  function _glDisableVertexAttribArray(index) {
      Module.ctx.disableVertexAttribArray(index);
    }
  function _glDrawElements(mode, count, type, indices) {
      Module.ctx.drawElements(mode, count, type, indices);
    }
  function _glFinish() { Module.ctx.finish() }
  function _glFlush() { Module.ctx.flush() }
  function _glClearDepth(x0) { Module.ctx.clearDepth(x0) }
  function _glClearDepthf(x0) { Module.ctx.clearDepth(x0) }
  function _glDepthFunc(x0) { Module.ctx.depthFunc(x0) }
  function _glFrontFace(x0) { Module.ctx.frontFace(x0) }
  function _glCullFace(x0) { Module.ctx.cullFace(x0) }
  function _glLineWidth(x0) { Module.ctx.lineWidth(x0) }
  function _glClearStencil(x0) { Module.ctx.clearStencil(x0) }
  function _glDepthMask(x0) { Module.ctx.depthMask(x0) }
  function _glStencilMask(x0) { Module.ctx.stencilMask(x0) }
  function _glGenerateMipmap(x0) { Module.ctx.generateMipmap(x0) }
  function _glActiveTexture(x0) { Module.ctx.activeTexture(x0) }
  function _glBlendEquation(x0) { Module.ctx.blendEquation(x0) }
  function _glSampleCoverage(x0) { Module.ctx.sampleCoverage(x0) }
  function _glIsEnabled(x0) { return Module.ctx.isEnabled(x0) }
  function _glBlendEquationSeparate(x0, x1) { Module.ctx.blendEquationSeparate(x0, x1) }
  function _glDepthRange(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glDepthRangef(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glStencilMaskSeparate(x0, x1) { Module.ctx.stencilMaskSeparate(x0, x1) }
  function _glHint(x0, x1) { Module.ctx.hint(x0, x1) }
  function _glPolygonOffset(x0, x1) { Module.ctx.polygonOffset(x0, x1) }
  function _glVertexAttrib1f(x0, x1) { Module.ctx.vertexAttrib1f(x0, x1) }
  function _glTexParameterf(x0, x1, x2) { Module.ctx.texParameterf(x0, x1, x2) }
  function _glVertexAttrib2f(x0, x1, x2) { Module.ctx.vertexAttrib2f(x0, x1, x2) }
  function _glStencilFunc(x0, x1, x2) { Module.ctx.stencilFunc(x0, x1, x2) }
  function _glStencilOp(x0, x1, x2) { Module.ctx.stencilOp(x0, x1, x2) }
  function _glScissor(x0, x1, x2, x3) { Module.ctx.scissor(x0, x1, x2, x3) }
  function _glVertexAttrib3f(x0, x1, x2, x3) { Module.ctx.vertexAttrib3f(x0, x1, x2, x3) }
  function _glColorMask(x0, x1, x2, x3) { Module.ctx.colorMask(x0, x1, x2, x3) }
  function _glBlendFuncSeparate(x0, x1, x2, x3) { Module.ctx.blendFuncSeparate(x0, x1, x2, x3) }
  function _glBlendColor(x0, x1, x2, x3) { Module.ctx.blendColor(x0, x1, x2, x3) }
  function _glStencilFuncSeparate(x0, x1, x2, x3) { Module.ctx.stencilFuncSeparate(x0, x1, x2, x3) }
  function _glStencilOpSeparate(x0, x1, x2, x3) { Module.ctx.stencilOpSeparate(x0, x1, x2, x3) }
  function _glVertexAttrib4f(x0, x1, x2, x3, x4) { Module.ctx.vertexAttrib4f(x0, x1, x2, x3, x4) }
  function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }
  function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }function _emscripten_procAddressTable(name) {
  switch(name) {
  case "glPixelStorei": return 326; break;
  case "glGetString": return 128; break;
  case "glGetIntegerv": return 8; break;
  case "glGetFloatv": return 32; break;
  case "glGetBooleanv": return 188; break;
  case "glGenTextures": return 24; break;
  case "glDeleteTextures": return 56; break;
  case "glCompressedTexImage2D": return 2; break;
  case "glCompressedTexSubImage2D": return 8; break;
  case "glTexImage2D": return 4; break;
  case "glTexSubImage2D": return 2; break;
  case "glReadPixels": return 2; break;
  case "glBindTexture": return 30; break;
  case "glGetTexParameterfv": return 48; break;
  case "glGetTexParameteriv": return 84; break;
  case "glTexParameterfv": return 40; break;
  case "glTexParameteriv": return 62; break;
  case "glIsTexture": return 48; break;
  case "glGenBuffers": return 108; break;
  case "glDeleteBuffers": return 190; break;
  case "glGetBufferParameteriv": return 50; break;
  case "glBufferData": return 14; break;
  case "glBufferSubData": return 38; break;
  case "glIsBuffer": return 54; break;
  case "glGenRenderbuffers": return 160; break;
  case "glDeleteRenderbuffers": return 64; break;
  case "glBindRenderbuffer": return 48; break;
  case "glGetRenderbufferParameteriv": return 12; break;
  case "glIsRenderbuffer": return 84; break;
  case "glGetUniformfv": return 42; break;
  case "glGetUniformiv": return 74; break;
  case "glGetUniformLocation": return 8; break;
  case "glGetVertexAttribfv": return 72; break;
  case "glGetVertexAttribiv": return 36; break;
  case "glGetVertexAttribPointerv": return 32; break;
  case "glGetActiveUniform": return 6; break;
  case "glUniform1f": return 4; break;
  case "glUniform2f": return 2; break;
  case "glUniform3f": return 2; break;
  case "glUniform4f": return 6; break;
  case "glUniform1i": return 290; break;
  case "glUniform2i": return 68; break;
  case "glUniform3i": return 40; break;
  case "glUniform4i": return 4; break;
  case "glUniform1iv": return 34; break;
  case "glUniform2iv": return 8; break;
  case "glUniform3iv": return 54; break;
  case "glUniform4iv": return 76; break;
  case "glUniform1fv": return 2; break;
  case "glUniform2fv": return 66; break;
  case "glUniform3fv": return 24; break;
  case "glUniform4fv": return 18; break;
  case "glUniformMatrix2fv": return 2; break;
  case "glUniformMatrix3fv": return 24; break;
  case "glUniformMatrix4fv": return 4; break;
  case "glBindBuffer": return 104; break;
  case "glVertexAttrib1fv": return 180; break;
  case "glVertexAttrib2fv": return 44; break;
  case "glVertexAttrib3fv": return 292; break;
  case "glVertexAttrib4fv": return 96; break;
  case "glGetAttribLocation": return 40; break;
  case "glGetActiveAttrib": return 4; break;
  case "glCreateShader": return 16; break;
  case "glDeleteShader": return 50; break;
  case "glGetAttachedShaders": return 34; break;
  case "glShaderSource": return 10; break;
  case "glGetShaderSource": return 50; break;
  case "glCompileShader": return 148; break;
  case "glGetShaderInfoLog": return 12; break;
  case "glGetShaderiv": return 38; break;
  case "glGetProgramiv": return 4; break;
  case "glIsShader": return 170; break;
  case "glCreateProgram": return 34; break;
  case "glDeleteProgram": return 120; break;
  case "glAttachShader": return 244; break;
  case "glDetachShader": return 156; break;
  case "glLinkProgram": return 66; break;
  case "glGetProgramInfoLog": return 48; break;
  case "glUseProgram": return 72; break;
  case "glValidateProgram": return 182; break;
  case "glIsProgram": return 224; break;
  case "glBindAttribLocation": return 20; break;
  case "glBindFramebuffer": return 120; break;
  case "glGenFramebuffers": return 122; break;
  case "glDeleteFramebuffers": return 258; break;
  case "glFramebufferRenderbuffer": return 22; break;
  case "glFramebufferTexture2D": return 8; break;
  case "glGetFramebufferAttachmentParameteriv": return 26; break;
  case "glIsFramebuffer": return 118; break;
  case "glVertexAttribPointer": return 18; break;
  case "glEnableVertexAttribArray": return 172; break;
  case "glDisableVertexAttribArray": return 6; break;
  case "glDrawArrays": return 28; break;
  case "glDrawElements": return 30; break;
  case "glGetError": return 30; break;
  case "glFinish": return 7408; break;
  case "glFlush": return 6900; break;
  case "glClearDepth": return 14; break;
  case "glClearDepthf": return 132; break;
  case "glDepthFunc": return 36; break;
  case "glEnable": return 128; break;
  case "glDisable": return 180; break;
  case "glFrontFace": return 24; break;
  case "glCullFace": return 58; break;
  case "glClear": return 106; break;
  case "glLineWidth": return 192; break;
  case "glClearStencil": return 2; break;
  case "glDepthMask": return 166; break;
  case "glStencilMask": return 156; break;
  case "glCheckFramebufferStatus": return 200; break;
  case "glGenerateMipmap": return 18; break;
  case "glActiveTexture": return 158; break;
  case "glBlendEquation": return 28; break;
  case "glSampleCoverage": return 190; break;
  case "glIsEnabled": return 34; break;
  case "glBlendFunc": return 306; break;
  case "glBlendEquationSeparate": return 276; break;
  case "glDepthRange": return 274; break;
  case "glDepthRangef": return 222; break;
  case "glStencilMaskSeparate": return 266; break;
  case "glHint": return 282; break;
  case "glPolygonOffset": return 200; break;
  case "glVertexAttrib1f": return 16; break;
  case "glTexParameteri": return 56; break;
  case "glTexParameterf": return 82; break;
  case "glVertexAttrib2f": return 6; break;
  case "glStencilFunc": return 58; break;
  case "glStencilOp": return 14; break;
  case "glViewport": return 8; break;
  case "glClearColor": return 20; break;
  case "glScissor": return 6; break;
  case "glVertexAttrib3f": return 18; break;
  case "glColorMask": return 36; break;
  case "glRenderbufferStorage": return 44; break;
  case "glBlendFuncSeparate": return 42; break;
  case "glBlendColor": return 16; break;
  case "glStencilFuncSeparate": return 46; break;
  case "glStencilOpSeparate": return 32; break;
  case "glVertexAttrib4f": return 6; break;
  case "glCopyTexImage2D": return 6; break;
  case "glCopyTexSubImage2D": return 4; break;
  }
  return 0;
  }function _emscripten_GetProcAddress(name) {
    name = name.replace('EXT', '').replace('ARB', '');
    switch(name) { // misc renamings
      case 'glCreateProgramObject': name = 'glCreateProgram'; break;
      case 'glUseProgramObject': name = 'glUseProgram'; break;
      case 'glCreateShaderObject': name = 'glCreateShader'; break;
      case 'glAttachObject': name = 'glAttachShader'; break;
      case 'glDetachObject': name = 'glDetachShader'; break;
    }
    var ret = _emscripten_procAddressTable(name);
    if (!ret) Module.printErr('WARNING: getProcAddress failed for ' + name);
    return ret;
  }function _eglGetProcAddress(name_) {
      return _emscripten_GetProcAddress(Pointer_stringify(name_));
    }
  function _emscripten_get_canvas_size(width, height, isFullscreen) {
      var canvas = Module['canvas'];
      HEAP32[((width)>>2)]=canvas.width;
      HEAP32[((height)>>2)]=canvas.height;
      HEAP32[((isFullscreen)>>2)]=Browser.isFullScreen ? 1 : 0;
    }
  var EGL={eglErrorCode:12288,setErrorCode:function (code) {
        EGL.eglErrorCode = code;
      },chooseConfig:function (display, attribList, config, config_size, numConfigs) { 
        if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
          EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
          return 0;
        }
        // TODO: read attribList.
        if ((!config || !config_size) && !numConfigs) {
          EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
          return 0;
        }
        if (numConfigs) {
          HEAP32[((numConfigs)>>2)]=1; // Total number of supported configs: 1.
        }
        if (config && config_size > 0) {
          HEAP32[((config)>>2)]=62002; 
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      }};function _eglBindAPI(api) {
      if (api == 0x30A0 /* EGL_OPENGL_ES_API */) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } else { // if (api == 0x30A1 /* EGL_OPENVG_API */ || api == 0x30A2 /* EGL_OPENGL_API */) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
    }
  function _eglMakeCurrent(display, draw, read, context) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      if (read != 62006 || draw != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _glutDestroyWindow(name) {
      Module.ctx = Browser.destroyContext(Module['canvas'], true, true);
      return 1;
    }function _eglDestroyContext(display, context) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglDestroySurface(display, surface) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0; 
      }
      if (surface != 62006 /* Magic ID for the only EGLSurface supported by Emscripten */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 1;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglTerminate(display) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      // TODO: Tear down EGL here. Currently a no-op since we don't need to actually do anything here for the browser.
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglGetDisplay(nativeDisplayType) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      // Note: As a 'conformant' implementation of EGL, we would prefer to init here only if the user
      //       calls this function with EGL_DEFAULT_DISPLAY. Other display IDs would be preferred to be unsupported
      //       and EGL_NO_DISPLAY returned. Uncomment the following code lines to do this.
      // Instead, an alternative route has been preferred, namely that the Emscripten EGL implementation
      // "emulates" X11, and eglGetDisplay is expected to accept/receive a pointer to an X11 Display object.
      // Therefore, be lax and allow anything to be passed in, and return the magic handle to our default EGLDisplay object.
  //    if (nativeDisplayType == 0 /* EGL_DEFAULT_DISPLAY */) {
          return 62000; // Magic ID for Emscripten 'default display'
  //    }
  //    else
  //      return 0; // EGL_NO_DISPLAY
    }
  function _eglInitialize(display, majorVersion, minorVersion) {
      if (display == 62000 /* Magic ID for Emscripten 'default display' */) {
        if (majorVersion) {
          HEAP32[((majorVersion)>>2)]=1; // Advertise EGL Major version: '1'
        }
        if (minorVersion) {
          HEAP32[((minorVersion)>>2)]=4; // Advertise EGL Minor version: '4'
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } 
      else {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
    }
  function _eglChooseConfig(display, attrib_list, configs, config_size, numConfigs) { 
      return EGL.chooseConfig(display, attrib_list, configs, config_size, numConfigs);
    }
  function _glutCreateWindow(name) {
      Module.ctx = Browser.createContext(Module['canvas'], true, true);
      return Module.ctx ? 1 /* a new GLUT window ID for the created context */ : 0 /* failure */;
    }function _eglCreateContext(display, config, hmm, contextAttribs) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      EGL.windowID = _glutCreateWindow();
      if (EGL.windowID != 0) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 62004; // Magic ID for Emscripten EGLContext
      } else {
        EGL.setErrorCode(0x3009 /* EGL_BAD_MATCH */); // By the EGL 1.4 spec, an implementation that does not support GLES2 (WebGL in this case), this error code is set.
        return 0; /* EGL_NO_CONTEXT */
      }
    }
  function _eglCreateWindowSurface(display, config, win, attrib_list) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      // TODO: Examine attrib_list! Parameters that can be present there are:
      // - EGL_RENDER_BUFFER (must be EGL_BACK_BUFFER)
      // - EGL_VG_COLORSPACE (can't be set)
      // - EGL_VG_ALPHA_FORMAT (can't be set)
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 62006; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglQuerySurface(display, surface, attribute, value) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (surface != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
      case 0x3028: // EGL_CONFIG_ID
        HEAP32[((value)>>2)]=62002;
          return 1;
      case 0x3058: // EGL_LARGEST_PBUFFER
        // Odd EGL API: If surface is not a pbuffer surface, 'value' should not be written to. It's not specified as an error, so true should(?) be returned.
        // Existing Android implementation seems to do so at least.
        return 1;
      case 0x3057: // EGL_WIDTH
        HEAP32[((value)>>2)]=Module.canvas.width;
        return 1;
      case 0x3056: // EGL_HEIGHT
        HEAP32[((value)>>2)]=Module.canvas.height;
        return 1;
      case 0x3090: // EGL_HORIZONTAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3091: // EGL_VERTICAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3092: // EGL_PIXEL_ASPECT_RATIO
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3086: // EGL_RENDER_BUFFER
        // The main surface is bound to the visible canvas window - it's always backbuffered. 
        // Alternative to EGL_BACK_BUFFER would be EGL_SINGLE_BUFFER.
        HEAP32[((value)>>2)]=0x3084; 
        return 1;
      case 0x3099: // EGL_MULTISAMPLE_RESOLVE
        HEAP32[((value)>>2)]=0x309A; 
        return 1;
      case 0x3093: // EGL_SWAP_BEHAVIOR
        // The two possibilities are EGL_BUFFER_PRESERVED and EGL_BUFFER_DESTROYED. Slightly unsure which is the
        // case for browser environment, but advertise the 'weaker' behavior to be sure.
        HEAP32[((value)>>2)]=0x3095;
        return 1;
      case 0x3080: // EGL_TEXTURE_FORMAT
      case 0x3081: // EGL_TEXTURE_TARGET
      case 0x3082: // EGL_MIPMAP_TEXTURE
      case 0x3083: // EGL_MIPMAP_LEVEL
        // This is a window surface, not a pbuffer surface. Spec:
        // "Querying EGL_TEXTURE_FORMAT, EGL_TEXTURE_TARGET, EGL_MIPMAP_TEXTURE, or EGL_MIPMAP_LEVEL for a non-pbuffer surface is not an error, but value is not modified."
        // So pass-through.
        return 1;
      default:
        EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
        return 0;
      }
    }
  function _rand() {
      return Math.floor(Math.random()*0x80000000);
    }
  function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }
  function _toupper(chr) {
      if (chr >= 97 && chr <= 122) {
        return chr - 97 + 65;
      } else {
        return chr;
      }
    }
  function _llvm_bswap_i16(x) {
      return ((x&0xff)<<8) | ((x>>8)&0xff);
    }
  Module["_strncpy"] = _strncpy;
  function __isFloat(text) {
      return !!(/^[+-]?[0-9]*\.?[0-9]+([eE][+-]?[0-9]+)?$/.exec(text));
    }function __scanString(format, get, unget, varargs) {
      if (!__scanString.whiteSpace) {
        __scanString.whiteSpace = {};
        __scanString.whiteSpace[32] = 1;
        __scanString.whiteSpace[9] = 1;
        __scanString.whiteSpace[10] = 1;
        __scanString.whiteSpace[11] = 1;
        __scanString.whiteSpace[12] = 1;
        __scanString.whiteSpace[13] = 1;
        __scanString.whiteSpace[' '] = 1;
        __scanString.whiteSpace['\t'] = 1;
        __scanString.whiteSpace['\n'] = 1;
        __scanString.whiteSpace['\v'] = 1;
        __scanString.whiteSpace['\f'] = 1;
        __scanString.whiteSpace['\r'] = 1;
      }
      // Supports %x, %4x, %d.%d, %lld, %s, %f, %lf.
      // TODO: Support all format specifiers.
      format = Pointer_stringify(format);
      var soFar = 0;
      if (format.indexOf('%n') >= 0) {
        // need to track soFar
        var _get = get;
        get = function() {
          soFar++;
          return _get();
        }
        var _unget = unget;
        unget = function() {
          soFar--;
          return _unget();
        }
      }
      var formatIndex = 0;
      var argsi = 0;
      var fields = 0;
      var argIndex = 0;
      var next;
      mainLoop:
      for (var formatIndex = 0; formatIndex < format.length;) {
        if (format[formatIndex] === '%' && format[formatIndex+1] == 'n') {
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          HEAP32[((argPtr)>>2)]=soFar;
          formatIndex += 2;
          continue;
        }
        if (format[formatIndex] === '%') {
          var nextC = format.indexOf('c', formatIndex+1);
          if (nextC > 0) {
            var maxx = 1;
            if (nextC > formatIndex+1) {
              var sub = format.substring(formatIndex+1, nextC)
              maxx = parseInt(sub);
              if (maxx != sub) maxx = 0;
            }
            if (maxx) {
              var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
              argIndex += Runtime.getAlignSize('void*', null, true);
              fields++;
              for (var i = 0; i < maxx; i++) {
                next = get();
                HEAP8[((argPtr++)|0)]=next;
              }
              formatIndex += nextC - formatIndex + 1;
              continue;
            }
          }
        }
        // remove whitespace
        while (1) {
          next = get();
          if (next == 0) return fields;
          if (!(next in __scanString.whiteSpace)) break;
        }
        unget();
        if (format[formatIndex] === '%') {
          formatIndex++;
          var suppressAssignment = false;
          if (format[formatIndex] == '*') {
            suppressAssignment = true;
            formatIndex++;
          }
          var maxSpecifierStart = formatIndex;
          while (format[formatIndex].charCodeAt(0) >= 48 &&
                 format[formatIndex].charCodeAt(0) <= 57) {
            formatIndex++;
          }
          var max_;
          if (formatIndex != maxSpecifierStart) {
            max_ = parseInt(format.slice(maxSpecifierStart, formatIndex), 10);
          }
          var long_ = false;
          var half = false;
          var longLong = false;
          if (format[formatIndex] == 'l') {
            long_ = true;
            formatIndex++;
            if (format[formatIndex] == 'l') {
              longLong = true;
              formatIndex++;
            }
          } else if (format[formatIndex] == 'h') {
            half = true;
            formatIndex++;
          }
          var type = format[formatIndex];
          formatIndex++;
          var curr = 0;
          var buffer = [];
          // Read characters according to the format. floats are trickier, they may be in an unfloat state in the middle, then be a valid float later
          if (type == 'f' || type == 'e' || type == 'g' ||
              type == 'F' || type == 'E' || type == 'G') {
            var last = 0;
            next = get();
            while (next > 0) {
              buffer.push(String.fromCharCode(next));
              if (__isFloat(buffer.join(''))) {
                last = buffer.length;
              }
              next = get();
            }
            for (var i = 0; i < buffer.length - last + 1; i++) {
              unget();
            }
            buffer.length = last;
          } else {
            next = get();
            var first = true;
            while ((curr < max_ || isNaN(max_)) && next > 0) {
              if (!(next in __scanString.whiteSpace) && // stop on whitespace
                  (type == 's' ||
                   ((type === 'd' || type == 'u' || type == 'i') && ((next >= 48 && next <= 57) ||
                                                                     (first && next == 45))) ||
                   ((type === 'x' || type === 'X') && (next >= 48 && next <= 57 ||
                                     next >= 97 && next <= 102 ||
                                     next >= 65 && next <= 70))) &&
                  (formatIndex >= format.length || next !== format[formatIndex].charCodeAt(0))) { // Stop when we read something that is coming up
                buffer.push(String.fromCharCode(next));
                next = get();
                curr++;
                first = false;
              } else {
                break;
              }
            }
            unget();
          }
          if (buffer.length === 0) return 0;  // Failure.
          if (suppressAssignment) continue;
          var text = buffer.join('');
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          switch (type) {
            case 'd': case 'u': case 'i':
              if (half) {
                HEAP16[((argPtr)>>1)]=parseInt(text, 10);
              } else if (longLong) {
                (tempI64 = [parseInt(text, 10)>>>0,(tempDouble=parseInt(text, 10),(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)],HEAP32[((argPtr)>>2)]=tempI64[0],HEAP32[(((argPtr)+(4))>>2)]=tempI64[1]);
              } else {
                HEAP32[((argPtr)>>2)]=parseInt(text, 10);
              }
              break;
            case 'X':
            case 'x':
              HEAP32[((argPtr)>>2)]=parseInt(text, 16)
              break;
            case 'F':
            case 'f':
            case 'E':
            case 'e':
            case 'G':
            case 'g':
            case 'E':
              // fallthrough intended
              if (long_) {
                HEAPF64[((argPtr)>>3)]=parseFloat(text)
              } else {
                HEAPF32[((argPtr)>>2)]=parseFloat(text)
              }
              break;
            case 's':
              var array = intArrayFromString(text);
              for (var j = 0; j < array.length; j++) {
                HEAP8[(((argPtr)+(j))|0)]=array[j]
              }
              break;
          }
          fields++;
        } else if (format[formatIndex] in __scanString.whiteSpace) {
          next = get();
          while (next in __scanString.whiteSpace) {
            if (next <= 0) break mainLoop;  // End of input.
            next = get();
          }
          unget(next);
          formatIndex++;
        } else {
          // Not a specifier.
          next = get();
          if (format[formatIndex].charCodeAt(0) !== next) {
            unget(next);
            break mainLoop;
          }
          formatIndex++;
        }
      }
      return fields;
    }function _sscanf(s, format, varargs) {
      // int sscanf(const char *restrict s, const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var index = 0;
      var get = function() { return HEAP8[(((s)+(index++))|0)]; };
      var unget = function() { index--; };
      return __scanString(format, get, unget, varargs);
    }
  var _llvm_pow_f64=Math.pow;
  var _cos=Math.cos;
  var _exp=Math.exp;
  var _floor=Math.floor;
  var _log=Math.log;
  function _exp2(x) {
      return Math.pow(2, x);
    }
  function _abort() {
      Module['abort']();
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
        case 10: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
  function _memchr(ptr, chr, num) {
      chr = unSign(chr);
      for (var i = 0; i < num; i++) {
        if (HEAP8[(ptr)] == chr) return ptr;
        ptr++;
      }
      return 0;
    }
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
___buildEnvironment(ENV);
Module["requestFullScreen"] = function(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function() { Browser.getUserMedia() }
GL.init()
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true; // seal the static portion of memory
STACK_MAX = STACK_BASE + 5242880;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
assert(DYNAMIC_BASE < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);
var Math_min = Math.min;
function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vif(index,a1,a2) {
  try {
    Module["dynCall_vif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viffff(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viffff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_if(index,a1) {
  try {
    return Module["dynCall_if"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiif(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiif"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vifff(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_vifff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_fii(index,a1,a2) {
  try {
    return Module["dynCall_fii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiif(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viff(index,a1,a2,a3) {
  try {
    Module["dynCall_viff"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iif(index,a1,a2) {
  try {
    return Module["dynCall_iif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ff(index,a1) {
  try {
    return Module["dynCall_ff"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_f(index) {
  try {
    return Module["dynCall_f"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env._stdout|0;var p=env._stderr|0;var q=+env.NaN;var r=+env.Infinity;var s=0;var t=0;var u=0;var v=0;var w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0.0;var F=0;var G=0;var H=0;var I=0;var J=0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=global.Math.floor;var Q=global.Math.abs;var R=global.Math.sqrt;var S=global.Math.pow;var T=global.Math.cos;var U=global.Math.sin;var V=global.Math.tan;var W=global.Math.acos;var X=global.Math.asin;var Y=global.Math.atan;var Z=global.Math.atan2;var _=global.Math.exp;var $=global.Math.log;var aa=global.Math.ceil;var ab=global.Math.imul;var ac=env.abort;var ad=env.assert;var ae=env.asmPrintInt;var af=env.asmPrintFloat;var ag=env.min;var ah=env.invoke_iiiiiiii;var ai=env.invoke_vif;var aj=env.invoke_viiiii;var ak=env.invoke_vi;var al=env.invoke_vii;var am=env.invoke_iiiiiii;var an=env.invoke_ii;var ao=env.invoke_viiiiiiiiiii;var ap=env.invoke_viffff;var aq=env.invoke_if;var ar=env.invoke_iiii;var as=env.invoke_viiiiif;var at=env.invoke_viiiiiiii;var au=env.invoke_vifff;var av=env.invoke_fii;var aw=env.invoke_iiif;var ax=env.invoke_viff;var ay=env.invoke_iif;var az=env.invoke_viiiiiii;var aA=env.invoke_ff;var aB=env.invoke_viiiiiiiii;var aC=env.invoke_iii;var aD=env.invoke_viiiiii;var aE=env.invoke_f;var aF=env.invoke_i;var aG=env.invoke_iiiii;var aH=env.invoke_viii;var aI=env.invoke_v;var aJ=env.invoke_viiii;var aK=env._llvm_lifetime_end;var aL=env._lseek;var aM=env._RWebInputDestroy;var aN=env._RWebAudioStop;var aO=env._glClearColor;var aP=env._sysconf;var aQ=env._rand;var aR=env.__scanString;var aS=env._fclose;var aT=env._RWebAudioInit;var aU=env._glGetVertexAttribPointerv;var aV=env._glGetRenderbufferParameteriv;var aW=env._eglDestroySurface;var aX=env._strtoul;var aY=env._strtoull;var aZ=env._glBindTexture;var a_=env._fflush;var a$=env._exp;var a0=env._glGetUniformiv;var a1=env._fabsf;var a2=env._strtol;var a3=env._fputc;var a4=env._glGetString;var a5=env._fwrite;var a6=env._gluUnProject;var a7=env._send;var a8=env._fputs;var a9=env._glLineWidth;var ba=env._glUniform2fv;var bb=env._emscripten_get_now;var bc=env._eglCreateContext;var bd=env._glBindAttribLocation;var be=env._glCompileShader;var bf=env._isspace;var bg=env._localtime;var bh=env._glDeleteTextures;var bi=env._eglBindAPI;var bj=env._glCompressedTexImage2D;var bk=env._glStencilFuncSeparate;var bl=env._read;var bm=env._RWebAudioBufferSize;var bn=env._glDeleteShader;var bo=env._RWebInputInit;var bp=env._glClearDepthf;var bq=env._glUniform4iv;var br=env._glGetTexParameteriv;var bs=env._glClearStencil;var bt=env._glLoadIdentity;var bu=env._glUniform1fv;var bv=env._llvm_pow_f64;var bw=env._glIsShader;var bx=env._strstr;var by=env._glSampleCoverage;var bz=env._fsync;var bA=env._glGenTextures;var bB=env._glDepthFunc;var bC=env._remove;var bD=env._glCompressedTexSubImage2D;var bE=env._glUniform1f;var bF=env._opendir;var bG=env._glGetTexParameterfv;var bH=env._RWebAudioWrite;var bI=env._glStencilMaskSeparate;var bJ=env._glCreateShader;var bK=env._round;var bL=env._glUniform1i;var bM=env._strncmp;var bN=env._cosf;var bO=env._glDeleteRenderbuffers;var bP=env._glLinkProgram;var bQ=env._snprintf;var bR=env._glUniform2i;var bS=env._fgetc;var bT=env._glStencilFunc;var bU=env._glShaderSource;var bV=env._readdir;var bW=env._glVertexAttribPointer;var bX=env._glHint;var bY=env._glBindBuffer;var bZ=env._glVertexPointer;var b_=env._fgets;var b$=env._close;var b0=env._getgid;var b1=env._glGetAttachedShaders;var b2=env._glBindFramebuffer;var b3=env._glIsFramebuffer;var b4=env._strchr;var b5=env._llvm_bswap_i16;var b6=env._glUniform4fv;var b7=env._abort;var b8=env.___setErrNo;var b9=env._glDeleteFramebuffers;var ca=env._eglTerminate;var cb=env._glGetVertexAttribfv;var cc=env._glIsBuffer;var cd=env._emscripten_GetProcAddress;var ce=env._eglGetProcAddress;var cf=env._ftell;var cg=env._glDeleteProgram;var ch=env._exit;var ci=env._sprintf;var cj=env._glRenderbufferStorage;var ck=env._strrchr;var cl=env._glAttachShader;var cm=env._RWebInputPoll;var cn=env._glUniform3i;var co=env._glIsProgram;var cp=env._glCheckFramebufferStatus;var cq=env.__isLeapYear;var cr=env._gluProject;var cs=env._llvm_uadd_with_overflow_i32;var ct=env._localtime_r;var cu=env._glUniform3f;var cv=env._glGetBufferParameteriv;var cw=env._glFlush;var cx=env._glBlendEquationSeparate;var cy=env._emscripten_get_canvas_size;var cz=env._glCopyTexImage2D;var cA=env._glDrawElements;var cB=env._glColorMask;var cC=env._sinf;var cD=env._gluLookAt;var cE=env._eglInitialize;var cF=env._recv;var cG=env.__parseInt64;var cH=env._glVertexAttrib1fv;var cI=env._glUniform2iv;var cJ=env._cos;var cK=env._putchar;var cL=env._glUniform1iv;var cM=env._glActiveTexture;var cN=env._glMatrixMode;var cO=env._glBlendEquation;var cP=env._strcmp;var cQ=env._glVertexAttrib1f;var cR=env._RWebAudioWriteAvail;var cS=env._glGenerateMipmap;var cT=env._memchr;var cU=env._glDetachShader;var cV=env._glGetShaderiv;var cW=env.__exit;var cX=env._strftime;var cY=env._glVertexAttrib3f;var cZ=env._glGenRenderbuffers;var c_=env._tzset;var c$=env._RWebAudioSampleRate;var c0=env._glGetShaderPrecisionFormat;var c1=env._glVertexAttrib4fv;var c2=env._glDepthMask;var c3=env._glDisableVertexAttribArray;var c4=env._glBegin;var c5=env._toupper;var c6=env._printf;var c7=env._glBindRenderbuffer;var c8=env._pread;var c9=env._fopen;var da=env._open;var db=env._glDrawArrays;var dc=env._usleep;var dd=env._llvm_pow_f32;var de=env.__arraySum;var df=env._glCopyTexSubImage2D;var dg=env._glDisable;var dh=env._puts;var di=env._glUniform4i;var dj=env._exp2;var dk=env._nanosleep;var dl=env._glClear;var dm=env._qsort;var dn=env._glUniform2f;var dp=env._eglDestroyContext;var dq=env._isalpha;var dr=env._glEnableVertexAttribArray;var ds=env._rmdir;var dt=env._glUniform3fv;var du=env._glStencilOp;var dv=env._strdup;var dw=env._glDepthRange;var dx=env._glUniform4f;var dy=env._glFramebufferTexture2D;var dz=env._glUniformMatrix2fv;var dA=env._glGenVertexArrays;var dB=env._eglMakeCurrent;var dC=env._glUniformMatrix3fv;var dD=env._glutCreateWindow;var dE=env._glBufferData;var dF=env._glBlendColor;var dG=env._glGetUniformLocation;var dH=env._glIsEnabled;var dI=env.__formatString;var dJ=env._getenv;var dK=env._glGetError;var dL=env._glGetVertexAttribiv;var dM=env._glTexParameteriv;var dN=env._glGetProgramiv;var dO=env._glVertexAttrib3fv;var dP=env._glGetFloatv;var dQ=env._glBufferSubData;var dR=env._glUniform3iv;var dS=env._glReadPixels;var dT=env._glGenFramebuffers;var dU=env._glFramebufferRenderbuffer;var dV=env._emscripten_procAddressTable;var dW=env._ceil;var dX=env.___errno_location;var dY=env._glGetIntegerv;var dZ=env._RWebAudioFree;var d_=env._llvm_lifetime_start;var d$=env._glIsRenderbuffer;var d0=env._llvm_bswap_i32;var d1=env._sbrk;var d2=env.__parseInt;var d3=env._RWebAudioSetNonblockState;var d4=env._glVertexAttrib2fv;var d5=env._glGetFramebufferAttachmentParameteriv;var d6=env._glUseProgram;var d7=env._sscanf;var d8=env._glTexImage2D;var d9=env._glGetProgramInfoLog;var ea=env._glTexSubImage2D;var eb=env._glStencilMask;var ec=env._fread;var ed=env._glStencilOpSeparate;var ee=env._strtok_r;var ef=env._glGetShaderInfoLog;var eg=env._glIsTexture;var eh=env._eglCreateWindowSurface;var ei=env._fprintf;var ej=env._glGetShaderSource;var ek=env._gluPerspective;var el=env._eglChooseConfig;var em=env.___buildEnvironment;var en=env._feof;var eo=env.__addDays;var ep=env._glScissor;var eq=env._glEnable;var er=env._glBlendFuncSeparate;var es=env._floor;var et=env.__reallyNegative;var eu=env._glGetActiveAttrib;var ev=env._fseek;var ew=env._sqrt;var ex=env._glTexParameterfv;var ey=env._write;var ez=env._glGenBuffers;var eA=env._glFinish;var eB=env._glGetAttribLocation;var eC=env._glVertexAttrib4f;var eD=env._rewind;var eE=env._sin;var eF=env._glBlendFunc;var eG=env._glCreateProgram;var eH=env._realpath;var eI=env._stat;var eJ=env._longjmp;var eK=env._glViewport;var eL=env._emscripten_set_main_loop;var eM=env._time;var eN=env._glVertexAttrib2f;var eO=env._closedir;var eP=env._isgraph;var eQ=env._readlink;var eR=env._log;var eS=env._glGetUniformfv;var eT=env._unlink;var eU=env._gluOrtho2D;var eV=env._glUniformMatrix4fv;var eW=env._glClearDepth;var eX=env._glGetActiveUniform;var eY=env._glutDestroyWindow;var eZ=env._pwrite;var e_=env.__isFloat;var e$=env._fabs;var e0=env._glTexParameterf;var e1=env._RWebAudioStart;var e2=env._glTexParameteri;var e3=env._glFrontFace;var e4=env._glCullFace;var e5=env._glDepthRangef;var e6=env._glDeleteBuffers;var e7=env._eglGetDisplay;var e8=env._emscripten_set_canvas_size;var e9=env._glGetBooleanv;var fa=env._eglQuerySurface;var fb=env._glPixelStorei;var fc=env._readdir_r;var fd=env._glValidateProgram;var fe=env._glPolygonOffset;
// EMSCRIPTEN_START_FUNCS
function oy(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=c[3579678]|0;if(g>>>0<f>>>0){h=g}else{return}L19276:while(1){do{if((a[14318709]|0)==0){i=h}else{if((a[14318702]|0)==0|(a[14318710]|0)!=0){i=h;break}if((a[14318704]|0)!=0){a[14318704]=0;b[7159324]=(b[7159324]|0)+1&65535}a[14318703]=0;a[14318702]=0;do{if((a[14318705]|0)==1){b[7159326]=(b[7159326]|0)-2&65535;g=c[3579663]|0;fj[c[186764]&511](g,a[14318648]|0);fj[c[186764]&511](g+1&65535,a[14318649]|0);c[3579662]=56;g=(c[3579678]|0)+195|0;c[3579678]=g;j=56;k=g}else{g=fl[c[3579680]&255](0)|0;if((a[14318705]|0)==2){l=d[14318706]<<8|g&255;b[7159326]=(b[7159326]|0)-2&65535;m=c[3579663]|0;fj[c[186764]&511](m,a[14318648]|0);fj[c[186764]&511](m+1&65535,a[14318649]|0);a[14318648]=fl[c[186832]&255](l)|0;a[14318649]=fl[c[186832]&255](l+1&65535)|0;l=(c[3579678]|0)+285|0;c[3579678]=l;j=c[3579662]&65535;k=l;break}l=g&16711680;if((l|0)==13434880){b[7159326]=(b[7159326]|0)-2&65535;m=c[3579663]|0;fj[c[186764]&511](m,a[14318648]|0);fj[c[186764]&511](m+1&65535,a[14318649]|0);c[3579662]=g&65535;m=(c[3579678]|0)+285|0;c[3579678]=m;j=g&65535;k=m;break}else if((l|0)==12779520){c[3579662]=g&65535;l=(c[3579678]|0)+180|0;c[3579678]=l;j=g&65535;k=l;break}else{b[7159326]=(b[7159326]|0)-2&65535;l=c[3579663]|0;fj[c[186764]&511](l,a[14318648]|0);fj[c[186764]&511](l+1&65535,a[14318649]|0);l=g&56;c[3579662]=l;g=(c[3579678]|0)+195|0;c[3579678]=g;j=l&65535;k=g;break}}}while(0);b[7159340]=j;if(k>>>0<f>>>0){i=k}else{n=14654;break L19276}}}while(0);a[14318710]=0;g=a[14318700]|0;a[14318700]=g+1&255;l=c[3579662]|0;m=l&65535;o=m+1&65535;b[7159324]=o;p=d[(c[747336+(l>>>10<<2)>>2]|0)+(l&1023)|0]|0;l=(e[(c[3118612]|0)+(p<<1)>>1]|0)+i|0;c[3579678]=l;q=o&255;L19296:do{switch(p|0){case 53:{o=c[186764]|0;r=e[7159334]|0;s=(fl[c[186832]&255](r)|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(s&255)|0];fj[o&511](r,s);break};case 54:{s=c[186764]|0;r=e[7159334]|0;o=c[3579662]|0;b[7159324]=(o&65535)+1&65535;fj[s&511](r,a[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0]|0);break};case 5:{o=(a[14318661|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(o&255)|0];a[14318661|0]=o;break};case 40:{if((a[14318656]&64)==0){b[7159324]=m+2&65535;break L19296}else{o=c[3579662]|0;r=(o&65535)+1&65535;b[7159324]=r;s=(a[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0]|0)+r&65535;b[7159324]=s;b[7159340]=s;c[3579678]=l+75;break L19296}break};case 41:{s=c[3579667]|0;b[7159340]=s+1&65535;r=s>>>7;a[14318656]=(s>>>15&1|r&16|r&40|a[14318656]&196)&255;b[7159334]=s<<1&65535;break};case 42:{s=c[3579662]|0;b[7159324]=(s&65535)+2&65535;r=s+1|0;o=d[(c[747336+((r>>>10&63)<<2)>>2]|0)+(r&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];c[3646042]=o;a[14318668]=fl[c[186832]&255](o)|0;a[14318669|0]=fl[c[186832]&255](o+1&65535)|0;b[7159340]=(c[3646042]|0)+1&65535;break};case 142:{o=c[3579664]|0;s=o&65280;r=o&1;o=(s>>>8)+r+((fl[c[186832]&255](e[7159334]|0)|0)&255)|0;a[14318656]=a[14450848+(r<<16|s|o&255)|0]|0;a[14318657|0]=o&255;break};case 143:{o=c[3579664]|0;s=o&65280;r=o&1;o=(d[14318657|0]|0)+r+(s>>>8)|0;a[14318656]=a[14450848+(r<<16|s|o&255)|0]|0;a[14318657|0]=o&255;break};case 144:{o=c[3579664]&65280;s=(o>>>8)-(d[14318661|0]|0)|0;a[14318656]=a[14319776+(s&255|o)|0]|0;a[14318657|0]=s&255;break};case 49:{s=c[3579662]|0;b[7159324]=(s&65535)+2&65535;o=s+1|0;b[7159326]=d[(c[747336+((o>>>10&63)<<2)>>2]|0)+(o&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];break};case 50:{s=c[3579662]|0;b[7159324]=(s&65535)+2&65535;o=s+1|0;r=d[(c[747336+((o>>>10&63)<<2)>>2]|0)+(o&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];c[3646042]=r;fj[c[186764]&511](r,a[14318657|0]|0);a[14318680]=(c[3646042]|0)+1&255;a[14318681|0]=a[14318657|0]|0;break};case 48:{if((a[14318656]&1)==0){r=c[3579662]|0;s=(r&65535)+1&65535;b[7159324]=s;o=(a[(c[747336+(r>>>10<<2)>>2]|0)+(r&1023)|0]|0)+s&65535;b[7159324]=o;b[7159340]=o;c[3579678]=l+75;break L19296}else{b[7159324]=m+2&65535;break L19296}break};case 51:{b[7159326]=(b[7159326]|0)+1&65535;break};case 52:{o=c[186764]|0;s=e[7159334]|0;r=(fl[c[186832]&255](s)|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(r&255)|0];fj[o&511](s,r);break};case 22:{r=c[3579662]|0;b[7159324]=(r&65535)+1&65535;a[14318665|0]=a[(c[747336+(r>>>10<<2)>>2]|0)+(r&1023)|0]|0;break};case 88:{a[14318664]=a[14318661|0]|0;break};case 89:{a[14318664]=a[14318660]|0;break};case 90:{a[14318664]=a[14318665|0]|0;break};case 92:{a[14318664]=a[14318669|0]|0;break};case 93:{a[14318664]=a[14318668]|0;break};case 94:{a[14318664]=fl[c[186832]&255](e[7159334]|0)|0;break};case 95:{a[14318664]=a[14318657|0]|0;break};case 129:{r=c[3579664]&65280;s=(r>>>8)+(d[14318660]|0)|0;a[14318656]=a[14450848+(s&255|r)|0]|0;a[14318657|0]=s&255;break};case 130:{s=c[3579664]&65280;r=(s>>>8)+(d[14318665|0]|0)|0;a[14318656]=a[14450848+(r&255|s)|0]|0;a[14318657|0]=r&255;break};case 131:{r=c[3579664]&65280;s=(r>>>8)+(d[14318664]|0)|0;a[14318656]=a[14450848+(s&255|r)|0]|0;a[14318657|0]=s&255;break};case 132:{s=c[3579664]&65280;r=(s>>>8)+(d[14318669|0]|0)|0;a[14318656]=a[14450848+(r&255|s)|0]|0;a[14318657|0]=r&255;break};case 67:{a[14318661|0]=a[14318664]|0;break};case 84:{a[14318665|0]=a[14318669|0]|0;break};case 85:{a[14318665|0]=a[14318668]|0;break};case 86:{a[14318665|0]=fl[c[186832]&255](e[7159334]|0)|0;break};case 87:{a[14318665|0]=a[14318657|0]|0;break};case 18:{fj[c[186764]&511](e[7159332]|0,a[14318657|0]|0);a[14318680]=(b[7159332]&255)+1&255;a[14318681|0]=a[14318657|0]|0;break};case 9:{r=c[3579667]|0;s=c[3579665]|0;o=s+r|0;b[7159340]=r+1&65535;a[14318656]=(o>>>16&1|a[14318656]&196|o>>>8&40|(s^r^o)>>>8&16)&255;b[7159334]=o&65535;break};case 203:{a[14318700]=g+2&255;o=c[3579662]|0;b[7159324]=(o&65535)+1&65535;r=d[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0]|0;c[3579678]=(e[(c[3118610]|0)+(r<<1)>>1]|0)+l;fG[c[735448+(r<<2)>>2]&16383]();break};case 204:{r=(a[14318656]&64)==0;o=c[3579662]|0;s=(o&65535)+2&65535;b[7159324]=s;t=o+1|0;u=d[(c[747336+((t>>>10&63)<<2)>>2]|0)+(t&1023)|0]<<8|d[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0];if(r){b[7159340]=u&65535;break L19296}else{c[3646042]=u;b[7159340]=u&65535;b[7159326]=(b[7159326]|0)-2&65535;u=c[3579663]|0;fj[c[186764]&511](u,s&255);fj[c[186764]&511](u+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;break L19296}break};case 205:{u=c[3579662]|0;s=(u&65535)+2&65535;b[7159324]=s;r=u+1|0;o=d[(c[747336+((r>>>10&63)<<2)>>2]|0)+(r&1023)|0]<<8|d[(c[747336+(u>>>10<<2)>>2]|0)+(u&1023)|0];c[3646042]=o;b[7159340]=o&65535;b[7159326]=(b[7159326]|0)-2&65535;o=c[3579663]|0;fj[c[186764]&511](o,s&255);fj[c[186764]&511](o+1&65535,a[14318649]|0);c[3579662]=c[3646042];break};case 206:{o=c[3579664]|0;s=o&65280;u=o&1;o=c[3579662]|0;b[7159324]=(o&65535)+1&65535;r=(s>>>8)+u+(d[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0]|0)|0;a[14318656]=a[14450848+(u<<16|s|r&255)|0]|0;a[14318657|0]=r&255;break};case 207:{b[7159326]=(b[7159326]|0)-2&65535;r=c[3579663]|0;fj[c[186764]&511](r,q);fj[c[186764]&511](r+1&65535,a[14318649]|0);c[3579662]=8;b[7159340]=8;break};case 208:{if((a[14318656]&1)!=0){break L19296}r=c[3579663]|0;a[14318648]=fl[c[186832]&255](r)|0;a[14318649]=fl[c[186832]&255](r+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;break};case 227:{r=c[3579663]|0;s=fl[c[186832]&255](r)|0;u=fl[c[186832]&255](r+1&65535)|0;r=c[3579663]|0;fj[c[186764]&511](r,a[14318668]|0);fj[c[186764]&511](r+1&65535,a[14318669|0]|0);r=(u&255)<<8|s&255;c[3579667]=r;b[7159340]=r&65535;break};case 228:{r=(a[14318656]&4)==0;s=c[3579662]|0;u=(s&65535)+2&65535;b[7159324]=u;o=s+1|0;t=d[(c[747336+((o>>>10&63)<<2)>>2]|0)+(o&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];if(r){c[3646042]=t;b[7159340]=t&65535;b[7159326]=(b[7159326]|0)-2&65535;r=c[3579663]|0;fj[c[186764]&511](r,u&255);fj[c[186764]&511](r+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;break L19296}else{b[7159340]=t&65535;break L19296}break};case 229:{b[7159326]=(b[7159326]|0)-2&65535;t=c[3579663]|0;fj[c[186764]&511](t,a[14318668]|0);fj[c[186764]&511](t+1&65535,a[14318669|0]|0);break};case 32:{if((a[14318656]&64)==0){t=c[3579662]|0;r=(t&65535)+1&65535;b[7159324]=r;u=(a[(c[747336+(t>>>10<<2)>>2]|0)+(t&1023)|0]|0)+r&65535;b[7159324]=u;b[7159340]=u;c[3579678]=l+75;break L19296}else{b[7159324]=m+2&65535;break L19296}break};case 150:{u=c[3579664]&65280;r=(u>>>8)-((fl[c[186832]&255](e[7159334]|0)|0)&255)|0;a[14318656]=a[14319776+(r&255|u)|0]|0;a[14318657|0]=r&255;break};case 151:{r=c[3579664]&65280;u=(r>>>8)-(d[14318657|0]|0)|0;a[14318656]=a[14319776+(u&255|r)|0]|0;a[14318657|0]=u&255;break};case 152:{u=c[3579664]|0;r=u&65280;t=u&1;u=(r>>>8)-(d[14318661|0]|0)-t|0;a[14318656]=a[14319776+(t<<16|r|u&255)|0]|0;a[14318657|0]=u&255;break};case 153:{u=c[3579664]|0;r=u&65280;t=u&1;u=(r>>>8)-(d[14318660]|0)-t|0;a[14318656]=a[14319776+(t<<16|r|u&255)|0]|0;a[14318657|0]=u&255;break};case 34:{u=c[3579662]|0;b[7159324]=(u&65535)+2&65535;r=u+1|0;t=d[(c[747336+((r>>>10&63)<<2)>>2]|0)+(r&1023)|0]<<8|d[(c[747336+(u>>>10<<2)>>2]|0)+(u&1023)|0];c[3646042]=t;fj[c[186764]&511](t,a[14318668]|0);fj[c[186764]&511](t+1&65535,a[14318669|0]|0);b[7159340]=(c[3646042]|0)+1&65535;break};case 10:{a[14318657|0]=fl[c[186832]&255](e[7159330]|0)|0;b[7159340]=(b[7159330]|0)+1&65535;break};case 11:{b[7159330]=(b[7159330]|0)-1&65535;break};case 27:{b[7159332]=(b[7159332]|0)-1&65535;break};case 35:{b[7159334]=(b[7159334]|0)+1&65535;break};case 60:{t=(a[14318657|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(t&255)|0];a[14318657|0]=t;break};case 30:{t=c[3579662]|0;b[7159324]=(t&65535)+1&65535;a[14318664]=a[(c[747336+(t>>>10<<2)>>2]|0)+(t&1023)|0]|0;break};case 8:{t=c[3579664]|0;c[3579664]=c[3579671];c[3579671]=t;break};case 1:{t=c[3579662]|0;b[7159324]=(t&65535)+2&65535;u=t+1|0;b[7159330]=d[(c[747336+((u>>>10&63)<<2)>>2]|0)+(u&1023)|0]<<8|d[(c[747336+(t>>>10<<2)>>2]|0)+(t&1023)|0];break};case 25:{t=c[3579667]|0;u=c[3579666]|0;r=u+t|0;b[7159340]=t+1&65535;a[14318656]=(r>>>16&1|a[14318656]&196|r>>>8&40|(u^t^r)>>>8&16)&255;b[7159334]=r&65535;break};case 55:{a[14318656]=a[14318656]&-20|a[14318657|0]&40|1;break};case 56:{if((a[14318656]&1)==0){b[7159324]=m+2&65535;break L19296}else{r=c[3579662]|0;t=(r&65535)+1&65535;b[7159324]=t;u=(a[(c[747336+(r>>>10<<2)>>2]|0)+(r&1023)|0]|0)+t&65535;b[7159324]=u;b[7159340]=u;c[3579678]=l+75;break L19296}break};case 31:{u=a[14318657|0]|0;t=(u&255)>>>1;r=a[14318656]|0;a[14318656]=r&-60|u&1|t&40;a[14318657|0]=r<<7|t;break};case 180:{t=a[14318657|0]|a[14318669|0];a[14318657|0]=t;a[14318656]=a[14319008+(t&255)|0]|0;break};case 181:{t=a[14318657|0]|a[14318668];a[14318657|0]=t;a[14318656]=a[14319008+(t&255)|0]|0;break};case 182:{t=fl[c[186832]&255](e[7159334]|0)|0|a[14318657|0];a[14318657|0]=t;a[14318656]=a[14319008+(t&255)|0]|0;break};case 183:{a[14318656]=a[14319008+(d[14318657|0]|0)|0]|0;break};case 184:{t=a[14318661|0]|0;r=c[3579664]&65280;a[14318656]=a[14319776+((r>>>8)-(t&255)&255|r)|0]&-41|t&40;break};case 185:{t=a[14318660]|0;r=c[3579664]&65280;a[14318656]=a[14319776+((r>>>8)-(t&255)&255|r)|0]&-41|t&40;break};case 186:{t=a[14318665|0]|0;r=c[3579664]&65280;a[14318656]=a[14319776+((r>>>8)-(t&255)&255|r)|0]&-41|t&40;break};case 187:{t=a[14318664]|0;r=c[3579664]&65280;a[14318656]=a[14319776+((r>>>8)-(t&255)&255|r)|0]&-41|t&40;break};case 188:{t=a[14318669|0]|0;r=c[3579664]&65280;a[14318656]=a[14319776+((r>>>8)-(t&255)&255|r)|0]&-41|t&40;break};case 133:{t=c[3579664]&65280;r=(t>>>8)+(d[14318668]|0)|0;a[14318656]=a[14450848+(r&255|t)|0]|0;a[14318657|0]=r&255;break};case 134:{r=c[3579664]&65280;t=((fl[c[186832]&255](e[7159334]|0)|0)&255)+(r>>>8)|0;a[14318656]=a[14450848+(t&255|r)|0]|0;a[14318657|0]=t&255;break};case 135:{t=c[3579664]&65280;r=(t>>>8)+(d[14318657|0]|0)|0;a[14318656]=a[14450848+(r&255|t)|0]|0;a[14318657|0]=r&255;break};case 136:{r=c[3579664]|0;t=r&65280;u=r&1;r=(d[14318661|0]|0)+u+(t>>>8)|0;a[14318656]=a[14450848+(u<<16|t|r&255)|0]|0;a[14318657|0]=r&255;break};case 137:{r=c[3579664]|0;t=r&65280;u=r&1;r=(d[14318660]|0)+u+(t>>>8)|0;a[14318656]=a[14450848+(u<<16|t|r&255)|0]|0;a[14318657|0]=r&255;break};case 147:{r=c[3579664]&65280;t=(r>>>8)-(d[14318664]|0)|0;a[14318656]=a[14319776+(t&255|r)|0]|0;a[14318657|0]=t&255;break};case 148:{t=c[3579664]&65280;r=(t>>>8)-(d[14318669|0]|0)|0;a[14318656]=a[14319776+(r&255|t)|0]|0;a[14318657|0]=r&255;break};case 149:{r=c[3579664]&65280;t=(r>>>8)-(d[14318668]|0)|0;a[14318656]=a[14319776+(t&255|r)|0]|0;a[14318657|0]=t&255;break};case 201:{t=c[3579663]|0;a[14318648]=fl[c[186832]&255](t)|0;a[14318649]=fl[c[186832]&255](t+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=c[3579662]&65535;break};case 202:{t=(a[14318656]&64)==0;r=c[3579662]|0;b[7159324]=(r&65535)+2&65535;u=r+1|0;s=d[(c[747336+((u>>>10&63)<<2)>>2]|0)+(u&1023)|0]<<8|d[(c[747336+(r>>>10<<2)>>2]|0)+(r&1023)|0];if(!t){c[3579662]=s}b[7159340]=s&65535;break};case 170:{s=a[14318657|0]^a[14318665|0];a[14318657|0]=s;a[14318656]=a[14319008+(s&255)|0]|0;break};case 171:{s=a[14318657|0]^a[14318664];a[14318657|0]=s;a[14318656]=a[14319008+(s&255)|0]|0;break};case 172:{s=a[14318657|0]^a[14318669|0];a[14318657|0]=s;a[14318656]=a[14319008+(s&255)|0]|0;break};case 173:{s=a[14318657|0]^a[14318668];a[14318657|0]=s;a[14318656]=a[14319008+(s&255)|0]|0;break};case 4:{s=(a[14318661|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(s&255)|0];a[14318661|0]=s;break};case 230:{s=c[3579662]|0;b[7159324]=(s&65535)+1&65535;t=a[14318657|0]&a[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];a[14318657|0]=t;a[14318656]=a[14319008+(t&255)|0]|16;break};case 231:{b[7159326]=(b[7159326]|0)-2&65535;t=c[3579663]|0;fj[c[186764]&511](t,q);fj[c[186764]&511](t+1&65535,a[14318649]|0);c[3579662]=32;b[7159340]=32;break};case 232:{if((a[14318656]&4)==0){break L19296}t=c[3579663]|0;a[14318648]=fl[c[186832]&255](t)|0;a[14318649]=fl[c[186832]&255](t+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;break};case 233:{b[7159324]=b[7159334]|0;break};case 234:{t=(a[14318656]&4)==0;s=c[3579662]|0;b[7159324]=(s&65535)+2&65535;r=s+1|0;u=d[(c[747336+((r>>>10&63)<<2)>>2]|0)+(r&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];if(!t){c[3579662]=u}b[7159340]=u&65535;break};case 235:{u=c[3579666]|0;c[3579666]=c[3579667];c[3579667]=u;break};case 236:{u=(a[14318656]&4)==0;t=c[3579662]|0;s=(t&65535)+2&65535;b[7159324]=s;r=t+1|0;o=d[(c[747336+((r>>>10&63)<<2)>>2]|0)+(r&1023)|0]<<8|d[(c[747336+(t>>>10<<2)>>2]|0)+(t&1023)|0];if(u){b[7159340]=o&65535;break L19296}else{c[3646042]=o;b[7159340]=o&65535;b[7159326]=(b[7159326]|0)-2&65535;o=c[3579663]|0;fj[c[186764]&511](o,s&255);fj[c[186764]&511](o+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;break L19296}break};case 68:{a[14318661|0]=a[14318669|0]|0;break};case 44:{o=(a[14318668]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(o&255)|0];a[14318668]=o;break};case 45:{o=(a[14318668]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(o&255)|0];a[14318668]=o;break};case 24:{o=c[3579662]|0;s=(o&65535)+1&65535;b[7159324]=s;u=(a[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0]|0)+s&65535;b[7159324]=u;b[7159340]=u;break};case 116:{fj[c[186764]&511](e[7159334]|0,a[14318669|0]|0);break};case 117:{u=b[7159334]|0;fj[c[186764]&511](u&65535,u&255);break};case 118:{b[7159324]=m;a[14318704]=1;break};case 119:{fj[c[186764]&511](e[7159334]|0,a[14318657|0]|0);break};case 156:{u=c[3579664]|0;s=u&65280;o=u&1;u=(s>>>8)-(d[14318669|0]|0)-o|0;a[14318656]=a[14319776+(o<<16|s|u&255)|0]|0;a[14318657|0]=u&255;break};case 157:{u=c[3579664]|0;s=u&65280;o=u&1;u=(s>>>8)-(d[14318668]|0)-o|0;a[14318656]=a[14319776+(o<<16|s|u&255)|0]|0;a[14318657|0]=u&255;break};case 158:{u=c[3579664]|0;s=u&65280;o=u&1;u=(s>>>8)-((fl[c[186832]&255](e[7159334]|0)|0)&255)-o|0;a[14318656]=a[14319776+(o<<16|s|u&255)|0]|0;a[14318657|0]=u&255;break};case 159:{u=c[3579664]|0;s=u&65280;o=u&1;u=(s>>>8)-(d[14318657|0]|0)-o|0;a[14318656]=a[14319776+(o<<16|s|u&255)|0]|0;a[14318657|0]=u&255;break};case 160:{u=a[14318657|0]&a[14318661|0];a[14318657|0]=u;a[14318656]=a[14319008+(u&255)|0]|16;break};case 161:{u=a[14318657|0]&a[14318660];a[14318657|0]=u;a[14318656]=a[14319008+(u&255)|0]|16;break};case 162:{u=a[14318657|0]&a[14318665|0];a[14318657|0]=u;a[14318656]=a[14319008+(u&255)|0]|16;break};case 163:{u=a[14318657|0]&a[14318664];a[14318657|0]=u;a[14318656]=a[14319008+(u&255)|0]|16;break};case 46:{u=c[3579662]|0;b[7159324]=(u&65535)+1&65535;a[14318668]=a[(c[747336+(u>>>10<<2)>>2]|0)+(u&1023)|0]|0;break};case 47:{u=~a[14318657|0];a[14318657|0]=u;a[14318656]=u&40|a[14318656]&-59|18;break};case 74:{a[14318660]=a[14318665|0]|0;break};case 75:{a[14318660]=a[14318664]|0;break};case 65:{a[14318661|0]=a[14318660]|0;break};case 66:{a[14318661|0]=a[14318665|0]|0;break};case 199:{b[7159326]=(b[7159326]|0)-2&65535;u=c[3579663]|0;fj[c[186764]&511](u,q);fj[c[186764]&511](u+1&65535,a[14318649]|0);c[3579662]=0;b[7159340]=0;break};case 2:{fj[c[186764]&511](e[7159330]|0,a[14318657|0]|0);a[14318680]=(b[7159330]&255)+1&255;a[14318681|0]=a[14318657|0]|0;break};case 209:{u=c[3579663]|0;a[14318664]=fl[c[186832]&255](u)|0;a[14318665|0]=fl[c[186832]&255](u+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;break};case 210:{u=(a[14318656]&1)==0;s=c[3579662]|0;b[7159324]=(s&65535)+2&65535;o=s+1|0;t=d[(c[747336+((o>>>10&63)<<2)>>2]|0)+(o&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];if(u){c[3579662]=t}b[7159340]=t&65535;break};case 96:{a[14318669|0]=a[14318661|0]|0;break};case 97:{a[14318669|0]=a[14318660]|0;break};case 98:{a[14318669|0]=a[14318665|0]|0;break};case 99:{a[14318669|0]=a[14318664]|0;break};case 101:{a[14318669|0]=a[14318668]|0;break};case 102:{a[14318669|0]=fl[c[186832]&255](e[7159334]|0)|0;break};case 110:{a[14318668]=fl[c[186832]&255](e[7159334]|0)|0;break};case 115:{fj[c[186764]&511](e[7159334]|0,a[14318664]|0);break};case 38:{t=c[3579662]|0;b[7159324]=(t&65535)+1&65535;a[14318669|0]=a[(c[747336+(t>>>10<<2)>>2]|0)+(t&1023)|0]|0;break};case 39:{t=a[14318657|0]|0;u=a[14318656]|0;s=u&255;o=((t&14)>>>0>9|s&16|0)!=0;do{if((s&2|0)==0){r=o?t+6&255:t;if((s&1|(t&255)>153|0)==0){v=r;break}v=r+96&255}else{r=o?t-6&255:t;if((s&1|(t&255)>153|0)==0){v=r;break}v=r-96&255}}while(0);a[14318656]=(t&255)>153|u&3|a[14319008+(v&255)|0]|(v^t)&16;a[14318657|0]=v;break};case 33:{s=c[3579662]|0;b[7159324]=(s&65535)+2&65535;o=s+1|0;b[7159334]=d[(c[747336+((o>>>10&63)<<2)>>2]|0)+(o&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];break};case 237:{a[14318700]=g+2&255;s=c[3579662]|0;b[7159324]=(s&65535)+1&65535;o=d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0]|0;c[3579678]=(e[(c[3118608]|0)+(o<<1)>>1]|0)+l;fG[c[733400+(o<<2)>>2]&16383]();break};case 238:{o=c[3579662]|0;b[7159324]=(o&65535)+1&65535;s=a[14318657|0]^a[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0];a[14318657|0]=s;a[14318656]=a[14319008+(s&255)|0]|0;break};case 239:{b[7159326]=(b[7159326]|0)-2&65535;s=c[3579663]|0;fj[c[186764]&511](s,q);fj[c[186764]&511](s+1&65535,a[14318649]|0);c[3579662]=40;b[7159340]=40;break};case 240:{if((a[14318656]|0)<0){break L19296}s=c[3579663]|0;a[14318648]=fl[c[186832]&255](s)|0;a[14318649]=fl[c[186832]&255](s+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;break};case 241:{s=c[3579663]|0;a[14318656]=fl[c[186832]&255](s)|0;a[14318657|0]=fl[c[186832]&255](s+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;break};case 242:{s=(a[14318656]|0)<0;o=c[3579662]|0;b[7159324]=(o&65535)+2&65535;r=o+1|0;w=d[(c[747336+((r>>>10&63)<<2)>>2]|0)+(r&1023)|0]<<8|d[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0];if(!s){c[3579662]=w}b[7159340]=w&65535;break};case 243:{a[14318703]=0;a[14318702]=0;break};case 7:{w=a[14318657|0]|0;s=w<<1|(w&255)>>>7;a[14318657|0]=s;a[14318656]=s&41|a[14318656]&-60;break};case 195:{s=c[3579662]|0;b[7159324]=(s&65535)+2&65535;w=s+1|0;o=d[(c[747336+((w>>>10&63)<<2)>>2]|0)+(w&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];c[3579662]=o;b[7159340]=o&65535;break};case 196:{o=(a[14318656]&64)==0;s=c[3579662]|0;w=(s&65535)+2&65535;b[7159324]=w;r=s+1|0;x=d[(c[747336+((r>>>10&63)<<2)>>2]|0)+(r&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];if(o){c[3646042]=x;b[7159340]=x&65535;b[7159326]=(b[7159326]|0)-2&65535;o=c[3579663]|0;fj[c[186764]&511](o,w&255);fj[c[186764]&511](o+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;break L19296}else{b[7159340]=x&65535;break L19296}break};case 197:{b[7159326]=(b[7159326]|0)-2&65535;x=c[3579663]|0;fj[c[186764]&511](x,a[14318660]|0);fj[c[186764]&511](x+1&65535,a[14318661|0]|0);break};case 198:{x=c[3579664]&65280;o=c[3579662]|0;b[7159324]=(o&65535)+1&65535;w=(d[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0]|0)+(x>>>8)|0;a[14318656]=a[14450848+(w&255|x)|0]|0;a[14318657|0]=w&255;break};case 200:{if((a[14318656]&64)==0){break L19296}w=c[3579663]|0;a[14318648]=fl[c[186832]&255](w)|0;a[14318649]=fl[c[186832]&255](w+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;break};case 78:{a[14318660]=fl[c[186832]&255](e[7159334]|0)|0;break};case 79:{a[14318660]=a[14318657|0]|0;break};case 80:{a[14318665|0]=a[14318661|0]|0;break};case 81:{a[14318665|0]=a[14318660]|0;break};case 83:{a[14318665|0]=a[14318664]|0;break};case 244:{w=(a[14318656]|0)<0;x=c[3579662]|0;o=(x&65535)+2&65535;b[7159324]=o;s=x+1|0;r=d[(c[747336+((s>>>10&63)<<2)>>2]|0)+(s&1023)|0]<<8|d[(c[747336+(x>>>10<<2)>>2]|0)+(x&1023)|0];if(w){b[7159340]=r&65535;break L19296}else{c[3646042]=r;b[7159340]=r&65535;b[7159326]=(b[7159326]|0)-2&65535;r=c[3579663]|0;fj[c[186764]&511](r,o&255);fj[c[186764]&511](r+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;break L19296}break};case 245:{b[7159326]=(b[7159326]|0)-2&65535;r=c[3579663]|0;fj[c[186764]&511](r,a[14318656]|0);fj[c[186764]&511](r+1&65535,a[14318657|0]|0);break};case 246:{r=c[3579662]|0;b[7159324]=(r&65535)+1&65535;o=a[14318657|0]|a[(c[747336+(r>>>10<<2)>>2]|0)+(r&1023)|0];a[14318657|0]=o;a[14318656]=a[14319008+(o&255)|0]|0;break};case 247:{b[7159326]=(b[7159326]|0)-2&65535;o=c[3579663]|0;fj[c[186764]&511](o,q);fj[c[186764]&511](o+1&65535,a[14318649]|0);c[3579662]=48;b[7159340]=48;break};case 248:{if((a[14318656]|0)>=0){break L19296}o=c[3579663]|0;a[14318648]=fl[c[186832]&255](o)|0;a[14318649]=fl[c[186832]&255](o+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;break};case 249:{b[7159326]=b[7159334]|0;break};case 250:{o=(a[14318656]|0)<0;r=c[3579662]|0;b[7159324]=(r&65535)+2&65535;w=r+1|0;x=d[(c[747336+((w>>>10&63)<<2)>>2]|0)+(w&1023)|0]<<8|d[(c[747336+(r>>>10<<2)>>2]|0)+(r&1023)|0];if(o){c[3579662]=x}b[7159340]=x&65535;break};case 222:{x=c[3579664]|0;o=x&65280;r=x&1;x=c[3579662]|0;b[7159324]=(x&65535)+1&65535;w=(o>>>8)-(d[(c[747336+(x>>>10<<2)>>2]|0)+(x&1023)|0]|0)-r|0;a[14318656]=a[14319776+(r<<16|o|w&255)|0]|0;a[14318657|0]=w&255;break};case 223:{b[7159326]=(b[7159326]|0)-2&65535;w=c[3579663]|0;fj[c[186764]&511](w,q);fj[c[186764]&511](w+1&65535,a[14318649]|0);c[3579662]=24;b[7159340]=24;break};case 224:{if((a[14318656]&4)!=0){break L19296}w=c[3579663]|0;a[14318648]=fl[c[186832]&255](w)|0;a[14318649]=fl[c[186832]&255](w+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;break};case 225:{w=c[3579663]|0;a[14318668]=fl[c[186832]&255](w)|0;a[14318669|0]=fl[c[186832]&255](w+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;break};case 226:{w=(a[14318656]&4)==0;o=c[3579662]|0;b[7159324]=(o&65535)+2&65535;r=o+1|0;x=d[(c[747336+((r>>>10&63)<<2)>>2]|0)+(r&1023)|0]<<8|d[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0];if(w){c[3579662]=x}b[7159340]=x&65535;break};case 120:{a[14318657|0]=a[14318661|0]|0;break};case 121:{a[14318657|0]=a[14318660]|0;break};case 122:{a[14318657|0]=a[14318665|0]|0;break};case 123:{a[14318657|0]=a[14318664]|0;break};case 124:{a[14318657|0]=a[14318669|0]|0;break};case 125:{a[14318657|0]=a[14318668]|0;break};case 126:{a[14318657|0]=fl[c[186832]&255](e[7159334]|0)|0;break};case 128:{x=c[3579664]&65280;w=(x>>>8)+(d[14318661|0]|0)|0;a[14318656]=a[14450848+(w&255|x)|0]|0;a[14318657|0]=w&255;break};case 6:{w=c[3579662]|0;b[7159324]=(w&65535)+1&65535;a[14318661|0]=a[(c[747336+(w>>>10<<2)>>2]|0)+(w&1023)|0]|0;break};case 19:{b[7159332]=(b[7159332]|0)+1&65535;break};case 15:{w=a[14318657|0]|0;x=w&1|a[14318656]&-60;o=(w&255)>>>1;a[14318657|0]=o|w<<7;a[14318656]=x|o&40;break};case 103:{a[14318669|0]=a[14318657|0]|0;break};case 104:{a[14318668]=a[14318661|0]|0;break};case 105:{a[14318668]=a[14318660]|0;break};case 106:{a[14318668]=a[14318665|0]|0;break};case 107:{a[14318668]=a[14318664]|0;break};case 108:{a[14318668]=a[14318669|0]|0;break};case 26:{a[14318657|0]=fl[c[186832]&255](e[7159332]|0)|0;b[7159340]=(b[7159332]|0)+1&65535;break};case 69:{a[14318661|0]=a[14318668]|0;break};case 70:{a[14318661|0]=fl[c[186832]&255](e[7159334]|0)|0;break};case 36:{o=(a[14318669|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(o&255)|0];a[14318669|0]=o;break};case 37:{o=(a[14318669|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(o&255)|0];a[14318669|0]=o;break};case 193:{o=c[3579663]|0;a[14318660]=fl[c[186832]&255](o)|0;a[14318661|0]=fl[c[186832]&255](o+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;break};case 43:{b[7159334]=(b[7159334]|0)-1&65535;break};case 16:{o=(a[14318661|0]|0)-1&255;a[14318661|0]=o;if(o<<24>>24==0){b[7159324]=m+2&65535;break L19296}else{o=c[3579662]|0;x=(o&65535)+1&65535;b[7159324]=x;w=(a[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0]|0)+x&65535;b[7159324]=w;b[7159340]=w;c[3579678]=l+75;break L19296}break};case 145:{w=c[3579664]&65280;x=(w>>>8)-(d[14318660]|0)|0;a[14318656]=a[14319776+(x&255|w)|0]|0;a[14318657|0]=x&255;break};case 146:{x=c[3579664]&65280;w=(x>>>8)-(d[14318665|0]|0)|0;a[14318656]=a[14319776+(w&255|x)|0]|0;a[14318657|0]=w&255;break};case 251:{a[14318703]=1;a[14318702]=1;a[14318710]=1;break};case 252:{w=(a[14318656]|0)<0;x=c[3579662]|0;o=(x&65535)+2&65535;b[7159324]=o;r=x+1|0;s=d[(c[747336+((r>>>10&63)<<2)>>2]|0)+(r&1023)|0]<<8|d[(c[747336+(x>>>10<<2)>>2]|0)+(x&1023)|0];if(w){c[3646042]=s;b[7159340]=s&65535;b[7159326]=(b[7159326]|0)-2&65535;w=c[3579663]|0;fj[c[186764]&511](w,o&255);fj[c[186764]&511](w+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;break L19296}else{b[7159340]=s&65535;break L19296}break};case 253:{a[14318700]=g+2&255;s=c[3579662]|0;b[7159324]=(s&65535)+1&65535;w=d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0]|0;c[3579678]=(e[(c[3118606]|0)+(w<<1)>>1]|0)+l;fG[c[732376+(w<<2)>>2]&16383]();break};case 254:{w=c[3579662]|0;b[7159324]=(w&65535)+1&65535;s=a[(c[747336+(w>>>10<<2)>>2]|0)+(w&1023)|0]|0;w=c[3579664]&65280;a[14318656]=a[14319776+((w>>>8)-(s&255)&255|w)|0]&-41|s&40;break};case 255:{b[7159326]=(b[7159326]|0)-2&65535;s=c[3579663]|0;fj[c[186764]&511](s,q);fj[c[186764]&511](s+1&65535,a[14318649]|0);c[3579662]=56;b[7159340]=56;break};case 17:{s=c[3579662]|0;b[7159324]=(s&65535)+2&65535;w=s+1|0;b[7159332]=d[(c[747336+((w>>>10&63)<<2)>>2]|0)+(w&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];break};case 174:{s=(fl[c[186832]&255](e[7159334]|0)|0)^a[14318657|0];a[14318657|0]=s;a[14318656]=a[14319008+(s&255)|0]|0;break};case 175:{a[14318657|0]=0;a[14318656]=a[14319008]|0;break};case 176:{s=a[14318657|0]|a[14318661|0];a[14318657|0]=s;a[14318656]=a[14319008+(s&255)|0]|0;break};case 177:{s=a[14318657|0]|a[14318660];a[14318657|0]=s;a[14318656]=a[14319008+(s&255)|0]|0;break};case 178:{s=a[14318657|0]|a[14318665|0];a[14318657|0]=s;a[14318656]=a[14319008+(s&255)|0]|0;break};case 179:{s=a[14318657|0]|a[14318664];a[14318657|0]=s;a[14318656]=a[14319008+(s&255)|0]|0;break};case 211:{s=c[3579662]|0;b[7159324]=(s&65535)+1&65535;w=a[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0]|0;s=a[14318657|0]|0;fj[c[186762]&511]((s&255)<<8|w&255,s);a[14318680]=w+1&255;a[14318681|0]=a[14318657|0]|0;break};case 212:{w=(a[14318656]&1)==0;s=c[3579662]|0;o=(s&65535)+2&65535;b[7159324]=o;x=s+1|0;r=d[(c[747336+((x>>>10&63)<<2)>>2]|0)+(x&1023)|0]<<8|d[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0];if(w){c[3646042]=r;b[7159340]=r&65535;b[7159326]=(b[7159326]|0)-2&65535;w=c[3579663]|0;fj[c[186764]&511](w,o&255);fj[c[186764]&511](w+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;break L19296}else{b[7159340]=r&65535;break L19296}break};case 213:{b[7159326]=(b[7159326]|0)-2&65535;r=c[3579663]|0;fj[c[186764]&511](r,a[14318664]|0);fj[c[186764]&511](r+1&65535,a[14318665|0]|0);break};case 23:{r=a[14318657|0]|0;w=r<<1;o=a[14318656]|0;a[14318656]=o&-60|(r&255)>>>7|w&40;a[14318657|0]=o&1|w;break};case 138:{w=c[3579664]|0;o=w&65280;r=w&1;w=(d[14318665|0]|0)+r+(o>>>8)|0;a[14318656]=a[14450848+(r<<16|o|w&255)|0]|0;a[14318657|0]=w&255;break};case 139:{w=c[3579664]|0;o=w&65280;r=w&1;w=(d[14318664]|0)+r+(o>>>8)|0;a[14318656]=a[14450848+(r<<16|o|w&255)|0]|0;a[14318657|0]=w&255;break};case 140:{w=c[3579664]|0;o=w&65280;r=w&1;w=(d[14318669|0]|0)+r+(o>>>8)|0;a[14318656]=a[14450848+(r<<16|o|w&255)|0]|0;a[14318657|0]=w&255;break};case 141:{w=c[3579664]|0;o=w&65280;r=w&1;w=(d[14318668]|0)+r+(o>>>8)|0;a[14318656]=a[14450848+(r<<16|o|w&255)|0]|0;a[14318657|0]=w&255;break};case 13:{w=(a[14318660]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(w&255)|0];a[14318660]=w;break};case 3:{b[7159330]=(b[7159330]|0)+1&65535;break};case 29:{w=(a[14318664]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(w&255)|0];a[14318664]=w;break};case 28:{w=(a[14318664]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(w&255)|0];a[14318664]=w;break};case 14:{w=c[3579662]|0;b[7159324]=(w&65535)+1&65535;a[14318660]=a[(c[747336+(w>>>10<<2)>>2]|0)+(w&1023)|0]|0;break};case 21:{w=(a[14318665|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(w&255)|0];a[14318665|0]=w;break};case 57:{w=c[3579667]|0;o=c[3579663]|0;r=o+w|0;b[7159340]=w+1&65535;a[14318656]=(r>>>16&1|a[14318656]&196|r>>>8&40|(o^w^r)>>>8&16)&255;b[7159334]=r&65535;break};case 58:{r=c[3579662]|0;b[7159324]=(r&65535)+2&65535;w=r+1|0;o=d[(c[747336+((w>>>10&63)<<2)>>2]|0)+(w&1023)|0]<<8|d[(c[747336+(r>>>10<<2)>>2]|0)+(r&1023)|0];c[3646042]=o;a[14318657|0]=fl[c[186832]&255](o)|0;b[7159340]=(c[3646042]|0)+1&65535;break};case 59:{b[7159326]=(b[7159326]|0)-1&65535;break};case 164:{o=a[14318657|0]&a[14318669|0];a[14318657|0]=o;a[14318656]=a[14319008+(o&255)|0]|16;break};case 165:{o=a[14318657|0]&a[14318668];a[14318657|0]=o;a[14318656]=a[14319008+(o&255)|0]|16;break};case 166:{o=(fl[c[186832]&255](e[7159334]|0)|0)&a[14318657|0];a[14318657|0]=o;a[14318656]=a[14319008+(o&255)|0]|16;break};case 167:{a[14318656]=a[14319008+(d[14318657|0]|0)|0]|16;break};case 168:{o=a[14318657|0]^a[14318661|0];a[14318657|0]=o;a[14318656]=a[14319008+(o&255)|0]|0;break};case 169:{o=a[14318657|0]^a[14318660];a[14318657|0]=o;a[14318656]=a[14319008+(o&255)|0]|0;break};case 71:{a[14318661|0]=a[14318657|0]|0;break};case 72:{a[14318660]=a[14318661|0]|0;break};case 20:{o=(a[14318665|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(o&255)|0];a[14318665|0]=o;break};case 214:{o=c[3579664]&65280;r=c[3579662]|0;b[7159324]=(r&65535)+1&65535;w=(o>>>8)-(d[(c[747336+(r>>>10<<2)>>2]|0)+(r&1023)|0]|0)|0;a[14318656]=a[14319776+(w&255|o)|0]|0;a[14318657|0]=w&255;break};case 215:{b[7159326]=(b[7159326]|0)-2&65535;w=c[3579663]|0;fj[c[186764]&511](w,q);fj[c[186764]&511](w+1&65535,a[14318649]|0);c[3579662]=16;b[7159340]=16;break};case 216:{if((a[14318656]&1)==0){break L19296}w=c[3579663]|0;a[14318648]=fl[c[186832]&255](w)|0;a[14318649]=fl[c[186832]&255](w+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;break};case 217:{w=c[3579665]|0;c[3579665]=c[3579672];c[3579672]=w;w=c[3579666]|0;c[3579666]=c[3579673];c[3579673]=w;w=c[3579667]|0;c[3579667]=c[3579674];c[3579674]=w;break};case 218:{w=(a[14318656]&1)==0;o=c[3579662]|0;b[7159324]=(o&65535)+2&65535;r=o+1|0;s=d[(c[747336+((r>>>10&63)<<2)>>2]|0)+(r&1023)|0]<<8|d[(c[747336+(o>>>10<<2)>>2]|0)+(o&1023)|0];if(!w){c[3579662]=s}b[7159340]=s&65535;break};case 154:{s=c[3579664]|0;w=s&65280;o=s&1;s=(w>>>8)-(d[14318665|0]|0)-o|0;a[14318656]=a[14319776+(o<<16|w|s&255)|0]|0;a[14318657|0]=s&255;break};case 155:{s=c[3579664]|0;w=s&65280;o=s&1;s=(w>>>8)-(d[14318664]|0)-o|0;a[14318656]=a[14319776+(o<<16|w|s&255)|0]|0;a[14318657|0]=s&255;break};case 12:{s=(a[14318660]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(s&255)|0];a[14318660]=s;break};case 76:{a[14318660]=a[14318669|0]|0;break};case 77:{a[14318660]=a[14318668]|0;break};case 61:{s=(a[14318657|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(s&255)|0];a[14318657|0]=s;break};case 62:{s=c[3579662]|0;b[7159324]=(s&65535)+1&65535;a[14318657|0]=a[(c[747336+(s>>>10<<2)>>2]|0)+(s&1023)|0]|0;break};case 63:{s=a[14318656]|0;a[14318656]=(s<<4&16|s&-19|a[14318657|0]&40)^1;break};case 111:{a[14318668]=a[14318657|0]|0;break};case 112:{fj[c[186764]&511](e[7159334]|0,a[14318661|0]|0);break};case 113:{fj[c[186764]&511](e[7159334]|0,a[14318660]|0);break};case 114:{fj[c[186764]&511](e[7159334]|0,a[14318665|0]|0);break};case 189:{s=a[14318668]|0;w=c[3579664]&65280;a[14318656]=a[14319776+((w>>>8)-(s&255)&255|w)|0]&-41|s&40;break};case 190:{s=fl[c[186832]&255](e[7159334]|0)|0;w=c[3579664]&65280;a[14318656]=a[14319776+((w>>>8)-(s&255)&255|w)|0]&-41|s&40;break};case 191:{s=a[14318657|0]|0;w=c[3579664]&65280;a[14318656]=a[14319776+((w>>>8)-(s&255)&255|w)|0]&-41|s&40;break};case 192:{if((a[14318656]&64)!=0){break L19296}s=c[3579663]|0;a[14318648]=fl[c[186832]&255](s)|0;a[14318649]=fl[c[186832]&255](s+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;break};case 194:{s=(a[14318656]&64)==0;w=c[3579662]|0;b[7159324]=(w&65535)+2&65535;o=w+1|0;r=d[(c[747336+((o>>>10&63)<<2)>>2]|0)+(o&1023)|0]<<8|d[(c[747336+(w>>>10<<2)>>2]|0)+(w&1023)|0];if(s){c[3579662]=r}b[7159340]=r&65535;break};case 219:{r=c[3579662]|0;b[7159324]=(r&65535)+1&65535;s=d[14318657|0]<<8|d[(c[747336+(r>>>10<<2)>>2]|0)+(r&1023)|0];a[14318657|0]=fl[c[186830]&255](s)|0;b[7159340]=s+1&65535;break};case 220:{s=(a[14318656]&1)==0;r=c[3579662]|0;w=(r&65535)+2&65535;b[7159324]=w;o=r+1|0;x=d[(c[747336+((o>>>10&63)<<2)>>2]|0)+(o&1023)|0]<<8|d[(c[747336+(r>>>10<<2)>>2]|0)+(r&1023)|0];if(s){b[7159340]=x&65535;break L19296}else{c[3646042]=x;b[7159340]=x&65535;b[7159326]=(b[7159326]|0)-2&65535;x=c[3579663]|0;fj[c[186764]&511](x,w&255);fj[c[186764]&511](x+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;break L19296}break};case 221:{a[14318700]=g+2&255;x=c[3579662]|0;b[7159324]=(x&65535)+1&65535;w=d[(c[747336+(x>>>10<<2)>>2]|0)+(x&1023)|0]|0;c[3579678]=(e[(c[3118606]|0)+(w<<1)>>1]|0)+l;fG[c[734424+(w<<2)>>2]&16383]();break};default:{}}}while(0);l=c[3579678]|0;if(l>>>0<f>>>0){h=l}else{n=14655;break}}if((n|0)==14654){return}else if((n|0)==14655){return}}function oz(){return}function oA(){var a=0;a=c[3579664]|0;c[3579664]=c[3579671];c[3579671]=a;return}function oB(b){b=b|0;a[14318709|0]=b&255;return}function oC(){b[7159330]=(b[7159330]|0)+1&65535;return}function oD(){var b=0,c=0;b=a[14318657|0]|0;c=b<<1|(b&255)>>>7;a[14318657|0]=c;a[14318656]=c&41|a[14318656]&-60;return}function oE(){var d=0,e=0,f=0;d=c[3579669]|0;e=c[3579665]|0;f=e+d|0;b[7159340]=d+1&65535;a[14318656]=(f>>>16&1|a[14318656]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[7159338]=f&65535;return}function oF(){b[7159330]=(b[7159330]|0)-1&65535;return}function oG(){var b=0,c=0,d=0;b=a[14318657|0]|0;c=b&1|a[14318656]&-60;d=(b&255)>>>1;a[14318657|0]=d|b<<7;a[14318656]=c|d&40;return}function oH(){b[7159332]=(b[7159332]|0)+1&65535;return}function oI(){var b=0,c=0,d=0;b=a[14318657|0]|0;c=b<<1;d=a[14318656]|0;a[14318656]=d&-60|(b&255)>>>7|c&40;a[14318657|0]=d&1|c;return}function oJ(){var d=0,e=0,f=0;d=c[3579669]|0;e=c[3579666]|0;f=e+d|0;b[7159340]=d+1&65535;a[14318656]=(f>>>16&1|a[14318656]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[7159338]=f&65535;return}function oK(){b[7159332]=(b[7159332]|0)-1&65535;return}function oL(){var b=0,c=0,d=0;b=a[14318657|0]|0;c=(b&255)>>>1;d=a[14318656]|0;a[14318656]=d&-60|b&1|c&40;a[14318657|0]=d<<7|c;return}function oM(){b[7159338]=(b[7159338]|0)+1&65535;return}function oN(){var d=0,e=0;d=c[3579669]|0;b[7159340]=d+1&65535;e=d>>>7;a[14318656]=(d>>>15&1|e&16|e&40|a[14318656]&196)&255;b[7159338]=d<<1&65535;return}function oO(){b[7159338]=(b[7159338]|0)-1&65535;return}function oP(){var b=0;b=~a[14318657|0];a[14318657|0]=b;a[14318656]=b&40|a[14318656]&-59|18;return}function oQ(){b[7159326]=(b[7159326]|0)+1&65535;return}function oR(){var a=0,e=0;a=c[3579662]|0;b[7159324]=(a&65535)+2&65535;e=a+1|0;b[7159330]=(d[(c[747336+((e>>>10&63)<<2)>>2]|0)+(e&1023)|0]|0)<<8|(d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0);return}function oS(){var b=0;b=(a[14318661|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318661|0]=b;return}function oT(){var b=0;b=(a[14318661|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318661|0]=b;return}function oU(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318661|0]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function oV(){var b=0;b=(a[14318660]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318660]=b;return}function oW(){var b=0;b=(a[14318660]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318660]=b;return}function oX(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318660]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function oY(){var d=0,e=0,f=0;d=(a[14318661|0]|0)-1&255;a[14318661|0]=d;if(d<<24>>24==0){b[7159324]=(b[7159324]|0)+1&65535;return}else{d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;c[3579678]=(c[3579678]|0)+75;return}}function oZ(){var a=0,e=0;a=c[3579662]|0;b[7159324]=(a&65535)+2&65535;e=a+1|0;b[7159332]=(d[(c[747336+((e>>>10&63)<<2)>>2]|0)+(e&1023)|0]|0)<<8|(d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0);return}function o_(){var b=0;b=(a[14318665|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318665|0]=b;return}function o$(){var b=0;b=(a[14318665|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318665|0]=b;return}function o0(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318665|0]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function o1(){var d=0,e=0,f=0;d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;return}function o2(){var b=0;b=(a[14318664]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318664]=b;return}function o3(){var b=0;b=(a[14318664]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318664]=b;return}function o4(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318664]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function o5(){var d=0,e=0,f=0;if((a[14318656]&64)==0){d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;c[3579678]=(c[3579678]|0)+75;return}else{b[7159324]=(b[7159324]|0)+1&65535;return}}function o6(){var a=0,e=0;a=c[3579662]|0;b[7159324]=(a&65535)+2&65535;e=a+1|0;b[7159338]=(d[(c[747336+((e>>>10&63)<<2)>>2]|0)+(e&1023)|0]|0)<<8|(d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0);return}function o7(){var b=0;b=(a[14318677|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318677|0]=b;return}function o8(){var b=0;b=(a[14318677|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318677|0]=b;return}function o9(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318677|0]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function pa(){var b=0,c=0,d=0,e=0,f=0,g=0;b=a[14318657|0]|0;c=a[14318656]|0;d=c&255;e=((b&14)>>>0>9|d&16|0)!=0;do{if((d&2|0)==0){f=e?b+6&255:b;if((d&1|(b&255)>153|0)==0){g=f;break}g=f+96&255}else{f=e?b-6&255:b;if((d&1|(b&255)>153|0)==0){g=f;break}g=f-96&255}}while(0);a[14318656]=(b&255)>153|c&3|a[14319008+(g&255)|0]|(g^b)&16;a[14318657|0]=g;return}function pb(){var d=0,e=0,f=0;if((a[14318656]&64)==0){b[7159324]=(b[7159324]|0)+1&65535;return}else{d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;c[3579678]=(c[3579678]|0)+75;return}}function pc(){var b=0;b=(a[14318676]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318676]=b;return}function pd(){var b=0;b=(a[14318676]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318676]=b;return}function pe(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318676]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function pf(){var d=0,e=0,f=0;if((a[14318656]&1)==0){d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;c[3579678]=(c[3579678]|0)+75;return}else{b[7159324]=(b[7159324]|0)+1&65535;return}}function pg(){var a=0,e=0;a=c[3579662]|0;b[7159324]=(a&65535)+2&65535;e=a+1|0;b[7159326]=(d[(c[747336+((e>>>10&63)<<2)>>2]|0)+(e&1023)|0]|0)<<8|(d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0);return}function ph(){fj[c[186764]&511](e[7159330]|0,a[14318657|0]|0);a[14318680]=(b[7159330]&255)+1&255;a[14318681|0]=a[14318657|0]|0;return}function pi(){a[14318657|0]=fl[c[186832]&255](e[7159330]|0)|0;b[7159340]=(b[7159330]|0)+1&65535;return}function pj(){fj[c[186764]&511](e[7159332]|0,a[14318657|0]|0);a[14318680]=(b[7159332]&255)+1&255;a[14318681|0]=a[14318657|0]|0;return}function pk(){a[14318657|0]=fl[c[186832]&255](e[7159332]|0)|0;b[7159340]=(b[7159332]|0)+1&65535;return}function pl(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;fj[c[186764]&511](g,a[14318676]|0);fj[c[186764]&511](g+1&65535,a[14318677|0]|0);b[7159340]=(c[3646042]|0)+1&65535;return}function pm(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;a[14318676]=fl[c[186832]&255](g)|0;a[14318677|0]=fl[c[186832]&255](g+1&65535)|0;b[7159340]=(c[3646042]|0)+1&65535;return}function pn(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;fj[c[186764]&511](g,a[14318657|0]|0);a[14318680]=(c[3646042]|0)+1&255;a[14318681|0]=a[14318657|0]|0;return}function po(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[186764]|0;e=(fl[c[186832]&255](d)|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(e&255)|0];fj[f&511](d,e);return}function pp(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[186764]|0;e=(fl[c[186832]&255](d)|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(e&255)|0];fj[f&511](d,e);return}function pq(){return}function pr(){return}function ps(){return}function pt(){return}function pu(){return}function pv(){return}function pw(){return}function px(){a[14318661|0]=a[14318660]|0;return}function py(){a[14318661|0]=a[14318665|0]|0;return}function pz(){a[14318661|0]=a[14318664]|0;return}function pA(){a[14318661|0]=a[14318677|0]|0;return}function pB(){a[14318661|0]=a[14318676]|0;return}function pC(){a[14318661|0]=a[14318657|0]|0;return}function pD(){a[14318660]=a[14318661|0]|0;return}function pE(){a[14318660]=a[14318665|0]|0;return}function pF(){a[14318660|0]=a[14318664|0]|0;return}function pG(){a[14318660]=a[14318677|0]|0;return}function pH(){a[14318660|0]=a[14318676|0]|0;return}function pI(){a[14318660]=a[14318657|0]|0;return}function pJ(){a[14318665|0]=a[14318661|0]|0;return}function pK(){a[14318665|0]=a[14318660]|0;return}function pL(){a[14318665|0]=a[14318664]|0;return}function pM(){a[14318665|0]=a[14318677|0]|0;return}function pN(){a[14318665|0]=a[14318676]|0;return}function pO(){a[14318665|0]=a[14318657|0]|0;return}function pP(){a[14318664]=a[14318661|0]|0;return}function pQ(){a[14318664|0]=a[14318660|0]|0;return}function pR(){a[14318664]=a[14318665|0]|0;return}function pS(){a[14318664]=a[14318677|0]|0;return}function pT(){a[14318664|0]=a[14318676|0]|0;return}function pU(){a[14318664]=a[14318657|0]|0;return}function pV(){a[14318677|0]=a[14318661|0]|0;return}function pW(){a[14318677|0]=a[14318660]|0;return}function pX(){a[14318677|0]=a[14318665|0]|0;return}function pY(){a[14318677|0]=a[14318664]|0;return}function pZ(){a[14318677|0]=a[14318676]|0;return}function p_(){a[14318677|0]=a[14318657|0]|0;return}function p$(){a[14318676]=a[14318661|0]|0;return}function p0(){a[14318676|0]=a[14318660|0]|0;return}function p1(){a[14318676]=a[14318665|0]|0;return}function p2(){a[14318676|0]=a[14318664|0]|0;return}function p3(){a[14318676]=a[14318677|0]|0;return}function p4(){a[14318676]=a[14318657|0]|0;return}function p5(){a[14318657|0]=a[14318661|0]|0;return}function p6(){a[14318657|0]=a[14318660]|0;return}function p7(){a[14318657|0]=a[14318665|0]|0;return}function p8(){a[14318657|0]=a[14318664]|0;return}function p9(){a[14318657|0]=a[14318677|0]|0;return}function qa(){a[14318657|0]=a[14318676]|0;return}function qb(){a[14318656]=a[14318656]&-20|a[14318657|0]&40|1;return}function qc(){var d=0,e=0,f=0;d=c[3579669]|0;e=c[3579663]|0;f=e+d|0;b[7159340]=d+1&65535;a[14318656]=(f>>>16&1|a[14318656]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[7159338]=f&65535;return}function qd(){b[7159326]=(b[7159326]|0)-1&65535;return}function qe(){var b=0;b=a[14318656]|0;a[14318656]=(b<<4&16|b&-19|a[14318657|0]&40)^1;return}function qf(){b[7159324]=(b[7159324]|0)-1&65535;a[14318704|0]=1;return}function qg(){var d=0,e=0,f=0;if((a[14318656]&1)==0){b[7159324]=(b[7159324]|0)+1&65535;return}else{d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;c[3579678]=(c[3579678]|0)+75;return}}function qh(){var b=0;b=(a[14318657|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318657|0]=b;return}function qi(){var b=0;b=(a[14318657|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318657|0]=b;return}function qj(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318657|0]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function qk(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318661|0]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function ql(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318660]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qm(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318665|0]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qn(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318664]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qo(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318677|0]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qp(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318676]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qq(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318657|0]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qr(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318661|0]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function qs(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318660]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function qt(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318665|0]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function qu(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318664]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function qv(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318677|0]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function qw(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[186764]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;fj[f&511](d,a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);return}function qx(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;a[14318657|0]=fl[c[186832]&255](g)|0;b[7159340]=(c[3646042]|0)+1&65535;return}function qy(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318661|0]=fl[c[186832]&255](d)|0;return}function qz(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318660]=fl[c[186832]&255](d)|0;return}function qA(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318665|0]=fl[c[186832]&255](d)|0;return}function qB(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318664]=fl[c[186832]&255](d)|0;return}function qC(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318669|0]=fl[c[186832]&255](d)|0;return}function qD(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318668]=fl[c[186832]&255](d)|0;return}function qE(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318661|0]|0);return}function qF(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318660]|0);return}function qG(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318665|0]|0);return}function qH(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318664]|0);return}function qI(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318669|0]|0);return}function qJ(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318668]|0);return}function qK(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318657|0]|0);return}function qL(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318657|0]=fl[c[186832]&255](d)|0;return}function qM(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[3579664]&65280;e=((fl[c[186832]&255](d)|0)&255)+(f>>>8)|0;a[14318656]=a[14450848+(e&255|f)|0]|0;a[14318657|0]=e&255;return}function qN(){a[14318657|0]=0;a[14318656]=a[14319008]|0;return}function qO(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318676]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function qP(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318657|0]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function qQ(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318661|0]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qR(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318660]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qS(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318665|0]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qT(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318664]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qU(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318677|0]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qV(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318676]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qW(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318657|0]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function qX(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318661|0]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function qY(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318660]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function qZ(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318665|0]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function q_(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318664]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function q$(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318677|0]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function q0(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318676]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function q1(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318657|0]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function q2(){var b=0;b=a[14318657|0]&a[14318661|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function q3(){var b=0;b=a[14318657|0]&a[14318660];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function q4(){var b=0;b=a[14318657|0]&a[14318665|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function q5(){var b=0;b=a[14318657|0]&a[14318664];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function q6(){var b=0;b=a[14318657|0]&a[14318677|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function q7(){var b=0;b=a[14318657|0]&a[14318676];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function q8(){a[14318656]=a[14319008+(d[14318657|0]|0)|0]|16;return}function q9(){var b=0;b=a[14318657|0]^a[14318661|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function ra(){var b=0;b=a[14318657|0]^a[14318660];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function rb(){var b=0;b=a[14318657|0]^a[14318665|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function rc(){var b=0;b=a[14318657|0]^a[14318664];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function rd(){var b=0;b=a[14318657|0]^a[14318677|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function re(){var b=0;b=a[14318657|0]^a[14318676];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function rf(){var b=0;b=a[14318657|0]|a[14318661|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function rg(){var b=0;b=a[14318657|0]|a[14318660];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function rh(){var b=0;b=a[14318657|0]|a[14318665|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function ri(){var b=0;b=a[14318657|0]|a[14318664];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function rj(){var b=0;b=a[14318657|0]|a[14318677|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function rk(){var b=0;b=a[14318657|0]|a[14318676];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function rl(){a[14318656]=a[14319008+(d[14318657|0]|0)|0]|0;return}function rm(){var b=0,d=0;b=a[14318661|0]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function rn(){var b=0,d=0;b=a[14318660]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function ro(){var b=0,d=0;b=a[14318665|0]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function rp(){var b=0,d=0;b=a[14318664]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function rq(){var b=0,d=0;b=a[14318677|0]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function rr(){var b=0,d=0;b=a[14318676]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function rs(){var b=0,d=0;b=a[14318657|0]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function rt(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&64)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(!e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function ru(){var a=0,e=0,f=0;a=c[3579662]|0;b[7159324]=(a&65535)+2&65535;e=a+1|0;f=(d[(c[747336+((e>>>10&63)<<2)>>2]|0)+(e&1023)|0]|0)<<8|(d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0);c[3579662]=f;b[7159340]=f&65535;return}function rv(){var d=0,e=0,f=0,g=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[3579664]|0;e=f&65280;g=f&1;f=(e>>>8)+g+((fl[c[186832]&255](d)|0)&255)|0;a[14318656]=a[14450848+(g<<16|e|f&255)|0]|0;a[14318657|0]=f&255;return}function rw(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[3579664]&65280;e=(f>>>8)-((fl[c[186832]&255](d)|0)&255)|0;a[14318656]=a[14319776+(e&255|f)|0]|0;a[14318657|0]=e&255;return}function rx(){var d=0,e=0,f=0,g=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[3579664]|0;e=f&65280;g=f&1;f=(e>>>8)-((fl[c[186832]&255](d)|0)&255)-g|0;a[14318656]=a[14319776+(g<<16|e|f&255)|0]|0;a[14318657|0]=f&255;return}function ry(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=fl[c[186832]&255](d)|0;d=a[14318657|0]&f;a[14318657|0]=d;a[14318656]=a[14319008+(d&255)|0]|16;return}function rz(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=fl[c[186832]&255](d)|0;d=a[14318657|0]^f;a[14318657|0]=d;a[14318656]=a[14319008+(d&255)|0]|0;return}function rA(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=fl[c[186832]&255](d)|0;d=a[14318657|0]|f;a[14318657|0]=d;a[14318656]=a[14319008+(d&255)|0]|0;return}function rB(){var d=0,e=0,f=0;d=b[7159338]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=fl[c[186832]&255](d)|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(f&255)&255|d)|0]&-41|f&40;return}function rC(){var d=0;if((a[14318656]&64)!=0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function rD(){var d=0;d=c[3579663]|0;a[14318660]=fl[c[186832]&255](d)|0;a[14318661|0]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;return}function rE(){var a=0;a=c[3579665]|0;c[3579665]=c[3579672];c[3579672]=a;a=c[3579666]|0;c[3579666]=c[3579673];c[3579673]=a;a=c[3579667]|0;c[3579667]=c[3579674];c[3579674]=a;return}function rF(){var e=0,f=0,g=0;e=c[3579664]&65280;f=c[3579662]|0;b[7159324]=(f&65535)+1&65535;g=(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0)+(e>>>8)|0;a[14318656]=a[14450848+(g&255|e)|0]|0;a[14318657|0]=g&255;return}function rG(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&64)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function rH(){var e=0,f=0,g=0,h=0;e=c[3579664]|0;f=e&65280;g=e&1;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;h=(f>>>8)+g+(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)|0;a[14318656]=a[14450848+(g<<16|f|h&255)|0]|0;a[14318657|0]=h&255;return}function rI(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&1)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(!e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function rJ(){var e=0,f=0,g=0;e=c[3579664]&65280;f=c[3579662]|0;b[7159324]=(f&65535)+1&65535;g=(e>>>8)-(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0)|0;a[14318656]=a[14319776+(g&255|e)|0]|0;a[14318657|0]=g&255;return}function rK(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&1)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function rL(){var e=0,f=0,g=0,h=0;e=c[3579664]|0;f=e&65280;g=e&1;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;h=(f>>>8)-(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)-g|0;a[14318656]=a[14319776+(g<<16|f|h&255)|0]|0;a[14318657|0]=h&255;return}function rM(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&4)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(!e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function rN(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&64)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;e=c[3579663]|0;fj[c[186764]&511](e,g&255);fj[c[186764]&511](e+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}else{b[7159340]=i&65535;return}}function rO(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318660]|0);fj[c[186764]&511](d+1&65535,a[14318661|0]|0);return}function rP(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=0;b[7159340]=0;return}function rQ(){var d=0;if((a[14318656]&64)==0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function rR(){var d=0;d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=c[3579662]&65535;return}function rS(){var f=0,g=0,h=0;f=b[7159338]|0;g=c[3579662]|0;b[7159324]=(g&65535)+1&65535;h=(a[(c[747336+(g>>>10<<2)>>2]|0)+(g&1023)|0]|0)+f&65535;c[3646042]=h&65535;b[7159340]=h;h=c[3579662]|0;b[7159324]=(h&65535)+1&65535;f=d[(c[747336+(h>>>10<<2)>>2]|0)+(h&1023)|0]|0;c[3579678]=(c[3579678]|0)+(e[(c[3118604]|0)+(f<<1)>>1]|0);fG[c[731352+(f<<2)>>2]&16383]();return}function rT(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&64)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){b[7159340]=i&65535;return}else{c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;i=c[3579663]|0;fj[c[186764]&511](i,g&255);fj[c[186764]&511](i+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}}function rU(){var e=0,f=0,g=0,h=0;e=c[3579662]|0;f=(e&65535)+2&65535;b[7159324]=f;g=e+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=h;b[7159340]=h&65535;b[7159326]=(b[7159326]|0)-2&65535;h=c[3579663]|0;fj[c[186764]&511](h,f&255);fj[c[186764]&511](h+1&65535,a[14318649]|0);c[3579662]=c[3646042];return}function rV(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=8;b[7159340]=8;return}function rW(){var d=0;if((a[14318656]&1)!=0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function rX(){var d=0;d=c[3579663]|0;a[14318664]=fl[c[186832]&255](d)|0;a[14318665|0]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;return}function rY(){var d=0,e=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;e=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;d=a[14318657|0]|0;fj[c[186762]&511]((d&255)<<8|e&255,d);a[14318680]=e+1&255;a[14318681|0]=a[14318657|0]|0;return}function rZ(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&1)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;e=c[3579663]|0;fj[c[186764]&511](e,g&255);fj[c[186764]&511](e+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}else{b[7159340]=i&65535;return}}function r_(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318664]|0);fj[c[186764]&511](d+1&65535,a[14318665|0]|0);return}function r$(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=16;b[7159340]=16;return}function r0(){var d=0;if((a[14318656]&1)==0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function r1(){var e=0,f=0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(d[14318657|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);a[14318657|0]=fl[c[186830]&255](f)|0;b[7159340]=f+1&65535;return}function r2(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&1)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){b[7159340]=i&65535;return}else{c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;i=c[3579663]|0;fj[c[186764]&511](i,g&255);fj[c[186764]&511](i+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}}function r3(){var a=0,f=0;a=c[3579662]|0;b[7159324]=(a&65535)+1&65535;f=d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0;c[3579678]=(c[3579678]|0)+(e[(c[3118606]|0)+(f<<1)>>1]|0);fG[c[734424+(f<<2)>>2]&16383]();return}function r4(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=24;b[7159340]=24;return}function r5(){var d=0;if((a[14318656]&4)!=0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function r6(){var d=0;d=c[3579663]|0;a[14318676]=fl[c[186832]&255](d)|0;a[14318677|0]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;return}function r7(){var d=0,e=0,f=0;d=c[3579663]|0;e=fl[c[186832]&255](d)|0;f=fl[c[186832]&255](d+1&65535)|0;d=c[3579663]|0;fj[c[186764]&511](d,a[14318676]|0);fj[c[186764]&511](d+1&65535,a[14318677|0]|0);d=(f&255)<<8|e&255;c[3579669]=d;b[7159340]=d&65535;return}function r8(){a[14318703|0]=0;a[14318702|0]=0;return}function r9(){a[14318703|0]=1;a[14318702|0]=1;a[14318710|0]=1;return}function sa(){return}function sb(){b[7159324]=b[7159338]|0;return}function sc(){var a=0;a=c[3579666]|0;c[3579666]=c[3579667];c[3579667]=a;return}function sd(){b[7159326]=b[7159338]|0;return}function se(){var a=0;a=c[3579664]|0;c[3579664]=c[3579671];c[3579671]=a;return}function sf(){b[7159330]=(b[7159330]|0)+1&65535;return}function sg(){var b=0,c=0;b=a[14318657|0]|0;c=b<<1|(b&255)>>>7;a[14318657|0]=c;a[14318656]=c&41|a[14318656]&-60;return}function sh(){var d=0,e=0,f=0;d=c[3579668]|0;e=c[3579665]|0;f=e+d|0;b[7159340]=d+1&65535;a[14318656]=(f>>>16&1|a[14318656]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[7159336]=f&65535;return}function si(){b[7159330]=(b[7159330]|0)-1&65535;return}function sj(){var b=0,c=0,d=0;b=a[14318657|0]|0;c=b&1|a[14318656]&-60;d=(b&255)>>>1;a[14318657|0]=d|b<<7;a[14318656]=c|d&40;return}function sk(){b[7159332]=(b[7159332]|0)+1&65535;return}function sl(){var d=0,e=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;e=a[14318657|0]&a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0];a[14318657|0]=e;a[14318656]=a[14319008+(e&255)|0]|16;return}function sm(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&4)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function sn(){var d=0,e=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;e=a[14318657|0]^a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0];a[14318657|0]=e;a[14318656]=a[14319008+(e&255)|0]|0;return}function so(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]|0)<0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]<<8|d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0];if(e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function sp(){var d=0,e=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;e=a[14318657|0]|a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0];a[14318657|0]=e;a[14318656]=a[14319008+(e&255)|0]|0;return}function sq(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]|0)<0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]<<8|d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0];if(!e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function sr(){var d=0,e=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;e=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(e&255)&255|d)|0]&-41|e&40;return}function ss(){var a=0,e=0;a=c[3579662]|0;b[7159324]=(a&65535)+2&65535;e=a+1|0;b[7159330]=(d[(c[747336+((e>>>10&63)<<2)>>2]|0)+(e&1023)|0]|0)<<8|(d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0);return}function st(){var b=0;b=(a[14318661|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318661|0]=b;return}function su(){var b=0;b=(a[14318661|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318661|0]=b;return}function sv(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318661|0]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function sw(){var b=0;b=(a[14318660]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318660]=b;return}function sx(){var b=0;b=(a[14318660]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318660]=b;return}function sy(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318660]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function sz(){var d=0,e=0,f=0;d=(a[14318661|0]|0)-1&255;a[14318661|0]=d;if(d<<24>>24==0){b[7159324]=(b[7159324]|0)+1&65535;return}else{d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;c[3579678]=(c[3579678]|0)+75;return}}function sA(){var a=0,e=0;a=c[3579662]|0;b[7159324]=(a&65535)+2&65535;e=a+1|0;b[7159332]=(d[(c[747336+((e>>>10&63)<<2)>>2]|0)+(e&1023)|0]|0)<<8|(d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0);return}function sB(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&4)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;e=c[3579663]|0;fj[c[186764]&511](e,g&255);fj[c[186764]&511](e+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}else{b[7159340]=i&65535;return}}function sC(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318676]|0);fj[c[186764]&511](d+1&65535,a[14318677|0]|0);return}function sD(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=32;b[7159340]=32;return}function sE(){var d=0;if((a[14318656]&4)==0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function sF(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&4)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){b[7159340]=i&65535;return}else{c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;i=c[3579663]|0;fj[c[186764]&511](i,g&255);fj[c[186764]&511](i+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}}function sG(){var f=0,g=0;a[14318700]=(a[14318700]|0)+1&255;f=c[3579662]|0;b[7159324]=(f&65535)+1&65535;g=d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0;c[3579678]=(c[3579678]|0)+(e[(c[3118608]|0)+(g<<1)>>1]|0);fG[c[733400+(g<<2)>>2]&16383]();return}function sH(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=40;b[7159340]=40;return}function sI(){var d=0;if((a[14318656]|0)<0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function sJ(){var d=0;d=c[3579663]|0;a[14318656]=fl[c[186832]&255](d)|0;a[14318657|0]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;return}function sK(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]|0)<0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]<<8|d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0];if(e){b[7159340]=i&65535;return}else{c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;i=c[3579663]|0;fj[c[186764]&511](i,g&255);fj[c[186764]&511](i+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}}function sL(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318656]|0);fj[c[186764]&511](d+1&65535,a[14318657|0]|0);return}function sM(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=48;b[7159340]=48;return}function sN(){var d=0;if((a[14318656]|0)>=0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function sO(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]|0)<0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]<<8|d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0];if(e){c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;e=c[3579663]|0;fj[c[186764]&511](e,g&255);fj[c[186764]&511](e+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}else{b[7159340]=i&65535;return}}function sP(){var a=0,f=0;a=c[3579662]|0;b[7159324]=(a&65535)+1&65535;f=d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0;c[3579678]=(c[3579678]|0)+(e[(c[3118606]|0)+(f<<1)>>1]|0);fG[c[732376+(f<<2)>>2]&16383]();return}function sQ(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=56;b[7159340]=56;return}function sR(){fj[c[186764]&511](e[7159330]|0,a[14318657|0]|0);a[14318680]=(b[7159330]&255)+1&255;a[14318681|0]=a[14318657|0]|0;return}function sS(){a[14318657|0]=fl[c[186832]&255](e[7159330]|0)|0;b[7159340]=(b[7159330]|0)+1&65535;return}function sT(){fj[c[186764]&511](e[7159332]|0,a[14318657|0]|0);a[14318680]=(b[7159332]&255)+1&255;a[14318681|0]=a[14318657|0]|0;return}function sU(){return}function sV(){return}function sW(){a[14318661|0]=a[14318660]|0;return}function sX(){a[14318661|0]=a[14318665|0]|0;return}function sY(){a[14318661|0]=a[14318664]|0;return}function sZ(){a[14318661|0]=a[14318673|0]|0;return}function s_(){a[14318661|0]=a[14318672]|0;return}function s$(){a[14318661|0]=a[14318657|0]|0;return}function s0(){a[14318660]=a[14318661|0]|0;return}function s1(){a[14318660]=a[14318665|0]|0;return}function s2(){a[14318660|0]=a[14318664|0]|0;return}function s3(){a[14318660]=a[14318673|0]|0;return}function s4(){a[14318660|0]=a[14318672|0]|0;return}function s5(){a[14318660]=a[14318657|0]|0;return}function s6(){var b=0,c=0,d=0;b=a[14318657|0]|0;c=b<<1;d=a[14318656]|0;a[14318656]=d&-60|(b&255)>>>7|c&40;a[14318657|0]=d&1|c;return}function s7(){var d=0,e=0,f=0;d=c[3579668]|0;e=c[3579666]|0;f=e+d|0;b[7159340]=d+1&65535;a[14318656]=(f>>>16&1|a[14318656]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[7159336]=f&65535;return}function s8(){b[7159332]=(b[7159332]|0)-1&65535;return}function s9(){var b=0,c=0,d=0;b=a[14318657|0]|0;c=(b&255)>>>1;d=a[14318656]|0;a[14318656]=d&-60|b&1|c&40;a[14318657|0]=d<<7|c;return}function ta(){b[7159336]=(b[7159336]|0)+1&65535;return}function tb(){var d=0,e=0;d=c[3579668]|0;b[7159340]=d+1&65535;e=d>>>7;a[14318656]=(d>>>15&1|e&16|e&40|a[14318656]&196)&255;b[7159336]=d<<1&65535;return}function tc(){b[7159336]=(b[7159336]|0)-1&65535;return}function td(){var b=0;b=~a[14318657|0];a[14318657|0]=b;a[14318656]=b&40|a[14318656]&-59|18;return}function te(){b[7159326]=(b[7159326]|0)+1&65535;return}function tf(){a[14318656]=a[14318656]&-20|a[14318657|0]&40|1;return}function tg(){var d=0,e=0,f=0;d=c[3579668]|0;e=c[3579663]|0;f=e+d|0;b[7159340]=d+1&65535;a[14318656]=(f>>>16&1|a[14318656]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[7159336]=f&65535;return}function th(){b[7159326]=(b[7159326]|0)-1&65535;return}function ti(){var b=0;b=a[14318656]|0;a[14318656]=(b<<4&16|b&-19|a[14318657|0]&40)^1;return}function tj(){var b=0;b=(a[14318665|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318665|0]=b;return}function tk(){var b=0;b=(a[14318665|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318665|0]=b;return}function tl(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318665|0]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function tm(){var d=0,e=0,f=0;d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;return}function tn(){var b=0;b=(a[14318664]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318664]=b;return}function to(){var b=0;b=(a[14318664]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318664]=b;return}function tp(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318664]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function tq(){var d=0,e=0,f=0;if((a[14318656]&64)==0){d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;c[3579678]=(c[3579678]|0)+75;return}else{b[7159324]=(b[7159324]|0)+1&65535;return}}function tr(){var a=0,e=0;a=c[3579662]|0;b[7159324]=(a&65535)+2&65535;e=a+1|0;b[7159336]=(d[(c[747336+((e>>>10&63)<<2)>>2]|0)+(e&1023)|0]|0)<<8|(d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0);return}function ts(){var b=0;b=(a[14318673|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318673|0]=b;return}function tt(){var b=0;b=(a[14318673|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318673|0]=b;return}function tu(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318673|0]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function tv(){var b=0,c=0,d=0,e=0,f=0,g=0;b=a[14318657|0]|0;c=a[14318656]|0;d=c&255;e=((b&14)>>>0>9|d&16|0)!=0;do{if((d&2|0)==0){f=e?b+6&255:b;if((d&1|(b&255)>153|0)==0){g=f;break}g=f+96&255}else{f=e?b-6&255:b;if((d&1|(b&255)>153|0)==0){g=f;break}g=f-96&255}}while(0);a[14318656]=(b&255)>153|c&3|a[14319008+(g&255)|0]|(g^b)&16;a[14318657|0]=g;return}function tw(){var d=0,e=0,f=0;if((a[14318656]&64)==0){b[7159324]=(b[7159324]|0)+1&65535;return}else{d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;c[3579678]=(c[3579678]|0)+75;return}}function tx(){var b=0;b=(a[14318672]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318672]=b;return}function ty(){var b=0;b=(a[14318672]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318672]=b;return}function tz(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318672]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function tA(){var d=0,e=0,f=0;if((a[14318656]&1)==0){d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;c[3579678]=(c[3579678]|0)+75;return}else{b[7159324]=(b[7159324]|0)+1&65535;return}}function tB(){var a=0,e=0;a=c[3579662]|0;b[7159324]=(a&65535)+2&65535;e=a+1|0;b[7159326]=(d[(c[747336+((e>>>10&63)<<2)>>2]|0)+(e&1023)|0]|0)<<8|(d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0);return}function tC(){var d=0,e=0,f=0;if((a[14318656]&1)==0){b[7159324]=(b[7159324]|0)+1&65535;return}else{d=c[3579662]|0;e=(d&65535)+1&65535;b[7159324]=e;f=(a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0)+e&65535;b[7159324]=f;b[7159340]=f;c[3579678]=(c[3579678]|0)+75;return}}function tD(){var b=0;b=(a[14318657|0]|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(b&255)|0];a[14318657|0]=b;return}function tE(){var b=0;b=(a[14318657|0]|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(b&255)|0];a[14318657|0]=b;return}function tF(){var d=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;a[14318657|0]=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;return}function tG(){a[14318657|0]=fl[c[186832]&255](e[7159332]|0)|0;b[7159340]=(b[7159332]|0)+1&65535;return}function tH(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;fj[c[186764]&511](g,a[14318672]|0);fj[c[186764]&511](g+1&65535,a[14318673|0]|0);b[7159340]=(c[3646042]|0)+1&65535;return}function tI(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;a[14318672]=fl[c[186832]&255](g)|0;a[14318673|0]=fl[c[186832]&255](g+1&65535)|0;b[7159340]=(c[3646042]|0)+1&65535;return}function tJ(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;fj[c[186764]&511](g,a[14318657|0]|0);a[14318680]=(c[3646042]|0)+1&255;a[14318681|0]=a[14318657|0]|0;return}function tK(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[186764]|0;e=(fl[c[186832]&255](d)|0)+1&255;a[14318656]=a[14318656]&1|a[14319264+(e&255)|0];fj[f&511](d,e);return}function tL(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[186764]|0;e=(fl[c[186832]&255](d)|0)-1&255;a[14318656]=a[14318656]&1|a[14319520+(e&255)|0];fj[f&511](d,e);return}function tM(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[186764]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;fj[f&511](d,a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);return}function tN(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;a[14318657|0]=fl[c[186832]&255](g)|0;b[7159340]=(c[3646042]|0)+1&65535;return}function tO(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318661|0]=fl[c[186832]&255](d)|0;return}function tP(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318660]=fl[c[186832]&255](d)|0;return}function tQ(){return}function tR(){return}function tS(){return}function tT(){return}function tU(){return}function tV(){a[14318665|0]=a[14318661|0]|0;return}function tW(){a[14318665|0]=a[14318660]|0;return}function tX(){a[14318665|0]=a[14318664]|0;return}function tY(){a[14318665|0]=a[14318673|0]|0;return}function tZ(){a[14318665|0]=a[14318672]|0;return}function t_(){a[14318665|0]=a[14318657|0]|0;return}function t$(){a[14318664]=a[14318661|0]|0;return}function t0(){a[14318664|0]=a[14318660|0]|0;return}function t1(){a[14318664]=a[14318665|0]|0;return}function t2(){a[14318664]=a[14318673|0]|0;return}function t3(){a[14318664|0]=a[14318672|0]|0;return}function t4(){a[14318664]=a[14318657|0]|0;return}function t5(){a[14318673|0]=a[14318661|0]|0;return}function t6(){a[14318673|0]=a[14318660]|0;return}function t7(){a[14318673|0]=a[14318665|0]|0;return}function t8(){a[14318673|0]=a[14318664]|0;return}function t9(){a[14318673|0]=a[14318672]|0;return}function ua(){a[14318673|0]=a[14318657|0]|0;return}function ub(){a[14318672]=a[14318661|0]|0;return}function uc(){a[14318672|0]=a[14318660|0]|0;return}function ud(){a[14318672]=a[14318665|0]|0;return}function ue(){a[14318672|0]=a[14318664|0]|0;return}function uf(){a[14318672]=a[14318673|0]|0;return}function ug(){a[14318672]=a[14318657|0]|0;return}function uh(){a[14318657|0]=a[14318661|0]|0;return}function ui(){a[14318657|0]=a[14318660]|0;return}function uj(){a[14318657|0]=a[14318665|0]|0;return}function uk(){a[14318657|0]=a[14318664]|0;return}function ul(){a[14318657|0]=a[14318673|0]|0;return}function um(){a[14318657|0]=a[14318672]|0;return}function un(){b[7159324]=(b[7159324]|0)-1&65535;a[14318704|0]=1;return}function uo(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318661|0]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function up(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318660]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function uq(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318665|0]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function ur(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318664]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function us(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318673|0]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function ut(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318672]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function uu(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)+(d[14318657|0]|0)|0;a[14318656]=a[14450848+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function uv(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318661|0]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function uw(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318660]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function ux(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318665|0]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function uy(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318664]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function uz(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318673|0]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function uA(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318672]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function uB(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(d[14318657|0]|0)+f+(e>>>8)|0;a[14318656]=a[14450848+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function uC(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318661|0]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function uD(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318660]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function uE(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318665|0]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function uF(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318664]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function uG(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318673|0]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function uH(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318672]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function uI(){var b=0,e=0;b=c[3579664]&65280;e=(b>>>8)-(d[14318657|0]|0)|0;a[14318656]=a[14319776+(e&255|b)|0]|0;a[14318657|0]=e&255;return}function uJ(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318661|0]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function uK(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318660]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function uL(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318665|0]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function uM(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318664]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function uN(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318665|0]=fl[c[186832]&255](d)|0;return}function uO(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318664]=fl[c[186832]&255](d)|0;return}function uP(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318669|0]=fl[c[186832]&255](d)|0;return}function uQ(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318668]=fl[c[186832]&255](d)|0;return}function uR(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318661|0]|0);return}function uS(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318660]|0);return}function uT(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318665|0]|0);return}function uU(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318664]|0);return}function uV(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318669|0]|0);return}function uW(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318668]|0);return}function uX(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;fj[c[186764]&511](d,a[14318657|0]|0);return}function uY(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;a[14318657|0]=fl[c[186832]&255](d)|0;return}function uZ(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[3579664]&65280;e=((fl[c[186832]&255](d)|0)&255)+(f>>>8)|0;a[14318656]=a[14450848+(e&255|f)|0]|0;a[14318657|0]=e&255;return}function u_(){var d=0,e=0,f=0,g=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[3579664]|0;e=f&65280;g=f&1;f=(e>>>8)+g+((fl[c[186832]&255](d)|0)&255)|0;a[14318656]=a[14450848+(g<<16|e|f&255)|0]|0;a[14318657|0]=f&255;return}function u$(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[3579664]&65280;e=(f>>>8)-((fl[c[186832]&255](d)|0)&255)|0;a[14318656]=a[14319776+(e&255|f)|0]|0;a[14318657|0]=e&255;return}function u0(){a[14318657|0]=0;a[14318656]=a[14319008]|0;return}function u1(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318673|0]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function u2(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318672]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function u3(){var b=0,e=0,f=0;b=c[3579664]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[14318657|0]|0)-f|0;a[14318656]=a[14319776+(f<<16|e|b&255)|0]|0;a[14318657|0]=b&255;return}function u4(){var b=0;b=a[14318657|0]&a[14318661|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function u5(){var b=0;b=a[14318657|0]&a[14318660];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function u6(){var b=0;b=a[14318657|0]&a[14318665|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function u7(){var b=0;b=a[14318657|0]&a[14318664];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function u8(){var b=0;b=a[14318657|0]&a[14318673|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function u9(){var b=0;b=a[14318657|0]&a[14318672];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|16;return}function va(){a[14318656]=a[14319008+(d[14318657|0]|0)|0]|16;return}function vb(){var b=0;b=a[14318657|0]^a[14318661|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vc(){var b=0;b=a[14318657|0]^a[14318660];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vd(){var b=0;b=a[14318657|0]^a[14318665|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function ve(){var b=0;b=a[14318657|0]^a[14318664];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vf(){var b=0;b=a[14318657|0]^a[14318673|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vg(){var b=0;b=a[14318657|0]^a[14318672];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vh(){var b=0;b=a[14318657|0]|a[14318661|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vi(){var b=0;b=a[14318657|0]|a[14318660];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vj(){var b=0;b=a[14318657|0]|a[14318665|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vk(){var b=0;b=a[14318657|0]|a[14318664];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vl(){var b=0;b=a[14318657|0]|a[14318673|0];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vm(){var b=0;b=a[14318657|0]|a[14318672];a[14318657|0]=b;a[14318656]=a[14319008+(b&255)|0]|0;return}function vn(){a[14318656]=a[14319008+(d[14318657|0]|0)|0]|0;return}function vo(){var b=0,d=0;b=a[14318661|0]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function vp(){var b=0,d=0;b=a[14318660]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function vq(){var b=0,d=0;b=a[14318665|0]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function vr(){var b=0,d=0;b=a[14318664]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function vs(){var b=0,d=0;b=a[14318673|0]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function vt(){var b=0,d=0;b=a[14318672]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function vu(){var b=0,d=0;b=a[14318657|0]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function vv(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&64)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(!e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function vw(){var a=0,e=0,f=0;a=c[3579662]|0;b[7159324]=(a&65535)+2&65535;e=a+1|0;f=(d[(c[747336+((e>>>10&63)<<2)>>2]|0)+(e&1023)|0]|0)<<8|(d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0);c[3579662]=f;b[7159340]=f&65535;return}function vx(){var e=0,f=0,g=0;e=c[3579664]&65280;f=c[3579662]|0;b[7159324]=(f&65535)+1&65535;g=(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0)+(e>>>8)|0;a[14318656]=a[14450848+(g&255|e)|0]|0;a[14318657|0]=g&255;return}function vy(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&64)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function vz(){var d=0,e=0,f=0,g=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=c[3579664]|0;e=f&65280;g=f&1;f=(e>>>8)-((fl[c[186832]&255](d)|0)&255)-g|0;a[14318656]=a[14319776+(g<<16|e|f&255)|0]|0;a[14318657|0]=f&255;return}function vA(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=fl[c[186832]&255](d)|0;d=a[14318657|0]&f;a[14318657|0]=d;a[14318656]=a[14319008+(d&255)|0]|16;return}function vB(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=fl[c[186832]&255](d)|0;d=a[14318657|0]^f;a[14318657|0]=d;a[14318656]=a[14319008+(d&255)|0]|0;return}function vC(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=fl[c[186832]&255](d)|0;d=a[14318657|0]|f;a[14318657|0]=d;a[14318656]=a[14319008+(d&255)|0]|0;return}function vD(){var d=0,e=0,f=0;d=b[7159336]|0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)+d&65535;d=f&65535;c[3646042]=d;b[7159340]=f;f=fl[c[186832]&255](d)|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(f&255)&255|d)|0]&-41|f&40;return}function vE(){var d=0;if((a[14318656]&64)!=0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function vF(){var d=0;d=c[3579663]|0;a[14318660]=fl[c[186832]&255](d)|0;a[14318661|0]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;return}function vG(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&64)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;e=c[3579663]|0;fj[c[186764]&511](e,g&255);fj[c[186764]&511](e+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}else{b[7159340]=i&65535;return}}function vH(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318660]|0);fj[c[186764]&511](d+1&65535,a[14318661|0]|0);return}function vI(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=0;b[7159340]=0;return}function vJ(){var d=0;if((a[14318656]&64)==0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function vK(){var d=0;d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=c[3579662]&65535;return}function vL(){var f=0,g=0,h=0;f=b[7159336]|0;g=c[3579662]|0;b[7159324]=(g&65535)+1&65535;h=(a[(c[747336+(g>>>10<<2)>>2]|0)+(g&1023)|0]|0)+f&65535;c[3646042]=h&65535;b[7159340]=h;h=c[3579662]|0;b[7159324]=(h&65535)+1&65535;f=d[(c[747336+(h>>>10<<2)>>2]|0)+(h&1023)|0]|0;c[3579678]=(c[3579678]|0)+(e[(c[3118604]|0)+(f<<1)>>1]|0);fG[c[731352+(f<<2)>>2]&16383]();return}function vM(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&64)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){b[7159340]=i&65535;return}else{c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;i=c[3579663]|0;fj[c[186764]&511](i,g&255);fj[c[186764]&511](i+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}}function vN(){var a=0;a=c[3579665]|0;c[3579665]=c[3579672];c[3579672]=a;a=c[3579666]|0;c[3579666]=c[3579673];c[3579673]=a;a=c[3579667]|0;c[3579667]=c[3579674];c[3579674]=a;return}function vO(){b[7159324]=b[7159336]|0;return}function vP(){var a=0;a=c[3579666]|0;c[3579666]=c[3579667];c[3579667]=a;return}function vQ(){var e=0,f=0,g=0,h=0;e=c[3579664]|0;f=e&65280;g=e&1;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;h=(f>>>8)+g+(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)|0;a[14318656]=a[14450848+(g<<16|f|h&255)|0]|0;a[14318657|0]=h&255;return}function vR(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&1)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(!e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function vS(){var e=0,f=0,g=0;e=c[3579664]&65280;f=c[3579662]|0;b[7159324]=(f&65535)+1&65535;g=(e>>>8)-(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0)|0;a[14318656]=a[14319776+(g&255|e)|0]|0;a[14318657|0]=g&255;return}function vT(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&1)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function vU(){var e=0,f=0,g=0,h=0;e=c[3579664]|0;f=e&65280;g=e&1;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;h=(f>>>8)-(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0)-g|0;a[14318656]=a[14319776+(g<<16|f|h&255)|0]|0;a[14318657|0]=h&255;return}function vV(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&4)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(!e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function vW(){var d=0,e=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;e=a[14318657|0]&a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0];a[14318657|0]=e;a[14318656]=a[14319008+(e&255)|0]|16;return}function vX(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&4)==0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function vY(){var d=0,e=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;e=a[14318657|0]^a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0];a[14318657|0]=e;a[14318656]=a[14319008+(e&255)|0]|0;return}function vZ(){var e=0,f=0,g=0,h=0;e=c[3579662]|0;f=(e&65535)+2&65535;b[7159324]=f;g=e+1|0;h=(d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=h;b[7159340]=h&65535;b[7159326]=(b[7159326]|0)-2&65535;h=c[3579663]|0;fj[c[186764]&511](h,f&255);fj[c[186764]&511](h+1&65535,a[14318649]|0);c[3579662]=c[3646042];return}function v_(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=8;b[7159340]=8;return}function v$(){var d=0;if((a[14318656]&1)!=0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function v0(){var d=0;d=c[3579663]|0;a[14318664]=fl[c[186832]&255](d)|0;a[14318665|0]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;return}function v1(){var d=0,e=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;e=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;d=a[14318657|0]|0;fj[c[186762]&511]((d&255)<<8|e&255,d);a[14318680]=e+1&255;a[14318681|0]=a[14318657|0]|0;return}function v2(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&1)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;e=c[3579663]|0;fj[c[186764]&511](e,g&255);fj[c[186764]&511](e+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}else{b[7159340]=i&65535;return}}function v3(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318664]|0);fj[c[186764]&511](d+1&65535,a[14318665|0]|0);return}function v4(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=16;b[7159340]=16;return}function v5(){var d=0;if((a[14318656]&1)==0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function v6(){var e=0,f=0;e=c[3579662]|0;b[7159324]=(e&65535)+1&65535;f=(d[14318657|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);a[14318657|0]=fl[c[186830]&255](f)|0;b[7159340]=f+1&65535;return}function v7(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&1)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){b[7159340]=i&65535;return}else{c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;i=c[3579663]|0;fj[c[186764]&511](i,g&255);fj[c[186764]&511](i+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}}function v8(){var a=0,f=0;a=c[3579662]|0;b[7159324]=(a&65535)+1&65535;f=d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0;c[3579678]=(c[3579678]|0)+(e[(c[3118606]|0)+(f<<1)>>1]|0);fG[c[734424+(f<<2)>>2]&16383]();return}function v9(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=24;b[7159340]=24;return}function wa(){var d=0;if((a[14318656]&4)!=0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function wb(){var d=0;d=c[3579663]|0;a[14318672]=fl[c[186832]&255](d)|0;a[14318673|0]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;return}function wc(){var d=0,e=0,f=0;d=c[3579663]|0;e=fl[c[186832]&255](d)|0;f=fl[c[186832]&255](d+1&65535)|0;d=c[3579663]|0;fj[c[186764]&511](d,a[14318672]|0);fj[c[186764]&511](d+1&65535,a[14318673|0]|0);d=(f&255)<<8|e&255;c[3579668]=d;b[7159340]=d&65535;return}function wd(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&4)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;e=c[3579663]|0;fj[c[186764]&511](e,g&255);fj[c[186764]&511](e+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}else{b[7159340]=i&65535;return}}function we(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318672]|0);fj[c[186764]&511](d+1&65535,a[14318673|0]|0);return}function wf(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=32;b[7159340]=32;return}function wg(){var d=0;if((a[14318656]&4)==0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function wh(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]&4)==0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=(d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0)<<8|(d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0);if(e){b[7159340]=i&65535;return}else{c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;i=c[3579663]|0;fj[c[186764]&511](i,g&255);fj[c[186764]&511](i+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}}function wi(){var f=0,g=0;a[14318700]=(a[14318700]|0)+1&255;f=c[3579662]|0;b[7159324]=(f&65535)+1&65535;g=d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0]|0;c[3579678]=(c[3579678]|0)+(e[(c[3118608]|0)+(g<<1)>>1]|0);fG[c[733400+(g<<2)>>2]&16383]();return}function wj(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=40;b[7159340]=40;return}function wk(){var d=0;if((a[14318656]|0)<0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function wl(){a[14318703|0]=0;a[14318702|0]=0;return}function wm(){a[14318703|0]=1;a[14318702|0]=1;a[14318710|0]=1;return}function wn(){b[7159326]=b[7159336]|0;return}function wo(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]|0)<0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]<<8|d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0];if(e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function wp(){var d=0,e=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;e=a[14318657|0]|a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0];a[14318657|0]=e;a[14318656]=a[14319008+(e&255)|0]|0;return}function wq(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]|0)<0;f=c[3579662]|0;b[7159324]=(f&65535)+2&65535;g=f+1|0;h=d[(c[747336+((g>>>10&63)<<2)>>2]|0)+(g&1023)|0]<<8|d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0];if(!e){i=h&65535;b[7159340]=i;return}c[3579662]=h;i=h&65535;b[7159340]=i;return}function wr(){var d=0,e=0;d=c[3579662]|0;b[7159324]=(d&65535)+1&65535;e=a[(c[747336+(d>>>10<<2)>>2]|0)+(d&1023)|0]|0;d=c[3579664]&65280;a[14318656]=a[14319776+((d>>>8)-(e&255)&255|d)|0]&-41|e&40;return}function ws(){var d=0;d=c[3579663]|0;a[14318656]=fl[c[186832]&255](d)|0;a[14318657|0]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;return}function wt(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]|0)<0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]<<8|d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0];if(e){b[7159340]=i&65535;return}else{c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;i=c[3579663]|0;fj[c[186764]&511](i,g&255);fj[c[186764]&511](i+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}}function wu(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318656]|0);fj[c[186764]&511](d+1&65535,a[14318657|0]|0);return}function wv(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=48;b[7159340]=48;return}function ww(){var d=0;if((a[14318656]|0)>=0){return}d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;c[3579678]=(c[3579678]|0)+90;return}function wx(){var e=0,f=0,g=0,h=0,i=0;e=(a[14318656]|0)<0;f=c[3579662]|0;g=(f&65535)+2&65535;b[7159324]=g;h=f+1|0;i=d[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]<<8|d[(c[747336+(f>>>10<<2)>>2]|0)+(f&1023)|0];if(e){c[3646042]=i;b[7159340]=i&65535;b[7159326]=(b[7159326]|0)-2&65535;e=c[3579663]|0;fj[c[186764]&511](e,g&255);fj[c[186764]&511](e+1&65535,a[14318649]|0);c[3579662]=c[3646042];c[3579678]=(c[3579678]|0)+105;return}else{b[7159340]=i&65535;return}}function wy(){var a=0,f=0;a=c[3579662]|0;b[7159324]=(a&65535)+1&65535;f=d[(c[747336+(a>>>10<<2)>>2]|0)+(a&1023)|0]|0;c[3579678]=(c[3579678]|0)+(e[(c[3118606]|0)+(f<<1)>>1]|0);fG[c[732376+(f<<2)>>2]&16383]();return}function wz(){var d=0;b[7159326]=(b[7159326]|0)-2&65535;d=c[3579663]|0;fj[c[186764]&511](d,a[14318648]|0);fj[c[186764]&511](d+1&65535,a[14318649]|0);c[3579662]=56;b[7159340]=56;return}function wA(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<1&254|d>>>7;a[14318656]=a[14319008+e|0]|(b&255)>>>7;b=e&255;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wB(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<1&254|d>>>7;a[14318656]=a[14319008+e|0]|(b&255)>>>7;b=e&255;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wC(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<1&254|d>>>7;a[14318656]=a[14319008+e|0]|(b&255)>>>7;b=e&255;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wD(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<1&254|d>>>7;a[14318656]=a[14319008+e|0]|(b&255)>>>7;b=e&255;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wE(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<1&254|d>>>7;a[14318656]=a[14319008+e|0]|(b&255)>>>7;b=e&255;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wF(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<1&254|d>>>7;a[14318656]=a[14319008+e|0]|(b&255)>>>7;b=e&255;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wG(){var b=0,d=0,e=0,f=0,g=0;b=c[186764]|0;d=c[3646042]|0;e=fl[c[186832]&255](d)|0;f=e&255;g=f<<1&254|f>>>7;a[14318656]=a[14319008+g|0]|(e&255)>>>7;fj[b&511](d,g&255);return}function wH(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<1&254|d>>>7;a[14318656]=a[14319008+e|0]|(b&255)>>>7;b=e&255;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wI(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<7&128|d>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wJ(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<7&128|d>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wK(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<7&128|d>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wL(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<7&128|d>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wM(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<7&128|d>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wN(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<7&128|d>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wO(){var b=0,d=0,e=0,f=0,g=0;b=c[186764]|0;d=c[3646042]|0;e=fl[c[186832]&255](d)|0;f=e&255;g=f<<7&128|f>>>1;a[14318656]=a[14319008+g|0]|e&1;fj[b&511](d,g&255);return}function wP(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d<<7&128|d>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wQ(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wR(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wS(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wT(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wU(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wV(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wW(){var b=0,d=0,e=0,f=0;b=c[186764]|0;d=c[3646042]|0;e=fl[c[186832]&255](d)|0;f=a[14318656]&1|(e&255)<<1&254;a[14318656]=a[14319008+f|0]|(e&255)>>>7;fj[b&511](d,f&255);return}function wX(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wY(){var b=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;e=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function wZ(){var b=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;e=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w_(){var b=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;e=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w$(){var b=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;e=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w0(){var b=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;e=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w1(){var b=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;e=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w2(){var b=0,e=0,f=0,g=0;b=c[186764]|0;e=c[3646042]|0;f=fl[c[186832]&255](e)|0;g=(d[14318656]|0)<<7&128|(f&255)>>>1;a[14318656]=a[14319008+g|0]|f&1;fj[b&511](e,g&255);return}function w3(){var b=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;e=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w4(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1;a[14318656]=a[14319008+(d&254)|0]|(b&255)>>>7;b=d&255;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w5(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1;a[14318656]=a[14319008+(d&254)|0]|(b&255)>>>7;b=d&255;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w6(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1;a[14318656]=a[14319008+(d&254)|0]|(b&255)>>>7;b=d&255;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w7(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1;a[14318656]=a[14319008+(d&254)|0]|(b&255)>>>7;b=d&255;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w8(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1;a[14318656]=a[14319008+(d&254)|0]|(b&255)>>>7;b=d&255;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function w9(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1;a[14318656]=a[14319008+(d&254)|0]|(b&255)>>>7;b=d&255;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xa(){var b=0,d=0,e=0,f=0;b=c[186764]|0;d=c[3646042]|0;e=fl[c[186832]&255](d)|0;f=(e&255)<<1;a[14318656]=a[14319008+(f&254)|0]|(e&255)>>>7;fj[b&511](d,f&255);return}function xb(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1;a[14318656]=a[14319008+(d&254)|0]|(b&255)>>>7;b=d&255;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xc(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d>>>1|d&128;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xd(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d>>>1|d&128;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xe(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d>>>1|d&128;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xf(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d>>>1|d&128;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xg(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d>>>1|d&128;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xh(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d>>>1|d&128;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xi(){var b=0,d=0,e=0,f=0,g=0;b=c[186764]|0;d=c[3646042]|0;e=fl[c[186832]&255](d)|0;f=e&255;g=f>>>1|f&128;a[14318656]=a[14319008+g|0]|e&1;fj[b&511](d,g&255);return}function xj(){var b=0,d=0,e=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=b&255;e=d>>>1|d&128;a[14318656]=a[14319008+e|0]|b&1;b=e&255;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xk(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1&254|1;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xl(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1&254|1;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xm(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1&254|1;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xn(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1&254|1;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xo(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1&254|1;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xp(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1&254|1;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xq(){var b=0,d=0,e=0,f=0;b=c[186764]|0;d=c[3646042]|0;e=fl[c[186832]&255](d)|0;f=(e&255)<<1&254|1;a[14318656]=a[14319008+f|0]|(e&255)>>>7;fj[b&511](d,f&255);return}function xr(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)<<1&254|1;a[14318656]=a[14319008+d|0]|(b&255)>>>7;b=d&255;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xs(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)>>>1;a[14318656]=a[14319008+d|0]|b&1;b=d&255;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xt(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)>>>1;a[14318656]=a[14319008+d|0]|b&1;b=d&255;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xu(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)>>>1;a[14318656]=a[14319008+d|0]|b&1;b=d&255;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xv(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)>>>1;a[14318656]=a[14319008+d|0]|b&1;b=d&255;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xw(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)>>>1;a[14318656]=a[14319008+d|0]|b&1;b=d&255;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xx(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)>>>1;a[14318656]=a[14319008+d|0]|b&1;b=d&255;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xy(){var b=0,d=0,e=0,f=0;b=c[186764]|0;d=c[3646042]|0;e=fl[c[186832]&255](d)|0;f=(e&255)>>>1;a[14318656]=a[14319008+f|0]|e&1;fj[b&511](d,f&255);return}function xz(){var b=0,d=0;b=fl[c[186832]&255](c[3646042]|0)|0;d=(b&255)>>>1;a[14318656]=a[14319008+d|0]|b&1;b=d&255;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function xA(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&1)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xB(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&1)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xC(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&1)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xD(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&1)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xE(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&1)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xF(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&1)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xG(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&1)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xH(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&1)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xI(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&2)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xJ(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&2)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xK(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&2)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xL(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&2)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xM(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&2)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xN(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&2)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xO(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&2)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xP(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&2)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xQ(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&4)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xR(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&4)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xS(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&4)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xT(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&4)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xU(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&4)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xV(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&4)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xW(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&4)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xX(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&4)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xY(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&8)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function xZ(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&8)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x_(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&8)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x$(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&8)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x0(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&8)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x1(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&8)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x2(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&8)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x3(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&8)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x4(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&16)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x5(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&16)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x6(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&16)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x7(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&16)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x8(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&16)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function x9(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&16)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function ya(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&16)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yb(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&16)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yc(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&32)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yd(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&32)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function ye(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&32)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yf(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&32)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yg(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&32)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yh(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&32)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yi(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&32)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yj(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&32)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yk(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&64)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yl(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&64)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function ym(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&64)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yn(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&64)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yo(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&64)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yp(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&64)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yq(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&64)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yr(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&64)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function ys(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&128)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yt(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&128)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yu(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&128)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yv(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&128)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yw(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&128)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yx(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&128)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yy(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&128)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yz(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](c[3646042]|0)|0)&128)|0]&199;a[14318656]=(b|d|(c[3646042]|0)>>>8&40|16)&255;return}function yA(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-2;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yB(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-2;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yC(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-2;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yD(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-2;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yE(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-2;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yF(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-2;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yG(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=(fl[c[186832]&255](b)|0)&-2;fj[a&511](b,d);return}function yH(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-2;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yI(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-3;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yJ(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-3;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yK(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-3;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yL(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-3;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yM(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-3;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yN(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-3;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yO(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=(fl[c[186832]&255](b)|0)&-3;fj[a&511](b,d);return}function yP(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-3;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yQ(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-5;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yR(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-5;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yS(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-5;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yT(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-5;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yU(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-5;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yV(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-5;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yW(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=(fl[c[186832]&255](b)|0)&-5;fj[a&511](b,d);return}function yX(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-5;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yY(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-9;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function yZ(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-9;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y_(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-9;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y$(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-9;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y0(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-9;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y1(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-9;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y2(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=(fl[c[186832]&255](b)|0)&-9;fj[a&511](b,d);return}function y3(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-9;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y4(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-17;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y5(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-17;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y6(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-17;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y7(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-17;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y8(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-17;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function y9(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-17;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function za(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=(fl[c[186832]&255](b)|0)&-17;fj[a&511](b,d);return}function zb(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-17;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zc(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-33;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zd(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-33;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function ze(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-33;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zf(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-33;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zg(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-33;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zh(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-33;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zi(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=(fl[c[186832]&255](b)|0)&-33;fj[a&511](b,d);return}function zj(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-33;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zk(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-65;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zl(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-65;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zm(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-65;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zn(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-65;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zo(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-65;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zp(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-65;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zq(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=(fl[c[186832]&255](b)|0)&-65;fj[a&511](b,d);return}function zr(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&-65;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zs(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&127;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zt(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&127;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zu(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&127;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zv(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&127;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zw(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&127;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zx(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&127;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zy(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=(fl[c[186832]&255](b)|0)&127;fj[a&511](b,d);return}function zz(){var b=0;b=(fl[c[186832]&255](c[3646042]|0)|0)&127;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zA(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|1;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zB(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|1;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zC(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|1;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zD(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|1;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zE(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|1;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zF(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|1;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zG(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=fl[c[186832]&255](b)|0|1;fj[a&511](b,d);return}function zH(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|1;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zI(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|2;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zJ(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|2;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zK(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|2;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zL(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|2;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zM(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|2;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function zN(){return}function zO(){return}function zP(){return}function zQ(){return}function zR(){return}function zS(){return}function zT(){return}function zU(){return}function zV(){return}function zW(){return}function zX(){return}function zY(){return}function zZ(){return}function z_(){return}function z$(){return}function z0(){return}function z1(){return}function z2(){return}function z3(){return}function z4(){return}function z5(){return}function z6(){return}function z7(){return}function z8(){return}function z9(){return}function Aa(){return}function Ab(){return}function Ac(){return}function Ad(){return}function Ae(){return}function Af(){return}function Ag(){return}function Ah(){return}function Ai(){return}function Aj(){return}function Ak(){return}function Al(){return}function Am(){return}function An(){return}function Ao(){return}function Ap(){return}function Aq(){return}function Ar(){return}function As(){return}function At(){return}function Au(){return}function Av(){return}function Aw(){return}function Ax(){return}function Ay(){return}function Az(){return}function AA(){return}function AB(){return}function AC(){return}function AD(){return}function AE(){return}function AF(){return}function AG(){return}function AH(){return}function AI(){return}function AJ(){return}function AK(){return}function AL(){return}function AM(){return}function AN(){a[14318705|0]=0;return}function AO(){a[14318706]=a[14318657|0]|0;return}function AP(){var d=0,e=0,f=0,g=0;d=c[3579667]|0;e=c[3579665]|0;f=d-e-(a[14318656]&1)|0;b[7159340]=(d&65535)+1&65535;g=f^d;a[14318656]=(f>>>8&168|f>>>16&1|((f&65535|0)!=0?0:64)|(g^e)>>>8&16|(g&(e^d))>>>13&4|2)&255;b[7159334]=f&65535;return}function AQ(){var d=0,e=0,f=0;d=c[3579667]|0;e=c[3579665]|0;f=e+d+(a[14318656]&1)|0;b[7159340]=(d&65535)+1&65535;a[14318656]=(f>>>8&168|f>>>16&1|((f&65535|0)!=0?0:64)|(e^d^f)>>>8&16|((f^e)&(d^32768^e))>>>13&4)&255;b[7159334]=f&65535;return}function AR(){var b=0,d=0,e=0;b=a[14318657|0]|0;a[14318657|0]=0;d=c[3579664]&65280;e=(d>>>8)-(b&255)|0;a[14318656]=a[14319776+(e&255|d)|0]|0;a[14318657|0]=e&255;return}function AS(){var b=0,d=0,e=0;b=a[14318657|0]|0;a[14318657|0]=0;d=c[3579664]&65280;e=(d>>>8)-(b&255)|0;a[14318656]=a[14319776+(e&255|d)|0]|0;a[14318657|0]=e&255;return}function AT(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|2;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function AU(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=fl[c[186832]&255](b)|0|2;fj[a&511](b,d);return}function AV(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|2;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function AW(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|4;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function AX(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|4;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function AY(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|4;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function AZ(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|4;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function A_(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|4;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function A$(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|4;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function A0(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=fl[c[186832]&255](b)|0|4;fj[a&511](b,d);return}function A1(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|4;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function A2(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|8;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function A3(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|8;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function A4(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|8;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function A5(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|8;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function A6(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|8;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function A7(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|8;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function A8(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=fl[c[186832]&255](b)|0|8;fj[a&511](b,d);return}function A9(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|8;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Ba(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|16;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bb(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|16;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bc(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|16;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bd(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|16;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Be(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|16;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bf(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|16;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bg(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=fl[c[186832]&255](b)|0|16;fj[a&511](b,d);return}function Bh(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|16;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bi(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|32;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bj(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|32;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bk(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|32;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bl(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|32;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bm(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|32;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bn(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|32;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bo(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=fl[c[186832]&255](b)|0|32;fj[a&511](b,d);return}function Bp(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|32;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bq(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|64;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Br(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|64;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bs(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|64;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bt(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|64;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bu(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|64;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bv(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|64;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bw(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=fl[c[186832]&255](b)|0|64;fj[a&511](b,d);return}function Bx(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|64;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function By(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|-128;a[14318661|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function Bz(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|-128;a[14318660]=b;fj[c[186764]&511](c[3646042]|0,b);return}function BA(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|-128;a[14318665|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function BB(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|-128;a[14318664]=b;fj[c[186764]&511](c[3646042]|0,b);return}function BC(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|-128;a[14318669|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function BD(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|-128;a[14318668]=b;fj[c[186764]&511](c[3646042]|0,b);return}function BE(){var a=0,b=0,d=0;a=c[186764]|0;b=c[3646042]|0;d=fl[c[186832]&255](b)|0|-128;fj[a&511](b,d);return}function BF(){var b=0;b=fl[c[186832]&255](c[3646042]|0)|0|-128;a[14318657|0]=b;fj[c[186764]&511](c[3646042]|0,b);return}function BG(){var b=0;b=fl[c[186830]&255](e[7159330]|0)|0;a[14318661|0]=b;a[14318656]=a[14318656]&1|a[14319008+(b&255)|0];return}function BH(){fj[c[186762]&511](e[7159330]|0,a[14318661|0]|0);return}function BI(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;fj[c[186764]&511](g,a[14318660]|0);fj[c[186764]&511](g+1&65535,a[14318661|0]|0);b[7159340]=(c[3646042]|0)+1&65535;return}function BJ(){var d=0;d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;a[14318702]=a[14318703]|0;return}function BK(){var b=0;b=fl[c[186830]&255](e[7159330]|0)|0;a[14318660]=b;a[14318656]=a[14318656]&1|a[14319008+(b&255)|0];return}function BL(){var a=0;a=b[7159330]|0;fj[c[186762]&511](a&65535,a&255);return}function BM(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;a[14318660]=fl[c[186832]&255](g)|0;a[14318661|0]=fl[c[186832]&255](g+1&65535)|0;b[7159340]=(c[3646042]|0)+1&65535;return}function BN(){a[14318705|0]=0;return}function BO(){a[14318705|0]=1;return}function BP(){a[14318705|0]=2;return}function BQ(){a[14318705|0]=0;return}function BR(){a[14318705|0]=0;return}function BS(){a[14318705|0]=1;return}function BT(){return}function BU(){a[14318705|0]=2;return}function BV(){return}function BW(){return}function BX(){return}function BY(){return}function BZ(){return}function B_(){return}function B$(){return}function B0(){return}function B1(){return}function B2(){return}function B3(){return}function B4(){return}function B5(){return}function B6(){return}function B7(){return}function B8(){return}function B9(){return}function Ca(){return}function Cb(){return}function Cc(){var b=0;b=a[14318657|0]|0;a[14318700]=b;a[14318701]=b&-128;return}function Cd(){var d=0,e=0,f=0,g=0;d=c[3579667]|0;e=c[3579666]|0;f=d-e-(a[14318656]&1)|0;b[7159340]=(d&65535)+1&65535;g=f^d;a[14318656]=(f>>>8&168|f>>>16&1|((f&65535|0)!=0?0:64)|(g^e)>>>8&16|(g&(e^d))>>>13&4|2)&255;b[7159334]=f&65535;return}function Ce(){var d=0,e=0,f=0;d=c[3579667]|0;e=c[3579666]|0;f=e+d+(a[14318656]&1)|0;b[7159340]=(d&65535)+1&65535;a[14318656]=(f>>>8&168|f>>>16&1|((f&65535|0)!=0?0:64)|(e^d^f)>>>8&16|((f^e)&(d^32768^e))>>>13&4)&255;b[7159334]=f&65535;return}function Cf(){var c=0,d=0;c=-(a[14318656]&1)|0;b[7159340]=(b[7159334]|0)+1&65535;d=c>>>8;a[14318656]=(d&16|c>>>16&1|d&168|((c&65535|0)!=0?0:64)|2)&255;b[7159334]=c&65535;return}function Cg(){var d=0,e=0,f=0,g=0;d=c[3579667]|0;e=d<<1;f=a[14318656]&1|e;b[7159340]=(d&65535)+1&65535;g=d>>>7;a[14318656]=(g&16|d>>>15&1|g&168|(e^d)>>>13&4|((f&65535|0)!=0?0:64))&255;b[7159334]=f&65535;return}function Ch(){var d=0,e=0,f=0,g=0;d=c[3579667]|0;e=c[3579663]|0;f=d-e-(a[14318656]&1)|0;b[7159340]=(d&65535)+1&65535;g=f^d;a[14318656]=(f>>>8&168|f>>>16&1|((f&65535|0)!=0?0:64)|(g^e)>>>8&16|(g&(e^d))>>>13&4|2)&255;b[7159334]=f&65535;return}function Ci(){var d=0,e=0,f=0;d=c[3579667]|0;e=c[3579663]|0;f=e+d+(a[14318656]&1)|0;b[7159340]=(d&65535)+1&65535;a[14318656]=(f>>>8&168|f>>>16&1|((f&65535|0)!=0?0:64)|(e^d^f)>>>8&16|((f^e)&(d^32768^e))>>>13&4)&255;b[7159334]=f&65535;return}function Cj(){var b=0,d=0,e=0;b=a[14318657|0]|0;a[14318657|0]=0;d=c[3579664]&65280;e=(d>>>8)-(b&255)|0;a[14318656]=a[14319776+(e&255|d)|0]|0;a[14318657|0]=e&255;return}function Ck(){var b=0;b=a[14318706]|0;a[14318657|0]=b;a[14318656]=a[14318656]&1|a[14581920+(b&255)|0]|a[14318703]<<2;return}function Cl(){var b=0,d=0,e=0;b=a[14318657|0]|0;a[14318657|0]=0;d=c[3579664]&65280;e=(d>>>8)-(b&255)|0;a[14318656]=a[14319776+(e&255|d)|0]|0;a[14318657|0]=e&255;return}function Cm(){var b=0;b=a[14318700]&127|a[14318701];a[14318657|0]=b;a[14318656]=a[14318656]&1|a[14581920+(b&255)|0]|a[14318703]<<2;return}function Cn(){var b=0,d=0,e=0;b=a[14318657|0]|0;a[14318657|0]=0;d=c[3579664]&65280;e=(d>>>8)-(b&255)|0;a[14318656]=a[14319776+(e&255|d)|0]|0;a[14318657|0]=e&255;return}function Co(){var b=0,d=0,e=0;b=a[14318657|0]|0;a[14318657|0]=0;d=c[3579664]&65280;e=(d>>>8)-(b&255)|0;a[14318656]=a[14319776+(e&255|d)|0]|0;a[14318657|0]=e&255;return}function Cp(){var b=0,d=0,e=0;b=a[14318657|0]|0;a[14318657|0]=0;d=c[3579664]&65280;e=(d>>>8)-(b&255)|0;a[14318656]=a[14319776+(e&255|d)|0]|0;a[14318657|0]=e&255;return}function Cq(){var b=0,d=0,e=0;b=a[14318657|0]|0;a[14318657|0]=0;d=c[3579664]&65280;e=(d>>>8)-(b&255)|0;a[14318656]=a[14319776+(e&255|d)|0]|0;a[14318657|0]=e&255;return}function Cr(){var d=0;d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;a[14318702]=a[14318703]|0;return}function Cs(){var b=0;b=fl[c[186830]&255](e[7159330]|0)|0;a[14318665|0]=b;a[14318656]=a[14318656]&1|a[14319008+(b&255)|0];return}function Ct(){fj[c[186762]&511](e[7159330]|0,a[14318665|0]|0);return}function Cu(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;fj[c[186764]&511](g,a[14318664]|0);fj[c[186764]&511](g+1&65535,a[14318665|0]|0);b[7159340]=(c[3646042]|0)+1&65535;return}function Cv(){var d=0;d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;a[14318702]=a[14318703]|0;return}function Cw(){var b=0;b=fl[c[186830]&255](e[7159330]|0)|0;a[14318664]=b;a[14318656]=a[14318656]&1|a[14319008+(b&255)|0];return}function Cx(){fj[c[186762]&511](e[7159330]|0,a[14318664]|0);return}function Cy(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;a[14318664]=fl[c[186832]&255](g)|0;a[14318665|0]=fl[c[186832]&255](g+1&65535)|0;b[7159340]=(c[3646042]|0)+1&65535;return}function Cz(){var d=0;d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;a[14318702]=a[14318703]|0;return}function CA(){var b=0;b=fl[c[186830]&255](e[7159330]|0)|0;a[14318669|0]=b;a[14318656]=a[14318656]&1|a[14319008+(b&255)|0];return}function CB(){fj[c[186762]&511](e[7159330]|0,a[14318669|0]|0);return}function CC(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;fj[c[186764]&511](g,a[14318668]|0);fj[c[186764]&511](g+1&65535,a[14318669|0]|0);b[7159340]=(c[3646042]|0)+1&65535;return}function CD(){var d=0;d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;a[14318702]=a[14318703]|0;return}function CE(){var d=0,f=0;d=fl[c[186832]&255](e[7159334]|0)|0;f=b[7159334]|0;b[7159340]=f+1&65535;fj[c[186764]&511](f&65535,a[14318657|0]<<4|(d&255)>>>4);f=a[14318657|0]&-16|d&15;a[14318657|0]=f;a[14318656]=a[14318656]&1|a[14319008+(f&255)|0];return}function CF(){var b=0;b=fl[c[186830]&255](e[7159330]|0)|0;a[14318668]=b;a[14318656]=a[14318656]&1|a[14319008+(b&255)|0];return}function CG(){fj[c[186762]&511](e[7159330]|0,a[14318668]|0);return}function CH(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;a[14318668]=fl[c[186832]&255](g)|0;a[14318669|0]=fl[c[186832]&255](g+1&65535)|0;b[7159340]=(c[3646042]|0)+1&65535;return}function CI(){var d=0;d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;a[14318702]=a[14318703]|0;return}function CJ(){var d=0,f=0;d=fl[c[186832]&255](e[7159334]|0)|0;f=b[7159334]|0;b[7159340]=f+1&65535;fj[c[186764]&511](f&65535,a[14318657|0]&15|d<<4);f=a[14318657|0]&-16|(d&255)>>>4;a[14318657|0]=f;a[14318656]=a[14318656]&1|a[14319008+(f&255)|0];return}function CK(){var b=0;b=fl[c[186830]&255](e[7159330]|0)|0;a[14318656]=a[14318656]&1|a[14319008+(b&255)|0];return}function CL(){fj[c[186762]&511](e[7159330]|0,0);return}function CM(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;fj[c[186764]&511](g,a[14318652]|0);fj[c[186764]&511](g+1&65535,a[14318653|0]|0);b[7159340]=(c[3646042]|0)+1&65535;return}function CN(){var d=0;d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;a[14318702]=a[14318703]|0;return}function CO(){var d=0;d=fl[c[186830]&255](e[7159330]|0)|0;a[14318657|0]=d;a[14318656]=a[14318656]&1|a[14319008+(d&255)|0];b[7159340]=(b[7159330]|0)+1&65535;return}function CP(){fj[c[186762]&511](e[7159330]|0,a[14318657|0]|0);b[7159340]=(b[7159330]|0)+1&65535;return}function CQ(){var e=0,f=0,g=0;e=c[3579662]|0;b[7159324]=(e&65535)+2&65535;f=e+1|0;g=(d[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0)<<8|(d[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0);c[3646042]=g;a[14318652]=fl[c[186832]&255](g)|0;a[14318653|0]=fl[c[186832]&255](g+1&65535)|0;b[7159340]=(c[3646042]|0)+1&65535;return}function CR(){var d=0;d=c[3579663]|0;a[14318648]=fl[c[186832]&255](d)|0;a[14318649]=fl[c[186832]&255](d+1&65535)|0;b[7159326]=(b[7159326]|0)+2&65535;b[7159340]=b[7159324]|0;a[14318702]=a[14318703]|0;return}function CS(){return}function CT(){return}function CU(){return}function CV(){return}function CW(){return}function CX(){return}function CY(){return}function CZ(){return}function C_(){return}function C$(){return}function C0(){return}function C1(){return}function C2(){return}function C3(){return}function C4(){return}function C5(){return}function C6(){return}function C7(){return}function C8(){return}function C9(){return}function Da(){return}function Db(){return}function Dc(){return}function Dd(){return}function De(){return}function Df(){return}function Dg(){var f=0,g=0,h=0,i=0,j=0;f=fl[c[186832]&255](e[7159334]|0)|0;fj[c[186764]&511](e[7159332]|0,f);g=a[14318656]&-63;a[14318656]=g;h=(d[14318657|0]|0)+(f&255)|0;if((h&2|0)==0){i=g}else{f=g|32;a[14318656]=f;i=f}if((h&8|0)==0){j=i}else{h=i|8;a[14318656]=h;j=h}b[7159334]=(b[7159334]|0)+1&65535;b[7159332]=(b[7159332]|0)+1&65535;h=(b[7159330]|0)-1&65535;b[7159330]=h;if(h<<16>>16==0){return}a[14318656]=j|4;return}function Dh(){var d=0,f=0,g=0,h=0,i=0;d=fl[c[186832]&255](e[7159334]|0)|0;f=a[14318657|0]|0;g=f-d&255;b[7159340]=(b[7159340]|0)+1&65535;b[7159334]=(b[7159334]|0)+1&65535;h=(b[7159330]|0)-1&65535;b[7159330]=h;i=a[14318656]&1|(f^d^g)&16|a[14581920+(g&255)|0]&-43;d=(i<<3<<24>>24>>7)+g&255;g=((d&2|0)==0?2:34)|i;i=(d&8|0)==0?g:g|8;a[14318656]=h<<16>>16==0?i:i|4;return}function Di(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=fl[c[186830]&255](e[7159330]|0)|0;b[7159340]=(b[7159330]|0)+1&65535;c[3579678]=(c[3579678]|0)+60;a[14318661|0]=(a[14318661|0]|0)-1&255;fj[c[186764]&511](e[7159334]|0,f);b[7159334]=(b[7159334]|0)+1&65535;g=d[14318661|0]|0;h=a[14581920+g|0]|0;a[14318656]=h;i=(d[14318660]|0)+1|0;j=f&255;if((j&128|0)==0){k=h}else{f=h|2;a[14318656]=f;k=f}if(((i&255)+j&256|0)==0){l=k;m=i+j|0;n=m&7;o=n^g;p=14319008+o|0;q=a[p]|0;r=q&4;s=r|l;a[14318656]=s;return}f=k|17;a[14318656]=f;l=f;m=i+j|0;n=m&7;o=n^g;p=14319008+o|0;q=a[p]|0;r=q&4;s=r|l;a[14318656]=s;return}function Dj(){var f=0,g=0,h=0,i=0,j=0;f=fl[c[186832]&255](e[7159334]|0)|0;a[14318661|0]=(a[14318661|0]|0)-1&255;g=b[7159330]|0;b[7159340]=g+1&65535;fj[c[186762]&511](g&65535,f);g=(b[7159334]|0)+1&65535;b[7159334]=g;h=d[14318661|0]|0;i=a[14581920+h|0]|0;j=f&255;f=(g&255)+j|0;g=(j&128|0)==0?i:i|2;a[14318656]=((f&256|0)==0?g:g|17)|a[14319008+(f&7^h)|0]&4;return}function Dk(){var f=0,g=0,h=0,i=0,j=0;f=fl[c[186832]&255](e[7159334]|0)|0;fj[c[186764]&511](e[7159332]|0,f);g=a[14318656]&-63;a[14318656]=g;h=(d[14318657|0]|0)+(f&255)|0;if((h&2|0)==0){i=g}else{f=g|32;a[14318656]=f;i=f}if((h&8|0)==0){j=i}else{h=i|8;a[14318656]=h;j=h}b[7159334]=(b[7159334]|0)-1&65535;b[7159332]=(b[7159332]|0)-1&65535;h=(b[7159330]|0)-1&65535;b[7159330]=h;if(h<<16>>16==0){return}a[14318656]=j|4;return}function Dl(){var d=0,f=0,g=0,h=0,i=0;d=fl[c[186832]&255](e[7159334]|0)|0;f=a[14318657|0]|0;g=f-d&255;b[7159340]=(b[7159340]|0)-1&65535;b[7159334]=(b[7159334]|0)-1&65535;h=(b[7159330]|0)-1&65535;b[7159330]=h;i=a[14318656]&1|(f^d^g)&16|a[14581920+(g&255)|0]&-43;d=(i<<3<<24>>24>>7)+g&255;g=((d&2|0)==0?2:34)|i;i=(d&8|0)==0?g:g|8;a[14318656]=h<<16>>16==0?i:i|4;return}function Dm(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=fl[c[186830]&255](e[7159330]|0)|0;b[7159340]=(b[7159330]|0)-1&65535;c[3579678]=(c[3579678]|0)+60;a[14318661|0]=(a[14318661|0]|0)-1&255;fj[c[186764]&511](e[7159334]|0,f);b[7159334]=(b[7159334]|0)-1&65535;g=d[14318661|0]|0;h=a[14581920+g|0]|0;a[14318656]=h;i=(d[14318660]|0)+255|0;j=f&255;if((j&128|0)==0){k=h}else{f=h|2;a[14318656]=f;k=f}if(((i&255)+j&256|0)==0){l=k;m=i+j|0;n=m&7;o=n^g;p=14319008+o|0;q=a[p]|0;r=q&4;s=r|l;a[14318656]=s;return}f=k|17;a[14318656]=f;l=f;m=i+j|0;n=m&7;o=n^g;p=14319008+o|0;q=a[p]|0;r=q&4;s=r|l;a[14318656]=s;return}function Dn(){var f=0,g=0,h=0,i=0,j=0;f=fl[c[186832]&255](e[7159334]|0)|0;a[14318661|0]=(a[14318661|0]|0)-1&255;g=b[7159330]|0;b[7159340]=g-1&65535;fj[c[186762]&511](g&65535,f);g=(b[7159334]|0)-1&65535;b[7159334]=g;h=d[14318661|0]|0;i=a[14581920+h|0]|0;j=f&255;f=(g&255)+j|0;g=(j&128|0)==0?i:i|2;a[14318656]=((f&256|0)==0?g:g|17)|a[14319008+(f&7^h)|0]&4;return}function Do(){var f=0,g=0,h=0,i=0,j=0;f=fl[c[186832]&255](e[7159334]|0)|0;fj[c[186764]&511](e[7159332]|0,f);g=a[14318656]&-63;a[14318656]=g;h=(d[14318657|0]|0)+(f&255)|0;if((h&2|0)==0){i=g}else{f=g|32;a[14318656]=f;i=f}if((h&8|0)==0){j=i}else{h=i|8;a[14318656]=h;j=h}b[7159334]=(b[7159334]|0)+1&65535;b[7159332]=(b[7159332]|0)+1&65535;h=(b[7159330]|0)-1&65535;b[7159330]=h;if(h<<16>>16==0){return}a[14318656]=j|4;j=b[7159324]|0;b[7159324]=j-2&65535;b[7159340]=j-1&65535;c[3579678]=(c[3579678]|0)+75;return}function Dp(){var d=0,f=0,g=0,h=0,i=0;d=fl[c[186832]&255](e[7159334]|0)|0;f=a[14318657|0]|0;g=f-d&255;b[7159340]=(b[7159340]|0)+1&65535;b[7159334]=(b[7159334]|0)+1&65535;h=(b[7159330]|0)-1&65535;b[7159330]=h;i=a[14318656]&1|(f^d^g)&16|a[14581920+(g&255)|0]&-43;d=(i<<3<<24>>24>>7)+g&255;g=((d&2|0)==0?2:34)|i;i=(d&8|0)==0?g:g|8;a[14318656]=i;if(h<<16>>16==0){return}a[14318656]=i|4;if((i&64)!=0){return}i=b[7159324]|0;b[7159324]=i-2&65535;b[7159340]=i-1&65535;c[3579678]=(c[3579678]|0)+75;return}function Dq(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fl[c[186830]&255](e[7159330]|0)|0;b[7159340]=(b[7159330]|0)+1&65535;c[3579678]=(c[3579678]|0)+60;a[14318661|0]=(a[14318661|0]|0)-1&255;fj[c[186764]&511](e[7159334]|0,f);b[7159334]=(b[7159334]|0)+1&65535;g=a[14318661|0]|0;h=g&255;i=a[14581920+h|0]|0;a[14318656]=i;j=(d[14318660]|0)+1|0;k=f&255;if((k&128|0)==0){l=i}else{f=i|2;a[14318656]=f;l=f}if(((j&255)+k&256|0)==0){m=l}else{f=l|17;a[14318656]=f;m=f}a[14318656]=a[14319008+(j+k&7^h)|0]&4|m;if(g<<24>>24==0){return}b[7159324]=(b[7159324]|0)-2&65535;c[3579678]=(c[3579678]|0)+75;return}function Dr(){var d=0,f=0,g=0,h=0,i=0,j=0;d=fl[c[186832]&255](e[7159334]|0)|0;a[14318661|0]=(a[14318661|0]|0)-1&255;f=b[7159330]|0;b[7159340]=f+1&65535;fj[c[186762]&511](f&65535,d);f=(b[7159334]|0)+1&65535;b[7159334]=f;g=a[14318661|0]|0;h=g&255;i=a[14581920+h|0]|0;j=d&255;d=(f&255)+j|0;f=(j&128|0)==0?i:i|2;a[14318656]=((d&256|0)==0?f:f|17)|a[14319008+(d&7^h)|0]&4;if(g<<24>>24==0){return}b[7159324]=(b[7159324]|0)-2&65535;c[3579678]=(c[3579678]|0)+75;return}function Ds(){var f=0,g=0,h=0,i=0,j=0;f=fl[c[186832]&255](e[7159334]|0)|0;fj[c[186764]&511](e[7159332]|0,f);g=a[14318656]&-63;a[14318656]=g;h=(d[14318657|0]|0)+(f&255)|0;if((h&2|0)==0){i=g}else{f=g|32;a[14318656]=f;i=f}if((h&8|0)==0){j=i}else{h=i|8;a[14318656]=h;j=h}b[7159334]=(b[7159334]|0)-1&65535;b[7159332]=(b[7159332]|0)-1&65535;h=(b[7159330]|0)-1&65535;b[7159330]=h;if(h<<16>>16==0){return}a[14318656]=j|4;j=b[7159324]|0;b[7159324]=j-2&65535;b[7159340]=j-1&65535;c[3579678]=(c[3579678]|0)+75;return}function Dt(){var d=0,f=0,g=0,h=0,i=0;d=fl[c[186832]&255](e[7159334]|0)|0;f=a[14318657|0]|0;g=f-d&255;b[7159340]=(b[7159340]|0)-1&65535;b[7159334]=(b[7159334]|0)-1&65535;h=(b[7159330]|0)-1&65535;b[7159330]=h;i=a[14318656]&1|(f^d^g)&16|a[14581920+(g&255)|0]&-43;d=(i<<3<<24>>24>>7)+g&255;g=((d&2|0)==0?2:34)|i;i=(d&8|0)==0?g:g|8;a[14318656]=i;if(h<<16>>16==0){return}a[14318656]=i|4;if((i&64)!=0){return}i=b[7159324]|0;b[7159324]=i-2&65535;b[7159340]=i-1&65535;c[3579678]=(c[3579678]|0)+75;return}function Du(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fl[c[186830]&255](e[7159330]|0)|0;b[7159340]=(b[7159330]|0)-1&65535;c[3579678]=(c[3579678]|0)+60;a[14318661|0]=(a[14318661|0]|0)-1&255;fj[c[186764]&511](e[7159334]|0,f);b[7159334]=(b[7159334]|0)-1&65535;g=a[14318661|0]|0;h=g&255;i=a[14581920+h|0]|0;a[14318656]=i;j=(d[14318660]|0)+255|0;k=f&255;if((k&128|0)==0){l=i}else{f=i|2;a[14318656]=f;l=f}if(((j&255)+k&256|0)==0){m=l}else{f=l|17;a[14318656]=f;m=f}a[14318656]=a[14319008+(j+k&7^h)|0]&4|m;if(g<<24>>24==0){return}b[7159324]=(b[7159324]|0)-2&65535;c[3579678]=(c[3579678]|0)+75;return}function Dv(){return}function Dw(){return}function Dx(){return}function Dy(){return}function Dz(){return}function DA(){return}function DB(){return}function DC(){return}function DD(){return}function DE(){return}function DF(){return}function DG(){return}function DH(){return}function DI(){return}function DJ(){return}function DK(){return}function DL(){return}function DM(){return}function DN(){return}function DO(){return}function DP(){return}function DQ(){return}function DR(){return}function DS(){return}function DT(){return}function DU(){return}function DV(){return}function DW(){return}function DX(){return}function DY(){return}function DZ(){return}function D_(){return}function D$(){return}function D0(){return}function D1(){return}function D2(){return}function D3(){return}function D4(){return}function D5(){return}function D6(){return}function D7(){return}function D8(){return}function D9(){return}function Ea(){return}function Eb(){return}function Ec(){return}function Ed(){return}function Ee(){return}function Ef(){return}function Eg(){return}function Eh(){return}function Ei(){return}function Ej(){return}function Ek(){return}function El(){return}function Em(){return}function En(){return}function Eo(){return}function Ep(){return}function Eq(){return}function Er(){return}function Es(){return}function Et(){return}function Eu(){return}function Ev(){return}function Ew(){return}function Ex(){return}function Ey(){return}function Ez(){var b=0,c=0,d=0;b=a[14318661|0]|0;c=b&255;d=c<<1&254|c>>>7;a[14318656]=a[14319008+d|0]|(b&255)>>>7;a[14318661|0]=d&255;return}function EA(){var b=0,c=0,d=0;b=a[14318660]|0;c=b&255;d=c<<1&254|c>>>7;a[14318656]=a[14319008+d|0]|(b&255)>>>7;a[14318660]=d&255;return}function EB(){var b=0,c=0,d=0;b=a[14318665|0]|0;c=b&255;d=c<<1&254|c>>>7;a[14318656]=a[14319008+d|0]|(b&255)>>>7;a[14318665|0]=d&255;return}function EC(){var b=0,c=0,d=0;b=a[14318664]|0;c=b&255;d=c<<1&254|c>>>7;a[14318656]=a[14319008+d|0]|(b&255)>>>7;a[14318664]=d&255;return}function ED(){var b=0,c=0,d=0;b=a[14318669|0]|0;c=b&255;d=c<<1&254|c>>>7;a[14318656]=a[14319008+d|0]|(b&255)>>>7;a[14318669|0]=d&255;return}function EE(){var b=0,c=0,d=0;b=a[14318668]|0;c=b&255;d=c<<1&254|c>>>7;a[14318656]=a[14319008+d|0]|(b&255)>>>7;a[14318668]=d&255;return}function EF(){var b=0,c=0,d=0;b=a[14318657|0]|0;c=b&255;d=c<<1&254|c>>>7;a[14318656]=a[14319008+d|0]|(b&255)>>>7;a[14318657|0]=d&255;return}function EG(){var b=0,c=0,d=0;b=a[14318661|0]|0;c=b&255;d=c<<7&128|c>>>1;a[14318656]=a[14319008+d|0]|b&1;a[14318661|0]=d&255;return}function EH(){var b=0,c=0,d=0;b=a[14318660]|0;c=b&255;d=c<<7&128|c>>>1;a[14318656]=a[14319008+d|0]|b&1;a[14318660]=d&255;return}function EI(){var b=0,c=0,d=0;b=a[14318665|0]|0;c=b&255;d=c<<7&128|c>>>1;a[14318656]=a[14319008+d|0]|b&1;a[14318665|0]=d&255;return}function EJ(){var b=0,c=0,d=0;b=a[14318664]|0;c=b&255;d=c<<7&128|c>>>1;a[14318656]=a[14319008+d|0]|b&1;a[14318664]=d&255;return}function EK(){var b=0,c=0,d=0;b=a[14318669|0]|0;c=b&255;d=c<<7&128|c>>>1;a[14318656]=a[14319008+d|0]|b&1;a[14318669|0]=d&255;return}function EL(){var b=0,c=0,d=0;b=a[14318668]|0;c=b&255;d=c<<7&128|c>>>1;a[14318656]=a[14319008+d|0]|b&1;a[14318668]=d&255;return}function EM(){var b=0,c=0,d=0;b=a[14318657|0]|0;c=b&255;d=c<<7&128|c>>>1;a[14318656]=a[14319008+d|0]|b&1;a[14318657|0]=d&255;return}function EN(){var b=0,c=0;b=a[14318661|0]|0;c=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318661|0]=c&255;return}function EO(){var b=0,c=0;b=a[14318660]|0;c=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318660]=c&255;return}function EP(){var b=0,c=0;b=a[14318665|0]|0;c=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318665|0]=c&255;return}function EQ(){var b=0,c=0;b=a[14318664]|0;c=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318664]=c&255;return}function ER(){var b=0,c=0;b=a[14318669|0]|0;c=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318669|0]=c&255;return}function ES(){var b=0,c=0;b=a[14318668]|0;c=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318668]=c&255;return}function ET(){var b=0,c=0;b=a[14318657|0]|0;c=a[14318656]&1|(b&255)<<1&254;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318657|0]=c&255;return}function EU(){var b=0,c=0;b=a[14318661|0]|0;c=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318661|0]=c&255;return}function EV(){var b=0,c=0;b=a[14318660]|0;c=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318660]=c&255;return}function EW(){var b=0,c=0;b=a[14318665|0]|0;c=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318665|0]=c&255;return}function EX(){var b=0,c=0;b=a[14318664]|0;c=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318664]=c&255;return}function EY(){var b=0,c=0;b=a[14318669|0]|0;c=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318669|0]=c&255;return}function EZ(){var b=0,c=0;b=a[14318668]|0;c=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318668]=c&255;return}function E_(){var b=0,c=0;b=a[14318657|0]|0;c=(d[14318656]|0)<<7&128|(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318657|0]=c&255;return}function E$(){var b=0,c=0;b=a[14318661|0]|0;c=(b&255)<<1;a[14318656]=a[14319008+(c&254)|0]|(b&255)>>>7;a[14318661|0]=c&255;return}function E0(){var b=0,c=0;b=a[14318660]|0;c=(b&255)<<1;a[14318656]=a[14319008+(c&254)|0]|(b&255)>>>7;a[14318660]=c&255;return}function E1(){var b=0,c=0;b=a[14318665|0]|0;c=(b&255)<<1;a[14318656]=a[14319008+(c&254)|0]|(b&255)>>>7;a[14318665|0]=c&255;return}function E2(){var b=0,c=0;b=a[14318664]|0;c=(b&255)<<1;a[14318656]=a[14319008+(c&254)|0]|(b&255)>>>7;a[14318664]=c&255;return}function E3(){var b=0,c=0;b=a[14318669|0]|0;c=(b&255)<<1;a[14318656]=a[14319008+(c&254)|0]|(b&255)>>>7;a[14318669|0]=c&255;return}function E4(){var b=0,c=0;b=a[14318668]|0;c=(b&255)<<1;a[14318656]=a[14319008+(c&254)|0]|(b&255)>>>7;a[14318668]=c&255;return}function E5(){var b=0,c=0;b=a[14318657|0]|0;c=(b&255)<<1;a[14318656]=a[14319008+(c&254)|0]|(b&255)>>>7;a[14318657|0]=c&255;return}function E6(){var b=0,c=0,d=0;b=a[14318661|0]|0;c=b&255;d=c>>>1|c&128;a[14318656]=a[14319008+d|0]|b&1;a[14318661|0]=d&255;return}function E7(){var b=0,c=0,d=0;b=a[14318660]|0;c=b&255;d=c>>>1|c&128;a[14318656]=a[14319008+d|0]|b&1;a[14318660]=d&255;return}function E8(){var b=0,c=0,d=0;b=a[14318665|0]|0;c=b&255;d=c>>>1|c&128;a[14318656]=a[14319008+d|0]|b&1;a[14318665|0]=d&255;return}function E9(){var b=0,c=0,d=0;b=a[14318664]|0;c=b&255;d=c>>>1|c&128;a[14318656]=a[14319008+d|0]|b&1;a[14318664]=d&255;return}function Fa(){var d=0,f=0,g=0,h=0,i=0,j=0;d=fl[c[186832]&255](e[7159334]|0)|0;a[14318661|0]=(a[14318661|0]|0)-1&255;f=b[7159330]|0;b[7159340]=f-1&65535;fj[c[186762]&511](f&65535,d);f=(b[7159334]|0)-1&65535;b[7159334]=f;g=a[14318661|0]|0;h=g&255;i=a[14581920+h|0]|0;j=d&255;d=(f&255)+j|0;f=(j&128|0)==0?i:i|2;a[14318656]=((d&256|0)==0?f:f|17)|a[14319008+(d&7^h)|0]&4;if(g<<24>>24==0){return}b[7159324]=(b[7159324]|0)-2&65535;c[3579678]=(c[3579678]|0)+75;return}function Fb(){var b=0,d=0,f=0,g=0,h=0;b=c[186764]|0;d=e[7159334]|0;f=fl[c[186832]&255](d)|0;g=f&255;h=g<<1&254|g>>>7;a[14318656]=a[14319008+h|0]|(f&255)>>>7;fj[b&511](d,h&255);return}function Fc(){var b=0,d=0,f=0,g=0,h=0;b=c[186764]|0;d=e[7159334]|0;f=fl[c[186832]&255](d)|0;g=f&255;h=g<<7&128|g>>>1;a[14318656]=a[14319008+h|0]|f&1;fj[b&511](d,h&255);return}function Fd(){var b=0,d=0,f=0,g=0;b=c[186764]|0;d=e[7159334]|0;f=fl[c[186832]&255](d)|0;g=a[14318656]&1|(f&255)<<1&254;a[14318656]=a[14319008+g|0]|(f&255)>>>7;fj[b&511](d,g&255);return}function Fe(){var b=0,f=0,g=0,h=0;b=c[186764]|0;f=e[7159334]|0;g=fl[c[186832]&255](f)|0;h=(d[14318656]|0)<<7&128|(g&255)>>>1;a[14318656]=a[14319008+h|0]|g&1;fj[b&511](f,h&255);return}function Ff(){var b=0,d=0,f=0,g=0;b=c[186764]|0;d=e[7159334]|0;f=fl[c[186832]&255](d)|0;g=(f&255)<<1;a[14318656]=a[14319008+(g&254)|0]|(f&255)>>>7;fj[b&511](d,g&255);return}function Fg(){var b=0,c=0,d=0;b=a[14318669|0]|0;c=b&255;d=c>>>1|c&128;a[14318656]=a[14319008+d|0]|b&1;a[14318669|0]=d&255;return}function Fh(){var b=0,c=0,d=0;b=a[14318668]|0;c=b&255;d=c>>>1|c&128;a[14318656]=a[14319008+d|0]|b&1;a[14318668]=d&255;return}function Fi(){var b=0,c=0,d=0;b=a[14318657|0]|0;c=b&255;d=c>>>1|c&128;a[14318656]=a[14319008+d|0]|b&1;a[14318657|0]=d&255;return}function Fj(){var b=0,c=0;b=a[14318661|0]|0;c=(b&255)<<1&254|1;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318661|0]=c&255;return}function Fk(){var b=0,c=0;b=a[14318660]|0;c=(b&255)<<1&254|1;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318660]=c&255;return}function Fl(){var b=0,c=0;b=a[14318665|0]|0;c=(b&255)<<1&254|1;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318665|0]=c&255;return}function Fm(){var b=0,c=0;b=a[14318664]|0;c=(b&255)<<1&254|1;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318664]=c&255;return}function Fn(){var b=0,c=0;b=a[14318669|0]|0;c=(b&255)<<1&254|1;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318669|0]=c&255;return}function Fo(){var b=0,c=0;b=a[14318668]|0;c=(b&255)<<1&254|1;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318668]=c&255;return}function Fp(){var b=0,c=0;b=a[14318657|0]|0;c=(b&255)<<1&254|1;a[14318656]=a[14319008+c|0]|(b&255)>>>7;a[14318657|0]=c&255;return}function Fq(){var b=0,c=0;b=a[14318661|0]|0;c=(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318661|0]=c&255;return}function Fr(){var b=0,c=0;b=a[14318660]|0;c=(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318660]=c&255;return}function Fs(){var b=0,c=0;b=a[14318665|0]|0;c=(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318665|0]=c&255;return}function Ft(){var b=0,c=0;b=a[14318664]|0;c=(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318664]=c&255;return}function Fu(){var b=0,c=0;b=a[14318669|0]|0;c=(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318669|0]=c&255;return}function Fv(){var b=0,c=0;b=a[14318668]|0;c=(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318668]=c&255;return}function Fw(){var b=0,c=0;b=a[14318657|0]|0;c=(b&255)>>>1;a[14318656]=a[14319008+c|0]|b&1;a[14318657|0]=c&255;return}function Fx(){var b=0;b=a[14318661|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&1)|0]&-57|16;return}function Fy(){var b=0;b=a[14318660]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&1)|0]&-57|16;return}function Fz(){var b=0;b=a[14318665|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&1)|0]&-57|16;return}function FA(){var b=0;b=a[14318664]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&1)|0]&-57|16;return}function FB(){var b=0;b=a[14318669|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&1)|0]&-57|16;return}function FC(){var b=0;b=a[14318668]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&1)|0]&-57|16;return}function FD(){var b=0;b=a[14318657|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&1)|0]&-57|16;return}function FE(){var b=0;b=a[14318661|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&2)|0]&-57|16;return}function FF(){var b=0;b=a[14318660]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&2)|0]&-57|16;return}function FG(){var b=0;b=a[14318665|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&2)|0]&-57|16;return}function FH(){var b=0;b=a[14318664]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&2)|0]&-57|16;return}function FI(){var b=0;b=a[14318669|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&2)|0]&-57|16;return}function FJ(){var b=0;b=a[14318668]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&2)|0]&-57|16;return}function FK(){var b=0;b=a[14318657|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&2)|0]&-57|16;return}function FL(){var b=0;b=a[14318661|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&4)|0]&-57|16;return}function FM(){var b=0;b=a[14318660]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&4)|0]&-57|16;return}function FN(){var b=0;b=a[14318665|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&4)|0]&-57|16;return}function FO(){var b=0;b=a[14318664]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&4)|0]&-57|16;return}function FP(){var b=0;b=a[14318669|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&4)|0]&-57|16;return}function FQ(){var b=0;b=a[14318668]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&4)|0]&-57|16;return}function FR(){var b=0;b=a[14318657|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&4)|0]&-57|16;return}function FS(){var b=0;b=a[14318661|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&8)|0]&-57|16;return}function FT(){var b=0;b=a[14318660]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&8)|0]&-57|16;return}function FU(){var b=0;b=a[14318665|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&8)|0]&-57|16;return}function FV(){var b=0;b=a[14318664]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&8)|0]&-57|16;return}function FW(){var b=0;b=a[14318669|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&8)|0]&-57|16;return}function FX(){var b=0;b=a[14318668]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&8)|0]&-57|16;return}function FY(){var b=0;b=a[14318657|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&8)|0]&-57|16;return}function FZ(){var b=0;b=a[14318661|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&16)|0]&-57|16;return}function F_(){var b=0;b=a[14318660]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&16)|0]&-57|16;return}function F$(){var b=0;b=a[14318665|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&16)|0]&-57|16;return}function F0(){var b=0;b=a[14318664]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&16)|0]&-57|16;return}function F1(){var b=0;b=a[14318669|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&16)|0]&-57|16;return}function F2(){var b=0;b=a[14318668]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&16)|0]&-57|16;return}function F3(){var b=0;b=a[14318657|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&16)|0]&-57|16;return}function F4(){var b=0;b=a[14318661|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&32)|0]&-57|16;return}function F5(){var b=0;b=a[14318660]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&32)|0]&-57|16;return}function F6(){var b=0,d=0,f=0,g=0,h=0;b=c[186764]|0;d=e[7159334]|0;f=fl[c[186832]&255](d)|0;g=f&255;h=g>>>1|g&128;a[14318656]=a[14319008+h|0]|f&1;fj[b&511](d,h&255);return}function F7(){var b=0,d=0,f=0,g=0;b=c[186764]|0;d=e[7159334]|0;f=fl[c[186832]&255](d)|0;g=(f&255)<<1&254|1;a[14318656]=a[14319008+g|0]|(f&255)>>>7;fj[b&511](d,g&255);return}function F8(){var b=0,d=0,f=0,g=0;b=c[186764]|0;d=e[7159334]|0;f=fl[c[186832]&255](d)|0;g=(f&255)>>>1;a[14318656]=a[14319008+g|0]|f&1;fj[b&511](d,g&255);return}function F9(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](e[7159334]|0)|0)&1)|0]&-57;a[14318656]=b|d|a[14318681|0]&40|16;return}function Ga(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](e[7159334]|0)|0)&2)|0]&-57;a[14318656]=b|d|a[14318681|0]&40|16;return}function Gb(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](e[7159334]|0)|0)&4)|0]&-57;a[14318656]=b|d|a[14318681|0]&40|16;return}function Gc(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](e[7159334]|0)|0)&8)|0]&-57;a[14318656]=b|d|a[14318681|0]&40|16;return}function Gd(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](e[7159334]|0)|0)&16)|0]&-57;a[14318656]=b|d|a[14318681|0]&40|16;return}function Ge(){a[14318661|0]=a[14318661|0]&-2;return}function Gf(){a[14318660]=a[14318660]&-2;return}function Gg(){a[14318665|0]=a[14318665|0]&-2;return}function Gh(){a[14318664]=a[14318664]&-2;return}function Gi(){a[14318669|0]=a[14318669|0]&-2;return}function Gj(){a[14318668]=a[14318668]&-2;return}function Gk(){a[14318657|0]=a[14318657|0]&-2;return}function Gl(){a[14318661|0]=a[14318661|0]&-3;return}function Gm(){a[14318660]=a[14318660]&-3;return}function Gn(){a[14318665|0]=a[14318665|0]&-3;return}function Go(){a[14318664]=a[14318664]&-3;return}function Gp(){a[14318669|0]=a[14318669|0]&-3;return}function Gq(){a[14318668]=a[14318668]&-3;return}function Gr(){a[14318657|0]=a[14318657|0]&-3;return}function Gs(){a[14318661|0]=a[14318661|0]&-5;return}function Gt(){a[14318660]=a[14318660]&-5;return}function Gu(){a[14318665|0]=a[14318665|0]&-5;return}function Gv(){a[14318664]=a[14318664]&-5;return}function Gw(){a[14318669|0]=a[14318669|0]&-5;return}function Gx(){a[14318668]=a[14318668]&-5;return}function Gy(){a[14318657|0]=a[14318657|0]&-5;return}function Gz(){a[14318661|0]=a[14318661|0]&-9;return}function GA(){a[14318660]=a[14318660]&-9;return}function GB(){a[14318665|0]=a[14318665|0]&-9;return}function GC(){a[14318664]=a[14318664]&-9;return}function GD(){a[14318669|0]=a[14318669|0]&-9;return}function GE(){a[14318668]=a[14318668]&-9;return}function GF(){a[14318657|0]=a[14318657|0]&-9;return}function GG(){a[14318661|0]=a[14318661|0]&-17;return}function GH(){a[14318660]=a[14318660]&-17;return}function GI(){a[14318665|0]=a[14318665|0]&-17;return}function GJ(){a[14318664]=a[14318664]&-17;return}function GK(){a[14318669|0]=a[14318669|0]&-17;return}function GL(){a[14318668]=a[14318668]&-17;return}function GM(){a[14318657|0]=a[14318657|0]&-17;return}function GN(){a[14318661|0]=a[14318661|0]&-33;return}function GO(){a[14318660]=a[14318660]&-33;return}function GP(){a[14318665|0]=a[14318665|0]&-33;return}function GQ(){a[14318664]=a[14318664]&-33;return}function GR(){a[14318669|0]=a[14318669|0]&-33;return}function GS(){a[14318668]=a[14318668]&-33;return}function GT(){a[14318657|0]=a[14318657|0]&-33;return}function GU(){a[14318661|0]=a[14318661|0]&-65;return}function GV(){a[14318660]=a[14318660]&-65;return}function GW(){a[14318665|0]=a[14318665|0]&-65;return}function GX(){a[14318664]=a[14318664]&-65;return}function GY(){a[14318669|0]=a[14318669|0]&-65;return}function GZ(){a[14318668]=a[14318668]&-65;return}function G_(){a[14318657|0]=a[14318657|0]&-65;return}function G$(){a[14318661|0]=a[14318661|0]&127;return}function G0(){a[14318660]=a[14318660]&127;return}function G1(){a[14318665|0]=a[14318665|0]&127;return}function G2(){a[14318664]=a[14318664]&127;return}function G3(){a[14318669|0]=a[14318669|0]&127;return}function G4(){a[14318668]=a[14318668]&127;return}function G5(){a[14318657|0]=a[14318657|0]&127;return}function G6(){a[14318661|0]=a[14318661|0]|1;return}function G7(){a[14318660]=a[14318660]|1;return}function G8(){a[14318665|0]=a[14318665|0]|1;return}function G9(){a[14318664]=a[14318664]|1;return}function Ha(){a[14318669|0]=a[14318669|0]|1;return}function Hb(){a[14318668]=a[14318668]|1;return}function Hc(){a[14318657|0]=a[14318657|0]|1;return}function Hd(){a[14318661|0]=a[14318661|0]|2;return}function He(){a[14318660]=a[14318660]|2;return}function Hf(){a[14318665|0]=a[14318665|0]|2;return}function Hg(){a[14318664]=a[14318664]|2;return}function Hh(){a[14318669|0]=a[14318669|0]|2;return}function Hi(){a[14318668]=a[14318668]|2;return}function Hj(){a[14318657|0]=a[14318657|0]|2;return}function Hk(){a[14318661|0]=a[14318661|0]|4;return}function Hl(){a[14318660]=a[14318660]|4;return}function Hm(){a[14318665|0]=a[14318665|0]|4;return}function Hn(){a[14318664]=a[14318664]|4;return}function Ho(){a[14318669|0]=a[14318669|0]|4;return}function Hp(){a[14318668]=a[14318668]|4;return}function Hq(){a[14318657|0]=a[14318657|0]|4;return}function Hr(){a[14318661|0]=a[14318661|0]|8;return}function Hs(){a[14318660]=a[14318660]|8;return}function Ht(){a[14318665|0]=a[14318665|0]|8;return}function Hu(){a[14318664]=a[14318664]|8;return}function Hv(){a[14318669|0]=a[14318669|0]|8;return}function Hw(){a[14318668]=a[14318668]|8;return}function Hx(){a[14318657|0]=a[14318657|0]|8;return}function Hy(){a[14318661|0]=a[14318661|0]|16;return}function Hz(){a[14318660]=a[14318660]|16;return}function HA(){var b=0;b=a[14318665|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&32)|0]&-57|16;return}function HB(){var b=0;b=a[14318664]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&32)|0]&-57|16;return}function HC(){var b=0;b=a[14318669|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&32)|0]&-57|16;return}function HD(){var b=0;b=a[14318668]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&32)|0]&-57|16;return}function HE(){var b=0;b=a[14318657|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&32)|0]&-57|16;return}function HF(){var b=0;b=a[14318661|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&64)|0]&-57|16;return}function HG(){var b=0;b=a[14318660]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&64)|0]&-57|16;return}function HH(){var b=0;b=a[14318665|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&64)|0]&-57|16;return}function HI(){var b=0;b=a[14318664]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&64)|0]&-57|16;return}function HJ(){var b=0;b=a[14318669|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&64)|0]&-57|16;return}function HK(){var b=0;b=a[14318668]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&64)|0]&-57|16;return}function HL(){var b=0;b=a[14318657|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&64)|0]&-57|16;return}function HM(){var b=0;b=a[14318661|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&128)|0]&-57|16;return}function HN(){var b=0;b=a[14318660]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&128)|0]&-57|16;return}function HO(){var b=0;b=a[14318665|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&128)|0]&-57|16;return}function HP(){var b=0;b=a[14318664]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&128)|0]&-57|16;return}function HQ(){var b=0;b=a[14318669|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&128)|0]&-57|16;return}function HR(){var b=0;b=a[14318668]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&128)|0]&-57|16;return}function HS(){var b=0;b=a[14318657|0]|0;a[14318656]=a[14318656]&1|b&40|a[14318752+(b&128)|0]&-57|16;return}function HT(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](e[7159334]|0)|0)&32)|0]&-57;a[14318656]=b|d|a[14318681|0]&40|16;return}function HU(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](e[7159334]|0)|0)&64)|0]&-57;a[14318656]=b|d|a[14318681|0]&40|16;return}function HV(){var b=0,d=0;b=a[14318656]&1;d=a[14318752+((fl[c[186832]&255](e[7159334]|0)|0)&128)|0]&-57;a[14318656]=b|d|a[14318681|0]&40|16;return}function HW(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=(fl[c[186832]&255](b)|0)&-2;fj[a&511](b,d);return}function HX(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=(fl[c[186832]&255](b)|0)&-3;fj[a&511](b,d);return}function HY(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=(fl[c[186832]&255](b)|0)&-5;fj[a&511](b,d);return}function HZ(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=(fl[c[186832]&255](b)|0)&-9;fj[a&511](b,d);return}function H_(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=(fl[c[186832]&255](b)|0)&-17;fj[a&511](b,d);return}function H$(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=(fl[c[186832]&255](b)|0)&-33;fj[a&511](b,d);return}function H0(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=(fl[c[186832]&255](b)|0)&-65;fj[a&511](b,d);return}function H1(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=(fl[c[186832]&255](b)|0)&127;fj[a&511](b,d);return}function H2(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=fl[c[186832]&255](b)|0|1;fj[a&511](b,d);return}function H3(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=fl[c[186832]&255](b)|0|2;fj[a&511](b,d);return}function H4(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=fl[c[186832]&255](b)|0|4;fj[a&511](b,d);return}function H5(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=fl[c[186832]&255](b)|0|8;fj[a&511](b,d);return}function H6(){a[14318665|0]=a[14318665|0]|16;return}function H7(){a[14318664]=a[14318664]|16;return}function H8(){a[14318669|0]=a[14318669|0]|16;return}function H9(){a[14318668]=a[14318668]|16;return}function Ia(){a[14318657|0]=a[14318657|0]|16;return}function Ib(){a[14318661|0]=a[14318661|0]|32;return}function Ic(){a[14318660]=a[14318660]|32;return}function Id(){a[14318665|0]=a[14318665|0]|32;return}function Ie(){a[14318664]=a[14318664]|32;return}function If(){a[14318669|0]=a[14318669|0]|32;return}function Ig(){a[14318668]=a[14318668]|32;return}function Ih(){a[14318657|0]=a[14318657|0]|32;return}function Ii(){a[14318661|0]=a[14318661|0]|64;return}function Ij(){a[14318660]=a[14318660]|64;return}function Ik(){a[14318665|0]=a[14318665|0]|64;return}function Il(){a[14318664]=a[14318664]|64;return}function Im(){a[14318669|0]=a[14318669|0]|64;return}function In(){a[14318668]=a[14318668]|64;return}function Io(){a[14318657|0]=a[14318657|0]|64;return}function Ip(){a[14318661|0]=a[14318661|0]|-128;return}function Iq(){a[14318660]=a[14318660]|-128;return}function Ir(){a[14318665|0]=a[14318665|0]|-128;return}function Is(){a[14318664]=a[14318664]|-128;return}function It(){a[14318669|0]=a[14318669|0]|-128;return}function Iu(){a[14318668]=a[14318668]|-128;return}function Iv(){a[14318657|0]=a[14318657|0]|-128;return}function Iw(a){a=a|0;c[291682]=a<<8;return}function Ix(){var a=0,d=0,e=0;a=c[291667]|0;c[291667]=a+2;d=1166604+((c[291673]&7)<<2)|0;e=c[d>>2]|b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;c[d>>2]=e;d=e&255;c[291677]=d;c[291678]=d;c[291680]=0;c[291679]=0;return}function Iy(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=fl[c[186832]&255](b)|0|16;fj[a&511](b,d);return}function Iz(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=fl[c[186832]&255](b)|0|32;fj[a&511](b,d);return}function IA(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=fl[c[186832]&255](b)|0|64;fj[a&511](b,d);return}function IB(){var a=0,b=0,d=0;a=c[186764]|0;b=e[7159334]|0;d=fl[c[186832]&255](b)|0|-128;fj[a&511](b,d);return}function IC(b){b=b|0;var f=0,g=0;if(a[670072]|0){ID();return}f=c[291673]|0;if((f&61440|0)!=8192){c[291649]=(c[291649]|0)+(d[602824+f|0]|0);a[670072]=1;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291673]=g;fG[c[274120+(g<<2)>>2]&16383]();a[670072]=0}c[291682]=b<<8;ID();return}function ID(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[291682]|0;f=c[291681]|0;if(d>>>0<=f>>>0){return}g=d>>>8;c[291686]=8;d=c[291683]&2;c[291683]=d;if((d|0)!=0){return}d=g+24|0;h=c[291675]|0;i=c[291674]|f|h<<11|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;c[291674]=0;c[1166672+(h<<2)>>2]=c[291666];c[291675]=4;c[291666]=c[291672];c[291681]=g<<8;do{if((a[962713]&a[888136])<<24>>24==0){a[1692344]=0;c[291682]=0}else{a[888136]=0;b[468728]=b[468728]&-129;if((a[962712]&a[1692344])<<24>>24==0){c[291682]=0;break}else{c[291682]=1024;break}}}while(0);g=d<<2;h=d>>>14&255;f=1161472+(h*20|0)|0;j=c[f>>2]|0;if((j|0)==0){k=c[1161464+(h*20|0)>>2]|0;h=g&65532;l=e[k+(h|2)>>1]|0|(e[k+h>>1]|0)<<16}else{h=g&16777212;g=(fl[j&255](h)|0)<<16;l=fl[c[f>>2]&255](h|2)|0|g}do{if((l|0)==0){g=c[290368]|0;if((g|0)==0){h=c[290366]|0;m=e[h+62>>1]|0|(e[h+60>>1]|0)<<16;break}else{h=(fl[g&255](60)|0)<<16;m=fl[c[290368]&255](62)|0|h;break}}else{m=l}}while(0);l=c[291667]|0;h=(c[291666]|0)-4|0;c[291666]=h;b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]=l>>>16&65535;h=(c[291666]|0)+2|0;b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]=l&65535;l=(c[291666]|0)-2|0;c[291666]=l;b[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]=i&65535;c[291667]=m;c[291649]=(c[291649]|0)+(e[536776+(d<<1)>>1]|0);return}function IE(a){a=a|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=1;g=0;h=i;i=i+168|0;c[h>>2]=0;while(1)switch(f|0){case 1:if((c[291649]|0)>>>0<a>>>0){f=2;break}else{f=15;break};case 2:aI(1158);if((s|0)!=0&(t|0)!=0){g=aIx(c[s>>2]|0,h)|0;if((g|0)>0){f=-1;break}else return}s=t=0;if((c[291683]|0)==0){f=4;break}else{f=3;break};case 3:c[291649]=a;f=15;break;case 4:c[291650]=a;j=aIw(1166756,f,h)|0;f=16;break;case 16:if((j|0)==0){f=5;break}else{f=6;break};case 5:k=c[291649]|0;f=13;break;case 6:l=c[291674]|0;m=c[291675]|0;n=c[291681]|0;o=c[291676]|0;p=c[291677]|0;q=c[291678]|0;r=c[291679]|0;u=c[291680]|0;c[291674]=0;c[1166672+(m<<2)>>2]=c[291666];c[291675]=4;v=c[291672]|0;c[291666]=v;if((c[291687]|0)==1){f=7;break}else{f=8;break};case 7:c[291683]=2;w=(c[291650]|0)-(d[602824+(c[291673]|0)|0]|0)|0;f=12;break;case 8:c[291687]=1;x=c[291667]|0;y=v-4|0;c[291666]=y;b[(c[1161464+((y>>>16&255)*20|0)>>2]|0)+(y&65535)>>1]=x>>>16&65535;y=(c[291666]|0)+2|0;b[(c[1161464+((y>>>16&255)*20|0)>>2]|0)+(y&65535)>>1]=x&65535;x=(c[291666]|0)-2|0;c[291666]=x;b[(c[1161464+((x>>>16&255)*20|0)>>2]|0)+(x&65535)>>1]=(m<<11|l|n|o>>>4&16|p>>>4&8|((q|0)==0)<<2|r>>>6&2|u>>>8&1)&65535;x=c[291673]|0;y=(c[291666]|0)-2|0;c[291666]=y;b[(c[1161464+((y>>>16&255)*20|0)>>2]|0)+(y&65535)>>1]=x&65535;x=c[291699]|0;y=(c[291666]|0)-4|0;c[291666]=y;b[(c[1161464+((y>>>16&255)*20|0)>>2]|0)+(y&65535)>>1]=x>>>16&65535;y=(c[291666]|0)+2|0;b[(c[1161464+((y>>>16&255)*20|0)>>2]|0)+(y&65535)>>1]=x&65535;x=c[291686]|c[291700]|c[291701];y=(c[291666]|0)-2|0;c[291666]=y;b[(c[1161464+((y>>>16&255)*20|0)>>2]|0)+(y&65535)>>1]=x&65535;z=c[290368]|0;if((z|0)==0){f=10;break}else{f=9;break};case 9:x=an(z|0,12)|0;if((s|0)!=0&(t|0)!=0){g=aIx(c[s>>2]|0,h)|0;if((g|0)>0){f=-1;break}else return}s=t=0;y=x<<16;x=an(c[290368]|0,14)|0;if((s|0)!=0&(t|0)!=0){g=aIx(c[s>>2]|0,h)|0;if((g|0)>0){f=-1;break}else return}s=t=0;A=x|y;f=11;break;case 10:y=c[290366]|0;A=e[y+14>>1]|0|(e[y+12>>1]|0)<<16;f=11;break;case 11:c[291667]=A;w=350-(d[602824+(c[291673]|0)|0]|0)+(c[291649]|0)|0;f=12;break;case 12:c[291649]=w;k=w;f=13;break;case 13:if(k>>>0<a>>>0){f=14;break}else{f=15;break};case 14:y=c[291667]|0;c[291667]=y+2;x=e[(c[1161464+((y>>>16&255)*20|0)>>2]|0)+(y&65535)>>1]|0;c[291673]=x;aI(c[274120+(x<<2)>>2]|0);if((s|0)!=0&(t|0)!=0){g=aIx(c[s>>2]|0,h)|0;if((g|0)>0){f=-1;break}else return}s=t=0;x=(c[291649]|0)+(d[602824+(c[291673]|0)|0]|0)|0;c[291649]=x;if(x>>>0<a>>>0){f=14;break}else{f=15;break};case 15:return;case-1:if((g|0)==4){j=t;f=16}s=t=0;break}}function IF(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[291675]|0;f=d<<11|c[291674]|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;c[291674]=0;c[1166672+(d<<2)>>2]=c[291666];c[291675]=4;d=c[291672]|0;c[291686]=8;g=(c[291667]|0)-2|0;h=d-4|0;c[291666]=h;b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]=g>>>16&65535;h=(c[291666]|0)+2|0;b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]=g&65535;g=(c[291666]|0)-2|0;c[291666]=g;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=f&65535;f=c[290368]|0;if((f|0)==0){g=c[290366]|0;i=e[g+18>>1]|0|(e[g+16>>1]|0)<<16;c[291667]=i;j=c[291673]|0;k=602824+j|0;l=a[k]|0;m=l&255;n=238-m|0;o=c[291649]|0;p=n+o|0;c[291649]=p;return}else{g=(fl[f&255](16)|0)<<16;i=fl[c[290368]&255](18)|0|g;c[291667]=i;j=c[291673]|0;k=602824+j|0;l=a[k]|0;m=l&255;n=238-m|0;o=c[291649]|0;p=n+o|0;c[291649]=p;return}}function IG(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=b>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]|0}else{i=fl[h&255](b&16777215)|0}h=i|f;f=h&255;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]=h&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[i&511](b&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function IH(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=1166604+((c[291673]&7|8)<<2)|0;g=c[b>>2]|0;c[b>>2]=g+1;b=g>>>16&255;h=c[1161468+(b*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i|f;f=h&255;i=c[1161476+(b*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]=h&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[i&511](g&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function II(){var a=0,b=0,d=0;a=(c[291677]|0)>>>4&8|(c[291676]|0)>>>4&16|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;b=c[291667]|0;c[291667]=b+2;d=a|(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0);b=d<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=d>>>2&1^1;c[291679]=d<<6&128;c[291680]=d<<8&256;return}function IJ(){var a=0,b=0,d=0;a=c[291667]|0;c[291667]=a+2;b=1166604+((c[291673]&7)<<2)|0;d=c[b>>2]|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0);c[b>>2]=d;b=d&65535;c[291677]=b>>>8;c[291678]=b;c[291680]=0;c[291679]=0;return}function IK(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[291666]|0;c[291666]=b+2;g=b>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]|0}else{i=fl[h&255](b&16777215)|0}h=i|f;f=h&255;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]=h&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[i&511](b&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function IL(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=1166604+((c[291673]&7|8)<<2)|0;g=(c[b>>2]|0)-1|0;c[b>>2]=g;b=g>>>16&255;h=c[1161468+(b*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i|f;f=h&255;i=c[1161476+(b*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]=h&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[i&511](g&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function IM(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=(c[291666]|0)-2|0;c[291666]=b;g=b>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]|0}else{i=fl[h&255](b&16777215)|0}h=i|f;f=h&255;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]=h&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[i&511](b&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function IN(){var f=0,g=0,h=0,i=0,j=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;i=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=f+4;f=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+i|0;i=f>>>16&255;g=c[1161468+(i*20|0)>>2]|0;if((g|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(f&65535^1)|0]|0}else{j=fl[g&255](f&16777215)|0}g=j|h;h=g&255;j=c[1161476+(i*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(f&65535^1)|0]=g&255;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[j&511](f&16777215,h);c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}}function IO(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;f=b+2|0;c[291667]=f;g=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;h=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=b+4;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){i=f<<16>>16}else{i=f}f=(b<<24>>24)+h+i|0;i=f>>>16&255;h=c[1161468+(i*20|0)>>2]|0;if((h|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(f&65535^1)|0]|0}else{j=fl[h&255](f&16777215)|0}h=j|g;g=h&255;j=c[1161476+(i*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(f&65535^1)|0]=h&255;c[291677]=g;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[j&511](f&16777215,g);c[291677]=g;c[291678]=g;c[291680]=0;c[291679]=0;return}}function IP(){var f=0,g=0,h=0,i=0,j=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291667]=f+4;f=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f>>>16&255;i=c[1161468+(g*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{j=fl[i&255](f&16777215)|0}i=j|h;h=i&255;j=c[1161476+(g*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=i&255;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[j&511](f&16777215,h);c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}}function IQ(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;f=b+2|0;c[291667]=f;g=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;c[291667]=b+6;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b+4|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|h<<16;i=h&255;h=c[1161468+(i*20|0)>>2]|0;if((h|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(b^1)|0]|0}else{j=fl[h&255](f&16777215)|0}h=j|g;g=h&255;j=c[1161476+(i*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(b^1)|0]=h&255;c[291677]=g;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[j&511](f&16777215,g);c[291677]=g;c[291678]=g;c[291680]=0;c[291679]=0;return}}function IR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j&65535|d;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[k&511](a&16777215,g);l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}}function IS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+2;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j&65535|d;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[k&511](f&16777215,g);l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}}function IT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;f=(c[a>>2]|0)-2|0;c[a>>2]=f;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j&65535|d;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[k&511](f&16777215,g);l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}}function IU(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=a+2|0;d=1166604+((c[291673]&7)<<2)|0;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16|c[d>>2];c[d>>2]=f;c[291677]=f>>>24;c[291678]=f;c[291680]=0;c[291679]=0;return}function IV(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291675]|0;if((a|0)==0){ahd();return}else{b=c[291667]|0;c[291667]=b+2;d=c[291674]|a<<11|(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)|c[291681];b=(c[291676]|0)>>>4&16|d|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2;f=b|(c[291679]|0)>>>6&2;g=f|(c[291680]|0)>>>8&1;c[291674]=d&32768;c[291681]=d&1792;h=g<<4;c[291676]=h&256;c[291677]=h&128;c[291678]=b>>>2&1^1;c[291679]=f<<6&128;c[291680]=g<<8&256;g=d>>>11&4;c[1166672+(a<<2)>>2]=c[291666];c[291675]=g;c[291666]=c[1166672+(g<<2)>>2];ID();return}}function IW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=(a&1|0)!=0;d=c[291688]|0;if(g&(d|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=d}else{d=fl[i&255](a&16777215)|0;j=d;k=c[291688]|0}d=j&65535|f;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=d&65535;l=d>>>8;c[291677]=l;c[291678]=d;c[291680]=0;c[291679]=0;return}else{fj[k&511](a&16777215,d);l=d>>>8;c[291677]=l;c[291678]=d;c[291680]=0;c[291679]=0;return}}function IX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+g+h|0;h=(d&1|0)!=0;g=c[291688]|0;if(h&(g|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;i=c[1161472+(a*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j&65535|f;if(h&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(a*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[k&511](d&16777215,g);l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}}function IY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(a&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j&65535|f;if(d&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[k&511](a&16777215,g);l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}}function IZ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+6;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=g&255;g=c[1161472+(j*20|0)>>2]|0;if((g|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0;l=i}else{i=fl[g&255](d&16777215)|0;k=i;l=c[291688]|0}i=k&65535|f;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=i&65535;m=i>>>8;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[l&511](d&16777215,i);m=i>>>8;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}}function I_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=a+2|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|g;l=j;m=c[291688]|0}j=f|l;if(d&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function I$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=a+2|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=f|l;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function I0(){var a=0;a=c[291673]|0;c[291678]=1<<(c[1166604+((a>>>9&7)<<2)>>2]&31)&c[1166604+((a&7)<<2)>>2];return}function I1(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;e=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=1166604+((a>>>9&7)<<2)|0;a=c[e>>2]&-65536;f=g>>>16&255;h=c[1161468+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i<<8;i=g+2|0;g=i>>>16&255;f=c[1161468+(g*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(g*20|0)>>2]|0)+(i&65535^1)|0]|0;k=j+h|0;l=k|a;c[e>>2]=l;return}else{j=fl[f&255](i&16777215)|0;k=j+h|0;l=k|a;c[e>>2]=l;return}}function I2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;c[291667]=a+4;d=a+2|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;a=(g&1|0)!=0;h=c[291688]|0;if(a&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=g>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](g&16777215)|0)<<16;k=fl[c[j>>2]&255](d+16777214&16777215)|0|h;m=k;n=c[291688]|0}k=f|m;if(a&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}g=d-2|0;d=g>>>16&255;n=c[1161480+(d*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]=k&65535;o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}else{fj[n&511](g&16777215,k&65535);o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}}function I3(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+f|0;f=(a&1|0)!=0;d=c[291688]|0;if(f&(d|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]<<16;m=d}else{d=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|d;l=j;m=c[291688]|0}j=g|l;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function I4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+f+h|0;h=(d&1|0)!=0;f=c[291688]|0;if(h&(f|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;i=1161472+(a*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=f}else{f=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|f;l=j;m=c[291688]|0}j=g|l;if(h&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(a*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[a&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function I5(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;c[291667]=a+6;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]<<16;m=f}else{f=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|f;l=j;m=c[291688]|0}j=g|l;if(d&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function I6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;c[291667]=a+8;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|f<<16;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=f&255;f=1161472+(j*20|0)|0;k=c[f>>2]|0;if((k|0)==0){l=d+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0)<<16;n=i}else{i=(fl[k&255](d&16777215)|0)<<16;k=fl[c[f>>2]&255](d+2&16777215)|0|i;m=k;n=c[291688]|0}k=g|m;if(h&(n|0)!=0){n=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(j*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=k>>>16&65535}else{fj[n&511](d&16777215,k>>>16)}n=d+2|0;d=n>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(n&65535)>>1]=k&65535;o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}else{fj[a&511](n&16777215,k&65535);o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}}function I7(){var a=0,e=0;a=c[291667]|0;c[291667]=a+2;e=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;c[291678]=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7)&d[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0];return}function I8(){var a=0,b=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){g=f<<16>>16}else{g=f}f=(b<<24>>24)+a+g|0;c[291678]=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7)&(d[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0);return}function I9(){var a=0;a=c[291667]|0;c[291667]=a+2;c[291678]=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255&1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);return}function Ja(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=1<<(c[1166604+((a>>>9&7)<<2)>>2]&31);c[291678]=d&c[b>>2];c[b>>2]=c[b>>2]^d;return}function Jb(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0}c[291678]=1<<(c[1166604+((h>>>9&7)<<2)>>2]&7)&g;return}function Jc(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}c[291678]=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7)&f;return}function Jd(){var a=0,b=0,e=0,f=0;a=c[291666]|0;c[291666]=a+2;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[291678]=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7)&f;return}function Je(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}c[291678]=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7)&f;return}function Jf(){var a=0,b=0,e=0,f=0;a=(c[291666]|0)-2|0;c[291666]=a;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[291678]=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7)&f;return}function Jg(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[291673]|0;e=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;i=a;j=i>>>9;k=j&7;l=1166604+(k<<2)|0;m=c[l>>2]|0;n=m&7;o=1<<n;p=o&h;c[291678]=p;return}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0;j=i>>>9;k=j&7;l=1166604+(k<<2)|0;m=c[l>>2]|0;n=m&7;o=1<<n;p=o&h;c[291678]=p;return}}function Jh(){var a=0,b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0;j=a;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n&7;p=1<<o;q=p&i;c[291678]=q;return}else{a=fl[b&255](f&16777215)|0;i=a;j=c[291673]|0;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n&7;p=1<<o;q=p&i;c[291678]=q;return}}function Ji(){var a=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[1161468+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}c[291678]=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7)&g;return}function Jj(){var a=0,b=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a^1)|0]|0}else{h=fl[g&255](a|b<<16&16711680)|0}c[291678]=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7)&h;return}function Jk(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+a|0;a=f>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(f&65535^1)|0]|0}else{g=fl[e&255](f&16777215)|0}e=f+2|0;a=e>>>16&255;h=c[1161468+(a*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}e=f+4|0;h=e>>>16&255;a=c[1161468+(h*20|0)>>2]|0;if((a|0)==0){j=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{j=fl[a&255](e&16777215)|0}e=(i<<16)+(g<<24)+(j<<8)|0;j=f+6|0;f=j>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){k=d[(c[1161464+(f*20|0)>>2]|0)+(j&65535^1)|0]|0;l=e+k|0;m=c[291673]|0;n=m>>>9;o=n&7;p=1166604+(o<<2)|0;c[p>>2]=l;return}else{k=fl[g&255](j&16777215)|0;l=e+k|0;m=c[291673]|0;n=m>>>9;o=n&7;p=1166604+(o<<2)|0;c[p>>2]=l;return}}function Jl(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[291673]|0}b=1<<(c[1166604+((i>>>9&7)<<2)>>2]&7);c[291678]=b&h;i=b^h;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=i&255;return}else{fj[h&511](e&16777215,i);return}}function Jm(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=f^g;g=c[1161476+(b*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function Jn(){var b=0,e=0,f=0,g=0,h=0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=f^g;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[g&511](b&16777215,h);return}}function Jo(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=f^g;g=c[1161476+(b*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function Jp(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=1<<(c[1166604+((a>>>9&7)<<2)>>2]&31);c[291678]=d&c[b>>2];c[b>>2]=c[b>>2]&~d;return}function Jq(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=f^g;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[g&511](b&16777215,h);return}}function Jr(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[291673]|0}e=1<<(c[1166604+((j>>>9&7)<<2)>>2]&7);c[291678]=e&i;j=e^i;i=c[1161476+(f*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]=j&255;return}else{fj[i&511](h&16777215,j);return}}function Js(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[1161468+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[291673]|0}b=1<<(c[1166604+((k>>>9&7)<<2)>>2]&7);c[291678]=b&j;k=b^j;j=c[1161476+(i*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]=k&255;return}else{fj[j&511](g&16777215,k);return}}function Jt(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=g&h;i=g^h;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function Ju(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&i;j=f^i;i=c[1161476+(h*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]=j&255;return}else{fj[i&511](g&16777215,j);return}}function Jv(){var d=0,e=0,f=0,g=0,h=0;d=c[291673]|0;e=c[1166604+((d&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=c[1166604+((d>>>9&7)<<2)>>2]|0;d=e>>>8;f=g>>>16&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=d&255}else{fj[h&511](g&16777215,d&255)}d=g+2|0;g=d>>>16&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[h&511](d&16777215,e&255);return}}function Jw(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[291673]|0}b=1<<(c[1166604+((i>>>9&7)<<2)>>2]&7);c[291678]=b&h;i=h&~b;b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=i&255;return}else{fj[b&511](e&16777215,i);return}}function Jx(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=g&~f;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function Jy(){var b=0,e=0,f=0,g=0,h=0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=g&~f;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[f&511](b&16777215,h);return}}function Jz(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=g&~f;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function JA(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=g&~f;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[f&511](b&16777215,h);return}}function JB(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[291673]|0}e=1<<(c[1166604+((j>>>9&7)<<2)>>2]&7);c[291678]=e&i;j=i&~e;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]=j&255;return}else{fj[e&511](h&16777215,j);return}}function JC(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[1161468+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[291673]|0}b=1<<(c[1166604+((k>>>9&7)<<2)>>2]&7);c[291678]=b&j;k=j&~b;b=c[1161476+(i*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]=k&255;return}else{fj[b&511](g&16777215,k);return}}function JD(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=1<<(c[1166604+((a>>>9&7)<<2)>>2]&31);c[291678]=d&c[b>>2];c[b>>2]=c[b>>2]|d;return}function JE(){var a=0,b=0,d=0;a=c[291667]|0;c[291667]=a+2;b=1166604+((c[291673]&7)<<2)|0;d=c[b>>2]&(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|-256);c[b>>2]=d;b=d&255;c[291678]=b;c[291677]=b;c[291680]=0;c[291679]=0;return}function JF(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=g&h;i=h&~g;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[g&511](f&16777215,i);return}}function JG(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&i;j=i&~f;f=c[1161476+(h*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]=j&255;return}else{fj[f&511](g&16777215,j);return}}function JH(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[291673]|0;e=c[1166604+((d&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=c[1166604+((d>>>9&7)<<2)>>2]|0;d=e>>>24;f=g>>>16&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=d&255}else{fj[h&511](g&16777215,d)}d=g+2|0;h=e>>>16;f=d>>>16&255;i=c[1161476+(f*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(d&65535^1)|0]=h&255}else{fj[i&511](d&16777215,h&255)}h=g+4|0;d=e>>>8;i=h>>>16&255;f=c[1161476+(i*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(h&65535^1)|0]=d&255}else{fj[f&511](h&16777215,d&255)}d=g+6|0;g=d>>>16&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[h&511](d&16777215,e&255);return}}function JI(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[291673]|0}b=1<<(c[1166604+((i>>>9&7)<<2)>>2]&7);c[291678]=b&h;i=b|h;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=i&255;return}else{fj[h&511](e&16777215,i);return}}function JJ(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=f|g;g=c[1161476+(b*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function JK(){var b=0,e=0,f=0,g=0,h=0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=f|g;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[g&511](b&16777215,h);return}}function JL(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=f|g;g=c[1161476+(b*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function JM(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&g;h=f|g;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[g&511](b&16777215,h);return}}function JN(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[291673]|0}e=1<<(c[1166604+((j>>>9&7)<<2)>>2]&7);c[291678]=e&i;j=e|i;i=c[1161476+(f*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]=j&255;return}else{fj[i&511](h&16777215,j);return}}function JO(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[1161468+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[291673]|0}b=1<<(c[1166604+((k>>>9&7)<<2)>>2]&7);c[291678]=b&j;k=b|j;j=c[1161476+(i*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]=k&255;return}else{fj[j&511](g&16777215,k);return}}function JP(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=g&h;i=g|h;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function JQ(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=1<<(c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&7);c[291678]=f&i;j=f|i;i=c[1161476+(h*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]=j&255;return}else{fj[i&511](g&16777215,j);return}}function JR(){var a=0,b=0,d=0;a=(c[291677]|0)>>>4&8|(c[291676]|0)>>>4&16|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;b=c[291667]|0;c[291667]=b+2;d=a&(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0);b=d<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=d>>>2&1^1;c[291679]=d<<6&128;c[291680]=d<<8&256;return}function JS(){var a=0,b=0,d=0;a=c[291667]|0;c[291667]=a+2;b=1166604+((c[291673]&7)<<2)|0;d=c[b>>2]&(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|-65536);c[b>>2]=d;b=d&65535;c[291678]=b;c[291677]=b>>>8;c[291680]=0;c[291679]=0;return}function JT(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=f&i;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,h);return}}function JU(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=1166604+((c[291673]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=f&i;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;i=c[1161476+(e*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[i&511](g&16777215,h);return}}function JV(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[291666]|0;c[291666]=e+2;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=f&i;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,h);return}}function JW(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=1166604+((c[291673]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=f&i;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;i=c[1161476+(e*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[i&511](g&16777215,h);return}}function JX(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=(c[291666]|0)-2|0;c[291666]=e;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=f&i;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,h);return}}function JY(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;h=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=e+4;e=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}f=g&i;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;i=c[1161476+(h*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[i&511](e&16777215,f);return}}function JZ(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;i=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=f+4;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=h&k;c[291677]=i;c[291678]=i;c[291680]=0;c[291679]=0;k=c[1161476+(j*20|0)>>2]|0;if((k|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[k&511](g&16777215,i);return}}function J_(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;c[291667]=e+4;e=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[1161468+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=g&i;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;i=c[1161476+(f*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,h);return}}function J$(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;c[291667]=f+6;i=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=h&k;c[291677]=i;c[291678]=i;c[291680]=0;c[291679]=0;k=c[1161476+(j*20|0)>>2]|0;if((k|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]=i&255;return}else{fj[k&511](g&16777215,i);return}}function J0(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j&d;c[291677]=g>>>8;c[291678]=g;c[291680]=0;c[291679]=0;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[k&511](a&16777215,g);return}}function J1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+2;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j&d;c[291677]=g>>>8;c[291678]=g;c[291680]=0;c[291679]=0;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[k&511](f&16777215,g);return}}function J2(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=a+2|0;d=1166604+((c[291673]&7)<<2)|0;f=c[d>>2]&(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16);c[d>>2]=f;c[291678]=f;c[291677]=f>>>24;c[291680]=0;c[291679]=0;return}function J3(){var a=0,b=0,d=0;a=c[291675]|0;if((a|0)==0){ahd();return}else{b=c[291667]|0;c[291667]=b+2;d=(c[291674]|a<<11|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1)&(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0);c[291674]=d&32768;c[291681]=d&1792;b=d<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=d>>>2&1^1;c[291679]=d<<6&128;c[291680]=d<<8&256;b=d>>>11&4;c[1166672+(a<<2)>>2]=c[291666];c[291675]=b;c[291666]=c[1166672+(b<<2)>>2];ID();return}}function J4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;f=(c[a>>2]|0)-2|0;c[a>>2]=f;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j&d;c[291677]=g>>>8;c[291678]=g;c[291680]=0;c[291679]=0;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[k&511](f&16777215,g);return}}function J5(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=(a&1|0)!=0;d=c[291688]|0;if(g&(d|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=d}else{d=fl[i&255](a&16777215)|0;j=d;k=c[291688]|0}d=j&f;c[291677]=d>>>8;c[291678]=d;c[291680]=0;c[291679]=0;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[k&511](a&16777215,d);return}}function J6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+g+h|0;h=(d&1|0)!=0;g=c[291688]|0;if(h&(g|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;i=c[1161472+(a*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j&f;c[291677]=g>>>8;c[291678]=g;c[291680]=0;c[291679]=0;if(h&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(a*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,g);return}}function J7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(a&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j&f;c[291677]=g>>>8;c[291678]=g;c[291680]=0;c[291679]=0;if(d&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[k&511](a&16777215,g);return}}function J8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+6;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=g&255;g=c[1161472+(j*20|0)>>2]|0;if((g|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0;l=i}else{i=fl[g&255](d&16777215)|0;k=i;l=c[291688]|0}i=k&f;c[291677]=i>>>8;c[291678]=i;c[291680]=0;c[291679]=0;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=i&65535;return}else{fj[l&511](d&16777215,i);return}}function J9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=a+2|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|g;l=j;m=c[291688]|0}j=l&f;c[291677]=j>>>24;c[291678]=j;c[291680]=0;c[291679]=0;if(d&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function Ka(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=a+2|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l&f;c[291677]=j>>>24;c[291678]=j;c[291680]=0;c[291679]=0;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function Kb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=a+2|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;a=(g&1|0)!=0;h=c[291688]|0;if(a&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=g>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](g&16777215)|0)<<16;k=fl[c[j>>2]&255](d+16777214&16777215)|0|h;m=k;n=c[291688]|0}k=m&f;c[291677]=k>>>24;c[291678]=k;c[291680]=0;c[291679]=0;if(a&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}g=d-2|0;d=g>>>16&255;n=c[1161480+(d*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]=k&65535;return}else{fj[n&511](g&16777215,k&65535);return}}function Kc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+f|0;f=(a&1|0)!=0;d=c[291688]|0;if(f&(d|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]<<16;m=d}else{d=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|d;l=j;m=c[291688]|0}j=l&g;c[291677]=j>>>24;c[291678]=j;c[291680]=0;c[291679]=0;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function Kd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+f+h|0;h=(d&1|0)!=0;f=c[291688]|0;if(h&(f|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;i=1161472+(a*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=f}else{f=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|f;l=j;m=c[291688]|0}j=l&g;c[291677]=j>>>24;c[291678]=j;c[291680]=0;c[291679]=0;if(h&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(a*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[a&511](m&16777215,j&65535);return}}function Ke(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;c[291667]=a+6;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]<<16;m=f}else{f=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|f;l=j;m=c[291688]|0}j=l&g;c[291677]=j>>>24;c[291678]=j;c[291680]=0;c[291679]=0;if(d&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function Kf(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=d&255;f=c[a>>2]|0;g=f&255;h=g-b|0;c[291677]=h;i=f-d&255;c[291678]=i;c[291680]=h;c[291676]=h;c[291679]=(h^f)&(b^g);c[a>>2]=c[a>>2]&-256|i;return}function Kg(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[a>>2]|0;f=b&65535;g=f-d|0;h=g>>>8;c[291677]=h;i=b-d&65535;c[291678]=i;c[291680]=h;c[291676]=h;c[291679]=((g^b)&(f^d))>>>8;c[a>>2]=c[a>>2]&-65536|i;return}function Kh(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i-f|0;c[291677]=h;j=h&255;c[291678]=j;c[291680]=h;c[291676]=h;c[291679]=(h^i)&(i^f);f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,j);return}}function Ki(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=1166604+((c[291673]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i-f|0;c[291677]=h;j=h&255;c[291678]=j;c[291680]=h;c[291676]=h;c[291679]=(h^i)&(i^f);f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,j);return}}function Kj(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[291666]|0;c[291666]=e+2;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i-f|0;c[291677]=h;j=h&255;c[291678]=j;c[291680]=h;c[291676]=h;c[291679]=(h^i)&(i^f);f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,j);return}}function Kk(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=1166604+((c[291673]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i-f|0;c[291677]=h;j=h&255;c[291678]=j;c[291680]=h;c[291676]=h;c[291679]=(h^i)&(i^f);f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,j);return}}function Kl(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=(c[291666]|0)-2|0;c[291666]=e;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i-f|0;c[291677]=h;j=h&255;c[291678]=j;c[291680]=h;c[291676]=h;c[291679]=(h^i)&(i^f);f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,j);return}}function Km(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;h=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=e+4;e=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}f=i-g|0;c[291677]=f;j=f&255;c[291678]=j;c[291680]=f;c[291676]=f;c[291679]=(f^i)&(i^g);g=c[1161476+(h*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,j);return}}function Kn(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;i=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=f+4;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=k-h|0;c[291677]=i;f=i&255;c[291678]=f;c[291680]=i;c[291676]=i;c[291679]=(i^k)&(k^h);h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[h&511](g&16777215,f);return}}function Ko(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;c[291667]=e+4;e=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[1161468+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i-g|0;c[291677]=h;j=h&255;c[291678]=j;c[291680]=h;c[291676]=h;c[291679]=(h^i)&(i^g);g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,j);return}}function Kp(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;c[291667]=f+6;i=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=k-h|0;c[291677]=i;l=i&255;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=(i^k)&(k^h);h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]=i&255;return}else{fj[h&511](g&16777215,l);return}}function Kq(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;c[291667]=a+8;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|f<<16;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=f&255;f=1161472+(j*20|0)|0;k=c[f>>2]|0;if((k|0)==0){l=d+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0)<<16;n=i}else{i=(fl[k&255](d&16777215)|0)<<16;k=fl[c[f>>2]&255](d+2&16777215)|0|i;m=k;n=c[291688]|0}k=m&g;c[291677]=k>>>24;c[291678]=k;c[291680]=0;c[291679]=0;if(h&(n|0)!=0){n=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(j*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=k>>>16&65535}else{fj[n&511](d&16777215,k>>>16)}n=d+2|0;d=n>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[a&511](n&16777215,k&65535);return}}function Kr(){var a=0,b=0,d=0,f=0,g=0;a=1166604+((c[291673]&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;f=b+2|0;b=c[a>>2]|0;g=b-(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d)|0;c[291677]=g>>>24;c[291678]=g;f=((g|d)&(b^-8388608)|g&d)>>>23;c[291680]=f;c[291676]=f;c[291679]=((g^b)&(b^d))>>>24;c[a>>2]=g;return}function Ks(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j-d|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^d))>>>8;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[k&511](a&16777215,l);return}}function Kt(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+2;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j-d|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^d))>>>8;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[k&511](f&16777215,l);return}}function Ku(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;f=(c[a>>2]|0)-2|0;c[a>>2]=f;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j-d|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^d))>>>8;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[k&511](f&16777215,l);return}}function Kv(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=(a&1|0)!=0;d=c[291688]|0;if(g&(d|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=d}else{d=fl[i&255](a&16777215)|0;j=d;k=c[291688]|0}d=j-f|0;i=d>>>8;c[291677]=i;l=d&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((d^j)&(j^f))>>>8;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[k&511](a&16777215,l);return}}function Kw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+g+h|0;h=(d&1|0)!=0;g=c[291688]|0;if(h&(g|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;i=c[1161472+(a*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j-f|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^f))>>>8;if(h&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(a*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,l);return}}function Kx(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(a&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j-f|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^f))>>>8;if(d&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[k&511](a&16777215,l);return}}function Ky(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+6;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=g&255;g=c[1161472+(j*20|0)>>2]|0;if((g|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0;l=i}else{i=fl[g&255](d&16777215)|0;k=i;l=c[291688]|0}i=k-f|0;g=i>>>8;c[291677]=g;m=i&65535;c[291678]=m;c[291680]=g;c[291676]=g;c[291679]=((i^k)&(k^f))>>>8;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=i&65535;return}else{fj[l&511](d&16777215,m);return}}
function _S(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;f=c[d>>2]|g;c[d>>2]=f;d=f&65535;c[291677]=d>>>8;c[291678]=d;c[291680]=0;c[291679]=0;return}function _T(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b&255;b=c[1161472+(f*20|0)>>2]|0;if((b|0)==0){g=e[(c[1161464+(f*20|0)>>2]|0)+a>>1]|0}else{g=fl[b&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[d>>2]|g;c[d>>2]=b;d=b&65535;c[291677]=d>>>8;c[291678]=d;c[291680]=0;c[291679]=0;return}function _U(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=1161472+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n|i;c[m>>2]=o;p=o>>>24;c[291677]=p;c[291678]=o;c[291680]=0;c[291679]=0;return}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[291673]|0;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n|i;c[m>>2]=o;p=o>>>24;c[291677]=p;c[291678]=o;c[291680]=0;c[291679]=0;return}}function _V(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=1161472+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[a>>2]|h;c[a>>2]=b;c[291677]=b>>>24;c[291678]=b;c[291680]=0;c[291679]=0;return}function _W(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[a>>2]|i;c[a>>2]=b;c[291677]=b>>>24;c[291678]=b;c[291680]=0;c[291679]=0;return}function _X(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=d+2|0;f=1166604+(((c[291673]|0)>>>9&7)<<2)|0;g=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]<<16|c[f>>2];c[f>>2]=g;c[291677]=g>>>24;c[291678]=g;c[291680]=0;c[291679]=0;return}function _Y(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=d+2|0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16|c[a>>2];c[a>>2]=b;c[291677]=b>>>24;c[291678]=b;c[291680]=0;c[291679]=0;return}function _Z(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=a+2|0;d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16|c[d>>2];c[d>>2]=f;c[291677]=f>>>24;c[291678]=f;c[291680]=0;c[291679]=0;return}function __(){var a=0,b=0,d=0;a=ahi()|0;b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]|a;c[b>>2]=d;c[291677]=d>>>24;c[291678]=d;c[291680]=0;c[291679]=0;return}function _$(){var a=0,b=0,d=0;a=ahh()|0;b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]|a;c[b>>2]=d;c[291677]=d>>>24;c[291678]=d;c[291680]=0;c[291679]=0;return}function _0(){var a=0,b=0,d=0;a=ahg()|0;b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]|a;c[b>>2]=d;c[291677]=d>>>24;c[291678]=d;c[291680]=0;c[291679]=0;return}function _1(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=d&65535;if((a|0)==0){c[291680]=0;ahc(5);return}e=c[b>>2]|0;f=(e>>>0)/(a>>>0)|0;if(f>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}g=d<<16;d=e;h=0;i=266;while(1){j=d<<1;do{if((d|0)<0){k=i;l=j-g|0}else{if(j>>>0<g>>>0){k=i+14|0;l=j;break}k=i+7|0;l=j-g|0}}while(0);j=h+1|0;if((j|0)<15){d=l;h=j;i=k}else{break}}c[291649]=(c[291649]|0)+(k<<1);c[291678]=f;c[291677]=f>>>8;c[291679]=0;c[291680]=0;c[b>>2]=((e>>>0)%(a>>>0)|0)<<16|f&65535;return}function _2(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=1161472+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n|i;c[m>>2]=o;p=o>>>24;c[291677]=p;c[291678]=o;c[291680]=0;c[291679]=0;return}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[291673]|0;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n|i;c[m>>2]=o;p=o>>>24;c[291677]=p;c[291678]=o;c[291680]=0;c[291679]=0;return}}function _3(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}if((g|0)==0){c[291680]=0;ahc(5);return}d=c[b>>2]|0;f=(d>>>0)/(g>>>0)|0;if(f>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}a=g<<16;h=d;i=0;j=266;while(1){k=h<<1;do{if((h|0)<0){l=j;m=k-a|0}else{if(k>>>0<a>>>0){l=j+14|0;m=k;break}l=j+7|0;m=k-a|0}}while(0);k=i+1|0;if((k|0)<15){h=m;i=k;j=l}else{break}}c[291649]=(c[291649]|0)+(l<<1);c[291678]=f;c[291677]=f>>>8;c[291679]=0;c[291680]=0;c[b>>2]=((d>>>0)%(g>>>0)|0)<<16|f&65535;return}function _4(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}if((g|0)==0){c[291680]=0;ahc(5);return}a=c[b>>2]|0;f=(a>>>0)/(g>>>0)|0;if(f>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}d=g<<16;h=a;i=0;j=266;while(1){k=h<<1;do{if((h|0)<0){l=j;m=k-d|0}else{if(k>>>0<d>>>0){l=j+14|0;m=k;break}l=j+7|0;m=k-d|0}}while(0);k=i+1|0;if((k|0)<15){h=m;i=k;j=l}else{break}}c[291649]=(c[291649]|0)+(l<<1);c[291678]=f;c[291677]=f>>>8;c[291679]=0;c[291680]=0;c[b>>2]=((a>>>0)%(g>>>0)|0)<<16|f&65535;return}function _5(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}if((g|0)==0){c[291680]=0;ahc(5);return}a=c[b>>2]|0;f=(a>>>0)/(g>>>0)|0;if(f>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}d=g<<16;h=a;i=0;j=266;while(1){k=h<<1;do{if((h|0)<0){l=j;m=k-d|0}else{if(k>>>0<d>>>0){l=j+14|0;m=k;break}l=j+7|0;m=k-d|0}}while(0);k=i+1|0;if((k|0)<15){h=m;i=k;j=l}else{break}}c[291649]=(c[291649]|0)+(l<<1);c[291678]=f;c[291677]=f>>>8;c[291679]=0;c[291680]=0;c[b>>2]=((a>>>0)%(g>>>0)|0)<<16|f&65535;return}function _6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=1166604+((a>>>9&7)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;if((g&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}if((h|0)==0){c[291680]=0;ahc(5);return}g=c[d>>2]|0;a=(g>>>0)/(h>>>0)|0;if(a>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}f=h<<16;i=g;j=0;k=266;while(1){l=i<<1;do{if((i|0)<0){m=k;n=l-f|0}else{if(l>>>0<f>>>0){m=k+14|0;n=l;break}m=k+7|0;n=l-f|0}}while(0);l=j+1|0;if((l|0)<15){i=n;j=l;k=m}else{break}}c[291649]=(c[291649]|0)+(m<<1);c[291678]=a;c[291677]=a>>>8;c[291679]=0;c[291680]=0;c[d>>2]=((g>>>0)%(h>>>0)|0)<<16|a&65535;return}function _7(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=(a&15)-(d&15)-((c[291676]|0)>>>8&1)|0;c[291679]=0;f=(e>>>0>9?e-6|0:e)+((a&240)-(d&240))|0;d=f>>>0>153;a=d?256:0;c[291680]=a;c[291676]=a;c[291677]=d?128:0;a=(d?f+160|0:f)&255;c[291678]=a|c[291678];c[b>>2]=a|c[b>>2]&-256;return}function _8(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=d&65535;if(d<<16>>16==0){c[291680]=0;ahc(5);return}d=c[a>>2]|0;f=(d>>>0)/(e>>>0)|0;if(f>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}g=e<<16;h=d;i=0;j=266;while(1){k=h<<1;do{if((h|0)<0){l=j;m=k-g|0}else{if(k>>>0<g>>>0){l=j+14|0;m=k;break}l=j+7|0;m=k-g|0}}while(0);k=i+1|0;if((k|0)<15){h=m;i=k;j=l}else{break}}c[291649]=(c[291649]|0)+(l<<1);c[291678]=f;c[291677]=f>>>8;c[291679]=0;c[291680]=0;c[a>>2]=((d>>>0)%(e>>>0)|0)<<16|f&65535;return}function _9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;if(h<<16>>16==0){c[291680]=0;ahc(5);return}h=c[a>>2]|0;d=(h>>>0)/(g>>>0)|0;if(d>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}f=g<<16;i=h;j=0;k=266;while(1){l=i<<1;do{if((i|0)<0){m=k;n=l-f|0}else{if(l>>>0<f>>>0){m=k+14|0;n=l;break}m=k+7|0;n=l-f|0}}while(0);l=j+1|0;if((l|0)<15){i=n;j=l;k=m}else{break}}c[291649]=(c[291649]|0)+(m<<1);c[291678]=d;c[291677]=d>>>8;c[291679]=0;c[291680]=0;c[a>>2]=((h>>>0)%(g>>>0)|0)<<16|d&65535;return}function $a(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&65535;if(e<<16>>16==0){c[291680]=0;ahc(5);return}e=c[a>>2]|0;f=(e>>>0)/(d>>>0)|0;if(f>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}g=d<<16;h=e;i=0;j=266;while(1){k=h<<1;do{if((h|0)<0){l=j;m=k-g|0}else{if(k>>>0<g>>>0){l=j+14|0;m=k;break}l=j+7|0;m=k-g|0}}while(0);k=i+1|0;if((k|0)<15){h=m;i=k;j=l}else{break}}c[291649]=(c[291649]|0)+(l<<1);c[291678]=f;c[291677]=f>>>8;c[291679]=0;c[291680]=0;c[a>>2]=((e>>>0)%(d>>>0)|0)<<16|f&65535;return}function $b(){var b=0,e=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;b=c[1161468+(e*20|0)>>2]|0;if((b|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[b&255](f&16777215)|0}b=(h&15)-(g&15)-((c[291676]|0)>>>8&1)|0;c[291679]=0;i=(b>>>0>9?b-6|0:b)+((h&240)-(g&240))|0;g=i>>>0>153;h=g?256:0;b=g?i+160|0:i;c[291680]=h;c[291676]=h;c[291677]=g?128:0;g=b&255;c[291678]=g|c[291678];h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[h&511](f&16777215,g);return}}function $c(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}if((h|0)==0){c[291680]=0;ahc(5);return}a=c[b>>2]|0;d=(a>>>0)/(h>>>0)|0;if(d>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}g=h<<16;f=a;i=0;j=266;while(1){k=f<<1;do{if((f|0)<0){l=j;m=k-g|0}else{if(k>>>0<g>>>0){l=j+14|0;m=k;break}l=j+7|0;m=k-g|0}}while(0);k=i+1|0;if((k|0)<15){f=m;i=k;j=l}else{break}}c[291649]=(c[291649]|0)+(l<<1);c[291678]=d;c[291677]=d>>>8;c[291679]=0;c[291680]=0;c[b>>2]=((a>>>0)%(h>>>0)|0)<<16|d&65535;return}function $d(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}if((h|0)==0){c[291680]=0;ahc(5);return}f=c[a>>2]|0;g=(f>>>0)/(h>>>0)|0;if(g>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}d=h<<16;i=f;j=0;k=266;while(1){l=i<<1;do{if((i|0)<0){m=k;n=l-d|0}else{if(l>>>0<d>>>0){m=k+14|0;n=l;break}m=k+7|0;n=l-d|0}}while(0);l=j+1|0;if((l|0)<15){i=n;j=l;k=m}else{break}}c[291649]=(c[291649]|0)+(m<<1);c[291678]=g;c[291677]=g>>>8;c[291679]=0;c[291680]=0;c[a>>2]=((f>>>0)%(h>>>0)|0)<<16|g&65535;return}function $e(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;if((b&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+b>>1]|0}else{h=fl[d&255](f&16777215)|0}if((h|0)==0){c[291680]=0;ahc(5);return}f=c[a>>2]|0;d=(f>>>0)/(h>>>0)|0;if(d>>>0>=65536){c[291649]=(c[291649]|0)+70;c[291679]=128;c[291677]=128;c[291680]=0;return}b=h<<16;g=f;i=0;j=266;while(1){k=g<<1;do{if((g|0)<0){l=j;m=k-b|0}else{if(k>>>0<b>>>0){l=j+14|0;m=k;break}l=j+7|0;m=k-b|0}}while(0);k=i+1|0;if((k|0)<15){g=m;i=k;j=l}else{break}}c[291649]=(c[291649]|0)+(l<<1);c[291678]=d;c[291677]=d>>>8;c[291679]=0;c[291680]=0;c[a>>2]=((f>>>0)%(h>>>0)|0)<<16|d&65535;return}function $f(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[e&255](f&16777215)|0}e=(h&15)-(g&15)-((c[291676]|0)>>>8&1)|0;c[291679]=0;i=(e>>>0>9?e-6|0:e)+((h&240)-(g&240))|0;g=i>>>0>153;h=g?256:0;e=g?i+160|0:i;c[291680]=h;c[291676]=h;c[291677]=g?128:0;g=e&255;c[291678]=g|c[291678];h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[h&511](f&16777215,g);return}}function $g(){var b=0,e=0,f=0,g=0,h=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=c[1166604+((b>>>9&7)<<2)>>2]|0;b=e>>>16&255;g=c[1161468+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h|f;f=g&255;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[h&511](e&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function $h(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h|b;b=g&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}else{fj[h&511](e&16777215,b);c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}}function $i(){var b=0,e=0,f=0,g=0,h=0;b=c[291666]|0;c[291666]=b+2;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h|e;e=g&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}else{fj[h&511](b&16777215,e);c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}}function $j(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h|b;b=g&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}else{fj[h&511](e&16777215,b);c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}}function $k(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h|e;e=g&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}else{fj[h&511](b&16777215,e);c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}}function $l(){var e=0,f=0,g=0,h=0,i=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=c[1166604+((e>>>9&7)<<2)>>2]|0;e=h>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[g&255](h&16777215)|0}g=i|f;f=g&255;i=c[1161476+(e*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(h&65535^1)|0]=g&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[i&511](h&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function $m(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=c[1166604+((b>>>9&7)<<2)>>2]|0;b=g>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j|i;i=f&255;j=c[1161476+(b*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]=f&255;c[291677]=i;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[j&511](g&16777215,i);c[291677]=i;c[291678]=i;c[291680]=0;c[291679]=0;return}}function $n(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[h&255](f&16777215)|0}h=i|e;e=h&255;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}else{fj[i&511](f&16777215,e);c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}}function $o(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;i=f&255;f=c[1161468+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(b^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j|h;h=f&255;j=c[1161476+(i*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(b^1)|0]=f&255;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[j&511](g&16777215,h);c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}}function $p(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j|f;f=g&65535;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;l=f>>>8;c[291677]=l;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[k&511](d&16777215,f);l=f>>>8;c[291677]=l;c[291678]=f;c[291680]=0;c[291679]=0;return}}function $q(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j|a;a=g&65535;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}else{fj[k&511](d&16777215,a);l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}}function $r(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j|a;a=g&65535;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}else{fj[k&511](d&16777215,a);l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}}function $s(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]|0;k=f}else{f=fl[i&255](g&16777215)|0;j=f;k=c[291688]|0}f=j|d;d=f&65535;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=f&65535;l=d>>>8;c[291677]=l;c[291678]=d;c[291680]=0;c[291679]=0;return}else{fj[k&511](g&16777215,d);l=d>>>8;c[291677]=l;c[291678]=d;c[291680]=0;c[291679]=0;return}}function $t(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;i=c[1161472+(g*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;k=d}else{d=fl[i&255](f&16777215)|0;j=d;k=c[291688]|0}d=j|h;h=d&65535;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(g*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;l=h>>>8;c[291677]=l;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[k&511](f&16777215,h);l=h>>>8;c[291677]=l;c[291678]=h;c[291680]=0;c[291679]=0;return}}function $u(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j|a;a=g&65535;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}else{fj[k&511](d&16777215,a);l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}}function $v(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=d&255;d=c[1161472+(j*20|0)>>2]|0;if((d|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0;l=i}else{i=fl[d&255](f&16777215)|0;k=i;l=c[291688]|0}i=k|g;g=i&65535;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=i&65535;m=g>>>8;c[291677]=m;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[l&511](f&16777215,g);m=g>>>8;c[291677]=m;c[291678]=g;c[291680]=0;c[291679]=0;return}}function $w(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l|f;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function $x(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l|a;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function $y(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;g=(f&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](f&16777215)|0)<<16;k=fl[c[j>>2]&255](d+16777214&16777215)|0|h;m=k;n=c[291688]|0}k=m|a;if(g&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}f=d-2|0;d=f>>>16&255;n=c[1161480+(d*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=k&65535;o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}else{fj[n&511](f&16777215,k&65535);o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}}function $z(){var a=0,b=0,d=0,e=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]<<16>>16;if((d|0)==0){c[291680]=0;ahc(5);return}aha(c[b>>2]|0,d&65535);a=c[b>>2]|0;if((a|0)==-2147483648&(d|0)==-1){aIv(1166708,0,16);c[b>>2]=0;return}e=(a|0)/(d|0)|0;if((e|0)==(e<<16>>16|0)){c[291678]=e;c[291677]=e>>8;c[291679]=0;c[291680]=0;c[b>>2]=((a|0)%(d|0)|0)<<16|e&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $A(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=g+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]<<16;m=f}else{f=(fl[j&255](g&16777215)|0)<<16;j=fl[c[i>>2]&255](g+2&16777215)|0|f;l=j;m=c[291688]|0}j=l|d;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[m&511](g&16777215,j>>>16)}m=g+2|0;g=m>>>16&255;h=c[1161480+(g*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function $B(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;i=1161472+(g*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;m=d}else{d=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](f+2&16777215)|0|d;l=j;m=c[291688]|0}j=l|h;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(g*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[g&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function $C(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l|a;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function $D(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=d&255;d=1161472+(j*20|0)|0;k=c[d>>2]|0;if((k|0)==0){l=f+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0)<<16;n=i}else{i=(fl[k&255](f&16777215)|0)<<16;k=fl[c[d>>2]&255](f+2&16777215)|0|i;m=k;n=c[291688]|0}k=m|g;if(h&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(j*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}n=f+2|0;f=n>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(n&65535)>>1]=k&65535;o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}else{fj[a&511](n&16777215,k&65535);o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}}function $E(){var a=0,b=0,d=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=g<<16>>16;if((d|0)==0){c[291680]=0;ahc(5);return}aha(c[b>>2]|0,d&65535);g=c[b>>2]|0;if((g|0)==-2147483648&(d|0)==-1){aIv(1166708,0,16);c[b>>2]=0;return}f=(g|0)/(d|0)|0;if((f|0)==(f<<16>>16|0)){c[291678]=f;c[291677]=f>>8;c[291679]=0;c[291680]=0;c[b>>2]=((g|0)%(d|0)|0)<<16|f&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $F(){var a=0,b=0,d=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=g<<16>>16;if((a|0)==0){c[291680]=0;ahc(5);return}aha(c[b>>2]|0,a&65535);g=c[b>>2]|0;if((g|0)==-2147483648&(a|0)==-1){aIv(1166708,0,16);c[b>>2]=0;return}f=(g|0)/(a|0)|0;if((f|0)==(f<<16>>16|0)){c[291678]=f;c[291677]=f>>8;c[291679]=0;c[291680]=0;c[b>>2]=((g|0)%(a|0)|0)<<16|f&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $G(){var a=0,d=0,e=0,f=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=d<<16>>16;if(d<<16>>16==0){c[291680]=0;ahc(5);return}aha(c[a>>2]|0,d);f=c[a>>2]|0;if((f|0)==-2147483648&d<<16>>16==-1){aIv(1166708,0,16);c[a>>2]=0;return}d=(f|0)/(e|0)|0;if((d|0)==(d<<16>>16|0)){c[291678]=d;c[291677]=d>>8;c[291679]=0;c[291680]=0;c[a>>2]=((f|0)%(e|0)|0)<<16|d&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $H(){var a=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h<<16>>16;if(h<<16>>16==0){c[291680]=0;ahc(5);return}aha(c[a>>2]|0,h);d=c[a>>2]|0;if((d|0)==-2147483648&h<<16>>16==-1){aIv(1166708,0,16);c[a>>2]=0;return}h=(d|0)/(g|0)|0;if((h|0)==(h<<16>>16|0)){c[291678]=h;c[291677]=h>>8;c[291679]=0;c[291680]=0;c[a>>2]=((d|0)%(g|0)|0)<<16|h&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $I(){var a=0,d=0,e=0,f=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e<<16>>16;if(e<<16>>16==0){c[291680]=0;ahc(5);return}aha(c[a>>2]|0,e);f=c[a>>2]|0;if((f|0)==-2147483648&e<<16>>16==-1){aIv(1166708,0,16);c[a>>2]=0;return}e=(f|0)/(d|0)|0;if((e|0)==(e<<16>>16|0)){c[291678]=e;c[291677]=e>>8;c[291679]=0;c[291680]=0;c[a>>2]=((f|0)%(d|0)|0)<<16|e&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $J(){var b=0,e=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[291666]|0)-2|0;c[291666]=e;f=e>>>16&255;b=c[1161468+(f*20|0)>>2]|0;if((b|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[b&255](e&16777215)|0}b=(h&15)-(g&15)-((c[291676]|0)>>>8&1)|0;c[291679]=0;i=(b>>>0>9?b-6|0:b)+((h&240)-(g&240))|0;g=i>>>0>153;h=g?256:0;b=g?i+160|0:i;c[291680]=h;c[291676]=h;c[291677]=g?128:0;g=b&255;c[291678]=g|c[291678];h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[h&511](e&16777215,g);return}}function $K(){var a=0,b=0,d=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=g<<16>>16;if((a|0)==0){c[291680]=0;ahc(5);return}aha(c[b>>2]|0,a&65535);g=c[b>>2]|0;if((g|0)==-2147483648&(a|0)==-1){aIv(1166708,0,16);c[b>>2]=0;return}f=(g|0)/(a|0)|0;if((f|0)==(f<<16>>16|0)){c[291678]=f;c[291677]=f>>8;c[291679]=0;c[291680]=0;c[b>>2]=((g|0)%(a|0)|0)<<16|f&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $L(){var a=0,d=0,f=0,g=0,h=0;a=c[291673]|0;d=1166604+((a>>>9&7)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;if((g&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}g=h<<16>>16;if((g|0)==0){c[291680]=0;ahc(5);return}aha(c[d>>2]|0,g&65535);h=c[d>>2]|0;if((h|0)==-2147483648&(g|0)==-1){aIv(1166708,0,16);c[d>>2]=0;return}a=(h|0)/(g|0)|0;if((a|0)==(a<<16>>16|0)){c[291678]=a;c[291677]=a>>8;c[291679]=0;c[291680]=0;c[d>>2]=((h|0)%(g|0)|0)<<16|a&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $M(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=h<<16>>16;if((a|0)==0){c[291680]=0;ahc(5);return}aha(c[b>>2]|0,a&65535);h=c[b>>2]|0;if((h|0)==-2147483648&(a|0)==-1){aIv(1166708,0,16);c[b>>2]=0;return}d=(h|0)/(a|0)|0;if((d|0)==(d<<16>>16|0)){c[291678]=d;c[291677]=d>>8;c[291679]=0;c[291680]=0;c[b>>2]=((h|0)%(a|0)|0)<<16|d&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $N(){var a=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}f=h<<16>>16;if((f|0)==0){c[291680]=0;ahc(5);return}aha(c[a>>2]|0,f&65535);h=c[a>>2]|0;if((h|0)==-2147483648&(f|0)==-1){aIv(1166708,0,16);c[a>>2]=0;return}g=(h|0)/(f|0)|0;if((g|0)==(g<<16>>16|0)){c[291678]=g;c[291677]=g>>8;c[291679]=0;c[291680]=0;c[a>>2]=((h|0)%(f|0)|0)<<16|g&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $O(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;if((b&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+b>>1]|0}else{h=fl[d&255](f&16777215)|0}f=h<<16>>16;if((f|0)==0){c[291680]=0;ahc(5);return}aha(c[a>>2]|0,f&65535);h=c[a>>2]|0;if((h|0)==-2147483648&(f|0)==-1){aIv(1166708,0,16);c[a>>2]=0;return}d=(h|0)/(f|0)|0;if((d|0)==(d<<16>>16|0)){c[291678]=d;c[291677]=d>>8;c[291679]=0;c[291680]=0;c[a>>2]=((h|0)%(f|0)|0)<<16|d&65535;return}else{c[291679]=128;c[291677]=128;c[291680]=0;return}}function $P(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=d&255;e=c[b>>2]|0;f=e&255;g=f-a|0;c[291677]=g;c[291680]=g;c[291676]=g;c[291679]=(g^e)&(f^a);a=e-d&255;c[291678]=a;c[b>>2]=c[b>>2]&-256|a;return}function $Q(){var a=0,e=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+e|0;e=d[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=c[a>>2]|0;g=f&255;h=g-e|0;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=(h^f)&(g^e);g=f-e&255;c[291678]=g;c[a>>2]=c[a>>2]&-256|g;return}function $R(){var a=0,b=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+b+h|0;h=d[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=c[a>>2]|0;b=g&255;f=b-h|0;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=(f^g)&(b^h);b=g-h&255;c[291678]=b;c[a>>2]=c[a>>2]&-256|b;return}function $S(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=d&255;f=c[a>>2]|0;g=f&255;h=g-b|0;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=(h^f)&(b^g);g=f-d&255;c[291678]=g;c[a>>2]=c[a>>2]&-256|g;return}function $T(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f-a|0;h=g>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=((g^e)&(f^a))>>>8;a=e-d&65535;c[291678]=a;c[b>>2]=c[b>>2]&-65536|a;return}function $U(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f-a|0;h=g>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=((g^e)&(f^a))>>>8;a=e-d&65535;c[291678]=a;c[b>>2]=c[b>>2]&-65536|a;return}function $V(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[291666]|0}e=h-2|0;c[291666]=e;h=e>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[b&255](e&16777215)|0}b=(i&15)-(g&15)-((c[291676]|0)>>>8&1)|0;c[291679]=0;f=(b>>>0>9?b-6|0:b)+((i&240)-(g&240))|0;g=f>>>0>153;i=g?256:0;b=g?f+160|0:f;c[291680]=i;c[291676]=i;c[291677]=g?128:0;g=b&255;c[291678]=g|c[291678];i=c[1161476+(h*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[i&511](e&16777215,g);return}}function $W(){var a=0,b=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;e=c[1166604+((a&7|8)<<2)>>2]|0;a=e>>>16&255;f=c[1161468+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[b>>2]|0;f=e&255;a=f-g|0;c[291677]=a;c[291680]=a;c[291676]=a;c[291679]=(a^f)&(f^g);f=e-g&255;c[291678]=f;c[b>>2]=c[b>>2]&-256|f;return}function $X(){var a=0,b=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;e=1166604+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+1;e=a>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(a&65535^1)|0]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;e=f-g|0;c[291677]=e;c[291680]=e;c[291676]=e;c[291679]=(e^f)&(f^g);f=a-g&255;c[291678]=f;c[b>>2]=c[b>>2]&-256|f;return}function $Y(){var a=0,b=0,e=0,f=0,g=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[a>>2]|0;f=b&255;e=f-g|0;c[291677]=e;c[291680]=e;c[291676]=e;c[291679]=(e^f)&(f^g);f=b-g&255;c[291678]=f;c[a>>2]=c[a>>2]&-256|f;return}function $Z(){var a=0,b=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;e=1166604+((a&7|8)<<2)|0;a=(c[e>>2]|0)-1|0;c[e>>2]=a;e=a>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(a&65535^1)|0]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;e=f-g|0;c[291677]=e;c[291680]=e;c[291676]=e;c[291679]=(e^f)&(f^g);f=a-g&255;c[291678]=f;c[b>>2]=c[b>>2]&-256|f;return}function $_(){var a=0,b=0,e=0,f=0,g=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[a>>2]|0;f=b&255;e=f-g|0;c[291677]=e;c[291680]=e;c[291676]=e;c[291679]=(e^f)&(f^g);f=b-g&255;c[291678]=f;c[a>>2]=c[a>>2]&-256|f;return}function $$(){var a=0,e=0,f=0,g=0,h=0;a=c[291673]|0;e=1166604+((a>>>9&7)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[1161468+(f*20|0)>>2]|0;if((a|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[a&255](g&16777215)|0}g=c[e>>2]|0;a=g&255;f=a-h|0;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=(f^a)&(a^h);a=g-h&255;c[291678]=a;c[e>>2]=c[e>>2]&-256|a;return}function $0(){var a=0,b=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=a>>>16&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(a&65535^1)|0]|0}else{i=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;h=f-i|0;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=(h^f)&(f^i);f=a-i&255;c[291678]=f;c[b>>2]=c[b>>2]&-256|f;return}function $1(){var a=0,e=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[a>>2]|0;g=f&255;e=g-h|0;c[291677]=e;c[291680]=e;c[291676]=e;c[291679]=(e^g)&(g^h);g=f-h&255;c[291678]=g;c[a>>2]=c[a>>2]&-256|g;return}function $2(){var a=0,b=0,f=0,g=0,h=0,i=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=c[a>>2]|0;b=f&255;h=b-i|0;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=(h^b)&(b^i);b=f-i&255;c[291678]=b;c[a>>2]=c[a>>2]&-256|b;return}function $3(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[b>>2]|0;f=d&65535;a=f-g|0;h=a>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=((a^f)&(f^g))>>>8;f=d-g&65535;c[291678]=f;c[b>>2]=c[b>>2]&-65536|f;return}function $4(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[a>>2]|0;g=f&65535;h=g-d|0;i=h>>>8;c[291677]=i;c[291680]=i;c[291676]=i;c[291679]=((h^f)&(g^d))>>>8;g=f-d&65535;c[291678]=g;c[a>>2]=c[a>>2]&-65536|g;return}function $5(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[a>>2]|0;b=f&65535;d=b-g|0;h=d>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=((d^f)&(b^g))>>>8;b=f-g&65535;c[291678]=b;c[a>>2]=c[a>>2]&-65536|b;return}function $6(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[a>>2]|0;f=b&65535;g=f-d|0;h=g>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=((g^b)&(f^d))>>>8;f=b-d&65535;c[291678]=f;c[a>>2]=c[a>>2]&-65536|f;return}function $7(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a-d|0;c[291677]=e>>>24;f=((e|d)&(a^-8388608)|e&d)>>>23;c[291680]=f;c[291676]=f;c[291679]=((e^a)&(a^d))>>>24;c[291678]=e;c[b>>2]=e;return}function $8(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[b>>2]|0;e=a-d|0;c[291677]=e>>>24;f=((e|d)&(a^-8388608)|e&d)>>>23;c[291680]=f;c[291676]=f;c[291679]=((e^a)&(a^d))>>>24;c[291678]=e;c[b>>2]=e;return}function $9(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&65535;d=f-g|0;h=d>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=((d^f)&(f^g))>>>8;f=a-g&65535;c[291678]=f;c[b>>2]=c[b>>2]&-65536|f;return}function aaa(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&65535;d=f-g|0;h=d>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=((d^f)&(f^g))>>>8;f=a-g&65535;c[291678]=f;c[b>>2]=c[b>>2]&-65536|f;return}function aab(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=1166604+((a>>>9&7)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;if((g&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}g=c[d>>2]|0;a=g&65535;f=a-h|0;i=f>>>8;c[291677]=i;c[291680]=i;c[291676]=i;c[291679]=((f^a)&(a^h))>>>8;a=g-h&65535;c[291678]=a;c[d>>2]=c[d>>2]&-65536|a;return}function aac(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=c[b>>2]|0;d=a&65535;g=d-h|0;f=g>>>8;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=((g^d)&(d^h))>>>8;d=a-h&65535;c[291678]=d;c[b>>2]=c[b>>2]&-65536|d;return}function aad(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}f=c[a>>2]|0;g=f&65535;d=g-h|0;i=d>>>8;c[291677]=i;c[291680]=i;c[291676]=i;c[291679]=((d^g)&(g^h))>>>8;g=f-h&65535;c[291678]=g;c[a>>2]=c[a>>2]&-65536|g;return}function aae(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;if((b&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+b>>1]|0}else{h=fl[d&255](f&16777215)|0}f=c[a>>2]|0;d=f&65535;b=d-h|0;g=b>>>8;c[291677]=g;c[291680]=g;c[291676]=g;c[291679]=((b^d)&(d^h))>>>8;d=f-h&65535;c[291678]=d;c[a>>2]=c[a>>2]&-65536|d;return}function aaf(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[b>>2]|0;d=a-i|0;c[291677]=d>>>24;f=((d|i)&(a^-8388608)|d&i)>>>23;c[291680]=f;c[291676]=f;c[291679]=((d^a)&(a^i))>>>24;c[291678]=d;c[b>>2]=d;return}function aag(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+4;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=1161472+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{d=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|d}d=c[b>>2]|0;a=d-i|0;c[291677]=a>>>24;f=((a|i)&(d^-8388608)|a&i)>>>23;c[291680]=f;c[291676]=f;c[291679]=((a^d)&(d^i))>>>24;c[291678]=a;c[b>>2]=a;return}function aah(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;f=a-4|0;c[d>>2]=f;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=1161472+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a-2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](a+16777214&16777215)|0|d}d=c[b>>2]|0;a=d-j|0;c[291677]=a>>>24;g=((a|j)&(d^-8388608)|a&j)>>>23;c[291680]=g;c[291676]=g;c[291679]=((a^d)&(d^j))>>>24;c[291678]=a;c[b>>2]=a;return}function aai(){var a=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]<<16;g=f+2|0;f=c[a>>2]|0;h=f-(e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|d)|0;c[291677]=h>>>24;g=((h|d)&(f^-8388608)|h&d)>>>23;c[291680]=g;c[291676]=g;c[291679]=((h^f)&(f^d))>>>24;c[291678]=h;c[a>>2]=h;return}function aaj(){var a=0,b=0,d=0,f=0,g=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;b=f+2|0;f=c[a>>2]|0;d=f-(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|g)|0;c[291677]=d>>>24;b=((d|g)&(f^-8388608)|d&g)>>>23;c[291680]=b;c[291676]=b;c[291679]=((d^f)&(f^g))>>>24;c[291678]=d;c[a>>2]=d;return}function aak(){var a=0,b=0,d=0,f=0,g=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;f=b+2|0;b=c[a>>2]|0;g=b-(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d)|0;c[291677]=g>>>24;f=((g|d)&(b^-8388608)|g&d)>>>23;c[291680]=f;c[291676]=f;c[291679]=((g^b)&(b^d))>>>24;c[291678]=g;c[a>>2]=g;return}function aal(){var a=0,b=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[1166604+((a&7)<<2)>>2]<<16>>16);return}function aam(){var a=0,b=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[1166604+((a&7|8)<<2)>>2]<<16>>16);return}function aan(){var a=0,d=0,e=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;c[a>>2]=(c[a>>2]|0)-(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0);return}function aao(){var a=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;c[a>>2]=(c[a>>2]|0)-(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0);return}function aap(){var a=0,b=0,d=0,e=0,f=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=ahi()|0;d=c[a>>2]|0;e=d-b|0;c[291677]=e>>>24;f=((e|b)&(d^-8388608)|e&b)>>>23;c[291680]=f;c[291676]=f;c[291679]=((e^d)&(d^b))>>>24;c[291678]=e;c[a>>2]=e;return}function aaq(){var a=0,b=0,d=0,e=0,f=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=ahh()|0;d=c[a>>2]|0;e=d-b|0;c[291677]=e>>>24;f=((e|b)&(d^-8388608)|e&b)>>>23;c[291680]=f;c[291676]=f;c[291679]=((e^d)&(d^b))>>>24;c[291678]=e;c[a>>2]=e;return}function aar(){var a=0,b=0,d=0,e=0,f=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=ahg()|0;d=c[a>>2]|0;e=d-b|0;c[291677]=e>>>24;f=((e|b)&(d^-8388608)|e&b)>>>23;c[291680]=f;c[291676]=f;c[291679]=((e^d)&(d^b))>>>24;c[291678]=e;c[a>>2]=e;return}function aas(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=1161472+(g*20|0)|0;f=c[d>>2]|0;if((f|0)==0){h=a+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j-i|0;l=k>>>24;c[291677]=l;m=k&i;n=j^-8388608;o=k|i;p=o&n;q=p|m;r=q>>>23;c[291680]=r;c[291676]=r;s=j^i;t=k^j;u=t&s;v=u>>>24;c[291679]=v;c[291678]=k;c[b>>2]=k;return}else{g=(fl[f&255](a&16777215)|0)<<16;i=fl[c[d>>2]&255](a+2&16777215)|0|g;j=c[b>>2]|0;k=j-i|0;l=k>>>24;c[291677]=l;m=k&i;n=j^-8388608;o=k|i;p=o&n;q=p|m;r=q>>>23;c[291680]=r;c[291676]=r;s=j^i;t=k^j;u=t&s;v=u>>>24;c[291679]=v;c[291678]=k;c[b>>2]=k;return}}function aat(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{g=fl[f&255](d&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function aau(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{g=fl[f&255](a&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function aav(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{g=fl[f&255](a&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function aaw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=1166604+((a>>>9&7|8)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;if((g&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0;i=h<<16;j=i>>16;k=c[d>>2]|0;l=k-j|0;c[d>>2]=l;return}else{h=fl[a&255](g&16777215)|0;i=h<<16;j=i>>16;k=c[d>>2]|0;l=k-j|0;c[d>>2]=l;return}}function aax(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;i=h<<16;j=i>>16;k=c[b>>2]|0;l=k-j|0;c[b>>2]=l;return}else{h=fl[d&255](a&16777215)|0;i=h<<16;j=i>>16;k=c[b>>2]|0;l=k-j|0;c[b>>2]=l;return}}function aay(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}else{h=fl[g&255](f&16777215)|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}}function aaz(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;if((b&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+b>>1]|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}else{h=fl[d&255](f&16777215)|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}}function aaA(){var a=0,d=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[291667]|0;c[291667]=d+2;c[a>>2]=(c[a>>2]|0)-(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0);return}function aaB(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]&255;a=c[b>>2]|0;e=a&255;f=e-d-((c[291676]|0)>>>8&1)|0;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=(f^a)&(e^d);d=f&255;c[291678]=d|c[291678];c[b>>2]=d|c[b>>2]&-256;return}function aaC(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]&65535;a=c[b>>2]|0;e=a&65535;f=e-d-((c[291676]|0)>>>8&1)|0;g=f>>>8;c[291677]=g;c[291680]=g;c[291676]=g;c[291679]=((f^a)&(e^d))>>>8;d=f&65535;c[291678]=d|c[291678];c[b>>2]=d|c[b>>2]&-65536;return}function aaD(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;b=c[1161468+(e*20|0)>>2]|0;if((b|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[b&255](f&16777215)|0}b=h-g-((c[291676]|0)>>>8&1)|0;c[291677]=b;c[291680]=b;c[291676]=b;c[291679]=(b^h)&(h^g);g=b&255;c[291678]=g|c[291678];h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[h&511](f&16777215,g);return}}function aaE(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[e&255](f&16777215)|0}e=h-g-((c[291676]|0)>>>8&1)|0;c[291677]=e;c[291680]=e;c[291676]=e;c[291679]=(e^h)&(h^g);g=e&255;c[291678]=g|c[291678];h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[h&511](f&16777215,g);return}}function aaF(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=c[1166604+((b>>>9&7)<<2)>>2]&255;b=e>>>16&255;g=c[1161468+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h-f|0;c[291677]=g;i=g&255;c[291678]=i;c[291680]=g;c[291676]=g;c[291679]=(g^h)&(h^f);f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[f&511](e&16777215,i);return}}function aaG(){var b=0,e=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&255;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h-b|0;c[291677]=g;i=g&255;c[291678]=i;c[291680]=g;c[291676]=g;c[291679]=(g^h)&(h^b);b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,i);return}}function aaH(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291666]|0;c[291666]=b+2;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&255;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h-e|0;c[291677]=g;i=g&255;c[291678]=i;c[291680]=g;c[291676]=g;c[291679]=(g^h)&(h^e);e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,i);return}}function aaI(){var b=0,e=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&255;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h-b|0;c[291677]=g;i=g&255;c[291678]=i;c[291680]=g;c[291676]=g;c[291679]=(g^h)&(h^b);b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,i);return}}function aaJ(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[291666]|0)-2|0;c[291666]=b;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&255;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h-e|0;c[291677]=g;i=g&255;c[291678]=i;c[291680]=g;c[291676]=g;c[291679]=(g^h)&(h^e);e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,i);return}}function aaK(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=c[1166604+((e>>>9&7)<<2)>>2]&255;e=h>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[g&255](h&16777215)|0}g=i-f|0;c[291677]=g;j=g&255;c[291678]=j;c[291680]=g;c[291676]=g;c[291679]=(g^i)&(i^f);f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(h&65535^1)|0]=g&255;return}else{fj[f&511](h&16777215,j);return}}function aaL(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=c[1166604+((b>>>9&7)<<2)>>2]&255;b=g>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j-i|0;c[291677]=f;h=f&255;c[291678]=h;c[291680]=f;c[291676]=f;c[291679]=(f^j)&(j^i);i=c[1161476+(b*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]=f&255;return}else{fj[i&511](g&16777215,h);return}}function aaM(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&255;g=f>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[h&255](f&16777215)|0}h=i-e|0;c[291677]=h;j=h&255;c[291678]=j;c[291680]=h;c[291676]=h;c[291679]=(h^i)&(i^e);e=c[1161476+(g*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[e&511](f&16777215,j);return}}function aaN(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&255;i=f&255;f=c[1161468+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(b^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j-h|0;c[291677]=f;k=f&255;c[291678]=k;c[291680]=f;c[291676]=f;c[291679]=(f^j)&(j^h);h=c[1161476+(i*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](g&16777215,k);return}}function aaO(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a-d-((c[291676]|0)>>>8&1)|0;c[291677]=e>>>24;f=((e|d)&(a^-8388608)|e&d)>>>23;c[291680]=f;c[291676]=f;c[291679]=((e^a)&(a^d))>>>24;c[291678]=e|c[291678];c[b>>2]=e;return}function aaP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-2|0;c[d>>2]=f;d=(f&1|0)!=0;a=c[291688]|0;if(d&(a|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=a}else{a=fl[i&255](f&16777215)|0;j=a;k=c[291688]|0}a=j-g-((c[291676]|0)>>>8&1)|0;i=a>>>8;c[291677]=i;c[291680]=i;c[291676]=i;c[291679]=((a^j)&(j^g))>>>8;g=a&65535;c[291678]=g|c[291678];if(d&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[k&511](f&16777215,g);return}}function aaQ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7)<<2)>>2]&65535;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j-f|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^f))>>>8;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,l);return}}function aaR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&65535;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j-a|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^a))>>>8;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,l);return}}function aaS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&65535;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j-a|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^a))>>>8;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,l);return}}function aaT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[1166604+((a>>>9&7)<<2)>>2]&65535;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]|0;k=f}else{f=fl[i&255](g&16777215)|0;j=f;k=c[291688]|0}f=j-d|0;i=f>>>8;c[291677]=i;l=f&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((f^j)&(j^d))>>>8;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=f&65535;return}else{fj[k&511](g&16777215,l);return}}function aaU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[1166604+((a>>>9&7)<<2)>>2]&65535;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;i=c[1161472+(g*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;k=d}else{d=fl[i&255](f&16777215)|0;j=d;k=c[291688]|0}d=j-h|0;i=d>>>8;c[291677]=i;l=d&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((d^j)&(j^h))>>>8;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(g*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[k&511](f&16777215,l);return}}function aaV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&65535;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j-a|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^a))>>>8;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,l);return}}function aaW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]&65535;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=d&255;d=c[1161472+(j*20|0)>>2]|0;if((d|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0;l=i}else{i=fl[d&255](f&16777215)|0;k=i;l=c[291688]|0}i=k-g|0;d=i>>>8;c[291677]=d;m=i&65535;c[291678]=m;c[291680]=d;c[291676]=d;c[291679]=((i^k)&(k^g))>>>8;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=i&65535;return}else{fj[l&511](f&16777215,m);return}}function aaX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=1161472+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=1161472+(h*20|0)|0;k=c[i>>2]|0;if((k|0)==0){l=d-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;n=f}else{f=(fl[k&255](g&16777215)|0)<<16;k=fl[c[i>>2]&255](d+16777214&16777215)|0|f;m=k;n=c[291688]|0}k=m-j-((c[291676]|0)>>>8&1)|0;c[291677]=k>>>24;f=((k|j)&(m^-8388608)|k&j)>>>23;c[291680]=f;c[291676]=f;c[291679]=((k^m)&(m^j))>>>24;c[291678]=k|c[291678];if(a&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(h*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}g=d-2|0;d=g>>>16&255;n=c[1161480+(d*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]=k&65535;return}else{fj[n&511](g&16777215,k&65535);return}}function aaY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l-f|0;c[291677]=j>>>24;c[291678]=j;g=((j|f)&(l^-8388608)|j&f)>>>23;c[291680]=g;c[291676]=g;c[291679]=((j^l)&(l^f))>>>24;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function aaZ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l-a|0;c[291677]=j>>>24;c[291678]=j;g=((j|a)&(l^-8388608)|j&a)>>>23;c[291680]=g;c[291676]=g;c[291679]=((j^l)&(l^a))>>>24;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function aa_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;g=(f&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](f&16777215)|0)<<16;k=fl[c[j>>2]&255](d+16777214&16777215)|0|h;m=k;n=c[291688]|0}k=m-a|0;c[291677]=k>>>24;c[291678]=k;h=((k|a)&(m^-8388608)|k&a)>>>23;c[291680]=h;c[291676]=h;c[291679]=((k^m)&(m^a))>>>24;if(g&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}f=d-2|0;d=f>>>16&255;n=c[1161480+(d*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=k&65535;return}else{fj[n&511](f&16777215,k&65535);return}}function aa$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=g+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]<<16;m=f}else{f=(fl[j&255](g&16777215)|0)<<16;j=fl[c[i>>2]&255](g+2&16777215)|0|f;l=j;m=c[291688]|0}j=l-d|0;c[291677]=j>>>24;c[291678]=j;f=((j|d)&(l^-8388608)|j&d)>>>23;c[291680]=f;c[291676]=f;c[291679]=((j^l)&(l^d))>>>24;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[m&511](g&16777215,j>>>16)}m=g+2|0;g=m>>>16&255;h=c[1161480+(g*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function aa0(){var a=0,b=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[1166604+((a&7)<<2)>>2]|0);return}function aa1(){var a=0,b=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[1166604+((a&7|8)<<2)>>2]|0);return}function aa2(){var a=0,d=0,f=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=f+2|0;c[a>>2]=(c[a>>2]|0)-(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]<<16);return}function aa3(){var a=0,b=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=ahi()|0;c[a>>2]=(c[a>>2]|0)-b;return}function aa4(){var a=0,b=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=ahh()|0;c[a>>2]=(c[a>>2]|0)-b;return}function aa5(){var a=0,b=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=ahg()|0;c[a>>2]=(c[a>>2]|0)-b;return}function aa6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;i=1161472+(g*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;m=d}else{d=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](f+2&16777215)|0|d;l=j;m=c[291688]|0}j=l-h|0;c[291677]=j>>>24;c[291678]=j;d=((j|h)&(l^-8388608)|j&h)>>>23;c[291680]=d;c[291676]=d;c[291679]=((j^l)&(l^h))>>>24;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(g*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[g&511](m&16777215,j&65535);return}}function aa7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l-a|0;c[291677]=j>>>24;c[291678]=j;g=((j|a)&(l^-8388608)|j&a)>>>23;c[291680]=g;c[291676]=g;c[291679]=((j^l)&(l^a))>>>24;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function aa8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=d&255;d=1161472+(j*20|0)|0;k=c[d>>2]|0;if((k|0)==0){l=f+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0)<<16;n=i}else{i=(fl[k&255](f&16777215)|0)<<16;k=fl[c[d>>2]&255](f+2&16777215)|0|i;m=k;n=c[291688]|0}k=m-g|0;c[291677]=k>>>24;c[291678]=k;i=((k|g)&(m^-8388608)|k&g)>>>23;c[291680]=i;c[291676]=i;c[291679]=((k^m)&(m^g))>>>24;if(h&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(j*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}n=f+2|0;f=n>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[a&511](n&16777215,k&65535);return}}function aa9(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function aba(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+4;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=1161472+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{d=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|d;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function abb(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;f=a-4|0;c[d>>2]=f;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=1161472+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a-2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=c[b>>2]|0;l=k-j|0;c[b>>2]=l;return}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](a+16777214&16777215)|0|d;k=c[b>>2]|0;l=k-j|0;c[b>>2]=l;return}}function abc(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=1161472+(g*20|0)|0;f=c[d>>2]|0;if((f|0)==0){h=a+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{g=(fl[f&255](a&16777215)|0)<<16;i=fl[c[d>>2]&255](a+2&16777215)|0|g;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function abd(){var a=0,b=0,d=0,f=0,g=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=f+2|0;c[a>>2]=(c[a>>2]|0)-(e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)<<16);return}function abe(){var a=0,b=0,d=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=b+2|0;c[a>>2]=(c[a>>2]|0)-(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16);return}function abf(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=c[1166604+((a&7)<<2)>>2]|0;d=b&255;e=c[1166604+((a>>>9&7)<<2)>>2]|0;a=e&255;f=a-d|0;c[291677]=f;c[291678]=e-b&255;c[291679]=(f^e)&(a^d);c[291680]=f;return}function abg(){var a=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;e=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=d[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=e&255;g=f-a|0;c[291677]=g;c[291678]=e-a&255;c[291679]=(g^e)&(f^a);c[291680]=g;return}function abh(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[291666]|0)-2|0;c[291666]=e;f=e>>>16&255;b=c[1161468+(f*20|0)>>2]|0;if((b|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[b&255](e&16777215)|0}b=h-g-((c[291676]|0)>>>8&1)|0;c[291677]=b;c[291680]=b;c[291676]=b;c[291679]=(b^h)&(h^g);g=b&255;c[291678]=g|c[291678];h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[h&511](e&16777215,g);return}}function abi(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[291666]|0}e=h-2|0;c[291666]=e;h=e>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[b&255](e&16777215)|0}b=i-g-((c[291676]|0)>>>8&1)|0;c[291677]=b;c[291680]=b;c[291676]=b;c[291679]=(b^i)&(i^g);g=b&255;c[291678]=g|c[291678];i=c[1161476+(h*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[i&511](e&16777215,g);return}}function abj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[291675]|0;f=d<<11|c[291674]|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;c[291674]=0;c[1166672+(d<<2)>>2]=c[291666];c[291675]=4;d=(c[291667]|0)-2|0;g=(c[291672]|0)-4|0;c[291666]=g;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[291666]|0)+2|0;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;d=(c[291666]|0)-2|0;c[291666]=d;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;f=c[290368]|0;if((f|0)==0){d=c[290366]|0;h=e[d+42>>1]|0|(e[d+40>>1]|0)<<16;c[291667]=h;i=c[291673]|0;j=602824+i|0;k=a[j]|0;l=k&255;m=28-l|0;n=c[291649]|0;o=m+n|0;c[291649]=o;return}else{d=(fl[f&255](40)|0)<<16;h=fl[c[290368]&255](42)|0|d;c[291667]=h;i=c[291673]|0;j=602824+i|0;k=a[j]|0;l=k&255;m=28-l|0;n=c[291649]|0;o=m+n|0;c[291649]=o;return}}function abk(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0}a=c[1166604+((h>>>9&7)<<2)>>2]|0;h=a&255;b=h-g|0;c[291677]=b;c[291678]=a-g&255;c[291679]=(b^h)&(h^g);c[291680]=b;return}function abl(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;e=b&255;a=e-f|0;c[291677]=a;c[291678]=b-f&255;c[291679]=(a^e)&(e^f);c[291680]=a;return}function abm(){var a=0,b=0,e=0,f=0;a=c[291666]|0;c[291666]=a+2;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;e=a&255;b=e-f|0;c[291677]=b;c[291678]=a-f&255;c[291679]=(b^e)&(e^f);c[291680]=b;return}function abn(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;e=b&255;a=e-f|0;c[291677]=a;c[291678]=b-f&255;c[291679]=(a^e)&(e^f);c[291680]=a;return}function abo(){var a=0,b=0,e=0,f=0;a=(c[291666]|0)-2|0;c[291666]=a;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;e=a&255;b=e-f|0;c[291677]=b;c[291678]=a-f&255;c[291679]=(b^e)&(e^f);c[291680]=b;return}function abp(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[291673]|0;e=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=c[1166604+((i>>>9&7)<<2)>>2]|0;i=a&255;g=i-h|0;c[291677]=g;c[291678]=a-h&255;c[291679]=(g^i)&(i^h);c[291680]=g;return}function abq(){var a=0,b=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0;j=a}else{a=fl[b&255](f&16777215)|0;i=a;j=c[291673]|0}a=c[1166604+((j>>>9&7)<<2)>>2]|0;j=a&255;f=j-i|0;c[291677]=f;c[291678]=a-i&255;c[291679]=(f^j)&(j^i);c[291680]=f;return}function abr(){var a=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[1161468+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=e&255;a=f-g|0;c[291677]=a;c[291678]=e-g&255;c[291679]=(a^f)&(f^g);c[291680]=a;return}function abs(){var a=0,b=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a^1)|0]|0}else{h=fl[g&255](a|b<<16&16711680)|0}b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;a=b&255;g=a-h|0;c[291677]=g;c[291678]=b-h&255;c[291679]=(g^a)&(a^h);c[291680]=g;return}function abt(){var a=0,b=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){g=f<<16>>16}else{g=f}f=(b<<24>>24)+a+g|0;g=d[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;a=f&255;b=a-g|0;c[291677]=b;c[291678]=f-g&255;c[291679]=(b^f)&(a^g);c[291680]=b;return}function abu(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=b&255;d=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=d&255;g=f-a|0;c[291677]=g;c[291678]=d-b&255;c[291679]=(g^d)&(f^a);c[291680]=g;return}function abv(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=c[1166604+((a&7)<<2)>>2]|0;d=b&65535;e=c[1166604+((a>>>9&7)<<2)>>2]|0;a=e&65535;f=a-d|0;g=f>>>8;c[291677]=g;c[291678]=e-b&65535;c[291679]=((f^e)&(a^d))>>>8;c[291680]=g;return}function abw(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=b&65535;e=c[1166604+((a>>>9&7)<<2)>>2]|0;a=e&65535;f=a-d|0;g=f>>>8;c[291677]=g;c[291678]=e-b&65535;c[291679]=((f^e)&(a^d))>>>8;c[291680]=g;return}function abx(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=d&65535;g=f-a|0;h=g>>>8;c[291677]=h;c[291678]=d-a&65535;c[291679]=((g^d)&(f^a))>>>8;c[291680]=h;return}function aby(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;a=d&65535;b=a-f|0;g=b>>>8;c[291677]=g;c[291678]=d-f&65535;c[291679]=((b^d)&(a^f))>>>8;c[291680]=g;return}function abz(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;d=a&65535;f=d-b|0;g=f>>>8;c[291677]=g;c[291678]=a-b&65535;c[291679]=((f^a)&(d^b))>>>8;c[291680]=g;return}function abA(){var a=0,b=0,d=0;a=c[291673]|0;b=c[1166604+((a&7)<<2)>>2]|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=d-b|0;c[291677]=a>>>24;c[291678]=a;c[291679]=((a^d)&(d^b))>>>24;c[291680]=((a|b)&(d^-8388608)|a&b)>>>23;return}function abB(){var a=0,b=0,d=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=d-b|0;c[291677]=a>>>24;c[291678]=a;c[291679]=((a^d)&(d^b))>>>24;c[291680]=((a|b)&(d^-8388608)|a&b)>>>23;return}function abC(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0}a=c[1166604+((h>>>9&7)<<2)>>2]|0;h=a&65535;b=h-g|0;f=b>>>8;c[291677]=f;c[291678]=a-g&65535;c[291679]=((b^h)&(h^g))>>>8;c[291680]=f;return}function abD(){var a=0,b=0,d=0,f=0,g=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;d=b&65535;a=d-f|0;g=a>>>8;c[291677]=g;c[291678]=b-f&65535;c[291679]=((a^d)&(d^f))>>>8;c[291680]=g;return}function abE(){var a=0,b=0,d=0,f=0,g=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;d=b&65535;a=d-f|0;g=a>>>8;c[291677]=g;c[291678]=b-f&65535;c[291679]=((a^d)&(d^f))>>>8;c[291680]=g;return}function abF(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;if((g&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=c[1166604+((i>>>9&7)<<2)>>2]|0;i=a&65535;g=i-h|0;f=g>>>8;c[291677]=f;c[291678]=a-h&65535;c[291679]=((g^i)&(i^h))>>>8;c[291680]=f;return}function abG(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=c[1161472+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[b&255](d&16777215)|0;h=a;i=c[291673]|0}a=c[1166604+((i>>>9&7)<<2)>>2]|0;i=a&65535;d=i-h|0;b=d>>>8;c[291677]=b;c[291678]=a-h&65535;c[291679]=((d^i)&(i^h))>>>8;c[291680]=b;return}function abH(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=d&65535;a=f-g|0;h=a>>>8;c[291677]=h;c[291678]=d-g&65535;c[291679]=((a^f)&(f^g))>>>8;c[291680]=h;return}function abI(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b&255;b=c[1161472+(f*20|0)>>2]|0;if((b|0)==0){g=e[(c[1161464+(f*20|0)>>2]|0)+a>>1]|0}else{g=fl[b&255](d&16777215)|0}d=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;b=d&65535;a=b-g|0;f=a>>>8;c[291677]=f;c[291678]=d-g&65535;c[291679]=((a^b)&(b^g))>>>8;c[291680]=f;return}function abJ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=1161472+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[291673]|0}g=c[1166604+((j>>>9&7)<<2)>>2]|0;j=g-i|0;c[291677]=j>>>24;c[291678]=j;c[291679]=((j^g)&(g^i))>>>24;c[291680]=((j|i)&(g^-8388608)|j&i)>>>23;return}function abK(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]<<16;f=d+2|0;d=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;g=d-(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|a)|0;c[291677]=g>>>24;c[291678]=g;c[291679]=((g^d)&(d^a))>>>24;c[291680]=((g|a)&(d^-8388608)|g&a)>>>23;return}function abL(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;a=d+2|0;d=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;b=d-(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|f)|0;c[291677]=b>>>24;c[291678]=b;c[291679]=((b^d)&(d^f))>>>24;c[291680]=((b|f)&(d^-8388608)|b&f)>>>23;return}function abM(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=a-(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b)|0;c[291677]=f>>>24;c[291678]=f;c[291679]=((f^a)&(a^b))>>>24;c[291680]=((f|b)&(a^-8388608)|f&b)>>>23;return}function abN(){var a=0,b=0,d=0;a=c[291673]|0;b=c[1166604+((a&7)<<2)>>2]<<16>>16;d=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[291677]=a>>>24;c[291678]=a;c[291679]=((a^d)&(b^d))>>>24;c[291680]=((a|b)&(d^-8388608)|a&b)>>>23;return}function abO(){var a=0,b=0,d=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]<<16>>16;d=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[291677]=a>>>24;c[291678]=a;c[291679]=((a^d)&(b^d))>>>24;c[291680]=((a|b)&(d^-8388608)|a&b)>>>23;return}function abP(){var a=0,b=0,d=0;a=ahi()|0;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;d=b-a|0;c[291677]=d>>>24;c[291678]=d;c[291679]=((d^b)&(b^a))>>>24;c[291680]=((d|a)&(b^-8388608)|d&a)>>>23;return}function abQ(){var a=0,b=0,d=0;a=ahh()|0;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;d=b-a|0;c[291677]=d>>>24;c[291678]=d;c[291679]=((d^b)&(b^a))>>>24;c[291680]=((d|a)&(b^-8388608)|d&a)>>>23;return}function abR(){var a=0,b=0,d=0;a=ahg()|0;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;d=b-a|0;c[291677]=d>>>24;c[291678]=d;c[291679]=((d^b)&(b^a))>>>24;c[291680]=((d|a)&(b^-8388608)|d&a)>>>23;return}function abS(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=1161472+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;b=a-h|0;c[291677]=b>>>24;c[291678]=b;c[291679]=((b^a)&(a^h))>>>24;c[291680]=((b|h)&(a^-8388608)|b&h)>>>23;return}function abT(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a}a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;b=a-i|0;c[291677]=b>>>24;c[291678]=b;c[291679]=((b^a)&(a^i))>>>24;c[291680]=((b|i)&(a^-8388608)|b&i)>>>23;return}function abU(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=1161472+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n-i|0;p=o>>>24;c[291677]=p;c[291678]=o;q=n^i;r=o^n;s=r&q;t=s>>>24;c[291679]=t;u=o&i;v=n^-8388608;w=o|i;x=w&v;y=x|u;z=y>>>23;c[291680]=z;return}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[291673]|0;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n-i|0;p=o>>>24;c[291677]=p;c[291678]=o;q=n^i;r=o^n;s=r&q;t=s>>>24;c[291679]=t;u=o&i;v=n^-8388608;w=o|i;x=w&v;y=x|u;z=y>>>23;c[291680]=z;return}}function abV(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0}a=g<<16>>16;g=c[1166604+((h>>>9&7|8)<<2)>>2]|0;h=g-a|0;c[291677]=h>>>24;c[291678]=h;c[291679]=((h^g)&(a^g))>>>24;c[291680]=((h|a)&(g^-8388608)|h&a)>>>23;return}function abW(){var a=0,b=0,d=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=f<<16>>16;f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;d=f-b|0;c[291677]=d>>>24;c[291678]=d;c[291679]=((d^f)&(b^f))>>>24;c[291680]=((d|b)&(f^-8388608)|d&b)>>>23;return}function abX(){var a=0,b=0,d=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=f<<16>>16;f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;d=f-b|0;c[291677]=d>>>24;c[291678]=d;c[291679]=((d^f)&(b^f))>>>24;c[291680]=((d|b)&(f^-8388608)|d&b)>>>23;return}function abY(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;if((g&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=h<<16>>16;h=c[1166604+((i>>>9&7|8)<<2)>>2]|0;i=h-a|0;c[291677]=i>>>24;c[291678]=i;c[291679]=((i^h)&(a^h))>>>24;c[291680]=((i|a)&(h^-8388608)|i&a)>>>23;return}function abZ(){var a=0,d=0,e=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;e=d-a|0;c[291677]=e>>>24;c[291678]=e;c[291679]=((e^d)&(d^a))>>>24;c[291680]=((e|a)&(d^-8388608)|e&a)>>>23;return}function ab_(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;a=f-g|0;c[291677]=a>>>24;c[291678]=a;c[291679]=((a^f)&(f^g))>>>24;c[291680]=((a|g)&(f^-8388608)|a&g)>>>23;return}function ab$(){var a=0,d=0,e=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;e=a-d|0;c[291677]=e>>>24;c[291678]=e;c[291679]=((e^a)&(a^d))>>>24;c[291680]=((e|d)&(a^-8388608)|e&d)>>>23;return}function ab0(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[b>>2]^c[1166604+((a>>>9&7)<<2)>>2]&255;c[b>>2]=d;b=d&255;c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}function ab1(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;a=c[1161468+(b*20|0)>>2]|0;if((a|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0;h=g-f|0;c[291677]=h;i=h&255;c[291678]=i;j=g^f;k=h^g;l=k&j;c[291679]=l;c[291680]=h;return}else{g=fl[a&255](e&16777215)|0;h=g-f|0;c[291677]=h;i=h&255;c[291678]=i;j=g^f;k=h^g;l=k&j;c[291679]=l;c[291680]=h;return}}function ab2(){var a=0,b=0,e=0,f=0,g=0;a=c[291666]|0;c[291666]=a+2;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;e=c[a>>2]|0;c[a>>2]=e+1;a=e>>>16&255;b=c[1161468+(a*20|0)>>2]|0;if((b|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[b&255](e&16777215)|0}e=g-f|0;c[291677]=e;c[291678]=e&255;c[291679]=(e^g)&(g^f);c[291680]=e;return}function ab3(){var b=0,e=0,f=0,g=0,h=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=c[1166604+((b>>>9&7)<<2)>>2]|0;b=e>>>16&255;g=c[1161468+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h^f;f=g&255;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[h&511](e&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function ab4(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h^b;b=g&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}else{fj[h&511](e&16777215,b);c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}}function ab5(){var b=0,e=0,f=0,g=0,h=0;b=c[291666]|0;c[291666]=b+2;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h^e;e=g&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}else{fj[h&511](b&16777215,e);c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}}function ab6(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h^b;b=g&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}else{fj[h&511](e&16777215,b);c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}}function ab7(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h^e;e=g&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}else{fj[h&511](b&16777215,e);c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}}function ab8(){var e=0,f=0,g=0,h=0,i=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=c[1166604+((e>>>9&7)<<2)>>2]|0;e=h>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[g&255](h&16777215)|0}g=i^f;f=g&255;i=c[1161476+(e*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(h&65535^1)|0]=g&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[i&511](h&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function ab9(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=c[1161472+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[b&255](d&16777215)|0;h=a;i=c[291673]|0}a=h<<16>>16;h=c[1166604+((i>>>9&7|8)<<2)>>2]|0;i=h-a|0;c[291677]=i>>>24;c[291678]=i;c[291679]=((i^h)&(a^h))>>>24;c[291680]=((i|a)&(h^-8388608)|i&a)>>>23;return}function aca(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=g<<16>>16;g=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;f=g-d|0;c[291677]=f>>>24;c[291678]=f;c[291679]=((f^g)&(d^g))>>>24;c[291680]=((f|d)&(g^-8388608)|f&d)>>>23;return}function acb(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b&255;b=c[1161472+(f*20|0)>>2]|0;if((b|0)==0){g=e[(c[1161464+(f*20|0)>>2]|0)+a>>1]|0}else{g=fl[b&255](d&16777215)|0}d=g<<16>>16;g=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;b=g-d|0;c[291677]=b>>>24;c[291678]=b;c[291679]=((b^g)&(d^g))>>>24;c[291680]=((b|d)&(g^-8388608)|b&d)>>>23;return}function acc(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[b>>2]^c[1166604+((a>>>9&7)<<2)>>2]&65535;c[b>>2]=d;b=d&65535;c[291677]=b>>>8;c[291678]=b;c[291680]=0;c[291679]=0;return}function acd(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=c[1166604+((b>>>9&7)<<2)>>2]|0;b=g>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j^i;i=f&255;j=c[1161476+(b*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]=f&255;c[291677]=i;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[j&511](g&16777215,i);c[291677]=i;c[291678]=i;c[291680]=0;c[291679]=0;return}}function ace(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[h&255](f&16777215)|0}h=i^e;e=h&255;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}else{fj[i&511](f&16777215,e);c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}}function acf(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;i=f&255;f=c[1161468+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(b^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j^h;h=f&255;j=c[1161476+(i*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(b^1)|0]=f&255;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[j&511](g&16777215,h);c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}}function acg(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+2;if((d&1|0)!=0&(c[291688]|0)!=0){b=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=b;eJ(1166756,1)}b=d>>>16&255;a=c[1161472+(b*20|0)>>2]|0;if((a|0)==0){g=e[(c[1161464+(b*20|0)>>2]|0)+(d&65535)>>1]|0;h=g-f|0;i=h>>>8;c[291677]=i;j=h&65535;c[291678]=j;k=g^f;l=h^g;m=l&k;n=m>>>8;c[291679]=n;c[291680]=i;return}else{g=fl[a&255](d&16777215)|0;h=g-f|0;i=h>>>8;c[291677]=i;j=h&65535;c[291678]=j;k=g^f;l=h^g;m=l&k;n=m>>>8;c[291679]=n;c[291680]=i;return}}function ach(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j^f;f=g&65535;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;l=f>>>8;c[291677]=l;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[k&511](d&16777215,f);l=f>>>8;c[291677]=l;c[291678]=f;c[291680]=0;c[291679]=0;return}}function aci(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j^a;a=g&65535;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}else{fj[k&511](d&16777215,a);l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}}function acj(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j^a;a=g&65535;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}else{fj[k&511](d&16777215,a);l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}}function ack(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]|0;k=f}else{f=fl[i&255](g&16777215)|0;j=f;k=c[291688]|0}f=j^d;d=f&65535;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=f&65535;l=d>>>8;c[291677]=l;c[291678]=d;c[291680]=0;c[291679]=0;return}else{fj[k&511](g&16777215,d);l=d>>>8;c[291677]=l;c[291678]=d;c[291680]=0;c[291679]=0;return}}function acl(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;i=c[1161472+(g*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;k=d}else{d=fl[i&255](f&16777215)|0;j=d;k=c[291688]|0}d=j^h;h=d&65535;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(g*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;l=h>>>8;c[291677]=l;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[k&511](f&16777215,h);l=h>>>8;c[291677]=l;c[291678]=h;c[291680]=0;c[291679]=0;return}}function acm(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[b>>2]^c[1166604+((a>>>9&7)<<2)>>2];c[b>>2]=d;c[291677]=d>>>24;c[291678]=d;c[291680]=0;c[291679]=0;return}function acn(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j^a;a=g&65535;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}else{fj[k&511](d&16777215,a);l=a>>>8;c[291677]=l;c[291678]=a;c[291680]=0;c[291679]=0;return}}function aco(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=d&255;d=c[1161472+(j*20|0)>>2]|0;if((d|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0;l=i}else{i=fl[d&255](f&16777215)|0;k=i;l=c[291688]|0}i=k^g;g=i&65535;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=i&65535;m=g>>>8;c[291677]=m;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[l&511](f&16777215,g);m=g>>>8;c[291677]=m;c[291678]=g;c[291680]=0;c[291679]=0;return}}function acp(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=1161472+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=1161472+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;i=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=i-h|0;k=j>>>24;c[291677]=k;c[291678]=j;l=i^h;m=j^i;n=m&l;o=n>>>24;c[291679]=o;p=j&h;q=i^-8388608;r=j|h;s=r&q;t=s|p;u=t>>>23;c[291680]=u;return}else{a=(fl[f&255](b&16777215)|0)<<16;i=fl[c[d>>2]&255](b+2&16777215)|0|a;j=i-h|0;k=j>>>24;c[291677]=k;c[291678]=j;l=i^h;m=j^i;n=m&l;o=n>>>24;c[291679]=o;p=j&h;q=i^-8388608;r=j|h;s=r&q;t=s|p;u=t>>>23;c[291680]=u;return}}function acq(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l^f;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function acr(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l^a;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function acs(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;g=(f&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](f&16777215)|0)<<16;k=fl[c[j>>2]&255](d+16777214&16777215)|0|h;m=k;n=c[291688]|0}k=m^a;if(g&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}f=d-2|0;d=f>>>16&255;n=c[1161480+(d*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=k&65535;o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}else{fj[n&511](f&16777215,k&65535);o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}}function act(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=g+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]<<16;m=f}else{f=(fl[j&255](g&16777215)|0)<<16;j=fl[c[i>>2]&255](g+2&16777215)|0|f;l=j;m=c[291688]|0}j=l^d;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[m&511](g&16777215,j>>>16)}m=g+2|0;g=m>>>16&255;h=c[1161480+(g*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function acu(){var a=0,b=0,d=0;a=c[291673]|0;b=c[1166604+((a&7)<<2)>>2]|0;d=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[291677]=a>>>24;c[291678]=a;c[291679]=((a^d)&(d^b))>>>24;c[291680]=((a|b)&(d^-8388608)|a&b)>>>23;return}function acv(){var a=0,b=0,d=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[291677]=a>>>24;c[291678]=a;c[291679]=((a^d)&(d^b))>>>24;c[291680]=((a|b)&(d^-8388608)|a&b)>>>23;return}function acw(){var a=0,b=0,d=0;a=ahi()|0;b=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;d=b-a|0;c[291677]=d>>>24;c[291678]=d;c[291679]=((d^b)&(b^a))>>>24;c[291680]=((d|a)&(b^-8388608)|d&a)>>>23;return}function acx(){var a=0,b=0,d=0;a=ahh()|0;b=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;d=b-a|0;c[291677]=d>>>24;c[291678]=d;c[291679]=((d^b)&(b^a))>>>24;c[291680]=((d|a)&(b^-8388608)|d&a)>>>23;return}function acy(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;i=1161472+(g*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;m=d}else{d=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](f+2&16777215)|0|d;l=j;m=c[291688]|0}j=l^h;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(g*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[g&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function acz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l^a;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function acA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=d&255;d=1161472+(j*20|0)|0;k=c[d>>2]|0;if((k|0)==0){l=f+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0)<<16;n=i}else{i=(fl[k&255](f&16777215)|0)<<16;k=fl[c[d>>2]&255](f+2&16777215)|0|i;m=k;n=c[291688]|0}k=m^g;if(h&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(j*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}n=f+2|0;f=n>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(n&65535)>>1]=k&65535;o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}else{fj[a&511](n&16777215,k&65535);o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}}function acB(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=1161472+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[291673]|0}g=c[1166604+((j>>>9&7|8)<<2)>>2]|0;j=g-i|0;c[291677]=j>>>24;c[291678]=j;c[291679]=((j^g)&(g^i))>>>24;c[291680]=((j|i)&(g^-8388608)|j&i)>>>23;return}function acC(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=1161472+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;b=a-h|0;c[291677]=b>>>24;c[291678]=b;c[291679]=((b^a)&(a^h))>>>24;c[291680]=((b|h)&(a^-8388608)|b&h)>>>23;return}function acD(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a}a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;b=a-i|0;c[291677]=b>>>24;c[291678]=b;c[291679]=((b^a)&(a^i))>>>24;c[291680]=((b|i)&(a^-8388608)|b&i)>>>23;return}function acE(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=1161472+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[291673]|0}f=c[1166604+((j>>>9&7|8)<<2)>>2]|0;j=f-i|0;c[291677]=j>>>24;c[291678]=j;c[291679]=((j^f)&(f^i))>>>24;c[291680]=((j|i)&(f^-8388608)|j&i)>>>23;return}function acF(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]<<16;f=d+2|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;g=d-(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|a)|0;c[291677]=g>>>24;c[291678]=g;c[291679]=((g^d)&(d^a))>>>24;c[291680]=((g|a)&(d^-8388608)|g&a)>>>23;return}function acG(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;a=d+2|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;b=d-(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|f)|0;c[291677]=b>>>24;c[291678]=b;c[291679]=((b^d)&(d^f))>>>24;c[291680]=((b|f)&(d^-8388608)|b&f)>>>23;return}function acH(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;f=a-(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b)|0;c[291677]=f>>>24;c[291678]=f;c[291679]=((f^a)&(a^b))>>>24;c[291680]=((f|b)&(a^-8388608)|f&b)>>>23;return}function acI(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[b>>2]&(c[1166604+((a&7)<<2)>>2]|-256);c[b>>2]=d;b=d&255;c[291678]=b;c[291677]=b;c[291680]=0;c[291679]=0;return}function acJ(){var a=0,e=0,f=0;a=c[291667]|0;c[291667]=a+2;e=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;f=c[a>>2]&(d[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|-256);c[a>>2]=f;a=f&255;c[291678]=a;c[291677]=a;c[291680]=0;c[291679]=0;return}function acK(){var a=0,b=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){g=f<<16>>16}else{g=f}f=(b<<24>>24)+a+g|0;g=1166604+(((c[291673]|0)>>>9&7)<<2)|0;a=c[g>>2]&(d[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0|-256);c[g>>2]=a;g=a&255;c[291678]=g;c[291677]=g;c[291680]=0;c[291679]=0;return}function acL(){var a=0,b=0,d=0;a=c[291667]|0;c[291667]=a+2;b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]&(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|-256);c[b>>2]=d;b=d&255;c[291678]=b;c[291677]=b;c[291680]=0;c[291679]=0;return}function acM(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[b>>2]&(c[1166604+((a&7)<<2)>>2]|-65536);c[b>>2]=d;b=d&65535;c[291678]=b;c[291677]=b>>>8;c[291680]=0;c[291679]=0;return}function acN(){var a=0,b=0,d=0;a=ahg()|0;b=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;d=b-a|0;c[291677]=d>>>24;c[291678]=d;c[291679]=((d^b)&(b^a))>>>24;c[291680]=((d|a)&(b^-8388608)|d&a)>>>23;return}function acO(){var a=0,b=0,e=0,f=0,g=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;a=c[1161468+(e*20|0)>>2]|0;if((a|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[a&255](b&16777215)|0}b=g-f|0;c[291677]=b;c[291678]=b&255;c[291679]=(b^g)&(g^f);c[291680]=b;return}function acP(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[291666]|0;b=a+2|0;c[291666]=b;e=a>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(a&65535^1)|0]|0;h=b}else{b=fl[f&255](a&16777215)|0;g=b;h=c[291666]|0}c[291666]=h+2;b=h>>>16&255;a=c[1161468+(b*20|0)>>2]|0;if((a|0)==0){i=d[(c[1161464+(b*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[a&255](h&16777215)|0}h=i-g|0;c[291677]=h;c[291678]=h&255;c[291679]=(h^i)&(i^g);c[291680]=h;return}function acQ(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0}a=1166604+((h>>>9&7)<<2)|0;h=c[a>>2]&(g|-256);c[a>>2]=h;a=h&255;c[291678]=a;c[291677]=a;c[291680]=0;c[291679]=0;return}function acR(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[b>>2]&(f|-256);c[b>>2]=e;b=e&255;c[291678]=b;c[291677]=b;c[291680]=0;c[291679]=0;return}function acS(){var a=0,b=0,e=0,f=0;a=c[291666]|0;c[291666]=a+2;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[a>>2]&(f|-256);c[a>>2]=e;a=e&255;c[291678]=a;c[291677]=a;c[291680]=0;c[291679]=0;return}function acT(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[b>>2]&(f|-256);c[b>>2]=e;b=e&255;c[291678]=b;c[291677]=b;c[291680]=0;c[291679]=0;return}function acU(){var a=0,b=0,e=0,f=0;a=(c[291666]|0)-2|0;c[291666]=a;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[a>>2]&(f|-256);c[a>>2]=e;a=e&255;c[291678]=a;c[291677]=a;c[291680]=0;c[291679]=0;return}function acV(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[291673]|0;e=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=1166604+((i>>>9&7)<<2)|0;i=c[a>>2]&(h|-256);c[a>>2]=i;a=i&255;c[291678]=a;c[291677]=a;c[291680]=0;c[291679]=0;return}function acW(){var a=0,b=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0;j=a}else{a=fl[b&255](f&16777215)|0;i=a;j=c[291673]|0}a=1166604+((j>>>9&7)<<2)|0;j=c[a>>2]&(i|-256);c[a>>2]=j;a=j&255;c[291678]=a;c[291677]=a;c[291680]=0;c[291679]=0;return}function acX(){var a=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[1161468+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7)<<2)|0;f=c[e>>2]&(g|-256);c[e>>2]=f;e=f&255;c[291678]=e;c[291677]=e;c[291680]=0;c[291679]=0;return}function acY(){var a=0,b=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a^1)|0]|0}else{h=fl[g&255](a|b<<16&16711680)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;a=c[b>>2]&(h|-256);c[b>>2]=a;b=a&255;c[291678]=b;c[291677]=b;c[291680]=0;c[291679]=0;return}function acZ(){var a=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;f=c[a>>2]&(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|-65536);c[a>>2]=f;a=f&65535;c[291678]=a;c[291677]=a>>>8;c[291680]=0;c[291679]=0;return}function ac_(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=1166604+(((c[291673]|0)>>>9&7)<<2)|0;a=c[f>>2]&(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|-65536);c[f>>2]=a;f=a&65535;c[291678]=f;c[291677]=f>>>8;c[291680]=0;c[291679]=0;return}function ac$(){var a=0,b=0,d=0;a=c[291667]|0;c[291667]=a+2;b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]&(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|-65536);c[b>>2]=d;b=d&65535;c[291678]=b;c[291677]=b>>>8;c[291680]=0;c[291679]=0;return}function ac0(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[b>>2]&c[1166604+((a&7)<<2)>>2];c[b>>2]=d;c[291678]=d;c[291677]=d>>>24;c[291680]=0;c[291679]=0;return}function ac1(){var a=0,b=0,d=0;a=ahi()|0;b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]&a;c[b>>2]=d;c[291678]=d;c[291677]=d>>>24;c[291680]=0;c[291679]=0;return}function ac2(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0}a=1166604+((h>>>9&7)<<2)|0;h=c[a>>2]&(g|-65536);c[a>>2]=h;a=h&65535;c[291678]=a;c[291677]=a>>>8;c[291680]=0;c[291679]=0;return}function ac3(){var a=0,b=0,d=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]&(f|-65536);c[b>>2]=d;b=d&65535;c[291678]=b;c[291677]=b>>>8;c[291680]=0;c[291679]=0;return}function ac4(){var a=0,b=0,d=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]&(f|-65536);c[b>>2]=d;b=d&65535;c[291678]=b;c[291677]=b>>>8;c[291680]=0;c[291679]=0;return}function ac5(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;if((g&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=1166604+((i>>>9&7)<<2)|0;i=c[a>>2]&(h|-65536);c[a>>2]=i;a=i&65535;c[291678]=a;c[291677]=a>>>8;c[291680]=0;c[291679]=0;return}function ac6(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=c[1161472+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a;j=h|-65536;k=i>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n&j;c[m>>2]=o;p=o&65535;c[291678]=p;q=p>>>8;c[291677]=q;c[291680]=0;c[291679]=0;return}else{a=fl[b&255](d&16777215)|0;h=a;i=c[291673]|0;j=h|-65536;k=i>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n&j;c[m>>2]=o;p=o&65535;c[291678]=p;q=p>>>8;c[291677]=q;c[291680]=0;c[291679]=0;return}}function ac7(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;f=c[d>>2]&(g|-65536);c[d>>2]=f;d=f&65535;c[291678]=d;c[291677]=d>>>8;c[291680]=0;c[291679]=0;return}function ac8(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b&255;b=c[1161472+(f*20|0)>>2]|0;if((b|0)==0){g=e[(c[1161464+(f*20|0)>>2]|0)+a>>1]|0}else{g=fl[b&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[d>>2]&(g|-65536);c[d>>2]=b;d=b&65535;c[291678]=d;c[291677]=d>>>8;c[291680]=0;c[291679]=0;return}function ac9(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=1161472+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n&i;c[m>>2]=o;c[291678]=o;p=o>>>24;c[291677]=p;c[291680]=0;c[291679]=0;return}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[291673]|0;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n&i;c[m>>2]=o;c[291678]=o;p=o>>>24;c[291677]=p;c[291680]=0;c[291679]=0;return}}function ada(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=1161472+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[a>>2]&h;c[a>>2]=b;c[291678]=b;c[291677]=b>>>24;c[291680]=0;c[291679]=0;return}function adb(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[a>>2]&i;c[a>>2]=b;c[291678]=b;c[291677]=b>>>24;c[291680]=0;c[291679]=0;return}function adc(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=d+2|0;f=1166604+(((c[291673]|0)>>>9&7)<<2)|0;g=c[f>>2]&(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]<<16);c[f>>2]=g;c[291678]=g;c[291677]=g>>>24;c[291680]=0;c[291679]=0;return}function add(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=d+2|0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[a>>2]&(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16);c[a>>2]=b;c[291678]=b;c[291677]=b>>>24;c[291680]=0;c[291679]=0;return}function ade(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=a+2|0;d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;f=c[d>>2]&(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16);c[d>>2]=f;c[291678]=f;c[291677]=f>>>24;c[291680]=0;c[291679]=0;return}function adf(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=ab(c[b>>2]&65535,d&65535)|0;e=d&65535;if(e<<16>>16==0){f=266}else{d=e;e=266;while(1){g=(d&1)==0?e:e+14|0;h=(d&65535)>>>1;if(h<<16>>16==0){f=g;break}else{d=h;e=g}}}c[291649]=(c[291649]|0)+f;c[b>>2]=a;c[291678]=a;c[291677]=a>>>24;c[291679]=0;c[291680]=0;return}function adg(){var a=0,b=0,d=0;a=ahh()|0;b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]&a;c[b>>2]=d;c[291678]=d;c[291677]=d>>>24;c[291680]=0;c[291679]=0;return}function adh(){var a=0,b=0,d=0;a=ahg()|0;b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]&a;c[b>>2]=d;c[291678]=d;c[291677]=d>>>24;c[291680]=0;c[291679]=0;return}function adi(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=1161472+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n&i;c[m>>2]=o;c[291678]=o;p=o>>>24;c[291677]=p;c[291680]=0;c[291679]=0;return}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[291673]|0;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;n=c[m>>2]|0;o=n&i;c[m>>2]=o;c[291678]=o;p=o>>>24;c[291677]=p;c[291680]=0;c[291679]=0;return}}function adj(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=ab(c[b>>2]&65535,g)|0;f=g&65535;if(f<<16>>16==0){h=266}else{g=f;f=266;while(1){a=(g&1)==0?f:f+14|0;i=(g&65535)>>>1;if(i<<16>>16==0){h=a;break}else{g=i;f=a}}}c[291649]=(c[291649]|0)+h;c[b>>2]=d;c[291678]=d;c[291677]=d>>>24;c[291679]=0;c[291680]=0;return}function adk(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=ab(c[b>>2]&65535,g)|0;f=g&65535;if(f<<16>>16==0){h=266;i=c[291649]|0;j=i+h|0;c[291649]=j;c[b>>2]=a;c[291678]=a;k=a>>>24;c[291677]=k;c[291679]=0;c[291680]=0;return}else{l=f;m=266}while(1){f=(l&1)==0?m:m+14|0;g=(l&65535)>>>1;if(g<<16>>16==0){h=f;break}else{l=g;m=f}}i=c[291649]|0;j=i+h|0;c[291649]=j;c[b>>2]=a;c[291678]=a;k=a>>>24;c[291677]=k;c[291679]=0;c[291680]=0;return}function adl(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=ab(c[b>>2]&65535,g)|0;f=g&65535;if(f<<16>>16==0){h=266;i=c[291649]|0;j=i+h|0;c[291649]=j;c[b>>2]=a;c[291678]=a;k=a>>>24;c[291677]=k;c[291679]=0;c[291680]=0;return}else{l=f;m=266}while(1){f=(l&1)==0?m:m+14|0;g=(l&65535)>>>1;if(g<<16>>16==0){h=f;break}else{l=g;m=f}}i=c[291649]|0;j=i+h|0;c[291649]=j;c[b>>2]=a;c[291678]=a;k=a>>>24;c[291677]=k;c[291679]=0;c[291680]=0;return}function adm(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=1166604+((a>>>9&7)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;if((g&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}g=ab(c[d>>2]&65535,h)|0;a=h&65535;if(a<<16>>16==0){i=266;j=c[291649]|0;k=j+i|0;c[291649]=k;c[d>>2]=g;c[291678]=g;l=g>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}else{m=a;n=266}while(1){a=(m&1)==0?n:n+14|0;h=(m&65535)>>>1;if(h<<16>>16==0){i=a;break}else{m=h;n=a}}j=c[291649]|0;k=j+i|0;c[291649]=k;c[d>>2]=g;c[291678]=g;l=g>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}function adn(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=ab(c[b>>2]&65535,h)|0;d=h&65535;if(d<<16>>16==0){i=266;j=c[291649]|0;k=j+i|0;c[291649]=k;c[b>>2]=a;c[291678]=a;l=a>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}else{m=d;n=266}while(1){d=(m&1)==0?n:n+14|0;h=(m&65535)>>>1;if(h<<16>>16==0){i=d;break}else{m=h;n=d}}j=c[291649]|0;k=j+i|0;c[291649]=k;c[b>>2]=a;c[291678]=a;l=a>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}function ado(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}f=ab(c[a>>2]&65535,h)|0;g=h&65535;if(g<<16>>16==0){i=266;j=c[291649]|0;k=j+i|0;c[291649]=k;c[a>>2]=f;c[291678]=f;l=f>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}else{m=g;n=266}while(1){g=(m&1)==0?n:n+14|0;h=(m&65535)>>>1;if(h<<16>>16==0){i=g;break}else{m=h;n=g}}j=c[291649]|0;k=j+i|0;c[291649]=k;c[a>>2]=f;c[291678]=f;l=f>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}function adp(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;if((b&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+b>>1]|0}else{h=fl[d&255](f&16777215)|0}f=ab(c[a>>2]&65535,h)|0;d=h&65535;if(d<<16>>16==0){i=266;j=c[291649]|0;k=j+i|0;c[291649]=k;c[a>>2]=f;c[291678]=f;l=f>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}else{m=d;n=266}while(1){d=(m&1)==0?n:n+14|0;h=(m&65535)>>>1;if(h<<16>>16==0){i=d;break}else{m=h;n=d}}j=c[291649]|0;k=j+i|0;c[291649]=k;c[a>>2]=f;c[291678]=f;l=f>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}function adq(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=ab(c[a>>2]&65535,d&65535)|0;if(d<<16>>16==0){f=266}else{g=d;d=266;while(1){h=(g&1)==0?d:d+14|0;i=(g&65535)>>>1;if(i<<16>>16==0){f=h;break}else{g=i;d=h}}}c[291649]=(c[291649]|0)+f;c[a>>2]=e;c[291678]=e;c[291677]=e>>>24;c[291679]=0;c[291680]=0;return}function adr(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=ab(c[a>>2]&65535,h&65535)|0;if(h<<16>>16==0){i=266}else{d=h;h=266;while(1){f=(d&1)==0?h:h+14|0;j=(d&65535)>>>1;if(j<<16>>16==0){i=f;break}else{d=j;h=f}}}c[291649]=(c[291649]|0)+i;c[a>>2]=g;c[291678]=g;c[291677]=g>>>24;c[291679]=0;c[291680]=0;return}function ads(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=ab(c[a>>2]&65535,e&65535)|0;if(e<<16>>16==0){f=266}else{g=e;e=266;while(1){h=(g&1)==0?e:e+14|0;i=(g&65535)>>>1;if(i<<16>>16==0){f=h;break}else{g=i;e=h}}}c[291649]=(c[291649]|0)+f;c[a>>2]=d;c[291678]=d;c[291677]=d>>>24;c[291679]=0;c[291680]=0;return}function adt(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=(a&15)+(d&15)+((c[291676]|0)>>>8&1)|0;f=(a&240)+(d&240)+(e>>>0>9?e+6|0:e)|0;d=f>>>0>153;a=(d&1)<<8;c[291680]=a;c[291676]=a;a=d?f-160|0:f;c[291679]=a&~e;c[291677]=a;e=a&255;c[291678]=e|c[291678];c[b>>2]=e|c[b>>2]&-256;return}function adu(){var b=0,e=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;b=c[1161468+(e*20|0)>>2]|0;if((b|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[b&255](f&16777215)|0}b=(h&15)+(g&15)+((c[291676]|0)>>>8&1)|0;i=(h&240)+(g&240)+(b>>>0>9?b+6|0:b)|0;g=i>>>0>153;h=(g&1)<<8;c[291680]=h;c[291676]=h;h=g?i-160|0:i;c[291679]=h&~b;c[291677]=h;b=h&255;c[291678]=b|c[291678];i=c[1161476+(e*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[i&511](f&16777215,b);return}}function adv(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[e&255](f&16777215)|0}e=(h&15)+(g&15)+((c[291676]|0)>>>8&1)|0;i=(h&240)+(g&240)+(e>>>0>9?e+6|0:e)|0;g=i>>>0>153;h=(g&1)<<8;c[291680]=h;c[291676]=h;h=g?i-160|0:i;c[291679]=h&~e;c[291677]=h;e=h&255;c[291678]=e|c[291678];i=c[1161476+(b*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[i&511](f&16777215,e);return}}function adw(){var b=0,e=0,f=0,g=0,h=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=c[1166604+((b>>>9&7)<<2)>>2]|0;b=e>>>16&255;g=c[1161468+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h&f;c[291677]=g;c[291680]=0;c[291679]=0;f=g&255;c[291678]=f;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[h&511](e&16777215,f);return}}function adx(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h&b;c[291677]=g;c[291680]=0;c[291679]=0;b=g&255;c[291678]=b;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[h&511](e&16777215,b);return}}function ady(){var b=0,e=0,f=0,g=0,h=0;b=c[291666]|0;c[291666]=b+2;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h&e;c[291677]=g;c[291680]=0;c[291679]=0;e=g&255;c[291678]=e;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[h&511](b&16777215,e);return}}function adz(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h&b;c[291677]=g;c[291680]=0;c[291679]=0;b=g&255;c[291678]=b;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[h&511](e&16777215,b);return}}function adA(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h&e;c[291677]=g;c[291680]=0;c[291679]=0;e=g&255;c[291678]=e;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[h&511](b&16777215,e);return}}function adB(){var e=0,f=0,g=0,h=0,i=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=c[1166604+((e>>>9&7)<<2)>>2]|0;e=h>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[g&255](h&16777215)|0}g=i&f;c[291677]=g;c[291680]=0;c[291679]=0;f=g&255;c[291678]=f;i=c[1161476+(e*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(h&65535^1)|0]=g&255;return}else{fj[i&511](h&16777215,f);return}}function adC(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=c[1166604+((b>>>9&7)<<2)>>2]|0;b=g>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j&i;c[291677]=f;c[291680]=0;c[291679]=0;i=f&255;c[291678]=i;j=c[1161476+(b*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]=f&255;return}else{fj[j&511](g&16777215,i);return}}function adD(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7)<<2)|0;a=c[b>>2]|0;c[b>>2]=c[d>>2];c[d>>2]=a;return}function adE(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[b>>2]|0;c[b>>2]=c[d>>2];c[d>>2]=a;return}function adF(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[b>>2]|0;c[b>>2]=c[d>>2];c[d>>2]=a;return}function adG(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[h&255](f&16777215)|0}h=i&e;c[291677]=h;c[291680]=0;c[291679]=0;e=h&255;c[291678]=e;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[i&511](f&16777215,e);return}}function adH(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;i=f&255;f=c[1161468+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(b^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j&h;c[291677]=f;c[291680]=0;c[291679]=0;h=f&255;c[291678]=h;j=c[1161476+(i*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[j&511](g&16777215,h);return}}function adI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j&f;c[291677]=g>>>8;c[291680]=0;c[291679]=0;f=g&65535;c[291678]=f;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,f);return}}function adJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j&a;c[291677]=g>>>8;c[291680]=0;c[291679]=0;a=g&65535;c[291678]=a;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,a);return}}function adK(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j&a;c[291677]=g>>>8;c[291680]=0;c[291679]=0;a=g&65535;c[291678]=a;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,a);return}}function adL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]|0;k=f}else{f=fl[i&255](g&16777215)|0;j=f;k=c[291688]|0}f=j&d;c[291677]=f>>>8;c[291680]=0;c[291679]=0;d=f&65535;c[291678]=d;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=f&65535;return}else{fj[k&511](g&16777215,d);return}}function adM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;i=c[1161472+(g*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;k=d}else{d=fl[i&255](f&16777215)|0;j=d;k=c[291688]|0}d=j&h;c[291677]=d>>>8;c[291680]=0;c[291679]=0;h=d&65535;c[291678]=h;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(g*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[k&511](f&16777215,h);return}}function adN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j&a;c[291677]=g>>>8;c[291680]=0;c[291679]=0;a=g&65535;c[291678]=a;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,a);return}}function adO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=d&255;d=c[1161472+(j*20|0)>>2]|0;if((d|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0;l=i}else{i=fl[d&255](f&16777215)|0;k=i;l=c[291688]|0}i=k&g;c[291677]=i>>>8;c[291680]=0;c[291679]=0;g=i&65535;c[291678]=g;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=i&65535;return}else{fj[l&511](f&16777215,g);return}}function adP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l&f;c[291677]=j>>>24;c[291678]=j;c[291680]=0;c[291679]=0;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function adQ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l&a;c[291677]=j>>>24;c[291678]=j;c[291680]=0;c[291679]=0;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function adR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;g=(f&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](f&16777215)|0)<<16;k=fl[c[j>>2]&255](d+16777214&16777215)|0|h;m=k;n=c[291688]|0}k=m&a;c[291677]=k>>>24;c[291678]=k;c[291680]=0;c[291679]=0;if(g&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}f=d-2|0;d=f>>>16&255;n=c[1161480+(d*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=k&65535;return}else{fj[n&511](f&16777215,k&65535);return}}function adS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=g+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]<<16;m=f}else{f=(fl[j&255](g&16777215)|0)<<16;j=fl[c[i>>2]&255](g+2&16777215)|0|f;l=j;m=c[291688]|0}j=l&d;c[291677]=j>>>24;c[291678]=j;c[291680]=0;c[291679]=0;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[m&511](g&16777215,j>>>16)}m=g+2|0;g=m>>>16&255;h=c[1161480+(g*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function adT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;i=1161472+(g*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;m=d}else{d=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](f+2&16777215)|0|d;l=j;m=c[291688]|0}j=l&h;c[291677]=j>>>24;c[291678]=j;c[291680]=0;c[291679]=0;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(g*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[g&511](m&16777215,j&65535);return}}function adU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l&a;c[291677]=j>>>24;c[291678]=j;c[291680]=0;c[291679]=0;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function adV(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=ab(c[b>>2]<<16>>16,d<<16>>16)|0;e=d&65535;f=d<<1&65534;if((f|0)==(e|0)){g=266}else{d=266;h=f^e;while(1){e=(h&1|0)==0?d:d+14|0;f=h>>1;if((f|0)==0){g=e;break}else{d=e;h=f}}}c[291649]=(c[291649]|0)+g;c[b>>2]=a;c[291678]=a;c[291677]=a>>>24;c[291679]=0;c[291680]=0;return}function adW(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=ab(c[a>>2]<<16>>16,d)|0;f=(d<<1^d)&65535;if((f|0)==0){g=266}else{d=266;h=f;while(1){f=(h&1|0)==0?d:d+14|0;i=h>>1;if((i|0)==0){g=f;break}else{d=f;h=i}}}c[291649]=(c[291649]|0)+g;c[a>>2]=e;c[291678]=e;c[291677]=e>>>24;c[291679]=0;c[291680]=0;return}function adX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=d&255;d=1161472+(j*20|0)|0;k=c[d>>2]|0;if((k|0)==0){l=f+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0)<<16;n=i}else{i=(fl[k&255](f&16777215)|0)<<16;k=fl[c[d>>2]&255](f+2&16777215)|0|i;m=k;n=c[291688]|0}k=m&g;c[291677]=k>>>24;c[291678]=k;c[291680]=0;c[291679]=0;if(h&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(j*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}n=f+2|0;f=n>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[a&511](n&16777215,k&65535);return}}function adY(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=ab(c[b>>2]<<16>>16,g<<16>>16)|0;f=g&65535;a=g<<1&65534;if((a|0)==(f|0)){h=266;i=c[291649]|0;j=i+h|0;c[291649]=j;c[b>>2]=d;c[291678]=d;k=d>>>24;c[291677]=k;c[291679]=0;c[291680]=0;return}g=266;l=a^f;while(1){f=(l&1|0)==0?g:g+14|0;a=l>>1;if((a|0)==0){h=f;break}else{g=f;l=a}}i=c[291649]|0;j=i+h|0;c[291649]=j;c[b>>2]=d;c[291678]=d;k=d>>>24;c[291677]=k;c[291679]=0;c[291680]=0;return}function adZ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=ab(c[b>>2]<<16>>16,g<<16>>16)|0;f=g&65535;d=g<<1&65534;if((d|0)==(f|0)){h=266;i=c[291649]|0;j=i+h|0;c[291649]=j;c[b>>2]=a;c[291678]=a;k=a>>>24;c[291677]=k;c[291679]=0;c[291680]=0;return}g=266;l=d^f;while(1){f=(l&1|0)==0?g:g+14|0;d=l>>1;if((d|0)==0){h=f;break}else{g=f;l=d}}i=c[291649]|0;j=i+h|0;c[291649]=j;c[b>>2]=a;c[291678]=a;k=a>>>24;c[291677]=k;c[291679]=0;c[291680]=0;return}function ad_(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=ab(c[b>>2]<<16>>16,g<<16>>16)|0;f=g&65535;d=g<<1&65534;if((d|0)==(f|0)){h=266;i=c[291649]|0;j=i+h|0;c[291649]=j;c[b>>2]=a;c[291678]=a;k=a>>>24;c[291677]=k;c[291679]=0;c[291680]=0;return}g=266;l=d^f;while(1){f=(l&1|0)==0?g:g+14|0;d=l>>1;if((d|0)==0){h=f;break}else{g=f;l=d}}i=c[291649]|0;j=i+h|0;c[291649]=j;c[b>>2]=a;c[291678]=a;k=a>>>24;c[291677]=k;c[291679]=0;c[291680]=0;return}function ad$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=1166604+((a>>>9&7)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;if((g&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}g=ab(c[d>>2]<<16>>16,h<<16>>16)|0;a=h&65535;f=h<<1&65534;if((f|0)==(a|0)){i=266;j=c[291649]|0;k=j+i|0;c[291649]=k;c[d>>2]=g;c[291678]=g;l=g>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}h=266;m=f^a;while(1){a=(m&1|0)==0?h:h+14|0;f=m>>1;if((f|0)==0){i=a;break}else{h=a;m=f}}j=c[291649]|0;k=j+i|0;c[291649]=k;c[d>>2]=g;c[291678]=g;l=g>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}function ad0(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=ab(c[b>>2]<<16>>16,h<<16>>16)|0;d=h&65535;g=h<<1&65534;if((g|0)==(d|0)){i=266;j=c[291649]|0;k=j+i|0;c[291649]=k;c[b>>2]=a;c[291678]=a;l=a>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}h=266;f=g^d;while(1){d=(f&1|0)==0?h:h+14|0;g=f>>1;if((g|0)==0){i=d;break}else{h=d;f=g}}j=c[291649]|0;k=j+i|0;c[291649]=k;c[b>>2]=a;c[291678]=a;l=a>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}function ad1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}f=ab(c[a>>2]<<16>>16,h<<16>>16)|0;g=h&65535;d=h<<1&65534;if((d|0)==(g|0)){i=266;j=c[291649]|0;k=j+i|0;c[291649]=k;c[a>>2]=f;c[291678]=f;l=f>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}h=266;m=d^g;while(1){g=(m&1|0)==0?h:h+14|0;d=m>>1;if((d|0)==0){i=g;break}else{h=g;m=d}}j=c[291649]|0;k=j+i|0;c[291649]=k;c[a>>2]=f;c[291678]=f;l=f>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}function ad2(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;if((b&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+b>>1]|0}else{h=fl[d&255](f&16777215)|0}f=ab(c[a>>2]<<16>>16,h<<16>>16)|0;d=h&65535;b=h<<1&65534;if((b|0)==(d|0)){i=266;j=c[291649]|0;k=j+i|0;c[291649]=k;c[a>>2]=f;c[291678]=f;l=f>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}h=266;g=b^d;while(1){d=(g&1|0)==0?h:h+14|0;b=g>>1;if((b|0)==0){i=d;break}else{h=d;g=b}}j=c[291649]|0;k=j+i|0;c[291649]=k;c[a>>2]=f;c[291678]=f;l=f>>>24;c[291677]=l;c[291679]=0;c[291680]=0;return}function ad3(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=ab(c[a>>2]<<16>>16,h)|0;d=(h<<1^h)&65535;if((d|0)==0){i=266}else{h=266;f=d;while(1){d=(f&1|0)==0?h:h+14|0;j=f>>1;if((j|0)==0){i=d;break}else{h=d;f=j}}}c[291649]=(c[291649]|0)+i;c[a>>2]=g;c[291678]=g;c[291677]=g>>>24;c[291679]=0;c[291680]=0;return}function ad4(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=ab(c[a>>2]<<16>>16,e)|0;f=(e<<1^e)&65535;if((f|0)==0){g=266}else{e=266;h=f;while(1){f=(h&1|0)==0?e:e+14|0;i=h>>1;if((i|0)==0){g=f;break}else{e=f;h=i}}}c[291649]=(c[291649]|0)+g;c[a>>2]=d;c[291678]=d;c[291677]=d>>>24;c[291679]=0;c[291680]=0;return}function ad5(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=d&255;e=c[b>>2]|0;f=e&255;g=f+a|0;c[291677]=g;c[291679]=(g^a)&(g^f);c[291680]=g;c[291676]=g;g=e+d&255;c[291678]=g;c[b>>2]=c[b>>2]&-256|g;return}function ad6(){var a=0,e=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+e|0;e=d[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=c[a>>2]|0;g=f&255;h=g+e|0;c[291677]=h;c[291679]=(h^e)&(h^g);c[291680]=h;c[291676]=h;h=f+e&255;c[291678]=h;c[a>>2]=c[a>>2]&-256|h;return}function ad7(){var b=0,e=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[291666]|0)-2|0;c[291666]=e;f=e>>>16&255;b=c[1161468+(f*20|0)>>2]|0;if((b|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[b&255](e&16777215)|0}b=(h&15)+(g&15)+((c[291676]|0)>>>8&1)|0;i=(h&240)+(g&240)+(b>>>0>9?b+6|0:b)|0;g=i>>>0>153;h=(g&1)<<8;c[291680]=h;c[291676]=h;h=g?i-160|0:i;c[291679]=h&~b;c[291677]=h;b=h&255;c[291678]=b|c[291678];i=c[1161476+(f*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,b);return}}function ad8(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[291666]|0}e=h-2|0;c[291666]=e;h=e>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[b&255](e&16777215)|0}b=(i&15)+(g&15)+((c[291676]|0)>>>8&1)|0;f=(i&240)+(g&240)+(b>>>0>9?b+6|0:b)|0;g=f>>>0>153;i=(g&1)<<8;c[291680]=i;c[291676]=i;i=g?f-160|0:f;c[291679]=i&~b;c[291677]=i;b=i&255;c[291678]=b|c[291678];f=c[1161476+(h*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=i&255;return}else{fj[f&511](e&16777215,b);return}}function ad9(){var a=0,b=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;e=c[1166604+((a&7|8)<<2)>>2]|0;a=e>>>16&255;f=c[1161468+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[b>>2]|0;f=e&255;a=f+g|0;c[291677]=a;c[291679]=(a^g)&(a^f);c[291680]=a;c[291676]=a;a=e+g&255;c[291678]=a;c[b>>2]=c[b>>2]&-256|a;return}function aea(){var a=0,b=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;e=1166604+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+1;e=a>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(a&65535^1)|0]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;e=f+g|0;c[291677]=e;c[291679]=(e^g)&(e^f);c[291680]=e;c[291676]=e;e=a+g&255;c[291678]=e;c[b>>2]=c[b>>2]&-256|e;return}function aeb(){var a=0,b=0,e=0,f=0,g=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[a>>2]|0;f=b&255;e=f+g|0;c[291677]=e;c[291679]=(e^g)&(e^f);c[291680]=e;c[291676]=e;e=b+g&255;c[291678]=e;c[a>>2]=c[a>>2]&-256|e;return}function aec(){var a=0,b=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;e=1166604+((a&7|8)<<2)|0;a=(c[e>>2]|0)-1|0;c[e>>2]=a;e=a>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(a&65535^1)|0]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;e=f+g|0;c[291677]=e;c[291679]=(e^g)&(e^f);c[291680]=e;c[291676]=e;e=a+g&255;c[291678]=e;c[b>>2]=c[b>>2]&-256|e;return}function aed(){var a=0,b=0,e=0,f=0,g=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[a>>2]|0;f=b&255;e=f+g|0;c[291677]=e;c[291679]=(e^g)&(e^f);c[291680]=e;c[291676]=e;e=b+g&255;c[291678]=e;c[a>>2]=c[a>>2]&-256|e;return}function aee(){var a=0,e=0,f=0,g=0,h=0;a=c[291673]|0;e=1166604+((a>>>9&7)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[1161468+(f*20|0)>>2]|0;if((a|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[a&255](g&16777215)|0}g=c[e>>2]|0;a=g&255;f=a+h|0;c[291677]=f;c[291679]=(f^h)&(f^a);c[291680]=f;c[291676]=f;f=g+h&255;c[291678]=f;c[e>>2]=c[e>>2]&-256|f;return}function aef(){var a=0,b=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=a>>>16&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(a&65535^1)|0]|0}else{i=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;h=f+i|0;c[291677]=h;c[291679]=(h^i)&(h^f);c[291680]=h;c[291676]=h;h=a+i&255;c[291678]=h;c[b>>2]=c[b>>2]&-256|h;return}function aeg(){var a=0,e=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[a>>2]|0;g=f&255;e=g+h|0;c[291677]=e;c[291679]=(e^h)&(e^g);c[291680]=e;c[291676]=e;e=f+h&255;c[291678]=e;c[a>>2]=c[a>>2]&-256|e;return}function aeh(){var a=0,b=0,f=0,g=0,h=0,i=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=c[a>>2]|0;b=f&255;h=b+i|0;c[291677]=h;c[291679]=(h^i)&(h^b);c[291680]=h;c[291676]=h;h=f+i&255;c[291678]=h;c[a>>2]=c[a>>2]&-256|h;return}function aei(){var a=0,b=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+b+h|0;h=d[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=c[a>>2]|0;b=g&255;f=b+h|0;c[291677]=f;c[291679]=(f^h)&(f^b);c[291680]=f;c[291676]=f;f=g+h&255;c[291678]=f;c[a>>2]=c[a>>2]&-256|f;return}function aej(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=d&255;f=c[a>>2]|0;g=f&255;h=b+g|0;c[291677]=h;c[291679]=(h^b)&(h^g);c[291680]=h;c[291676]=h;h=d+f&255;c[291678]=h;c[a>>2]=c[a>>2]&-256|h;return}function aek(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f+a|0;h=g>>>8;c[291677]=h;c[291679]=((g^a)&(g^f))>>>8;c[291680]=h;c[291676]=h;h=e+d&65535;c[291678]=h;c[b>>2]=c[b>>2]&-65536|h;return}function ael(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f+a|0;h=g>>>8;c[291677]=h;c[291679]=((g^a)&(g^f))>>>8;c[291680]=h;c[291676]=h;h=e+d&65535;c[291678]=h;c[b>>2]=c[b>>2]&-65536|h;return}function aem(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[a>>2]|0;g=f&65535;h=g+d|0;i=h>>>8;c[291677]=i;c[291679]=((h^d)&(h^g))>>>8;c[291680]=i;c[291676]=i;i=f+d&65535;c[291678]=i;c[a>>2]=c[a>>2]&-65536|i;return}function aen(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[a>>2]|0;b=f&65535;d=b+g|0;h=d>>>8;c[291677]=h;c[291679]=((d^g)&(d^b))>>>8;c[291680]=h;c[291676]=h;h=f+g&65535;c[291678]=h;c[a>>2]=c[a>>2]&-65536|h;return}function aeo(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[a>>2]|0;f=b&65535;g=f+d|0;h=g>>>8;c[291677]=h;c[291679]=((g^d)&(g^f))>>>8;c[291680]=h;c[291676]=h;h=b+d&65535;c[291678]=h;c[a>>2]=c[a>>2]&-65536|h;return}function aep(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a+d|0;c[291677]=e>>>24;c[291679]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(a|d)|a&d)>>>23;c[291680]=f;c[291676]=f;c[291678]=e;c[b>>2]=e;return}function aeq(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[b>>2]|0;e=a+d|0;c[291677]=e>>>24;c[291679]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(a|d)|a&d)>>>23;c[291680]=f;c[291676]=f;c[291678]=e;c[b>>2]=e;return}function aer(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[b>>2]|0;f=d&65535;a=f+g|0;h=a>>>8;c[291677]=h;c[291679]=((a^g)&(a^f))>>>8;c[291680]=h;c[291676]=h;h=d+g&65535;c[291678]=h;c[b>>2]=c[b>>2]&-65536|h;return}function aes(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&65535;d=f+g|0;h=d>>>8;c[291677]=h;c[291679]=((d^g)&(d^f))>>>8;c[291680]=h;c[291676]=h;h=a+g&65535;c[291678]=h;c[b>>2]=c[b>>2]&-65536|h;return}function aet(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&65535;d=f+g|0;h=d>>>8;c[291677]=h;c[291679]=((d^g)&(d^f))>>>8;c[291680]=h;c[291676]=h;h=a+g&65535;c[291678]=h;c[b>>2]=c[b>>2]&-65536|h;return}function aeu(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=1166604+((a>>>9&7)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;if((g&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}g=c[d>>2]|0;a=g&65535;f=a+h|0;i=f>>>8;c[291677]=i;c[291679]=((f^h)&(f^a))>>>8;c[291680]=i;c[291676]=i;i=g+h&65535;c[291678]=i;c[d>>2]=c[d>>2]&-65536|i;return}function aev(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=c[b>>2]|0;d=a&65535;g=d+h|0;f=g>>>8;c[291677]=f;c[291679]=((g^h)&(g^d))>>>8;c[291680]=f;c[291676]=f;f=a+h&65535;c[291678]=f;c[b>>2]=c[b>>2]&-65536|f;return}function aew(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}f=c[a>>2]|0;g=f&65535;d=g+h|0;i=d>>>8;c[291677]=i;c[291679]=((d^h)&(d^g))>>>8;c[291680]=i;c[291676]=i;i=f+h&65535;c[291678]=i;c[a>>2]=c[a>>2]&-65536|i;return}function aex(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;if((b&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+b>>1]|0}else{h=fl[d&255](f&16777215)|0}f=c[a>>2]|0;d=f&65535;b=d+h|0;g=b>>>8;c[291677]=g;c[291679]=((b^h)&(b^d))>>>8;c[291680]=g;c[291676]=g;g=f+h&65535;c[291678]=g;c[a>>2]=c[a>>2]&-65536|g;return}function aey(){var a=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]<<16;g=f+2|0;f=c[a>>2]|0;h=(e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|d)+f|0;c[291677]=h>>>24;c[291679]=((h^d)&(h^f))>>>24;g=((h^-8388608)&(f|d)|f&d)>>>23;c[291680]=g;c[291676]=g;c[291678]=h;c[a>>2]=h;return}function aez(){var a=0,b=0,d=0,f=0,g=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;b=f+2|0;f=c[a>>2]|0;d=(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|g)+f|0;c[291677]=d>>>24;c[291679]=((d^g)&(d^f))>>>24;b=((d^-8388608)&(f|g)|f&g)>>>23;c[291680]=b;c[291676]=b;c[291678]=d;c[a>>2]=d;return}function aeA(){var a=0,b=0,d=0,f=0,g=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;f=b+2|0;b=c[a>>2]|0;g=(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d)+b|0;c[291677]=g>>>24;c[291679]=((g^d)&(g^b))>>>24;f=((g^-8388608)&(b|d)|b&d)>>>23;c[291680]=f;c[291676]=f;c[291678]=g;c[a>>2]=g;return}function aeB(){var a=0,b=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[1166604+((a&7)<<2)>>2]<<16>>16)+(c[b>>2]|0);return}function aeC(){var a=0,b=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[1166604+((a&7|8)<<2)>>2]<<16>>16)+(c[b>>2]|0);return}function aeD(){var a=0,b=0,d=0,e=0,f=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=ahi()|0;d=c[a>>2]|0;e=d+b|0;c[291677]=e>>>24;c[291679]=((e^b)&(e^d))>>>24;f=((e^-8388608)&(d|b)|d&b)>>>23;c[291680]=f;c[291676]=f;c[291678]=e;c[a>>2]=e;return}function aeE(){var a=0,b=0,d=0,e=0,f=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=ahh()|0;d=c[a>>2]|0;e=d+b|0;c[291677]=e>>>24;c[291679]=((e^b)&(e^d))>>>24;f=((e^-8388608)&(d|b)|d&b)>>>23;c[291680]=f;c[291676]=f;c[291678]=e;c[a>>2]=e;return}function aeF(){var a=0,b=0,d=0,e=0,f=0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;b=ahg()|0;d=c[a>>2]|0;e=d+b|0;c[291677]=e>>>24;c[291679]=((e^b)&(e^d))>>>24;f=((e^-8388608)&(d|b)|d&b)>>>23;c[291680]=f;c[291676]=f;c[291678]=e;c[a>>2]=e;return}function aeG(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[b>>2]|0;d=a+i|0;c[291677]=d>>>24;c[291679]=((d^i)&(d^a))>>>24;f=((d^-8388608)&(a|i)|a&i)>>>23;c[291680]=f;c[291676]=f;c[291678]=d;c[b>>2]=d;return}function aeH(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+4;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=1161472+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{d=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|d}d=c[b>>2]|0;a=d+i|0;c[291677]=a>>>24;c[291679]=((a^i)&(a^d))>>>24;f=((a^-8388608)&(d|i)|d&i)>>>23;c[291680]=f;c[291676]=f;c[291678]=a;c[b>>2]=a;return}function aeI(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;f=a-4|0;c[d>>2]=f;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=1161472+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a-2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](a+16777214&16777215)|0|d}d=c[b>>2]|0;a=d+j|0;c[291677]=a>>>24;c[291679]=((a^j)&(a^d))>>>24;g=((a^-8388608)&(d|j)|d&j)>>>23;c[291680]=g;c[291676]=g;c[291678]=a;c[b>>2]=a;return}function aeJ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=1161472+(g*20|0)|0;f=c[d>>2]|0;if((f|0)==0){h=a+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j+i|0;l=k>>>24;c[291677]=l;m=k^i;n=k^j;o=m&n;p=o>>>24;c[291679]=p;q=j&i;r=k^-8388608;s=j|i;t=r&s;u=t|q;v=u>>>23;c[291680]=v;c[291676]=v;c[291678]=k;c[b>>2]=k;return}else{g=(fl[f&255](a&16777215)|0)<<16;i=fl[c[d>>2]&255](a+2&16777215)|0|g;j=c[b>>2]|0;k=j+i|0;l=k>>>24;c[291677]=l;m=k^i;n=k^j;o=m&n;p=o>>>24;c[291679]=p;q=j&i;r=k^-8388608;s=j|i;t=r&s;u=t|q;v=u>>>23;c[291680]=v;c[291676]=v;c[291678]=k;c[b>>2]=k;return}}function aeK(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}else{g=fl[f&255](d&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}}function aeL(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}else{g=fl[f&255](a&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}}function aeM(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}else{g=fl[f&255](a&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}}function aeN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=1166604+((a>>>9&7|8)<<2)|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;if((g&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0;i=h<<16;j=i>>16;k=c[d>>2]|0;l=j+k|0;c[d>>2]=l;return}else{h=fl[a&255](g&16777215)|0;i=h<<16;j=i>>16;k=c[d>>2]|0;l=j+k|0;c[d>>2]=l;return}}function aeO(){var a=0,d=0,e=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;c[a>>2]=(c[a>>2]|0)+(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0);return}function aeP(){var a=0,d=0,f=0,g=0,h=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;c[a>>2]=(c[a>>2]|0)+(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0);return}function aeQ(){var a=0,d=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[291667]|0;c[291667]=d+2;c[a>>2]=(c[a>>2]|0)+(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0);return}function aeR(){var a=0,b=0,d=0,e=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]&255;a=c[b>>2]&255;e=a+d+((c[291676]|0)>>>8&1)|0;c[291677]=e;c[291679]=(e^d)&(e^a);c[291680]=e;c[291676]=e;a=e&255;c[291678]=a|c[291678];c[b>>2]=a|c[b>>2]&-256;return}function aeS(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;b=c[1161468+(e*20|0)>>2]|0;if((b|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[b&255](f&16777215)|0}b=h+g+((c[291676]|0)>>>8&1)|0;c[291677]=b;c[291679]=(b^g)&(b^h);c[291680]=b;c[291676]=b;h=b&255;c[291678]=h|c[291678];g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[g&511](f&16777215,h);return}}function aeT(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[e&255](f&16777215)|0}e=h+g+((c[291676]|0)>>>8&1)|0;c[291677]=e;c[291679]=(e^g)&(e^h);c[291680]=e;c[291676]=e;h=e&255;c[291678]=h|c[291678];g=c[1161476+(b*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[g&511](f&16777215,h);return}}function aeU(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=c[1166604+((b>>>9&7)<<2)>>2]|0;b=f&255;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i+b|0;c[291677]=h;c[291679]=(h^b)&(h^i);c[291680]=h;c[291676]=h;h=i+f|0;f=h&255;c[291678]=f;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,f);return}}function aeV(){var b=0,e=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=b&255;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i+f|0;c[291677]=h;c[291679]=(h^f)&(h^i);c[291680]=h;c[291676]=h;h=i+b|0;b=h&255;c[291678]=b;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,b);return}}function aeW(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291666]|0;c[291666]=b+2;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=e&255;g=b>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]|0}else{i=fl[h&255](b&16777215)|0}h=i+f|0;c[291677]=h;c[291679]=(h^f)&(h^i);c[291680]=h;c[291676]=h;h=i+e|0;e=h&255;c[291678]=e;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[i&511](b&16777215,e);return}}function aeX(){var b=0,e=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=b&255;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i+f|0;c[291677]=h;c[291679]=(h^f)&(h^i);c[291680]=h;c[291676]=h;h=i+b|0;b=h&255;c[291678]=b;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,b);return}}function aeY(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[291666]|0)-2|0;c[291666]=b;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=e&255;g=b>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]|0}else{i=fl[h&255](b&16777215)|0}h=i+f|0;c[291677]=h;c[291679]=(h^f)&(h^i);c[291680]=h;c[291676]=h;h=i+e|0;e=h&255;c[291678]=e;i=c[1161476+(g*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[i&511](b&16777215,e);return}}function aeZ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;i=h<<16;j=i>>16;k=c[b>>2]|0;l=j+k|0;c[b>>2]=l;return}else{h=fl[d&255](a&16777215)|0;i=h<<16;j=i>>16;k=c[b>>2]|0;l=j+k|0;c[b>>2]=l;return}}function ae_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=j+k|0;c[a>>2]=l;return}else{h=fl[g&255](f&16777215)|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=j+k|0;c[a>>2]=l;return}}function ae$(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;if((b&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+b>>1]|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=j+k|0;c[a>>2]=l;return}else{h=fl[d&255](f&16777215)|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=j+k|0;c[a>>2]=l;return}}function ae0(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]&65535;a=c[b>>2]&65535;e=a+d+((c[291676]|0)>>>8&1)|0;f=e>>>8;c[291677]=f;c[291679]=((e^d)&(e^a))>>>8;c[291680]=f;c[291676]=f;f=e&65535;c[291678]=f|c[291678];c[b>>2]=f|c[b>>2]&-65536;return}function ae1(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=c[1166604+((e>>>9&7)<<2)>>2]|0;e=f&255;g=h>>>16&255;i=c[1161468+(g*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]|0}else{j=fl[i&255](h&16777215)|0}i=j+e|0;c[291677]=i;c[291679]=(i^e)&(i^j);c[291680]=i;c[291676]=i;i=j+f|0;f=i&255;c[291678]=f;j=c[1161476+(g*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]=i&255;return}else{fj[j&511](h&16777215,f);return}}function ae2(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=c[1166604+((b>>>9&7)<<2)>>2]|0;b=i&255;f=g>>>16&255;h=c[1161468+(f*20|0)>>2]|0;if((h|0)==0){j=d[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[h&255](g&16777215)|0}h=j+b|0;c[291677]=h;c[291679]=(h^b)&(h^j);c[291680]=h;c[291676]=h;h=j+i|0;i=h&255;c[291678]=i;j=c[1161476+(f*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[j&511](g&16777215,i);return}}function ae3(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;g=e&255;h=f>>>16&255;i=c[1161468+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{j=fl[i&255](f&16777215)|0}i=j+g|0;c[291677]=i;c[291679]=(i^g)&(i^j);c[291680]=i;c[291676]=i;i=j+e|0;e=i&255;c[291678]=e;j=c[1161476+(h*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[j&511](f&16777215,e);return}}function ae4(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;i=h&255;j=f&255;f=c[1161468+(j*20|0)>>2]|0;if((f|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(b^1)|0]|0}else{k=fl[f&255](g&16777215)|0}f=k+i|0;c[291677]=f;c[291679]=(f^i)&(f^k);c[291680]=f;c[291676]=f;f=k+h|0;h=f&255;c[291678]=h;k=c[1161476+(j*20|0)>>2]|0;if((k|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[k&511](g&16777215,h);return}}function ae5(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-2|0;c[d>>2]=f;d=(f&1|0)!=0;a=c[291688]|0;if(d&(a|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=a}else{a=fl[i&255](f&16777215)|0;j=a;k=c[291688]|0}a=j+g+((c[291676]|0)>>>8&1)|0;i=a>>>8;c[291677]=i;c[291679]=((a^g)&(a^j))>>>8;c[291680]=i;c[291676]=i;i=a&65535;c[291678]=i|c[291678];if(d&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[k&511](f&16777215,i);return}}function ae6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7)<<2)>>2]|0;a=f&65535;g=(d&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d>>>16&255;j=c[1161472+(i*20|0)>>2]|0;if((j|0)==0){k=e[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]|0;l=h}else{h=fl[j&255](d&16777215)|0;k=h;l=c[291688]|0}h=k+a|0;j=h>>>8;c[291677]=j;c[291679]=((h^a)&(h^k))>>>8;c[291680]=j;c[291676]=j;j=k+f|0;f=j&65535;c[291678]=f;if(g&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(i*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[l&511](d&16777215,f);return}}function ae7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=a&65535;g=(d&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d>>>16&255;j=c[1161472+(i*20|0)>>2]|0;if((j|0)==0){k=e[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]|0;l=h}else{h=fl[j&255](d&16777215)|0;k=h;l=c[291688]|0}h=k+f|0;j=h>>>8;c[291677]=j;c[291679]=((h^f)&(h^k))>>>8;c[291680]=j;c[291676]=j;j=k+a|0;a=j&65535;c[291678]=a;if(g&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(i*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[l&511](d&16777215,a);return}}function ae8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=a&65535;g=(d&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d>>>16&255;j=c[1161472+(i*20|0)>>2]|0;if((j|0)==0){k=e[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]|0;l=h}else{h=fl[j&255](d&16777215)|0;k=h;l=c[291688]|0}h=k+f|0;j=h>>>8;c[291677]=j;c[291679]=((h^f)&(h^k))>>>8;c[291680]=j;c[291676]=j;j=k+a|0;a=j&65535;c[291678]=a;if(g&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(i*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[l&511](d&16777215,a);return}}function ae9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=d&65535;f=(g&1|0)!=0;h=c[291688]|0;if(f&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=g>>>16&255;j=c[1161472+(i*20|0)>>2]|0;if((j|0)==0){k=e[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]|0;l=h}else{h=fl[j&255](g&16777215)|0;k=h;l=c[291688]|0}h=k+a|0;j=h>>>8;c[291677]=j;c[291679]=((h^a)&(h^k))>>>8;c[291680]=j;c[291676]=j;j=k+d|0;d=j&65535;c[291678]=d;if(f&(l|0)!=0){l=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(i*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[l&511](g&16777215,d);return}}function afa(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[1166604+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a+d+((c[291676]|0)>>>8&1)|0;c[291677]=e>>>24;c[291679]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(a|d)|a&d)>>>23;c[291680]=f;c[291676]=f;c[291678]=e|c[291678];c[b>>2]=e;return}function afb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[1166604+((a>>>9&7)<<2)>>2]|0;a=h&65535;d=(f&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;j=c[1161472+(i*20|0)>>2]|0;if((j|0)==0){k=e[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]|0;l=g}else{g=fl[j&255](f&16777215)|0;k=g;l=c[291688]|0}g=k+a|0;j=g>>>8;c[291677]=j;c[291679]=((g^a)&(g^k))>>>8;c[291680]=j;c[291676]=j;j=k+h|0;h=j&65535;c[291678]=h;if(d&(l|0)!=0){l=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(i*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[l&511](f&16777215,h);return}}function afc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=a&65535;g=(d&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d>>>16&255;j=c[1161472+(i*20|0)>>2]|0;if((j|0)==0){k=e[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]|0;l=h}else{h=fl[j&255](d&16777215)|0;k=h;l=c[291688]|0}h=k+f|0;j=h>>>8;c[291677]=j;c[291679]=((h^f)&(h^k))>>>8;c[291680]=j;c[291676]=j;j=k+a|0;a=j&65535;c[291678]=a;if(g&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(i*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[l&511](d&16777215,a);return}}function afd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;h=g&65535;i=(a&1|0)!=0;j=c[291688]|0;if(i&(j|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=k;eJ(1166756,1)}k=d&255;d=c[1161472+(k*20|0)>>2]|0;if((d|0)==0){l=e[(c[1161464+(k*20|0)>>2]|0)+a>>1]|0;m=j}else{j=fl[d&255](f&16777215)|0;l=j;m=c[291688]|0}j=l+h|0;d=j>>>8;c[291677]=d;c[291679]=((j^h)&(j^l))>>>8;c[291680]=d;c[291676]=d;d=l+g|0;g=d&65535;c[291678]=g;if(i&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(k*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+a>>1]=d&65535;return}else{fj[m&511](f&16777215,g);return}}function afe(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=1161472+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=1161472+(h*20|0)|0;k=c[i>>2]|0;if((k|0)==0){l=d-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;n=f}else{f=(fl[k&255](g&16777215)|0)<<16;k=fl[c[i>>2]&255](d+16777214&16777215)|0|f;m=k;n=c[291688]|0}k=m+j+((c[291676]|0)>>>8&1)|0;c[291677]=k>>>24;c[291679]=((k^j)&(k^m))>>>24;f=((k^-8388608)&(m|j)|m&j)>>>23;c[291680]=f;c[291676]=f;c[291678]=k|c[291678];if(a&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(h*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}g=d-2|0;d=g>>>16&255;n=c[1161480+(d*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]=k&65535;return}else{fj[n&511](g&16777215,k&65535);return}}function aff(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l+f|0;c[291677]=j>>>24;c[291679]=((j^f)&(j^l))>>>24;g=((j^-8388608)&(l|f)|l&f)>>>23;c[291680]=g;c[291676]=g;c[291678]=j;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function afg(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l+a|0;c[291677]=j>>>24;c[291679]=((j^a)&(j^l))>>>24;g=((j^-8388608)&(l|a)|l&a)>>>23;c[291680]=g;c[291676]=g;c[291678]=j;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function afh(){var a=0,b=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[1166604+((a&7)<<2)>>2]|0)+(c[b>>2]|0);return}function afi(){var a=0,b=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[1166604+((a&7|8)<<2)>>2]|0)+(c[b>>2]|0);return}function afj(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;g=(f&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](f&16777215)|0)<<16;k=fl[c[j>>2]&255](d+16777214&16777215)|0|h;m=k;n=c[291688]|0}k=m+a|0;c[291677]=k>>>24;c[291679]=((k^a)&(k^m))>>>24;h=((k^-8388608)&(m|a)|m&a)>>>23;c[291680]=h;c[291676]=h;c[291678]=k;if(g&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}f=d-2|0;d=f>>>16&255;n=c[1161480+(d*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=k&65535;return}else{fj[n&511](f&16777215,k&65535);return}}function afk(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(g&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=g+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]<<16;m=f}else{f=(fl[j&255](g&16777215)|0)<<16;j=fl[c[i>>2]&255](g+2&16777215)|0|f;l=j;m=c[291688]|0}j=l+d|0;c[291677]=j>>>24;c[291679]=((j^d)&(j^l))>>>24;f=((j^-8388608)&(l|d)|l&d)>>>23;c[291680]=f;c[291676]=f;c[291678]=j;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[m&511](g&16777215,j>>>16)}m=g+2|0;g=m>>>16&255;h=c[1161480+(g*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function afl(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[1166604+((a>>>9&7)<<2)>>2]|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;i=1161472+(g*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;m=d}else{d=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](f+2&16777215)|0|d;l=j;m=c[291688]|0}j=l+h|0;c[291677]=j>>>24;c[291679]=((j^h)&(j^l))>>>24;d=((j^-8388608)&(l|h)|l&h)>>>23;c[291680]=d;c[291676]=d;c[291678]=j;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(g*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[g&511](m&16777215,j&65535);return}}function afm(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;f=(d&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l+a|0;c[291677]=j>>>24;c[291679]=((j^a)&(j^l))>>>24;g=((j^-8388608)&(l|a)|l&a)>>>23;c[291680]=g;c[291676]=g;c[291678]=j;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function afn(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=d&255;d=1161472+(j*20|0)|0;k=c[d>>2]|0;if((k|0)==0){l=f+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0)<<16;n=i}else{i=(fl[k&255](f&16777215)|0)<<16;k=fl[c[d>>2]&255](f+2&16777215)|0|i;m=k;n=c[291688]|0}k=m+g|0;c[291677]=k>>>24;c[291679]=((k^g)&(k^m))>>>24;i=((k^-8388608)&(m|g)|m&g)>>>23;c[291680]=i;c[291676]=i;c[291678]=k;if(h&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(j*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}n=f+2|0;f=n>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[a&511](n&16777215,k&65535);return}}function afo(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}}function afp(){var a=0,d=0,f=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=f+2|0;c[a>>2]=(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]<<16)+(c[a>>2]|0);return}function afq(){var a=0,b=0,d=0,f=0,g=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=f+2|0;c[a>>2]=(e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)<<16)+(c[a>>2]|0);return}function afr(){var a=0,b=0,d=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=b+2|0;c[a>>2]=(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16)+(c[a>>2]|0);return}function afs(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;e=(a>>>9)+7&7;a=e+1|0;f=c[b>>2]|0;g=f&255;h=g>>>(a>>>0);c[291649]=(a*14|0)+(c[291649]|0);if((f&128|0)==0){i=h}else{i=d[11504+a|0]|0|h}c[b>>2]=c[b>>2]&-256|i;c[291677]=i;c[291678]=i;c[291679]=0;i=g<<8-e;c[291680]=i;c[291676]=i;return}function aft(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]&255;f=e>>>(a>>>0);c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f|c[b>>2]&-256;c[291677]=0;c[291678]=f;f=e<<8-d;c[291680]=f;c[291676]=f;c[291679]=0;return}function afu(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[291676]&256|c[b>>2]&255;f=e>>>(a>>>0)|e<<8-d;c[291649]=(a*14|0)+(c[291649]|0);c[291676]=f;c[291680]=f;a=f&255;c[b>>2]=a|c[b>>2]&-256;c[291677]=a;c[291678]=a;c[291679]=0;return}function afv(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=a>>>9;a=d+7&7;e=d&7;d=c[b>>2]&255;f=(d<<8-e|d>>>(e>>>0))&255;c[291649]=(c[291649]|0)+14+(a*14|0);c[b>>2]=f|c[b>>2]&-256;c[291677]=f;c[291678]=f;c[291680]=d<<8-a;c[291679]=0;return}function afw(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[291680]=c[291676];c[291677]=c[b>>2];e=c[b>>2]&255;c[291678]=e;c[291679]=0;return}else{a=(d>>>0)%9|0;f=c[291676]&256|c[b>>2]&255;g=f>>>(a>>>0)|f<<9-a;c[291649]=(c[291649]|0)+(d*14|0);c[291676]=g;c[291680]=g;d=g&255;c[b>>2]=d|c[b>>2]&-256;c[291677]=d;e=d;c[291678]=e;c[291679]=0;return}}function afx(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&7;f=c[b>>2]&255;g=(f>>>(e>>>0)|f<<8-e)&255;if((a|0)==0){h=f;i=0}else{c[291649]=(c[291649]|0)+(a*14|0);c[b>>2]=c[b>>2]&-256|g;h=g;i=f<<8-(d+7&7)}c[291680]=i;c[291677]=h;c[291678]=h;c[291679]=0;return}function afy(){var a=0,b=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=ahi()|0;c[a>>2]=(c[a>>2]|0)+b;return}function afz(){var a=0,b=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=ahh()|0;c[a>>2]=(c[a>>2]|0)+b;return}function afA(){var a=0,b=0;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=ahg()|0;c[a>>2]=(c[a>>2]|0)+b;return}function afB(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[291666]|0)-2|0;c[291666]=e;f=e>>>16&255;b=c[1161468+(f*20|0)>>2]|0;if((b|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[b&255](e&16777215)|0}b=h+g+((c[291676]|0)>>>8&1)|0;c[291677]=b;c[291679]=(b^g)&(b^h);c[291680]=b;c[291676]=b;h=b&255;c[291678]=h|c[291678];g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[g&511](e&16777215,h);return}}function afC(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[291666]|0}e=h-2|0;c[291666]=e;h=e>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[b&255](e&16777215)|0}b=i+g+((c[291676]|0)>>>8&1)|0;c[291677]=b;c[291679]=(b^g)&(b^i);c[291680]=b;c[291676]=b;i=b&255;c[291678]=i|c[291678];g=c[1161476+(h*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[g&511](e&16777215,i);return}}function afD(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;e=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&255;g=f>>>(e>>>0);if((e|0)==0){c[291680]=0;c[291677]=f;c[291678]=f;c[291679]=0;return}c[291649]=(c[291649]|0)+(e*14|0);h=(a&128|0)!=0;if(e>>>0<8){if(h){i=d[11504+e|0]|0|g}else{i=g}c[b>>2]=c[b>>2]&-256|i;g=f<<9-e;c[291680]=g;c[291676]=g;c[291677]=i;c[291678]=i;c[291679]=0;return}i=c[b>>2]|0;if(h){c[b>>2]=i|255;c[291680]=256;c[291676]=256;c[291677]=128;c[291678]=-1;c[291679]=0;return}else{c[b>>2]=i&-256;aIv(1166704,0,20);return}}function afE(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]&255;e=a>>>(d>>>0);if((d|0)==0){c[291680]=0;c[291677]=a;c[291678]=a;c[291679]=0;return}c[291649]=(c[291649]|0)+(d*14|0);f=c[b>>2]&-256;if(d>>>0<9){c[b>>2]=f|e;g=a<<9-d;c[291680]=g;c[291676]=g;c[291677]=0;c[291678]=e;c[291679]=0;return}else{c[b>>2]=f;aIv(1166704,0,20);return}}function afF(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+4;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=1161472+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}else{d=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|d;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}}function afG(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=1166604+((a&7|8)<<2)|0;a=c[d>>2]|0;f=a-4|0;c[d>>2]=f;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=1161472+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a-2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=c[b>>2]|0;l=k+j|0;c[b>>2]=l;return}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](a+16777214&16777215)|0|d;k=c[b>>2]|0;l=k+j|0;c[b>>2]=l;return}}function afH(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a>>>9&7|8)<<2)|0;d=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=1161472+(g*20|0)|0;f=c[d>>2]|0;if((f|0)==0){h=a+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}else{g=(fl[f&255](a&16777215)|0)<<16;i=fl[c[d>>2]&255](a+2&16777215)|0|g;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}}function afI(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;f=c[b>>2]|0;g=f&65535;h=g>>>(a>>>0);c[291649]=(a*14|0)+(c[291649]|0);if((f&32768|0)==0){i=h}else{i=e[11840+(a<<1)>>1]|0|h}c[b>>2]=c[b>>2]&-65536|i;c[291677]=i>>>8;c[291678]=i;c[291679]=0;i=g<<8-d;c[291680]=i;c[291676]=i;return}function afJ(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]&65535;f=e>>>(a>>>0);c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f|c[b>>2]&-65536;c[291677]=0;c[291678]=f;f=e<<8-d;c[291680]=f;c[291676]=f;c[291679]=0;return}function afK(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=(c[291676]|0)>>>8<<16&65536|c[b>>2]&65535;f=e>>>(a>>>0)|e<<16-d;c[291649]=(a*14|0)+(c[291649]|0);a=f>>>8;c[291676]=a;c[291680]=a;a=f&65535;c[b>>2]=a|c[b>>2]&-65536;c[291677]=a>>>8;c[291678]=a;c[291679]=0;return}function afL(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]&65535;f=(e>>>(a>>>0)|e<<(d^15))&65535;c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f|c[b>>2]&-65536;c[291677]=f>>>8;c[291678]=f;c[291680]=e<<8-d;c[291679]=0;return}function afM(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[291680]=c[291676];c[291677]=(c[b>>2]|0)>>>8;e=c[b>>2]&65535;c[291678]=e;c[291679]=0;return}else{a=(d>>>0)%17|0;f=(c[291676]|0)>>>8<<16&65536|c[b>>2]&65535;g=f>>>(a>>>0)|f<<17-a;c[291649]=(c[291649]|0)+(d*14|0);d=g>>>8;c[291676]=d;c[291680]=d;d=g&65535;c[b>>2]=d|c[b>>2]&-65536;c[291677]=d>>>8;e=d;c[291678]=e;c[291679]=0;return}}function afN(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&15;f=c[b>>2]&65535;g=(f>>>(e>>>0)|f<<16-e)&65535;if((a|0)==0){h=f;i=0}else{c[291649]=(c[291649]|0)+(a*14|0);c[b>>2]=c[b>>2]&-65536|g;h=g;i=f>>>((d+15&15)>>>0)<<8}c[291680]=i;c[291677]=h>>>8;c[291678]=h;c[291679]=0;return}function afO(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e>>>(a>>>0);c[291649]=(a*14|0)+(c[291649]|0);if((e|0)<0){g=c[11576+(a<<2)>>2]|f}else{g=f}c[b>>2]=g;c[291677]=g>>>24;c[291678]=g;c[291679]=0;g=e<<8-d;c[291680]=g;c[291676]=g;return}function afP(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e>>>(a>>>0);c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f;c[291677]=0;c[291678]=f;f=e<<8-d;c[291680]=f;c[291676]=f;c[291679]=0;return}function afQ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=32-d|0;g=d^31;h=((f>>>0<32?e<<f:0)|e>>>(a>>>0))&~(1<<g)|((c[291676]|0)>>>8&1)<<g;c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=h;b=((1<<d&e|0)!=0)<<8;c[291676]=b;c[291680]=b;c[291677]=h>>>24;c[291678]=h;c[291679]=0;return}function afR(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e>>>(a>>>0)|e<<(d^31);c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f;c[291677]=f>>>24;c[291678]=f;c[291680]=e<<8-d;c[291679]=0;return}function afS(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a>>>(d>>>0);if((d|0)==0){c[291680]=0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;return}c[291649]=(c[291649]|0)+(d*14|0);if(d>>>0<32){c[b>>2]=e;f=a>>>((d-1|0)>>>0)<<8;c[291676]=f;c[291680]=f;c[291677]=0;c[291678]=e;c[291679]=0;return}c[b>>2]=0;if((d|0)==32){g=a>>>23&256}else{g=0}c[291680]=g;c[291676]=g;c[291677]=0;c[291678]=0;c[291679]=0;return}function afT(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=(d>>>0)%33|0;e=c[b>>2]|0;f=33-a|0;g=32-a|0;h=c[291676]|0;i=((a>>>0<32?e>>>(a>>>0):0)|(f>>>0<32?e<<f:0))&~(1<<g)|(h>>>8&1)<<g;if((d|0)!=0){c[291649]=(c[291649]|0)+(d*14|0)}if((a|0)==0){j=e;k=h;c[291680]=k;l=j>>>24;c[291677]=l;c[291678]=j;c[291679]=0;return}c[b>>2]=i;b=((1<<a-1&e|0)!=0)<<8;c[291676]=b;j=i;k=b;c[291680]=k;l=j>>>24;c[291677]=l;c[291678]=j;c[291679]=0;return}function afU(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&31;f=c[b>>2]|0;g=32-e|0;h=(g>>>0<32?f<<g:0)|f>>>(e>>>0);if((a|0)==0){i=f;j=0}else{c[291649]=(c[291649]|0)+(a*14|0);c[b>>2]=h;i=h;j=f>>>((d+31&31)>>>0)<<8}c[291680]=j;c[291677]=i>>>24;c[291678]=i;c[291679]=0;return}function afV(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&65535;g=f>>>(d>>>0);if((d|0)==0){c[291680]=0;c[291677]=f>>>8;c[291678]=f;c[291679]=0;return}c[291649]=(c[291649]|0)+(d*14|0);h=(a&32768|0)!=0;if(d>>>0<16){if(h){i=e[11840+(d<<1)>>1]|0|g}else{i=g}c[b>>2]=c[b>>2]&-65536|i;g=f>>>((d-1|0)>>>0)<<8;c[291676]=g;c[291680]=g;c[291677]=i>>>8;c[291678]=i;c[291679]=0;return}i=c[b>>2]|0;if(h){c[b>>2]=i|65535;c[291680]=256;c[291676]=256;c[291677]=128;c[291678]=-1;c[291679]=0;return}else{c[b>>2]=i&-65536;aIv(1166704,0,20);return}}function afW(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]&65535;e=a>>>(d>>>0);if((d|0)==0){c[291680]=0;c[291677]=a>>>8;c[291678]=a;c[291679]=0;return}c[291649]=(c[291649]|0)+(d*14|0);f=c[b>>2]&-65536;if(d>>>0<17){c[b>>2]=f|e;g=a>>>((d-1|0)>>>0)<<8;c[291676]=g;c[291680]=g;c[291677]=0;c[291678]=e;c[291679]=0;return}else{c[b>>2]=f;aIv(1166704,0,20);return}}function afX(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a>>>(d>>>0);if((d|0)==0){c[291680]=0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;return}c[291649]=(c[291649]|0)+(d*14|0);f=(a|0)<0;if(d>>>0<32){if(f){g=c[11576+(d<<2)>>2]|e}else{g=e}c[b>>2]=g;e=a>>>((d-1|0)>>>0)<<8;c[291676]=e;c[291680]=e;c[291677]=g>>>24;c[291678]=g;c[291679]=0;return}if(f){c[b>>2]=-1;c[291680]=256;c[291676]=256;c[291677]=128;c[291678]=-1;c[291679]=0;return}else{c[b>>2]=0;aIv(1166704,0,20);return}}function afY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=i>>>1;h=(i&32768|0)==0?f:f|32768;if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=h&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}else{fj[j&511](a&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}}function afZ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i>>>1;h=(i&32768|0)==0?f:f|32768;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=h&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}}function af_(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;e=(a>>>9)+7&7;a=e+1|0;f=c[b>>2]|0;g=(f&255)<<a;h=g&255;c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=h|c[b>>2]&-256;c[291680]=g;c[291676]=g;c[291677]=h;c[291678]=h;h=d[e+11506|0]|0;e=h&f;if((e|0)==0){i=0;c[291679]=i;return}if((e|0)!=(h|0)){i=128;c[291679]=i;return}i=(a>>>0>7)<<7;c[291679]=i;return}function af$(){var a=0,b=0,d=0,e=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=(c[b>>2]&255)<<d;e=a&255;c[291649]=(d*14|0)+(c[291649]|0);c[b>>2]=e|c[b>>2]&-256;c[291677]=e;c[291678]=e;c[291680]=a;c[291676]=a;c[291679]=0;return}function af0(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[291676]&256|c[b>>2]&255;f=e<<a|e>>>((8-d|0)>>>0);c[291649]=(a*14|0)+(c[291649]|0);c[291676]=f;c[291680]=f;a=f&255;c[b>>2]=a|c[b>>2]&-256;c[291677]=a;c[291678]=a;c[291679]=0;return}function af1(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=a>>>9;a=(d+7&7)+1|0;e=d&7;d=c[b>>2]&255;f=(d>>>((8-e|0)>>>0)|d<<e)&255;c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f|c[b>>2]&-256;c[291677]=f;c[291678]=f;c[291680]=d<<a;c[291679]=0;return}function af2(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;e=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&255;g=f<<e;h=g&255;if((e|0)==0){c[291680]=0;c[291677]=f;c[291678]=f;c[291679]=0;return}c[291649]=(c[291649]|0)+(e*14|0);i=c[b>>2]&-256;if(e>>>0<8){c[b>>2]=i|h;c[291680]=g;c[291676]=g;c[291677]=h;c[291678]=h;h=d[e+11505|0]|0;g=h&a;if((g|0)==0){j=0}else{j=((g|0)!=(h|0))<<7}c[291679]=j;return}else{c[b>>2]=i;if((e|0)==8){k=a<<8&256}else{k=0}c[291680]=k;c[291676]=k;c[291677]=0;c[291678]=0;c[291679]=((f|0)!=0)<<7;return}}function af3(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[291680]=c[291676];c[291677]=c[b>>2];e=c[b>>2]&255;c[291678]=e;c[291679]=0;return}else{a=(d>>>0)%9|0;f=c[291676]&256|c[b>>2]&255;g=f<<a|f>>>((9-a|0)>>>0);c[291649]=(c[291649]|0)+(d*14|0);c[291676]=g;c[291680]=g;d=g&255;c[b>>2]=d|c[b>>2]&-256;c[291677]=d;e=d;c[291678]=e;c[291679]=0;return}}function af4(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&7;d=c[b>>2]|0;f=d&255;g=f<<e;h=(g|f>>>((8-e|0)>>>0))&255;if((a|0)==0){c[291680]=0;c[291677]=f;c[291678]=f;c[291679]=0;return}c[291649]=(c[291649]|0)+(a*14|0);if((e|0)==0){c[291680]=d<<8&256;c[291677]=f;c[291678]=f;c[291679]=0;return}else{c[b>>2]=c[b>>2]&-256|h;c[291680]=g;c[291677]=h;c[291678]=h;c[291679]=0;return}}function af5(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;f=c[b>>2]|0;g=f&65535;h=g<<a&65535;c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=h|c[b>>2]&-65536;c[291677]=h>>>8;c[291678]=h;h=g>>>((d^7)>>>0);c[291680]=h;c[291676]=h;h=e[11840+(d+2<<1)>>1]|0;d=h&f;if((d|0)==0){i=0;c[291679]=i;return}i=((d|0)!=(h|0))<<7;c[291679]=i;return}function af6(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]&255;e=a<<d;f=e&255;if((d|0)==0){c[291680]=0;c[291677]=a;c[291678]=a;c[291679]=0;return}c[291649]=(c[291649]|0)+(d*14|0);a=c[b>>2]&-256;if(d>>>0<9){c[b>>2]=a|f;c[291680]=e;c[291676]=e;c[291677]=f;c[291678]=f;c[291679]=0;return}else{c[b>>2]=a;aIv(1166704,0,20);return}}function af7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i>>>1;h=(i&32768|0)==0?f:f|32768;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=h&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}}function af8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=i>>>1;h=(i&32768|0)==0?d:d|32768;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=h&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}else{fj[j&511](f&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}}function af9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=i>>>1;h=(i&32768|0)==0?a:a|32768;if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=h&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}}function aga(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i>>>1;h=(i&32768|0)==0?f:f|32768;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=h&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;l=i<<8;c[291676]=l;c[291680]=l;return}}function agb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=j>>>1;d=(j&32768|0)==0?h:h|32768;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=d&65535;l=d>>>8;c[291677]=l;c[291678]=d;c[291679]=0;m=j<<8;c[291676]=m;c[291680]=m;return}else{fj[k&511](f&16777215,d);l=d>>>8;c[291677]=l;c[291678]=d;c[291679]=0;m=j<<8;c[291676]=m;c[291680]=m;return}}function agc(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]&65535;f=e<<a&65535;c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f|c[b>>2]&-65536;c[291677]=f>>>8;c[291678]=f;f=e>>>((d^7)>>>0);c[291680]=f;c[291676]=f;c[291679]=0;return}function agd(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=(c[291676]|0)>>>8<<16&65536|c[b>>2]&65535;f=e<<a|e>>>((16-d|0)>>>0);c[291649]=(a*14|0)+(c[291649]|0);a=f>>>8;c[291676]=a;c[291680]=a;a=f&65535;c[b>>2]=a|c[b>>2]&-65536;c[291677]=a>>>8;c[291678]=a;c[291679]=0;return}function age(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]&65535;f=(e<<a|e>>>((d^15)>>>0))&65535;c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f|c[b>>2]&-65536;c[291677]=f>>>8;c[291678]=f;c[291680]=e>>>((d^7)>>>0);c[291679]=0;return}function agf(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&65535;g=f<<d;h=g&65535;if((d|0)==0){c[291680]=0;c[291677]=f>>>8;c[291678]=f;c[291679]=0;return}c[291649]=(c[291649]|0)+(d*14|0);i=c[b>>2]&-65536;if(d>>>0<16){c[b>>2]=i|h;j=g>>>8;c[291680]=j;c[291676]=j;c[291677]=h>>>8;c[291678]=h;h=e[11840+(d+1<<1)>>1]|0;j=h&a;if((j|0)==0){k=0}else{k=((j|0)!=(h|0))<<7}c[291679]=k;return}else{c[b>>2]=i;if((d|0)==16){l=a<<8&256}else{l=0}c[291680]=l;c[291676]=l;c[291677]=0;c[291678]=0;c[291679]=((f|0)!=0)<<7;return}}function agg(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[291680]=c[291676];c[291677]=(c[b>>2]|0)>>>8;e=c[b>>2]&65535;c[291678]=e;c[291679]=0;return}else{a=(d>>>0)%17|0;f=(c[291676]|0)>>>8<<16&65536|c[b>>2]&65535;g=f<<a|f>>>((17-a|0)>>>0);c[291649]=(c[291649]|0)+(d*14|0);d=g>>>8;c[291676]=d;c[291680]=d;d=g&65535;c[b>>2]=d|c[b>>2]&-65536;c[291677]=d>>>8;e=d;c[291678]=e;c[291679]=0;return}}function agh(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&15;d=c[b>>2]|0;f=d&65535;g=f<<e;h=(g|f>>>((16-e|0)>>>0))&65535;if((a|0)==0){c[291680]=0;c[291677]=f>>>8;c[291678]=f;c[291679]=0;return}c[291649]=(c[291649]|0)+(a*14|0);if((e|0)==0){c[291680]=d<<8&256;c[291677]=f>>>8;c[291678]=f;c[291679]=0;return}else{c[b>>2]=c[b>>2]&-65536|h;c[291680]=g>>>8;c[291677]=h>>>8;c[291678]=h;c[291679]=0;return}}function agi(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e<<a;c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f;c[291677]=f>>>24;c[291678]=f;f=e>>>((23-d|0)>>>0);c[291680]=f;c[291676]=f;f=c[11576+(d+2<<2)>>2]|0;d=f&e;if((d|0)==0){g=0;c[291679]=g;return}g=((d|0)!=(f|0))<<7;c[291679]=g;return}function agj(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e<<a;c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f;c[291677]=f>>>24;c[291678]=f;f=e>>>((23-d|0)>>>0);c[291680]=f;c[291676]=f;c[291679]=0;return}function agk(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=32-d|0;g=((f>>>0<32?e>>>(f>>>0):0)|e<<a)&~(1<<d)|((c[291676]|0)>>>8&1)<<d;c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=g;b=((1<<(d^31)&e|0)!=0)<<8;c[291676]=b;c[291680]=b;c[291677]=g>>>24;c[291678]=g;c[291679]=0;return}function agl(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e<<a|e>>>((d^31)>>>0);c[291649]=(a*14|0)+(c[291649]|0);c[b>>2]=f;c[291677]=f>>>24;c[291678]=f;c[291680]=e>>>((23-d|0)>>>0);c[291679]=0;return}function agm(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a<<d;if((d|0)==0){c[291680]=0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;return}c[291649]=(c[291649]|0)+(d*14|0);if(d>>>0<32){c[b>>2]=e;f=a>>>((32-d|0)>>>0)<<8;c[291680]=f;c[291676]=f;c[291677]=e>>>24;c[291678]=e;e=c[11576+(d+1<<2)>>2]|0;f=e&a;if((f|0)==0){g=0}else{g=((f|0)!=(e|0))<<7}c[291679]=g;return}else{c[b>>2]=0;if((d|0)==32){h=a<<8&256}else{h=0}c[291680]=h;c[291676]=h;c[291677]=0;c[291678]=0;c[291679]=((a|0)!=0)<<7;return}}function agn(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a<<d;if((d|0)==0){c[291680]=0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;return}c[291649]=(c[291649]|0)+(d*14|0);if(d>>>0<32){c[b>>2]=e;f=a>>>((32-d|0)>>>0)<<8;c[291680]=f;c[291676]=f;c[291677]=e>>>24;c[291678]=e;c[291679]=0;return}c[b>>2]=0;if((d|0)==32){g=a<<8&256}else{g=0}c[291680]=g;c[291676]=g;c[291677]=0;c[291678]=0;c[291679]=0;return}function ago(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=(d>>>0)%33|0;e=c[b>>2]|0;f=33-a|0;g=a-1|0;h=c[291676]|0;i=((a>>>0<32?e<<a:0)|(f>>>0<32?e>>>(f>>>0):0))&~(1<<g)|(h>>>8&1)<<g;if((d|0)!=0){c[291649]=(c[291649]|0)+(d*14|0)}if((a|0)==0){j=e;k=h;c[291680]=k;l=j>>>24;c[291677]=l;c[291678]=j;c[291679]=0;return}c[b>>2]=i;b=((1<<32-a&e|0)!=0)<<8;c[291676]=b;j=i;k=b;c[291680]=k;l=j>>>24;c[291677]=l;c[291678]=j;c[291679]=0;return}function agp(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&31;d=c[b>>2]|0;f=32-e|0;g=(f>>>0<32?d>>>(f>>>0):0)|d<<e;if((a|0)==0){h=d;i=0}else{c[291649]=(c[291649]|0)+(a*14|0);c[b>>2]=g;h=g;i=d>>>((f&31)>>>0)<<8}c[291680]=i;c[291677]=h>>>24;c[291678]=h;c[291679]=0;return}function agq(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=c[1166604+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]&65535;e=a<<d;f=e&65535;if((d|0)==0){c[291680]=0;c[291677]=a>>>8;c[291678]=a;c[291679]=0;return}c[291649]=(c[291649]|0)+(d*14|0);a=c[b>>2]&-65536;if(d>>>0<17){c[b>>2]=a|f;d=e>>>8;c[291680]=d;c[291676]=d;c[291677]=f>>>8;c[291678]=f;c[291679]=0;return}else{c[b>>2]=a;aIv(1166704,0,20);return}}function agr(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=i<<1;h=f&65534;if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535}else{fj[j&511](a&16777215,h)}c[291677]=h>>>8;c[291678]=h;h=i>>>7;c[291680]=h;c[291676]=h;h=i&49152;if((h|0)==0){k=0;c[291679]=k;return}k=((h|0)!=49152)<<7;c[291679]=k;return}function ags(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i<<1;h=f&65534;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535}else{fj[j&511](d&16777215,h)}c[291677]=h>>>8;c[291678]=h;h=i>>>7;c[291680]=h;c[291676]=h;h=i&49152;if((h|0)==0){k=0;c[291679]=k;return}k=((h|0)!=49152)<<7;c[291679]=k;return}function agt(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i<<1;h=f&65534;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535}else{fj[j&511](d&16777215,h)}c[291677]=h>>>8;c[291678]=h;h=i>>>7;c[291680]=h;c[291676]=h;h=i&49152;if((h|0)==0){k=0;c[291679]=k;return}k=((h|0)!=49152)<<7;c[291679]=k;return}function agu(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=i<<1;h=d&65534;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535}else{fj[j&511](f&16777215,h)}c[291677]=h>>>8;c[291678]=h;h=i>>>7;c[291680]=h;c[291676]=h;h=i&49152;if((h|0)==0){k=0;c[291679]=k;return}k=((h|0)!=49152)<<7;c[291679]=k;return}function agv(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=i<<1;h=a&65534;if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535}else{fj[j&511](d&16777215,h)}c[291677]=h>>>8;c[291678]=h;h=i>>>7;c[291680]=h;c[291676]=h;h=i&49152;if((h|0)==0){k=0;c[291679]=k;return}k=((h|0)!=49152)<<7;c[291679]=k;return}function agw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i<<1;h=f&65534;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535}else{fj[j&511](d&16777215,h)}c[291677]=h>>>8;c[291678]=h;h=i>>>7;c[291680]=h;c[291676]=h;h=i&49152;if((h|0)==0){k=0;c[291679]=k;return}k=((h|0)!=49152)<<7;c[291679]=k;return}function agx(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=j<<1;d=h&65534;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535}else{fj[k&511](f&16777215,d)}c[291677]=d>>>8;c[291678]=d;d=j>>>7;c[291680]=d;c[291676]=d;d=j&49152;if((d|0)==0){l=0;c[291679]=l;return}l=((d|0)!=49152)<<7;c[291679]=l;return}function agy(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=i>>>1;if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535;c[291677]=0;c[291678]=f;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}else{fj[j&511](a&16777215,f);c[291677]=0;c[291678]=f;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}}function agz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i>>>1;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;c[291677]=0;c[291678]=f;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}else{fj[j&511](d&16777215,f);c[291677]=0;c[291678]=f;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}}function agA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i>>>1;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;c[291677]=0;c[291678]=f;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}else{fj[j&511](d&16777215,f);c[291677]=0;c[291678]=f;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}}function agB(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=i>>>1;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;c[291677]=0;c[291678]=d;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}else{fj[j&511](f&16777215,d);c[291677]=0;c[291678]=d;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}}function agC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=i>>>1;if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;c[291677]=0;c[291678]=a;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}else{fj[j&511](d&16777215,a);c[291677]=0;c[291678]=a;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}}function agD(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i>>>1;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;c[291677]=0;c[291678]=f;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}else{fj[j&511](d&16777215,f);c[291677]=0;c[291678]=f;k=i<<8;c[291676]=k;c[291680]=k;c[291679]=0;return}}
function awJ(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[240594]&256|0)!=0?255:0;b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function awK(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[240594]&256|0)!=0?255:0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function awL(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[240594]&256|0)!=0?255:0;g=d&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function awM(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=(c[240592]|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awN(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[240592]|0)!=0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function awO(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;d=(c[240592]|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awP(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[240592]|0)!=0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function awQ(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;d=(c[240592]|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awR(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[240592]|0)!=0?255:0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function awS(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[240592]|0)!=0?255:0;b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function awT(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[240592]|0)!=0?255:0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function awU(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[240592]|0)!=0?255:0;g=d&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function awV(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=(c[240592]|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awW(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[240592]|0)==0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function awX(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;d=(c[240592]|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awY(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if((c[240593]&128|0)==0){c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}else{c[a>>2]=b&-256;return}}function awZ(){var a=0,d=0,e=0;if((c[240593]&128|0)==0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function aw_(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if((c[240593]&128|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}}function aw$(){var a=0,d=0,e=0;if((c[240593]&128|0)!=0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function aw0(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[240592]|0)==0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function aw1(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;d=(c[240592]|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function aw2(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[240592]|0)==0?255:0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function aw3(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[240592]|0)==0?255:0;b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function aw4(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[240592]|0)==0?255:0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function aw5(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[240592]|0)==0?255:0;g=d&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function aw6(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=(c[240593]&128|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function aw7(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[240593]&128|0)==0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function aw8(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;d=(c[240593]&128|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function aw9(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[240593]&128|0)==0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function axa(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;d=(c[240593]&128|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axb(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[240593]&128|0)==0?255:0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function axc(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[240593]&128|0)==0?255:0;b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function axd(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[240593]&128|0)==0?255:0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function axe(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[240593]&128|0)==0?255:0;g=d&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function axf(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=(c[240593]&128|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axg(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[240593]&128|0)!=0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function axh(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;d=(c[240593]&128|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axi(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[240593]&128|0)!=0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function axj(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;d=(c[240593]&128|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axk(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if((c[240591]&128|0)==0){c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}else{c[a>>2]=b&-256;return}}function axl(){var a=0,d=0,e=0;if((c[240591]&128|0)==0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function axm(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if((c[240591]&128|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}}function axn(){var a=0,d=0,e=0;if((c[240591]&128|0)!=0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function axo(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[240593]&128|0)!=0?255:0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function axp(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[240593]&128|0)!=0?255:0;b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function axq(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[240593]&128|0)!=0?255:0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function axr(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[240593]&128|0)!=0?255:0;g=d&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function axs(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=(c[240591]&128|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axt(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[240591]&128|0)==0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function axu(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;d=(c[240591]&128|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axv(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[240591]&128|0)==0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function axw(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;d=(c[240591]&128|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axx(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[240591]&128|0)==0?255:0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function axy(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[240591]&128|0)==0?255:0;b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function axz(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[240591]&128|0)==0?255:0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function axA(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[240591]&128|0)==0?255:0;g=d&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function axB(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=(c[240591]&128|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axC(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[240591]&128|0)!=0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function axD(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;d=(c[240591]&128|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axE(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[240591]&128|0)!=0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function axF(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;d=(c[240591]&128|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axG(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[240591]&128|0)!=0?255:0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function axH(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if(((c[240593]^c[240591])&128|0)==0){c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}else{c[a>>2]=b&-256;return}}function axI(){var a=0,d=0,e=0;if(((c[240593]^c[240591])&128|0)==0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function axJ(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if(((c[240593]^c[240591])&128|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}}function axK(){var a=0,d=0,e=0;if(((c[240593]^c[240591])&128|0)!=0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function axL(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[240591]&128|0)!=0?255:0;b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function axM(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[240591]&128|0)!=0?255:0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function axN(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[240591]&128|0)!=0?255:0;g=d&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function axO(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=((c[240593]^c[240591])&128|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axP(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=((c[240593]^c[240591])&128|0)==0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function axQ(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;d=((c[240593]^c[240591])&128|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axR(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=((c[240593]^c[240591])&128|0)==0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function axS(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;d=((c[240593]^c[240591])&128|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axT(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=((c[240593]^c[240591])&128|0)==0?255:0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function axU(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=((c[240593]^c[240591])&128|0)==0?255:0;b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function axV(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=((c[240593]^c[240591])&128|0)==0?255:0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function axW(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=((c[240593]^c[240591])&128|0)==0?255:0;g=d&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function axX(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=((c[240593]^c[240591])&128|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function axY(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=((c[240593]^c[240591])&128|0)!=0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function axZ(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;d=((c[240593]^c[240591])&128|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ax_(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=((c[240593]^c[240591])&128|0)!=0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function ax$(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;d=((c[240593]^c[240591])&128|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ax0(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=((c[240593]^c[240591])&128|0)!=0?255:0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function ax1(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if(((c[240593]^c[240591])&128|0)==0&(c[240592]|0)!=0){c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}else{c[a>>2]=b&-256;return}}function ax2(){var a=0,d=0,e=0;if(((c[240593]^c[240591])&128|0)==0&(c[240592]|0)!=0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function ax3(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if(((c[240593]^c[240591])&128|0)==0&(c[240592]|0)!=0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}}function ax4(){var a=0,d=0,e=0;if(!(((c[240593]^c[240591])&128|0)==0&(c[240592]|0)!=0)){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function ax5(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=((c[240593]^c[240591])&128|0)!=0?255:0;b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function ax6(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=((c[240593]^c[240591])&128|0)!=0?255:0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function ax7(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=((c[240593]^c[240591])&128|0)!=0?255:0;g=d&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function ax8(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;if(((c[240593]^c[240591])&128|0)==0){d=(c[240592]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ax9(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if(((c[240593]^c[240591])&128|0)==0){e=(c[240592]|0)!=0?255:0}else{e=0}b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function aya(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;if(((c[240593]^c[240591])&128|0)==0){d=(c[240592]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ayb(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if(((c[240593]^c[240591])&128|0)==0){e=(c[240592]|0)!=0?255:0}else{e=0}b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function ayc(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;if(((c[240593]^c[240591])&128|0)==0){d=(c[240592]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ayd(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;if(((c[240593]^c[240591])&128|0)==0){g=(c[240592]|0)!=0?255:0}else{g=0}d=f>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function aye(){var b=0,d=0,f=0,g=0,h=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if(((c[240593]^c[240591])&128|0)==0){h=(c[240592]|0)!=0?255:0}else{h=0}g=d>>>16&255;b=c[957132+(g*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(d&65535^1)|0]=h&255;return}else{fj[b&511](d&16777215,h);return}}function ayf(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if(((c[240593]^c[240591])&128|0)==0){f=(c[240592]|0)!=0?255:0}else{f=0}d=e>>>16&255;g=c[957132+(d*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function ayg(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;if(((c[240593]^c[240591])&128|0)==0){g=(c[240592]|0)!=0?255:0}else{g=0}f=d&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b^1)|0]=g&255;return}else{fj[h&511](b|d<<16&16711680,g);return}}function ayh(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;if(((c[240593]^c[240591])&128|0)==0){d=(c[240592]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ayi(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if(((c[240593]^c[240591])&128|0)==0){e=(c[240592]|0)==0?255:0}else{e=255}b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function ayj(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;if(((c[240593]^c[240591])&128|0)==0){d=(c[240592]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ayk(){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}function ayl(){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}function aym(){if((c[240594]&256|0)==0&(c[240592]|0)!=0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayn(){if((c[240594]&256|0)==0&(c[240592]|0)!=0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayo(){if((c[240594]&256|0)==0&(c[240592]|0)!=0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayp(){if((c[240594]&256|0)==0&(c[240592]|0)!=0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayq(){if((c[240594]&256|0)==0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayr(){if((c[240594]&256|0)==0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ays(){if((c[240594]&256|0)==0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayt(){if((c[240594]&256|0)==0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayu(){if((c[240592]|0)==0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayv(){if((c[240592]|0)==0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayw(){if((c[240592]|0)==0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayx(){if((c[240592]|0)==0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayy(){var a=0;a=c[240581]|0;c[240581]=a+2;c[240581]=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a;return}function ayz(){var a=0,d=0,e=0;a=c[240581]|0;d=a+2|0;c[240581]=d;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(c[240580]|0)-4|0;c[240580]=a;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535;a=(c[240580]|0)+2|0;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d&65535;c[240581]=(e<<16>>16)-2+(c[240581]|0);return}function ayA(){var a=0,d=0;a=c[240581]|0;d=(c[240580]|0)-4|0;c[240580]=d;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a>>>16&65535;d=(c[240580]|0)+2|0;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a&65535;c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}function ayB(){var a=0,d=0;a=c[240581]|0;d=(c[240580]|0)-4|0;c[240580]=d;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a>>>16&65535;d=(c[240580]|0)+2|0;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a&65535;c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}function ayC(){var a=0,d=0;a=(c[240594]&256|0)==0&(c[240592]|0)!=0;d=c[240581]|0;c[240581]=d+2;if(a){c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[240563]=(c[240563]|0)+8;return}}function ayD(){var a=0,d=0;a=(c[240594]&256|0)==0&(c[240592]|0)!=0;d=c[240581]|0;c[240581]=d+2;if(a){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function ayE(){var a=0,d=0;a=(c[240594]&256|0)==0;d=c[240581]|0;c[240581]=d+2;if(a){c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[240563]=(c[240563]|0)+8;return}}function ayF(){var a=0,d=0;a=(c[240594]&256|0)==0;d=c[240581]|0;c[240581]=d+2;if(a){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function ayG(){var a=0,d=0;a=(c[240592]|0)==0;d=c[240581]|0;c[240581]=d+2;if(a){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function ayH(){var a=0,d=0;a=(c[240592]|0)==0;d=c[240581]|0;c[240581]=d+2;if(a){c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[240563]=(c[240563]|0)+8;return}}function ayI(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if(((c[240593]^c[240591])&128|0)==0){e=(c[240592]|0)==0?255:0}else{e=255}b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function ayJ(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;if(((c[240593]^c[240591])&128|0)==0){d=(c[240592]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ayK(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;if(((c[240593]^c[240591])&128|0)==0){g=(c[240592]|0)==0?255:0}else{g=255}d=f>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function ayL(){var b=0,d=0,f=0,g=0,h=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if(((c[240593]^c[240591])&128|0)==0){h=(c[240592]|0)==0?255:0}else{h=255}g=d>>>16&255;b=c[957132+(g*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(d&65535^1)|0]=h&255;return}else{fj[b&511](d&16777215,h);return}}function ayM(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if(((c[240593]^c[240591])&128|0)==0){f=(c[240592]|0)==0?255:0}else{f=255}d=e>>>16&255;g=c[957132+(d*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function ayN(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;if(((c[240593]^c[240591])&128|0)==0){g=(c[240592]|0)==0?255:0}else{g=255}f=d&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b^1)|0]=g&255;return}else{fj[h&511](b|d<<16&16711680,g);return}}function ayO(){if((c[240593]&128|0)==0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayP(){if((c[240593]&128|0)==0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayQ(){if((c[240593]&128|0)==0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayR(){if((c[240593]&128|0)==0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayS(){if((c[240591]&128|0)==0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayT(){if((c[240591]&128|0)==0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayU(){if((c[240591]&128|0)==0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayV(){if((c[240591]&128|0)==0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayW(){if(((c[240593]^c[240591])&128|0)==0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayX(){if(((c[240593]^c[240591])&128|0)==0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ayY(){if(((c[240593]^c[240591])&128|0)==0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ayZ(){if(((c[240593]^c[240591])&128|0)==0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ay_(){if(((c[240593]^c[240591])&128|0)==0&(c[240592]|0)!=0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ay$(){if(((c[240593]^c[240591])&128|0)==0&(c[240592]|0)!=0){c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}else{c[240563]=(c[240563]|0)-8;return}}function ay0(){if(((c[240593]^c[240591])&128|0)==0&(c[240592]|0)!=0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ay1(){if(((c[240593]^c[240591])&128|0)==0&(c[240592]|0)!=0){c[240563]=(c[240563]|0)-8;return}else{c[240581]=(c[240587]<<24>>24)+(c[240581]|0);return}}function ay2(){var a=0,d=0;a=(c[240593]&128|0)==0;d=c[240581]|0;c[240581]=d+2;if(a){c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[240563]=(c[240563]|0)+8;return}}function ay3(){var a=0,d=0;a=(c[240593]&128|0)==0;d=c[240581]|0;c[240581]=d+2;if(a){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function ay4(){var a=0,d=0;a=(c[240591]&128|0)==0;d=c[240581]|0;c[240581]=d+2;if(a){c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[240563]=(c[240563]|0)+8;return}}function ay5(){var a=0,d=0;a=(c[240591]&128|0)==0;d=c[240581]|0;c[240581]=d+2;if(a){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function ay6(){var a=0,d=0;a=((c[240593]^c[240591])&128|0)==0;d=c[240581]|0;c[240581]=d+2;if(a){c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[240563]=(c[240563]|0)+8;return}}function ay7(){var a=0,d=0;a=((c[240593]^c[240591])&128|0)==0;d=c[240581]|0;c[240581]=d+2;if(a){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function ay8(){var a=0,d=0;a=((c[240593]^c[240591])&128|0)==0&(c[240592]|0)!=0;d=c[240581]|0;c[240581]=d+2;if(a){c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[240563]=(c[240563]|0)+8;return}}function ay9(){var a=0,d=0;a=((c[240593]^c[240591])&128|0)==0&(c[240592]|0)!=0;d=c[240581]|0;c[240581]=d+2;if(a){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function aza(){var a=0,b=0;a=c[240587]|0;b=a<<24>>24;c[962260+((a>>>9&7)<<2)>>2]=b;c[240591]=b>>>24;c[240592]=b;c[240593]=0;c[240594]=0;return}function azb(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[b>>2]|c[962260+((a&7)<<2)>>2]&255;c[b>>2]=d;b=d&255;c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}function azc(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}a=962260+((h>>>9&7)<<2)|0;h=c[a>>2]|g;c[a>>2]=h;a=h&255;c[240591]=a;c[240592]=a;c[240594]=0;c[240593]=0;return}function azd(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[b>>2]|f;c[b>>2]=e;b=e&255;c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}function aze(){var a=0,b=0,e=0,f=0;a=c[240580]|0;c[240580]=a+2;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[a>>2]|f;c[a>>2]=e;a=e&255;c[240591]=a;c[240592]=a;c[240594]=0;c[240593]=0;return}function azf(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[b>>2]|f;c[b>>2]=e;b=e&255;c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}function azg(){var a=0,b=0,e=0,f=0;a=(c[240580]|0)-2|0;c[240580]=a;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[a>>2]|f;c[a>>2]=e;a=e&255;c[240591]=a;c[240592]=a;c[240594]=0;c[240593]=0;return}function azh(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[240587]|0;e=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7)<<2)|0;i=c[a>>2]|h;c[a>>2]=i;a=i&255;c[240591]=a;c[240592]=a;c[240594]=0;c[240593]=0;return}function azi(){var a=0,e=0,f=0;a=c[240581]|0;c[240581]=a+2;e=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;f=c[a>>2]|d[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0];c[a>>2]=f;a=f&255;c[240591]=a;c[240592]=a;c[240594]=0;c[240593]=0;return}function azj(){var a=0,b=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){g=f<<16>>16}else{g=f}f=(b<<24>>24)+a+g|0;g=962260+(((c[240587]|0)>>>9&7)<<2)|0;a=c[g>>2]|(d[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0);c[g>>2]=a;g=a&255;c[240591]=g;c[240592]=g;c[240594]=0;c[240593]=0;return}function azk(){var a=0,d=0,e=0;a=c[240581]|0;c[240581]=a+2;d=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[d>>2]|b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;c[d>>2]=e;d=e&255;c[240591]=d;c[240592]=d;c[240594]=0;c[240593]=0;return}function azl(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[b>>2]|c[962260+((a&7)<<2)>>2]&65535;c[b>>2]=d;b=d&65535;c[240591]=b>>>8;c[240592]=b;c[240594]=0;c[240593]=0;return}function azm(){var a=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;f=c[a>>2]|e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1];c[a>>2]=f;a=f&65535;c[240591]=a>>>8;c[240592]=a;c[240594]=0;c[240593]=0;return}function azn(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=962260+(((c[240587]|0)>>>9&7)<<2)|0;a=c[f>>2]|(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0);c[f>>2]=a;f=a&65535;c[240591]=f>>>8;c[240592]=f;c[240594]=0;c[240593]=0;return}function azo(){var a=0,b=0,d=0;a=c[240581]|0;c[240581]=a+2;b=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[b>>2]|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0);c[b>>2]=d;b=d&65535;c[240591]=b>>>8;c[240592]=b;c[240594]=0;c[240593]=0;return}function azp(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[b>>2]|c[962260+((a&7)<<2)>>2];c[b>>2]=d;c[240591]=d>>>24;c[240592]=d;c[240594]=0;c[240593]=0;return}function azq(){var a=0,b=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0;j=a}else{a=fl[b&255](f&16777215)|0;i=a;j=c[240587]|0}a=962260+((j>>>9&7)<<2)|0;j=c[a>>2]|i;c[a>>2]=j;a=j&255;c[240591]=a;c[240592]=a;c[240594]=0;c[240593]=0;return}function azr(){var a=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[957124+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7)<<2)|0;f=c[e>>2]|g;c[e>>2]=f;e=f&255;c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}function azs(){var a=0,b=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a^1)|0]|0}else{h=fl[g&255](a|b<<16&16711680)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;a=c[b>>2]|h;c[b>>2]=a;b=a&255;c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}function azt(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}a=962260+((h>>>9&7)<<2)|0;h=c[a>>2]|g;c[a>>2]=h;a=h&65535;c[240591]=a>>>8;c[240592]=a;c[240594]=0;c[240593]=0;return}function azu(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[b>>2]|f;c[b>>2]=d;b=d&65535;c[240591]=b>>>8;c[240592]=b;c[240594]=0;c[240593]=0;return}function azv(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[b>>2]|f;c[b>>2]=d;b=d&65535;c[240591]=b>>>8;c[240592]=b;c[240594]=0;c[240593]=0;return}function azw(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7)<<2)|0;i=c[a>>2]|h;c[a>>2]=i;a=i&65535;c[240591]=a>>>8;c[240592]=a;c[240594]=0;c[240593]=0;return}function azx(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[957128+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[b&255](d&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7)<<2)|0;i=c[a>>2]|h;c[a>>2]=i;a=i&65535;c[240591]=a>>>8;c[240592]=a;c[240594]=0;c[240593]=0;return}function azy(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7)<<2)|0;f=c[d>>2]|g;c[d>>2]=f;d=f&65535;c[240591]=d>>>8;c[240592]=d;c[240594]=0;c[240593]=0;return}function azz(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=b&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+a>>1]|0}else{g=fl[f&255](a|b<<16&16711680)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;a=c[b>>2]|g;c[b>>2]=a;b=a&65535;c[240591]=b>>>8;c[240592]=b;c[240594]=0;c[240593]=0;return}function azA(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[240587]|0}g=962260+((j>>>9&7)<<2)|0;j=c[g>>2]|i;c[g>>2]=j;c[240591]=j>>>24;c[240592]=j;c[240594]=0;c[240593]=0;return}function azB(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=b>>>16&255;d=957128+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[a>>2]|h;c[a>>2]=b;c[240591]=b>>>24;c[240592]=b;c[240594]=0;c[240593]=0;return}function azC(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=d+2|0;f=962260+(((c[240587]|0)>>>9&7)<<2)|0;g=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]<<16|c[f>>2];c[f>>2]=g;c[240591]=g>>>24;c[240592]=g;c[240594]=0;c[240593]=0;return}function azD(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=d+2|0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16|c[a>>2];c[a>>2]=b;c[240591]=b>>>24;c[240592]=b;c[240594]=0;c[240593]=0;return}function azE(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+4;b=a+2|0;d=962260+(((c[240587]|0)>>>9&7)<<2)|0;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16|c[d>>2];c[d>>2]=f;c[240591]=f>>>24;c[240592]=f;c[240594]=0;c[240593]=0;return}function azF(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[a>>2]|i;c[a>>2]=b;c[240591]=b>>>24;c[240592]=b;c[240594]=0;c[240593]=0;return}function azG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]<<16;k=a;l=k>>>9;m=l&7;n=962260+(m<<2)|0;o=c[n>>2]|0;p=o|j;c[n>>2]=p;q=p>>>24;c[240591]=q;c[240592]=p;c[240594]=0;c[240593]=0;return}else{a=(fl[h&255](g&16777215)|0)<<16;h=fl[c[f>>2]&255](g+2&16777215)|0|a;j=h;k=c[240587]|0;l=k>>>9;m=l&7;n=962260+(m<<2)|0;o=c[n>>2]|0;p=o|j;c[n>>2]=p;q=p>>>24;c[240591]=q;c[240592]=p;c[240594]=0;c[240593]=0;return}}function azH(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=957128+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=962260+(l<<2)|0;n=c[m>>2]|0;o=n|i;c[m>>2]=o;p=o>>>24;c[240591]=p;c[240592]=o;c[240594]=0;c[240593]=0;return}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[240587]|0;k=j>>>9;l=k&7;m=962260+(l<<2)|0;n=c[m>>2]|0;o=n|i;c[m>>2]=o;p=o>>>24;c[240591]=p;c[240592]=o;c[240594]=0;c[240593]=0;return}}function azI(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[a>>2]|i;c[a>>2]=d;c[240591]=d>>>24;c[240592]=d;c[240594]=0;c[240593]=0;return}function azJ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;f=b&255;b=957128+(f*20|0)|0;g=c[b>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+a>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[b>>2]&255](d+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[a>>2]|i;c[a>>2]=d;c[240591]=d>>>24;c[240592]=d;c[240594]=0;c[240593]=0;return}function azK(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=d&65535;if((a|0)==0){c[240594]=0;aH3(5);return}e=c[b>>2]|0;f=(e>>>0)/(a>>>0)|0;if(f>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}g=d<<16;d=e;h=0;i=152;while(1){j=d<<1;do{if((d|0)<0){k=i;l=j-g|0}else{if(j>>>0<g>>>0){k=i+8|0;l=j;break}k=i+4|0;l=j-g|0}}while(0);j=h+1|0;if((j|0)<15){d=l;h=j;i=k}else{break}}c[240563]=(c[240563]|0)+(k<<1);c[240592]=f;c[240591]=f>>>8;c[240593]=0;c[240594]=0;c[b>>2]=((e>>>0)%(a>>>0)|0)<<16|f&65535;return}function azL(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}if((g|0)==0){c[240594]=0;aH3(5);return}d=c[b>>2]|0;f=(d>>>0)/(g>>>0)|0;if(f>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}a=g<<16;h=d;i=0;j=152;while(1){k=h<<1;do{if((h|0)<0){l=j;m=k-a|0}else{if(k>>>0<a>>>0){l=j+8|0;m=k;break}l=j+4|0;m=k-a|0}}while(0);k=i+1|0;if((k|0)<15){h=m;i=k;j=l}else{break}}c[240563]=(c[240563]|0)+(l<<1);c[240592]=f;c[240591]=f>>>8;c[240593]=0;c[240594]=0;c[b>>2]=((d>>>0)%(g>>>0)|0)<<16|f&65535;return}function azM(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}if((g|0)==0){c[240594]=0;aH3(5);return}a=c[b>>2]|0;f=(a>>>0)/(g>>>0)|0;if(f>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}d=g<<16;h=a;i=0;j=152;while(1){k=h<<1;do{if((h|0)<0){l=j;m=k-d|0}else{if(k>>>0<d>>>0){l=j+8|0;m=k;break}l=j+4|0;m=k-d|0}}while(0);k=i+1|0;if((k|0)<15){h=m;i=k;j=l}else{break}}c[240563]=(c[240563]|0)+(l<<1);c[240592]=f;c[240591]=f>>>8;c[240593]=0;c[240594]=0;c[b>>2]=((a>>>0)%(g>>>0)|0)<<16|f&65535;return}function azN(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}if((g|0)==0){c[240594]=0;aH3(5);return}a=c[b>>2]|0;f=(a>>>0)/(g>>>0)|0;if(f>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}d=g<<16;h=a;i=0;j=152;while(1){k=h<<1;do{if((h|0)<0){l=j;m=k-d|0}else{if(k>>>0<d>>>0){l=j+8|0;m=k;break}l=j+4|0;m=k-d|0}}while(0);k=i+1|0;if((k|0)<15){h=m;i=k;j=l}else{break}}c[240563]=(c[240563]|0)+(l<<1);c[240592]=f;c[240591]=f>>>8;c[240593]=0;c[240594]=0;c[b>>2]=((a>>>0)%(g>>>0)|0)<<16|f&65535;return}function azO(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=(a&15)-(d&15)-((c[240590]|0)>>>8&1)|0;c[240593]=0;f=(e>>>0>9?e-6|0:e)+((a&240)-(d&240))|0;d=f>>>0>153;a=d?256:0;c[240594]=a;c[240590]=a;c[240591]=d?128:0;a=(d?f+160|0:f)&255;c[240592]=a|c[240592];c[b>>2]=a|c[b>>2]&-256;return}function azP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240587]|0;d=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}if((h|0)==0){c[240594]=0;aH3(5);return}g=c[d>>2]|0;a=(g>>>0)/(h>>>0)|0;if(a>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}f=h<<16;i=g;j=0;k=152;while(1){l=i<<1;do{if((i|0)<0){m=k;n=l-f|0}else{if(l>>>0<f>>>0){m=k+8|0;n=l;break}m=k+4|0;n=l-f|0}}while(0);l=j+1|0;if((l|0)<15){i=n;j=l;k=m}else{break}}c[240563]=(c[240563]|0)+(m<<1);c[240592]=a;c[240591]=a>>>8;c[240593]=0;c[240594]=0;c[d>>2]=((g>>>0)%(h>>>0)|0)<<16|a&65535;return}function azQ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}if((h|0)==0){c[240594]=0;aH3(5);return}a=c[b>>2]|0;d=(a>>>0)/(h>>>0)|0;if(d>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}g=h<<16;f=a;i=0;j=152;while(1){k=f<<1;do{if((f|0)<0){l=j;m=k-g|0}else{if(k>>>0<g>>>0){l=j+8|0;m=k;break}l=j+4|0;m=k-g|0}}while(0);k=i+1|0;if((k|0)<15){f=m;i=k;j=l}else{break}}c[240563]=(c[240563]|0)+(l<<1);c[240592]=d;c[240591]=d>>>8;c[240593]=0;c[240594]=0;c[b>>2]=((a>>>0)%(h>>>0)|0)<<16|d&65535;return}function azR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}if((h|0)==0){c[240594]=0;aH3(5);return}f=c[a>>2]|0;g=(f>>>0)/(h>>>0)|0;if(g>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}d=h<<16;i=f;j=0;k=152;while(1){l=i<<1;do{if((i|0)<0){m=k;n=l-d|0}else{if(l>>>0<d>>>0){m=k+8|0;n=l;break}m=k+4|0;n=l-d|0}}while(0);l=j+1|0;if((l|0)<15){i=n;j=l;k=m}else{break}}c[240563]=(c[240563]|0)+(m<<1);c[240592]=g;c[240591]=g>>>8;c[240593]=0;c[240594]=0;c[a>>2]=((f>>>0)%(h>>>0)|0)<<16|g&65535;return}function azS(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+b>>1]|0}else{h=fl[g&255](b|d<<16&16711680)|0}if((h|0)==0){c[240594]=0;aH3(5);return}d=c[a>>2]|0;b=(d>>>0)/(h>>>0)|0;if(b>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}g=h<<16;f=d;i=0;j=152;while(1){k=f<<1;do{if((f|0)<0){l=j;m=k-g|0}else{if(k>>>0<g>>>0){l=j+8|0;m=k;break}l=j+4|0;m=k-g|0}}while(0);k=i+1|0;if((k|0)<15){f=m;i=k;j=l}else{break}}c[240563]=(c[240563]|0)+(l<<1);c[240592]=b;c[240591]=b>>>8;c[240593]=0;c[240594]=0;c[a>>2]=((d>>>0)%(h>>>0)|0)<<16|b&65535;return}function azT(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=d&65535;if(d<<16>>16==0){c[240594]=0;aH3(5);return}d=c[a>>2]|0;f=(d>>>0)/(e>>>0)|0;if(f>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}g=e<<16;h=d;i=0;j=152;while(1){k=h<<1;do{if((h|0)<0){l=j;m=k-g|0}else{if(k>>>0<g>>>0){l=j+8|0;m=k;break}l=j+4|0;m=k-g|0}}while(0);k=i+1|0;if((k|0)<15){h=m;i=k;j=l}else{break}}c[240563]=(c[240563]|0)+(l<<1);c[240592]=f;c[240591]=f>>>8;c[240593]=0;c[240594]=0;c[a>>2]=((d>>>0)%(e>>>0)|0)<<16|f&65535;return}function azU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;if(h<<16>>16==0){c[240594]=0;aH3(5);return}h=c[a>>2]|0;d=(h>>>0)/(g>>>0)|0;if(d>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}f=g<<16;i=h;j=0;k=152;while(1){l=i<<1;do{if((i|0)<0){m=k;n=l-f|0}else{if(l>>>0<f>>>0){m=k+8|0;n=l;break}m=k+4|0;n=l-f|0}}while(0);l=j+1|0;if((l|0)<15){i=n;j=l;k=m}else{break}}c[240563]=(c[240563]|0)+(m<<1);c[240592]=d;c[240591]=d>>>8;c[240593]=0;c[240594]=0;c[a>>2]=((h>>>0)%(g>>>0)|0)<<16|d&65535;return}function azV(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&65535;if(e<<16>>16==0){c[240594]=0;aH3(5);return}e=c[a>>2]|0;f=(e>>>0)/(d>>>0)|0;if(f>>>0>=65536){c[240563]=(c[240563]|0)+70;c[240593]=128;c[240591]=128;c[240594]=0;return}g=d<<16;h=e;i=0;j=152;while(1){k=h<<1;do{if((h|0)<0){l=j;m=k-g|0}else{if(k>>>0<g>>>0){l=j+8|0;m=k;break}l=j+4|0;m=k-g|0}}while(0);k=i+1|0;if((k|0)<15){h=m;i=k;j=l}else{break}}c[240563]=(c[240563]|0)+(l<<1);c[240592]=f;c[240591]=f>>>8;c[240593]=0;c[240594]=0;c[a>>2]=((e>>>0)%(d>>>0)|0)<<16|f&65535;return}function azW(){var b=0,e=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;b=c[957124+(e*20|0)>>2]|0;if((b|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[b&255](f&16777215)|0}b=(h&15)-(g&15)-((c[240590]|0)>>>8&1)|0;c[240593]=0;i=(b>>>0>9?b-6|0:b)+((h&240)-(g&240))|0;g=i>>>0>153;h=g?256:0;b=g?i+160|0:i;c[240594]=h;c[240590]=h;c[240591]=g?128:0;g=b&255;c[240592]=g|c[240592];h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[h&511](f&16777215,g);return}}function azX(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[e&255](f&16777215)|0}e=(h&15)-(g&15)-((c[240590]|0)>>>8&1)|0;c[240593]=0;i=(e>>>0>9?e-6|0:e)+((h&240)-(g&240))|0;g=i>>>0>153;h=g?256:0;e=g?i+160|0:i;c[240594]=h;c[240590]=h;c[240591]=g?128:0;g=e&255;c[240592]=g|c[240592];h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[h&511](f&16777215,g);return}}function azY(){var b=0,e=0,f=0,g=0,h=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=c[962260+((b>>>9&7)<<2)>>2]|0;b=e>>>16&255;g=c[957124+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h|f;f=g&255;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[h&511](e&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function azZ(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h|b;b=g&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}else{fj[h&511](e&16777215,b);c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}}function az_(){var b=0,e=0,f=0,g=0,h=0;b=c[240580]|0;c[240580]=b+2;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h|e;e=g&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}else{fj[h&511](b&16777215,e);c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}}function az$(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h|b;b=g&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}else{fj[h&511](e&16777215,b);c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}}function az0(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h|e;e=g&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}else{fj[h&511](b&16777215,e);c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}}function az1(){var e=0,f=0,g=0,h=0,i=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=c[962260+((e>>>9&7)<<2)>>2]|0;e=h>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[g&255](h&16777215)|0}g=i|f;f=g&255;i=c[957132+(e*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(h&65535^1)|0]=g&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[i&511](h&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function az2(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=c[962260+((b>>>9&7)<<2)>>2]|0;b=g>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j|i;i=f&255;j=c[957132+(b*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]=f&255;c[240591]=i;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[j&511](g&16777215,i);c[240591]=i;c[240592]=i;c[240594]=0;c[240593]=0;return}}function az3(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[h&255](f&16777215)|0}h=i|e;e=h&255;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}else{fj[i&511](f&16777215,e);c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}}function az4(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;i=f&255;f=c[957124+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(b^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j|h;h=f&255;j=c[957132+(i*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(b^1)|0]=f&255;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[j&511](g&16777215,h);c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}}function az5(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7)<<2)>>2]|0;a=d>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h|f;f=g&65535;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=f>>>8;c[240591]=i;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[h&511](d&16777215,f);i=f>>>8;c[240591]=i;c[240592]=f;c[240594]=0;c[240593]=0;return}}function az6(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h|a;a=g&65535;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}else{fj[h&511](d&16777215,a);i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}}function az7(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h|a;a=g&65535;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}else{fj[h&511](d&16777215,a);i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}}function az8(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=g>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[f&255](g&16777215)|0}f=h|d;d=f&65535;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=f&65535;i=d>>>8;c[240591]=i;c[240592]=d;c[240594]=0;c[240593]=0;return}else{fj[h&511](g&16777215,d);i=d>>>8;c[240591]=i;c[240592]=d;c[240594]=0;c[240593]=0;return}}function az9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[962260+((a>>>9&7)<<2)>>2]|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{i=fl[d&255](f&16777215)|0}d=i|h;h=d&65535;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;j=h>>>8;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[i&511](f&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}}function aAa(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h|a;a=g&65535;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}else{fj[h&511](d&16777215,a);i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}}function aAb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;h=d&255;d=c[957128+(h*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0}else{i=fl[d&255](f&16777215)|0}d=i|g;g=d&65535;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=d&65535;j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[i&511](f&16777215,g);j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}}function aAc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7)<<2)>>2]|0;a=d>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j|f;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[f&511](d&16777215,i>>>16)}f=d+2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[a&511](f&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aAd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j|a;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[a&511](d&16777215,i>>>16)}a=d+2|0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[f&511](a&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aAe(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=957128+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[h>>2]&255](d+16777214&16777215)|0|j}j=k|a;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[a&511](f&16777215,j>>>16)}f=d-2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=j&65535;l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}else{fj[a&511](f&16777215,j&65535);l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}}function aAf(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=g>>>16&255;f=957128+(a*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]<<16}else{i=(fl[h&255](g&16777215)|0)<<16;j=fl[c[f>>2]&255](g+2&16777215)|0|i}i=j|d;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i>>>16&65535}else{fj[d&511](g&16777215,i>>>16)}d=g+2|0;g=d>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[a&511](d&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aAg(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[962260+((a>>>9&7)<<2)>>2]|0;a=f>>>16&255;d=957128+(a*20|0)|0;g=c[d>>2]|0;if((g|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{i=(fl[g&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|i}i=j|h;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[h&511](f&16777215,i>>>16)}h=f+2|0;f=h>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[a&511](h&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aAh(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j|a;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[a&511](d&16777215,i>>>16)}a=d+2|0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[f&511](a&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aAi(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;h=d&255;d=957128+(h*20|0)|0;i=c[d>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[d>>2]&255](f+2&16777215)|0|j}j=k|g;g=c[957136+(h*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[g&511](f&16777215,j>>>16)}g=f+2|0;f=g>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=j&65535;l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}else{fj[a&511](g&16777215,j&65535);l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}}function aAj(){var a=0,b=0,d=0,e=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]<<16>>16;if((d|0)==0){c[240594]=0;aH3(5);return}aH$(c[b>>2]|0,d&65535);a=c[b>>2]|0;if((a|0)==-2147483648&(d|0)==-1){aIv(962364,0,16);c[b>>2]=0;return}e=(a|0)/(d|0)|0;if((e|0)==(e<<16>>16|0)){c[240592]=e;c[240591]=e>>8;c[240593]=0;c[240594]=0;c[b>>2]=((a|0)%(d|0)|0)<<16|e&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAk(){var a=0,b=0,d=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=g<<16>>16;if((d|0)==0){c[240594]=0;aH3(5);return}aH$(c[b>>2]|0,d&65535);g=c[b>>2]|0;if((g|0)==-2147483648&(d|0)==-1){aIv(962364,0,16);c[b>>2]=0;return}f=(g|0)/(d|0)|0;if((f|0)==(f<<16>>16|0)){c[240592]=f;c[240591]=f>>8;c[240593]=0;c[240594]=0;c[b>>2]=((g|0)%(d|0)|0)<<16|f&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAl(){var a=0,b=0,d=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=g<<16>>16;if((a|0)==0){c[240594]=0;aH3(5);return}aH$(c[b>>2]|0,a&65535);g=c[b>>2]|0;if((g|0)==-2147483648&(a|0)==-1){aIv(962364,0,16);c[b>>2]=0;return}f=(g|0)/(a|0)|0;if((f|0)==(f<<16>>16|0)){c[240592]=f;c[240591]=f>>8;c[240593]=0;c[240594]=0;c[b>>2]=((g|0)%(a|0)|0)<<16|f&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAm(){var a=0,b=0,d=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=g<<16>>16;if((a|0)==0){c[240594]=0;aH3(5);return}aH$(c[b>>2]|0,a&65535);g=c[b>>2]|0;if((g|0)==-2147483648&(a|0)==-1){aIv(962364,0,16);c[b>>2]=0;return}f=(g|0)/(a|0)|0;if((f|0)==(f<<16>>16|0)){c[240592]=f;c[240591]=f>>8;c[240593]=0;c[240594]=0;c[b>>2]=((g|0)%(a|0)|0)<<16|f&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAn(){var a=0,d=0,f=0,g=0,h=0;a=c[240587]|0;d=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}g=h<<16>>16;if((g|0)==0){c[240594]=0;aH3(5);return}aH$(c[d>>2]|0,g&65535);h=c[d>>2]|0;if((h|0)==-2147483648&(g|0)==-1){aIv(962364,0,16);c[d>>2]=0;return}a=(h|0)/(g|0)|0;if((a|0)==(a<<16>>16|0)){c[240592]=a;c[240591]=a>>8;c[240593]=0;c[240594]=0;c[d>>2]=((h|0)%(g|0)|0)<<16|a&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAo(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=h<<16>>16;if((a|0)==0){c[240594]=0;aH3(5);return}aH$(c[b>>2]|0,a&65535);h=c[b>>2]|0;if((h|0)==-2147483648&(a|0)==-1){aIv(962364,0,16);c[b>>2]=0;return}d=(h|0)/(a|0)|0;if((d|0)==(d<<16>>16|0)){c[240592]=d;c[240591]=d>>8;c[240593]=0;c[240594]=0;c[b>>2]=((h|0)%(a|0)|0)<<16|d&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAp(){var a=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}f=h<<16>>16;if((f|0)==0){c[240594]=0;aH3(5);return}aH$(c[a>>2]|0,f&65535);h=c[a>>2]|0;if((h|0)==-2147483648&(f|0)==-1){aIv(962364,0,16);c[a>>2]=0;return}g=(h|0)/(f|0)|0;if((g|0)==(g<<16>>16|0)){c[240592]=g;c[240591]=g>>8;c[240593]=0;c[240594]=0;c[a>>2]=((h|0)%(f|0)|0)<<16|g&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAq(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+b>>1]|0}else{h=fl[g&255](b|d<<16&16711680)|0}d=h<<16>>16;if((d|0)==0){c[240594]=0;aH3(5);return}aH$(c[a>>2]|0,d&65535);h=c[a>>2]|0;if((h|0)==-2147483648&(d|0)==-1){aIv(962364,0,16);c[a>>2]=0;return}b=(h|0)/(d|0)|0;if((b|0)==(b<<16>>16|0)){c[240592]=b;c[240591]=b>>8;c[240593]=0;c[240594]=0;c[a>>2]=((h|0)%(d|0)|0)<<16|b&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAr(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=d&255;e=c[b>>2]|0;f=e&255;g=f-a|0;c[240591]=g;c[240594]=g;c[240590]=g;c[240593]=(g^e)&(f^a);a=e-d&255;c[240592]=a;c[b>>2]=c[b>>2]&-256|a;return}function aAs(){var a=0,d=0,e=0,f=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=d<<16>>16;if(d<<16>>16==0){c[240594]=0;aH3(5);return}aH$(c[a>>2]|0,d);f=c[a>>2]|0;if((f|0)==-2147483648&d<<16>>16==-1){aIv(962364,0,16);c[a>>2]=0;return}d=(f|0)/(e|0)|0;if((d|0)==(d<<16>>16|0)){c[240592]=d;c[240591]=d>>8;c[240593]=0;c[240594]=0;c[a>>2]=((f|0)%(e|0)|0)<<16|d&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAt(){var a=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h<<16>>16;if(h<<16>>16==0){c[240594]=0;aH3(5);return}aH$(c[a>>2]|0,h);d=c[a>>2]|0;if((d|0)==-2147483648&h<<16>>16==-1){aIv(962364,0,16);c[a>>2]=0;return}h=(d|0)/(g|0)|0;if((h|0)==(h<<16>>16|0)){c[240592]=h;c[240591]=h>>8;c[240593]=0;c[240594]=0;c[a>>2]=((d|0)%(g|0)|0)<<16|h&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAu(){var a=0,d=0,e=0,f=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e<<16>>16;if(e<<16>>16==0){c[240594]=0;aH3(5);return}aH$(c[a>>2]|0,e);f=c[a>>2]|0;if((f|0)==-2147483648&e<<16>>16==-1){aIv(962364,0,16);c[a>>2]=0;return}e=(f|0)/(d|0)|0;if((e|0)==(e<<16>>16|0)){c[240592]=e;c[240591]=e>>8;c[240593]=0;c[240594]=0;c[a>>2]=((f|0)%(d|0)|0)<<16|e&65535;return}else{c[240593]=128;c[240591]=128;c[240594]=0;return}}function aAv(){var b=0,e=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[240580]|0)-2|0;c[240580]=e;f=e>>>16&255;b=c[957124+(f*20|0)>>2]|0;if((b|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[b&255](e&16777215)|0}b=(h&15)-(g&15)-((c[240590]|0)>>>8&1)|0;c[240593]=0;i=(b>>>0>9?b-6|0:b)+((h&240)-(g&240))|0;g=i>>>0>153;h=g?256:0;b=g?i+160|0:i;c[240594]=h;c[240590]=h;c[240591]=g?128:0;g=b&255;c[240592]=g|c[240592];h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[h&511](e&16777215,g);return}}function aAw(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[240580]|0}e=h-2|0;c[240580]=e;h=e>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[b&255](e&16777215)|0}b=(i&15)-(g&15)-((c[240590]|0)>>>8&1)|0;c[240593]=0;f=(b>>>0>9?b-6|0:b)+((i&240)-(g&240))|0;g=f>>>0>153;i=g?256:0;b=g?f+160|0:f;c[240594]=i;c[240590]=i;c[240591]=g?128:0;g=b&255;c[240592]=g|c[240592];i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[i&511](e&16777215,g);return}}function aAx(){var a=0,b=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;e=c[962260+((a&7|8)<<2)>>2]|0;a=e>>>16&255;f=c[957124+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[b>>2]|0;f=e&255;a=f-g|0;c[240591]=a;c[240594]=a;c[240590]=a;c[240593]=(a^f)&(f^g);f=e-g&255;c[240592]=f;c[b>>2]=c[b>>2]&-256|f;return}function aAy(){var a=0,b=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;e=962260+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+1;e=a>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(a&65535^1)|0]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;e=f-g|0;c[240591]=e;c[240594]=e;c[240590]=e;c[240593]=(e^f)&(f^g);f=a-g&255;c[240592]=f;c[b>>2]=c[b>>2]&-256|f;return}function aAz(){var a=0,b=0,e=0,f=0,g=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[a>>2]|0;f=b&255;e=f-g|0;c[240591]=e;c[240594]=e;c[240590]=e;c[240593]=(e^f)&(f^g);f=b-g&255;c[240592]=f;c[a>>2]=c[a>>2]&-256|f;return}function aAA(){var a=0,b=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;e=962260+((a&7|8)<<2)|0;a=(c[e>>2]|0)-1|0;c[e>>2]=a;e=a>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(a&65535^1)|0]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;e=f-g|0;c[240591]=e;c[240594]=e;c[240590]=e;c[240593]=(e^f)&(f^g);f=a-g&255;c[240592]=f;c[b>>2]=c[b>>2]&-256|f;return}function aAB(){var a=0,b=0,e=0,f=0,g=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[a>>2]|0;f=b&255;e=f-g|0;c[240591]=e;c[240594]=e;c[240590]=e;c[240593]=(e^f)&(f^g);f=b-g&255;c[240592]=f;c[a>>2]=c[a>>2]&-256|f;return}function aAC(){var a=0,e=0,f=0,g=0,h=0;a=c[240587]|0;e=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957124+(f*20|0)>>2]|0;if((a|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[a&255](g&16777215)|0}g=c[e>>2]|0;a=g&255;f=a-h|0;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=(f^a)&(a^h);a=g-h&255;c[240592]=a;c[e>>2]=c[e>>2]&-256|a;return}function aAD(){var a=0,b=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=a>>>16&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(a&65535^1)|0]|0}else{i=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;h=f-i|0;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=(h^f)&(f^i);f=a-i&255;c[240592]=f;c[b>>2]=c[b>>2]&-256|f;return}function aAE(){var a=0,e=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[a>>2]|0;g=f&255;e=g-h|0;c[240591]=e;c[240594]=e;c[240590]=e;c[240593]=(e^g)&(g^h);g=f-h&255;c[240592]=g;c[a>>2]=c[a>>2]&-256|g;return}function aAF(){var a=0,e=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+e|0;e=d[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=c[a>>2]|0;g=f&255;h=g-e|0;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=(h^f)&(g^e);g=f-e&255;c[240592]=g;c[a>>2]=c[a>>2]&-256|g;return}function aAG(){var a=0,b=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+b+h|0;h=d[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=c[a>>2]|0;b=g&255;f=b-h|0;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=(f^g)&(b^h);b=g-h&255;c[240592]=b;c[a>>2]=c[a>>2]&-256|b;return}function aAH(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=d&255;f=c[a>>2]|0;g=f&255;h=g-b|0;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=(h^f)&(b^g);g=f-d&255;c[240592]=g;c[a>>2]=c[a>>2]&-256|g;return}function aAI(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f-a|0;h=g>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=((g^e)&(f^a))>>>8;a=e-d&65535;c[240592]=a;c[b>>2]=c[b>>2]&-65536|a;return}function aAJ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f-a|0;h=g>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=((g^e)&(f^a))>>>8;a=e-d&65535;c[240592]=a;c[b>>2]=c[b>>2]&-65536|a;return}function aAK(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[a>>2]|0;g=f&65535;h=g-d|0;i=h>>>8;c[240591]=i;c[240594]=i;c[240590]=i;c[240593]=((h^f)&(g^d))>>>8;g=f-d&65535;c[240592]=g;c[a>>2]=c[a>>2]&-65536|g;return}function aAL(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[a>>2]|0;b=f&65535;d=b-g|0;h=d>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=((d^f)&(b^g))>>>8;b=f-g&65535;c[240592]=b;c[a>>2]=c[a>>2]&-65536|b;return}function aAM(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[a>>2]|0;f=b&65535;g=f-d|0;h=g>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=((g^b)&(f^d))>>>8;f=b-d&65535;c[240592]=f;c[a>>2]=c[a>>2]&-65536|f;return}function aAN(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a-d|0;c[240591]=e>>>24;f=((e|d)&(a^-8388608)|e&d)>>>23;c[240594]=f;c[240590]=f;c[240593]=((e^a)&(a^d))>>>24;c[240592]=e;c[b>>2]=e;return}function aAO(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[b>>2]|0;e=a-d|0;c[240591]=e>>>24;f=((e|d)&(a^-8388608)|e&d)>>>23;c[240594]=f;c[240590]=f;c[240593]=((e^a)&(a^d))>>>24;c[240592]=e;c[b>>2]=e;return}function aAP(){var a=0,b=0,f=0,g=0,h=0,i=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=c[a>>2]|0;b=f&255;h=b-i|0;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=(h^b)&(b^i);b=f-i&255;c[240592]=b;c[a>>2]=c[a>>2]&-256|b;return}function aAQ(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[b>>2]|0;f=d&65535;a=f-g|0;h=a>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=((a^f)&(f^g))>>>8;f=d-g&65535;c[240592]=f;c[b>>2]=c[b>>2]&-65536|f;return}function aAR(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&65535;d=f-g|0;h=d>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=((d^f)&(f^g))>>>8;f=a-g&65535;c[240592]=f;c[b>>2]=c[b>>2]&-65536|f;return}function aAS(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&65535;d=f-g|0;h=d>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=((d^f)&(f^g))>>>8;f=a-g&65535;c[240592]=f;c[b>>2]=c[b>>2]&-65536|f;return}function aAT(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}g=c[d>>2]|0;a=g&65535;f=a-h|0;i=f>>>8;c[240591]=i;c[240594]=i;c[240590]=i;c[240593]=((f^a)&(a^h))>>>8;a=g-h&65535;c[240592]=a;c[d>>2]=c[d>>2]&-65536|a;return}function aAU(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=c[b>>2]|0;d=a&65535;g=d-h|0;f=g>>>8;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=((g^d)&(d^h))>>>8;d=a-h&65535;c[240592]=d;c[b>>2]=c[b>>2]&-65536|d;return}function aAV(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}f=c[a>>2]|0;g=f&65535;d=g-h|0;i=d>>>8;c[240591]=i;c[240594]=i;c[240590]=i;c[240593]=((d^g)&(g^h))>>>8;g=f-h&65535;c[240592]=g;c[a>>2]=c[a>>2]&-65536|g;return}function aAW(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+b>>1]|0}else{h=fl[g&255](b|d<<16&16711680)|0}d=c[a>>2]|0;b=d&65535;g=b-h|0;f=g>>>8;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=((g^b)&(b^h))>>>8;b=d-h&65535;c[240592]=b;c[a>>2]=c[a>>2]&-65536|b;return}function aAX(){var a=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]<<16;g=f+2|0;f=c[a>>2]|0;h=f-(e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|d)|0;c[240591]=h>>>24;g=((h|d)&(f^-8388608)|h&d)>>>23;c[240594]=g;c[240590]=g;c[240593]=((h^f)&(f^d))>>>24;c[240592]=h;c[a>>2]=h;return}function aAY(){var a=0,b=0,d=0,f=0,g=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;b=f+2|0;f=c[a>>2]|0;d=f-(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|g)|0;c[240591]=d>>>24;b=((d|g)&(f^-8388608)|d&g)>>>23;c[240594]=b;c[240590]=b;c[240593]=((d^f)&(f^g))>>>24;c[240592]=d;c[a>>2]=d;return}function aAZ(){var a=0,b=0,d=0,f=0,g=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;f=b+2|0;b=c[a>>2]|0;g=b-(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d)|0;c[240591]=g>>>24;f=((g|d)&(b^-8388608)|g&d)>>>23;c[240594]=f;c[240590]=f;c[240593]=((g^b)&(b^d))>>>24;c[240592]=g;c[a>>2]=g;return}function aA_(){var a=0,b=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[962260+((a&7)<<2)>>2]<<16>>16);return}function aA$(){var a=0,b=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[962260+((a&7|8)<<2)>>2]<<16>>16);return}function aA0(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[b>>2]|0;d=a-i|0;c[240591]=d>>>24;f=((d|i)&(a^-8388608)|d&i)>>>23;c[240594]=f;c[240590]=f;c[240593]=((d^a)&(a^i))>>>24;c[240592]=d;c[b>>2]=d;return}function aA1(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+4;d=a>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{d=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|d}d=c[b>>2]|0;a=d-i|0;c[240591]=a>>>24;f=((a|i)&(d^-8388608)|a&i)>>>23;c[240594]=f;c[240590]=f;c[240593]=((a^d)&(d^i))>>>24;c[240592]=a;c[b>>2]=a;return}function aA2(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;f=a-4|0;c[d>>2]=f;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](a+16777214&16777215)|0|d}d=c[b>>2]|0;a=d-j|0;c[240591]=a>>>24;g=((a|j)&(d^-8388608)|a&j)>>>23;c[240594]=g;c[240590]=g;c[240593]=((a^d)&(d^j))>>>24;c[240592]=a;c[b>>2]=a;return}function aA3(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=957128+(f*20|0)|0;h=c[a>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]<<16}else{f=(fl[h&255](g&16777215)|0)<<16;j=fl[c[a>>2]&255](g+2&16777215)|0|f}f=c[d>>2]|0;g=f-j|0;c[240591]=g>>>24;a=((g|j)&(f^-8388608)|g&j)>>>23;c[240594]=a;c[240590]=a;c[240593]=((g^f)&(f^j))>>>24;c[240592]=g;c[d>>2]=g;return}function aA4(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=957128+(g*20|0)|0;f=c[d>>2]|0;if((f|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{g=(fl[f&255](a&16777215)|0)<<16;i=fl[c[d>>2]&255](a+2&16777215)|0|g}g=c[b>>2]|0;a=g-i|0;c[240591]=a>>>24;d=((a|i)&(g^-8388608)|a&i)>>>23;c[240594]=d;c[240590]=d;c[240593]=((a^g)&(g^i))>>>24;c[240592]=a;c[b>>2]=a;return}function aA5(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]<<16}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](f+2&16777215)|0|d}d=c[a>>2]|0;f=d-j|0;c[240591]=f>>>24;g=((f|j)&(d^-8388608)|f&j)>>>23;c[240594]=g;c[240590]=g;c[240593]=((f^d)&(d^j))>>>24;c[240592]=f;c[a>>2]=f;return}function aA6(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;g=d&255;d=957128+(g*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+b>>1]|0)<<16}else{b=(fl[h&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|b}b=c[a>>2]|0;f=b-j|0;c[240591]=f>>>24;d=((f|j)&(b^-8388608)|f&j)>>>23;c[240594]=d;c[240590]=d;c[240593]=((f^b)&(b^j))>>>24;c[240592]=f;c[a>>2]=f;return}function aA7(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{g=fl[f&255](d&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function aA8(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{g=fl[f&255](a&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function aA9(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=962260+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{g=fl[f&255](a&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function aBa(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;d=962260+((a>>>9&7|8)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0;i=h<<16;j=i>>16;k=c[d>>2]|0;l=k-j|0;c[d>>2]=l;return}else{h=fl[a&255](g&16777215)|0;i=h<<16;j=i>>16;k=c[d>>2]|0;l=k-j|0;c[d>>2]=l;return}}function aBb(){var a=0,d=0,e=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;c[a>>2]=(c[a>>2]|0)-(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0);return}function aBc(){var a=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;c[a>>2]=(c[a>>2]|0)-(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0);return}function aBd(){var a=0,d=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;c[a>>2]=(c[a>>2]|0)-(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0);return}function aBe(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]&255;a=c[b>>2]|0;e=a&255;f=e-d-((c[240590]|0)>>>8&1)|0;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=(f^a)&(e^d);d=f&255;c[240592]=d|c[240592];c[b>>2]=d|c[b>>2]&-256;return}function aBf(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0;i=h<<16;j=i>>16;k=c[b>>2]|0;l=k-j|0;c[b>>2]=l;return}else{h=fl[d&255](a&16777215)|0;i=h<<16;j=i>>16;k=c[b>>2]|0;l=k-j|0;c[b>>2]=l;return}}function aBg(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}else{h=fl[g&255](f&16777215)|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}}function aBh(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+b>>1]|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}else{h=fl[g&255](b|d<<16&16711680)|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}}function aBi(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;b=c[957124+(e*20|0)>>2]|0;if((b|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[b&255](f&16777215)|0}b=h-g-((c[240590]|0)>>>8&1)|0;c[240591]=b;c[240594]=b;c[240590]=b;c[240593]=(b^h)&(h^g);g=b&255;c[240592]=g|c[240592];h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[h&511](f&16777215,g);return}}function aBj(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[e&255](f&16777215)|0}e=h-g-((c[240590]|0)>>>8&1)|0;c[240591]=e;c[240594]=e;c[240590]=e;c[240593]=(e^h)&(h^g);g=e&255;c[240592]=g|c[240592];h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[h&511](f&16777215,g);return}}function aBk(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=c[962260+((b>>>9&7)<<2)>>2]&255;b=e>>>16&255;g=c[957124+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h-f|0;c[240591]=g;i=g&255;c[240592]=i;c[240594]=g;c[240590]=g;c[240593]=(g^h)&(h^f);f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[f&511](e&16777215,i);return}}function aBl(){var b=0,e=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&255;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h-b|0;c[240591]=g;i=g&255;c[240592]=i;c[240594]=g;c[240590]=g;c[240593]=(g^h)&(h^b);b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,i);return}}function aBm(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240580]|0;c[240580]=b+2;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&255;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h-e|0;c[240591]=g;i=g&255;c[240592]=i;c[240594]=g;c[240590]=g;c[240593]=(g^h)&(h^e);e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,i);return}}function aBn(){var b=0,e=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&255;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h-b|0;c[240591]=g;i=g&255;c[240592]=i;c[240594]=g;c[240590]=g;c[240593]=(g^h)&(h^b);b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,i);return}}function aBo(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[240580]|0)-2|0;c[240580]=b;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&255;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h-e|0;c[240591]=g;i=g&255;c[240592]=i;c[240594]=g;c[240590]=g;c[240593]=(g^h)&(h^e);e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,i);return}}function aBp(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=c[962260+((e>>>9&7)<<2)>>2]&255;e=h>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[g&255](h&16777215)|0}g=i-f|0;c[240591]=g;j=g&255;c[240592]=j;c[240594]=g;c[240590]=g;c[240593]=(g^i)&(i^f);f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(h&65535^1)|0]=g&255;return}else{fj[f&511](h&16777215,j);return}}function aBq(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]&65535;a=c[b>>2]|0;e=a&65535;f=e-d-((c[240590]|0)>>>8&1)|0;g=f>>>8;c[240591]=g;c[240594]=g;c[240590]=g;c[240593]=((f^a)&(e^d))>>>8;d=f&65535;c[240592]=d|c[240592];c[b>>2]=d|c[b>>2]&-65536;return}function aBr(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a-d-((c[240590]|0)>>>8&1)|0;c[240591]=e>>>24;f=((e|d)&(a^-8388608)|e&d)>>>23;c[240594]=f;c[240590]=f;c[240593]=((e^a)&(a^d))>>>24;c[240592]=e|c[240592];c[b>>2]=e;return}function aBs(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=c[962260+((b>>>9&7)<<2)>>2]&255;b=g>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j-i|0;c[240591]=f;h=f&255;c[240592]=h;c[240594]=f;c[240590]=f;c[240593]=(f^j)&(j^i);i=c[957132+(b*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]=f&255;return}else{fj[i&511](g&16777215,h);return}}function aBt(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&255;g=f>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[h&255](f&16777215)|0}h=i-e|0;c[240591]=h;j=h&255;c[240592]=j;c[240594]=h;c[240590]=h;c[240593]=(h^i)&(i^e);e=c[957132+(g*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[e&511](f&16777215,j);return}}function aBu(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&255;i=f&255;f=c[957124+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(b^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j-h|0;c[240591]=f;k=f&255;c[240592]=k;c[240594]=f;c[240590]=f;c[240593]=(f^j)&(j^h);h=c[957132+(i*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](g&16777215,k);return}}function aBv(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-2|0;c[d>>2]=f;d=f>>>16&255;a=c[957128+(d*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[a&255](f&16777215)|0}a=h-g-((c[240590]|0)>>>8&1)|0;i=a>>>8;c[240591]=i;c[240594]=i;c[240590]=i;c[240593]=((a^h)&(h^g))>>>8;g=a&65535;c[240592]=g|c[240592];h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[h&511](f&16777215,g);return}}function aBw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7)<<2)>>2]&65535;a=d>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h-f|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^f))>>>8;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[f&511](d&16777215,j);return}}function aBx(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&65535;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h-a|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^a))>>>8;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[a&511](d&16777215,j);return}}function aBy(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&65535;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h-a|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^a))>>>8;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[a&511](d&16777215,j);return}}function aBz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[962260+((a>>>9&7)<<2)>>2]&65535;a=g>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[f&255](g&16777215)|0}f=h-d|0;i=f>>>8;c[240591]=i;j=f&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((f^h)&(h^d))>>>8;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=f&65535;return}else{fj[d&511](g&16777215,j);return}}function aBA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[962260+((a>>>9&7)<<2)>>2]&65535;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{i=fl[d&255](f&16777215)|0}d=i-h|0;g=d>>>8;c[240591]=g;j=d&65535;c[240592]=j;c[240594]=g;c[240590]=g;c[240593]=((d^i)&(i^h))>>>8;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[h&511](f&16777215,j);return}}function aBB(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&65535;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h-a|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^a))>>>8;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[a&511](d&16777215,j);return}}function aBC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&65535;h=d&255;d=c[957128+(h*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0}else{i=fl[d&255](f&16777215)|0}d=i-g|0;j=d>>>8;c[240591]=j;k=d&65535;c[240592]=k;c[240594]=j;c[240590]=j;c[240593]=((d^i)&(i^g))>>>8;g=c[957136+(h*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=d&65535;return}else{fj[g&511](f&16777215,k);return}}function aBD(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;a=g>>>16&255;f=957128+(a*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=d-2|0;k=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{i=(fl[h&255](g&16777215)|0)<<16;k=fl[c[f>>2]&255](d+16777214&16777215)|0|i}i=k-j-((c[240590]|0)>>>8&1)|0;c[240591]=i>>>24;f=((i|j)&(k^-8388608)|i&j)>>>23;c[240594]=f;c[240590]=f;c[240593]=((i^k)&(k^j))>>>24;c[240592]=i|c[240592];j=c[957136+(a*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i>>>16&65535}else{fj[j&511](g&16777215,i>>>16)}g=d-2|0;d=g>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[j&511](g&16777215,i&65535);return}}function aBE(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7)<<2)>>2]|0;a=d>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j-f|0;c[240591]=i>>>24;c[240592]=i;g=((i|f)&(j^-8388608)|i&f)>>>23;c[240594]=g;c[240590]=g;c[240593]=((i^j)&(j^f))>>>24;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[f&511](d&16777215,i>>>16)}f=d+2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[a&511](f&16777215,i&65535);return}}function aBF(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j-a|0;c[240591]=i>>>24;c[240592]=i;g=((i|a)&(j^-8388608)|i&a)>>>23;c[240594]=g;c[240590]=g;c[240593]=((i^j)&(j^a))>>>24;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[a&511](d&16777215,i>>>16)}a=d+2|0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[f&511](a&16777215,i&65535);return}}function aBG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=957128+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[h>>2]&255](d+16777214&16777215)|0|j}j=k-a|0;c[240591]=j>>>24;c[240592]=j;h=((j|a)&(k^-8388608)|j&a)>>>23;c[240594]=h;c[240590]=h;c[240593]=((j^k)&(k^a))>>>24;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[a&511](f&16777215,j>>>16)}f=d-2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[a&511](f&16777215,j&65535);return}}function aBH(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=g>>>16&255;f=957128+(a*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]<<16}else{i=(fl[h&255](g&16777215)|0)<<16;j=fl[c[f>>2]&255](g+2&16777215)|0|i}i=j-d|0;c[240591]=i>>>24;c[240592]=i;f=((i|d)&(j^-8388608)|i&d)>>>23;c[240594]=f;c[240590]=f;c[240593]=((i^j)&(j^d))>>>24;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i>>>16&65535}else{fj[d&511](g&16777215,i>>>16)}d=g+2|0;g=d>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[a&511](d&16777215,i&65535);return}}function aBI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[962260+((a>>>9&7)<<2)>>2]|0;a=f>>>16&255;d=957128+(a*20|0)|0;g=c[d>>2]|0;if((g|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{i=(fl[g&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|i}i=j-h|0;c[240591]=i>>>24;c[240592]=i;d=((i|h)&(j^-8388608)|i&h)>>>23;c[240594]=d;c[240590]=d;c[240593]=((i^j)&(j^h))>>>24;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[h&511](f&16777215,i>>>16)}h=f+2|0;f=h>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]=i&65535;return}else{fj[a&511](h&16777215,i&65535);return}}function aBJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j-a|0;c[240591]=i>>>24;c[240592]=i;g=((i|a)&(j^-8388608)|i&a)>>>23;c[240594]=g;c[240590]=g;c[240593]=((i^j)&(j^a))>>>24;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[a&511](d&16777215,i>>>16)}a=d+2|0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[f&511](a&16777215,i&65535);return}}function aBK(){var a=0,b=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[962260+((a&7)<<2)>>2]|0);return}function aBL(){var a=0,b=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[962260+((a&7|8)<<2)>>2]|0);return}function aBM(){var a=0,d=0,f=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=f+2|0;c[a>>2]=(c[a>>2]|0)-(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]<<16);return}function aBN(){var a=0,b=0,d=0,f=0,g=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=f+2|0;c[a>>2]=(c[a>>2]|0)-(e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)<<16);return}function aBO(){var a=0,b=0,d=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=b+2|0;c[a>>2]=(c[a>>2]|0)-(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16);return}function aBP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;h=d&255;d=957128+(h*20|0)|0;i=c[d>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[d>>2]&255](f+2&16777215)|0|j}j=k-g|0;c[240591]=j>>>24;c[240592]=j;d=((j|g)&(k^-8388608)|j&g)>>>23;c[240594]=d;c[240590]=d;c[240593]=((j^k)&(k^g))>>>24;g=c[957136+(h*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[g&511](f&16777215,j>>>16)}g=f+2|0;f=g>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[a&511](g&16777215,j&65535);return}}function aBQ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function aBR(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+4;d=a>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{d=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|d;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function aBS(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;f=a-4|0;c[d>>2]=f;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=c[b>>2]|0;l=k-j|0;c[b>>2]=l;return}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](a+16777214&16777215)|0|d;k=c[b>>2]|0;l=k-j|0;c[b>>2]=l;return}}function aBT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;d=962260+((a>>>9&7|8)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=957128+(f*20|0)|0;h=c[a>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]<<16;k=c[d>>2]|0;l=k-j|0;c[d>>2]=l;return}else{f=(fl[h&255](g&16777215)|0)<<16;j=fl[c[a>>2]&255](g+2&16777215)|0|f;k=c[d>>2]|0;l=k-j|0;c[d>>2]=l;return}}function aBU(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=957128+(g*20|0)|0;f=c[d>>2]|0;if((f|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}else{g=(fl[f&255](a&16777215)|0)<<16;i=fl[c[d>>2]&255](a+2&16777215)|0|g;j=c[b>>2]|0;k=j-i|0;c[b>>2]=k;return}}function aBV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]<<16;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](f+2&16777215)|0|d;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}}function aBW(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;g=d&255;d=957128+(g*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+b>>1]|0)<<16;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}else{b=(fl[h&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|b;k=c[a>>2]|0;l=k-j|0;c[a>>2]=l;return}}function aBX(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[240580]|0)-2|0;c[240580]=e;f=e>>>16&255;b=c[957124+(f*20|0)>>2]|0;if((b|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[b&255](e&16777215)|0}b=h-g-((c[240590]|0)>>>8&1)|0;c[240591]=b;c[240594]=b;c[240590]=b;c[240593]=(b^h)&(h^g);g=b&255;c[240592]=g|c[240592];h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[h&511](e&16777215,g);return}}function aBY(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[240580]|0}e=h-2|0;c[240580]=e;h=e>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[b&255](e&16777215)|0}b=i-g-((c[240590]|0)>>>8&1)|0;c[240591]=b;c[240594]=b;c[240590]=b;c[240593]=(b^i)&(i^g);g=b&255;c[240592]=g|c[240592];i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[i&511](e&16777215,g);return}}function aBZ(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=c[962260+((a&7)<<2)>>2]|0;d=b&255;e=c[962260+((a>>>9&7)<<2)>>2]|0;a=e&255;f=a-d|0;c[240591]=f;c[240592]=e-b&255;c[240593]=(f^e)&(a^d);c[240594]=f;return}function aB_(){var a=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;e=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=d[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=e&255;g=f-a|0;c[240591]=g;c[240592]=e-a&255;c[240593]=(g^e)&(f^a);c[240594]=g;return}function aB$(){var a=0,b=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){g=f<<16>>16}else{g=f}f=(b<<24>>24)+a+g|0;g=d[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;a=f&255;b=a-g|0;c[240591]=b;c[240592]=f-g&255;c[240593]=(b^f)&(a^g);c[240594]=b;return}function aB0(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=b&255;d=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d&255;g=f-a|0;c[240591]=g;c[240592]=d-b&255;c[240593]=(g^d)&(f^a);c[240594]=g;return}function aB1(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=c[962260+((a&7)<<2)>>2]|0;d=b&65535;e=c[962260+((a>>>9&7)<<2)>>2]|0;a=e&65535;f=a-d|0;g=f>>>8;c[240591]=g;c[240592]=e-b&65535;c[240593]=((f^e)&(a^d))>>>8;c[240594]=g;return}function aB2(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b&65535;e=c[962260+((a>>>9&7)<<2)>>2]|0;a=e&65535;f=a-d|0;g=f>>>8;c[240591]=g;c[240592]=e-b&65535;c[240593]=((f^e)&(a^d))>>>8;c[240594]=g;return}function aB3(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[240589]|0;f=d<<11|c[240588]|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;c[240588]=0;c[962328+(d<<2)>>2]=c[240580];c[240589]=4;d=(c[240581]|0)-2|0;g=(c[240586]|0)-4|0;c[240580]=g;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[240580]|0)+2|0;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;d=(c[240580]|0)-2|0;c[240580]=d;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;f=c[239282]|0;if((f|0)==0){d=c[239280]|0;h=e[d+42>>1]|0|(e[d+40>>1]|0)<<16;c[240581]=h;i=c[240587]|0;j=537288+i|0;k=a[j]|0;l=k&255;m=16-l|0;n=c[240563]|0;o=m+n|0;c[240563]=o;return}else{d=(fl[f&255](40)|0)<<16;h=fl[c[239282]&255](42)|0|d;c[240581]=h;i=c[240587]|0;j=537288+i|0;k=a[j]|0;l=k&255;m=16-l|0;n=c[240563]|0;o=m+n|0;c[240563]=o;return}}function aB4(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}a=c[962260+((h>>>9&7)<<2)>>2]|0;h=a&255;b=h-g|0;c[240591]=b;c[240592]=a-g&255;c[240593]=(b^h)&(h^g);c[240594]=b;return}function aB5(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;e=b&255;a=e-f|0;c[240591]=a;c[240592]=b-f&255;c[240593]=(a^e)&(e^f);c[240594]=a;return}function aB6(){var a=0,b=0,e=0,f=0;a=c[240580]|0;c[240580]=a+2;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;e=a&255;b=e-f|0;c[240591]=b;c[240592]=a-f&255;c[240593]=(b^e)&(e^f);c[240594]=b;return}function aB7(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;e=b&255;a=e-f|0;c[240591]=a;c[240592]=b-f&255;c[240593]=(a^e)&(e^f);c[240594]=a;return}function aB8(){var a=0,b=0,e=0,f=0;a=(c[240580]|0)-2|0;c[240580]=a;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;e=a&255;b=e-f|0;c[240591]=b;c[240592]=a-f&255;c[240593]=(b^e)&(e^f);c[240594]=b;return}function aB9(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[240587]|0;e=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=c[962260+((i>>>9&7)<<2)>>2]|0;i=a&255;g=i-h|0;c[240591]=g;c[240592]=a-h&255;c[240593]=(g^i)&(i^h);c[240594]=g;return}function aCa(){var a=0,b=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0;j=a}else{a=fl[b&255](f&16777215)|0;i=a;j=c[240587]|0}a=c[962260+((j>>>9&7)<<2)>>2]|0;j=a&255;f=j-i|0;c[240591]=f;c[240592]=a-i&255;c[240593]=(f^j)&(j^i);c[240594]=f;return}function aCb(){var a=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[957124+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=e&255;a=f-g|0;c[240591]=a;c[240592]=e-g&255;c[240593]=(a^f)&(f^g);c[240594]=a;return}function aCc(){var a=0,b=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a^1)|0]|0}else{h=fl[g&255](a|b<<16&16711680)|0}b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;a=b&255;g=a-h|0;c[240591]=g;c[240592]=b-h&255;c[240593]=(g^a)&(a^h);c[240594]=g;return}function aCd(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}a=c[962260+((h>>>9&7)<<2)>>2]|0;h=a&65535;b=h-g|0;f=b>>>8;c[240591]=f;c[240592]=a-g&65535;c[240593]=((b^h)&(h^g))>>>8;c[240594]=f;return}function aCe(){var a=0,b=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;d=b&65535;a=d-f|0;g=a>>>8;c[240591]=g;c[240592]=b-f&65535;c[240593]=((a^d)&(d^f))>>>8;c[240594]=g;return}function aCf(){var a=0,b=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;d=b&65535;a=d-f|0;g=a>>>8;c[240591]=g;c[240592]=b-f&65535;c[240593]=((a^d)&(d^f))>>>8;c[240594]=g;return}function aCg(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d&65535;g=f-a|0;h=g>>>8;c[240591]=h;c[240592]=d-a&65535;c[240593]=((g^d)&(f^a))>>>8;c[240594]=h;return}function aCh(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;a=d&65535;b=a-f|0;g=b>>>8;c[240591]=g;c[240592]=d-f&65535;c[240593]=((b^d)&(a^f))>>>8;c[240594]=g;return}function aCi(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;d=a&65535;f=d-b|0;g=f>>>8;c[240591]=g;c[240592]=a-b&65535;c[240593]=((f^a)&(d^b))>>>8;c[240594]=g;return}function aCj(){var a=0,b=0,d=0;a=c[240587]|0;b=c[962260+((a&7)<<2)>>2]|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=d-b|0;c[240591]=a>>>24;c[240592]=a;c[240593]=((a^d)&(d^b))>>>24;c[240594]=((a|b)&(d^-8388608)|a&b)>>>23;return}function aCk(){var a=0,b=0,d=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=d-b|0;c[240591]=a>>>24;c[240592]=a;c[240593]=((a^d)&(d^b))>>>24;c[240594]=((a|b)&(d^-8388608)|a&b)>>>23;return}function aCl(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=c[962260+((i>>>9&7)<<2)>>2]|0;i=a&65535;g=i-h|0;f=g>>>8;c[240591]=f;c[240592]=a-h&65535;c[240593]=((g^i)&(i^h))>>>8;c[240594]=f;return}function aCm(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[957128+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[b&255](d&16777215)|0;h=a;i=c[240587]|0}a=c[962260+((i>>>9&7)<<2)>>2]|0;i=a&65535;d=i-h|0;b=d>>>8;c[240591]=b;c[240592]=a-h&65535;c[240593]=((d^i)&(i^h))>>>8;c[240594]=b;return}function aCn(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d&65535;a=f-g|0;h=a>>>8;c[240591]=h;c[240592]=d-g&65535;c[240593]=((a^f)&(f^g))>>>8;c[240594]=h;return}function aCo(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=b&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+a>>1]|0}else{g=fl[f&255](a|b<<16&16711680)|0}b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;a=b&65535;f=a-g|0;d=f>>>8;c[240591]=d;c[240592]=b-g&65535;c[240593]=((f^a)&(a^g))>>>8;c[240594]=d;return}function aCp(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[240587]|0}g=c[962260+((j>>>9&7)<<2)>>2]|0;j=g-i|0;c[240591]=j>>>24;c[240592]=j;c[240593]=((j^g)&(g^i))>>>24;c[240594]=((j|i)&(g^-8388608)|j&i)>>>23;return}function aCq(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=b>>>16&255;d=957128+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;b=a-h|0;c[240591]=b>>>24;c[240592]=b;c[240593]=((b^a)&(a^h))>>>24;c[240594]=((b|h)&(a^-8388608)|b&h)>>>23;return}function aCr(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;b=a-i|0;c[240591]=b>>>24;c[240592]=b;c[240593]=((b^a)&(a^i))>>>24;c[240594]=((b|i)&(a^-8388608)|b&i)>>>23;return}function aCs(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]<<16;k=a}else{a=(fl[h&255](g&16777215)|0)<<16;h=fl[c[f>>2]&255](g+2&16777215)|0|a;j=h;k=c[240587]|0}h=c[962260+((k>>>9&7)<<2)>>2]|0;k=h-j|0;c[240591]=k>>>24;c[240592]=k;c[240593]=((k^h)&(h^j))>>>24;c[240594]=((k|j)&(h^-8388608)|k&j)>>>23;return}function aCt(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=957128+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[240587]|0}f=c[962260+((j>>>9&7)<<2)>>2]|0;j=f-i|0;c[240591]=j>>>24;c[240592]=j;c[240593]=((j^f)&(f^i))>>>24;c[240594]=((j|i)&(f^-8388608)|j&i)>>>23;return}function aCu(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;d=a-i|0;c[240591]=d>>>24;c[240592]=d;c[240593]=((d^a)&(a^i))>>>24;c[240594]=((d|i)&(a^-8388608)|d&i)>>>23;return}function aCv(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]<<16;f=d+2|0;d=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;g=d-(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|a)|0;c[240591]=g>>>24;c[240592]=g;c[240593]=((g^d)&(d^a))>>>24;c[240594]=((g|a)&(d^-8388608)|g&a)>>>23;return}function aCw(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;a=d+2|0;d=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;b=d-(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|f)|0;c[240591]=b>>>24;c[240592]=b;c[240593]=((b^d)&(d^f))>>>24;c[240594]=((b|f)&(d^-8388608)|b&f)>>>23;return}function aCx(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+4;b=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=a-(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b)|0;c[240591]=f>>>24;c[240592]=f;c[240593]=((f^a)&(a^b))>>>24;c[240594]=((f|b)&(a^-8388608)|f&b)>>>23;return}function aCy(){var a=0,b=0,d=0;a=c[240587]|0;b=c[962260+((a&7)<<2)>>2]<<16>>16;d=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[240591]=a>>>24;c[240592]=a;c[240593]=((a^d)&(b^d))>>>24;c[240594]=((a|b)&(d^-8388608)|a&b)>>>23;return}function aCz(){var a=0,b=0,d=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]<<16>>16;d=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[240591]=a>>>24;c[240592]=a;c[240593]=((a^d)&(b^d))>>>24;c[240594]=((a|b)&(d^-8388608)|a&b)>>>23;return}function aCA(){var a=0,d=0,e=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;e=d-a|0;c[240591]=e>>>24;c[240592]=e;c[240593]=((e^d)&(d^a))>>>24;c[240594]=((e|a)&(d^-8388608)|e&a)>>>23;return}function aCB(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;a=f-g|0;c[240591]=a>>>24;c[240592]=a;c[240593]=((a^f)&(f^g))>>>24;c[240594]=((a|g)&(f^-8388608)|a&g)>>>23;return}function aCC(){var a=0,d=0,e=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;e=a-d|0;c[240591]=e>>>24;c[240592]=e;c[240593]=((e^a)&(a^d))>>>24;c[240594]=((e|d)&(a^-8388608)|e&d)>>>23;return}function aCD(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[b>>2]^c[962260+((a>>>9&7)<<2)>>2]&255;c[b>>2]=d;b=d&255;c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}function aCE(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;f=b&255;b=957128+(f*20|0)|0;g=c[b>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+a>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[b>>2]&255](d+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;d=a-i|0;c[240591]=d>>>24;c[240592]=d;c[240593]=((d^a)&(a^i))>>>24;c[240594]=((d|i)&(a^-8388608)|d&i)>>>23;return}function aCF(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}a=g<<16>>16;g=c[962260+((h>>>9&7|8)<<2)>>2]|0;h=g-a|0;c[240591]=h>>>24;c[240592]=h;c[240593]=((h^g)&(a^g))>>>24;c[240594]=((h|a)&(g^-8388608)|h&a)>>>23;return}function aCG(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=f<<16>>16;f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;d=f-b|0;c[240591]=d>>>24;c[240592]=d;c[240593]=((d^f)&(b^f))>>>24;c[240594]=((d|b)&(f^-8388608)|d&b)>>>23;return}function aCH(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=f<<16>>16;f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;d=f-b|0;c[240591]=d>>>24;c[240592]=d;c[240593]=((d^f)&(b^f))>>>24;c[240594]=((d|b)&(f^-8388608)|d&b)>>>23;return}function aCI(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=h<<16>>16;h=c[962260+((i>>>9&7|8)<<2)>>2]|0;i=h-a|0;c[240591]=i>>>24;c[240592]=i;c[240593]=((i^h)&(a^h))>>>24;c[240594]=((i|a)&(h^-8388608)|i&a)>>>23;return}function aCJ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[957128+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[b&255](d&16777215)|0;h=a;i=c[240587]|0}a=h<<16>>16;h=c[962260+((i>>>9&7|8)<<2)>>2]|0;i=h-a|0;c[240591]=i>>>24;c[240592]=i;c[240593]=((i^h)&(a^h))>>>24;c[240594]=((i|a)&(h^-8388608)|i&a)>>>23;return}function aCK(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=g<<16>>16;g=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;f=g-d|0;c[240591]=f>>>24;c[240592]=f;c[240593]=((f^g)&(d^g))>>>24;c[240594]=((f|d)&(g^-8388608)|f&d)>>>23;return}function aCL(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=b&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+a>>1]|0}else{g=fl[f&255](a|b<<16&16711680)|0}b=g<<16>>16;g=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;a=g-b|0;c[240591]=a>>>24;c[240592]=a;c[240593]=((a^g)&(b^g))>>>24;c[240594]=((a|b)&(g^-8388608)|a&b)>>>23;return}function aCM(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[b>>2]^c[962260+((a>>>9&7)<<2)>>2]&65535;c[b>>2]=d;b=d&65535;c[240591]=b>>>8;c[240592]=b;c[240594]=0;c[240593]=0;return}function aCN(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;a=c[957124+(b*20|0)>>2]|0;if((a|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0;h=g-f|0;c[240591]=h;i=h&255;c[240592]=i;j=g^f;k=h^g;l=k&j;c[240593]=l;c[240594]=h;return}else{g=fl[a&255](e&16777215)|0;h=g-f|0;c[240591]=h;i=h&255;c[240592]=i;j=g^f;k=h^g;l=k&j;c[240593]=l;c[240594]=h;return}}function aCO(){var a=0,b=0,e=0,f=0,g=0;a=c[240580]|0;c[240580]=a+2;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;e=c[a>>2]|0;c[a>>2]=e+1;a=e>>>16&255;b=c[957124+(a*20|0)>>2]|0;if((b|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[b&255](e&16777215)|0}e=g-f|0;c[240591]=e;c[240592]=e&255;c[240593]=(e^g)&(g^f);c[240594]=e;return}function aCP(){var b=0,e=0,f=0,g=0,h=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=c[962260+((b>>>9&7)<<2)>>2]|0;b=e>>>16&255;g=c[957124+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h^f;f=g&255;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[h&511](e&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function aCQ(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h^b;b=g&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}else{fj[h&511](e&16777215,b);c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}}function aCR(){var b=0,e=0,f=0,g=0,h=0;b=c[240580]|0;c[240580]=b+2;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h^e;e=g&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}else{fj[h&511](b&16777215,e);c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}}function aCS(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h^b;b=g&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}else{fj[h&511](e&16777215,b);c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}}function aCT(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h^e;e=g&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}else{fj[h&511](b&16777215,e);c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}}function aCU(){var e=0,f=0,g=0,h=0,i=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=c[962260+((e>>>9&7)<<2)>>2]|0;e=h>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[g&255](h&16777215)|0}g=i^f;f=g&255;i=c[957132+(e*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(h&65535^1)|0]=g&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[i&511](h&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function aCV(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=c[962260+((b>>>9&7)<<2)>>2]|0;b=g>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j^i;i=f&255;j=c[957132+(b*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]=f&255;c[240591]=i;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[j&511](g&16777215,i);c[240591]=i;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aCW(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[h&255](f&16777215)|0}h=i^e;e=h&255;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}else{fj[i&511](f&16777215,e);c[240591]=e;c[240592]=e;c[240594]=0;c[240593]=0;return}}function aCX(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;i=f&255;f=c[957124+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(b^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j^h;h=f&255;j=c[957132+(i*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(b^1)|0]=f&255;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[j&511](g&16777215,h);c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}}function aCY(){var a=0,b=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+2;b=d>>>16&255;a=c[957128+(b*20|0)>>2]|0;if((a|0)==0){g=e[(c[957120+(b*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[a&255](d&16777215)|0}d=g-f|0;a=d>>>8;c[240591]=a;c[240592]=d&65535;c[240593]=((d^g)&(g^f))>>>8;c[240594]=a;return}function aCZ(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7)<<2)>>2]|0;a=d>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h^f;f=g&65535;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=f>>>8;c[240591]=i;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[h&511](d&16777215,f);i=f>>>8;c[240591]=i;c[240592]=f;c[240594]=0;c[240593]=0;return}}function aC_(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[b>>2]^c[962260+((a>>>9&7)<<2)>>2];c[b>>2]=d;c[240591]=d>>>24;c[240592]=d;c[240594]=0;c[240593]=0;return}function aC$(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h^a;a=g&65535;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}else{fj[h&511](d&16777215,a);i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}}function aC0(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h^a;a=g&65535;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}else{fj[h&511](d&16777215,a);i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}}function aC1(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=g>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[f&255](g&16777215)|0}f=h^d;d=f&65535;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=f&65535;i=d>>>8;c[240591]=i;c[240592]=d;c[240594]=0;c[240593]=0;return}else{fj[h&511](g&16777215,d);i=d>>>8;c[240591]=i;c[240592]=d;c[240594]=0;c[240593]=0;return}}function aC2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[962260+((a>>>9&7)<<2)>>2]|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{i=fl[d&255](f&16777215)|0}d=i^h;h=d&65535;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;j=h>>>8;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[i&511](f&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}}function aC3(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h^a;a=g&65535;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}else{fj[h&511](d&16777215,a);i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}}function aC4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;h=d&255;d=c[957128+(h*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0}else{i=fl[d&255](f&16777215)|0}d=i^g;g=d&65535;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=d&65535;j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[i&511](f&16777215,g);j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}}function aC5(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=b>>>16&255;d=957128+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=b>>>16&255;d=957128+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;i=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=i-h|0;k=j>>>24;c[240591]=k;c[240592]=j;l=i^h;m=j^i;n=m&l;o=n>>>24;c[240593]=o;p=j&h;q=i^-8388608;r=j|h;s=r&q;t=s|p;u=t>>>23;c[240594]=u;return}else{a=(fl[f&255](b&16777215)|0)<<16;i=fl[c[d>>2]&255](b+2&16777215)|0|a;j=i-h|0;k=j>>>24;c[240591]=k;c[240592]=j;l=i^h;m=j^i;n=m&l;o=n>>>24;c[240593]=o;p=j&h;q=i^-8388608;r=j|h;s=r&q;t=s|p;u=t>>>23;c[240594]=u;return}}function aC6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7)<<2)>>2]|0;a=d>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j^f;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[f&511](d&16777215,i>>>16)}f=d+2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[a&511](f&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aC7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j^a;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[a&511](d&16777215,i>>>16)}a=d+2|0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[f&511](a&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aC8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=957128+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[h>>2]&255](d+16777214&16777215)|0|j}j=k^a;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[a&511](f&16777215,j>>>16)}f=d-2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=j&65535;l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}else{fj[a&511](f&16777215,j&65535);l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}}function aC9(){var a=0,b=0,d=0;a=c[240587]|0;b=c[962260+((a&7)<<2)>>2]|0;d=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[240591]=a>>>24;c[240592]=a;c[240593]=((a^d)&(d^b))>>>24;c[240594]=((a|b)&(d^-8388608)|a&b)>>>23;return}function aDa(){var a=0,b=0,d=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[240591]=a>>>24;c[240592]=a;c[240593]=((a^d)&(d^b))>>>24;c[240594]=((a|b)&(d^-8388608)|a&b)>>>23;return}function aDb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=g>>>16&255;f=957128+(a*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]<<16}else{i=(fl[h&255](g&16777215)|0)<<16;j=fl[c[f>>2]&255](g+2&16777215)|0|i}i=j^d;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i>>>16&65535}else{fj[d&511](g&16777215,i>>>16)}d=g+2|0;g=d>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[a&511](d&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aDc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[962260+((a>>>9&7)<<2)>>2]|0;a=f>>>16&255;d=957128+(a*20|0)|0;g=c[d>>2]|0;if((g|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{i=(fl[g&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|i}i=j^h;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[h&511](f&16777215,i>>>16)}h=f+2|0;f=h>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[a&511](h&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aDd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j^a;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[a&511](d&16777215,i>>>16)}a=d+2|0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[f&511](a&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function aDe(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;h=d&255;d=957128+(h*20|0)|0;i=c[d>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[d>>2]&255](f+2&16777215)|0|j}j=k^g;g=c[957136+(h*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[g&511](f&16777215,j>>>16)}g=f+2|0;f=g>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=j&65535;l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}else{fj[a&511](g&16777215,j&65535);l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}}function aDf(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[240587]|0}g=c[962260+((j>>>9&7|8)<<2)>>2]|0;j=g-i|0;c[240591]=j>>>24;c[240592]=j;c[240593]=((j^g)&(g^i))>>>24;c[240594]=((j|i)&(g^-8388608)|j&i)>>>23;return}function aDg(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=b>>>16&255;d=957128+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;b=a-h|0;c[240591]=b>>>24;c[240592]=b;c[240593]=((b^a)&(a^h))>>>24;c[240594]=((b|h)&(a^-8388608)|b&h)>>>23;return}function aDh(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;b=a-i|0;c[240591]=b>>>24;c[240592]=b;c[240593]=((b^a)&(a^i))>>>24;c[240594]=((b|i)&(a^-8388608)|b&i)>>>23;return}function aDi(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]<<16;k=a}else{a=(fl[h&255](g&16777215)|0)<<16;h=fl[c[f>>2]&255](g+2&16777215)|0|a;j=h;k=c[240587]|0}h=c[962260+((k>>>9&7|8)<<2)>>2]|0;k=h-j|0;c[240591]=k>>>24;c[240592]=k;c[240593]=((k^h)&(h^j))>>>24;c[240594]=((k|j)&(h^-8388608)|k&j)>>>23;return}function aDj(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=957128+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[240587]|0}f=c[962260+((j>>>9&7|8)<<2)>>2]|0;j=f-i|0;c[240591]=j>>>24;c[240592]=j;c[240593]=((j^f)&(f^i))>>>24;c[240594]=((j|i)&(f^-8388608)|j&i)>>>23;return}function aDk(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]<<16;f=d+2|0;d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;g=d-(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|a)|0;c[240591]=g>>>24;c[240592]=g;c[240593]=((g^d)&(d^a))>>>24;c[240594]=((g|a)&(d^-8388608)|g&a)>>>23;return}function aDl(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;a=d+2|0;d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;b=d-(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|f)|0;c[240591]=b>>>24;c[240592]=b;c[240593]=((b^d)&(d^f))>>>24;c[240594]=((b|f)&(d^-8388608)|b&f)>>>23;return}function aDm(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+4;b=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;f=a-(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b)|0;c[240591]=f>>>24;c[240592]=f;c[240593]=((f^a)&(a^b))>>>24;c[240594]=((f|b)&(a^-8388608)|f&b)>>>23;return}function aDn(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[b>>2]&(c[962260+((a&7)<<2)>>2]|-256);c[b>>2]=d;b=d&255;c[240592]=b;c[240591]=b;c[240594]=0;c[240593]=0;return}function aDo(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;d=a-i|0;c[240591]=d>>>24;c[240592]=d;c[240593]=((d^a)&(a^i))>>>24;c[240594]=((d|i)&(a^-8388608)|d&i)>>>23;return}function aDp(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;f=b&255;b=957128+(f*20|0)|0;g=c[b>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+a>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[b>>2]&255](d+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;d=a-i|0;c[240591]=d>>>24;c[240592]=d;c[240593]=((d^a)&(a^i))>>>24;c[240594]=((d|i)&(a^-8388608)|d&i)>>>23;return}function aDq(){var a=0,b=0,e=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;a=c[957124+(e*20|0)>>2]|0;if((a|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[a&255](b&16777215)|0}b=g-f|0;c[240591]=b;c[240592]=b&255;c[240593]=(b^g)&(g^f);c[240594]=b;return}function aDr(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[240580]|0;b=a+2|0;c[240580]=b;e=a>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(a&65535^1)|0]|0;h=b}else{b=fl[f&255](a&16777215)|0;g=b;h=c[240580]|0}c[240580]=h+2;b=h>>>16&255;a=c[957124+(b*20|0)>>2]|0;if((a|0)==0){i=d[(c[957120+(b*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[a&255](h&16777215)|0}h=i-g|0;c[240591]=h;c[240592]=h&255;c[240593]=(h^i)&(i^g);c[240594]=h;return}function aDs(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}a=962260+((h>>>9&7)<<2)|0;h=c[a>>2]&(g|-256);c[a>>2]=h;a=h&255;c[240592]=a;c[240591]=a;c[240594]=0;c[240593]=0;return}function aDt(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[b>>2]&(f|-256);c[b>>2]=e;b=e&255;c[240592]=b;c[240591]=b;c[240594]=0;c[240593]=0;return}function aDu(){var a=0,b=0,e=0,f=0;a=c[240580]|0;c[240580]=a+2;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[a>>2]&(f|-256);c[a>>2]=e;a=e&255;c[240592]=a;c[240591]=a;c[240594]=0;c[240593]=0;return}function aDv(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[b>>2]&(f|-256);c[b>>2]=e;b=e&255;c[240592]=b;c[240591]=b;c[240594]=0;c[240593]=0;return}function aDw(){var a=0,b=0,e=0,f=0;a=(c[240580]|0)-2|0;c[240580]=a;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[a>>2]&(f|-256);c[a>>2]=e;a=e&255;c[240592]=a;c[240591]=a;c[240594]=0;c[240593]=0;return}function aDx(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[240587]|0;e=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7)<<2)|0;i=c[a>>2]&(h|-256);c[a>>2]=i;a=i&255;c[240592]=a;c[240591]=a;c[240594]=0;c[240593]=0;return}function aDy(){var a=0,b=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0;j=a}else{a=fl[b&255](f&16777215)|0;i=a;j=c[240587]|0}a=962260+((j>>>9&7)<<2)|0;j=c[a>>2]&(i|-256);c[a>>2]=j;a=j&255;c[240592]=a;c[240591]=a;c[240594]=0;c[240593]=0;return}function aDz(){var a=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[957124+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7)<<2)|0;f=c[e>>2]&(g|-256);c[e>>2]=f;e=f&255;c[240592]=e;c[240591]=e;c[240594]=0;c[240593]=0;return}function aDA(){var a=0,b=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a^1)|0]|0}else{h=fl[g&255](a|b<<16&16711680)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;a=c[b>>2]&(h|-256);c[b>>2]=a;b=a&255;c[240592]=b;c[240591]=b;c[240594]=0;c[240593]=0;return}function aDB(){var a=0,e=0,f=0;a=c[240581]|0;c[240581]=a+2;e=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;f=c[a>>2]&(d[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|-256);c[a>>2]=f;a=f&255;c[240592]=a;c[240591]=a;c[240594]=0;c[240593]=0;return}function aDC(){var a=0,b=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){g=f<<16>>16}else{g=f}f=(b<<24>>24)+a+g|0;g=962260+(((c[240587]|0)>>>9&7)<<2)|0;a=c[g>>2]&(d[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0|-256);c[g>>2]=a;g=a&255;c[240592]=g;c[240591]=g;c[240594]=0;c[240593]=0;return}function aDD(){var a=0,b=0,d=0;a=c[240581]|0;c[240581]=a+2;b=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[b>>2]&(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|-256);c[b>>2]=d;b=d&255;c[240592]=b;c[240591]=b;c[240594]=0;c[240593]=0;return}function aDE(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[b>>2]&(c[962260+((a&7)<<2)>>2]|-65536);c[b>>2]=d;b=d&65535;c[240592]=b;c[240591]=b>>>8;c[240594]=0;c[240593]=0;return}function aDF(){var a=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;f=c[a>>2]&(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|-65536);c[a>>2]=f;a=f&65535;c[240592]=a;c[240591]=a>>>8;c[240594]=0;c[240593]=0;return}function aDG(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=962260+(((c[240587]|0)>>>9&7)<<2)|0;a=c[f>>2]&(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|-65536);c[f>>2]=a;f=a&65535;c[240592]=f;c[240591]=f>>>8;c[240594]=0;c[240593]=0;return}function aDH(){var a=0,b=0,d=0;a=c[240581]|0;c[240581]=a+2;b=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[b>>2]&(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|-65536);c[b>>2]=d;b=d&65535;c[240592]=b;c[240591]=b>>>8;c[240594]=0;c[240593]=0;return}function aDI(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[b>>2]&c[962260+((a&7)<<2)>>2];c[b>>2]=d;c[240592]=d;c[240591]=d>>>24;c[240594]=0;c[240593]=0;return}function aDJ(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}a=962260+((h>>>9&7)<<2)|0;h=c[a>>2]&(g|-65536);c[a>>2]=h;a=h&65535;c[240592]=a;c[240591]=a>>>8;c[240594]=0;c[240593]=0;return}function aDK(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[b>>2]&(f|-65536);c[b>>2]=d;b=d&65535;c[240592]=b;c[240591]=b>>>8;c[240594]=0;c[240593]=0;return}function aDL(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[b>>2]&(f|-65536);c[b>>2]=d;b=d&65535;c[240592]=b;c[240591]=b>>>8;c[240594]=0;c[240593]=0;return}function aDM(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7)<<2)|0;i=c[a>>2]&(h|-65536);c[a>>2]=i;a=i&65535;c[240592]=a;c[240591]=a>>>8;c[240594]=0;c[240593]=0;return}function aDN(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[957128+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[b&255](d&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7)<<2)|0;i=c[a>>2]&(h|-65536);c[a>>2]=i;a=i&65535;c[240592]=a;c[240591]=a>>>8;c[240594]=0;c[240593]=0;return}function aDO(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7)<<2)|0;f=c[d>>2]&(g|-65536);c[d>>2]=f;d=f&65535;c[240592]=d;c[240591]=d>>>8;c[240594]=0;c[240593]=0;return}function aDP(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=b&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+a>>1]|0}else{g=fl[f&255](a|b<<16&16711680)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;a=c[b>>2]&(g|-65536);c[b>>2]=a;b=a&65535;c[240592]=b;c[240591]=b>>>8;c[240594]=0;c[240593]=0;return}function aDQ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[240587]|0}g=962260+((j>>>9&7)<<2)|0;j=c[g>>2]&i;c[g>>2]=j;c[240592]=j;c[240591]=j>>>24;c[240594]=0;c[240593]=0;return}function aDR(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=b>>>16&255;d=957128+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[a>>2]&h;c[a>>2]=b;c[240592]=b;c[240591]=b>>>24;c[240594]=0;c[240593]=0;return}function aDS(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[a>>2]&i;c[a>>2]=b;c[240592]=b;c[240591]=b>>>24;c[240594]=0;c[240593]=0;return}function aDT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]<<16;k=a;l=k>>>9;m=l&7;n=962260+(m<<2)|0;o=c[n>>2]|0;p=o&j;c[n>>2]=p;c[240592]=p;q=p>>>24;c[240591]=q;c[240594]=0;c[240593]=0;return}else{a=(fl[h&255](g&16777215)|0)<<16;h=fl[c[f>>2]&255](g+2&16777215)|0|a;j=h;k=c[240587]|0;l=k>>>9;m=l&7;n=962260+(m<<2)|0;o=c[n>>2]|0;p=o&j;c[n>>2]=p;c[240592]=p;q=p>>>24;c[240591]=q;c[240594]=0;c[240593]=0;return}}function aDU(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=d+2|0;f=962260+(((c[240587]|0)>>>9&7)<<2)|0;g=c[f>>2]&(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]<<16);c[f>>2]=g;c[240592]=g;c[240591]=g>>>24;c[240594]=0;c[240593]=0;return}function aDV(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=d+2|0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[a>>2]&(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16);c[a>>2]=b;c[240592]=b;c[240591]=b>>>24;c[240594]=0;c[240593]=0;return}function aDW(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+4;b=a+2|0;d=962260+(((c[240587]|0)>>>9&7)<<2)|0;f=c[d>>2]&(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16);c[d>>2]=f;c[240592]=f;c[240591]=f>>>24;c[240594]=0;c[240593]=0;return}function aDX(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=ab(c[b>>2]&65535,d&65535)|0;e=d&65535;if(e<<16>>16==0){f=152}else{d=e;e=152;while(1){g=(d&1)==0?e:e+8|0;h=(d&65535)>>>1;if(h<<16>>16==0){f=g;break}else{d=h;e=g}}}c[240563]=(c[240563]|0)+f;c[b>>2]=a;c[240592]=a;c[240591]=a>>>24;c[240593]=0;c[240594]=0;return}function aDY(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=957128+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=962260+(l<<2)|0;n=c[m>>2]|0;o=n&i;c[m>>2]=o;c[240592]=o;p=o>>>24;c[240591]=p;c[240594]=0;c[240593]=0;return}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[240587]|0;k=j>>>9;l=k&7;m=962260+(l<<2)|0;n=c[m>>2]|0;o=n&i;c[m>>2]=o;c[240592]=o;p=o>>>24;c[240591]=p;c[240594]=0;c[240593]=0;return}}function aDZ(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[a>>2]&i;c[a>>2]=d;c[240592]=d;c[240591]=d>>>24;c[240594]=0;c[240593]=0;return}function aD_(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;f=b&255;b=957128+(f*20|0)|0;g=c[b>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+a>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[b>>2]&255](d+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[a>>2]&i;c[a>>2]=d;c[240592]=d;c[240591]=d>>>24;c[240594]=0;c[240593]=0;return}function aD$(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=ab(c[b>>2]&65535,g)|0;f=g&65535;if(f<<16>>16==0){h=152}else{g=f;f=152;while(1){a=(g&1)==0?f:f+8|0;i=(g&65535)>>>1;if(i<<16>>16==0){h=a;break}else{g=i;f=a}}}c[240563]=(c[240563]|0)+h;c[b>>2]=d;c[240592]=d;c[240591]=d>>>24;c[240593]=0;c[240594]=0;return}function aD0(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=ab(c[b>>2]&65535,g)|0;f=g&65535;if(f<<16>>16==0){h=152}else{g=f;f=152;while(1){d=(g&1)==0?f:f+8|0;i=(g&65535)>>>1;if(i<<16>>16==0){h=d;break}else{g=i;f=d}}}c[240563]=(c[240563]|0)+h;c[b>>2]=a;c[240592]=a;c[240591]=a>>>24;c[240593]=0;c[240594]=0;return}function aD1(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=ab(c[b>>2]&65535,g)|0;f=g&65535;if(f<<16>>16==0){h=152}else{g=f;f=152;while(1){d=(g&1)==0?f:f+8|0;i=(g&65535)>>>1;if(i<<16>>16==0){h=d;break}else{g=i;f=d}}}c[240563]=(c[240563]|0)+h;c[b>>2]=a;c[240592]=a;c[240591]=a>>>24;c[240593]=0;c[240594]=0;return}function aD2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}g=ab(c[d>>2]&65535,h)|0;a=h&65535;if(a<<16>>16==0){i=152}else{h=a;a=152;while(1){f=(h&1)==0?a:a+8|0;j=(h&65535)>>>1;if(j<<16>>16==0){i=f;break}else{h=j;a=f}}}c[240563]=(c[240563]|0)+i;c[d>>2]=g;c[240592]=g;c[240591]=g>>>24;c[240593]=0;c[240594]=0;return}function aD3(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=ab(c[b>>2]&65535,h)|0;d=h&65535;if(d<<16>>16==0){i=152;j=c[240563]|0;k=j+i|0;c[240563]=k;c[b>>2]=a;c[240592]=a;l=a>>>24;c[240591]=l;c[240593]=0;c[240594]=0;return}else{m=d;n=152}while(1){d=(m&1)==0?n:n+8|0;h=(m&65535)>>>1;if(h<<16>>16==0){i=d;break}else{m=h;n=d}}j=c[240563]|0;k=j+i|0;c[240563]=k;c[b>>2]=a;c[240592]=a;l=a>>>24;c[240591]=l;c[240593]=0;c[240594]=0;return}function aD4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}f=ab(c[a>>2]&65535,h)|0;g=h&65535;if(g<<16>>16==0){i=152}else{h=g;g=152;while(1){d=(h&1)==0?g:g+8|0;j=(h&65535)>>>1;if(j<<16>>16==0){i=d;break}else{h=j;g=d}}}c[240563]=(c[240563]|0)+i;c[a>>2]=f;c[240592]=f;c[240591]=f>>>24;c[240593]=0;c[240594]=0;return}function aD5(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+b>>1]|0}else{h=fl[g&255](b|d<<16&16711680)|0}d=ab(c[a>>2]&65535,h)|0;b=h&65535;if(b<<16>>16==0){i=152;j=c[240563]|0;k=j+i|0;c[240563]=k;c[a>>2]=d;c[240592]=d;l=d>>>24;c[240591]=l;c[240593]=0;c[240594]=0;return}else{m=b;n=152}while(1){b=(m&1)==0?n:n+8|0;h=(m&65535)>>>1;if(h<<16>>16==0){i=b;break}else{m=h;n=b}}j=c[240563]|0;k=j+i|0;c[240563]=k;c[a>>2]=d;c[240592]=d;l=d>>>24;c[240591]=l;c[240593]=0;c[240594]=0;return}function aD6(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=ab(c[a>>2]&65535,d&65535)|0;if(d<<16>>16==0){f=152}else{g=d;d=152;while(1){h=(g&1)==0?d:d+8|0;i=(g&65535)>>>1;if(i<<16>>16==0){f=h;break}else{g=i;d=h}}}c[240563]=(c[240563]|0)+f;c[a>>2]=e;c[240592]=e;c[240591]=e>>>24;c[240593]=0;c[240594]=0;return}function aD7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=ab(c[a>>2]&65535,h&65535)|0;if(h<<16>>16==0){i=152}else{d=h;h=152;while(1){f=(d&1)==0?h:h+8|0;j=(d&65535)>>>1;if(j<<16>>16==0){i=f;break}else{d=j;h=f}}}c[240563]=(c[240563]|0)+i;c[a>>2]=g;c[240592]=g;c[240591]=g>>>24;c[240593]=0;c[240594]=0;return}function aD8(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=ab(c[a>>2]&65535,e&65535)|0;if(e<<16>>16==0){f=152}else{g=e;e=152;while(1){h=(g&1)==0?e:e+8|0;i=(g&65535)>>>1;if(i<<16>>16==0){f=h;break}else{g=i;e=h}}}c[240563]=(c[240563]|0)+f;c[a>>2]=d;c[240592]=d;c[240591]=d>>>24;c[240593]=0;c[240594]=0;return}function aD9(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=(a&15)+(d&15)+((c[240590]|0)>>>8&1)|0;f=(a&240)+(d&240)+(e>>>0>9?e+6|0:e)|0;d=f>>>0>153;a=(d&1)<<8;c[240594]=a;c[240590]=a;a=d?f-160|0:f;c[240593]=a&~e;c[240591]=a;e=a&255;c[240592]=e|c[240592];c[b>>2]=e|c[b>>2]&-256;return}function aEa(){var b=0,e=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;b=c[957124+(e*20|0)>>2]|0;if((b|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[b&255](f&16777215)|0}b=(h&15)+(g&15)+((c[240590]|0)>>>8&1)|0;i=(h&240)+(g&240)+(b>>>0>9?b+6|0:b)|0;g=i>>>0>153;h=(g&1)<<8;c[240594]=h;c[240590]=h;h=g?i-160|0:i;c[240593]=h&~b;c[240591]=h;b=h&255;c[240592]=b|c[240592];i=c[957132+(e*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[i&511](f&16777215,b);return}}function aEb(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[e&255](f&16777215)|0}e=(h&15)+(g&15)+((c[240590]|0)>>>8&1)|0;i=(h&240)+(g&240)+(e>>>0>9?e+6|0:e)|0;g=i>>>0>153;h=(g&1)<<8;c[240594]=h;c[240590]=h;h=g?i-160|0:i;c[240593]=h&~e;c[240591]=h;e=h&255;c[240592]=e|c[240592];i=c[957132+(b*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[i&511](f&16777215,e);return}}function aEc(){var b=0,e=0,f=0,g=0,h=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=c[962260+((b>>>9&7)<<2)>>2]|0;b=e>>>16&255;g=c[957124+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h&f;c[240591]=g;c[240594]=0;c[240593]=0;f=g&255;c[240592]=f;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[h&511](e&16777215,f);return}}function aEd(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h&b;c[240591]=g;c[240594]=0;c[240593]=0;b=g&255;c[240592]=b;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[h&511](e&16777215,b);return}}function aEe(){var b=0,e=0,f=0,g=0,h=0;b=c[240580]|0;c[240580]=b+2;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h&e;c[240591]=g;c[240594]=0;c[240593]=0;e=g&255;c[240592]=e;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[h&511](b&16777215,e);return}}function aEf(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h&b;c[240591]=g;c[240594]=0;c[240593]=0;b=g&255;c[240592]=b;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[h&511](e&16777215,b);return}}function aEg(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h&e;c[240591]=g;c[240594]=0;c[240593]=0;e=g&255;c[240592]=e;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[h&511](b&16777215,e);return}}function aEh(){var e=0,f=0,g=0,h=0,i=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=c[962260+((e>>>9&7)<<2)>>2]|0;e=h>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[g&255](h&16777215)|0}g=i&f;c[240591]=g;c[240594]=0;c[240593]=0;f=g&255;c[240592]=f;i=c[957132+(e*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(h&65535^1)|0]=g&255;return}else{fj[i&511](h&16777215,f);return}}function aEi(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=c[962260+((b>>>9&7)<<2)>>2]|0;b=g>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j&i;c[240591]=f;c[240594]=0;c[240593]=0;i=f&255;c[240592]=i;j=c[957132+(b*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]=f&255;return}else{fj[j&511](g&16777215,i);return}}function aEj(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7)<<2)|0;a=c[b>>2]|0;c[b>>2]=c[d>>2];c[d>>2]=a;return}function aEk(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[b>>2]|0;c[b>>2]=c[d>>2];c[d>>2]=a;return}function aEl(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[b>>2]|0;c[b>>2]=c[d>>2];c[d>>2]=a;return}function aEm(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[h&255](f&16777215)|0}h=i&e;c[240591]=h;c[240594]=0;c[240593]=0;e=h&255;c[240592]=e;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[i&511](f&16777215,e);return}}function aEn(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;i=f&255;f=c[957124+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(b^1)|0]|0}else{j=fl[f&255](g&16777215)|0}f=j&h;c[240591]=f;c[240594]=0;c[240593]=0;h=f&255;c[240592]=h;j=c[957132+(i*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[j&511](g&16777215,h);return}}function aEo(){var a=0,d=0,f=0,g=0,h=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7)<<2)>>2]|0;a=d>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h&f;c[240591]=g>>>8;c[240594]=0;c[240593]=0;f=g&65535;c[240592]=f;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[h&511](d&16777215,f);return}}function aEp(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h&a;c[240591]=g>>>8;c[240594]=0;c[240593]=0;a=g&65535;c[240592]=a;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[h&511](d&16777215,a);return}}function aEq(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h&a;c[240591]=g>>>8;c[240594]=0;c[240593]=0;a=g&65535;c[240592]=a;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[h&511](d&16777215,a);return}}function aEr(){var a=0,d=0,f=0,g=0,h=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=g>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[f&255](g&16777215)|0}f=h&d;c[240591]=f>>>8;c[240594]=0;c[240593]=0;d=f&65535;c[240592]=d;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=f&65535;return}else{fj[h&511](g&16777215,d);return}}function aEs(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[962260+((a>>>9&7)<<2)>>2]|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{i=fl[d&255](f&16777215)|0}d=i&h;c[240591]=d>>>8;c[240594]=0;c[240593]=0;h=d&65535;c[240592]=h;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[i&511](f&16777215,h);return}}function aEt(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[g&255](d&16777215)|0}g=h&a;c[240591]=g>>>8;c[240594]=0;c[240593]=0;a=g&65535;c[240592]=a;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[h&511](d&16777215,a);return}}function aEu(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;h=d&255;d=c[957128+(h*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0}else{i=fl[d&255](f&16777215)|0}d=i&g;c[240591]=d>>>8;c[240594]=0;c[240593]=0;g=d&65535;c[240592]=g;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=d&65535;return}else{fj[i&511](f&16777215,g);return}}function aEv(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7)<<2)>>2]|0;a=d>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j&f;c[240591]=i>>>24;c[240592]=i;c[240594]=0;c[240593]=0;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[f&511](d&16777215,i>>>16)}f=d+2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[a&511](f&16777215,i&65535);return}}function aEw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j&a;c[240591]=i>>>24;c[240592]=i;c[240594]=0;c[240593]=0;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[a&511](d&16777215,i>>>16)}a=d+2|0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[f&511](a&16777215,i&65535);return}}function aEx(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=ab(c[b>>2]<<16>>16,d<<16>>16)|0;e=d&65535;f=d<<1&65534;if((f|0)==(e|0)){g=152}else{d=152;h=f^e;while(1){e=(h&1|0)==0?d:d+8|0;f=h>>1;if((f|0)==0){g=e;break}else{d=e;h=f}}}c[240563]=(c[240563]|0)+g;c[b>>2]=a;c[240592]=a;c[240591]=a>>>24;c[240593]=0;c[240594]=0;return}function aEy(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=957128+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[h>>2]&255](d+16777214&16777215)|0|j}j=k&a;c[240591]=j>>>24;c[240592]=j;c[240594]=0;c[240593]=0;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[a&511](f&16777215,j>>>16)}f=d-2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[a&511](f&16777215,j&65535);return}}function aEz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=g>>>16&255;f=957128+(a*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]<<16}else{i=(fl[h&255](g&16777215)|0)<<16;j=fl[c[f>>2]&255](g+2&16777215)|0|i}i=j&d;c[240591]=i>>>24;c[240592]=i;c[240594]=0;c[240593]=0;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i>>>16&65535}else{fj[d&511](g&16777215,i>>>16)}d=g+2|0;g=d>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[a&511](d&16777215,i&65535);return}}function aEA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[962260+((a>>>9&7)<<2)>>2]|0;a=f>>>16&255;d=957128+(a*20|0)|0;g=c[d>>2]|0;if((g|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{i=(fl[g&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|i}i=j&h;c[240591]=i>>>24;c[240592]=i;c[240594]=0;c[240593]=0;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[h&511](f&16777215,i>>>16)}h=f+2|0;f=h>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]=i&65535;return}else{fj[a&511](h&16777215,i&65535);return}}function aEB(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j&a;c[240591]=i>>>24;c[240592]=i;c[240594]=0;c[240593]=0;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[a&511](d&16777215,i>>>16)}a=d+2|0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[f&511](a&16777215,i&65535);return}}function aEC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;h=d&255;d=957128+(h*20|0)|0;i=c[d>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[d>>2]&255](f+2&16777215)|0|j}j=k&g;c[240591]=j>>>24;c[240592]=j;c[240594]=0;c[240593]=0;g=c[957136+(h*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[g&511](f&16777215,j>>>16)}g=f+2|0;f=g>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[a&511](g&16777215,j&65535);return}}function aED(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=ab(c[b>>2]<<16>>16,g<<16>>16)|0;f=g&65535;a=g<<1&65534;if((a|0)==(f|0)){h=152}else{g=152;i=a^f;while(1){f=(i&1|0)==0?g:g+8|0;a=i>>1;if((a|0)==0){h=f;break}else{g=f;i=a}}}c[240563]=(c[240563]|0)+h;c[b>>2]=d;c[240592]=d;c[240591]=d>>>24;c[240593]=0;c[240594]=0;return}function aEE(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=ab(c[b>>2]<<16>>16,g<<16>>16)|0;f=g&65535;d=g<<1&65534;if((d|0)==(f|0)){h=152}else{g=152;i=d^f;while(1){f=(i&1|0)==0?g:g+8|0;d=i>>1;if((d|0)==0){h=f;break}else{g=f;i=d}}}c[240563]=(c[240563]|0)+h;c[b>>2]=a;c[240592]=a;c[240591]=a>>>24;c[240593]=0;c[240594]=0;return}function aEF(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=ab(c[b>>2]<<16>>16,g<<16>>16)|0;f=g&65535;d=g<<1&65534;if((d|0)==(f|0)){h=152}else{g=152;i=d^f;while(1){f=(i&1|0)==0?g:g+8|0;d=i>>1;if((d|0)==0){h=f;break}else{g=f;i=d}}}c[240563]=(c[240563]|0)+h;c[b>>2]=a;c[240592]=a;c[240591]=a>>>24;c[240593]=0;c[240594]=0;return}function aEG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240587]|0;d=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}g=ab(c[d>>2]<<16>>16,h<<16>>16)|0;a=h&65535;f=h<<1&65534;if((f|0)==(a|0)){i=152;j=c[240563]|0;k=j+i|0;c[240563]=k;c[d>>2]=g;c[240592]=g;l=g>>>24;c[240591]=l;c[240593]=0;c[240594]=0;return}h=152;m=f^a;while(1){a=(m&1|0)==0?h:h+8|0;f=m>>1;if((f|0)==0){i=a;break}else{h=a;m=f}}j=c[240563]|0;k=j+i|0;c[240563]=k;c[d>>2]=g;c[240592]=g;l=g>>>24;c[240591]=l;c[240593]=0;c[240594]=0;return}function aEH(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=ab(c[a>>2]<<16>>16,d)|0;f=(d<<1^d)&65535;if((f|0)==0){g=152}else{d=152;h=f;while(1){f=(h&1|0)==0?d:d+8|0;i=h>>1;if((i|0)==0){g=f;break}else{d=f;h=i}}}c[240563]=(c[240563]|0)+g;c[a>>2]=e;c[240592]=e;c[240591]=e>>>24;c[240593]=0;c[240594]=0;return}function aEI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=ab(c[a>>2]<<16>>16,h)|0;d=(h<<1^h)&65535;if((d|0)==0){i=152}else{h=152;f=d;while(1){d=(f&1|0)==0?h:h+8|0;j=f>>1;if((j|0)==0){i=d;break}else{h=d;f=j}}}c[240563]=(c[240563]|0)+i;c[a>>2]=g;c[240592]=g;c[240591]=g>>>24;c[240593]=0;c[240594]=0;return}function aEJ(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=ab(c[a>>2]<<16>>16,e)|0;f=(e<<1^e)&65535;if((f|0)==0){g=152}else{e=152;h=f;while(1){f=(h&1|0)==0?e:e+8|0;i=h>>1;if((i|0)==0){g=f;break}else{e=f;h=i}}}c[240563]=(c[240563]|0)+g;c[a>>2]=d;c[240592]=d;c[240591]=d>>>24;c[240593]=0;c[240594]=0;return}function aEK(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=d&255;e=c[b>>2]|0;f=e&255;g=f+a|0;c[240591]=g;c[240593]=(g^a)&(g^f);c[240594]=g;c[240590]=g;g=e+d&255;c[240592]=g;c[b>>2]=c[b>>2]&-256|g;return}function aEL(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=ab(c[b>>2]<<16>>16,h<<16>>16)|0;d=h&65535;g=h<<1&65534;if((g|0)==(d|0)){i=152;j=c[240563]|0;k=j+i|0;c[240563]=k;c[b>>2]=a;c[240592]=a;l=a>>>24;c[240591]=l;c[240593]=0;c[240594]=0;return}h=152;f=g^d;while(1){d=(f&1|0)==0?h:h+8|0;g=f>>1;if((g|0)==0){i=d;break}else{h=d;f=g}}j=c[240563]|0;k=j+i|0;c[240563]=k;c[b>>2]=a;c[240592]=a;l=a>>>24;c[240591]=l;c[240593]=0;c[240594]=0;return}function aEM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}f=ab(c[a>>2]<<16>>16,h<<16>>16)|0;g=h&65535;d=h<<1&65534;if((d|0)==(g|0)){i=152}else{h=152;j=d^g;while(1){g=(j&1|0)==0?h:h+8|0;d=j>>1;if((d|0)==0){i=g;break}else{h=g;j=d}}}c[240563]=(c[240563]|0)+i;c[a>>2]=f;c[240592]=f;c[240591]=f>>>24;c[240593]=0;c[240594]=0;return}function aEN(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+b>>1]|0}else{h=fl[g&255](b|d<<16&16711680)|0}d=ab(c[a>>2]<<16>>16,h<<16>>16)|0;b=h&65535;g=h<<1&65534;if((g|0)==(b|0)){i=152;j=c[240563]|0;k=j+i|0;c[240563]=k;c[a>>2]=d;c[240592]=d;l=d>>>24;c[240591]=l;c[240593]=0;c[240594]=0;return}h=152;f=g^b;while(1){b=(f&1|0)==0?h:h+8|0;g=f>>1;if((g|0)==0){i=b;break}else{h=b;f=g}}j=c[240563]|0;k=j+i|0;c[240563]=k;c[a>>2]=d;c[240592]=d;l=d>>>24;c[240591]=l;c[240593]=0;c[240594]=0;return}function aEO(){var b=0,e=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[240580]|0)-2|0;c[240580]=e;f=e>>>16&255;b=c[957124+(f*20|0)>>2]|0;if((b|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[b&255](e&16777215)|0}b=(h&15)+(g&15)+((c[240590]|0)>>>8&1)|0;i=(h&240)+(g&240)+(b>>>0>9?b+6|0:b)|0;g=i>>>0>153;h=(g&1)<<8;c[240594]=h;c[240590]=h;h=g?i-160|0:i;c[240593]=h&~b;c[240591]=h;b=h&255;c[240592]=b|c[240592];i=c[957132+(f*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,b);return}}function aEP(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[240580]|0}e=h-2|0;c[240580]=e;h=e>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[b&255](e&16777215)|0}b=(i&15)+(g&15)+((c[240590]|0)>>>8&1)|0;f=(i&240)+(g&240)+(b>>>0>9?b+6|0:b)|0;g=f>>>0>153;i=(g&1)<<8;c[240594]=i;c[240590]=i;i=g?f-160|0:f;c[240593]=i&~b;c[240591]=i;b=i&255;c[240592]=b|c[240592];f=c[957132+(h*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=i&255;return}else{fj[f&511](e&16777215,b);return}}function aEQ(){var a=0,b=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;e=c[962260+((a&7|8)<<2)>>2]|0;a=e>>>16&255;f=c[957124+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[b>>2]|0;f=e&255;a=f+g|0;c[240591]=a;c[240593]=(a^g)&(a^f);c[240594]=a;c[240590]=a;a=e+g&255;c[240592]=a;c[b>>2]=c[b>>2]&-256|a;return}function aER(){var a=0,b=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;e=962260+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+1;e=a>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(a&65535^1)|0]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;e=f+g|0;c[240591]=e;c[240593]=(e^g)&(e^f);c[240594]=e;c[240590]=e;e=a+g&255;c[240592]=e;c[b>>2]=c[b>>2]&-256|e;return}function aES(){var a=0,b=0,e=0,f=0,g=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[a>>2]|0;f=b&255;e=f+g|0;c[240591]=e;c[240593]=(e^g)&(e^f);c[240594]=e;c[240590]=e;e=b+g&255;c[240592]=e;c[a>>2]=c[a>>2]&-256|e;return}function aET(){var a=0,b=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;e=962260+((a&7|8)<<2)|0;a=(c[e>>2]|0)-1|0;c[e>>2]=a;e=a>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(a&65535^1)|0]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;e=f+g|0;c[240591]=e;c[240593]=(e^g)&(e^f);c[240594]=e;c[240590]=e;e=a+g&255;c[240592]=e;c[b>>2]=c[b>>2]&-256|e;return}function aEU(){var a=0,b=0,e=0,f=0,g=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[a>>2]|0;f=b&255;e=f+g|0;c[240591]=e;c[240593]=(e^g)&(e^f);c[240594]=e;c[240590]=e;e=b+g&255;c[240592]=e;c[a>>2]=c[a>>2]&-256|e;return}function aEV(){var a=0,e=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+e|0;e=d[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=c[a>>2]|0;g=f&255;h=g+e|0;c[240591]=h;c[240593]=(h^e)&(h^g);c[240594]=h;c[240590]=h;h=f+e&255;c[240592]=h;c[a>>2]=c[a>>2]&-256|h;return}function aEW(){var a=0,b=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+b+h|0;h=d[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=c[a>>2]|0;b=g&255;f=b+h|0;c[240591]=f;c[240593]=(f^h)&(f^b);c[240594]=f;c[240590]=f;f=g+h&255;c[240592]=f;c[a>>2]=c[a>>2]&-256|f;return}function aEX(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=d&255;f=c[a>>2]|0;g=f&255;h=b+g|0;c[240591]=h;c[240593]=(h^b)&(h^g);c[240594]=h;c[240590]=h;h=d+f&255;c[240592]=h;c[a>>2]=c[a>>2]&-256|h;return}function aEY(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f+a|0;h=g>>>8;c[240591]=h;c[240593]=((g^a)&(g^f))>>>8;c[240594]=h;c[240590]=h;h=e+d&65535;c[240592]=h;c[b>>2]=c[b>>2]&-65536|h;return}function aEZ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f+a|0;h=g>>>8;c[240591]=h;c[240593]=((g^a)&(g^f))>>>8;c[240594]=h;c[240590]=h;h=e+d&65535;c[240592]=h;c[b>>2]=c[b>>2]&-65536|h;return}function aE_(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[a>>2]|0;g=f&65535;h=g+d|0;i=h>>>8;c[240591]=i;c[240593]=((h^d)&(h^g))>>>8;c[240594]=i;c[240590]=i;i=f+d&65535;c[240592]=i;c[a>>2]=c[a>>2]&-65536|i;return}function aE$(){var a=0,e=0,f=0,g=0,h=0;a=c[240587]|0;e=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957124+(f*20|0)>>2]|0;if((a|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[a&255](g&16777215)|0}g=c[e>>2]|0;a=g&255;f=a+h|0;c[240591]=f;c[240593]=(f^h)&(f^a);c[240594]=f;c[240590]=f;f=g+h&255;c[240592]=f;c[e>>2]=c[e>>2]&-256|f;return}function aE0(){var a=0,b=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=a>>>16&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(a&65535^1)|0]|0}else{i=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&255;h=f+i|0;c[240591]=h;c[240593]=(h^i)&(h^f);c[240594]=h;c[240590]=h;h=a+i&255;c[240592]=h;c[b>>2]=c[b>>2]&-256|h;return}function aE1(){var a=0,e=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[a>>2]|0;g=f&255;e=g+h|0;c[240591]=e;c[240593]=(e^h)&(e^g);c[240594]=e;c[240590]=e;e=f+h&255;c[240592]=e;c[a>>2]=c[a>>2]&-256|e;return}function aE2(){var a=0,b=0,f=0,g=0,h=0,i=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=c[a>>2]|0;b=f&255;h=b+i|0;c[240591]=h;c[240593]=(h^i)&(h^b);c[240594]=h;c[240590]=h;h=f+i&255;c[240592]=h;c[a>>2]=c[a>>2]&-256|h;return}function aE3(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[b>>2]|0;f=d&65535;a=f+g|0;h=a>>>8;c[240591]=h;c[240593]=((a^g)&(a^f))>>>8;c[240594]=h;c[240590]=h;h=d+g&65535;c[240592]=h;c[b>>2]=c[b>>2]&-65536|h;return}function aE4(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&65535;d=f+g|0;h=d>>>8;c[240591]=h;c[240593]=((d^g)&(d^f))>>>8;c[240594]=h;c[240590]=h;h=a+g&65535;c[240592]=h;c[b>>2]=c[b>>2]&-65536|h;return}function aE5(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=c[b>>2]|0;f=a&65535;d=f+g|0;h=d>>>8;c[240591]=h;c[240593]=((d^g)&(d^f))>>>8;c[240594]=h;c[240590]=h;h=a+g&65535;c[240592]=h;c[b>>2]=c[b>>2]&-65536|h;return}function aE6(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}g=c[d>>2]|0;a=g&65535;f=a+h|0;i=f>>>8;c[240591]=i;c[240593]=((f^h)&(f^a))>>>8;c[240594]=i;c[240590]=i;i=g+h&65535;c[240592]=i;c[d>>2]=c[d>>2]&-65536|i;return}function aE7(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=c[b>>2]|0;d=a&65535;g=d+h|0;f=g>>>8;c[240591]=f;c[240593]=((g^h)&(g^d))>>>8;c[240594]=f;c[240590]=f;f=a+h&65535;c[240592]=f;c[b>>2]=c[b>>2]&-65536|f;return}function aE8(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}f=c[a>>2]|0;g=f&65535;d=g+h|0;i=d>>>8;c[240591]=i;c[240593]=((d^h)&(d^g))>>>8;c[240594]=i;c[240590]=i;i=f+h&65535;c[240592]=i;c[a>>2]=c[a>>2]&-65536|i;return}function aE9(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+b>>1]|0}else{h=fl[g&255](b|d<<16&16711680)|0}d=c[a>>2]|0;b=d&65535;g=b+h|0;f=g>>>8;c[240591]=f;c[240593]=((g^h)&(g^b))>>>8;c[240594]=f;c[240590]=f;f=d+h&65535;c[240592]=f;c[a>>2]=c[a>>2]&-65536|f;return}function aFa(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[a>>2]|0;b=f&65535;d=b+g|0;h=d>>>8;c[240591]=h;c[240593]=((d^g)&(d^b))>>>8;c[240594]=h;c[240590]=h;h=f+g&65535;c[240592]=h;c[a>>2]=c[a>>2]&-65536|h;return}function aFb(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[a>>2]|0;f=b&65535;g=f+d|0;h=g>>>8;c[240591]=h;c[240593]=((g^d)&(g^f))>>>8;c[240594]=h;c[240590]=h;h=b+d&65535;c[240592]=h;c[a>>2]=c[a>>2]&-65536|h;return}function aFc(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a+d|0;c[240591]=e>>>24;c[240593]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(a|d)|a&d)>>>23;c[240594]=f;c[240590]=f;c[240592]=e;c[b>>2]=e;return}function aFd(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[b>>2]|0;e=a+d|0;c[240591]=e>>>24;c[240593]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(a|d)|a&d)>>>23;c[240594]=f;c[240590]=f;c[240592]=e;c[b>>2]=e;return}function aFe(){var a=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]<<16;g=f+2|0;f=c[a>>2]|0;h=(e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|d)+f|0;c[240591]=h>>>24;c[240593]=((h^d)&(h^f))>>>24;g=((h^-8388608)&(f|d)|f&d)>>>23;c[240594]=g;c[240590]=g;c[240592]=h;c[a>>2]=h;return}function aFf(){var a=0,b=0,d=0,f=0,g=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;b=f+2|0;f=c[a>>2]|0;d=(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|g)+f|0;c[240591]=d>>>24;c[240593]=((d^g)&(d^f))>>>24;b=((d^-8388608)&(f|g)|f&g)>>>23;c[240594]=b;c[240590]=b;c[240592]=d;c[a>>2]=d;return}function aFg(){var a=0,b=0,d=0,f=0,g=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;f=b+2|0;b=c[a>>2]|0;g=(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d)+b|0;c[240591]=g>>>24;c[240593]=((g^d)&(g^b))>>>24;f=((g^-8388608)&(b|d)|b&d)>>>23;c[240594]=f;c[240590]=f;c[240592]=g;c[a>>2]=g;return}function aFh(){var a=0,b=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[962260+((a&7)<<2)>>2]<<16>>16)+(c[b>>2]|0);return}function aFi(){var a=0,b=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[962260+((a&7|8)<<2)>>2]<<16>>16)+(c[b>>2]|0);return}function aFj(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[b>>2]|0;d=a+i|0;c[240591]=d>>>24;c[240593]=((d^i)&(d^a))>>>24;f=((d^-8388608)&(a|i)|a&i)>>>23;c[240594]=f;c[240590]=f;c[240592]=d;c[b>>2]=d;return}function aFk(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+4;d=a>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{d=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|d}d=c[b>>2]|0;a=d+i|0;c[240591]=a>>>24;c[240593]=((a^i)&(a^d))>>>24;f=((a^-8388608)&(d|i)|d&i)>>>23;c[240594]=f;c[240590]=f;c[240592]=a;c[b>>2]=a;return}function aFl(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;f=a-4|0;c[d>>2]=f;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](a+16777214&16777215)|0|d}d=c[b>>2]|0;a=d+j|0;c[240591]=a>>>24;c[240593]=((a^j)&(a^d))>>>24;g=((a^-8388608)&(d|j)|d&j)>>>23;c[240594]=g;c[240590]=g;c[240592]=a;c[b>>2]=a;return}function aFm(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=962260+((a>>>9&7)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=957128+(f*20|0)|0;h=c[a>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]<<16}else{f=(fl[h&255](g&16777215)|0)<<16;j=fl[c[a>>2]&255](g+2&16777215)|0|f}f=c[d>>2]|0;g=f+j|0;c[240591]=g>>>24;c[240593]=((g^j)&(g^f))>>>24;a=((g^-8388608)&(f|j)|f&j)>>>23;c[240594]=a;c[240590]=a;c[240592]=g;c[d>>2]=g;return}function aFn(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=957128+(g*20|0)|0;f=c[d>>2]|0;if((f|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{g=(fl[f&255](a&16777215)|0)<<16;i=fl[c[d>>2]&255](a+2&16777215)|0|g}g=c[b>>2]|0;a=g+i|0;c[240591]=a>>>24;c[240593]=((a^i)&(a^g))>>>24;d=((a^-8388608)&(g|i)|g&i)>>>23;c[240594]=d;c[240590]=d;c[240592]=a;c[b>>2]=a;return}function aFo(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]<<16}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](f+2&16777215)|0|d}d=c[a>>2]|0;f=d+j|0;c[240591]=f>>>24;c[240593]=((f^j)&(f^d))>>>24;g=((f^-8388608)&(d|j)|d&j)>>>23;c[240594]=g;c[240590]=g;c[240592]=f;c[a>>2]=f;return}function aFp(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;g=d&255;d=957128+(g*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+b>>1]|0)<<16}else{b=(fl[h&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|b}b=c[a>>2]|0;f=b+j|0;c[240591]=f>>>24;c[240593]=((f^j)&(f^b))>>>24;d=((f^-8388608)&(b|j)|b&j)>>>23;c[240594]=d;c[240590]=d;c[240592]=f;c[a>>2]=f;return}function aFq(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}else{g=fl[f&255](d&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}}function aFr(){var a=0,d=0,e=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;c[a>>2]=(c[a>>2]|0)+(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0);return}function aFs(){var a=0,d=0,f=0,g=0,h=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+d+h|0;c[a>>2]=(c[a>>2]|0)+(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0);return}function aFt(){var a=0,d=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;c[a>>2]=(c[a>>2]|0)+(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0);return}function aFu(){var a=0,b=0,d=0,e=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]&255;a=c[b>>2]&255;e=a+d+((c[240590]|0)>>>8&1)|0;c[240591]=e;c[240593]=(e^d)&(e^a);c[240594]=e;c[240590]=e;a=e&255;c[240592]=a|c[240592];c[b>>2]=a|c[b>>2]&-256;return}function aFv(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}else{g=fl[f&255](a&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}}function aFw(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=962260+((a&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}else{g=fl[f&255](a&16777215)|0;h=g<<16;i=h>>16;j=c[b>>2]|0;k=i+j|0;c[b>>2]=k;return}}function aFx(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;d=962260+((a>>>9&7|8)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0;i=h<<16;j=i>>16;k=c[d>>2]|0;l=j+k|0;c[d>>2]=l;return}else{h=fl[a&255](g&16777215)|0;i=h<<16;j=i>>16;k=c[d>>2]|0;l=j+k|0;c[d>>2]=l;return}}function aFy(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0;i=h<<16;j=i>>16;k=c[b>>2]|0;l=j+k|0;c[b>>2]=l;return}else{h=fl[d&255](a&16777215)|0;i=h<<16;j=i>>16;k=c[b>>2]|0;l=j+k|0;c[b>>2]=l;return}}function aFz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=j+k|0;c[a>>2]=l;return}else{h=fl[g&255](f&16777215)|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=j+k|0;c[a>>2]=l;return}}function aFA(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+b>>1]|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=j+k|0;c[a>>2]=l;return}else{h=fl[g&255](b|d<<16&16711680)|0;i=h<<16;j=i>>16;k=c[a>>2]|0;l=j+k|0;c[a>>2]=l;return}}function aFB(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;b=c[957124+(e*20|0)>>2]|0;if((b|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[b&255](f&16777215)|0}b=h+g+((c[240590]|0)>>>8&1)|0;c[240591]=b;c[240593]=(b^g)&(b^h);c[240594]=b;c[240590]=b;h=b&255;c[240592]=h|c[240592];g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[g&511](f&16777215,h);return}}function aFC(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[e&255](f&16777215)|0}e=h+g+((c[240590]|0)>>>8&1)|0;c[240591]=e;c[240593]=(e^g)&(e^h);c[240594]=e;c[240590]=e;h=e&255;c[240592]=h|c[240592];g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[g&511](f&16777215,h);return}}function aFD(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=c[962260+((b>>>9&7)<<2)>>2]|0;b=f&255;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i+b|0;c[240591]=h;c[240593]=(h^b)&(h^i);c[240594]=h;c[240590]=h;h=i+f|0;f=h&255;c[240592]=f;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,f);return}}function aFE(){var b=0,e=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=b&255;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i+f|0;c[240591]=h;c[240593]=(h^f)&(h^i);c[240594]=h;c[240590]=h;h=i+b|0;b=h&255;c[240592]=b;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,b);return}}function aFF(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240580]|0;c[240580]=b+2;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=e&255;g=b>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]|0}else{i=fl[h&255](b&16777215)|0}h=i+f|0;c[240591]=h;c[240593]=(h^f)&(h^i);c[240594]=h;c[240590]=h;h=i+e|0;e=h&255;c[240592]=e;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[i&511](b&16777215,e);return}}function aFG(){var b=0,e=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=b&255;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i+f|0;c[240591]=h;c[240593]=(h^f)&(h^i);c[240594]=h;c[240590]=h;h=i+b|0;b=h&255;c[240592]=b;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,b);return}}function aFH(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]&65535;a=c[b>>2]&65535;e=a+d+((c[240590]|0)>>>8&1)|0;f=e>>>8;c[240591]=f;c[240593]=((e^d)&(e^a))>>>8;c[240594]=f;c[240590]=f;f=e&65535;c[240592]=f|c[240592];c[b>>2]=f|c[b>>2]&-65536;return}function aFI(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[240580]|0)-2|0;c[240580]=b;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=e&255;g=b>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]|0}else{i=fl[h&255](b&16777215)|0}h=i+f|0;c[240591]=h;c[240593]=(h^f)&(h^i);c[240594]=h;c[240590]=h;h=i+e|0;e=h&255;c[240592]=e;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[i&511](b&16777215,e);return}}function aFJ(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=c[962260+((e>>>9&7)<<2)>>2]|0;e=f&255;g=h>>>16&255;i=c[957124+(g*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]|0}else{j=fl[i&255](h&16777215)|0}i=j+e|0;c[240591]=i;c[240593]=(i^e)&(i^j);c[240594]=i;c[240590]=i;i=j+f|0;f=i&255;c[240592]=f;j=c[957132+(g*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]=i&255;return}else{fj[j&511](h&16777215,f);return}}function aFK(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=c[962260+((b>>>9&7)<<2)>>2]|0;b=i&255;f=g>>>16&255;h=c[957124+(f*20|0)>>2]|0;if((h|0)==0){j=d[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[h&255](g&16777215)|0}h=j+b|0;c[240591]=h;c[240593]=(h^b)&(h^j);c[240594]=h;c[240590]=h;h=j+i|0;i=h&255;c[240592]=i;j=c[957132+(f*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[j&511](g&16777215,i);return}}function aFL(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;g=e&255;h=f>>>16&255;i=c[957124+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{j=fl[i&255](f&16777215)|0}i=j+g|0;c[240591]=i;c[240593]=(i^g)&(i^j);c[240594]=i;c[240590]=i;i=j+e|0;e=i&255;c[240592]=e;j=c[957132+(h*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[j&511](f&16777215,e);return}}function aFM(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;i=h&255;j=f&255;f=c[957124+(j*20|0)>>2]|0;if((f|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(b^1)|0]|0}else{k=fl[f&255](g&16777215)|0}f=k+i|0;c[240591]=f;c[240593]=(f^i)&(f^k);c[240594]=f;c[240590]=f;f=k+h|0;h=f&255;c[240592]=h;k=c[957132+(j*20|0)>>2]|0;if((k|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[k&511](g&16777215,h);return}}function aFN(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-2|0;c[d>>2]=f;d=f>>>16&255;a=c[957128+(d*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[a&255](f&16777215)|0}a=h+g+((c[240590]|0)>>>8&1)|0;i=a>>>8;c[240591]=i;c[240593]=((a^g)&(a^h))>>>8;c[240594]=i;c[240590]=i;i=a&65535;c[240592]=i|c[240592];h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[h&511](f&16777215,i);return}}function aFO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7)<<2)>>2]|0;a=f&65535;g=d>>>16&255;h=c[957128+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{i=fl[h&255](d&16777215)|0}h=i+a|0;j=h>>>8;c[240591]=j;c[240593]=((h^a)&(h^i))>>>8;c[240594]=j;c[240590]=j;j=i+f|0;f=j&65535;c[240592]=f;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[i&511](d&16777215,f);return}}function aFP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=a&65535;g=d>>>16&255;h=c[957128+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{i=fl[h&255](d&16777215)|0}h=i+f|0;j=h>>>8;c[240591]=j;c[240593]=((h^f)&(h^i))>>>8;c[240594]=j;c[240590]=j;j=i+a|0;a=j&65535;c[240592]=a;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[i&511](d&16777215,a);return}}function aFQ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=a&65535;g=d>>>16&255;h=c[957128+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{i=fl[h&255](d&16777215)|0}h=i+f|0;j=h>>>8;c[240591]=j;c[240593]=((h^f)&(h^i))>>>8;c[240594]=j;c[240590]=j;j=i+a|0;a=j&65535;c[240592]=a;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[i&511](d&16777215,a);return}}function aFR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=d&65535;f=g>>>16&255;h=c[957128+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{i=fl[h&255](g&16777215)|0}h=i+a|0;j=h>>>8;c[240591]=j;c[240593]=((h^a)&(h^i))>>>8;c[240594]=j;c[240590]=j;j=i+d|0;d=j&65535;c[240592]=d;i=c[957136+(f*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[i&511](g&16777215,d);return}}function aFS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[962260+((a>>>9&7)<<2)>>2]|0;a=h&65535;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{i=fl[g&255](f&16777215)|0}g=i+a|0;j=g>>>8;c[240591]=j;c[240593]=((g^a)&(g^i))>>>8;c[240594]=j;c[240590]=j;j=i+h|0;h=j&65535;c[240592]=h;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[i&511](f&16777215,h);return}}function aFT(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a>>>9&7)<<2)|0;d=c[962260+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a+d+((c[240590]|0)>>>8&1)|0;c[240591]=e>>>24;c[240593]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(a|d)|a&d)>>>23;c[240594]=f;c[240590]=f;c[240592]=e|c[240592];c[b>>2]=e;return}function aFU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=a&65535;g=d>>>16&255;h=c[957128+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{i=fl[h&255](d&16777215)|0}h=i+f|0;j=h>>>8;c[240591]=j;c[240593]=((h^f)&(h^i))>>>8;c[240594]=j;c[240590]=j;j=i+a|0;a=j&65535;c[240592]=a;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[i&511](d&16777215,a);return}}function aFV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;h=g&65535;i=d&255;d=c[957128+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[957120+(i*20|0)>>2]|0)+a>>1]|0}else{j=fl[d&255](f&16777215)|0}d=j+h|0;k=d>>>8;c[240591]=k;c[240593]=((d^h)&(d^j))>>>8;c[240594]=k;c[240590]=k;k=j+g|0;g=k&65535;c[240592]=g;j=c[957136+(i*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(i*20|0)>>2]|0)+a>>1]=k&65535;return}else{fj[j&511](f&16777215,g);return}}function aFW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;a=g>>>16&255;f=957128+(a*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=d-2|0;k=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{i=(fl[h&255](g&16777215)|0)<<16;k=fl[c[f>>2]&255](d+16777214&16777215)|0|i}i=k+j+((c[240590]|0)>>>8&1)|0;c[240591]=i>>>24;c[240593]=((i^j)&(i^k))>>>24;f=((i^-8388608)&(k|j)|k&j)>>>23;c[240594]=f;c[240590]=f;c[240592]=i|c[240592];f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i>>>16&65535}else{fj[f&511](g&16777215,i>>>16)}g=d-2|0;d=g>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[f&511](g&16777215,i&65535);return}}function aFX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7)<<2)>>2]|0;a=d>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j+f|0;c[240591]=i>>>24;c[240593]=((i^f)&(i^j))>>>24;g=((i^-8388608)&(j|f)|j&f)>>>23;c[240594]=g;c[240590]=g;c[240592]=i;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[g&511](d&16777215,i>>>16)}g=d+2|0;d=g>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[a&511](g&16777215,i&65535);return}}function aFY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j+a|0;c[240591]=i>>>24;c[240593]=((i^a)&(i^j))>>>24;g=((i^-8388608)&(j|a)|j&a)>>>23;c[240594]=g;c[240590]=g;c[240592]=i;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[g&511](d&16777215,i>>>16)}g=d+2|0;d=g>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[f&511](g&16777215,i&65535);return}}function aFZ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;g=f>>>16&255;h=957128+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[h>>2]&255](d+16777214&16777215)|0|j}j=k+a|0;c[240591]=j>>>24;c[240593]=((j^a)&(j^k))>>>24;h=((j^-8388608)&(k|a)|k&a)>>>23;c[240594]=h;c[240590]=h;c[240592]=j;h=c[957136+(g*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[h&511](f&16777215,j>>>16)}f=d-2|0;d=f>>>16&255;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[h&511](f&16777215,j&65535);return}}function aF_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=g>>>16&255;f=957128+(a*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]<<16}else{i=(fl[h&255](g&16777215)|0)<<16;j=fl[c[f>>2]&255](g+2&16777215)|0|i}i=j+d|0;c[240591]=i>>>24;c[240593]=((i^d)&(i^j))>>>24;f=((i^-8388608)&(j|d)|j&d)>>>23;c[240594]=f;c[240590]=f;c[240592]=i;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i>>>16&65535}else{fj[f&511](g&16777215,i>>>16)}f=g+2|0;g=f>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[a&511](f&16777215,i&65535);return}}function aF$(){var a=0,b=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[962260+((a&7)<<2)>>2]|0)+(c[b>>2]|0);return}function aF0(){var a=0,b=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[962260+((a&7|8)<<2)>>2]|0)+(c[b>>2]|0);return}function aF1(){var a=0,d=0,f=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=f+2|0;c[a>>2]=(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]<<16)+(c[a>>2]|0);return}function aF2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[962260+((a>>>9&7)<<2)>>2]|0;a=f>>>16&255;d=957128+(a*20|0)|0;g=c[d>>2]|0;if((g|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{i=(fl[g&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|i}i=j+h|0;c[240591]=i>>>24;c[240593]=((i^h)&(i^j))>>>24;d=((i^-8388608)&(j|h)|j&h)>>>23;c[240594]=d;c[240590]=d;c[240592]=i;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[d&511](f&16777215,i>>>16)}d=f+2|0;f=d>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[a&511](d&16777215,i&65535);return}}function aF3(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j+a|0;c[240591]=i>>>24;c[240593]=((i^a)&(i^j))>>>24;g=((i^-8388608)&(j|a)|j&a)>>>23;c[240594]=g;c[240590]=g;c[240592]=i;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[g&511](d&16777215,i>>>16)}g=d+2|0;d=g>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[f&511](g&16777215,i&65535);return}}function aF4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;h=d&255;d=957128+(h*20|0)|0;i=c[d>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[d>>2]&255](f+2&16777215)|0|j}j=k+g|0;c[240591]=j>>>24;c[240593]=((j^g)&(j^k))>>>24;d=((j^-8388608)&(k|g)|k&g)>>>23;c[240594]=d;c[240590]=d;c[240592]=j;d=c[957136+(h*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[d&511](f&16777215,j>>>16)}d=f+2|0;f=d>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[a&511](d&16777215,j&65535);return}}function aF5(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}}function aF6(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+4;d=a>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}else{d=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|d;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}}function aF7(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=962260+((a&7|8)<<2)|0;a=c[d>>2]|0;f=a-4|0;c[d>>2]=f;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=c[b>>2]|0;l=k+j|0;c[b>>2]=l;return}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](a+16777214&16777215)|0|d;k=c[b>>2]|0;l=k+j|0;c[b>>2]=l;return}}function aF8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;d=962260+((a>>>9&7|8)<<2)|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=957128+(f*20|0)|0;h=c[a>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]<<16;k=c[d>>2]|0;l=k+j|0;c[d>>2]=l;return}else{f=(fl[h&255](g&16777215)|0)<<16;j=fl[c[a>>2]&255](g+2&16777215)|0|f;k=c[d>>2]|0;l=k+j|0;c[d>>2]=l;return}}function aF9(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a>>>9&7|8)<<2)|0;d=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=a<<16>>16}else{g=a}a=(f<<24>>24)+d+g|0;g=a>>>16&255;d=957128+(g*20|0)|0;f=c[d>>2]|0;if((f|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}else{g=(fl[f&255](a&16777215)|0)<<16;i=fl[c[d>>2]&255](a+2&16777215)|0|g;j=c[b>>2]|0;k=j+i|0;c[b>>2]=k;return}}function aGa(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]<<16;k=c[a>>2]|0;l=k+j|0;c[a>>2]=l;return}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](f+2&16777215)|0|d;k=c[a>>2]|0;l=k+j|0;c[a>>2]=l;return}}function aGb(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;g=d&255;d=957128+(g*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+b>>1]|0)<<16;k=c[a>>2]|0;l=k+j|0;c[a>>2]=l;return}else{b=(fl[h&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|b;k=c[a>>2]|0;l=k+j|0;c[a>>2]=l;return}}function aGc(){var a=0,b=0,d=0,f=0,g=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=f+2|0;c[a>>2]=(e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)<<16)+(c[a>>2]|0);return}function aGd(){var a=0,b=0,d=0;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=b+2|0;c[a>>2]=(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16)+(c[a>>2]|0);return}function aGe(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;e=(a>>>9)+7&7;a=e+1|0;f=c[b>>2]|0;g=f&255;h=g>>>(a>>>0);c[240563]=(a<<3)+(c[240563]|0);if((f&128|0)==0){i=h}else{i=d[11504+a|0]|0|h}c[b>>2]=c[b>>2]&-256|i;c[240591]=i;c[240592]=i;c[240593]=0;i=g<<8-e;c[240594]=i;c[240590]=i;return}function aGf(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]&255;f=e>>>(a>>>0);c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f|c[b>>2]&-256;c[240591]=0;c[240592]=f;f=e<<8-d;c[240594]=f;c[240590]=f;c[240593]=0;return}function aGg(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[240590]&256|c[b>>2]&255;f=e>>>(a>>>0)|e<<8-d;c[240563]=(a<<3)+(c[240563]|0);c[240590]=f;c[240594]=f;a=f&255;c[b>>2]=a|c[b>>2]&-256;c[240591]=a;c[240592]=a;c[240593]=0;return}function aGh(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=a>>>9;a=d+7&7;e=d&7;d=c[b>>2]&255;f=(d<<8-e|d>>>(e>>>0))&255;c[240563]=(c[240563]|0)+8+(a<<3);c[b>>2]=f|c[b>>2]&-256;c[240591]=f;c[240592]=f;c[240594]=d<<8-a;c[240593]=0;return}function aGi(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[240594]=c[240590];c[240591]=c[b>>2];e=c[b>>2]&255;c[240592]=e;c[240593]=0;return}else{a=(d>>>0)%9|0;f=c[240590]&256|c[b>>2]&255;g=f>>>(a>>>0)|f<<9-a;c[240563]=(c[240563]|0)+(d<<3);c[240590]=g;c[240594]=g;d=g&255;c[b>>2]=d|c[b>>2]&-256;c[240591]=d;e=d;c[240592]=e;c[240593]=0;return}}function aGj(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&7;f=c[b>>2]&255;g=(f>>>(e>>>0)|f<<8-e)&255;if((a|0)==0){h=f;i=0}else{c[240563]=(c[240563]|0)+(a<<3);c[b>>2]=c[b>>2]&-256|g;h=g;i=f<<8-(d+7&7)}c[240594]=i;c[240591]=h;c[240592]=h;c[240593]=0;return}function aGk(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;f=c[b>>2]|0;g=f&65535;h=g>>>(a>>>0);c[240563]=(a<<3)+(c[240563]|0);if((f&32768|0)==0){i=h}else{i=e[11840+(a<<1)>>1]|0|h}c[b>>2]=c[b>>2]&-65536|i;c[240591]=i>>>8;c[240592]=i;c[240593]=0;i=g<<8-d;c[240594]=i;c[240590]=i;return}function aGl(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]&65535;f=e>>>(a>>>0);c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f|c[b>>2]&-65536;c[240591]=0;c[240592]=f;f=e<<8-d;c[240594]=f;c[240590]=f;c[240593]=0;return}function aGm(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=(c[240590]|0)>>>8<<16&65536|c[b>>2]&65535;f=e>>>(a>>>0)|e<<16-d;c[240563]=(a<<3)+(c[240563]|0);a=f>>>8;c[240590]=a;c[240594]=a;a=f&65535;c[b>>2]=a|c[b>>2]&-65536;c[240591]=a>>>8;c[240592]=a;c[240593]=0;return}function aGn(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]&65535;f=(e>>>(a>>>0)|e<<(d^15))&65535;c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f|c[b>>2]&-65536;c[240591]=f>>>8;c[240592]=f;c[240594]=e<<8-d;c[240593]=0;return}function aGo(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[240594]=c[240590];c[240591]=(c[b>>2]|0)>>>8;e=c[b>>2]&65535;c[240592]=e;c[240593]=0;return}else{a=(d>>>0)%17|0;f=(c[240590]|0)>>>8<<16&65536|c[b>>2]&65535;g=f>>>(a>>>0)|f<<17-a;c[240563]=(c[240563]|0)+(d<<3);d=g>>>8;c[240590]=d;c[240594]=d;d=g&65535;c[b>>2]=d|c[b>>2]&-65536;c[240591]=d>>>8;e=d;c[240592]=e;c[240593]=0;return}}function aGp(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[240580]|0)-2|0;c[240580]=e;f=e>>>16&255;b=c[957124+(f*20|0)>>2]|0;if((b|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[b&255](e&16777215)|0}b=h+g+((c[240590]|0)>>>8&1)|0;c[240591]=b;c[240593]=(b^g)&(b^h);c[240594]=b;c[240590]=b;h=b&255;c[240592]=h|c[240592];g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[g&511](e&16777215,h);return}}function aGq(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[240580]|0}e=h-2|0;c[240580]=e;h=e>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[b&255](e&16777215)|0}b=i+g+((c[240590]|0)>>>8&1)|0;c[240591]=b;c[240593]=(b^g)&(b^i);c[240594]=b;c[240590]=b;i=b&255;c[240592]=i|c[240592];g=c[957132+(h*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[g&511](e&16777215,i);return}}
function Rn(){var a=0,d=0,e=0,f=0,g=0;a=c[291667]|0;d=a+2|0;c[291667]=d;e=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f&65535;g=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;c[291677]=e>>>8;c[291678]=e;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f;return}else{fj[d&511](a&16777215,e);return}}function Ro(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+f|0;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=a>>>16&255;d=c[1161480+(f*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]=h;return}else{fj[d&511](a&16777215,g);return}}function Rp(){var a=0,d=0,e=0,f=0,g=0;a=c[291667]|0;d=a+2|0;c[291667]=d;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=e&65535;g=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=e;return}else{fj[d&511](a&16777215,f);return}}function Rq(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7)<<2)>>2]|0;f=d&65535;g=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;h=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=a<<16>>16}else{i=a}a=(h<<24>>24)+g+i|0;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;g=c[1161480+(i*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,f);return}}function Rr(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=d&65535;g=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;h=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=a<<16>>16}else{i=a}a=(h<<24>>24)+g+i|0;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;g=c[1161480+(i*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,f);return}}function Rs(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291673]|0}a=c[1166604+((i>>>9&7|8)<<2)>>2]|0;i=c[291667]|0;c[291667]=i+2;d=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){j=i<<16>>16}else{j=i}i=(d<<24>>24)+a+j|0;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((i&1|0)!=0&(c[291688]|0)!=0){j=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=i>>>16&255;a=c[1161480+(j*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[a&511](i&16777215,h);return}}function Rt(){var a=0,d=0,f=0,g=0,h=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=f<<16>>16}else{h=f}f=(a<<24>>24)+d+h|0;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;d=c[1161480+(h*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[d&511](f&16777215,g);return}}function Ru(){var a=0,d=0,f=0,g=0,h=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=f<<16>>16}else{h=f}f=(a<<24>>24)+d+h|0;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;d=c[1161480+(h*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[d&511](f&16777215,g);return}}function Rv(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;if((h&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=h;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=h>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){i=e[(c[1161464+(d*20|0)>>2]|0)+(h&65535)>>1]|0;j=a;k=g}else{g=fl[f&255](h&16777215)|0;i=g;j=c[291673]|0;k=c[291667]|0}g=c[1166604+((j>>>9&7|8)<<2)>>2]|0;c[291667]=k+2;j=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;k=c[1166604+(j>>>12<<2)>>2]|0;if((j&2048|0)==0){l=k<<16>>16}else{l=k}k=(j<<24>>24)+g+l|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((k&1|0)!=0&(c[291688]|0)!=0){l=c[291675]|1;c[291699]=k;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=k>>>16&255;g=c[1161480+(l*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(k&65535)>>1]=i&65535;return}else{fj[g&511](k&16777215,i);return}}function Rw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=f<<16>>16}else{i=f}f=(h<<24>>24)+d+i|0;if((f&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]|0;k=a;l=g}else{g=fl[d&255](f&16777215)|0;j=g;k=c[291673]|0;l=c[291667]|0}g=c[1166604+((k>>>9&7|8)<<2)>>2]|0;c[291667]=l+2;k=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;l=c[1166604+(k>>>12<<2)>>2]|0;if((k&2048|0)==0){m=l<<16>>16}else{m=l}l=(k<<24>>24)+g+m|0;c[291677]=j>>>8;c[291678]=j;c[291679]=0;c[291680]=0;if((l&1|0)!=0&(c[291688]|0)!=0){m=c[291675]|1;c[291699]=l;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=l>>>16&255;g=c[1161480+(m*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+(l&65535)>>1]=j&65535;return}else{fj[g&511](l&16777215,j);return}}function Rx(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=c[1161472+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]|0;i=d}else{d=fl[g&255](f&16777215)|0;h=d;i=c[291667]|0}d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=i+2;f=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=i<<16>>16}else{j=i}i=(f<<24>>24)+d+j|0;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((i&1|0)!=0&(c[291688]|0)!=0){j=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=i>>>16&255;d=c[1161480+(j*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[d&511](i&16777215,h);return}}function Ry(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|f<<16;if((a&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f&255;f=c[1161472+(h*20|0)>>2]|0;if((f|0)==0){i=e[(c[1161464+(h*20|0)>>2]|0)+a>>1]|0;j=d}else{d=fl[f&255](g&16777215)|0;i=d;j=c[291667]|0}d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=j+2;g=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;j=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){k=j<<16>>16}else{k=j}j=(g<<24>>24)+d+k|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((j&1|0)!=0&(c[291688]|0)!=0){k=c[291675]|1;c[291699]=j;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=j>>>16&255;d=c[1161480+(k*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(j&65535)>>1]=i&65535;return}else{fj[d&511](j&16777215,i);return}}function Rz(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g&65535;h=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=d<<16>>16}else{i=d}d=(a<<24>>24)+h+i|0;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=d>>>16&255;h=c[1161480+(i*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]=g;return}else{fj[h&511](d&16777215,f);return}}function RA(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=d<<16>>16}else{i=d}d=(a<<24>>24)+f+i|0;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=d>>>16&255;f=c[1161480+(i*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]=h;return}else{fj[f&511](d&16777215,g);return}}function RB(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=f&65535;h=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=d<<16>>16}else{i=d}d=(a<<24>>24)+h+i|0;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=d>>>16&255;h=c[1161480+(i*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]=f;return}else{fj[h&511](d&16777215,g);return}}function RC(){var a=0,d=0,e=0,f=0,g=0;a=c[1166604+((c[291673]&7)<<2)>>2]|0;d=a&65535;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[291677]=d>>>8;c[291678]=d;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=f>>>16&255;g=c[1161480+(e*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[g&511](f&16777215,d);return}}function RD(){var a=0,d=0,e=0,f=0,g=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=a&65535;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[291677]=d>>>8;c[291678]=d;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=f>>>16&255;g=c[1161480+(e*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[g&511](f&16777215,d);return}}function RE(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291688]|0;if((a&1|0)!=0&(d|0)!=0){f=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=a>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]|0;i=d}else{d=fl[g&255](a&16777215)|0;h=d;i=c[291688]|0}d=c[291667]|0;c[291667]=d+2;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;d=c[1161480+(i*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[d&511](a&16777215,h);return}}function RF(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291688]|0}a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=d>>>16&255;a=c[1161480+(i*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]=h&65535;return}else{fj[a&511](d&16777215,h);return}}function RG(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291688]|0}a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=d>>>16&255;a=c[1161480+(i*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(d&65535)>>1]=h&65535;return}else{fj[a&511](d&16777215,h);return}}function RH(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=c[291688]|0;if((g&1|0)!=0&(a|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;h=c[1161472+(d*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;j=f;k=a}else{a=fl[h&255](g&16777215)|0;i=a;j=c[291667]|0;k=c[291688]|0}c[291667]=j+2;a=b[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=a>>>16&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[j&511](a&16777215,i);return}}function RI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=d<<16>>16}else{h=d}d=(g<<24>>24)+a+h|0;h=c[291688]|0;if((d&1|0)!=0&(h|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;g=c[1161472+(a*20|0)>>2]|0;if((g|0)==0){i=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;j=f;k=h}else{h=fl[g&255](d&16777215)|0;i=h;j=c[291667]|0;k=c[291688]|0}c[291667]=j+2;h=b[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((h&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=h>>>16&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(h&65535)>>1]=i&65535;return}else{fj[j&511](h&16777215,i);return}}function RJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[291688]|0;if((f&1|0)!=0&(a|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d;k=a}else{a=fl[h&255](f&16777215)|0;i=a;j=c[291667]|0;k=c[291688]|0}c[291667]=j+2;a=b[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=a>>>16&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[j&511](a&16777215,i);return}}function RK(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|f<<16;h=c[291688]|0;if((a&1|0)!=0&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f&255;f=c[1161472+(i*20|0)>>2]|0;if((f|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=d;l=h}else{h=fl[f&255](g&16777215)|0;j=h;k=c[291667]|0;l=c[291688]|0}c[291667]=k+2;h=b[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;c[291677]=j>>>8;c[291678]=j;c[291679]=0;c[291680]=0;if((h&1|0)!=0&(l|0)!=0){l=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=h>>>16&255;k=c[1161480+(l*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[k&511](h&16777215,j);return}}function RL(){var a=0,d=0,e=0,f=0,g=0;a=c[291667]|0;d=a+2|0;c[291667]=d;e=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f&65535;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=e>>>8;c[291678]=e;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=f;return}else{fj[g&511](a&16777215,e);return}}function RM(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=h;return}else{fj[f&511](a&16777215,g);return}}function RN(){var a=0,d=0,e=0,f=0,g=0;a=c[291667]|0;d=a+2|0;c[291667]=d;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=e&65535;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=e;return}else{fj[g&511](a&16777215,f);return}}function RO(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[1166604+((c[291673]&7)<<2)>>2]|0;d=a&65535;f=c[291667]|0;c[291667]=f+4;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=f|g<<16;c[291677]=d>>>8;c[291678]=d;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=g&255;g=c[1161480+(i*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+f>>1]=a&65535;return}else{fj[g&511](h&16777215,d);return}}function RP(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=a&65535;f=c[291667]|0;c[291667]=f+4;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=f|g<<16;c[291677]=d>>>8;c[291678]=d;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=g&255;g=c[1161480+(i*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+f>>1]=a&65535;return}else{fj[g&511](h&16777215,d);return}}function RQ(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291688]|0;if((a&1|0)!=0&(d|0)!=0){f=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=a>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]|0;i=d}else{d=fl[g&255](a&16777215)|0;h=d;i=c[291688]|0}d=c[291667]|0;c[291667]=d+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|a<<16;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=a&255;a=c[1161480+(i*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+d>>1]=h&65535;return}else{fj[a&511](g&16777215,h);return}}function RR(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291688]|0}a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|d<<16;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161480+(i*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535;return}else{fj[d&511](g&16777215,h);return}}function RS(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291688]|0}a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|d<<16;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161480+(i*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535;return}else{fj[d&511](g&16777215,h);return}}function RT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=c[291688]|0;if((g&1|0)!=0&(a|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;h=c[1161472+(d*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;j=f;k=a}else{a=fl[h&255](g&16777215)|0;i=a;j=c[291667]|0;k=c[291688]|0}c[291667]=j+4;a=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;g=j+2|0;j=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=j|a<<16;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((j&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=a&255;a=c[1161480+(k*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+j>>1]=i&65535;return}else{fj[a&511](g&16777215,i);return}}function RU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=d<<16>>16}else{h=d}d=(g<<24>>24)+a+h|0;h=c[291688]|0;if((d&1|0)!=0&(h|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;g=c[1161472+(a*20|0)>>2]|0;if((g|0)==0){i=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;j=f;k=h}else{h=fl[g&255](d&16777215)|0;i=h;j=c[291667]|0;k=c[291688]|0}c[291667]=j+4;h=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;d=j+2|0;j=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=j|h<<16;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((j&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=h&255;h=c[1161480+(k*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+j>>1]=i&65535;return}else{fj[h&511](d&16777215,i);return}}function RV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[291688]|0;if((f&1|0)!=0&(a|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d;k=a}else{a=fl[h&255](f&16777215)|0;i=a;j=c[291667]|0;k=c[291688]|0}c[291667]=j+4;a=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;f=j+2|0;j=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=j|a<<16;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((j&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=a&255;a=c[1161480+(k*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+j>>1]=i&65535;return}else{fj[a&511](f&16777215,i);return}}function RW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|f<<16;h=c[291688]|0;if((a&1|0)!=0&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f&255;f=c[1161472+(i*20|0)>>2]|0;if((f|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=d;l=h}else{h=fl[f&255](g&16777215)|0;j=h;k=c[291667]|0;l=c[291688]|0}c[291667]=k+4;h=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;g=k+2|0;k=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=k|h<<16;c[291677]=j>>>8;c[291678]=j;c[291679]=0;c[291680]=0;if((k&1|0)!=0&(l|0)!=0){l=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=h&255;h=c[1161480+(l*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+k>>1]=j&65535;return}else{fj[h&511](g&16777215,j);return}}function RX(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g&65535;c[291667]=a+6;h=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|h<<16;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=h&255;h=c[1161480+(i*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=g;return}else{fj[h&511](d&16777215,f);return}}function RY(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;c[291667]=a+6;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|f<<16;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=f&255;f=c[1161480+(i*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h;return}else{fj[f&511](d&16777215,g);return}}function RZ(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=-(((c[291676]|0)>>>8&1)+(c[a>>2]&255)|0)|0;c[291677]=b;c[291680]=b;c[291676]=b;c[291679]=c[a>>2]&b;d=b&255;c[291678]=d|c[291678];c[a>>2]=c[a>>2]&-256|d;return}function R_(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=-(((c[291676]|0)>>>8&1)+(c[a>>2]&65535)|0)|0;d=b>>>8;c[291677]=d;c[291680]=d;c[291676]=d;c[291679]=(c[a>>2]&b)>>>8;d=b&65535;c[291678]=d|c[291678];c[a>>2]=c[a>>2]&-65536|d;return}function R$(){var b=0,e=0,f=0,g=0,h=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-(((c[291676]|0)>>>8&1)+g|0)|0;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=g&f;g=f&255;c[291678]=g|c[291678];h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function R0(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=-(((c[291676]|0)>>>8&1)+g|0)|0;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=g&f;g=f&255;c[291678]=g|c[291678];h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[h&511](e&16777215,g);return}}function R1(){var b=0,e=0,f=0,g=0,h=0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-(((c[291676]|0)>>>8&1)+g|0)|0;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=g&f;g=f&255;c[291678]=g|c[291678];h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function R2(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=-(((c[291676]|0)>>>8&1)+g|0)|0;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=g&f;g=f&255;c[291678]=g|c[291678];h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[h&511](e&16777215,g);return}}function R3(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-(((c[291676]|0)>>>8&1)+g|0)|0;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=g&f;g=f&255;c[291678]=g|c[291678];h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function R4(){var e=0,f=0,g=0,h=0,i=0;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}f=-(((c[291676]|0)>>>8&1)+h|0)|0;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=h&f;h=f&255;c[291678]=h|c[291678];i=c[1161476+(e*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=f&255;return}else{fj[i&511](g&16777215,h);return}}function R5(){var b=0,f=0,g=0,h=0,i=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}b=-(((c[291676]|0)>>>8&1)+i|0)|0;c[291677]=b;c[291680]=b;c[291676]=b;c[291679]=i&b;i=b&255;c[291678]=i|c[291678];g=c[1161476+(h*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[g&511](f&16777215,i);return}}function R6(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=-(((c[291676]|0)>>>8&1)+h|0)|0;c[291677]=g;c[291680]=g;c[291676]=g;c[291679]=h&g;h=g&255;c[291678]=h|c[291678];i=c[1161476+(e*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[i&511](f&16777215,h);return}}function R7(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=-(((c[291676]|0)>>>8&1)+i|0)|0;c[291677]=f;c[291680]=f;c[291676]=f;c[291679]=i&f;i=f&255;c[291678]=i|c[291678];j=c[1161476+(h*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[j&511](g&16777215,i);return}}function R8(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=f&65535;c[291667]=a+6;h=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|h<<16;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=h&255;h=c[1161480+(i*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=f;return}else{fj[h&511](d&16777215,g);return}}function R9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=-(((c[291676]|0)>>>8&1)+(i&65535)|0)|0;h=f>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=(i&f)>>>8;i=f&65535;c[291678]=i|c[291678];if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535;return}else{fj[j&511](a&16777215,i);return}}function Sa(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=-(((c[291676]|0)>>>8&1)+(c[a>>2]|0)|0)|0;c[291677]=b>>>24;d=(c[a>>2]|b)>>>23;c[291680]=d;c[291676]=d;c[291679]=(c[a>>2]&b)>>>24;c[291678]=c[291678]|b;c[a>>2]=b;return}function Sb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=-(((c[291676]|0)>>>8&1)+(i&65535)|0)|0;h=f>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=(i&f)>>>8;i=f&65535;c[291678]=i|c[291678];if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[j&511](d&16777215,i);return}}function Sc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=-(((c[291676]|0)>>>8&1)+(i&65535)|0)|0;h=f>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=(i&f)>>>8;i=f&65535;c[291678]=i|c[291678];if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[j&511](d&16777215,i);return}}function Sd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=-(((c[291676]|0)>>>8&1)+(i&65535)|0)|0;h=d>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=(i&d)>>>8;i=d&65535;c[291678]=i|c[291678];if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[j&511](f&16777215,i);return}}function Se(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=-(((c[291676]|0)>>>8&1)+(i&65535)|0)|0;h=a>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=(i&a)>>>8;i=a&65535;c[291678]=i|c[291678];if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[j&511](d&16777215,i);return}}function Sf(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=-(((c[291676]|0)>>>8&1)+(i&65535)|0)|0;h=f>>>8;c[291677]=h;c[291680]=h;c[291676]=h;c[291679]=(i&f)>>>8;i=f&65535;c[291678]=i|c[291678];if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[j&511](d&16777215,i);return}}function Sg(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=-(((c[291676]|0)>>>8&1)+(j&65535)|0)|0;d=h>>>8;c[291677]=d;c[291680]=d;c[291676]=d;c[291679]=(j&h)>>>8;j=h&65535;c[291678]=j|c[291678];if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535;return}else{fj[k&511](f&16777215,j);return}}function Sh(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=a+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;l=f}else{f=(fl[i&255](a&16777215)|0)<<16;i=fl[c[h>>2]&255](a+2&16777215)|0|f;k=i;l=c[291688]|0}i=-(((c[291676]|0)>>>8&1)+k|0)|0;c[291677]=i>>>24;f=(k|i)>>>23;c[291680]=f;c[291676]=f;c[291679]=(k&i)>>>24;c[291678]=c[291678]|i;if(d&(l|0)!=0){l=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[l&511](a&16777215,i>>>16)}l=a+2|0;a=l>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(l&65535)>>1]=i&65535;return}else{fj[g&511](l&16777215,i&65535);return}}function Si(){var a=0;a=1166604+((c[291673]&7)<<2)|0;c[a>>2]=c[a>>2]&-65536|c[291674]|c[291675]<<11|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;return}function Sj(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;l=f}else{f=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|f;k=i;l=c[291688]|0}i=-(((c[291676]|0)>>>8&1)+k|0)|0;c[291677]=i>>>24;f=(k|i)>>>23;c[291680]=f;c[291676]=f;c[291679]=(k&i)>>>24;c[291678]=c[291678]|i;if(a&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[l&511](d&16777215,i>>>16)}l=d+2|0;d=l>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(l&65535)>>1]=i&65535;return}else{fj[g&511](l&16777215,i&65535);return}}function Sk(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d-2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](d+16777214&16777215)|0|g;l=j;m=c[291688]|0}j=-(((c[291676]|0)>>>8&1)+l|0)|0;c[291677]=j>>>24;g=(l|j)>>>23;c[291680]=g;c[291676]=g;c[291679]=(l&j)>>>24;c[291678]=c[291678]|j;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}f=d-2|0;d=f>>>16&255;m=c[1161480+(d*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[m&511](f&16777215,j&65535);return}}function Sl(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]<<16;l=d}else{d=(fl[i&255](f&16777215)|0)<<16;i=fl[c[h>>2]&255](f+2&16777215)|0|d;k=i;l=c[291688]|0}i=-(((c[291676]|0)>>>8&1)+k|0)|0;c[291677]=i>>>24;d=(k|i)>>>23;c[291680]=d;c[291676]=d;c[291679]=(k&i)>>>24;c[291678]=c[291678]|i;if(a&(l|0)!=0){l=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[l&511](f&16777215,i>>>16)}l=f+2|0;f=l>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(l&65535)>>1]=i&65535;return}else{fj[g&511](l&16777215,i&65535);return}}function Sm(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=1161472+(f*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;l=a}else{a=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|a;k=i;l=c[291688]|0}i=-(((c[291676]|0)>>>8&1)+k|0)|0;c[291677]=i>>>24;a=(k|i)>>>23;c[291680]=a;c[291676]=a;c[291679]=(k&i)>>>24;c[291678]=c[291678]|i;if(g&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(f*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[l&511](d&16777215,i>>>16)}l=d+2|0;d=l>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(l&65535)>>1]=i&65535;return}else{fj[f&511](l&16777215,i&65535);return}}function Sn(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]<<16;l=f}else{f=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|f;k=i;l=c[291688]|0}i=-(((c[291676]|0)>>>8&1)+k|0)|0;c[291677]=i>>>24;f=(k|i)>>>23;c[291680]=f;c[291676]=f;c[291679]=(k&i)>>>24;c[291678]=c[291678]|i;if(a&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[l&511](d&16777215,i>>>16)}l=d+2|0;d=l>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(l&65535)>>1]=i&65535;return}else{fj[g&511](l&16777215,i&65535);return}}function So(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=1161472+(i*20|0)|0;j=c[d>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0)<<16;m=h}else{h=(fl[j&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|h;l=j;m=c[291688]|0}j=-(((c[291676]|0)>>>8&1)+l|0)|0;c[291677]=j>>>24;h=(l|j)>>>23;c[291680]=h;c[291676]=h;c[291679]=(l&j)>>>24;c[291678]=c[291678]|j;if(g&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(i*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[a&511](m&16777215,j&65535);return}}function Sp(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=c[1166604+((a>>>9&7)<<2)>>2]|0;d=b<<16;e=d>>16;f=c[1166604+((a&7)<<2)>>2]|0;c[291678]=e&65535;c[291679]=0;c[291680]=0;do{if((d|0)>-65536){if((e|0)>(f<<16>>16|0)){break}return}}while(0);c[291677]=b>>>15<<7&128;ahc(6);return}function Sq(){var a=0,d=0,e=0,f=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291675]|0;e=c[291674]|d<<11|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;if((a&1|0)!=0&(c[291688]|0)!=0){c[291699]=a;c[291700]=0;c[291701]=d|1;eJ(1166756,1)}d=a>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=e&65535;return}else{fj[f&511](a&16777215,e);return}}function Sr(){var a=0,d=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[291675]|0;e=c[291674]|a<<11|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;if((d&1|0)!=0&(c[291688]|0)!=0){c[291699]=d;c[291700]=0;c[291701]=a|1;eJ(1166756,1)}a=d>>>16&255;f=c[1161480+(a*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=e&65535;return}else{fj[f&511](d&16777215,e);return}}function Ss(){var a=0,d=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[291675]|0;e=c[291674]|a<<11|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;if((d&1|0)!=0&(c[291688]|0)!=0){c[291699]=d;c[291700]=0;c[291701]=a|1;eJ(1166756,1)}a=d>>>16&255;f=c[1161480+(a*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=e&65535;return}else{fj[f&511](d&16777215,e);return}}function St(){var a=0,d=0,e=0,f=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=c[291675]|0;d=c[291674]|a<<11|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;if((e&1|0)!=0&(c[291688]|0)!=0){c[291699]=e;c[291700]=0;c[291701]=a|1;eJ(1166756,1)}a=e>>>16&255;f=c[1161480+(a*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(e&65535)>>1]=d&65535;return}else{fj[f&511](e&16777215,d);return}}function Su(){var a=0,d=0,f=0,g=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=c[291675]|0;a=c[291674]|g<<11|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;if((d&1|0)!=0&(c[291688]|0)!=0){c[291699]=d;c[291700]=0;c[291701]=g|1;eJ(1166756,1)}g=d>>>16&255;f=c[1161480+(g*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[f&511](d&16777215,a);return}}function Sv(){var a=0,d=0,e=0,f=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[291675]|0;e=c[291674]|a<<11|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;if((d&1|0)!=0&(c[291688]|0)!=0){c[291699]=d;c[291700]=0;c[291701]=a|1;eJ(1166756,1)}a=d>>>16&255;f=c[1161480+(a*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=e&65535;return}else{fj[f&511](d&16777215,e);return}}function Sw(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[291675]|0;h=c[291674]|g<<11|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;if((a&1|0)!=0&(c[291688]|0)!=0){c[291699]=f;c[291700]=0;c[291701]=g|1;eJ(1166756,1)}g=d&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+a>>1]=h&65535;return}else{fj[d&511](f&16777215,h);return}}function Sx(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=c[1166604+((a>>>9&7)<<2)>>2]|0;d=b<<16;f=d>>16;g=c[1166604+((a&7|8)<<2)>>2]|0;if((g&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=g>>>16&255;h=c[1161472+(a*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(a*20|0)>>2]|0)+(g&65535)>>1]|0}else{i=fl[h&255](g&16777215)|0}c[291678]=f&65535;c[291679]=0;c[291680]=0;do{if((d|0)>-65536){if((f|0)>(i<<16>>16|0)){break}return}}while(0);c[291677]=b>>>15<<7&128;ahc(6);return}function Sy(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=c[1166604+((a>>>9&7)<<2)>>2]|0;d=b<<16;f=d>>16;g=1166604+((a&7|8)<<2)|0;a=c[g>>2]|0;c[g>>2]=a+2;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{i=fl[h&255](a&16777215)|0}c[291678]=f&65535;c[291679]=0;c[291680]=0;do{if((d|0)>-65536){if((f|0)>(i<<16>>16|0)){break}return}}while(0);c[291677]=b>>>15<<7&128;ahc(6);return}function Sz(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;b=c[1166604+((a>>>9&7)<<2)>>2]|0;d=b<<16;f=d>>16;g=1166604+((a&7|8)<<2)|0;a=(c[g>>2]|0)-2|0;c[g>>2]=a;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{i=fl[h&255](a&16777215)|0}c[291678]=f&65535;c[291679]=0;c[291680]=0;do{if((d|0)>-65536){if((f|0)>(i<<16>>16|0)){break}return}}while(0);c[291677]=b>>>15<<7&128;ahc(6);return}function SA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;d=c[1166604+((a>>>9&7)<<2)>>2]|0;f=d<<16;g=f>>16;h=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;i=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+h|0;if((i&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=i;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=i>>>16&255;a=c[1161472+(h*20|0)>>2]|0;if((a|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(i&65535)>>1]|0}else{j=fl[a&255](i&16777215)|0}c[291678]=g&65535;c[291679]=0;c[291680]=0;do{if((f|0)>-65536){if((g|0)>(j<<16>>16|0)){break}return}}while(0);c[291677]=d>>>15<<7&128;ahc(6);return}function SB(){var a=0;a=c[291673]|0;c[1166604+((a>>>9&7|8)<<2)>>2]=c[1166604+((a&7|8)<<2)>>2];return}function SC(){var a=0,d=0,e=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;c[1166604+((a>>>9&7|8)<<2)>>2]=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d;return}function SD(){var a=0,b=0,d=0,f=0,g=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}c[1166604+((a>>>9&7|8)<<2)>>2]=(f<<24>>24)+b+g;return}function SE(){var a=0;a=c[291667]|0;c[291667]=a+2;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;return}function SF(){var a=0,b=0;a=c[291667]|0;c[291667]=a+4;b=a+2|0;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;return}function SG(){var a=0;a=c[291667]|0;c[291667]=a+2;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a;return}function SH(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=(b<<24>>24)+a+f;return}function SI(){var a=0,d=0,e=0,f=0,g=0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;d=a<<16;e=d>>16;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+f|0;f=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;c[291678]=e&65535;c[291679]=0;c[291680]=0;do{if((d|0)>-65536){if((e|0)>(f<<16>>16|0)){break}return}}while(0);c[291677]=a>>>15<<7&128;ahc(6);return}function SJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;d=a<<16;f=d>>16;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;i=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){j=i<<16>>16}else{j=i}i=(h<<24>>24)+g+j|0;j=b[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;c[291678]=f&65535;c[291679]=0;c[291680]=0;do{if((d|0)>-65536){if((f|0)>(j<<16>>16|0)){break}return}}while(0);c[291677]=a>>>15<<7&128;ahc(6);return}function SK(){var a=0,d=0,e=0,f=0,g=0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;d=a<<16;e=d>>16;f=c[291667]|0;c[291667]=f+2;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291678]=e&65535;c[291679]=0;c[291680]=0;do{if((d|0)>-65536){if((e|0)>(g<<16>>16|0)){break}return}}while(0);c[291677]=a>>>15<<7&128;ahc(6);return}function SL(){var a=0;a=1166604+((c[291673]&7)<<2)|0;c[a>>2]=c[a>>2]&-256;aIv(1166708,0,16);return}function SM(){var b=0,d=0,e=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=b>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;aIv(1166708,0,16);return}else{fj[e&511](b&16777215,0);aIv(1166708,0,16);return}}function SN(){var b=0,d=0,e=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=d>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=0;aIv(1166708,0,16);return}else{fj[e&511](d&16777215,0);aIv(1166708,0,16);return}}function SO(){var b=0,d=0,e=0;b=c[291666]|0;c[291666]=b+2;d=b>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;aIv(1166708,0,16);return}else{fj[e&511](b&16777215,0);aIv(1166708,0,16);return}}function SP(){var b=0,d=0,e=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=d>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=0;aIv(1166708,0,16);return}else{fj[e&511](d&16777215,0);aIv(1166708,0,16);return}}function SQ(){var b=0,d=0,e=0;b=(c[291666]|0)-2|0;c[291666]=b;d=b>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;aIv(1166708,0,16);return}else{fj[e&511](b&16777215,0);aIv(1166708,0,16);return}}function SR(){var d=0,e=0,f=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=f>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(f&65535^1)|0]=0;aIv(1166708,0,16);return}else{fj[e&511](f&16777215,0);aIv(1166708,0,16);return}}function SS(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[1161476+(g*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(d&65535^1)|0]=0;aIv(1166708,0,16);return}else{fj[b&511](d&16777215,0);aIv(1166708,0,16);return}}function ST(){var d=0,e=0,f=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e>>>16&255;f=c[1161476+(d*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(e&65535^1)|0]=0;aIv(1166708,0,16);return}else{fj[f&511](e&16777215,0);aIv(1166708,0,16);return}}function SU(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=c[1166604+((a>>>9&7)<<2)>>2]|0;d=b<<16;f=d>>16;g=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;h=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=a<<16>>16}else{i=a}a=(h<<24>>24)+g+i|0;if((a&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;g=c[1161472+(i*20|0)>>2]|0;if((g|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]|0}else{j=fl[g&255](a&16777215)|0}c[291678]=f&65535;c[291679]=0;c[291680]=0;do{if((d|0)>-65536){if((f|0)>(j<<16>>16|0)){break}return}}while(0);c[291677]=b>>>15<<7&128;ahc(6);return}function SV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;d=a<<16;f=d>>16;g=c[291667]|0;c[291667]=g+2;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;if((h&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=h;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=h>>>16&255;i=c[1161472+(g*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(g*20|0)>>2]|0)+(h&65535)>>1]|0}else{j=fl[i&255](h&16777215)|0}c[291678]=f&65535;c[291679]=0;c[291680]=0;do{if((d|0)>-65536){if((f|0)>(j<<16>>16|0)){break}return}}while(0);c[291677]=a>>>15<<7&128;ahc(6);return}function SW(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]|0;b=a<<16;d=b>>16;f=c[291667]|0;c[291667]=f+4;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=f|g<<16;if((f&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=h;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=g&255;g=c[1161472+(i*20|0)>>2]|0;if((g|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+f>>1]|0}else{j=fl[g&255](h&16777215)|0}c[291678]=d&65535;c[291679]=0;c[291680]=0;do{if((b|0)>-65536){if((d|0)>(j<<16>>16|0)){break}return}}while(0);c[291677]=a>>>15<<7&128;ahc(6);return}function SX(){var b=0,d=0,f=0,g=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b^1)|0]=0;aIv(1166708,0,16);return}else{fj[g&511](b|d<<16&16711680,0);aIv(1166708,0,16);return}}function SY(){var a=0;a=1166604+((c[291673]&7)<<2)|0;c[a>>2]=c[a>>2]&-65536;aIv(1166708,0,16);return}function SZ(){c[1166604+((c[291673]&7)<<2)>>2]=0;aIv(1166708,0,16);return}function S_(){var a=0,d=0,e=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;e=c[1161480+(d*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[e&511](a&16777215,0);aIv(1166708,0,16);return}}function S$(){var a=0,d=0,e=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;e=c[1161480+(a*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[e&511](d&16777215,0);aIv(1166708,0,16);return}}function S0(){var a=0,d=0,e=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;e=c[1161480+(a*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[e&511](d&16777215,0);aIv(1166708,0,16);return}}function S1(){var a=0,d=0,e=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;if((e&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=e>>>16&255;d=c[1161480+(a*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(e&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[d&511](e&16777215,0);aIv(1166708,0,16);return}}function S2(){var a=0,d=0,f=0,g=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;a=c[1161480+(g*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[a&511](d&16777215,0);aIv(1166708,0,16);return}}function S3(){var a=0,d=0,e=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;e=c[1161480+(a*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[e&511](d&16777215,0);aIv(1166708,0,16);return}}function S4(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+a>>1]=0;aIv(1166708,0,16);return}else{fj[d&511](f&16777215,0);aIv(1166708,0,16);return}}function S5(){var a=0,d=0,e=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;e=c[1161480+(d*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=0}else{fj[e&511](a&16777215,0)}e=a+2|0;a=e>>>16&255;d=c[1161480+(a*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(e&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[d&511](e&16777215,0);aIv(1166708,0,16);return}}function S6(){var a=0,d=0,e=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;e=c[1161480+(a*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=0}else{fj[e&511](d&16777215,0)}e=d+2|0;d=e>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[a&511](e&16777215,0);aIv(1166708,0,16);return}}function S7(){var a=0,d=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;e=d-4|0;c[a>>2]=e;if((e&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=e>>>16&255;f=c[1161480+(a*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(e&65535)>>1]=0}else{fj[f&511](e&16777215,0)}e=d-2|0;d=e>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[f&511](e&16777215,0);aIv(1166708,0,16);return}}function S8(){var a=0,d=0,e=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;if((e&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=e>>>16&255;d=c[1161480+(a*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(e&65535)>>1]=0}else{fj[d&511](e&16777215,0)}d=e+2|0;e=d>>>16&255;a=c[1161480+(e*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[a&511](d&16777215,0);aIv(1166708,0,16);return}}function S9(){var a=0,d=0,f=0,g=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;a=c[1161480+(g*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=0}else{fj[a&511](d&16777215,0)}a=d+2|0;d=a>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[g&511](a&16777215,0);aIv(1166708,0,16);return}}function Ta(){var a=0,d=0,e=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;e=c[1161480+(a*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=0}else{fj[e&511](d&16777215,0)}e=d+2|0;d=e>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[a&511](e&16777215,0);aIv(1166708,0,16);return}}function Tb(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=-(c[a>>2]&255)|0;c[291677]=b;c[291676]=b;c[291680]=b;c[291679]=c[a>>2]&b;d=b&255;c[291678]=d;c[a>>2]=c[a>>2]&-256|d;return}function Tc(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=-(c[a>>2]&65535)|0;d=b>>>8;c[291677]=d;c[291676]=d;c[291680]=d;c[291679]=(c[a>>2]&b)>>>8;d=b&65535;c[291678]=d;c[a>>2]=c[a>>2]&-65536|d;return}function Td(){var b=0,e=0,f=0,g=0,h=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-g|0;c[291677]=f;c[291676]=f;c[291680]=f;c[291679]=g&f;g=f&255;c[291678]=g;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function Te(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=-g|0;c[291677]=f;c[291676]=f;c[291680]=f;c[291679]=g&f;g=f&255;c[291678]=g;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[h&511](e&16777215,g);return}}function Tf(){var b=0,e=0,f=0,g=0,h=0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-g|0;c[291677]=f;c[291676]=f;c[291680]=f;c[291679]=g&f;g=f&255;c[291678]=g;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function Tg(){var b=0,e=0,f=0,g=0,h=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=-g|0;c[291677]=f;c[291676]=f;c[291680]=f;c[291679]=g&f;g=f&255;c[291678]=g;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[h&511](e&16777215,g);return}}function Th(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-g|0;c[291677]=f;c[291676]=f;c[291680]=f;c[291679]=g&f;g=f&255;c[291678]=g;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function Ti(){var e=0,f=0,g=0,h=0,i=0;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}f=-h|0;c[291677]=f;c[291676]=f;c[291680]=f;c[291679]=h&f;h=f&255;c[291678]=h;i=c[1161476+(e*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=f&255;return}else{fj[i&511](g&16777215,h);return}}function Tj(){var b=0,f=0,g=0,h=0,i=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}b=-i|0;c[291677]=b;c[291676]=b;c[291680]=b;c[291679]=i&b;i=b&255;c[291678]=i;g=c[1161476+(h*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[g&511](f&16777215,i);return}}function Tk(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=-h|0;c[291677]=g;c[291676]=g;c[291680]=g;c[291679]=h&g;h=g&255;c[291678]=h;i=c[1161476+(e*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[i&511](f&16777215,h);return}}function Tl(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=-i|0;c[291677]=f;c[291676]=f;c[291680]=f;c[291679]=i&f;i=f&255;c[291678]=i;j=c[1161476+(h*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[j&511](g&16777215,i);return}}function Tm(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+a>>1]=0}else{fj[d&511](f&16777215,0)}d=f+2|0;f=d>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(1166708,0,16);return}else{fj[a&511](d&16777215,0);aIv(1166708,0,16);return}}function Tn(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=-i|0;h=f>>>8;c[291677]=h;c[291676]=h;c[291680]=h;c[291679]=(i&f)>>>8;i=f&65535;c[291678]=i;if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535;return}else{fj[j&511](a&16777215,i);return}}function To(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=-i|0;h=f>>>8;c[291677]=h;c[291676]=h;c[291680]=h;c[291679]=(i&f)>>>8;i=f&65535;c[291678]=i;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[j&511](d&16777215,i);return}}function Tp(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=-(c[a>>2]|0)|0;c[291677]=b>>>24;d=(c[a>>2]|b)>>>23;c[291676]=d;c[291680]=d;c[291679]=(c[a>>2]&b)>>>24;c[291678]=b;c[a>>2]=b;return}function Tq(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=-i|0;h=f>>>8;c[291677]=h;c[291676]=h;c[291680]=h;c[291679]=(i&f)>>>8;i=f&65535;c[291678]=i;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[j&511](d&16777215,i);return}}function Tr(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=-i|0;h=d>>>8;c[291677]=h;c[291676]=h;c[291680]=h;c[291679]=(i&d)>>>8;i=d&65535;c[291678]=i;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[j&511](f&16777215,i);return}}function Ts(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=-i|0;h=a>>>8;c[291677]=h;c[291676]=h;c[291680]=h;c[291679]=(i&a)>>>8;i=a&65535;c[291678]=i;if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[j&511](d&16777215,i);return}}function Tt(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=-i|0;h=f>>>8;c[291677]=h;c[291676]=h;c[291680]=h;c[291679]=(i&f)>>>8;i=f&65535;c[291678]=i;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[j&511](d&16777215,i);return}}function Tu(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=-j|0;d=h>>>8;c[291677]=d;c[291676]=d;c[291680]=d;c[291679]=(j&h)>>>8;j=h&65535;c[291678]=j;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535;return}else{fj[k&511](f&16777215,j);return}}function Tv(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=a+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;l=f}else{f=(fl[i&255](a&16777215)|0)<<16;i=fl[c[h>>2]&255](a+2&16777215)|0|f;k=i;l=c[291688]|0}i=-k|0;c[291677]=i>>>24;f=(k|i)>>>23;c[291676]=f;c[291680]=f;c[291679]=(k&i)>>>24;c[291678]=i;if(d&(l|0)!=0){l=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[l&511](a&16777215,i>>>16)}l=a+2|0;a=l>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(l&65535)>>1]=i&65535;return}else{fj[g&511](l&16777215,i&65535);return}}function Tw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;l=f}else{f=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|f;k=i;l=c[291688]|0}i=-k|0;c[291677]=i>>>24;f=(k|i)>>>23;c[291676]=f;c[291680]=f;c[291679]=(k&i)>>>24;c[291678]=i;if(a&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[l&511](d&16777215,i>>>16)}l=d+2|0;d=l>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(l&65535)>>1]=i&65535;return}else{fj[g&511](l&16777215,i&65535);return}}function Tx(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d-2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](d+16777214&16777215)|0|g;l=j;m=c[291688]|0}j=-l|0;c[291677]=j>>>24;g=(l|j)>>>23;c[291676]=g;c[291680]=g;c[291679]=(l&j)>>>24;c[291678]=j;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}f=d-2|0;d=f>>>16&255;m=c[1161480+(d*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[m&511](f&16777215,j&65535);return}}function Ty(){var a=0,b=0;a=c[1166604+((c[291673]&7)<<2)>>2]|0;b=a<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=a>>>2&1^1;c[291679]=a<<6&128;c[291680]=a<<8&256;return}function Tz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]<<16;l=d}else{d=(fl[i&255](f&16777215)|0)<<16;i=fl[c[h>>2]&255](f+2&16777215)|0|d;k=i;l=c[291688]|0}i=-k|0;c[291677]=i>>>24;d=(k|i)>>>23;c[291676]=d;c[291680]=d;c[291679]=(k&i)>>>24;c[291678]=i;if(a&(l|0)!=0){l=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[l&511](f&16777215,i>>>16)}l=f+2|0;f=l>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(l&65535)>>1]=i&65535;return}else{fj[g&511](l&16777215,i&65535);return}}function TA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=1161472+(f*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;l=a}else{a=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|a;k=i;l=c[291688]|0}i=-k|0;c[291677]=i>>>24;a=(k|i)>>>23;c[291676]=a;c[291680]=a;c[291679]=(k&i)>>>24;c[291678]=i;if(g&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(f*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[l&511](d&16777215,i>>>16)}l=d+2|0;d=l>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(l&65535)>>1]=i&65535;return}else{fj[f&511](l&16777215,i&65535);return}}function TB(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]<<16;l=f}else{f=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|f;k=i;l=c[291688]|0}i=-k|0;c[291677]=i>>>24;f=(k|i)>>>23;c[291676]=f;c[291680]=f;c[291679]=(k&i)>>>24;c[291678]=i;if(a&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[l&511](d&16777215,i>>>16)}l=d+2|0;d=l>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(l&65535)>>1]=i&65535;return}else{fj[g&511](l&16777215,i&65535);return}}function TC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=1161472+(i*20|0)|0;j=c[d>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0)<<16;m=h}else{h=(fl[j&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|h;l=j;m=c[291688]|0}j=-l|0;c[291677]=j>>>24;h=(l|j)>>>23;c[291676]=h;c[291680]=h;c[291679]=(l&j)>>>24;c[291678]=j;if(g&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(i*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[a&511](m&16777215,j&65535);return}}function TD(){var a=0,b=0,d=0,f=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if((a&1|0)!=0&(c[291688]|0)!=0){b=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=b;eJ(1166756,1)}b=a>>>16&255;d=c[1161472+(b*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(b*20|0)>>2]|0)+(a&65535)>>1]|0}else{f=fl[d&255](a&16777215)|0}a=f<<4;c[291676]=a&256;c[291677]=a&128;c[291678]=f>>>2&1^1;c[291679]=f<<6&128;c[291680]=f<<8&256;return}function TE(){var a=0,b=0,d=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=f<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=f>>>2&1^1;c[291679]=f<<6&128;c[291680]=f<<8&256;return}function TF(){var a=0,b=0,d=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=f<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=f>>>2&1^1;c[291679]=f<<6&128;c[291680]=f<<8&256;return}function TG(){var a=0,d=0,f=0,g=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}f=g<<4;c[291676]=f&256;c[291677]=f&128;c[291678]=g>>>2&1^1;c[291679]=g<<6&128;c[291680]=g<<8&256;return}function TH(){var a=0,d=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a<<4;c[291676]=d&256;c[291677]=d&128;c[291678]=a>>>2&1^1;c[291679]=a<<6&128;c[291680]=a<<8&256;return}function TI(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f<<4;c[291676]=d&256;c[291677]=d&128;c[291678]=f>>>2&1^1;c[291679]=f<<6&128;c[291680]=f<<8&256;return}function TJ(){var a=0,b=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=b<<4;c[291676]=a&256;c[291677]=a&128;c[291678]=b>>>2&1^1;c[291679]=b<<6&128;c[291680]=b<<8&256;return}function TK(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;d=b&255^255;c[a>>2]=d|b&-256;c[291677]=d;c[291678]=d;c[291680]=0;c[291679]=0;return}function TL(){var b=0,e=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=g&255^255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[g&511](b&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function TM(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=g&255^255;g=c[1161476+(b*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[g&511](e&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function TN(){var b=0,e=0,f=0,g=0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=g&255^255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[g&511](b&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function TO(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=g&255^255;g=c[1161476+(b*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[g&511](e&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function TP(){var b=0,e=0,f=0,g=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=g&255^255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[g&511](b&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function TQ(){var e=0,f=0,g=0,h=0;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}f=h&255^255;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=f&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[h&511](g&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function TR(){var b=0,f=0,g=0,h=0,i=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}b=i&255^255;i=c[1161476+(h*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]=b&255;c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}else{fj[i&511](f&16777215,b);c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}}function TS(){var e=0,f=0,g=0,h=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=h&255^255;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;c[291677]=g;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[h&511](f&16777215,g);c[291677]=g;c[291678]=g;c[291680]=0;c[291679]=0;return}}function TT(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=i&255^255;i=c[1161476+(h*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]=f&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[i&511](g&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function TU(){var a=0,b=0,d=0,f=0,g=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){f=b<<16>>16}else{f=b}b=(d<<24>>24)+a+f|0;if((b&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){g=e[(c[1161464+(f*20|0)>>2]|0)+(b&65535)>>1]|0}else{g=fl[a&255](b&16777215)|0}b=g<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=g>>>2&1^1;c[291679]=g<<6&128;c[291680]=g<<8&256;return}function TV(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=g<<4;c[291676]=d&256;c[291677]=d&128;c[291678]=g>>>2&1^1;c[291679]=g<<6&128;c[291680]=g<<8&256;return}function TW(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b&255;b=c[1161472+(f*20|0)>>2]|0;if((b|0)==0){g=e[(c[1161464+(f*20|0)>>2]|0)+a>>1]|0}else{g=fl[b&255](d&16777215)|0}d=g<<4;c[291676]=d&256;c[291677]=d&128;c[291678]=g>>>2&1^1;c[291679]=g<<6&128;c[291680]=g<<8&256;return}function TX(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;d=b&65535^65535;c[a>>2]=d|b&-65536;c[291677]=d>>>8;c[291678]=d;c[291680]=0;c[291679]=0;return}function TY(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=~c[a>>2];c[a>>2]=b;c[291677]=b>>>24;c[291678]=b;c[291680]=0;c[291679]=0;return}function TZ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=i&65535^65535;if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535;k=f>>>8;c[291677]=k;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[j&511](a&16777215,f);k=f>>>8;c[291677]=k;c[291678]=f;c[291680]=0;c[291679]=0;return}}function T_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i&65535^65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=f>>>8;c[291677]=k;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[j&511](d&16777215,f);k=f>>>8;c[291677]=k;c[291678]=f;c[291680]=0;c[291679]=0;return}}function T$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i&65535^65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=f>>>8;c[291677]=k;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[j&511](d&16777215,f);k=f>>>8;c[291677]=k;c[291678]=f;c[291680]=0;c[291679]=0;return}}function T0(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=i&65535^65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;k=d>>>8;c[291677]=k;c[291678]=d;c[291680]=0;c[291679]=0;return}else{fj[j&511](f&16777215,d);k=d>>>8;c[291677]=k;c[291678]=d;c[291680]=0;c[291679]=0;return}}function T1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=i&65535^65535;if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;k=a>>>8;c[291677]=k;c[291678]=a;c[291680]=0;c[291679]=0;return}else{fj[j&511](d&16777215,a);k=a>>>8;c[291677]=k;c[291678]=a;c[291680]=0;c[291679]=0;return}}function T2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i&65535^65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=f>>>8;c[291677]=k;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[j&511](d&16777215,f);k=f>>>8;c[291677]=k;c[291678]=f;c[291680]=0;c[291679]=0;return}}function T3(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=j&65535^65535;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535;l=h>>>8;c[291677]=l;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[k&511](f&16777215,h);l=h>>>8;c[291677]=l;c[291678]=h;c[291680]=0;c[291679]=0;return}}function T4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=a+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;l=f}else{f=(fl[i&255](a&16777215)|0)<<16;i=fl[c[h>>2]&255](a+2&16777215)|0|f;k=i;l=c[291688]|0}i=~k;if(d&(l|0)!=0){l=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[l&511](a&16777215,i>>>16)}l=a+2|0;a=l>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(l&65535)>>1]=i&65535;m=i>>>24;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[g&511](l&16777215,i&65535);m=i>>>24;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}}function T5(){var a=0,b=0,d=0;a=c[291675]|0;if((a|0)==0){ahd();return}else{b=c[1166604+((c[291673]&7)<<2)>>2]|0;c[291674]=b&32768;c[291681]=b&1792;d=b<<4;c[291676]=d&256;c[291677]=d&128;c[291678]=b>>>2&1^1;c[291679]=b<<6&128;c[291680]=b<<8&256;d=b>>>11&4;c[1166672+(a<<2)>>2]=c[291666];c[291675]=d;c[291666]=c[1166672+(d<<2)>>2];ID();return}}function T6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;l=f}else{f=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|f;k=i;l=c[291688]|0}i=~k;if(a&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[l&511](d&16777215,i>>>16)}l=d+2|0;d=l>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(l&65535)>>1]=i&65535;m=i>>>24;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[g&511](l&16777215,i&65535);m=i>>>24;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}}function T7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d-2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](d+16777214&16777215)|0|g;l=j;m=c[291688]|0}j=~l;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}f=d-2|0;d=f>>>16&255;m=c[1161480+(d*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[m&511](f&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function T8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]<<16;l=d}else{d=(fl[i&255](f&16777215)|0)<<16;i=fl[c[h>>2]&255](f+2&16777215)|0|d;k=i;l=c[291688]|0}i=~k;if(a&(l|0)!=0){l=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[l&511](f&16777215,i>>>16)}l=f+2|0;f=l>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(l&65535)>>1]=i&65535;m=i>>>24;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[g&511](l&16777215,i&65535);m=i>>>24;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}}function T9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=1161472+(f*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;l=a}else{a=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|a;k=i;l=c[291688]|0}i=~k;if(g&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(f*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[l&511](d&16777215,i>>>16)}l=d+2|0;d=l>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(l&65535)>>1]=i&65535;m=i>>>24;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[f&511](l&16777215,i&65535);m=i>>>24;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}}function Ua(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]<<16;l=f}else{f=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|f;k=i;l=c[291688]|0}i=~k;if(a&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(g*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[l&511](d&16777215,i>>>16)}l=d+2|0;d=l>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(l&65535)>>1]=i&65535;m=i>>>24;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[g&511](l&16777215,i&65535);m=i>>>24;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}}function Ub(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=1161472+(i*20|0)|0;j=c[d>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0)<<16;m=h}else{h=(fl[j&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|h;l=j;m=c[291688]|0}j=~l;if(g&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(i*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[a&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function Uc(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=1166604+((c[291673]&7)<<2)|0;b=154-(c[a>>2]|0)-((c[291676]|0)>>>8&1)|0;d=b&255;if((d|0)==154){c[291679]=0;e=154;f=0;c[291680]=f;c[291676]=f;c[291677]=e;return}g=(b|-256)^255;c[291679]=g;if((b&15|0)==10){h=(b&240)+16|0}else{h=d}d=h&255;c[291679]=d&g;c[a>>2]=c[a>>2]&-256|d;c[291678]=c[291678]|d;e=d;f=256;c[291680]=f;c[291676]=f;c[291677]=e;return}function Ud(){var a=0,d=0,f=0;a=c[291675]|0;if((a|0)==0){ahd();return}else{d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291674]=d&32768;c[291681]=d&1792;f=d<<4;c[291676]=f&256;c[291677]=f&128;c[291678]=d>>>2&1^1;c[291679]=d<<6&128;c[291680]=d<<8&256;f=d>>>11&4;c[1166672+(a<<2)>>2]=c[291666];c[291675]=f;c[291666]=c[1166672+(f<<2)>>2];ID();return}}function Ue(){var a=0,b=0,d=0,f=0,g=0;a=c[291675]|0;if((a|0)==0){ahd();return}b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291674]=g&32768;c[291681]=g&1792;f=g<<4;c[291676]=f&256;c[291677]=f&128;c[291678]=g>>>2&1^1;c[291679]=g<<6&128;c[291680]=g<<8&256;f=g>>>11&4;c[1166672+(a<<2)>>2]=c[291666];c[291675]=f;c[291666]=c[1166672+(f<<2)>>2];ID();return}function Uf(){var a=0,b=0,d=0;a=c[291675]|0;if((a|0)==0){ahd();return}else{b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;c[291674]=d&32768;c[291681]=d&1792;b=d<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=d>>>2&1^1;c[291679]=d<<6&128;c[291680]=d<<8&256;b=d>>>11&4;c[1166672+(a<<2)>>2]=c[291666];c[291675]=b;c[291666]=c[1166672+(b<<2)>>2];ID();return}}function Ug(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291675]|0;if((a|0)==0){ahd();return}b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){c[291699]=b;c[291700]=16;c[291701]=a|1;eJ(1166756,1)}d=b>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291675]|0}c[291674]=g&32768;c[291681]=g&1792;a=g<<4;c[291676]=a&256;c[291677]=a&128;c[291678]=g>>>2&1^1;c[291679]=g<<6&128;c[291680]=g<<8&256;a=g>>>11&4;c[1166672+(h<<2)>>2]=c[291666];c[291675]=a;c[291666]=c[1166672+(a<<2)>>2];ID();return}function Uh(){var a=0,b=0,d=0,f=0;if((c[291675]|0)==0){ahd();return}a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}c[291674]=f&32768;c[291681]=f&1792;b=f<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=f>>>2&1^1;c[291679]=f<<6&128;c[291680]=f<<8&256;b=f>>>11&4;c[1166672+(c[291675]<<2)>>2]=c[291666];c[291675]=b;c[291666]=c[1166672+(b<<2)>>2];ID();return}function Ui(){var a=0,b=0,d=0,f=0;if((c[291675]|0)==0){ahd();return}a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}c[291674]=f&32768;c[291681]=f&1792;b=f<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=f>>>2&1^1;c[291679]=f<<6&128;c[291680]=f<<8&256;b=f>>>11&4;c[1166672+(c[291675]<<2)>>2]=c[291666];c[291675]=b;c[291666]=c[1166672+(b<<2)>>2];ID();return}function Uj(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291675]|0;if((a|0)==0){ahd();return}d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;if((g&1|0)!=0&(c[291688]|0)!=0){c[291699]=g;c[291700]=16;c[291701]=a|1;eJ(1166756,1)}d=g>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291675]|0}c[291674]=h&32768;c[291681]=h&1792;a=h<<4;c[291676]=a&256;c[291677]=a&128;c[291678]=h>>>2&1^1;c[291679]=h<<6&128;c[291680]=h<<8&256;a=h>>>11&4;c[1166672+(i<<2)>>2]=c[291666];c[291675]=a;c[291666]=c[1166672+(a<<2)>>2];ID();return}function Uk(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291675]|0;if((a|0)==0){ahd();return}b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){c[291699]=d;c[291700]=16;c[291701]=a|1;eJ(1166756,1)}g=d>>>16&255;b=c[1161472+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[b&255](d&16777215)|0;h=a;i=c[291675]|0}c[291674]=h&32768;c[291681]=h&1792;a=h<<4;c[291676]=a&256;c[291677]=a&128;c[291678]=h>>>2&1^1;c[291679]=h<<6&128;c[291680]=h<<8&256;a=h>>>11&4;c[1166672+(i<<2)>>2]=c[291666];c[291675]=a;c[291666]=c[1166672+(a<<2)>>2];ID();return}function Ul(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291675]|0;if((a|0)==0){ahd();return}d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((f&1|0)!=0&(c[291688]|0)!=0){c[291699]=f;c[291700]=16;c[291701]=a|1;eJ(1166756,1)}d=f>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0;i=a}else{a=fl[g&255](f&16777215)|0;h=a;i=c[291675]|0}c[291674]=h&32768;c[291681]=h&1792;a=h<<4;c[291676]=a&256;c[291677]=a&128;c[291678]=h>>>2&1^1;c[291679]=h<<6&128;c[291680]=h<<8&256;a=h>>>11&4;c[1166672+(i<<2)>>2]=c[291666];c[291675]=a;c[291666]=c[1166672+(a<<2)>>2];ID();return}function Um(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291675]|0;if((a|0)==0){ahd();return}b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|d<<16;if((b&1|0)!=0&(c[291688]|0)!=0){c[291699]=f;c[291700]=16;c[291701]=a|1;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+b>>1]|0;i=a}else{a=fl[d&255](f&16777215)|0;h=a;i=c[291675]|0}c[291674]=h&32768;c[291681]=h&1792;a=h<<4;c[291676]=a&256;c[291677]=a&128;c[291678]=h>>>2&1^1;c[291679]=h<<6&128;c[291680]=h<<8&256;a=h>>>11&4;c[1166672+(i<<2)>>2]=c[291666];c[291675]=a;c[291666]=c[1166672+(a<<2)>>2];ID();return}function Un(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]<<16;c[291678]=b;d=(c[a>>2]|0)>>>16|b;c[a>>2]=d;c[291678]=d;c[291677]=(c[a>>2]|0)>>>24;c[291680]=0;c[291679]=0;return}function Uo(){var a=0,d=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(c[291666]|0)-4|0;c[291666]=d;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a>>>16&65535;d=(c[291666]|0)+2|0;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}function Up(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=154-g-((c[291676]|0)>>>8&1)|0;g=f&255;if((g|0)==154){c[291679]=0;h=154;i=0;c[291680]=i;c[291676]=i;c[291677]=h;return}j=(f|-256)^255;c[291679]=j;if((f&15|0)==10){k=(f&240)+16|0}else{k=g}g=k&255;c[291679]=g&j;j=c[1161476+(e*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=k&255}else{fj[j&511](b&16777215,g)}c[291678]=c[291678]|g;h=g;i=256;c[291680]=i;c[291676]=i;c[291677]=h;return}function Uq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=154-g-((c[291676]|0)>>>8&1)|0;g=f&255;if((g|0)==154){c[291679]=0;h=154;i=0;c[291680]=i;c[291676]=i;c[291677]=h;return}j=(f|-256)^255;c[291679]=j;if((f&15|0)==10){k=(f&240)+16|0}else{k=g}g=k&255;c[291679]=g&j;j=c[1161476+(b*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=k&255}else{fj[j&511](e&16777215,g)}c[291678]=c[291678]|g;h=g;i=256;c[291680]=i;c[291676]=i;c[291677]=h;return}function Ur(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=154-g-((c[291676]|0)>>>8&1)|0;g=f&255;if((g|0)==154){c[291679]=0;h=154;i=0;c[291680]=i;c[291676]=i;c[291677]=h;return}j=(f|-256)^255;c[291679]=j;if((f&15|0)==10){k=(f&240)+16|0}else{k=g}g=k&255;c[291679]=g&j;j=c[1161476+(e*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=k&255}else{fj[j&511](b&16777215,g)}c[291678]=c[291678]|g;h=g;i=256;c[291680]=i;c[291676]=i;c[291677]=h;return}function Us(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=154-g-((c[291676]|0)>>>8&1)|0;g=f&255;if((g|0)==154){c[291679]=0;h=154;i=0;c[291680]=i;c[291676]=i;c[291677]=h;return}j=(f|-256)^255;c[291679]=j;if((f&15|0)==10){k=(f&240)+16|0}else{k=g}g=k&255;c[291679]=g&j;j=c[1161476+(b*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]=k&255}else{fj[j&511](e&16777215,g)}c[291678]=c[291678]|g;h=g;i=256;c[291680]=i;c[291676]=i;c[291677]=h;return}function Ut(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=154-g-((c[291676]|0)>>>8&1)|0;g=f&255;if((g|0)==154){c[291679]=0;h=154;i=0;c[291680]=i;c[291676]=i;c[291677]=h;return}j=(f|-256)^255;c[291679]=j;if((f&15|0)==10){k=(f&240)+16|0}else{k=g}g=k&255;c[291679]=g&j;j=c[1161476+(e*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=k&255}else{fj[j&511](b&16777215,g)}c[291678]=c[291678]|g;h=g;i=256;c[291680]=i;c[291676]=i;c[291677]=h;return}function Uu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}f=154-h-((c[291676]|0)>>>8&1)|0;h=f&255;if((h|0)==154){c[291679]=0;i=154;j=0;c[291680]=j;c[291676]=j;c[291677]=i;return}k=(f|-256)^255;c[291679]=k;if((f&15|0)==10){l=(f&240)+16|0}else{l=h}h=l&255;c[291679]=h&k;k=c[1161476+(e*20|0)>>2]|0;if((k|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=l&255}else{fj[k&511](g&16777215,h)}c[291678]=c[291678]|h;i=h;j=256;c[291680]=j;c[291676]=j;c[291677]=i;return}function Uv(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}b=154-i-((c[291676]|0)>>>8&1)|0;i=b&255;if((i|0)==154){c[291679]=0;j=154;k=0;c[291680]=k;c[291676]=k;c[291677]=j;return}g=(b|-256)^255;c[291679]=g;if((b&15|0)==10){l=(b&240)+16|0}else{l=i}i=l&255;c[291679]=i&g;g=c[1161476+(h*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]=l&255}else{fj[g&511](f&16777215,i)}c[291678]=c[291678]|i;j=i;k=256;c[291680]=k;c[291676]=k;c[291677]=j;return}function Uw(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=154-h-((c[291676]|0)>>>8&1)|0;h=g&255;if((h|0)==154){c[291679]=0;i=154;j=0;c[291680]=j;c[291676]=j;c[291677]=i;return}k=(g|-256)^255;c[291679]=k;if((g&15|0)==10){l=(g&240)+16|0}else{l=h}h=l&255;c[291679]=h&k;k=c[1161476+(e*20|0)>>2]|0;if((k|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=l&255}else{fj[k&511](f&16777215,h)}c[291678]=c[291678]|h;i=h;j=256;c[291680]=j;c[291676]=j;c[291677]=i;return}function Ux(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=154-i-((c[291676]|0)>>>8&1)|0;i=f&255;if((i|0)==154){c[291679]=0;j=154;k=0;c[291680]=k;c[291676]=k;c[291677]=j;return}l=(f|-256)^255;c[291679]=l;if((f&15|0)==10){m=(f&240)+16|0}else{m=i}i=m&255;c[291679]=i&l;l=c[1161476+(h*20|0)>>2]|0;if((l|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]=m&255}else{fj[l&511](g&16777215,i)}c[291678]=c[291678]|i;j=i;k=256;c[291680]=k;c[291676]=k;c[291677]=j;return}function Uy(){var a=0,d=0,e=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(c[291666]|0)-4|0;c[291666]=a;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=e>>>16&65535;a=(c[291666]|0)+2|0;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=e&65535;return}function Uz(){var a=0,d=0,f=0,g=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(c[291666]|0)-4|0;c[291666]=g;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[291666]|0)+2|0;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;return}function UA(){var a=0,d=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(c[291666]|0)-4|0;c[291666]=a;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d<<16>>16>>>16&65535;a=(c[291666]|0)+2|0;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d;return}function UB(){var a=0,d=0,e=0;a=c[291667]|0;c[291667]=a+4;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;e=a+2|0;a=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=(c[291666]|0)-4|0;c[291666]=e;b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]=d;d=(c[291666]|0)+2|0;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a;return}function UC(){var a=0,d=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=(c[291666]|0)-4|0;c[291666]=a;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535;a=(c[291666]|0)+2|0;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}function UD(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=(c[291666]|0)-4|0;c[291666]=g;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=f>>>16&65535;g=(c[291666]|0)+2|0;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=f&65535;return}function UE(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;d=((b&128|0)!=0?65280:0)|b&-65281;c[a>>2]=d;c[291677]=d>>>8;c[291678]=c[a>>2]&65535;c[291679]=0;c[291680]=0;return}function UF(){var a=0,b=0,d=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;d=(b&32768|0)!=0?-65536:0;c[a>>2]=d|b&65535;c[291677]=d>>>24;c[291678]=c[a>>2];c[291679]=0;c[291680]=0;return}function UG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=0;while(1){if((1<<a&d|0)==0){h=g;i=f}else{j=c[1166604+(a<<2)>>2]|0;if((f&1|0)!=0&(c[291688]|0)!=0){k=23529;break}l=f>>>16&255;m=c[1161480+(l*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(f&65535)>>1]=j&65535}else{fj[m&511](f&16777215,j&65535)}h=g+1|0;i=f+2|0}j=a+1|0;if(j>>>0<16){a=j;f=i;g=h}else{k=23535;break}}if((k|0)==23529){g=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=g;eJ(1166756,1)}else if((k|0)==23535){c[291649]=(c[291649]|0)+(h*28|0);return}}function UH(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=0;while(1){if((1<<a&d|0)==0){h=g;i=f}else{j=f-2|0;k=c[1166604+(15-a<<2)>>2]|0;if((j&1|0)!=0&(c[291688]|0)!=0){l=23539;break}m=j>>>16&255;n=c[1161480+(m*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+(j&65535)>>1]=k&65535}else{fj[n&511](j&16777215,k&65535)}h=g+1|0;i=j}k=a+1|0;if(k>>>0<16){a=k;f=i;g=h}else{l=23545;break}}if((l|0)==23539){g=c[291675]|1;c[291699]=j;c[291700]=0;c[291701]=g;eJ(1166756,1)}else if((l|0)==23545){c[1166604+((c[291673]&7|8)<<2)>>2]=i;c[291649]=(c[291649]|0)+(h*28|0);return}}function UI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=0;h=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=0;while(1){if((1<<a&f|0)==0){i=g;j=h}else{d=c[1166604+(a<<2)>>2]|0;if((h&1|0)!=0&(c[291688]|0)!=0){k=23549;break}l=h>>>16&255;m=c[1161480+(l*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(h&65535)>>1]=d&65535}else{fj[m&511](h&16777215,d&65535)}i=g+1|0;j=h+2|0}d=a+1|0;if(d>>>0<16){a=d;h=j;g=i}else{k=23555;break}}if((k|0)==23549){g=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=g;eJ(1166756,1)}else if((k|0)==23555){c[291649]=(c[291649]|0)+(i*28|0);return}}function UJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=0;i=(a<<24>>24)+g+h|0;h=0;while(1){if((1<<d&f|0)==0){j=h;k=i}else{g=c[1166604+(d<<2)>>2]|0;if((i&1|0)!=0&(c[291688]|0)!=0){l=23561;break}a=i>>>16&255;m=c[1161480+(a*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(i&65535)>>1]=g&65535}else{fj[m&511](i&16777215,g&65535)}j=h+1|0;k=i+2|0}g=d+1|0;if(g>>>0<16){d=g;i=k;h=j}else{l=23567;break}}if((l|0)==23561){h=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=h;eJ(1166756,1)}else if((l|0)==23567){c[291649]=(c[291649]|0)+(j*28|0);return}}function UK(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=0;g=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{j=c[1166604+(a<<2)>>2]|0;if((g&1|0)!=0&(c[291688]|0)!=0){k=23571;break}l=g>>>16&255;m=c[1161480+(l*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(g&65535)>>1]=j&65535}else{fj[m&511](g&16777215,j&65535)}h=d+1|0;i=g+2|0}j=a+1|0;if(j>>>0<16){a=j;g=i;d=h}else{k=23577;break}}if((k|0)==23577){c[291649]=(c[291649]|0)+(h*28|0);return}else if((k|0)==23571){k=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=k;eJ(1166756,1)}}function UL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+6;g=a+4|0;a=0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;d=0;while(1){if((1<<a&f|0)==0){i=d;j=h}else{g=c[1166604+(a<<2)>>2]|0;if((h&1|0)!=0&(c[291688]|0)!=0){k=23581;break}l=h>>>16&255;m=c[1161480+(l*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(h&65535)>>1]=g&65535}else{fj[m&511](h&16777215,g&65535)}i=d+1|0;j=h+2|0}g=a+1|0;if(g>>>0<16){a=g;h=j;d=i}else{k=23587;break}}if((k|0)==23587){c[291649]=(c[291649]|0)+(i*28|0);return}else if((k|0)==23581){k=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=k;eJ(1166756,1)}}function UM(){var a=0;a=c[1166604+((c[291673]&7)<<2)>>2]&255;c[291677]=a;c[291678]=a;c[291679]=0;c[291680]=0;return}function UN(){var a=0,b=0,e=0,f=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;return}function UO(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;return}function UP(){var a=0,b=0,e=0,f=0;a=c[291666]|0;c[291666]=a+2;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;return}function UQ(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;return}function UR(){var a=0,b=0,e=0,f=0;a=(c[291666]|0)-2|0;c[291666]=a;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;return}function US(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=0;while(1){if((1<<a&d|0)==0){h=g;i=f}else{j=c[1166604+(a<<2)>>2]|0;if((f&1|0)!=0&(c[291688]|0)!=0){k=23612;break}l=f>>>16&255;m=c[1161480+(l*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;l=m>>>16&255;n=c[1161480+(l*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(m&65535)>>1]=j&65535}else{fj[n&511](m&16777215,j&65535)}h=g+1|0;i=f+4|0}j=a+1|0;if(j>>>0<16){a=j;f=i;g=h}else{k=23621;break}}if((k|0)==23621){c[291649]=(c[291649]|0)+(h*56|0);return}else if((k|0)==23612){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}}function UT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=0;while(1){if((1<<a&d|0)==0){h=g;i=f}else{j=f-4|0;k=f-2|0;l=1166604+(15-a<<2)|0;m=c[l>>2]|0;if((k&1|0)!=0&(c[291688]|0)!=0){n=23625;break}o=k>>>16&255;p=c[1161480+(o*20|0)>>2]|0;if((p|0)==0){b[(c[1161464+(o*20|0)>>2]|0)+(k&65535)>>1]=m&65535}else{fj[p&511](k&16777215,m&65535)}m=(c[l>>2]|0)>>>16;if((j&1|0)!=0&(c[291688]|0)!=0){n=23630;break}l=j>>>16&255;p=c[1161480+(l*20|0)>>2]|0;if((p|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(j&65535)>>1]=m&65535}else{fj[p&511](j&16777215,m)}h=g+1|0;i=j}m=a+1|0;if(m>>>0<16){a=m;f=i;g=h}else{n=23636;break}}if((n|0)==23636){c[1166604+((c[291673]&7|8)<<2)>>2]=i;c[291649]=(c[291649]|0)+(h*56|0);return}else if((n|0)==23625){h=c[291675]|1;c[291699]=k;c[291700]=0;c[291701]=h;eJ(1166756,1)}else if((n|0)==23630){n=c[291675]|1;c[291699]=j;c[291700]=0;c[291701]=n;eJ(1166756,1)}}function UU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=0;h=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=0;while(1){if((1<<a&f|0)==0){i=g;j=h}else{d=c[1166604+(a<<2)>>2]|0;if((h&1|0)!=0&(c[291688]|0)!=0){k=23640;break}l=h>>>16&255;m=c[1161480+(l*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(h&65535)>>1]=d>>>16&65535}else{fj[m&511](h&16777215,d>>>16)}m=h+2|0;l=m>>>16&255;n=c[1161480+(l*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(m&65535)>>1]=d&65535}else{fj[n&511](m&16777215,d&65535)}i=g+1|0;j=h+4|0}d=a+1|0;if(d>>>0<16){a=d;h=j;g=i}else{k=23649;break}}if((k|0)==23649){c[291649]=(c[291649]|0)+(i*56|0);return}else if((k|0)==23640){k=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=k;eJ(1166756,1)}}function UV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=0;i=(a<<24>>24)+g+h|0;h=0;while(1){if((1<<d&f|0)==0){j=h;k=i}else{g=c[1166604+(d<<2)>>2]|0;if((i&1|0)!=0&(c[291688]|0)!=0){l=23655;break}a=i>>>16&255;m=c[1161480+(a*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(i&65535)>>1]=g>>>16&65535}else{fj[m&511](i&16777215,g>>>16)}m=i+2|0;a=m>>>16&255;n=c[1161480+(a*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=g&65535}else{fj[n&511](m&16777215,g&65535)}j=h+1|0;k=i+4|0}g=d+1|0;if(g>>>0<16){d=g;i=k;h=j}else{l=23664;break}}if((l|0)==23664){c[291649]=(c[291649]|0)+(j*56|0);return}else if((l|0)==23655){l=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=l;eJ(1166756,1)}}function UW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=0;g=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{j=c[1166604+(a<<2)>>2]|0;if((g&1|0)!=0&(c[291688]|0)!=0){k=23668;break}l=g>>>16&255;m=c[1161480+(l*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[m&511](g&16777215,j>>>16)}m=g+2|0;l=m>>>16&255;n=c[1161480+(l*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(m&65535)>>1]=j&65535}else{fj[n&511](m&16777215,j&65535)}h=d+1|0;i=g+4|0}j=a+1|0;if(j>>>0<16){a=j;g=i;d=h}else{k=23677;break}}if((k|0)==23677){c[291649]=(c[291649]|0)+(h*56|0);return}else if((k|0)==23668){k=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=k;eJ(1166756,1)}}function UX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+6;g=a+4|0;a=0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;d=0;while(1){if((1<<a&f|0)==0){i=d;j=h}else{g=c[1166604+(a<<2)>>2]|0;if((h&1|0)!=0&(c[291688]|0)!=0){k=23681;break}l=h>>>16&255;m=c[1161480+(l*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(h&65535)>>1]=g>>>16&65535}else{fj[m&511](h&16777215,g>>>16)}m=h+2|0;l=m>>>16&255;n=c[1161480+(l*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(m&65535)>>1]=g&65535}else{fj[n&511](m&16777215,g&65535)}i=d+1|0;j=h+4|0}g=a+1|0;if(g>>>0<16){a=g;h=j;d=i}else{k=23690;break}}if((k|0)==23681){d=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=d;eJ(1166756,1)}else if((k|0)==23690){c[291649]=(c[291649]|0)+(i*56|0);return}}function UY(){var a=0;a=c[1166604+((c[291673]&7)<<2)>>2]&65535;c[291677]=a>>>8;c[291678]=a;c[291679]=0;c[291680]=0;return}function UZ(){var a=0;a=c[1166604+((c[291673]&7)<<2)>>2]|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;return}function U_(){var a=0,e=0,f=0,g=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+a|0;a=f>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(f&65535^1)|0]|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;return}else{g=fl[e&255](f&16777215)|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;return}}function U$(){var a=0,b=0,f=0,g=0,h=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=b<<16>>16}else{g=b}b=(f<<24>>24)+a+g|0;g=b>>>16&255;a=c[1161468+(g*20|0)>>2]|0;if((a|0)==0){h=d[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;return}else{h=fl[a&255](b&16777215)|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;return}}function U0(){var a=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[1161468+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;return}else{g=fl[f&255](e&16777215)|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;return}}function U1(){var a=0,b=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a^1)|0]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;return}else{h=fl[g&255](a|b<<16&16711680)|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;return}}function U2(){var a=0;a=ahi()|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;return}function U3(){var a=0,b=0,d=0,f=0,g=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if((a&1|0)!=0&(c[291688]|0)!=0){b=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=b;eJ(1166756,1)}b=a>>>16&255;d=c[1161472+(b*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(b*20|0)>>2]|0)+(a&65535)>>1]|0;g=f>>>8;c[291677]=g;c[291678]=f;c[291679]=0;c[291680]=0;return}else{f=fl[d&255](a&16777215)|0;g=f>>>8;c[291677]=g;c[291678]=f;c[291679]=0;c[291680]=0;return}}function U4(){var a=0,b=0,d=0,f=0,g=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0;g=f>>>8;c[291677]=g;c[291678]=f;c[291679]=0;c[291680]=0;return}else{f=fl[d&255](b&16777215)|0;g=f>>>8;c[291677]=g;c[291678]=f;c[291679]=0;c[291680]=0;return}}function U5(){var a=0,b=0,d=0,f=0,g=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0;g=f>>>8;c[291677]=g;c[291678]=f;c[291679]=0;c[291680]=0;return}else{f=fl[d&255](b&16777215)|0;g=f>>>8;c[291677]=g;c[291678]=f;c[291679]=0;c[291680]=0;return}}function U6(){var a=0,d=0,f=0,g=0,h=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]|0;h=g>>>8;c[291677]=h;c[291678]=g;c[291679]=0;c[291680]=0;return}else{g=fl[d&255](f&16777215)|0;h=g>>>8;c[291677]=h;c[291678]=g;c[291679]=0;c[291680]=0;return}}function U7(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){f=b<<16>>16}else{f=b}b=(d<<24>>24)+a+f|0;if((b&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){g=e[(c[1161464+(f*20|0)>>2]|0)+(b&65535)>>1]|0;h=g>>>8;c[291677]=h;c[291678]=g;c[291679]=0;c[291680]=0;return}else{g=fl[a&255](b&16777215)|0;h=g>>>8;c[291677]=h;c[291678]=g;c[291679]=0;c[291680]=0;return}}function U8(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;h=g>>>8;c[291677]=h;c[291678]=g;c[291679]=0;c[291680]=0;return}else{g=fl[f&255](d&16777215)|0;h=g>>>8;c[291677]=h;c[291678]=g;c[291679]=0;c[291680]=0;return}}function U9(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b&255;b=c[1161472+(f*20|0)>>2]|0;if((b|0)==0){g=e[(c[1161464+(f*20|0)>>2]|0)+a>>1]|0;h=g>>>8;c[291677]=h;c[291678]=g;c[291679]=0;c[291680]=0;return}else{g=fl[b&255](d&16777215)|0;h=g>>>8;c[291677]=h;c[291678]=g;c[291679]=0;c[291680]=0;return}}function Va(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if((a&1|0)!=0&(c[291688]|0)!=0){b=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=b;eJ(1166756,1)}b=a>>>16&255;d=1161472+(b*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=a+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(b*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;i=h>>>24;c[291677]=i;c[291678]=h;c[291679]=0;c[291680]=0;return}else{b=(fl[f&255](a&16777215)|0)<<16;h=fl[c[d>>2]&255](a+2&16777215)|0|b;i=h>>>24;c[291677]=i;c[291678]=h;c[291679]=0;c[291680]=0;return}}function Vb(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=1161472+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;i=h>>>24;c[291677]=i;c[291678]=h;c[291679]=0;c[291680]=0;return}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a;i=h>>>24;c[291677]=i;c[291678]=h;c[291679]=0;c[291680]=0;return}}function Vc(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=i>>>24;c[291677]=j;c[291678]=i;c[291679]=0;c[291680]=0;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a;j=i>>>24;c[291677]=j;c[291678]=i;c[291679]=0;c[291680]=0;return}}function Vd(){var a=0;a=1166604+((c[291673]&7)<<2)|0;c[291678]=c[a>>2]&255;c[291677]=c[a>>2];c[291679]=0;c[291680]=0;c[a>>2]=c[a>>2]|128;return}function Ve(){var a=0;a=ahh()|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;return}function Vf(){var a=0;a=ahg()|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;return}function Vg(){var a=0,b=0,e=0,f=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[291678]=f;c[291677]=f;c[291679]=0;c[291680]=0;return}function Vh(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}c[291678]=f;c[291677]=f;c[291679]=0;c[291680]=0;return}function Vi(){var a=0,b=0,e=0,f=0;a=c[291666]|0;c[291666]=a+2;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[291678]=f;c[291677]=f;c[291679]=0;c[291680]=0;return}function Vj(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}c[291678]=f;c[291677]=f;c[291679]=0;c[291680]=0;return}function Vk(){var a=0,b=0,e=0,f=0;a=(c[291666]|0)-2|0;c[291666]=a;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[291678]=f;c[291677]=f;c[291679]=0;c[291680]=0;return}function Vl(){var a=0,e=0,f=0,g=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+a|0;a=f>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(f&65535^1)|0]|0;c[291678]=g;c[291677]=g;c[291679]=0;c[291680]=0;return}else{g=fl[e&255](f&16777215)|0;c[291678]=g;c[291677]=g;c[291679]=0;c[291680]=0;return}}function Vm(){var a=0,b=0,f=0,g=0,h=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=b<<16>>16}else{g=b}b=(f<<24>>24)+a+g|0;g=b>>>16&255;a=c[1161468+(g*20|0)>>2]|0;if((a|0)==0){h=d[(c[1161464+(g*20|0)>>2]|0)+(b&65535^1)|0]|0;c[291678]=h;c[291677]=h;c[291679]=0;c[291680]=0;return}else{h=fl[a&255](b&16777215)|0;c[291678]=h;c[291677]=h;c[291679]=0;c[291680]=0;return}}function Vn(){var a=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[1161468+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0;c[291678]=g;c[291677]=g;c[291679]=0;c[291680]=0;return}else{g=fl[f&255](e&16777215)|0;c[291678]=g;c[291677]=g;c[291679]=0;c[291680]=0;return}}function Vo(){var a=0,b=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a^1)|0]|0;c[291678]=h;c[291677]=h;c[291679]=0;c[291680]=0;return}else{h=fl[g&255](a|b<<16&16711680)|0;c[291678]=h;c[291677]=h;c[291679]=0;c[291680]=0;return}}function Vp(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){f=b<<16>>16}else{f=b}b=(d<<24>>24)+a+f|0;if((b&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b>>>16&255;a=1161472+(f*20|0)|0;d=c[a>>2]|0;if((d|0)==0){g=b+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;i=h>>>24;c[291677]=i;c[291678]=h;c[291679]=0;c[291680]=0;return}else{f=(fl[d&255](b&16777215)|0)<<16;h=fl[c[a>>2]&255](b+2&16777215)|0|f;i=h>>>24;c[291677]=i;c[291678]=h;c[291679]=0;c[291680]=0;return}}function Vq(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=0;while(1){if((1<<a&b|0)==0){g=f;h=d}else{if((d&1|0)!=0&(c[291688]|0)!=0){i=23864;break}j=d>>>16&255;k=c[1161472+(j*20|0)>>2]|0;if((k|0)==0){l=e[(c[1161464+(j*20|0)>>2]|0)+(d&65535)>>1]|0}else{l=fl[k&255](d&16777215)|0}c[1166604+(a<<2)>>2]=l<<16>>16;g=f+1|0;h=d+2|0}k=a+1|0;if(k>>>0<16){a=k;d=h;f=g}else{i=23870;break}}if((i|0)==23864){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}else if((i|0)==23870){c[291649]=(c[291649]|0)+(g*28|0);return}}function Vr(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=0;while(1){if((1<<a&b|0)==0){g=f;h=d}else{if((d&1|0)!=0&(c[291688]|0)!=0){i=23874;break}j=d>>>16&255;k=c[1161472+(j*20|0)>>2]|0;if((k|0)==0){l=e[(c[1161464+(j*20|0)>>2]|0)+(d&65535)>>1]|0}else{l=fl[k&255](d&16777215)|0}c[1166604+(a<<2)>>2]=l<<16>>16;g=f+1|0;h=d+2|0}k=a+1|0;if(k>>>0<16){a=k;d=h;f=g}else{i=23880;break}}if((i|0)==23874){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}else if((i|0)==23880){c[1166604+((c[291673]&7|8)<<2)>>2]=h;c[291649]=(c[291649]|0)+(g*28|0);return}}function Vs(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=0;h=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=0;while(1){if((1<<a&f|0)==0){i=g;j=h}else{if((h&1|0)!=0&(c[291688]|0)!=0){k=23884;break}d=h>>>16&255;l=c[1161472+(d*20|0)>>2]|0;if((l|0)==0){m=e[(c[1161464+(d*20|0)>>2]|0)+(h&65535)>>1]|0}else{m=fl[l&255](h&16777215)|0}c[1166604+(a<<2)>>2]=m<<16>>16;i=g+1|0;j=h+2|0}l=a+1|0;if(l>>>0<16){a=l;h=j;g=i}else{k=23890;break}}if((k|0)==23890){c[291649]=(c[291649]|0)+(i*28|0);return}else if((k|0)==23884){k=c[291675]|1;c[291699]=h;c[291700]=16;c[291701]=k;eJ(1166756,1)}}function Vt(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;b=a+2|0;c[291667]=b;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){g=b<<16>>16}else{g=b}b=0;h=(a<<24>>24)+f+g|0;g=0;while(1){if((1<<b&d|0)==0){i=g;j=h}else{if((h&1|0)!=0&(c[291688]|0)!=0){k=23896;break}f=h>>>16&255;a=c[1161472+(f*20|0)>>2]|0;if((a|0)==0){l=e[(c[1161464+(f*20|0)>>2]|0)+(h&65535)>>1]|0}else{l=fl[a&255](h&16777215)|0}c[1166604+(b<<2)>>2]=l<<16>>16;i=g+1|0;j=h+2|0}a=b+1|0;if(a>>>0<16){b=a;h=j;g=i}else{k=23902;break}}if((k|0)==23896){g=c[291675]|1;c[291699]=h;c[291700]=16;c[291701]=g;eJ(1166756,1)}else if((k|0)==23902){c[291649]=(c[291649]|0)+(i*28|0);return}}function Vu(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=0;g=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{c[1166604+(a<<2)>>2]=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;h=d+1|0;i=g+2|0}j=a+1|0;if(j>>>0<16){a=j;g=i;d=h}else{break}}c[291649]=(c[291649]|0)+(h*28|0);return}function Vv(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=g<<16>>16}else{h=g}g=0;i=(a<<24>>24)+d+h|0;h=0;while(1){if((1<<g&f|0)==0){j=h;k=i}else{c[1166604+(g<<2)>>2]=b[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;j=h+1|0;k=i+2|0}d=g+1|0;if(d>>>0<16){g=d;i=k;h=j}else{break}}c[291649]=(c[291649]|0)+(j*28|0);return}function Vw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=0;g=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{if((g&1|0)!=0&(c[291688]|0)!=0){j=23918;break}k=g>>>16&255;l=c[1161472+(k*20|0)>>2]|0;if((l|0)==0){m=e[(c[1161464+(k*20|0)>>2]|0)+(g&65535)>>1]|0}else{m=fl[l&255](g&16777215)|0}c[1166604+(a<<2)>>2]=m<<16>>16;h=d+1|0;i=g+2|0}l=a+1|0;if(l>>>0<16){a=l;g=i;d=h}else{j=23924;break}}if((j|0)==23924){c[291649]=(c[291649]|0)+(h*28|0);return}else if((j|0)==23918){j=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=j;eJ(1166756,1)}}function Vx(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;b=a+2|0;c[291667]=b;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+6;f=a+4|0;a=0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;b=0;while(1){if((1<<a&d|0)==0){h=b;i=g}else{if((g&1|0)!=0&(c[291688]|0)!=0){j=23928;break}f=g>>>16&255;k=c[1161472+(f*20|0)>>2]|0;if((k|0)==0){l=e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{l=fl[k&255](g&16777215)|0}c[1166604+(a<<2)>>2]=l<<16>>16;h=b+1|0;i=g+2|0}k=a+1|0;if(k>>>0<16){a=k;g=i;b=h}else{j=23934;break}}if((j|0)==23928){b=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=b;eJ(1166756,1)}else if((j|0)==23934){c[291649]=(c[291649]|0)+(h*28|0);return}}function Vy(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=0;while(1){if((1<<a&b|0)==0){g=f;h=d}else{if((d&1|0)!=0&(c[291688]|0)!=0){i=23938;break}j=d>>>16&255;k=1161472+(j*20|0)|0;l=c[k>>2]|0;if((l|0)==0){m=d+2|0;n=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{j=(fl[l&255](d&16777215)|0)<<16;n=fl[c[k>>2]&255](d+2&16777215)|0|j}c[1166604+(a<<2)>>2]=n;g=f+1|0;h=d+4|0}j=a+1|0;if(j>>>0<16){a=j;d=h;f=g}else{i=23944;break}}if((i|0)==23938){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}else if((i|0)==23944){c[291649]=(c[291649]|0)+(g*56|0);return}}function Vz(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=0;while(1){if((1<<a&b|0)==0){g=f;h=d}else{if((d&1|0)!=0&(c[291688]|0)!=0){i=23948;break}j=d>>>16&255;k=1161472+(j*20|0)|0;l=c[k>>2]|0;if((l|0)==0){m=d+2|0;n=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{j=(fl[l&255](d&16777215)|0)<<16;n=fl[c[k>>2]&255](d+2&16777215)|0|j}c[1166604+(a<<2)>>2]=n;g=f+1|0;h=d+4|0}j=a+1|0;if(j>>>0<16){a=j;d=h;f=g}else{i=23954;break}}if((i|0)==23948){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}else if((i|0)==23954){c[1166604+((c[291673]&7|8)<<2)>>2]=h;c[291649]=(c[291649]|0)+(g*56|0);return}}function VA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=0;h=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=0;while(1){if((1<<a&f|0)==0){i=g;j=h}else{if((h&1|0)!=0&(c[291688]|0)!=0){k=23958;break}d=h>>>16&255;l=1161472+(d*20|0)|0;m=c[l>>2]|0;if((m|0)==0){n=h+2|0;o=e[(c[1161464+((n>>>16&255)*20|0)>>2]|0)+(n&65535)>>1]|e[(c[1161464+(d*20|0)>>2]|0)+(h&65535)>>1]<<16}else{d=(fl[m&255](h&16777215)|0)<<16;o=fl[c[l>>2]&255](h+2&16777215)|0|d}c[1166604+(a<<2)>>2]=o;i=g+1|0;j=h+4|0}d=a+1|0;if(d>>>0<16){a=d;h=j;g=i}else{k=23964;break}}if((k|0)==23958){g=c[291675]|1;c[291699]=h;c[291700]=16;c[291701]=g;eJ(1166756,1)}else if((k|0)==23964){c[291649]=(c[291649]|0)+(i*56|0);return}}function VB(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;b=a+2|0;c[291667]=b;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){g=b<<16>>16}else{g=b}b=0;h=(a<<24>>24)+f+g|0;g=0;while(1){if((1<<b&d|0)==0){i=g;j=h}else{if((h&1|0)!=0&(c[291688]|0)!=0){k=23970;break}f=h>>>16&255;a=1161472+(f*20|0)|0;l=c[a>>2]|0;if((l|0)==0){m=h+2|0;n=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(h&65535)>>1]|0)<<16}else{f=(fl[l&255](h&16777215)|0)<<16;n=fl[c[a>>2]&255](h+2&16777215)|0|f}c[1166604+(b<<2)>>2]=n;i=g+1|0;j=h+4|0}f=b+1|0;if(f>>>0<16){b=f;h=j;g=i}else{k=23976;break}}if((k|0)==23976){c[291649]=(c[291649]|0)+(i*56|0);return}else if((k|0)==23970){k=c[291675]|1;c[291699]=h;c[291700]=16;c[291701]=k;eJ(1166756,1)}}function VC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=0;g=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{if((g&1|0)!=0&(c[291688]|0)!=0){j=23980;break}k=g>>>16&255;l=1161472+(k*20|0)|0;m=c[l>>2]|0;if((m|0)==0){n=g+2|0;o=e[(c[1161464+((n>>>16&255)*20|0)>>2]|0)+(n&65535)>>1]|e[(c[1161464+(k*20|0)>>2]|0)+(g&65535)>>1]<<16}else{k=(fl[m&255](g&16777215)|0)<<16;o=fl[c[l>>2]&255](g+2&16777215)|0|k}c[1166604+(a<<2)>>2]=o;h=d+1|0;i=g+4|0}k=a+1|0;if(k>>>0<16){a=k;g=i;d=h}else{j=23986;break}}if((j|0)==23980){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}else if((j|0)==23986){c[291649]=(c[291649]|0)+(h*56|0);return}}function VD(){return}function VE(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=0;g=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{j=g+2|0;c[1166604+(a<<2)>>2]=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]<<16;h=d+1|0;i=g+4|0}j=a+1|0;if(j>>>0<16){a=j;g=i;d=h}else{break}}c[291649]=(c[291649]|0)+(h*56|0);return}function VF(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;b=a+2|0;c[291667]=b;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){g=f<<16>>16}else{g=f}f=0;h=(a<<24>>24)+b+g|0;g=0;while(1){if((1<<f&d|0)==0){i=g;j=h}else{b=h+2|0;c[1166604+(f<<2)>>2]=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0)<<16;i=g+1|0;j=h+4|0}b=f+1|0;if(b>>>0<16){f=b;h=j;g=i}else{break}}c[291649]=(c[291649]|0)+(i*56|0);return}function VG(){var a=0,d=0,e=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;e=(c[291666]|0)-4|0;c[291666]=e;b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]=d>>>16&65535;e=(c[291666]|0)+2|0;b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]=d&65535;c[a>>2]=c[291666];a=c[291666]|0;d=c[291667]|0;c[291667]=d+2;c[291666]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a;return}function VH(){var a=0,b=0,d=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[291666]=b+4;d=b+2|0;c[a>>2]=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;return}function VI(){var a=0,b=0;a=c[291666]|0;c[291666]=a+4;b=a+2|0;c[291667]=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;return}function VJ(){var a=0,b=0,d=0,f=0;a=c[291666]|0;b=a+2|0;c[291666]=b;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=d<<4;c[291676]=f&256;c[291677]=f&128;c[291678]=d>>>2&1^1;c[291679]=d<<6&128;c[291680]=d<<8&256;c[291666]=a+6;d=a+4|0;c[291667]=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;return}function VK(){var a=0,d=0,e=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;e=(c[291666]|0)-4|0;c[291666]=e;b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]=d>>>16&65535;e=(c[291666]|0)+2|0;b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]=d&65535;c[291667]=a;return}function VL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]&15|32;d=c[291675]|0;f=d<<11|c[291674]|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;c[291674]=0;c[1166672+(d<<2)>>2]=c[291666];c[291675]=4;d=c[291667]|0;g=(c[291672]|0)-4|0;c[291666]=g;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[291666]|0)+2|0;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;d=(c[291666]|0)-2|0;c[291666]=d;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;f=a<<2;d=c[290368]|0;if((d|0)==0){g=c[290366]|0;h=e[g+(f|2)>>1]|0|(e[g+f>>1]|0)<<16;c[291667]=h;i=536776+(a<<1)|0;j=b[i>>1]|0;k=j&65535;l=c[291649]|0;m=l+k|0;c[291649]=m;return}else{g=(fl[d&255](f)|0)<<16;h=fl[c[290368]&255](f|2)|0|g;c[291667]=h;i=536776+(a<<1)|0;j=b[i>>1]|0;k=j&65535;l=c[291649]|0;m=l+k|0;c[291649]=m;return}}function VM(){if((c[291675]|0)==0){ahd();return}else{c[291668]=c[1166604+((c[291673]&7|8)<<2)>>2];return}}function VN(){if((c[291675]|0)==0){ahd();return}else{c[1166604+((c[291673]&7|8)<<2)>>2]=c[291668];return}}function VO(){if((c[291675]|0)==0){ahd();return}else{c[291649]=(c[291649]|0)+924;return}}function VP(){var a=0,b=0,d=0;a=c[291675]|0;if((a|0)==0){ahd();return}else{b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;c[291683]=c[291683]|1;c[291674]=d&32768;c[291681]=d&1792;b=d<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=d>>>2&1^1;c[291679]=d<<6&128;c[291680]=d<<8&256;b=d>>>11&4;c[1166672+(a<<2)>>2]=c[291666];c[291675]=b;c[291666]=c[1166672+(b<<2)>>2];ID();c[291649]=(c[291650]|0)-28;return}}function VQ(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291675]|0;if((a|0)==0){ahd();return}else{b=c[291666]|0;d=b+2|0;c[291666]=d;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+6|0;c[291666]=g;h=b+4|0;c[291667]=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;c[291674]=f&32768;c[291681]=f&1792;d=f<<4;c[291676]=d&256;c[291677]=d&128;c[291678]=f>>>2&1^1;c[291679]=f<<6&128;c[291680]=f<<8&256;d=f>>>11&4;c[1166672+(a<<2)>>2]=g;c[291675]=d;c[291666]=c[1166672+(d<<2)>>2];ID();c[291686]=0;c[291687]=0;return}}function VR(){if((c[291679]&128|0)==0){return}ahc(7);return}function VS(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;b=a+2|0;c[291667]=b;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+6;f=a+4|0;a=0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;b=0;while(1){if((1<<a&d|0)==0){h=b;i=g}else{if((g&1|0)!=0&(c[291688]|0)!=0){j=24049;break}f=g>>>16&255;k=1161472+(f*20|0)|0;l=c[k>>2]|0;if((l|0)==0){m=g+2|0;n=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{f=(fl[l&255](g&16777215)|0)<<16;n=fl[c[k>>2]&255](g+2&16777215)|0|f}c[1166604+(a<<2)>>2]=n;h=b+1|0;i=g+4|0}f=a+1|0;if(f>>>0<16){a=f;g=i;b=h}else{j=24055;break}}if((j|0)==24049){b=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=b;eJ(1166756,1)}else if((j|0)==24055){c[291649]=(c[291649]|0)+(h*56|0);return}}function VT(){var a=0,d=0,e=0,f=0,g=0;a=c[291666]|0;d=a-4|0;c[291666]=d;if((d&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=d>>>16;f=e&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=e&65535}else{fj[g&511](d&16777215,e)}e=a-2|0;a=e>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(e&65535)>>1]=d&65535}else{fj[g&511](e&16777215,d&65535)}d=c[291666]|0;e=c[291667]|0;c[291667]=e+2;c[291666]=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d;return}function VU(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291666]|0;if((a&1|0)!=0&(c[291688]|0)!=0){b=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=b;eJ(1166756,1)}b=a>>>16&255;d=1161472+(b*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=a+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(b*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;c[291666]=h;return}else{b=(fl[f&255](a&16777215)|0)<<16;h=fl[c[d>>2]&255](a+2&16777215)|0|b;c[291666]=h;return}}function VV(){var a=0,d=0,e=0,f=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;e=d+2|0;c[291667]=e;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(c[291666]|0)-4|0;c[291666]=a;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=e>>>16&65535;a=(c[291666]|0)+2|0;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=e&65535;c[291667]=f;return}function VW(){var a=0,d=0,f=0,g=0,h=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=d<<16>>16}else{h=d}d=(c[291666]|0)-4|0;c[291666]=d;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f>>>16&65535;d=(c[291666]|0)+2|0;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;c[291667]=(g<<24>>24)+a+h;return}function VX(){var a=0,d=0,e=0;a=c[291667]|0;d=a+2|0;c[291667]=d;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(c[291666]|0)-4|0;c[291666]=a;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535;a=(c[291666]|0)+2|0;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d&65535;c[291667]=e;return}function VY(){var a=0,d=0,f=0,g=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=(c[291666]|0)-4|0;c[291666]=a;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535;a=(c[291666]|0)+2|0;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d&65535;c[291667]=g;return}function VZ(){var a=0,d=0,e=0;a=c[291667]|0;d=a+2|0;c[291667]=d;e=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=(c[291666]|0)-4|0;c[291666]=a;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535;a=(c[291666]|0)+2|0;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d&65535;c[291667]=e;return}function V_(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(c[291666]|0)-4|0;c[291666]=g;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[291666]|0)+2|0;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;c[291667]=(f<<24>>24)+a+h;return}function V$(){c[291667]=c[1166604+((c[291673]&7|8)<<2)>>2];return}function V0(){var a=0,d=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a;return}function V1(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)!=0){f=b;g=d<<24;h=g>>24;i=h+a|0;j=i+f|0;c[291667]=j;return}f=b<<16>>16;g=d<<24;h=g>>24;i=h+a|0;j=i+f|0;c[291667]=j;return}function V2(){var a=0;a=c[291667]|0;c[291667]=a+2;c[291667]=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;return}function V3(){var a=0,b=0;a=c[291667]|0;c[291667]=a+4;b=a+2|0;c[291667]=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;return}function V4(){var a=0;a=c[291667]|0;c[291667]=a+2;c[291667]=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a;return}function V5(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}c[291667]=(b<<24>>24)+a+f;return}function V6(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&255;f=d+e|0;c[291677]=f;c[291679]=(f^d)&(f^e);c[291680]=f;c[291676]=f;f=d+a&255;c[291678]=f;c[b>>2]=f|c[b>>2]&-256;return}function V7(){var b=0,e=0,f=0,g=0,h=0;b=c[291673]|0;e=((b>>>9)+7&7)+1|0;f=c[1166604+((b&7|8)<<2)>>2]|0;b=f>>>16&255;g=c[1161468+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=h+e|0;c[291677]=g;c[291679]=(g^e)&(g^h);c[291680]=g;c[291676]=g;h=g&255;c[291678]=h;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,h);return}}function V8(){var b=0,e=0,f=0,g=0,h=0;b=c[291673]|0;e=((b>>>9)+7&7)+1|0;f=1166604+((b&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+1;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h+e|0;c[291677]=g;c[291679]=(g^e)&(g^h);c[291680]=g;c[291676]=g;h=g&255;c[291678]=h;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,h);return}}function V9(){var b=0,e=0,f=0,g=0,h=0;b=(((c[291673]|0)>>>9)+7&7)+1|0;e=c[291666]|0;c[291666]=e+2;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h+b|0;c[291677]=g;c[291679]=(g^b)&(g^h);c[291680]=g;c[291676]=g;h=g&255;c[291678]=h;b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,h);return}}function Wa(){var b=0,e=0,f=0,g=0,h=0;b=c[291673]|0;e=((b>>>9)+7&7)+1|0;f=1166604+((b&7|8)<<2)|0;b=(c[f>>2]|0)-1|0;c[f>>2]=b;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h+e|0;c[291677]=g;c[291679]=(g^e)&(g^h);c[291680]=g;c[291676]=g;h=g&255;c[291678]=h;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,h);return}}function Wb(){var b=0,e=0,f=0,g=0,h=0;b=(((c[291673]|0)>>>9)+7&7)+1|0;e=(c[291666]|0)-2|0;c[291666]=e;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h+b|0;c[291677]=g;c[291679]=(g^b)&(g^h);c[291680]=g;c[291676]=g;h=g&255;c[291678]=h;b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,h);return}}function Wc(){var e=0,f=0,g=0,h=0,i=0;e=c[291673]|0;f=((e>>>9)+7&7)+1|0;g=c[1166604+((e&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;h=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+g|0;g=h>>>16&255;e=c[1161468+(g*20|0)>>2]|0;if((e|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[e&255](h&16777215)|0}e=i+f|0;c[291677]=e;c[291679]=(e^f)&(e^i);c[291680]=e;c[291676]=e;i=e&255;c[291678]=i;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]=e&255;return}else{fj[f&511](h&16777215,i);return}}function Wd(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&65535;f=d+e|0;g=f>>>8;c[291677]=g;c[291679]=((f^d)&(f^e))>>>8;c[291680]=g;c[291676]=g;g=d+a&65535;c[291678]=g;c[b>>2]=g|c[b>>2]&-65536;return}function We(){var a=0,b=0;a=c[291673]|0;b=1166604+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)+1+((a>>>9)+7&7);return}function Wf(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291673]|0;f=((b>>>9)+7&7)+1|0;g=c[1166604+((b&7|8)<<2)>>2]|0;b=c[291667]|0;c[291667]=b+2;h=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=b<<16>>16}else{i=b}b=(h<<24>>24)+g+i|0;i=b>>>16&255;g=c[1161468+(i*20|0)>>2]|0;if((g|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(b&65535^1)|0]|0}else{j=fl[g&255](b&16777215)|0}g=j+f|0;c[291677]=g;c[291679]=(g^f)&(g^j);c[291680]=g;c[291676]=g;j=g&255;c[291678]=j;f=c[1161476+(i*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[f&511](b&16777215,j);return}}function Wg(){var e=0,f=0,g=0,h=0,i=0;e=(((c[291673]|0)>>>9)+7&7)+1|0;f=c[291667]|0;c[291667]=f+2;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g>>>16&255;h=c[1161468+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i+e|0;c[291677]=h;c[291679]=(h^e)&(h^i);c[291680]=h;c[291676]=h;i=h&255;c[291678]=i;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,i);return}}function Wh(){var b=0,f=0,g=0,h=0,i=0,j=0;b=(((c[291673]|0)>>>9)+7&7)+1|0;f=c[291667]|0;c[291667]=f+4;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=f|g<<16;i=g&255;g=c[1161468+(i*20|0)>>2]|0;if((g|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(f^1)|0]|0}else{j=fl[g&255](h&16777215)|0}g=j+b|0;c[291677]=g;c[291679]=(g^b)&(g^j);c[291680]=g;c[291676]=g;j=g&255;c[291678]=j;b=c[1161476+(i*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(f^1)|0]=g&255;return}else{fj[b&511](h&16777215,j);return}}function Wi(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j+d|0;i=g>>>8;c[291677]=i;c[291679]=((g^d)&(g^j))>>>8;c[291680]=i;c[291676]=i;i=g&65535;c[291678]=i;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[k&511](f&16777215,i);return}}function Wj(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=1166604+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+2;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j+d|0;i=g>>>8;c[291677]=i;c[291679]=((g^d)&(g^j))>>>8;c[291680]=i;c[291676]=i;i=g&65535;c[291678]=i;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[k&511](a&16777215,i);return}}function Wk(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=1166604+((a&7|8)<<2)|0;a=(c[f>>2]|0)-2|0;c[f>>2]=a;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j+d|0;i=g>>>8;c[291677]=i;c[291679]=((g^d)&(g^j))>>>8;c[291680]=i;c[291676]=i;i=g&65535;c[291678]=i;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[k&511](a&16777215,i);return}}function Wl(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=(g&1|0)!=0;a=c[291688]|0;if(f&(a|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]|0;k=a}else{a=fl[i&255](g&16777215)|0;j=a;k=c[291688]|0}a=j+d|0;i=a>>>8;c[291677]=i;c[291679]=((a^d)&(a^j))>>>8;c[291680]=i;c[291676]=i;i=a&65535;c[291678]=i;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=a&65535;return}else{fj[k&511](g&16777215,i);return}}function Wm(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=(a&1|0)!=0;f=c[291688]|0;if(h&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;i=c[1161472+(g*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;k=f}else{f=fl[i&255](a&16777215)|0;j=f;k=c[291688]|0}f=j+d|0;i=f>>>8;c[291677]=i;c[291679]=((f^d)&(f^j))>>>8;c[291680]=i;c[291676]=i;i=f&65535;c[291678]=i;if(h&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(g*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535;return}else{fj[k&511](a&16777215,i);return}}function Wn(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=(((c[291673]|0)>>>9)+7&7)+1|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(f&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j+a|0;i=g>>>8;c[291677]=i;c[291679]=((g^a)&(g^j))>>>8;c[291680]=i;c[291676]=i;i=g&65535;c[291678]=i;if(d&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[k&511](f&16777215,i);return}}function Wo(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=d+a|0;c[291677]=e>>>24;c[291679]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(d|a)|d&a)>>>23;c[291680]=f;c[291676]=f;c[291678]=e;c[b>>2]=e;return}function Wp(){var a=0,b=0;a=c[291673]|0;b=1166604+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)+1+((a>>>9)+7&7);return}function Wq(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=(((c[291673]|0)>>>9)+7&7)+1|0;d=c[291667]|0;c[291667]=d+4;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;h=(d&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=f&255;f=c[1161472+(j*20|0)>>2]|0;if((f|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+d>>1]|0;l=i}else{i=fl[f&255](g&16777215)|0;k=i;l=c[291688]|0}i=k+a|0;f=i>>>8;c[291677]=f;c[291679]=((i^a)&(i^k))>>>8;c[291680]=f;c[291676]=f;f=i&65535;c[291678]=f;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+d>>1]=i&65535;return}else{fj[l&511](g&16777215,f);return}}function Wr(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](f+2&16777215)|0|g;l=j;m=c[291688]|0}j=l+d|0;c[291677]=j>>>24;c[291679]=((j^d)&(j^l))>>>24;g=((j^-8388608)&(l|d)|l&d)>>>23;c[291680]=g;c[291676]=g;c[291678]=j;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;h=c[1161480+(f*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function Ws(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=1166604+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+4;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|g;l=j;m=c[291688]|0}j=l+d|0;c[291677]=j>>>24;c[291679]=((j^d)&(j^l))>>>24;g=((j^-8388608)&(l|d)|l&d)>>>23;c[291680]=g;c[291676]=g;c[291678]=j;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function Wt(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=1166604+((a&7|8)<<2)|0;a=c[f>>2]|0;g=a-4|0;c[f>>2]=g;f=(g&1|0)!=0;h=c[291688]|0;if(f&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=g>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=a-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](g&16777215)|0)<<16;k=fl[c[j>>2]&255](a+16777214&16777215)|0|h;m=k;n=c[291688]|0}k=m+d|0;c[291677]=k>>>24;c[291679]=((k^d)&(k^m))>>>24;h=((k^-8388608)&(m|d)|m&d)>>>23;c[291680]=h;c[291676]=h;c[291678]=k;if(f&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}g=a-2|0;a=g>>>16&255;n=c[1161480+(a*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(g&65535)>>1]=k&65535;return}else{fj[n&511](g&16777215,k&65535);return}}function Wu(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=(g&1|0)!=0;a=c[291688]|0;if(f&(a|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=g+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]<<16;m=a}else{a=(fl[j&255](g&16777215)|0)<<16;j=fl[c[i>>2]&255](g+2&16777215)|0|a;l=j;m=c[291688]|0}j=l+d|0;c[291677]=j>>>24;c[291679]=((j^d)&(j^l))>>>24;a=((j^-8388608)&(l|d)|l&d)>>>23;c[291680]=a;c[291676]=a;c[291678]=j;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[m&511](g&16777215,j>>>16)}m=g+2|0;g=m>>>16&255;h=c[1161480+(g*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function Wv(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=(a&1|0)!=0;f=c[291688]|0;if(h&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;i=1161472+(g*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;m=f}else{f=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|f;l=j;m=c[291688]|0}j=l+d|0;c[291677]=j>>>24;c[291679]=((j^d)&(j^l))>>>24;f=((j^-8388608)&(l|d)|l&d)>>>23;c[291680]=f;c[291676]=f;c[291678]=j;if(h&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(g*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[g&511](m&16777215,j&65535);return}}function Ww(){c[291667]=(c[291667]|0)+2;return}function Wx(){var a=0;a=1166604+((c[291673]&7)<<2)|0;c[a>>2]=c[a>>2]|255;return}function Wy(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&255;f=e-d|0;c[291677]=f;g=a-d&255;c[291678]=g;c[291680]=f;c[291676]=f;c[291679]=(f^e)&(d^e);c[b>>2]=g|c[b>>2]&-256;return}function Wz(){var b=0,d=0,e=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=b>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=-1;return}else{fj[e&511](b&16777215,255);return}}function WA(){var b=0,d=0,e=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=d>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=-1;return}else{fj[e&511](d&16777215,255);return}}function WB(){var b=0,d=0,e=0;b=c[291666]|0;c[291666]=b+2;d=b>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=-1;return}else{fj[e&511](b&16777215,255);return}}function WC(){var b=0,d=0,e=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=d>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=-1;return}else{fj[e&511](d&16777215,255);return}}function WD(){var b=0,d=0,e=0;b=(c[291666]|0)-2|0;c[291666]=b;d=b>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=-1;return}else{fj[e&511](b&16777215,255);return}}function WE(){var d=0,e=0,f=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=f>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(f&65535^1)|0]=-1;return}else{fj[e&511](f&16777215,255);return}}function WF(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[1161476+(g*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(d&65535^1)|0]=-1;return}else{fj[b&511](d&16777215,255);return}}function WG(){var d=0,e=0,f=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e>>>16&255;f=c[1161476+(d*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(e&65535^1)|0]=-1;return}else{fj[f&511](e&16777215,255);return}}function WH(){var b=0,d=0,f=0,g=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b^1)|0]=-1;return}else{fj[g&511](b|d<<16&16711680,255);return}}function WI(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=((b>>>9)+7&7)+1|0;f=c[1166604+((b&7|8)<<2)>>2]|0;b=f>>>16&255;g=c[1161468+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=h-e|0;c[291677]=g;i=g&255;c[291678]=i;c[291680]=g;c[291676]=g;c[291679]=(g^h)&(h^e);e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,i);return}}function WJ(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=((b>>>9)+7&7)+1|0;f=1166604+((b&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+1;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h-e|0;c[291677]=g;i=g&255;c[291678]=i;c[291680]=g;c[291676]=g;c[291679]=(g^h)&(h^e);e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,i);return}}function WK(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(((c[291673]|0)>>>9)+7&7)+1|0;e=c[291666]|0;c[291666]=e+2;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h-b|0;c[291677]=g;i=g&255;c[291678]=i;c[291680]=g;c[291676]=g;c[291679]=(g^h)&(h^b);b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,i);return}}function WL(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=((b>>>9)+7&7)+1|0;f=1166604+((b&7|8)<<2)|0;b=(c[f>>2]|0)-1|0;c[f>>2]=b;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h-e|0;c[291677]=g;i=g&255;c[291678]=i;c[291680]=g;c[291676]=g;c[291679]=(g^h)&(h^e);e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,i);return}}function WM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=(((c[291673]|0)>>>9)+7&7)+1|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(f&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]<<16;m=g}else{g=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](f+2&16777215)|0|g;l=j;m=c[291688]|0}j=l+a|0;c[291677]=j>>>24;c[291679]=((j^a)&(j^l))>>>24;g=((j^-8388608)&(l|a)|l&a)>>>23;c[291680]=g;c[291676]=g;c[291678]=j;if(d&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;h=c[1161480+(f*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function WN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=(((c[291673]|0)>>>9)+7&7)+1|0;d=c[291667]|0;c[291667]=d+4;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;h=(d&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=f&255;f=1161472+(j*20|0)|0;k=c[f>>2]|0;if((k|0)==0){l=g+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+d>>1]|0)<<16;n=i}else{i=(fl[k&255](g&16777215)|0)<<16;k=fl[c[f>>2]&255](g+2&16777215)|0|i;m=k;n=c[291688]|0}k=m+a|0;c[291677]=k>>>24;c[291679]=((k^a)&(k^m))>>>24;i=((k^-8388608)&(m|a)|m&a)>>>23;c[291680]=i;c[291676]=i;c[291678]=k;if(h&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(j*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+d>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}n=g+2|0;g=n>>>16&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[d&511](n&16777215,k&65535);return}}function WO(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&65535;f=e-d|0;g=f>>>8;c[291677]=g;h=a-d&65535;c[291678]=h;c[291680]=g;c[291676]=g;c[291679]=((f^e)&(d^e))>>>8;c[b>>2]=h|c[b>>2]&-65536;return}function WP(){var a=0,b=0;a=c[291673]|0;b=1166604+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-1-((a>>>9)+7&7);return}function WQ(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(((c[291673]|0)>>>9)+7&7)+1|0;e=(c[291666]|0)-2|0;c[291666]=e;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h-b|0;c[291677]=g;i=g&255;c[291678]=i;c[291680]=g;c[291676]=g;c[291679]=(g^h)&(h^b);b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,i);return}}function WR(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291673]|0;f=((e>>>9)+7&7)+1|0;g=c[1166604+((e&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;h=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+g|0;g=h>>>16&255;e=c[1161468+(g*20|0)>>2]|0;if((e|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[e&255](h&16777215)|0}e=i-f|0;c[291677]=e;j=e&255;c[291678]=j;c[291680]=e;c[291676]=e;c[291679]=(e^i)&(i^f);f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]=e&255;return}else{fj[f&511](h&16777215,j);return}}function WS(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291673]|0;f=((b>>>9)+7&7)+1|0;g=c[1166604+((b&7|8)<<2)>>2]|0;b=c[291667]|0;c[291667]=b+2;h=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=b<<16>>16}else{i=b}b=(h<<24>>24)+g+i|0;i=b>>>16&255;g=c[1161468+(i*20|0)>>2]|0;if((g|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(b&65535^1)|0]|0}else{j=fl[g&255](b&16777215)|0}g=j-f|0;c[291677]=g;h=g&255;c[291678]=h;c[291680]=g;c[291676]=g;c[291679]=(g^j)&(j^f);f=c[1161476+(i*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[f&511](b&16777215,h);return}}function WT(){var e=0,f=0,g=0,h=0,i=0,j=0;e=(((c[291673]|0)>>>9)+7&7)+1|0;f=c[291667]|0;c[291667]=f+2;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g>>>16&255;h=c[1161468+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i-e|0;c[291677]=h;j=h&255;c[291678]=j;c[291680]=h;c[291676]=h;c[291679]=(h^i)&(i^e);e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,j);return}}function WU(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(((c[291673]|0)>>>9)+7&7)+1|0;f=c[291667]|0;c[291667]=f+4;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=f|g<<16;i=g&255;g=c[1161468+(i*20|0)>>2]|0;if((g|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(f^1)|0]|0}else{j=fl[g&255](h&16777215)|0}g=j-b|0;c[291677]=g;k=g&255;c[291678]=k;c[291680]=g;c[291676]=g;c[291679]=(g^j)&(j^b);b=c[1161476+(i*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(f^1)|0]=g&255;return}else{fj[b&511](h&16777215,k);return}}function WV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j-d|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^d))>>>8;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[k&511](f&16777215,l);return}}function WW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=1166604+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+2;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j-d|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^d))>>>8;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[k&511](a&16777215,l);return}}function WX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=1166604+((a&7|8)<<2)|0;a=(c[f>>2]|0)-2|0;c[f>>2]=a;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j-d|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^d))>>>8;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[k&511](a&16777215,l);return}}function WY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=(g&1|0)!=0;a=c[291688]|0;if(f&(a|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]|0;k=a}else{a=fl[i&255](g&16777215)|0;j=a;k=c[291688]|0}a=j-d|0;i=a>>>8;c[291677]=i;l=a&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((a^j)&(j^d))>>>8;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=a&65535;return}else{fj[k&511](g&16777215,l);return}}function WZ(){var a=0,b=0,d=0,e=0,f=0;a=c[291673]|0;b=1166604+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a-d|0;c[291677]=e>>>24;c[291678]=e;f=((e|d)&(a^-8388608)|e&d)>>>23;c[291680]=f;c[291676]=f;c[291679]=((e^a)&(d^a))>>>24;c[b>>2]=e;return}function W_(){var a=0,b=0;a=c[291673]|0;b=1166604+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-1-((a>>>9)+7&7);return}function W$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=(a&1|0)!=0;f=c[291688]|0;if(h&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;i=c[1161472+(g*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;k=f}else{f=fl[i&255](a&16777215)|0;j=f;k=c[291688]|0}f=j-d|0;i=f>>>8;c[291677]=i;l=f&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((f^j)&(j^d))>>>8;if(h&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(g*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535;return}else{fj[k&511](a&16777215,l);return}}function W0(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=(((c[291673]|0)>>>9)+7&7)+1|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(f&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j-a|0;i=g>>>8;c[291677]=i;l=g&65535;c[291678]=l;c[291680]=i;c[291676]=i;c[291679]=((g^j)&(j^a))>>>8;if(d&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[k&511](f&16777215,l);return}}function W1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=(((c[291673]|0)>>>9)+7&7)+1|0;d=c[291667]|0;c[291667]=d+4;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;h=(d&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=f&255;f=c[1161472+(j*20|0)>>2]|0;if((f|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+d>>1]|0;l=i}else{i=fl[f&255](g&16777215)|0;k=i;l=c[291688]|0}i=k-a|0;f=i>>>8;c[291677]=f;m=i&65535;c[291678]=m;c[291680]=f;c[291676]=f;c[291679]=((i^k)&(k^a))>>>8;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+d>>1]=i&65535;return}else{fj[l&511](g&16777215,m);return}}function W2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](f+2&16777215)|0|g;l=j;m=c[291688]|0}j=l-d|0;c[291677]=j>>>24;c[291678]=j;g=((j|d)&(l^-8388608)|j&d)>>>23;c[291680]=g;c[291676]=g;c[291679]=((j^l)&(l^d))>>>24;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;h=c[1161480+(f*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function W3(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=1166604+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+4;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|g;l=j;m=c[291688]|0}j=l-d|0;c[291677]=j>>>24;c[291678]=j;g=((j|d)&(l^-8388608)|j&d)>>>23;c[291680]=g;c[291676]=g;c[291679]=((j^l)&(l^d))>>>24;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function W4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=1166604+((a&7|8)<<2)|0;a=c[f>>2]|0;g=a-4|0;c[f>>2]=g;f=(g&1|0)!=0;h=c[291688]|0;if(f&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=g>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=a-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](g&16777215)|0)<<16;k=fl[c[j>>2]&255](a+16777214&16777215)|0|h;m=k;n=c[291688]|0}k=m-d|0;c[291677]=k>>>24;c[291678]=k;h=((k|d)&(m^-8388608)|k&d)>>>23;c[291680]=h;c[291676]=h;c[291679]=((k^m)&(m^d))>>>24;if(f&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}g=a-2|0;a=g>>>16&255;n=c[1161480+(a*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(g&65535)>>1]=k&65535;return}else{fj[n&511](g&16777215,k&65535);return}}function W5(){var a=0;a=1166604+((c[291673]&7)<<2)|0;c[a>>2]=c[a>>2]&-256;return}function W6(){var a=0,d=0,e=0,f=0;a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;c[291648]=0;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){f=(c[291649]|0)+14|0;c[291649]=f;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;f=(c[291649]|0)-14|0;c[291649]=f;return}}function W7(){var b=0,d=0,e=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=b>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;return}else{fj[e&511](b&16777215,0);return}}function W8(){var b=0,d=0,e=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=d>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=0;return}else{fj[e&511](d&16777215,0);return}}function W9(){var b=0,d=0,e=0;b=c[291666]|0;c[291666]=b+2;d=b>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;return}else{fj[e&511](b&16777215,0);return}}function Xa(){var b=0,d=0,e=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=d>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=0;return}else{fj[e&511](d&16777215,0);return}}function Xb(){var b=0,d=0,e=0;b=(c[291666]|0)-2|0;c[291666]=b;d=b>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;return}else{fj[e&511](b&16777215,0);return}}function Xc(){var d=0,e=0,f=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=f>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(f&65535^1)|0]=0;return}else{fj[e&511](f&16777215,0);return}}function Xd(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[1161476+(g*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(d&65535^1)|0]=0;return}else{fj[b&511](d&16777215,0);return}}function Xe(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=(g&1|0)!=0;a=c[291688]|0;if(f&(a|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=g+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]<<16;m=a}else{a=(fl[j&255](g&16777215)|0)<<16;j=fl[c[i>>2]&255](g+2&16777215)|0|a;l=j;m=c[291688]|0}j=l-d|0;c[291677]=j>>>24;c[291678]=j;a=((j|d)&(l^-8388608)|j&d)>>>23;c[291680]=a;c[291676]=a;c[291679]=((j^l)&(l^d))>>>24;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[m&511](g&16777215,j>>>16)}m=g+2|0;g=m>>>16&255;h=c[1161480+(g*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function Xf(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=((a>>>9)+7&7)+1|0;f=c[1166604+((a&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=(a&1|0)!=0;f=c[291688]|0;if(h&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;i=1161472+(g*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;m=f}else{f=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|f;l=j;m=c[291688]|0}j=l-d|0;c[291677]=j>>>24;c[291678]=j;f=((j|d)&(l^-8388608)|j&d)>>>23;c[291680]=f;c[291676]=f;c[291679]=((j^l)&(l^d))>>>24;if(h&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(g*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[g&511](m&16777215,j&65535);return}}function Xg(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=(((c[291673]|0)>>>9)+7&7)+1|0;d=c[291667]|0;c[291667]=d+2;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(f&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]<<16;m=g}else{g=(fl[j&255](f&16777215)|0)<<16;j=fl[c[i>>2]&255](f+2&16777215)|0|g;l=j;m=c[291688]|0}j=l-a|0;c[291677]=j>>>24;c[291678]=j;g=((j|a)&(l^-8388608)|j&a)>>>23;c[291680]=g;c[291676]=g;c[291679]=((j^l)&(l^a))>>>24;if(d&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[m&511](f&16777215,j>>>16)}m=f+2|0;f=m>>>16&255;h=c[1161480+(f*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(m&65535)>>1]=j&65535;return}else{fj[h&511](m&16777215,j&65535);return}}function Xh(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=(((c[291673]|0)>>>9)+7&7)+1|0;d=c[291667]|0;c[291667]=d+4;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;h=(d&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=f&255;f=1161472+(j*20|0)|0;k=c[f>>2]|0;if((k|0)==0){l=g+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+d>>1]|0)<<16;n=i}else{i=(fl[k&255](g&16777215)|0)<<16;k=fl[c[f>>2]&255](g+2&16777215)|0|i;m=k;n=c[291688]|0}k=m-a|0;c[291677]=k>>>24;c[291678]=k;i=((k|a)&(m^-8388608)|k&a)>>>23;c[291680]=i;c[291676]=i;c[291679]=((k^m)&(m^a))>>>24;if(h&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(j*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+d>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}n=g+2|0;g=n>>>16&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[d&511](n&16777215,k&65535);return}}function Xi(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if((c[291680]&256|0)==0&(c[291678]|0)!=0){c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}else{c[a>>2]=b&-256;return}}function Xj(){var a=0,d=0,e=0;if((c[291680]&256|0)==0&(c[291678]|0)!=0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function Xk(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if((c[291680]&256|0)==0&(c[291678]|0)!=0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}}function Xl(){var a=0,d=0,e=0;if(!((c[291680]&256|0)==0&(c[291678]|0)!=0)){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function Xm(){var d=0,e=0,f=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e>>>16&255;f=c[1161476+(d*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(e&65535^1)|0]=0;return}else{fj[f&511](e&16777215,0);return}}function Xn(){var b=0,d=0,f=0,g=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b^1)|0]=0;return}else{fj[g&511](b|d<<16&16711680,0);return}}function Xo(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if((c[291680]&256|0)==0){d=(c[291678]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Xp(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if((c[291680]&256|0)==0){e=(c[291678]|0)!=0?255:0}else{e=0}b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function Xq(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;if((c[291680]&256|0)==0){d=(c[291678]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Xr(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if((c[291680]&256|0)==0){e=(c[291678]|0)!=0?255:0}else{e=0}b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function Xs(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;if((c[291680]&256|0)==0){d=(c[291678]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Xt(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;if((c[291680]&256|0)==0){g=(c[291678]|0)!=0?255:0}else{g=0}d=f>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function Xu(){var b=0,d=0,f=0,g=0,h=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((c[291680]&256|0)==0){h=(c[291678]|0)!=0?255:0}else{h=0}g=d>>>16&255;b=c[1161476+(g*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(d&65535^1)|0]=h&255;return}else{fj[b&511](d&16777215,h);return}}function Xv(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((c[291680]&256|0)==0){f=(c[291678]|0)!=0?255:0}else{f=0}d=e>>>16&255;g=c[1161476+(d*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function Xw(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;if((c[291680]&256|0)==0){g=(c[291678]|0)!=0?255:0}else{g=0}f=d&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b^1)|0]=g&255;return}else{fj[h&511](b|d<<16&16711680,g);return}}function Xx(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if((c[291680]&256|0)==0){d=(c[291678]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Xy(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if((c[291680]&256|0)==0){e=(c[291678]|0)==0?255:0}else{e=255}b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function Xz(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;if((c[291680]&256|0)==0){d=(c[291678]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function XA(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if((c[291680]&256|0)==0){e=(c[291678]|0)==0?255:0}else{e=255}b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function XB(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;if((c[291680]&256|0)==0){d=(c[291678]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function XC(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;if((c[291680]&256|0)==0){g=(c[291678]|0)==0?255:0}else{g=255}d=f>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function XD(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if((c[291680]&256|0)==0){c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}else{c[a>>2]=b&-256;return}}function XE(){var a=0,d=0,e=0;if((c[291680]&256|0)==0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function XF(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if((c[291680]&256|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}}function XG(){var a=0,d=0,e=0;if((c[291680]&256|0)!=0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function XH(){var b=0,d=0,f=0,g=0,h=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((c[291680]&256|0)==0){h=(c[291678]|0)==0?255:0}else{h=255}g=d>>>16&255;b=c[1161476+(g*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(d&65535^1)|0]=h&255;return}else{fj[b&511](d&16777215,h);return}}function XI(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((c[291680]&256|0)==0){f=(c[291678]|0)==0?255:0}else{f=255}d=e>>>16&255;g=c[1161476+(d*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function XJ(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;if((c[291680]&256|0)==0){g=(c[291678]|0)==0?255:0}else{g=255}f=d&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b^1)|0]=g&255;return}else{fj[h&511](b|d<<16&16711680,g);return}}function XK(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(c[291680]&256|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function XL(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[291680]&256|0)==0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function XM(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;d=(c[291680]&256|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function XN(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[291680]&256|0)==0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function XO(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;d=(c[291680]&256|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function XP(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[291680]&256|0)==0?255:0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function XQ(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[291680]&256|0)==0?255:0;b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function XR(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[291680]&256|0)==0?255:0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function XS(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[291680]&256|0)==0?255:0;g=d&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function XT(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(c[291680]&256|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function XU(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[291680]&256|0)!=0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function XV(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;d=(c[291680]&256|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function XW(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[291680]&256|0)!=0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function XX(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;d=(c[291680]&256|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function XY(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[291680]&256|0)!=0?255:0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function XZ(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if((c[291678]|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}}function X_(){var a=0,d=0,e=0;if((c[291678]|0)!=0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function X$(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if((c[291678]|0)==0){c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}else{c[a>>2]=b&-256;return}}function X0(){var a=0,d=0,e=0;if((c[291678]|0)==0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function X1(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[291680]&256|0)!=0?255:0;b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function X2(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[291680]&256|0)!=0?255:0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function X3(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[291680]&256|0)!=0?255:0;g=d&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function X4(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(c[291678]|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function X5(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[291678]|0)!=0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function X6(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;d=(c[291678]|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function X7(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[291678]|0)!=0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function X8(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;d=(c[291678]|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function X9(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[291678]|0)!=0?255:0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function Ya(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[291678]|0)!=0?255:0;b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function Yb(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[291678]|0)!=0?255:0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function Yc(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[291678]|0)!=0?255:0;g=d&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function Yd(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(c[291678]|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Ye(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[291678]|0)==0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function Yf(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;d=(c[291678]|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Yg(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[291678]|0)==0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function Yh(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;d=(c[291678]|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Yi(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[291678]|0)==0?255:0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function Yj(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[291678]|0)==0?255:0;b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function Yk(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if((c[291679]&128|0)==0){c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}else{c[a>>2]=b&-256;return}}function Yl(){var a=0,d=0,e=0;if((c[291679]&128|0)==0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function Ym(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if((c[291679]&128|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}}function Yn(){var a=0,d=0,e=0;if((c[291679]&128|0)!=0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function Yo(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[291678]|0)==0?255:0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function Yp(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[291678]|0)==0?255:0;g=d&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function Yq(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(c[291679]&128|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Yr(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[291679]&128|0)==0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function Ys(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;d=(c[291679]&128|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Yt(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[291679]&128|0)==0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function Yu(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;d=(c[291679]&128|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Yv(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[291679]&128|0)==0?255:0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function Yw(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[291679]&128|0)==0?255:0;b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function Yx(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[291679]&128|0)==0?255:0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function Yy(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[291679]&128|0)==0?255:0;g=d&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function Yz(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(c[291679]&128|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function YA(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[291679]&128|0)!=0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function YB(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;d=(c[291679]&128|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function YC(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[291679]&128|0)!=0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function YD(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;d=(c[291679]&128|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function YE(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[291679]&128|0)!=0?255:0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function YF(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[291679]&128|0)!=0?255:0;b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function YG(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[291679]&128|0)!=0?255:0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function YH(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if((c[291677]&128|0)==0){c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}else{c[a>>2]=b&-256;return}}function YI(){var a=0,d=0,e=0;if((c[291677]&128|0)==0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function YJ(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if((c[291677]&128|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}}function YK(){var a=0,d=0,e=0;if((c[291677]&128|0)!=0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function YL(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[291679]&128|0)!=0?255:0;g=d&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function YM(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(c[291677]&128|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function YN(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[291677]&128|0)==0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function YO(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;d=(c[291677]&128|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function YP(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[291677]&128|0)==0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function YQ(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;d=(c[291677]&128|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function YR(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[291677]&128|0)==0?255:0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function YS(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[291677]&128|0)==0?255:0;b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function YT(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[291677]&128|0)==0?255:0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function YU(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[291677]&128|0)==0?255:0;g=d&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function YV(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(c[291677]&128|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function YW(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[291677]&128|0)!=0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function YX(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;d=(c[291677]&128|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function YY(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[291677]&128|0)!=0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function YZ(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;d=(c[291677]&128|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Y_(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[291677]&128|0)!=0?255:0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function Y$(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[291677]&128|0)!=0?255:0;b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function Y0(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[291677]&128|0)!=0?255:0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function Y1(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[291677]&128|0)!=0?255:0;g=d&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function Y2(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if(((c[291679]^c[291677])&128|0)==0){c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}else{c[a>>2]=b&-256;return}}function Y3(){var a=0,d=0,e=0;if(((c[291679]^c[291677])&128|0)==0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function Y4(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if(((c[291679]^c[291677])&128|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}}function Y5(){var a=0,d=0,e=0;if(((c[291679]^c[291677])&128|0)!=0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function Y6(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if(((c[291679]^c[291677])&128|0)==0&(c[291678]|0)!=0){c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}else{c[a>>2]=b&-256;return}}function Y7(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=((c[291679]^c[291677])&128|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Y8(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=((c[291679]^c[291677])&128|0)==0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function Y9(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;d=((c[291679]^c[291677])&128|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Za(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=((c[291679]^c[291677])&128|0)==0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function Zb(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;d=((c[291679]^c[291677])&128|0)==0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Zc(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=((c[291679]^c[291677])&128|0)==0?255:0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function Zd(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=((c[291679]^c[291677])&128|0)==0?255:0;b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function Ze(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=((c[291679]^c[291677])&128|0)==0?255:0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function Zf(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=((c[291679]^c[291677])&128|0)==0?255:0;g=d&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function Zg(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=((c[291679]^c[291677])&128|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Zh(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=((c[291679]^c[291677])&128|0)!=0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function Zi(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;d=((c[291679]^c[291677])&128|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Zj(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=((c[291679]^c[291677])&128|0)!=0?255:0;e=d>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function Zk(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;d=((c[291679]^c[291677])&128|0)!=0?255:0;e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Zl(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=((c[291679]^c[291677])&128|0)!=0?255:0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function Zm(){var b=0,d=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=((c[291679]^c[291677])&128|0)!=0?255:0;b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function Zn(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=((c[291679]^c[291677])&128|0)!=0?255:0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function Zo(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=((c[291679]^c[291677])&128|0)!=0?255:0;g=d&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function Zp(){var a=0,d=0,e=0;if(((c[291679]^c[291677])&128|0)==0&(c[291678]|0)!=0){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function Zq(){var a=0,b=0;a=1166604+((c[291673]&7)<<2)|0;b=c[a>>2]|0;if(((c[291679]^c[291677])&128|0)==0&(c[291678]|0)!=0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[291649]=(c[291649]|0)+14;return}}function Zr(){var a=0,d=0,e=0;if(!(((c[291679]^c[291677])&128|0)==0&(c[291678]|0)!=0)){c[291667]=(c[291667]|0)+2;return}a=1166604+((c[291673]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[291667]|0;c[291667]=d+2;if((e|0)==65535){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[291649]=(c[291649]|0)-14;return}}function Zs(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if(((c[291679]^c[291677])&128|0)==0){d=(c[291678]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Zt(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if(((c[291679]^c[291677])&128|0)==0){e=(c[291678]|0)!=0?255:0}else{e=0}b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function Zu(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;if(((c[291679]^c[291677])&128|0)==0){d=(c[291678]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Zv(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if(((c[291679]^c[291677])&128|0)==0){e=(c[291678]|0)!=0?255:0}else{e=0}b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function Zw(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;if(((c[291679]^c[291677])&128|0)==0){d=(c[291678]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function Zx(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;if(((c[291679]^c[291677])&128|0)==0){g=(c[291678]|0)!=0?255:0}else{g=0}d=f>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function Zy(){var b=0,d=0,f=0,g=0,h=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if(((c[291679]^c[291677])&128|0)==0){h=(c[291678]|0)!=0?255:0}else{h=0}g=d>>>16&255;b=c[1161476+(g*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(d&65535^1)|0]=h&255;return}else{fj[b&511](d&16777215,h);return}}function Zz(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if(((c[291679]^c[291677])&128|0)==0){f=(c[291678]|0)!=0?255:0}else{f=0}d=e>>>16&255;g=c[1161476+(d*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function ZA(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;if(((c[291679]^c[291677])&128|0)==0){g=(c[291678]|0)!=0?255:0}else{g=0}f=d&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b^1)|0]=g&255;return}else{fj[h&511](b|d<<16&16711680,g);return}}function ZB(){var b=0,d=0,e=0,f=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if(((c[291679]^c[291677])&128|0)==0){d=(c[291678]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ZC(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if(((c[291679]^c[291677])&128|0)==0){e=(c[291678]|0)==0?255:0}else{e=255}b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function ZD(){var b=0,d=0,e=0,f=0;b=c[291666]|0;c[291666]=b+2;if(((c[291679]^c[291677])&128|0)==0){d=(c[291678]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ZE(){var b=0,d=0,e=0,f=0;b=1166604+((c[291673]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if(((c[291679]^c[291677])&128|0)==0){e=(c[291678]|0)==0?255:0}else{e=255}b=d>>>16&255;f=c[1161476+(b*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function ZF(){var b=0,d=0,e=0,f=0;b=(c[291666]|0)-2|0;c[291666]=b;if(((c[291679]^c[291677])&128|0)==0){d=(c[291678]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function ZG(){var d=0,e=0,f=0,g=0;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;if(((c[291679]^c[291677])&128|0)==0){g=(c[291678]|0)==0?255:0}else{g=255}d=f>>>16&255;e=c[1161476+(d*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function ZH(){var b=0,d=0,f=0,g=0,h=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if(((c[291679]^c[291677])&128|0)==0){h=(c[291678]|0)==0?255:0}else{h=255}g=d>>>16&255;b=c[1161476+(g*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(d&65535^1)|0]=h&255;return}else{fj[b&511](d&16777215,h);return}}function ZI(){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}function ZJ(){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}function ZK(){if((c[291680]&256|0)==0&(c[291678]|0)!=0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function ZL(){if((c[291680]&256|0)==0&(c[291678]|0)!=0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function ZM(){if((c[291680]&256|0)==0&(c[291678]|0)!=0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function ZN(){if((c[291680]&256|0)==0&(c[291678]|0)!=0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function ZO(){if((c[291680]&256|0)==0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function ZP(){if((c[291680]&256|0)==0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function ZQ(){if((c[291680]&256|0)==0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function ZR(){if((c[291680]&256|0)==0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function ZS(){if((c[291678]|0)==0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function ZT(){if((c[291678]|0)==0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function ZU(){if((c[291678]|0)==0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function ZV(){if((c[291678]|0)==0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function ZW(){if((c[291679]&128|0)==0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function ZX(){if((c[291679]&128|0)==0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function ZY(){if((c[291679]&128|0)==0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function ZZ(){if((c[291679]&128|0)==0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function Z_(){if((c[291677]&128|0)==0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function Z$(){if((c[291677]&128|0)==0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function Z0(){var a=0;a=c[291667]|0;c[291667]=a+2;c[291667]=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a;return}function Z1(){var a=0,d=0,e=0;a=c[291667]|0;d=a+2|0;c[291667]=d;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(c[291666]|0)-4|0;c[291666]=a;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535;a=(c[291666]|0)+2|0;b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d&65535;c[291667]=(e<<16>>16)-2+(c[291667]|0);return}function Z2(){var a=0,d=0;a=c[291667]|0;d=(c[291666]|0)-4|0;c[291666]=d;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a>>>16&65535;d=(c[291666]|0)+2|0;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a&65535;c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}function Z3(){var a=0,d=0;a=c[291667]|0;d=(c[291666]|0)-4|0;c[291666]=d;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a>>>16&65535;d=(c[291666]|0)+2|0;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a&65535;c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}function Z4(){var a=0,d=0;a=(c[291680]&256|0)==0&(c[291678]|0)!=0;d=c[291667]|0;c[291667]=d+2;if(a){c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[291649]=(c[291649]|0)+14;return}}function Z5(){var a=0,d=0;a=(c[291680]&256|0)==0&(c[291678]|0)!=0;d=c[291667]|0;c[291667]=d+2;if(a){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function Z6(){var a=0,d=0;a=(c[291680]&256|0)==0;d=c[291667]|0;c[291667]=d+2;if(a){c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[291649]=(c[291649]|0)+14;return}}function Z7(){var a=0,d=0;a=(c[291680]&256|0)==0;d=c[291667]|0;c[291667]=d+2;if(a){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function Z8(){var a=0,d=0;a=(c[291678]|0)==0;d=c[291667]|0;c[291667]=d+2;if(a){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function Z9(){var a=0,d=0;a=(c[291678]|0)==0;d=c[291667]|0;c[291667]=d+2;if(a){c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[291649]=(c[291649]|0)+14;return}}function _a(){var a=0,d=0;a=(c[291679]&128|0)==0;d=c[291667]|0;c[291667]=d+2;if(a){c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[291649]=(c[291649]|0)+14;return}}function _b(){var a=0,d=0;a=(c[291679]&128|0)==0;d=c[291667]|0;c[291667]=d+2;if(a){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function _c(){var a=0,d=0;a=(c[291677]&128|0)==0;d=c[291667]|0;c[291667]=d+2;if(a){c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[291649]=(c[291649]|0)+14;return}}function _d(){var d=0,e=0,f=0,g=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if(((c[291679]^c[291677])&128|0)==0){f=(c[291678]|0)==0?255:0}else{f=255}d=e>>>16&255;g=c[1161476+(d*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function _e(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+4;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;if(((c[291679]^c[291677])&128|0)==0){g=(c[291678]|0)==0?255:0}else{g=255}f=d&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b^1)|0]=g&255;return}else{fj[h&511](b|d<<16&16711680,g);return}}function _f(){if((c[291677]&128|0)==0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function _g(){if((c[291677]&128|0)==0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function _h(){if(((c[291679]^c[291677])&128|0)==0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function _i(){if(((c[291679]^c[291677])&128|0)==0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function _j(){if(((c[291679]^c[291677])&128|0)==0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function _k(){if(((c[291679]^c[291677])&128|0)==0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function _l(){if(((c[291679]^c[291677])&128|0)==0&(c[291678]|0)!=0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function _m(){if(((c[291679]^c[291677])&128|0)==0&(c[291678]|0)!=0){c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}else{c[291649]=(c[291649]|0)-14;return}}function _n(){if(((c[291679]^c[291677])&128|0)==0&(c[291678]|0)!=0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function _o(){if(((c[291679]^c[291677])&128|0)==0&(c[291678]|0)!=0){c[291649]=(c[291649]|0)-14;return}else{c[291667]=(c[291673]<<24>>24)+(c[291667]|0);return}}function _p(){var a=0,d=0;a=(c[291677]&128|0)==0;d=c[291667]|0;c[291667]=d+2;if(a){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function _q(){var a=0,d=0;a=((c[291679]^c[291677])&128|0)==0;d=c[291667]|0;c[291667]=d+2;if(a){c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[291649]=(c[291649]|0)+14;return}}function _r(){var a=0,d=0;a=((c[291679]^c[291677])&128|0)==0;d=c[291667]|0;c[291667]=d+2;if(a){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function _s(){var a=0,d=0;a=((c[291679]^c[291677])&128|0)==0&(c[291678]|0)!=0;d=c[291667]|0;c[291667]=d+2;if(a){c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}else{c[291649]=(c[291649]|0)+14;return}}function _t(){var a=0,d=0;a=((c[291679]^c[291677])&128|0)==0&(c[291678]|0)!=0;d=c[291667]|0;c[291667]=d+2;if(a){c[291649]=(c[291649]|0)+14;return}else{c[291667]=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;return}}function _u(){var a=0,b=0;a=c[291673]|0;b=a<<24>>24;c[1166604+((a>>>9&7)<<2)>>2]=b;c[291677]=b>>>24;c[291678]=b;c[291679]=0;c[291680]=0;return}function _v(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[b>>2]|c[1166604+((a&7)<<2)>>2]&255;c[b>>2]=d;b=d&255;c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}function _w(){var a=0,e=0,f=0;a=c[291667]|0;c[291667]=a+2;e=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;f=c[a>>2]|d[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0];c[a>>2]=f;a=f&255;c[291677]=a;c[291678]=a;c[291680]=0;c[291679]=0;return}function _x(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0}a=1166604+((h>>>9&7)<<2)|0;h=c[a>>2]|g;c[a>>2]=h;a=h&255;c[291677]=a;c[291678]=a;c[291680]=0;c[291679]=0;return}function _y(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[b>>2]|f;c[b>>2]=e;b=e&255;c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}function _z(){var a=0,b=0,e=0,f=0;a=c[291666]|0;c[291666]=a+2;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[a>>2]|f;c[a>>2]=e;a=e&255;c[291677]=a;c[291678]=a;c[291680]=0;c[291679]=0;return}function _A(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[b>>2]|f;c[b>>2]=e;b=e&255;c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}function _B(){var a=0,b=0,e=0,f=0;a=(c[291666]|0)-2|0;c[291666]=a;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[a>>2]|f;c[a>>2]=e;a=e&255;c[291677]=a;c[291678]=a;c[291680]=0;c[291679]=0;return}function _C(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[291673]|0;e=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=1166604+((i>>>9&7)<<2)|0;i=c[a>>2]|h;c[a>>2]=i;a=i&255;c[291677]=a;c[291678]=a;c[291680]=0;c[291679]=0;return}function _D(){var a=0,b=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0;j=a}else{a=fl[b&255](f&16777215)|0;i=a;j=c[291673]|0}a=1166604+((j>>>9&7)<<2)|0;j=c[a>>2]|i;c[a>>2]=j;a=j&255;c[291677]=a;c[291678]=a;c[291680]=0;c[291679]=0;return}function _E(){var a=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[1161468+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7)<<2)|0;f=c[e>>2]|g;c[e>>2]=f;e=f&255;c[291677]=e;c[291678]=e;c[291680]=0;c[291679]=0;return}function _F(){var a=0,b=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a^1)|0]|0}else{h=fl[g&255](a|b<<16&16711680)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;a=c[b>>2]|h;c[b>>2]=a;b=a&255;c[291677]=b;c[291678]=b;c[291680]=0;c[291679]=0;return}function _G(){var a=0,b=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){g=f<<16>>16}else{g=f}f=(b<<24>>24)+a+g|0;g=1166604+(((c[291673]|0)>>>9&7)<<2)|0;a=c[g>>2]|(d[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0);c[g>>2]=a;g=a&255;c[291677]=g;c[291678]=g;c[291680]=0;c[291679]=0;return}function _H(){var a=0,d=0,e=0;a=c[291667]|0;c[291667]=a+2;d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;e=c[d>>2]|b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;c[d>>2]=e;d=e&255;c[291677]=d;c[291678]=d;c[291680]=0;c[291679]=0;return}function _I(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[b>>2]|c[1166604+((a&7)<<2)>>2]&65535;c[b>>2]=d;b=d&65535;c[291677]=b>>>8;c[291678]=b;c[291680]=0;c[291679]=0;return}function _J(){var a=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;f=c[a>>2]|e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1];c[a>>2]=f;a=f&65535;c[291677]=a>>>8;c[291678]=a;c[291680]=0;c[291679]=0;return}function _K(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=1166604+(((c[291673]|0)>>>9&7)<<2)|0;a=c[f>>2]|(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0);c[f>>2]=a;f=a&65535;c[291677]=f>>>8;c[291678]=f;c[291680]=0;c[291679]=0;return}function _L(){var a=0,b=0,d=0;a=c[291667]|0;c[291667]=a+2;b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0);c[b>>2]=d;b=d&65535;c[291677]=b>>>8;c[291678]=b;c[291680]=0;c[291679]=0;return}function _M(){var a=0,b=0,d=0;a=c[291673]|0;b=1166604+((a>>>9&7)<<2)|0;d=c[b>>2]|c[1166604+((a&7)<<2)>>2];c[b>>2]=d;c[291677]=d>>>24;c[291678]=d;c[291680]=0;c[291679]=0;return}function _N(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0}a=1166604+((h>>>9&7)<<2)|0;h=c[a>>2]|g;c[a>>2]=h;a=h&65535;c[291677]=a>>>8;c[291678]=a;c[291680]=0;c[291679]=0;return}function _O(){var a=0,b=0,d=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]|f;c[b>>2]=d;b=d&65535;c[291677]=b>>>8;c[291678]=b;c[291680]=0;c[291679]=0;return}function _P(){var a=0,b=0,d=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;d=c[b>>2]|f;c[b>>2]=d;b=d&65535;c[291677]=b>>>8;c[291678]=b;c[291680]=0;c[291679]=0;return}function _Q(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;if((g&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=1166604+((i>>>9&7)<<2)|0;i=c[a>>2]|h;c[a>>2]=i;a=i&65535;c[291677]=a>>>8;c[291678]=a;c[291680]=0;c[291679]=0;return}function _R(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=c[1161472+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a;j=i>>>9;k=j&7;l=1166604+(k<<2)|0;m=c[l>>2]|0;n=m|h;c[l>>2]=n;o=n&65535;p=o>>>8;c[291677]=p;c[291678]=o;c[291680]=0;c[291679]=0;return}else{a=fl[b&255](d&16777215)|0;h=a;i=c[291673]|0;j=i>>>9;k=j&7;l=1166604+(k<<2)|0;m=c[l>>2]|0;n=m|h;c[l>>2]=n;o=n&65535;p=o>>>8;c[291677]=p;c[291678]=o;c[291680]=0;c[291679]=0;return}}
function agE(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=j>>>1;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535;c[291677]=0;c[291678]=h;l=j<<8;c[291676]=l;c[291680]=l;c[291679]=0;return}else{fj[k&511](f&16777215,h);c[291677]=0;c[291678]=h;l=j<<8;c[291676]=l;c[291680]=l;c[291679]=0;return}}function agF(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=i<<1;h=f&65534;if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}else{fj[j&511](a&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}}function agG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i<<1;h=f&65534;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}}function agH(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i<<1;h=f&65534;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}}function agI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=i<<1;h=d&65534;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}else{fj[j&511](f&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}}function agJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=i<<1;h=a&65534;if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}}function agK(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i<<1;h=f&65534;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291676]=l;c[291679]=0;return}}function agL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=j<<1;d=h&65534;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535;l=d>>>8;c[291677]=l;c[291678]=d;m=j>>>7;c[291680]=m;c[291676]=m;c[291679]=0;return}else{fj[k&511](f&16777215,d);l=d>>>8;c[291677]=l;c[291678]=d;m=j>>>7;c[291680]=m;c[291676]=m;c[291679]=0;return}}function agM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=((c[291676]|0)>>>8<<16&65536|i)>>>1;h=(f|i<<16)>>>8;c[291676]=h;c[291680]=h;h=f&65535;if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}else{fj[j&511](a&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}}function agN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=((c[291676]|0)>>>8<<16&65536|i)>>>1;h=(f|i<<16)>>>8;c[291676]=h;c[291680]=h;h=f&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}}function agO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=((c[291676]|0)>>>8<<16&65536|i)>>>1;h=(f|i<<16)>>>8;c[291676]=h;c[291680]=h;h=f&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}}function agP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=((c[291676]|0)>>>8<<16&65536|i)>>>1;h=(d|i<<16)>>>8;c[291676]=h;c[291680]=h;h=d&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}else{fj[j&511](f&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}}function agQ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=((c[291676]|0)>>>8<<16&65536|i)>>>1;h=(a|i<<16)>>>8;c[291676]=h;c[291680]=h;h=a&65535;if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}}function agR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=((c[291676]|0)>>>8<<16&65536|i)>>>1;h=(f|i<<16)>>>8;c[291676]=h;c[291680]=h;h=f&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;c[291679]=0;return}}function agS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=((c[291676]|0)>>>8<<16&65536|j)>>>1;d=(h|j<<16)>>>8;c[291676]=d;c[291680]=d;d=h&65535;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535;l=d>>>8;c[291677]=l;c[291678]=d;c[291679]=0;return}else{fj[k&511](f&16777215,d);l=d>>>8;c[291677]=l;c[291678]=d;c[291679]=0;return}}function agT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=(c[291676]|0)>>>8<<16&65536|i;i=f<<1|f>>>16;f=i>>>8;c[291676]=f;c[291680]=f;f=i&65535;if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=i&65535;k=f>>>8;c[291677]=k;c[291678]=f;c[291679]=0;return}else{fj[j&511](a&16777215,f);k=f>>>8;c[291677]=k;c[291678]=f;c[291679]=0;return}}function agU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=(c[291676]|0)>>>8<<16&65536|i;i=f<<1|f>>>16;f=i>>>8;c[291676]=f;c[291680]=f;f=i&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=i&65535;k=f>>>8;c[291677]=k;c[291678]=f;c[291679]=0;return}else{fj[j&511](d&16777215,f);k=f>>>8;c[291677]=k;c[291678]=f;c[291679]=0;return}}function agV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=(c[291676]|0)>>>8<<16&65536|i;i=f<<1|f>>>16;f=i>>>8;c[291676]=f;c[291680]=f;f=i&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=i&65535;k=f>>>8;c[291677]=k;c[291678]=f;c[291679]=0;return}else{fj[j&511](d&16777215,f);k=f>>>8;c[291677]=k;c[291678]=f;c[291679]=0;return}}function agW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=(c[291676]|0)>>>8<<16&65536|i;i=d<<1|d>>>16;d=i>>>8;c[291676]=d;c[291680]=d;d=i&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=i&65535;k=d>>>8;c[291677]=k;c[291678]=d;c[291679]=0;return}else{fj[j&511](f&16777215,d);k=d>>>8;c[291677]=k;c[291678]=d;c[291679]=0;return}}function agX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=(c[291676]|0)>>>8<<16&65536|i;i=a<<1|a>>>16;a=i>>>8;c[291676]=a;c[291680]=a;a=i&65535;if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=i&65535;k=a>>>8;c[291677]=k;c[291678]=a;c[291679]=0;return}else{fj[j&511](d&16777215,a);k=a>>>8;c[291677]=k;c[291678]=a;c[291679]=0;return}}function agY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=(c[291676]|0)>>>8<<16&65536|i;i=f<<1|f>>>16;f=i>>>8;c[291676]=f;c[291680]=f;f=i&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=i&65535;k=f>>>8;c[291677]=k;c[291678]=f;c[291679]=0;return}else{fj[j&511](d&16777215,f);k=f>>>8;c[291677]=k;c[291678]=f;c[291679]=0;return}}function agZ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=(c[291676]|0)>>>8<<16&65536|j;j=h<<1|h>>>16;h=j>>>8;c[291676]=h;c[291680]=h;h=j&65535;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=j&65535;l=h>>>8;c[291677]=l;c[291678]=h;c[291679]=0;return}else{fj[k&511](f&16777215,h);l=h>>>8;c[291677]=l;c[291678]=h;c[291679]=0;return}}function ag_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=i>>>1|i<<15;h=f&65535;if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}else{fj[j&511](a&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}}function ag$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i>>>1|i<<15;h=f&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}}function ag0(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i>>>1|i<<15;h=f&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}}function ag1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=i>>>1|i<<15;h=d&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}else{fj[j&511](f&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}}function ag2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=i>>>1|i<<15;h=a&65535;if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}}function ag3(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i>>>1|i<<15;h=f&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i<<8;c[291680]=l;c[291679]=0;return}}function ag4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=j>>>1|j<<15;d=h&65535;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535;l=d>>>8;c[291677]=l;c[291678]=d;m=j<<8;c[291680]=m;c[291679]=0;return}else{fj[k&511](f&16777215,d);l=d>>>8;c[291677]=l;c[291678]=d;m=j<<8;c[291680]=m;c[291679]=0;return}}function ag5(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;j=f}else{f=fl[h&255](a&16777215)|0;i=f;j=c[291688]|0}f=i<<1|i>>>15;h=f&65535;if(d&(j|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}else{fj[j&511](a&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}}function ag6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i<<1|i>>>15;h=f&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}}function ag7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i<<1|i>>>15;h=f&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}}function ag8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(f&1|0)!=0;d=c[291688]|0;if(a&(d|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d}else{d=fl[h&255](f&16777215)|0;i=d;j=c[291688]|0}d=i<<1|i>>>15;h=d&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=d&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}else{fj[j&511](f&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}}function ag9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(d&1|0)!=0;a=c[291688]|0;if(g&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;j=a}else{a=fl[h&255](d&16777215)|0;i=a;j=c[291688]|0}a=i<<1|i>>>15;h=a&65535;if(g&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(f*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}}function aha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a>>31&7;e=(a|0)>-1;f=e?a:-a|0;a=b<<16>>16;g=b<<16>>16>-1;b=g?a:-a|0;if((f>>16|0)>=(b|0)){h=d|56;i=h<<1;j=c[291649]|0;k=j+i|0;c[291649]=k;return}a=(f|0)/(b|0)|0;b=d+427|0;do{if(g){if(e){l=d+420|0;break}else{l=d+434|0;break}}else{l=b}}while(0);b=(a&2|0)==0?l+7|0:l;l=(a&4|0)==0?b+7|0:b;b=(a&8|0)==0?l+7|0:l;l=(a&16|0)==0?b+7|0:b;b=(a&32|0)==0?l+7|0:l;l=(a&64|0)==0?b+7|0:b;b=(a&128|0)==0?l+7|0:l;l=(a&256|0)==0?b+7|0:b;b=(a&512|0)==0?l+7|0:l;l=(a&1024|0)==0?b+7|0:b;b=(a&2048|0)==0?l+7|0:l;l=(a&4096|0)==0?b+7|0:b;b=(a&8192|0)==0?l+7|0:l;l=(a&16384|0)==0?b+7|0:b;h=(a&32768|0)==0?l+7|0:l;i=h<<1;j=c[291649]|0;k=j+i|0;c[291649]=k;return}function ahb(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[291675]|0;f=d<<11|c[291674]|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;c[291674]=0;c[1166672+(d<<2)>>2]=c[291666];c[291675]=4;d=(c[291667]|0)-2|0;g=(c[291672]|0)-4|0;c[291666]=g;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[291666]|0)+2|0;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;d=(c[291666]|0)-2|0;c[291666]=d;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;f=c[290368]|0;if((f|0)==0){d=c[290366]|0;h=e[d+46>>1]|0|(e[d+44>>1]|0)<<16;c[291667]=h;i=c[291673]|0;j=602824+i|0;k=a[j]|0;l=k&255;m=28-l|0;n=c[291649]|0;o=m+n|0;c[291649]=o;return}else{d=(fl[f&255](44)|0)<<16;h=fl[c[290368]&255](46)|0|d;c[291667]=h;i=c[291673]|0;j=602824+i|0;k=a[j]|0;l=k&255;m=28-l|0;n=c[291649]|0;o=m+n|0;c[291649]=o;return}}function ahc(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[291675]|0;f=d<<11|c[291674]|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;c[291674]=0;c[1166672+(d<<2)>>2]=c[291666];c[291675]=4;d=c[291667]|0;g=(c[291672]|0)-4|0;c[291666]=g;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[291666]|0)+2|0;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;d=(c[291666]|0)-2|0;c[291666]=d;b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;f=a<<2;d=a>>>14&255;g=1161472+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=c[1161464+(d*20|0)>>2]|0;d=f&65532;j=e[i+(d|2)>>1]|0|(e[i+d>>1]|0)<<16;c[291667]=j;k=536776+(a<<1)|0;l=b[k>>1]|0;m=l&65535;n=c[291649]|0;o=n+m|0;c[291649]=o;return}else{d=f&16777212;f=(fl[h&255](d)|0)<<16;j=fl[c[g>>2]&255](d|2)|0|f;c[291667]=j;k=536776+(a<<1)|0;l=b[k>>1]|0;m=l&65535;n=c[291649]|0;o=n+m|0;c[291649]=o;return}}function ahd(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[291675]|0;f=d<<11|c[291674]|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;c[291674]=0;c[1166672+(d<<2)>>2]=c[291666];c[291675]=4;d=c[291672]|0;c[291686]=8;g=(c[291667]|0)-2|0;h=d-4|0;c[291666]=h;b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]=g>>>16&65535;h=(c[291666]|0)+2|0;b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]=g&65535;g=(c[291666]|0)-2|0;c[291666]=g;b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=f&65535;f=c[290368]|0;if((f|0)==0){g=c[290366]|0;i=e[g+34>>1]|0|(e[g+32>>1]|0)<<16;c[291667]=i;j=c[291673]|0;k=602824+j|0;l=a[k]|0;m=l&255;n=238-m|0;o=c[291649]|0;p=n+o|0;c[291649]=p;return}else{g=(fl[f&255](32)|0)<<16;i=fl[c[290368]&255](34)|0|g;c[291667]=i;j=c[291673]|0;k=602824+j|0;l=a[k]|0;m=l&255;n=238-m|0;o=c[291649]|0;p=n+o|0;c[291649]=p;return}}function ahe(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(d&1|0)!=0;f=c[291688]|0;if(a&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291688]|0}f=i<<1|i>>>15;h=f&65535;if(a&(j|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=c[1161480+(g*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}else{fj[j&511](d&16777215,h);k=h>>>8;c[291677]=k;c[291678]=h;l=i>>>7;c[291680]=l;c[291679]=0;return}}function ahf(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=(a&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=d&255;d=c[1161472+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=h}else{h=fl[d&255](f&16777215)|0;j=h;k=c[291688]|0}h=j<<1|j>>>15;d=h&65535;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+a>>1]=h&65535;l=d>>>8;c[291677]=l;c[291678]=d;m=j>>>7;c[291680]=m;c[291679]=0;return}else{fj[k&511](f&16777215,d);l=d>>>8;c[291677]=l;c[291678]=d;m=j>>>7;c[291680]=m;c[291679]=0;return}}function ahg(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1);return 0}f=b&255;b=1161472+(f*20|0)|0;g=c[b>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+a>>1]|0)<<16;return i|0}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[b>>2]&255](d+2&16777215)|0|a;return i|0}return 0}function ahh(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1);return 0}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]<<16;return i|0}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a;return i|0}return 0}function ahi(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=a;eJ(1166756,1);return 0}a=f>>>16&255;d=1161472+(a*20|0)|0;g=c[d>>2]|0;if((g|0)==0){h=f+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]<<16;return i|0}else{a=(fl[g&255](f&16777215)|0)<<16;i=fl[c[d>>2]&255](f+2&16777215)|0|a;return i|0}return 0}function ahj(){var a=0,d=0,e=0;a=c[240581]|0;c[240581]=a+2;d=962260+((c[240587]&7)<<2)|0;e=c[d>>2]|b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;c[d>>2]=e;d=e&255;c[240591]=d;c[240592]=d;c[240594]=0;c[240593]=0;return}function ahk(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[240596]|0;g=c[240595]|0;if(f>>>0<=g>>>0){return}h=f>>>8;f=c[240597]&2;c[240597]=f;if((f|0)!=0){return}f=h+24|0;i=c[240589]|0;j=c[240588]|g|i<<11|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;c[240588]=0;c[962328+(i<<2)>>2]=c[240580];c[240589]=4;c[240580]=c[240586];c[240595]=h<<8;i=(d[11630188]|0)&(1<<h^255)&255;a[11630188]=i;if((h|0)==2){a[11629665]=a[11629665]&-2}c[240596]=(d[670008+((a[11629714]&i&255)>>>1)|0]|0)<<8;i=f<<2;h=f>>>14&255;g=957128+(h*20|0)|0;k=c[g>>2]|0;if((k|0)==0){l=c[957120+(h*20|0)>>2]|0;h=i&65532;m=e[l+(h|2)>>1]|0|(e[l+h>>1]|0)<<16}else{h=i&16777212;i=(fl[k&255](h)|0)<<16;m=fl[c[g>>2]&255](h|2)|0|i}do{if((m|0)==0){i=c[239282]|0;if((i|0)==0){h=c[239280]|0;n=e[h+62>>1]|0|(e[h+60>>1]|0)<<16;break}else{h=(fl[i&255](60)|0)<<16;n=fl[c[239282]&255](62)|0|h;break}}else{n=m}}while(0);m=c[240581]|0;h=(c[240580]|0)-4|0;c[240580]=h;b[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]=m>>>16&65535;h=(c[240580]|0)+2|0;b[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]=m&65535;m=(c[240580]|0)-2|0;c[240580]=m;b[(c[957120+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]=j&65535;c[240581]=n;c[240563]=(c[240563]|0)+(e[536264+(f<<1)>>1]|0);return}function ahl(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[240589]|0;f=d<<11|c[240588]|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;c[240588]=0;c[962328+(d<<2)>>2]=c[240580];c[240589]=4;d=(c[240581]|0)-2|0;g=(c[240586]|0)-4|0;c[240580]=g;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[240580]|0)+2|0;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;d=(c[240580]|0)-2|0;c[240580]=d;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;f=c[239282]|0;if((f|0)==0){d=c[239280]|0;h=e[d+18>>1]|0|(e[d+16>>1]|0)<<16;c[240581]=h;i=c[240587]|0;j=537288+i|0;k=a[j]|0;l=k&255;m=136-l|0;n=c[240563]|0;o=m+n|0;c[240563]=o;return}else{d=(fl[f&255](16)|0)<<16;h=fl[c[239282]&255](18)|0|d;c[240581]=h;i=c[240587]|0;j=537288+i|0;k=a[j]|0;l=k&255;m=136-l|0;n=c[240563]|0;o=m+n|0;c[240563]=o;return}}function ahm(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=b>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]|0}else{i=fl[h&255](b&16777215)|0}h=i|f;f=h&255;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]=h&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[i&511](b&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function ahn(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=962260+((c[240587]&7|8)<<2)|0;g=c[b>>2]|0;c[b>>2]=g+1;b=g>>>16&255;h=c[957124+(b*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i|f;f=h&255;i=c[957132+(b*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]=h&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[i&511](g&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function aho(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[240580]|0;c[240580]=b+2;g=b>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]|0}else{i=fl[h&255](b&16777215)|0}h=i|f;f=h&255;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]=h&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[i&511](b&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function ahp(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=962260+((c[240587]&7|8)<<2)|0;g=(c[b>>2]|0)-1|0;c[b>>2]=g;b=g>>>16&255;h=c[957124+(b*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i|f;f=h&255;i=c[957132+(b*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(g&65535^1)|0]=h&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[i&511](g&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function ahq(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=(c[240580]|0)-2|0;c[240580]=b;g=b>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]|0}else{i=fl[h&255](b&16777215)|0}h=i|f;f=h&255;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]=h&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[i&511](b&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function ahr(){var f=0,g=0,h=0,i=0,j=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;i=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=f+4;f=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+i|0;i=f>>>16&255;g=c[957124+(i*20|0)>>2]|0;if((g|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(f&65535^1)|0]|0}else{j=fl[g&255](f&16777215)|0}g=j|h;h=g&255;j=c[957132+(i*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(f&65535^1)|0]=g&255;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[j&511](f&16777215,h);c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}}function ahs(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;f=b+2|0;c[240581]=f;g=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;h=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=b+4;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){i=f<<16>>16}else{i=f}f=(b<<24>>24)+h+i|0;i=f>>>16&255;h=c[957124+(i*20|0)>>2]|0;if((h|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(f&65535^1)|0]|0}else{j=fl[h&255](f&16777215)|0}h=j|g;g=h&255;j=c[957132+(i*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(f&65535^1)|0]=h&255;c[240591]=g;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[j&511](f&16777215,g);c[240591]=g;c[240592]=g;c[240594]=0;c[240593]=0;return}}function aht(){var f=0,g=0,h=0,i=0,j=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240581]=f+4;f=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f>>>16&255;i=c[957124+(g*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{j=fl[i&255](f&16777215)|0}i=j|h;h=i&255;j=c[957132+(g*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=i&255;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[j&511](f&16777215,h);c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}}function ahu(){var a=0,b=0,d=0;a=(c[240591]|0)>>>4&8|(c[240590]|0)>>>4&16|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;b=c[240581]|0;c[240581]=b+2;d=a|(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0);b=d<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=d>>>2&1^1;c[240593]=d<<6&128;c[240594]=d<<8&256;return}function ahv(){var a=0,b=0,d=0;a=c[240581]|0;c[240581]=a+2;b=962260+((c[240587]&7)<<2)|0;d=c[b>>2]|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0);c[b>>2]=d;b=d&65535;c[240591]=b>>>8;c[240592]=b;c[240594]=0;c[240593]=0;return}function ahw(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+4;b=a+2|0;d=962260+((c[240587]&7)<<2)|0;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16|c[d>>2];c[d>>2]=f;c[240591]=f>>>24;c[240592]=f;c[240594]=0;c[240593]=0;return}function ahx(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;f=b+2|0;c[240581]=f;g=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;c[240581]=b+6;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b+4|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|h<<16;i=h&255;h=c[957124+(i*20|0)>>2]|0;if((h|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(b^1)|0]|0}else{j=fl[h&255](f&16777215)|0}h=j|g;g=h&255;j=c[957132+(i*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(b^1)|0]=h&255;c[240591]=g;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[j&511](f&16777215,g);c[240591]=g;c[240592]=g;c[240594]=0;c[240593]=0;return}}function ahy(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=a>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h&65535|d;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=g&65535;i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[d&511](a&16777215,g);i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}}function ahz(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+2;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h&65535|d;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[d&511](f&16777215,g);i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}}function ahA(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;f=(c[a>>2]|0)-2|0;c[a>>2]=f;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h&65535|d;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[d&511](f&16777215,g);i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}}function ahB(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}d=h&65535|f;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=d&65535;i=d>>>8;c[240591]=i;c[240592]=d;c[240594]=0;c[240593]=0;return}else{fj[f&511](a&16777215,d);i=d>>>8;c[240591]=i;c[240592]=d;c[240594]=0;c[240593]=0;return}}function ahC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+g+h|0;h=d>>>16&255;g=c[957128+(h*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0}else{i=fl[g&255](d&16777215)|0}g=i&65535|f;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[f&511](d&16777215,g);j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}}function ahD(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h&65535|f;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=g&65535;i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[f&511](a&16777215,g);i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}}function ahE(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+6;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;h=g&255;g=c[957128+(h*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0}else{i=fl[g&255](d&16777215)|0}g=i&65535|f;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=g&65535;j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[f&511](d&16777215,g);j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}}function ahF(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240589]|0;if((a|0)==0){aH4();return}else{b=c[240581]|0;c[240581]=b+2;d=c[240588]|a<<11|(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)|c[240595];b=(c[240590]|0)>>>4&16|d|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2;f=b|(c[240593]|0)>>>6&2;g=f|(c[240594]|0)>>>8&1;c[240588]=d&32768;c[240595]=d&1792;h=g<<4;c[240590]=h&256;c[240591]=h&128;c[240592]=b>>>2&1^1;c[240593]=f<<6&128;c[240594]=g<<8&256;g=d>>>11&4;c[962328+(a<<2)>>2]=c[240580];c[240589]=g;c[240580]=c[962328+(g<<2)>>2];ahk();return}}function ahG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=a+2|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[g>>2]&255](a+2&16777215)|0|i}i=f|j;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[j&511](a&16777215,i>>>16)}j=a+2|0;a=j>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(j&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[d&511](j&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function ahH(){var a=0;a=c[240587]|0;c[240592]=1<<(c[962260+((a>>>9&7)<<2)>>2]&31)&c[962260+((a&7)<<2)>>2];return}function ahI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=a+2|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=f|j;j=c[957136+(a*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[j&511](d&16777215,i>>>16)}j=d+2|0;d=j>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(j&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[a&511](j&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function ahJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;c[240581]=a+4;d=a+2|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;a=g>>>16&255;h=957128+(a*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{j=(fl[i&255](g&16777215)|0)<<16;k=fl[c[h>>2]&255](d+16777214&16777215)|0|j}j=f|k;k=c[957136+(a*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[k&511](g&16777215,j>>>16)}g=d-2|0;d=g>>>16&255;k=c[957136+(d*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=j&65535;l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}else{fj[k&511](g&16777215,j&65535);l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}}function ahK(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+f|0;f=a>>>16&255;d=957128+(f*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[d>>2]&255](a+2&16777215)|0|i}i=g|j;j=c[957136+(f*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[j&511](a&16777215,i>>>16)}j=a+2|0;a=j>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(j&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[f&511](j&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function ahL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+f+h|0;h=d>>>16&255;f=957128+(h*20|0)|0;a=c[f>>2]|0;if((a|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[a&255](d&16777215)|0)<<16;j=fl[c[f>>2]&255](d+2&16777215)|0|i}i=g|j;j=c[957136+(h*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[j&511](d&16777215,i>>>16)}j=d+2|0;d=j>>>16&255;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(j&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[h&511](j&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function ahM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;c[240581]=a+6;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[f>>2]&255](a+2&16777215)|0|i}i=g|j;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[j&511](a&16777215,i>>>16)}j=a+2|0;a=j>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(j&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[d&511](j&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function ahN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;c[240581]=a+8;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|f<<16;h=f&255;f=957128+(h*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16}else{j=(fl[i&255](d&16777215)|0)<<16;k=fl[c[f>>2]&255](d+2&16777215)|0|j}j=g|k;k=c[957136+(h*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[k&511](d&16777215,j>>>16)}k=d+2|0;d=k>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(k&65535)>>1]=j&65535;l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}else{fj[a&511](k&16777215,j&65535);l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}}function ahO(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;e=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=962260+((a>>>9&7)<<2)|0;a=c[e>>2]&-65536;f=g>>>16&255;h=c[957124+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i<<8;i=g+2|0;g=i>>>16&255;f=c[957124+(g*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(g*20|0)>>2]|0)+(i&65535^1)|0]|0;k=j+h|0;l=k|a;c[e>>2]=l;return}else{j=fl[f&255](i&16777215)|0;k=j+h|0;l=k|a;c[e>>2]=l;return}}function ahP(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}c[240592]=1<<(c[962260+((h>>>9&7)<<2)>>2]&7)&g;return}function ahQ(){var a=0,e=0;a=c[240581]|0;c[240581]=a+2;e=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;c[240592]=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7)&d[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0];return}function ahR(){var a=0,b=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){g=f<<16>>16}else{g=f}f=(b<<24>>24)+a+g|0;c[240592]=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7)&(d[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0);return}function ahS(){var a=0;a=c[240581]|0;c[240581]=a+2;c[240592]=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255&1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);return}function ahT(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=1<<(c[962260+((a>>>9&7)<<2)>>2]&31);c[240592]=d&c[b>>2];c[b>>2]=c[b>>2]^d;return}function ahU(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}c[240592]=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7)&f;return}function ahV(){var a=0,b=0,e=0,f=0;a=c[240580]|0;c[240580]=a+2;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[240592]=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7)&f;return}function ahW(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}c[240592]=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7)&f;return}function ahX(){var a=0,b=0,e=0,f=0;a=(c[240580]|0)-2|0;c[240580]=a;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[240592]=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7)&f;return}function ahY(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[240587]|0;e=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;i=a;j=i>>>9;k=j&7;l=962260+(k<<2)|0;m=c[l>>2]|0;n=m&7;o=1<<n;p=o&h;c[240592]=p;return}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0;j=i>>>9;k=j&7;l=962260+(k<<2)|0;m=c[l>>2]|0;n=m&7;o=1<<n;p=o&h;c[240592]=p;return}}function ahZ(){var a=0,b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0;j=a;k=j>>>9;l=k&7;m=962260+(l<<2)|0;n=c[m>>2]|0;o=n&7;p=1<<o;q=p&i;c[240592]=q;return}else{a=fl[b&255](f&16777215)|0;i=a;j=c[240587]|0;k=j>>>9;l=k&7;m=962260+(l<<2)|0;n=c[m>>2]|0;o=n&7;p=1<<o;q=p&i;c[240592]=q;return}}function ah_(){var a=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[957124+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}c[240592]=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7)&g;return}function ah$(){var a=0,b=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a^1)|0]|0}else{h=fl[g&255](a|b<<16&16711680)|0}c[240592]=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7)&h;return}function ah0(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+a|0;a=f>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(f&65535^1)|0]|0}else{g=fl[e&255](f&16777215)|0}e=f+2|0;a=e>>>16&255;h=c[957124+(a*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}e=f+4|0;h=e>>>16&255;a=c[957124+(h*20|0)>>2]|0;if((a|0)==0){j=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{j=fl[a&255](e&16777215)|0}e=(i<<16)+(g<<24)+(j<<8)|0;j=f+6|0;f=j>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){k=d[(c[957120+(f*20|0)>>2]|0)+(j&65535^1)|0]|0;l=e+k|0;m=c[240587]|0;n=m>>>9;o=n&7;p=962260+(o<<2)|0;c[p>>2]=l;return}else{k=fl[g&255](j&16777215)|0;l=e+k|0;m=c[240587]|0;n=m>>>9;o=n&7;p=962260+(o<<2)|0;c[p>>2]=l;return}}function ah1(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[240587]|0}b=1<<(c[962260+((i>>>9&7)<<2)>>2]&7);c[240592]=b&h;i=b^h;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=i&255;return}else{fj[h&511](e&16777215,i);return}}function ah2(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=f^g;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function ah3(){var b=0,e=0,f=0,g=0,h=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=f^g;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[g&511](b&16777215,h);return}}function ah4(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=f^g;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function ah5(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=f^g;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[g&511](b&16777215,h);return}}function ah6(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=1<<(c[962260+((a>>>9&7)<<2)>>2]&31);c[240592]=d&c[b>>2];c[b>>2]=c[b>>2]&~d;return}function ah7(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[240587]|0}e=1<<(c[962260+((j>>>9&7)<<2)>>2]&7);c[240592]=e&i;j=e^i;i=c[957132+(f*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]=j&255;return}else{fj[i&511](h&16777215,j);return}}function ah8(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[957124+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[240587]|0}b=1<<(c[962260+((k>>>9&7)<<2)>>2]&7);c[240592]=b&j;k=b^j;j=c[957132+(i*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]=k&255;return}else{fj[j&511](g&16777215,k);return}}function ah9(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=g&h;i=g^h;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function aia(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&i;j=f^i;i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]=j&255;return}else{fj[i&511](g&16777215,j);return}}function aib(){var d=0,e=0,f=0,g=0,h=0;d=c[240587]|0;e=c[962260+((d&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=c[962260+((d>>>9&7)<<2)>>2]|0;d=e>>>8;f=g>>>16&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=d&255}else{fj[h&511](g&16777215,d&255)}d=g+2|0;g=d>>>16&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[h&511](d&16777215,e&255);return}}function aic(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[240587]|0}b=1<<(c[962260+((i>>>9&7)<<2)>>2]&7);c[240592]=b&h;i=h&~b;b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=i&255;return}else{fj[b&511](e&16777215,i);return}}function aid(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=g&~f;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function aie(){var b=0,e=0,f=0,g=0,h=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=g&~f;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[f&511](b&16777215,h);return}}function aif(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=g&~f;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function aig(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=g&~f;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[f&511](b&16777215,h);return}}function aih(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[240587]|0}e=1<<(c[962260+((j>>>9&7)<<2)>>2]&7);c[240592]=e&i;j=i&~e;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]=j&255;return}else{fj[e&511](h&16777215,j);return}}function aii(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[957124+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[240587]|0}b=1<<(c[962260+((k>>>9&7)<<2)>>2]&7);c[240592]=b&j;k=j&~b;b=c[957132+(i*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]=k&255;return}else{fj[b&511](g&16777215,k);return}}function aij(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=g&h;i=h&~g;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[g&511](f&16777215,i);return}}function aik(){var a=0,b=0,d=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=1<<(c[962260+((a>>>9&7)<<2)>>2]&31);c[240592]=d&c[b>>2];c[b>>2]=c[b>>2]|d;return}function ail(){var a=0,b=0,d=0;a=c[240581]|0;c[240581]=a+2;b=962260+((c[240587]&7)<<2)|0;d=c[b>>2]&(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|-256);c[b>>2]=d;b=d&255;c[240592]=b;c[240591]=b;c[240594]=0;c[240593]=0;return}function aim(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&i;j=i&~f;f=c[957132+(h*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]=j&255;return}else{fj[f&511](g&16777215,j);return}}function ain(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[240587]|0;e=c[962260+((d&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=c[962260+((d>>>9&7)<<2)>>2]|0;d=e>>>24;f=g>>>16&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=d&255}else{fj[h&511](g&16777215,d)}d=g+2|0;h=e>>>16;f=d>>>16&255;i=c[957132+(f*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(d&65535^1)|0]=h&255}else{fj[i&511](d&16777215,h&255)}h=g+4|0;d=e>>>8;i=h>>>16&255;f=c[957132+(i*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(h&65535^1)|0]=d&255}else{fj[f&511](h&16777215,d&255)}d=g+6|0;g=d>>>16&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[h&511](d&16777215,e&255);return}}function aio(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[240587]|0}b=1<<(c[962260+((i>>>9&7)<<2)>>2]&7);c[240592]=b&h;i=b|h;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=i&255;return}else{fj[h&511](e&16777215,i);return}}function aip(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=f|g;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function aiq(){var b=0,e=0,f=0,g=0,h=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=f|g;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[g&511](b&16777215,h);return}}function air(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=f|g;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function ais(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&g;h=f|g;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[g&511](b&16777215,h);return}}function ait(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[240587]|0}e=1<<(c[962260+((j>>>9&7)<<2)>>2]&7);c[240592]=e&i;j=e|i;i=c[957132+(f*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]=j&255;return}else{fj[i&511](h&16777215,j);return}}function aiu(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[957124+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[240587]|0}b=1<<(c[962260+((k>>>9&7)<<2)>>2]&7);c[240592]=b&j;k=b|j;j=c[957132+(i*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]=k&255;return}else{fj[j&511](g&16777215,k);return}}function aiv(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=g&h;i=g|h;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function aiw(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=1<<(c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]&7);c[240592]=f&i;j=f|i;i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]=j&255;return}else{fj[i&511](g&16777215,j);return}}function aix(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=f&i;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,h);return}}function aiy(){var a=0,b=0,d=0;a=(c[240591]|0)>>>4&8|(c[240590]|0)>>>4&16|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;b=c[240581]|0;c[240581]=b+2;d=a&(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0);b=d<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=d>>>2&1^1;c[240593]=d<<6&128;c[240594]=d<<8&256;return}function aiz(){var a=0,b=0,d=0;a=c[240581]|0;c[240581]=a+2;b=962260+((c[240587]&7)<<2)|0;d=c[b>>2]&(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|-65536);c[b>>2]=d;b=d&65535;c[240592]=b;c[240591]=b>>>8;c[240594]=0;c[240593]=0;return}function aiA(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=962260+((c[240587]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=f&i;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;i=c[957132+(e*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[i&511](g&16777215,h);return}}function aiB(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[240580]|0;c[240580]=e+2;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=f&i;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,h);return}}function aiC(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=962260+((c[240587]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=f&i;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;i=c[957132+(e*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[i&511](g&16777215,h);return}}function aiD(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=(c[240580]|0)-2|0;c[240580]=e;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=f&i;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;i=c[957132+(g*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,h);return}}function aiE(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;h=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=e+4;e=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}f=g&i;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[i&511](e&16777215,f);return}}function aiF(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;i=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=f+4;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=h&k;c[240591]=i;c[240592]=i;c[240594]=0;c[240593]=0;k=c[957132+(j*20|0)>>2]|0;if((k|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[k&511](g&16777215,i);return}}function aiG(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;c[240581]=e+4;e=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[957124+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=g&i;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;i=c[957132+(f*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[i&511](e&16777215,h);return}}function aiH(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;c[240581]=f+6;i=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=h&k;c[240591]=i;c[240592]=i;c[240594]=0;c[240593]=0;k=c[957132+(j*20|0)>>2]|0;if((k|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]=i&255;return}else{fj[k&511](g&16777215,i);return}}function aiI(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=a>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h&d;c[240591]=g>>>8;c[240592]=g;c[240594]=0;c[240593]=0;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[d&511](a&16777215,g);return}}function aiJ(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+2;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h&d;c[240591]=g>>>8;c[240592]=g;c[240594]=0;c[240593]=0;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[d&511](f&16777215,g);return}}function aiK(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;f=(c[a>>2]|0)-2|0;c[a>>2]=f;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h&d;c[240591]=g>>>8;c[240592]=g;c[240594]=0;c[240593]=0;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[d&511](f&16777215,g);return}}function aiL(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+4;b=a+2|0;d=962260+((c[240587]&7)<<2)|0;f=c[d>>2]&(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16);c[d>>2]=f;c[240592]=f;c[240591]=f>>>24;c[240594]=0;c[240593]=0;return}function aiM(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}d=h&f;c[240591]=d>>>8;c[240592]=d;c[240594]=0;c[240593]=0;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[f&511](a&16777215,d);return}}function aiN(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+g+h|0;h=d>>>16&255;g=c[957128+(h*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0}else{i=fl[g&255](d&16777215)|0}g=i&f;c[240591]=g>>>8;c[240592]=g;c[240594]=0;c[240593]=0;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[f&511](d&16777215,g);return}}function aiO(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h&f;c[240591]=g>>>8;c[240592]=g;c[240594]=0;c[240593]=0;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[f&511](a&16777215,g);return}}function aiP(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+6;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;h=g&255;g=c[957128+(h*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0}else{i=fl[g&255](d&16777215)|0}g=i&f;c[240591]=g>>>8;c[240592]=g;c[240594]=0;c[240593]=0;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=g&65535;return}else{fj[f&511](d&16777215,g);return}}function aiQ(){var a=0,b=0,d=0;a=c[240589]|0;if((a|0)==0){aH4();return}else{b=c[240581]|0;c[240581]=b+2;d=(c[240588]|a<<11|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1)&(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0);c[240588]=d&32768;c[240595]=d&1792;b=d<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=d>>>2&1^1;c[240593]=d<<6&128;c[240594]=d<<8&256;b=d>>>11&4;c[962328+(a<<2)>>2]=c[240580];c[240589]=b;c[240580]=c[962328+(b<<2)>>2];ahk();return}}function aiR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=a+2|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[g>>2]&255](a+2&16777215)|0|i}i=j&f;c[240591]=i>>>24;c[240592]=i;c[240594]=0;c[240593]=0;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[f&511](a&16777215,i>>>16)}f=a+2|0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[d&511](f&16777215,i&65535);return}}function aiS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=a+2|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j&f;c[240591]=i>>>24;c[240592]=i;c[240594]=0;c[240593]=0;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[f&511](d&16777215,i>>>16)}f=d+2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[a&511](f&16777215,i&65535);return}}function aiT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=a+2|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;a=g>>>16&255;h=957128+(a*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{j=(fl[i&255](g&16777215)|0)<<16;k=fl[c[h>>2]&255](d+16777214&16777215)|0|j}j=k&f;c[240591]=j>>>24;c[240592]=j;c[240594]=0;c[240593]=0;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[f&511](g&16777215,j>>>16)}g=d-2|0;d=g>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[f&511](g&16777215,j&65535);return}}function aiU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+f|0;f=a>>>16&255;d=957128+(f*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[d>>2]&255](a+2&16777215)|0|i}i=j&g;c[240591]=i>>>24;c[240592]=i;c[240594]=0;c[240593]=0;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[g&511](a&16777215,i>>>16)}g=a+2|0;a=g>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[f&511](g&16777215,i&65535);return}}function aiV(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=d&255;f=c[a>>2]|0;g=f&255;h=g-b|0;c[240591]=h;i=f-d&255;c[240592]=i;c[240594]=h;c[240590]=h;c[240593]=(h^f)&(b^g);c[a>>2]=c[a>>2]&-256|i;return}function aiW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+f+h|0;h=d>>>16&255;f=957128+(h*20|0)|0;a=c[f>>2]|0;if((a|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[a&255](d&16777215)|0)<<16;j=fl[c[f>>2]&255](d+2&16777215)|0|i}i=j&g;c[240591]=i>>>24;c[240592]=i;c[240594]=0;c[240593]=0;g=c[957136+(h*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[g&511](d&16777215,i>>>16)}g=d+2|0;d=g>>>16&255;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[h&511](g&16777215,i&65535);return}}function aiX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;c[240581]=a+6;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[f>>2]&255](a+2&16777215)|0|i}i=j&g;c[240591]=i>>>24;c[240592]=i;c[240594]=0;c[240593]=0;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[g&511](a&16777215,i>>>16)}g=a+2|0;a=g>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[d&511](g&16777215,i&65535);return}}function aiY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;c[240581]=a+8;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|f<<16;h=f&255;f=957128+(h*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16}else{j=(fl[i&255](d&16777215)|0)<<16;k=fl[c[f>>2]&255](d+2&16777215)|0|j}j=k&g;c[240591]=j>>>24;c[240592]=j;c[240594]=0;c[240593]=0;g=c[957136+(h*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[g&511](d&16777215,j>>>16)}g=d+2|0;d=g>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[a&511](g&16777215,j&65535);return}}function aiZ(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i-f|0;c[240591]=h;j=h&255;c[240592]=j;c[240594]=h;c[240590]=h;c[240593]=(h^i)&(i^f);f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,j);return}}function ai_(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=962260+((c[240587]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i-f|0;c[240591]=h;j=h&255;c[240592]=j;c[240594]=h;c[240590]=h;c[240593]=(h^i)&(i^f);f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,j);return}}function ai$(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[240580]|0;c[240580]=e+2;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i-f|0;c[240591]=h;j=h&255;c[240592]=j;c[240594]=h;c[240590]=h;c[240593]=(h^i)&(i^f);f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,j);return}}function ai0(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=962260+((c[240587]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i-f|0;c[240591]=h;j=h&255;c[240592]=j;c[240594]=h;c[240590]=h;c[240593]=(h^i)&(i^f);f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,j);return}}function ai1(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=(c[240580]|0)-2|0;c[240580]=e;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i-f|0;c[240591]=h;j=h&255;c[240592]=j;c[240594]=h;c[240590]=h;c[240593]=(h^i)&(i^f);f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,j);return}}function ai2(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;h=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=e+4;e=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}f=i-g|0;c[240591]=f;j=f&255;c[240592]=j;c[240594]=f;c[240590]=f;c[240593]=(f^i)&(i^g);g=c[957132+(h*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,j);return}}function ai3(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[a>>2]|0;f=b&65535;g=f-d|0;h=g>>>8;c[240591]=h;i=b-d&65535;c[240592]=i;c[240594]=h;c[240590]=h;c[240593]=((g^b)&(f^d))>>>8;c[a>>2]=c[a>>2]&-65536|i;return}function ai4(){var a=0,b=0,d=0,f=0,g=0;a=962260+((c[240587]&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;f=b+2|0;b=c[a>>2]|0;g=b-(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d)|0;c[240591]=g>>>24;c[240592]=g;f=((g|d)&(b^-8388608)|g&d)>>>23;c[240594]=f;c[240590]=f;c[240593]=((g^b)&(b^d))>>>24;c[a>>2]=g;return}function ai5(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;i=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=f+4;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=k-h|0;c[240591]=i;f=i&255;c[240592]=f;c[240594]=i;c[240590]=i;c[240593]=(i^k)&(k^h);h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[h&511](g&16777215,f);return}}function ai6(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;c[240581]=e+4;e=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[957124+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i-g|0;c[240591]=h;j=h&255;c[240592]=j;c[240594]=h;c[240590]=h;c[240593]=(h^i)&(i^g);g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,j);return}}function ai7(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;c[240581]=f+6;i=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=k-h|0;c[240591]=i;l=i&255;c[240592]=l;c[240594]=i;c[240590]=i;c[240593]=(i^k)&(k^h);h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]=i&255;return}else{fj[h&511](g&16777215,l);return}}function ai8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=a>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h-d|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^d))>>>8;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[d&511](a&16777215,j);return}}function ai9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+2;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h-d|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^d))>>>8;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[d&511](f&16777215,j);return}}function aja(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;f=(c[a>>2]|0)-2|0;c[a>>2]=f;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h-d|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^d))>>>8;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[d&511](f&16777215,j);return}}function ajb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}d=h-f|0;i=d>>>8;c[240591]=i;j=d&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((d^h)&(h^f))>>>8;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[f&511](a&16777215,j);return}}function ajc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+g+h|0;h=d>>>16&255;g=c[957128+(h*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0}else{i=fl[g&255](d&16777215)|0}g=i-f|0;a=g>>>8;c[240591]=a;j=g&65535;c[240592]=j;c[240594]=a;c[240590]=a;c[240593]=((g^i)&(i^f))>>>8;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[f&511](d&16777215,j);return}}function ajd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h-f|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^f))>>>8;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[f&511](a&16777215,j);return}}function aje(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+6;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;h=g&255;g=c[957128+(h*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0}else{i=fl[g&255](d&16777215)|0}g=i-f|0;j=g>>>8;c[240591]=j;k=g&65535;c[240592]=k;c[240594]=j;c[240590]=j;c[240593]=((g^i)&(i^f))>>>8;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=g&65535;return}else{fj[f&511](d&16777215,k);return}}function ajf(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=f>>>16&255;h=957128+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[h>>2]&255](f+2&16777215)|0|j}j=k-a|0;c[240591]=j>>>24;c[240592]=j;a=((j|d)&(k^-8388608)|j&d)>>>23;c[240594]=a;c[240590]=a;c[240593]=((j^k)&(k^d))>>>24;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[d&511](f&16777215,j>>>16)}d=f+2|0;f=d>>>16&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[g&511](d&16777215,j&65535);return}}function ajg(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=962260+((c[240587]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+4;f=g>>>16&255;h=957128+(f*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=g+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{j=(fl[i&255](g&16777215)|0)<<16;k=fl[c[h>>2]&255](g+2&16777215)|0|j}j=k-a|0;c[240591]=j>>>24;c[240592]=j;a=((j|d)&(k^-8388608)|j&d)>>>23;c[240594]=a;c[240590]=a;c[240593]=((j^k)&(k^d))>>>24;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[d&511](g&16777215,j>>>16)}d=g+2|0;g=d>>>16&255;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[f&511](d&16777215,j&65535);return}}function ajh(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;c[240581]=a+4;d=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=962260+((c[240587]&7|8)<<2)|0;g=c[f>>2]|0;h=g-4|0;c[f>>2]=h;f=h>>>16&255;i=957128+(f*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=g-2|0;l=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]|0)<<16}else{k=(fl[j&255](h&16777215)|0)<<16;l=fl[c[i>>2]&255](g+16777214&16777215)|0|k}k=l-a|0;c[240591]=k>>>24;c[240592]=k;a=((k|d)&(l^-8388608)|k&d)>>>23;c[240594]=a;c[240590]=a;c[240593]=((k^l)&(l^d))>>>24;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]=k>>>16&65535}else{fj[d&511](h&16777215,k>>>16)}h=g-2|0;g=h>>>16&255;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(h&65535)>>1]=k&65535;return}else{fj[d&511](h&16777215,k&65535);return}}function aji(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|f;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=a>>>16&255;d=957128+(g*20|0)|0;i=c[d>>2]|0;if((i|0)==0){j=a+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]<<16}else{j=(fl[i&255](a&16777215)|0)<<16;k=fl[c[d>>2]&255](a+2&16777215)|0|j}j=k-h|0;c[240591]=j>>>24;c[240592]=j;h=((j|f)&(k^-8388608)|j&f)>>>23;c[240594]=h;c[240590]=h;c[240593]=((j^k)&(k^f))>>>24;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[f&511](a&16777215,j>>>16)}f=a+2|0;a=f>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[g&511](f&16777215,j&65535);return}}function ajj(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|f;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=d<<16>>16}else{i=d}d=(a<<24>>24)+g+i|0;i=d>>>16&255;g=957128+(i*20|0)|0;a=c[g>>2]|0;if((a|0)==0){j=d+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{j=(fl[a&255](d&16777215)|0)<<16;k=fl[c[g>>2]&255](d+2&16777215)|0|j}j=k-h|0;c[240591]=j>>>24;c[240592]=j;h=((j|f)&(k^-8388608)|j&f)>>>23;c[240594]=h;c[240590]=h;c[240593]=((j^k)&(k^f))>>>24;f=c[957136+(i*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[f&511](d&16777215,j>>>16)}f=d+2|0;d=f>>>16&255;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[i&511](f&16777215,j&65535);return}}function ajk(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|f;c[240581]=a+6;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;g=957128+(d*20|0)|0;i=c[g>>2]|0;if((i|0)==0){j=a+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]<<16}else{j=(fl[i&255](a&16777215)|0)<<16;k=fl[c[g>>2]&255](a+2&16777215)|0|j}j=k-h|0;c[240591]=j>>>24;c[240592]=j;h=((j|f)&(k^-8388608)|j&f)>>>23;c[240594]=h;c[240590]=h;c[240593]=((j^k)&(k^f))>>>24;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[f&511](a&16777215,j>>>16)}f=a+2|0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[d&511](f&16777215,j&65535);return}}function ajl(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=d&255;f=c[a>>2]|0;g=f&255;h=b+g|0;c[240591]=h;c[240593]=(h^b)&(h^g);c[240594]=h;c[240590]=h;h=d+f&255;c[240592]=h;c[a>>2]=c[a>>2]&-256|h;return}function ajm(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7)<<2)|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[a>>2]|0;f=b&65535;g=f+d|0;h=g>>>8;c[240591]=h;c[240593]=((g^d)&(g^f))>>>8;c[240594]=h;c[240590]=h;h=b+d&65535;c[240592]=h;c[a>>2]=c[a>>2]&-65536|h;return}function ajn(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|f;c[240581]=a+8;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;i=g&255;g=957128+(i*20|0)|0;j=c[g>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[957120+(i*20|0)>>2]|0)+a>>1]|0)<<16}else{k=(fl[j&255](d&16777215)|0)<<16;l=fl[c[g>>2]&255](d+2&16777215)|0|k}k=l-h|0;c[240591]=k>>>24;c[240592]=k;h=((k|f)&(l^-8388608)|k&f)>>>23;c[240594]=h;c[240590]=h;c[240593]=((k^l)&(l^f))>>>24;f=c[957136+(i*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(i*20|0)>>2]|0)+a>>1]=k>>>16&65535}else{fj[f&511](d&16777215,k>>>16)}f=d+2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=k&65535;return}else{fj[a&511](f&16777215,k&65535);return}}function ajo(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;h=g>>>16&255;i=c[957124+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(h*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[i&255](g&16777215)|0}i=j+b|0;c[240591]=i;c[240593]=(i^b)&(i^j);c[240594]=i;c[240590]=i;i=j+f|0;f=i&255;c[240592]=f;j=c[957132+(h*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[j&511](g&16777215,f);return}}function ajp(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=962260+((c[240587]&7|8)<<2)|0;h=c[g>>2]|0;c[g>>2]=h+1;g=h>>>16&255;i=c[957124+(g*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]|0}else{j=fl[i&255](h&16777215)|0}i=j+b|0;c[240591]=i;c[240593]=(i^b)&(i^j);c[240594]=i;c[240590]=i;i=j+f|0;f=i&255;c[240592]=f;j=c[957132+(g*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]=i&255;return}else{fj[j&511](h&16777215,f);return}}function ajq(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=c[240580]|0;c[240580]=g+2;h=g>>>16&255;i=c[957124+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(h*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[i&255](g&16777215)|0}i=j+b|0;c[240591]=i;c[240593]=(i^b)&(i^j);c[240594]=i;c[240590]=i;i=j+f|0;f=i&255;c[240592]=f;j=c[957132+(h*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[j&511](g&16777215,f);return}}function ajr(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=962260+((c[240587]&7|8)<<2)|0;h=(c[g>>2]|0)-1|0;c[g>>2]=h;g=h>>>16&255;i=c[957124+(g*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]|0}else{j=fl[i&255](h&16777215)|0}i=j+b|0;c[240591]=i;c[240593]=(i^b)&(i^j);c[240594]=i;c[240590]=i;i=j+f|0;f=i&255;c[240592]=f;j=c[957132+(g*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]=i&255;return}else{fj[j&511](h&16777215,f);return}}function ajs(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=(c[240580]|0)-2|0;c[240580]=g;h=g>>>16&255;i=c[957124+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(h*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[i&255](g&16777215)|0}i=j+b|0;c[240591]=i;c[240593]=(i^b)&(i^j);c[240594]=i;c[240590]=i;i=j+f|0;f=i&255;c[240592]=f;j=c[957132+(h*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[j&511](g&16777215,f);return}}function ajt(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;i=h&255;j=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=f+4;f=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+j|0;j=f>>>16&255;g=c[957124+(j*20|0)>>2]|0;if((g|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(f&65535^1)|0]|0}else{k=fl[g&255](f&16777215)|0}g=k+i|0;c[240591]=g;c[240593]=(g^i)&(g^k);c[240594]=g;c[240590]=g;g=k+h|0;h=g&255;c[240592]=h;k=c[957132+(j*20|0)>>2]|0;if((k|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[k&511](f&16777215,h);return}}function aju(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240581]|0;f=b+2|0;c[240581]=f;g=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;h=g&255;i=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=b+4;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){j=f<<16>>16}else{j=f}f=(b<<24>>24)+i+j|0;j=f>>>16&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(f&65535^1)|0]|0}else{k=fl[i&255](f&16777215)|0}i=k+h|0;c[240591]=i;c[240593]=(i^h)&(i^k);c[240594]=i;c[240590]=i;i=k+g|0;g=i&255;c[240592]=g;k=c[957132+(j*20|0)>>2]|0;if((k|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[k&511](f&16777215,g);return}}function ajv(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;i=h&255;c[240581]=f+4;f=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f>>>16&255;j=c[957124+(g*20|0)>>2]|0;if((j|0)==0){k=d[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{k=fl[j&255](f&16777215)|0}j=k+i|0;c[240591]=j;c[240593]=(j^i)&(j^k);c[240594]=j;c[240590]=j;j=k+h|0;h=j&255;c[240592]=h;k=c[957132+(g*20|0)>>2]|0;if((k|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=j&255;return}else{fj[k&511](f&16777215,h);return}}function ajw(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240581]|0;f=b+2|0;c[240581]=f;g=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;h=g&255;c[240581]=b+6;i=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b+4|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|i<<16;j=i&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(b^1)|0]|0}else{k=fl[i&255](f&16777215)|0}i=k+h|0;c[240591]=i;c[240593]=(i^h)&(i^k);c[240594]=i;c[240590]=i;i=k+g|0;g=i&255;c[240592]=g;k=c[957132+(j*20|0)>>2]|0;if((k|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(b^1)|0]=i&255;return}else{fj[k&511](f&16777215,g);return}}function ajx(){var a=0,b=0,d=0,f=0,g=0;a=962260+((c[240587]&7)<<2)|0;b=c[240581]|0;c[240581]=b+4;d=(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;f=b+2|0;b=c[a>>2]|0;g=(e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d)+b|0;c[240591]=g>>>24;c[240593]=((g^d)&(g^b))>>>24;f=((g^-8388608)&(b|d)|b&d)>>>23;c[240594]=f;c[240590]=f;c[240592]=g;c[a>>2]=g;return}function ajy(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=a>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h+d|0;i=g>>>8;c[240591]=i;c[240593]=((g^d)&(g^h))>>>8;c[240594]=i;c[240590]=i;i=g&65535;c[240592]=i;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[h&511](a&16777215,i);return}}function ajz(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+2;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h+d|0;i=g>>>8;c[240591]=i;c[240593]=((g^d)&(g^h))>>>8;c[240594]=i;c[240590]=i;i=g&65535;c[240592]=i;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[h&511](f&16777215,i);return}}function ajA(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;f=(c[a>>2]|0)-2|0;c[a>>2]=f;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h+d|0;i=g>>>8;c[240591]=i;c[240593]=((g^d)&(g^h))>>>8;c[240594]=i;c[240590]=i;i=g&65535;c[240592]=i;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[h&511](f&16777215,i);return}}function ajB(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}d=h+f|0;i=d>>>8;c[240591]=i;c[240593]=((d^f)&(d^h))>>>8;c[240594]=i;c[240590]=i;i=d&65535;c[240592]=i;h=c[957136+(g*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[h&511](a&16777215,i);return}}function ajC(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+g+h|0;h=d>>>16&255;g=c[957128+(h*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0}else{i=fl[g&255](d&16777215)|0}g=i+f|0;a=g>>>8;c[240591]=a;c[240593]=((g^f)&(g^i))>>>8;c[240594]=a;c[240590]=a;a=g&65535;c[240592]=a;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[i&511](d&16777215,a);return}}function ajD(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h+f|0;i=g>>>8;c[240591]=i;c[240593]=((g^f)&(g^h))>>>8;c[240594]=i;c[240590]=i;i=g&65535;c[240592]=i;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[h&511](a&16777215,i);return}}function ajE(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+6;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;h=g&255;g=c[957128+(h*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0}else{i=fl[g&255](d&16777215)|0}g=i+f|0;j=g>>>8;c[240591]=j;c[240593]=((g^f)&(g^i))>>>8;c[240594]=j;c[240590]=j;j=g&65535;c[240592]=j;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=g&65535;return}else{fj[i&511](d&16777215,j);return}}function ajF(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=f>>>16&255;h=957128+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{j=(fl[i&255](f&16777215)|0)<<16;k=fl[c[h>>2]&255](f+2&16777215)|0|j}j=k+a|0;c[240591]=j>>>24;c[240593]=((j^d)&(j^k))>>>24;a=((j^-8388608)&(k|d)|k&d)>>>23;c[240594]=a;c[240590]=a;c[240592]=j;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[a&511](f&16777215,j>>>16)}a=f+2|0;f=a>>>16&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[g&511](a&16777215,j&65535);return}}function ajG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=962260+((c[240587]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+4;f=g>>>16&255;h=957128+(f*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=g+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{j=(fl[i&255](g&16777215)|0)<<16;k=fl[c[h>>2]&255](g+2&16777215)|0|j}j=k+a|0;c[240591]=j>>>24;c[240593]=((j^d)&(j^k))>>>24;a=((j^-8388608)&(k|d)|k&d)>>>23;c[240594]=a;c[240590]=a;c[240592]=j;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[a&511](g&16777215,j>>>16)}a=g+2|0;g=a>>>16&255;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[f&511](a&16777215,j&65535);return}}function ajH(){var a=0,d=0;a=c[962260+((c[240587]&7)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;c[240592]=1<<(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]&31)&a;return}function ajI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;c[240581]=a+4;d=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=962260+((c[240587]&7|8)<<2)|0;g=c[f>>2]|0;h=g-4|0;c[f>>2]=h;f=h>>>16&255;i=957128+(f*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=g-2|0;l=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]|0)<<16}else{k=(fl[j&255](h&16777215)|0)<<16;l=fl[c[i>>2]&255](g+16777214&16777215)|0|k}k=l+a|0;c[240591]=k>>>24;c[240593]=((k^d)&(k^l))>>>24;a=((k^-8388608)&(l|d)|l&d)>>>23;c[240594]=a;c[240590]=a;c[240592]=k;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]=k>>>16&65535}else{fj[a&511](h&16777215,k>>>16)}h=g-2|0;g=h>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(h&65535)>>1]=k&65535;return}else{fj[a&511](h&16777215,k&65535);return}}function ajJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|f;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=a>>>16&255;d=957128+(g*20|0)|0;i=c[d>>2]|0;if((i|0)==0){j=a+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]<<16}else{j=(fl[i&255](a&16777215)|0)<<16;k=fl[c[d>>2]&255](a+2&16777215)|0|j}j=k+h|0;c[240591]=j>>>24;c[240593]=((j^f)&(j^k))>>>24;h=((j^-8388608)&(k|f)|k&f)>>>23;c[240594]=h;c[240590]=h;c[240592]=j;h=c[957136+(g*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[h&511](a&16777215,j>>>16)}h=a+2|0;a=h>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[g&511](h&16777215,j&65535);return}}function ajK(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|f;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=d<<16>>16}else{i=d}d=(a<<24>>24)+g+i|0;i=d>>>16&255;g=957128+(i*20|0)|0;a=c[g>>2]|0;if((a|0)==0){j=d+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{j=(fl[a&255](d&16777215)|0)<<16;k=fl[c[g>>2]&255](d+2&16777215)|0|j}j=k+h|0;c[240591]=j>>>24;c[240593]=((j^f)&(j^k))>>>24;h=((j^-8388608)&(k|f)|k&f)>>>23;c[240594]=h;c[240590]=h;c[240592]=j;h=c[957136+(i*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[h&511](d&16777215,j>>>16)}h=d+2|0;d=h>>>16&255;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[i&511](h&16777215,j&65535);return}}function ajL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|f;c[240581]=a+6;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;g=957128+(d*20|0)|0;i=c[g>>2]|0;if((i|0)==0){j=a+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]<<16}else{j=(fl[i&255](a&16777215)|0)<<16;k=fl[c[g>>2]&255](a+2&16777215)|0|j}j=k+h|0;c[240591]=j>>>24;c[240593]=((j^f)&(j^k))>>>24;h=((j^-8388608)&(k|f)|k&f)>>>23;c[240594]=h;c[240590]=h;c[240592]=j;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[h&511](a&16777215,j>>>16)}h=a+2|0;a=h>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[d&511](h&16777215,j&65535);return}}function ajM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|f;c[240581]=a+8;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;i=g&255;g=957128+(i*20|0)|0;j=c[g>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[957120+(i*20|0)>>2]|0)+a>>1]|0)<<16}else{k=(fl[j&255](d&16777215)|0)<<16;l=fl[c[g>>2]&255](d+2&16777215)|0|k}k=l+h|0;c[240591]=k>>>24;c[240593]=((k^f)&(k^l))>>>24;h=((k^-8388608)&(l|f)|l&f)>>>23;c[240594]=h;c[240590]=h;c[240592]=k;h=c[957136+(i*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(i*20|0)>>2]|0)+a>>1]=k>>>16&65535}else{fj[h&511](d&16777215,k>>>16)}h=d+2|0;d=h>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]=k&65535;return}else{fj[a&511](h&16777215,k&65535);return}}function ajN(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=a>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a&65535^1)|0]|0;i=1<<e;j=h&i;c[240592]=j;return}else{h=fl[g&255](a&16777215)|0;i=1<<e;j=h&i;c[240592]=j;return}}function ajO(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;a=962260+((c[240587]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+1;a=f>>>16&255;g=c[957124+(a*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(a*20|0)>>2]|0)+(f&65535^1)|0]|0;i=1<<e;j=h&i;c[240592]=j;return}else{h=fl[g&255](f&16777215)|0;i=1<<e;j=h&i;c[240592]=j;return}}function ajP(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;a=c[240580]|0;c[240580]=a+2;f=a>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a&65535^1)|0]|0;i=1<<e;j=h&i;c[240592]=j;return}else{h=fl[g&255](a&16777215)|0;i=1<<e;j=h&i;c[240592]=j;return}}function ajQ(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;a=962260+((c[240587]&7|8)<<2)|0;f=(c[a>>2]|0)-1|0;c[a>>2]=f;a=f>>>16&255;g=c[957124+(a*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(a*20|0)>>2]|0)+(f&65535^1)|0]|0;i=1<<e;j=h&i;c[240592]=j;return}else{h=fl[g&255](f&16777215)|0;i=1<<e;j=h&i;c[240592]=j;return}}function ajR(){var a=0,e=0,f=0;a=c[240581]|0;e=a+2|0;c[240581]=e;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;c[240581]=a+4;a=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+e|0;c[240592]=d[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535^1)|0]&1<<f;return}function ajS(){var a=0,f=0,g=0,h=0,i=0;a=c[240581]|0;f=a+2|0;c[240581]=f;g=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;c[240581]=a+4;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=h<<16>>16}else{i=h}h=(a<<24>>24)+f+i|0;c[240592]=(d[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535^1)|0]|0)&1<<g;return}function ajT(){var a=0,d=0,e=0;a=962260+((c[240587]&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=1<<(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]&31);c[240592]=e&c[a>>2];c[a>>2]=e^c[a>>2];return}function ajU(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;a=(c[240580]|0)-2|0;c[240580]=a;f=a>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a&65535^1)|0]|0;i=1<<e;j=h&i;c[240592]=j;return}else{h=fl[g&255](a&16777215)|0;i=1<<e;j=h&i;c[240592]=j;return}}function ajV(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;e=a+2|0;c[240581]=e;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+g|0;g=a>>>16&255;e=c[957124+(g*20|0)>>2]|0;if((e|0)==0){h=d[(c[957120+(g*20|0)>>2]|0)+(a&65535^1)|0]|0;i=1<<f;j=h&i;c[240592]=j;return}else{h=fl[e&255](a&16777215)|0;i=1<<f;j=h&i;c[240592]=j;return}}function ajW(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;f=a+2|0;c[240581]=f;g=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;h=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=f<<16>>16}else{i=f}f=(a<<24>>24)+h+i|0;i=f>>>16&255;h=c[957124+(i*20|0)>>2]|0;if((h|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(f&65535^1)|0]|0;k=1<<g;l=j&k;c[240592]=l;return}else{j=fl[h&255](f&16777215)|0;k=1<<g;l=j&k;c[240592]=l;return}}function ajX(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;e=a+2|0;c[240581]=e;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;c[240581]=a+4;a=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=a>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(a&65535^1)|0]|0;i=1<<f;j=h&i;c[240592]=j;return}else{h=fl[g&255](a&16777215)|0;i=1<<f;j=h&i;c[240592]=j;return}}function ajY(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;f=a+2|0;c[240581]=f;g=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;c[240581]=a+6;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a+4|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=h&255;i=c[957124+(f*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(f*20|0)>>2]|0)+(a^1)|0]|0;k=1<<g;l=j&k;c[240592]=l;return}else{j=fl[i&255](a|h<<16&16711680)|0;k=1<<g;l=j&k;c[240592]=l;return}}function ajZ(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&f;h=i^f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function aj_(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=962260+((c[240587]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[240592]=i&f;h=i^f;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function aj$(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[240580]|0;c[240580]=e+2;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&f;h=i^f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function aj0(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=962260+((c[240587]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[240592]=i&f;h=i^f;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function aj1(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=(c[240580]|0)-2|0;c[240580]=e;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&f;h=i^f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function aj2(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);h=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=e+4;e=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}c[240592]=i&g;f=i^g;g=c[957132+(h*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function aj3(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=1<<(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);i=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=f+4;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[240592]=k&h;i=k^h;h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function aj4(){var a=0,d=0,e=0;a=962260+((c[240587]&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=1<<(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]&31);c[240592]=e&c[a>>2];c[a>>2]=c[a>>2]&~e;return}function aj5(){var a=0,d=0,e=0;a=962260+((c[240587]&7)<<2)|0;d=c[240581]|0;c[240581]=d+2;e=1<<(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]&31);c[240592]=e&c[a>>2];c[a>>2]=e|c[a>>2];return}function aj6(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);c[240581]=e+4;e=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[957124+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&g;h=i^g;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function aj7(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=1<<(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);c[240581]=f+6;i=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[240592]=k&h;i=k^h;h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function aj8(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&f;h=i&~f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function aj9(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=962260+((c[240587]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[240592]=i&f;h=i&~f;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function aka(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[240580]|0;c[240580]=e+2;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&f;h=i&~f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function akb(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=962260+((c[240587]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[240592]=i&f;h=i&~f;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function akc(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=(c[240580]|0)-2|0;c[240580]=e;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&f;h=i&~f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function akd(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);h=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=e+4;e=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}c[240592]=i&g;f=i&~g;g=c[957132+(h*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function ake(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=1<<(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);i=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=f+4;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[240592]=k&h;i=k&~h;h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function akf(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);c[240581]=e+4;e=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[957124+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&g;h=i&~g;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function akg(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=1<<(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);c[240581]=f+6;i=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[240592]=k&h;i=k&~h;h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function akh(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&f;h=i|f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function aki(){var a=0,d=0,e=0;a=c[240581]|0;c[240581]=a+2;d=962260+((c[240587]&7)<<2)|0;e=c[d>>2]^b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;c[d>>2]=e;d=e&255;c[240591]=d;c[240592]=d;c[240594]=0;c[240593]=0;return}function akj(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=962260+((c[240587]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[240592]=i&f;h=i|f;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function akk(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[240580]|0;c[240580]=e+2;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&f;h=i|f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function akl(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=962260+((c[240587]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[240592]=i&f;h=i|f;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function akm(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=(c[240580]|0)-2|0;c[240580]=e;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&f;h=i|f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function akn(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);h=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=e+4;e=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}c[240592]=i&g;f=i|g;g=c[957132+(h*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function ako(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=1<<(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);i=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=f+4;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[240592]=k&h;i=k|h;h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function akp(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=1<<(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);c[240581]=e+4;e=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[957124+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[240592]=i&g;h=i|g;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function akq(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=1<<(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);c[240581]=f+6;i=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[240592]=k&h;i=k|h;h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function akr(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i^f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[f&511](e&16777215,h);c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}}function aks(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=962260+((c[240587]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i^f;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[f&511](g&16777215,h);c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}}function akt(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[240580]|0;c[240580]=e+2;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i^f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[f&511](e&16777215,h);c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}}function aku(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=962260+((c[240587]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i^f;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[f&511](g&16777215,h);c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}}function akv(){var a=0,b=0,d=0;a=(c[240591]|0)>>>4&8|(c[240590]|0)>>>4&16|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;b=c[240581]|0;c[240581]=b+2;d=a^(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0);b=d<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=d>>>2&1^1;c[240593]=d<<6&128;c[240594]=d<<8&256;return}function akw(){var a=0,b=0,d=0;a=c[240581]|0;c[240581]=a+2;b=962260+((c[240587]&7)<<2)|0;d=c[b>>2]^(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0);c[b>>2]=d;b=d&65535;c[240591]=b>>>8;c[240592]=b;c[240594]=0;c[240593]=0;return}function akx(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=(c[240580]|0)-2|0;c[240580]=e;g=e>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i^f;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[f&511](e&16777215,h);c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}}function aky(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;h=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=e+4;e=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}f=i^g;g=c[957132+(h*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[g&511](e&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function akz(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;i=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=f+4;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=k^h;h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;c[240591]=i;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[h&511](g&16777215,i);c[240591]=i;c[240592]=i;c[240594]=0;c[240593]=0;return}}function akA(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;c[240581]=e+4;e=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[957124+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i^g;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[g&511](e&16777215,h);c[240591]=h;c[240592]=h;c[240594]=0;c[240593]=0;return}}function akB(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;c[240581]=f+6;i=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[957124+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=k^h;h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f^1)|0]=i&255;c[240591]=i;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[h&511](g&16777215,i);c[240591]=i;c[240592]=i;c[240594]=0;c[240593]=0;return}}function akC(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=a>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h^d;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=g&65535;i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[d&511](a&16777215,g);i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}}function akD(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+2;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h^d;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[d&511](f&16777215,g);i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}}function akE(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;f=(c[a>>2]|0)-2|0;c[a>>2]=f;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h^d;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[d&511](f&16777215,g);i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}}function akF(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}d=h^f;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=d&65535;i=d>>>8;c[240591]=i;c[240592]=d;c[240594]=0;c[240593]=0;return}else{fj[f&511](a&16777215,d);i=d>>>8;c[240591]=i;c[240592]=d;c[240594]=0;c[240593]=0;return}}function akG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+g+h|0;h=d>>>16&255;g=c[957128+(h*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0}else{i=fl[g&255](d&16777215)|0}g=i^f;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]=g&65535;j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[f&511](d&16777215,g);j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}}function akH(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h^f;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=g&65535;i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[f&511](a&16777215,g);i=g>>>8;c[240591]=i;c[240592]=g;c[240594]=0;c[240593]=0;return}}function akI(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+4;b=a+2|0;d=962260+((c[240587]&7)<<2)|0;f=c[d>>2]^(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16);c[d>>2]=f;c[240591]=f>>>24;c[240592]=f;c[240594]=0;c[240593]=0;return}function akJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+6;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;h=g&255;g=c[957128+(h*20|0)>>2]|0;if((g|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0}else{i=fl[g&255](d&16777215)|0}g=i^f;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=g&65535;j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[f&511](d&16777215,g);j=g>>>8;c[240591]=j;c[240592]=g;c[240594]=0;c[240593]=0;return}}function akK(){var a=0,b=0,d=0;a=c[240589]|0;if((a|0)==0){aH4();return}else{b=c[240581]|0;c[240581]=b+2;d=(c[240588]|a<<11|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1)^(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0);c[240588]=d&32768;c[240595]=d&1792;b=d<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=d>>>2&1^1;c[240593]=d<<6&128;c[240594]=d<<8&256;b=d>>>11&4;c[962328+(a<<2)>>2]=c[240580];c[240589]=b;c[240580]=c[962328+(b<<2)>>2];ahk();return}}function akL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=a+2|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[g>>2]&255](a+2&16777215)|0|i}i=j^f;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[f&511](a&16777215,i>>>16)}f=a+2|0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[d&511](f&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function akM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=a+2|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|i}i=j^f;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[f&511](d&16777215,i>>>16)}f=d+2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[a&511](f&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function akN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;c[240581]=a+4;d=a+2|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;a=g>>>16&255;h=957128+(a*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{j=(fl[i&255](g&16777215)|0)<<16;k=fl[c[h>>2]&255](d+16777214&16777215)|0|j}j=k^f;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[f&511](g&16777215,j>>>16)}g=d-2|0;d=g>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=j&65535;l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}else{fj[f&511](g&16777215,j&65535);l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}}function akO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+f|0;f=a>>>16&255;d=957128+(f*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[d>>2]&255](a+2&16777215)|0|i}i=j^g;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[g&511](a&16777215,i>>>16)}g=a+2|0;a=g>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[f&511](g&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function akP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+f+h|0;h=d>>>16&255;f=957128+(h*20|0)|0;a=c[f>>2]|0;if((a|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[a&255](d&16777215)|0)<<16;j=fl[c[f>>2]&255](d+2&16777215)|0|i}i=j^g;g=c[957136+(h*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[g&511](d&16777215,i>>>16)}g=d+2|0;d=g>>>16&255;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[h&511](g&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function akQ(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=b&255;d=c[962260+((c[240587]&7)<<2)>>2]|0;f=d&255;g=f-a|0;c[240591]=g;c[240592]=d-b&255;c[240593]=(g^d)&(f^a);c[240594]=g;return}function akR(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+((c[240587]&7)<<2)>>2]|0;d=a&65535;f=d-b|0;g=f>>>8;c[240591]=g;c[240592]=a-b&65535;c[240593]=((f^a)&(d^b))>>>8;c[240594]=g;return}function akS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;c[240581]=a+6;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[f>>2]&255](a+2&16777215)|0|i}i=j^g;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[g&511](a&16777215,i>>>16)}g=a+2|0;a=g>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[d&511](g&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function akT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;c[240581]=a+8;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|f<<16;h=f&255;f=957128+(h*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16}else{j=(fl[i&255](d&16777215)|0)<<16;k=fl[c[f>>2]&255](d+2&16777215)|0|j}j=k^g;g=c[957136+(h*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(h*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[g&511](d&16777215,j>>>16)}g=d+2|0;d=g>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=j&65535;l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}else{fj[a&511](g&16777215,j&65535);l=j>>>24;c[240591]=l;c[240592]=j;c[240594]=0;c[240593]=0;return}}function akU(){var a=0,e=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=a>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a&65535^1)|0]|0}else{h=fl[g&255](a&16777215)|0}a=h-e|0;c[240591]=a;c[240592]=a&255;c[240593]=(a^h)&(h^e);c[240594]=a;return}function akV(){var a=0,e=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=962260+((c[240587]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+1;a=f>>>16&255;g=c[957124+(a*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(a*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=h-e|0;c[240591]=f;c[240592]=f&255;c[240593]=(f^h)&(h^e);c[240594]=f;return}function akW(){var a=0,e=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=c[240580]|0;c[240580]=a+2;f=a>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a&65535^1)|0]|0}else{h=fl[g&255](a&16777215)|0}a=h-e|0;c[240591]=a;c[240592]=a&255;c[240593]=(a^h)&(h^e);c[240594]=a;return}function akX(){var a=0,e=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=962260+((c[240587]&7|8)<<2)|0;f=(c[a>>2]|0)-1|0;c[a>>2]=f;a=f>>>16&255;g=c[957124+(a*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(a*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=h-e|0;c[240591]=f;c[240592]=f&255;c[240593]=(f^h)&(h^e);c[240594]=f;return}function akY(){var a=0,e=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=(c[240580]|0)-2|0;c[240580]=a;f=a>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a&65535^1)|0]|0}else{h=fl[g&255](a&16777215)|0}a=h-e|0;c[240591]=a;c[240592]=a&255;c[240593]=(a^h)&(h^e);c[240594]=a;return}function akZ(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;e=a+2|0;c[240581]=e;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+g|0;g=a>>>16&255;e=c[957124+(g*20|0)>>2]|0;if((e|0)==0){h=d[(c[957120+(g*20|0)>>2]|0)+(a&65535^1)|0]|0;i=h-f|0;c[240591]=i;j=i&255;c[240592]=j;k=h^f;l=i^h;m=l&k;c[240593]=m;c[240594]=i;return}else{h=fl[e&255](a&16777215)|0;i=h-f|0;c[240591]=i;j=i&255;c[240592]=j;k=h^f;l=i^h;m=l&k;c[240593]=m;c[240594]=i;return}}function ak_(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[240581]|0;f=a+2|0;c[240581]=f;g=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;h=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=f<<16>>16}else{i=f}f=(a<<24>>24)+h+i|0;i=f>>>16&255;h=c[957124+(i*20|0)>>2]|0;if((h|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(f&65535^1)|0]|0;k=j-g|0;c[240591]=k;l=k&255;c[240592]=l;m=j^g;n=k^j;o=n&m;c[240593]=o;c[240594]=k;return}else{j=fl[h&255](f&16777215)|0;k=j-g|0;c[240591]=k;l=k&255;c[240592]=l;m=j^g;n=k^j;o=n&m;c[240593]=o;c[240594]=k;return}}function ak$(){var a=0,e=0,f=0,g=0,h=0;a=c[240581]|0;e=a+2|0;c[240581]=e;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;c[240581]=a+4;a=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=a>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(a&65535^1)|0]|0}else{h=fl[g&255](a&16777215)|0}a=h-f|0;c[240591]=a;c[240592]=a&255;c[240593]=(a^h)&(h^f);c[240594]=a;return}function ak0(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[240581]|0;f=a+2|0;c[240581]=f;g=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;c[240581]=a+6;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a+4|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=h&255;i=c[957124+(f*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(f*20|0)>>2]|0)+(a^1)|0]|0;k=j-g|0;c[240591]=k;l=k&255;c[240592]=l;m=j^g;n=k^j;o=n&m;c[240593]=o;c[240594]=k;return}else{j=fl[i&255](a|h<<16&16711680)|0;k=j-g|0;c[240591]=k;l=k&255;c[240592]=l;m=j^g;n=k^j;o=n&m;c[240593]=o;c[240594]=k;return}}function ak1(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=g-b|0;f=a>>>8;c[240591]=f;c[240592]=a&65535;c[240593]=((a^g)&(g^b))>>>8;c[240594]=f;return}function ak2(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+4;b=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=c[962260+((c[240587]&7)<<2)>>2]|0;f=a-(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b)|0;c[240591]=f>>>24;c[240592]=f;c[240593]=((f^a)&(a^b))>>>24;c[240594]=((f|b)&(a^-8388608)|f&b)>>>23;return}function ak3(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=g-b|0;f=d>>>8;c[240591]=f;c[240592]=d&65535;c[240593]=((d^g)&(g^b))>>>8;c[240594]=f;return}function ak4(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=g-b|0;f=d>>>8;c[240591]=f;c[240592]=d&65535;c[240593]=((d^g)&(g^b))>>>8;c[240594]=f;return}function ak5(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=a>>>16&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[d&255](a&16777215)|0}a=h-f|0;d=a>>>8;c[240591]=d;c[240592]=a&65535;c[240593]=((a^h)&(h^f))>>>8;c[240594]=d;return}function ak6(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[240581]|0;b=a+2|0;c[240581]=b;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){g=b<<16>>16}else{g=b}b=(a<<24>>24)+f+g|0;g=b>>>16&255;f=c[957128+(g*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(b&65535)>>1]|0;i=h-d|0;j=i>>>8;c[240591]=j;k=i&65535;c[240592]=k;l=h^d;m=i^h;n=m&l;o=n>>>8;c[240593]=o;c[240594]=j;return}else{h=fl[f&255](b&16777215)|0;i=h-d|0;j=i>>>8;c[240591]=j;k=i&65535;c[240592]=k;l=h^d;m=i^h;n=m&l;o=n>>>8;c[240593]=o;c[240594]=j;return}}function ak7(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}a=h-f|0;g=a>>>8;c[240591]=g;c[240592]=a&65535;c[240593]=((a^h)&(h^f))>>>8;c[240594]=g;return}function ak8(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[240581]|0;b=a+2|0;c[240581]=b;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+6;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=a+4|0;a=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=c[957128+(b*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(b*20|0)>>2]|0)+a>>1]|0;i=h-d|0;j=i>>>8;c[240591]=j;k=i&65535;c[240592]=k;l=h^d;m=i^h;n=m&l;o=n>>>8;c[240593]=o;c[240594]=j;return}else{h=fl[g&255](a|f<<16&16711680)|0;i=h-d|0;j=i>>>8;c[240591]=j;k=i&65535;c[240592]=k;l=h^d;m=i^h;n=m&l;o=n>>>8;c[240593]=o;c[240594]=j;return}}function ak9(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;b=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{f=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|f}f=j-a|0;c[240591]=f>>>24;c[240592]=f;c[240593]=((f^j)&(j^b))>>>24;c[240594]=((f|b)&(j^-8388608)|f&b)>>>23;return}function ala(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[240581]|0;c[240581]=a+4;b=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b;d=962260+((c[240587]&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+4;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=j-a|0;l=k>>>24;c[240591]=l;c[240592]=k;m=j^b;n=k^j;o=n&m;p=o>>>24;c[240593]=p;q=k&b;r=j^-8388608;s=k|b;t=s&r;u=t|q;v=u>>>23;c[240594]=v;return}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](f+2&16777215)|0|d;k=j-a|0;l=k>>>24;c[240591]=l;c[240592]=k;m=j^b;n=k^j;o=n&m;p=o>>>24;c[240593]=p;q=k&b;r=j^-8388608;s=k|b;t=s&r;u=t|q;v=u>>>23;c[240594]=v;return}}function alb(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[240581]|0;c[240581]=a+4;b=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b;d=962260+((c[240587]&7|8)<<2)|0;f=c[d>>2]|0;g=f-4|0;c[d>>2]=g;d=g>>>16&255;h=957128+(d*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=f-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;l=k-a|0;m=l>>>24;c[240591]=m;c[240592]=l;n=k^b;o=l^k;p=o&n;q=p>>>24;c[240593]=q;r=l&b;s=k^-8388608;t=l|b;u=t&s;v=u|r;w=v>>>23;c[240594]=w;return}else{d=(fl[i&255](g&16777215)|0)<<16;k=fl[c[h>>2]&255](f+16777214&16777215)|0|d;l=k-a|0;m=l>>>24;c[240591]=m;c[240592]=l;n=k^b;o=l^k;p=o&n;q=p>>>24;c[240593]=q;r=l&b;s=k^-8388608;t=l|b;u=t&s;v=u|r;w=v>>>23;c[240594]=w;return}}function alc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|f;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=a>>>16&255;d=957128+(g*20|0)|0;i=c[d>>2]|0;if((i|0)==0){j=a+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]<<16;l=k-h|0;m=l>>>24;c[240591]=m;c[240592]=l;n=k^f;o=l^k;p=o&n;q=p>>>24;c[240593]=q;r=l&f;s=k^-8388608;t=l|f;u=t&s;v=u|r;w=v>>>23;c[240594]=w;return}else{g=(fl[i&255](a&16777215)|0)<<16;k=fl[c[d>>2]&255](a+2&16777215)|0|g;l=k-h|0;m=l>>>24;c[240591]=m;c[240592]=l;n=k^f;o=l^k;p=o&n;q=p>>>24;c[240593]=q;r=l&f;s=k^-8388608;t=l|f;u=t&s;v=u|r;w=v>>>23;c[240594]=w;return}}function ald(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[240581]|0;b=a+4|0;c[240581]=b;d=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+6;a=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=b<<16>>16}else{h=b}b=(a<<24>>24)+f+h|0;h=b>>>16&255;f=957128+(h*20|0)|0;a=c[f>>2]|0;if((a|0)==0){i=b+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;k=j-g|0;l=k>>>24;c[240591]=l;c[240592]=k;m=j^d;n=k^j;o=n&m;p=o>>>24;c[240593]=p;q=k&d;r=j^-8388608;s=k|d;t=s&r;u=t|q;v=u>>>23;c[240594]=v;return}else{h=(fl[a&255](b&16777215)|0)<<16;j=fl[c[f>>2]&255](b+2&16777215)|0|h;k=j-g|0;l=k>>>24;c[240591]=l;c[240592]=k;m=j^d;n=k^j;o=n&m;p=o>>>24;c[240593]=p;q=k&d;r=j^-8388608;s=k|d;t=s&r;u=t|q;v=u>>>23;c[240594]=v;return}}function ale(){var a=0,b=0,d=0;a=c[240587]|0;b=c[962260+((a&7)<<2)>>2]&255;d=962260+((a>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-256|b;c[240591]=b;c[240592]=b;c[240593]=0;c[240594]=0;return}function alf(){var a=0,e=0;a=c[240581]|0;c[240581]=a+2;e=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=d[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[e>>2]=c[e>>2]&-256|a;c[240591]=a;c[240592]=a;c[240593]=0;c[240594]=0;return}function alg(){var a=0,b=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){g=f<<16>>16}else{g=f}f=(b<<24>>24)+a+g|0;g=d[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[f>>2]=c[f>>2]&-256|g;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;return}function alh(){var a=0,d=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|d;c[240591]=d;c[240592]=d;c[240593]=0;c[240594]=0;return}function ali(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|f;c[240581]=a+6;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a>>>16&255;g=957128+(d*20|0)|0;i=c[g>>2]|0;if((i|0)==0){j=a+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]<<16;l=k-h|0;m=l>>>24;c[240591]=m;c[240592]=l;n=k^f;o=l^k;p=o&n;q=p>>>24;c[240593]=q;r=l&f;s=k^-8388608;t=l|f;u=t&s;v=u|r;w=v>>>23;c[240594]=w;return}else{d=(fl[i&255](a&16777215)|0)<<16;k=fl[c[g>>2]&255](a+2&16777215)|0|d;l=k-h|0;m=l>>>24;c[240591]=m;c[240592]=l;n=k^f;o=l^k;p=o&n;q=p>>>24;c[240593]=q;r=l&f;s=k^-8388608;t=l|f;u=t&s;v=u|r;w=v>>>23;c[240594]=w;return}}function alj(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[240581]|0;b=a+4|0;c[240581]=b;d=(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;c[240581]=a+8;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=a+6|0;a=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=a|f<<16;h=f&255;f=957128+(h*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=b+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16;l=k-g|0;m=l>>>24;c[240591]=m;c[240592]=l;n=k^d;o=l^k;p=o&n;q=p>>>24;c[240593]=q;r=l&d;s=k^-8388608;t=l|d;u=t&s;v=u|r;w=v>>>23;c[240594]=w;return}else{a=(fl[i&255](b&16777215)|0)<<16;k=fl[c[f>>2]&255](b+2&16777215)|0|a;l=k-g|0;m=l>>>24;c[240591]=m;c[240592]=l;n=k^d;o=l^k;p=o&n;q=p>>>24;c[240593]=q;r=l&d;s=k^-8388608;t=l|d;u=t&s;v=u|r;w=v>>>23;c[240594]=w;return}}function alk(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}a=962260+((h>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|g;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;return}function all(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-256|f;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;return}function alm(){var a=0,b=0,e=0,f=0;a=c[240580]|0;c[240580]=a+2;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|f;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;return}function aln(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-256|f;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;return}function alo(){var a=0,b=0,e=0,f=0;a=(c[240580]|0)-2|0;c[240580]=a;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|f;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;return}function alp(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[240587]|0;e=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|h;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;return}function alq(){var a=0,b=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0;j=a}else{a=fl[b&255](f&16777215)|0;i=a;j=c[240587]|0}a=962260+((j>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|i;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;return}function alr(){var a=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[957124+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[e>>2]=c[e>>2]&-256|g;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;return}function als(){var a=0,b=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a^1)|0]|0}else{h=fl[g&255](a|b<<16&16711680)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-256|h;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;return}function alt(){var b=0,d=0,e=0,f=0,g=0;b=c[240587]|0;d=c[962260+((b&7)<<2)>>2]|0;e=d&255;f=c[962260+((b>>>9&7|8)<<2)>>2]|0;c[240591]=e;c[240592]=e;c[240593]=0;c[240594]=0;b=f>>>16&255;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,e);return}}function alu(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[240587]|0}b=c[962260+((i>>>9&7|8)<<2)>>2]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;i=b>>>16&255;e=c[957132+(i*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[e&511](b&16777215,h);return}}function alv(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=e>>>16&255;b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function alw(){var b=0,e=0,f=0,g=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=b>>>16&255;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,g);return}}function alx(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=e>>>16&255;b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function aly(){var b=0,e=0,f=0,g=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=b>>>16&255;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,g);return}}function alz(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[240587]|0}e=c[962260+((j>>>9&7|8)<<2)>>2]|0;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;j=e>>>16&255;h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(e&65535^1)|0]=i&255;return}else{fj[h&511](e&16777215,i);return}}function alA(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[957124+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[240587]|0}b=c[962260+((k>>>9&7|8)<<2)>>2]|0;c[240591]=j;c[240592]=j;c[240593]=0;c[240594]=0;k=b>>>16&255;g=c[957132+(k*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(k*20|0)>>2]|0)+(b&65535^1)|0]=j&255;return}else{fj[g&511](b&16777215,j);return}}function alB(){var e=0,f=0,g=0,h=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;g=f>>>16&255;e=c[957132+(g*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[e&511](f&16777215,h);return}}function alC(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;b=f>>>16&255;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function alD(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=a[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=d&255;f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=e;c[240592]=e;c[240593]=0;c[240594]=0;g=f>>>16&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=d;return}else{fj[h&511](f&16777215,e);return}}function alE(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=a[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;b=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;d=b>>>16&255;h=c[957132+(d*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=g;return}else{fj[h&511](b&16777215,f);return}}function alF(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&255;f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=d;c[240592]=d;c[240593]=0;c[240594]=0;g=f>>>16&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[h&511](f&16777215,d);return}}function alG(){var b=0,d=0,e=0,f=0,g=0;b=c[240587]|0;d=c[962260+((b&7)<<2)>>2]|0;e=d&255;f=962260+((b>>>9&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+1;c[240591]=e;c[240592]=e;c[240593]=0;c[240594]=0;f=b>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[g&511](b&16777215,e);return}}function alH(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[240587]|0}b=962260+((i>>>9&7|8)<<2)|0;i=c[b>>2]|0;c[b>>2]=i+1;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;b=i>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(i&65535^1)|0]=h&255;return}else{fj[e&511](i&16777215,h);return}}function alI(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+1;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;e=f>>>16&255;b=c[957132+(e*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[b&511](f&16777215,g);return}}function alJ(){var b=0,e=0,f=0,g=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;b=f>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function alK(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+1;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;e=f>>>16&255;b=c[957132+(e*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[b&511](f&16777215,g);return}}function alL(){var b=0,e=0,f=0,g=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;b=f>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function alM(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[240587]|0}e=962260+((j>>>9&7|8)<<2)|0;j=c[e>>2]|0;c[e>>2]=j+1;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;e=j>>>16&255;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(j&65535^1)|0]=i&255;return}else{fj[h&511](j&16777215,i);return}}function alN(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[957124+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[240587]|0}b=962260+((k>>>9&7|8)<<2)|0;k=c[b>>2]|0;c[b>>2]=k+1;c[240591]=j;c[240592]=j;c[240593]=0;c[240594]=0;b=k>>>16&255;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(k&65535^1)|0]=j&255;return}else{fj[g&511](k&16777215,j);return}}function alO(){var e=0,f=0,g=0,h=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=g>>>16&255;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function alP(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+1;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;f=b>>>16&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=i&255;return}else{fj[h&511](b&16777215,i);return}}function alQ(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=a[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=d&255;f=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;c[240591]=e;c[240592]=e;c[240593]=0;c[240594]=0;f=g>>>16&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=d;return}else{fj[h&511](g&16777215,e);return}}function alR(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=a[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;b=d>>>16&255;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g;return}else{fj[h&511](d&16777215,f);return}}function alS(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&255;f=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;c[240591]=d;c[240592]=d;c[240593]=0;c[240594]=0;f=g>>>16&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=e&255;return}else{fj[h&511](g&16777215,d);return}}function alT(){var b=0,d=0,e=0,f=0,g=0;b=c[240587]|0;d=c[962260+((b&7)<<2)>>2]|0;e=d&255;f=962260+((b>>>9&7|8)<<2)|0;b=(c[f>>2]|0)-1|0;c[f>>2]=b;c[240591]=e;c[240592]=e;c[240593]=0;c[240594]=0;f=b>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[g&511](b&16777215,e);return}}function alU(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=c[962260+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[240587]|0}b=962260+((i>>>9&7|8)<<2)|0;i=(c[b>>2]|0)-1|0;c[b>>2]=i;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;b=i>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(i&65535^1)|0]=h&255;return}else{fj[e&511](i&16777215,h);return}}function alV(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;e=f>>>16&255;b=c[957132+(e*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[b&511](f&16777215,g);return}}function alW(){var b=0,e=0,f=0,g=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;b=f>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function alX(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;e=f>>>16&255;b=c[957132+(e*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[b&511](f&16777215,g);return}}function alY(){var b=0,e=0,f=0,g=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;b=f>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function alZ(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[240587]|0}e=962260+((j>>>9&7|8)<<2)|0;j=(c[e>>2]|0)-1|0;c[e>>2]=j;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;e=j>>>16&255;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(j&65535^1)|0]=i&255;return}else{fj[h&511](j&16777215,i);return}}function al_(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[957124+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[240587]|0}b=962260+((k>>>9&7|8)<<2)|0;k=(c[b>>2]|0)-1|0;c[b>>2]=k;c[240591]=j;c[240592]=j;c[240593]=0;c[240594]=0;b=k>>>16&255;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(k&65535^1)|0]=j&255;return}else{fj[g&511](k&16777215,j);return}}function al$(){var e=0,f=0,g=0,h=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=g>>>16&255;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function al0(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;b=(c[f>>2]|0)-1|0;c[f>>2]=b;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;f=b>>>16&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=i&255;return}else{fj[h&511](b&16777215,i);return}}function al1(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=a[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=d&255;f=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;c[240591]=e;c[240592]=e;c[240593]=0;c[240594]=0;f=g>>>16&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=d;return}else{fj[h&511](g&16777215,e);return}}function al2(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=a[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;b=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;b=d>>>16&255;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g;return}else{fj[h&511](d&16777215,f);return}}function al3(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&255;f=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;c[240591]=d;c[240592]=d;c[240593]=0;c[240594]=0;f=g>>>16&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=e&255;return}else{fj[h&511](g&16777215,d);return}}function al4(){var d=0,e=0,f=0,g=0,h=0;d=c[240587]|0;e=c[962260+((d&7)<<2)>>2]|0;f=e&255;g=c[962260+((d>>>9&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;h=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;g=h>>>16&255;d=c[957132+(g*20|0)>>2]|0;if((d|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]=e&255;return}else{fj[d&511](h&16777215,f);return}}function al5(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=f>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]|0;j=e}else{e=fl[h&255](f&16777215)|0;i=e;j=c[240587]|0}e=c[962260+((j>>>9&7|8)<<2)>>2]|0;j=c[240581]|0;c[240581]=j+2;f=(b[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0)+e|0;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;e=f>>>16&255;j=c[957132+(e*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[j&511](f&16777215,i);return}}function al6(){var e=0,f=0,g=0,h=0;e=962260+((c[240587]&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+1;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;e=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function al7(){var e=0,f=0,g=0,h=0;e=c[240580]|0;c[240580]=e+2;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}e=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;f=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+e|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[g&511](f&16777215,h);return}}function al8(){var e=0,f=0,g=0,h=0;e=962260+((c[240587]&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;e=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function al9(){var e=0,f=0,g=0,h=0;e=(c[240580]|0)-2|0;c[240580]=e;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}e=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;f=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+e|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[g&511](f&16777215,h);return}}function ama(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[240587]|0;f=c[962260+((e&7|8)<<2)>>2]|0;g=c[240581]|0;h=g+2|0;c[240581]=h;i=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=i>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){j=d[(c[957120+(f*20|0)>>2]|0)+(i&65535^1)|0]|0;k=e;l=h}else{h=fl[g&255](i&16777215)|0;j=h;k=c[240587]|0;l=c[240581]|0}h=c[962260+((k>>>9&7|8)<<2)>>2]|0;c[240581]=l+2;k=(b[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0)+h|0;c[240591]=j;c[240592]=j;c[240593]=0;c[240594]=0;h=k>>>16&255;l=c[957132+(h*20|0)>>2]|0;if((l|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(k&65535^1)|0]=j&255;return}else{fj[l&511](k&16777215,j);return}}function amb(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[240587]|0;g=c[962260+((f&7|8)<<2)>>2]|0;h=c[240581]|0;i=h+2|0;c[240581]=i;j=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=c[962260+(j>>>12<<2)>>2]|0;if((j&2048|0)==0){k=h<<16>>16}else{k=h}h=(j<<24>>24)+g+k|0;k=h>>>16&255;g=c[957124+(k*20|0)>>2]|0;if((g|0)==0){l=d[(c[957120+(k*20|0)>>2]|0)+(h&65535^1)|0]|0;m=f;n=i}else{i=fl[g&255](h&16777215)|0;l=i;m=c[240587]|0;n=c[240581]|0}i=c[962260+((m>>>9&7|8)<<2)>>2]|0;c[240581]=n+2;m=(b[(c[957120+((n>>>16&255)*20|0)>>2]|0)+(n&65535)>>1]|0)+i|0;c[240591]=l;c[240592]=l;c[240593]=0;c[240594]=0;i=m>>>16&255;n=c[957132+(i*20|0)>>2]|0;if((n|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(m&65535^1)|0]=l&255;return}else{fj[n&511](m&16777215,l);return}}function amc(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;j=f}else{f=fl[h&255](g&16777215)|0;i=f;j=c[240581]|0}f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=j+2;g=(b[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0)+f|0;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;f=g>>>16&255;j=c[957132+(f*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[j&511](g&16777215,i);return}}function amd(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[240581]|0;g=f+4|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;i=f+2|0;f=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=h&255;j=c[957124+(i*20|0)>>2]|0;if((j|0)==0){k=d[(c[957120+(i*20|0)>>2]|0)+(f^1)|0]|0;l=g}else{g=fl[j&255](f|h<<16&16711680)|0;k=g;l=c[240581]|0}g=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=l+2;h=(b[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0)+g|0;c[240591]=k;c[240592]=k;c[240593]=0;c[240594]=0;g=h>>>16&255;l=c[957132+(g*20|0)>>2]|0;if((l|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]=k&255;return}else{fj[l&511](h&16777215,k);return}}function ame(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;e=d+2|0;c[240581]=e;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;g=a[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;h=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=d+4;d=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+h|0;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;h=d>>>16&255;e=c[957132+(h*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(d&65535^1)|0]=g;return}else{fj[e&511](d&16777215,f);return}}function amf(){var d=0,f=0,g=0,h=0,i=0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;h=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){i=h<<16>>16}else{i=h}h=(g<<24>>24)+d+i|0;i=a[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535^1)|0]|0;h=i&255;g=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=d+4;d=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+g|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;g=d>>>16&255;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(d&65535^1)|0]=i;return}else{fj[f&511](d&16777215,h);return}}function amg(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;e=d+2|0;c[240581]=e;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=f&255;h=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=d+4;d=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+h|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;h=d>>>16&255;e=c[957132+(h*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(d&65535^1)|0]=f&255;return}else{fj[e&511](d&16777215,g);return}}function amh(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[240587]|0;d=c[962260+((b&7)<<2)>>2]|0;f=d&255;g=c[962260+((b>>>9&7|8)<<2)>>2]|0;b=c[240581]|0;c[240581]=b+2;h=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=b<<16>>16}else{i=b}b=(h<<24>>24)+g+i|0;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;i=b>>>16&255;g=c[957132+(i*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[g&511](b&16777215,f);return}}function ami(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=f>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]|0;j=b}else{b=fl[h&255](f&16777215)|0;i=b;j=c[240587]|0}b=c[962260+((j>>>9&7|8)<<2)>>2]|0;j=c[240581]|0;c[240581]=j+2;f=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;j=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){k=j<<16>>16}else{k=j}j=(f<<24>>24)+b+k|0;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;k=j>>>16&255;b=c[957132+(k*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(k*20|0)>>2]|0)+(j&65535^1)|0]=i&255;return}else{fj[b&511](j&16777215,i);return}}function amj(){var b=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;b=f>>>16&255;g=c[957124+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){i=g<<16>>16}else{i=g}g=(b<<24>>24)+f+i|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;i=g>>>16&255;f=c[957132+(i*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function amk(){var b=0,f=0,g=0,h=0,i=0;b=c[240580]|0;c[240580]=b+2;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}b=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){i=g<<16>>16}else{i=g}g=(f<<24>>24)+b+i|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;i=g>>>16&255;b=c[957132+(i*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[b&511](g&16777215,h);return}}function aml(){var b=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;g=c[957124+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){i=g<<16>>16}else{i=g}g=(b<<24>>24)+f+i|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;i=g>>>16&255;f=c[957132+(i*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function amm(){var b=0,f=0,g=0,h=0,i=0;b=(c[240580]|0)-2|0;c[240580]=b;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}b=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;g=c[240581]|0;c[240581]=g+2;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){i=g<<16>>16}else{i=g}g=(f<<24>>24)+b+i|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;i=g>>>16&255;b=c[957132+(i*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[b&511](g&16777215,h);return}}function amn(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[240587]|0;g=c[962260+((f&7|8)<<2)>>2]|0;h=c[240581]|0;i=h+2|0;c[240581]=i;j=(b[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0)+g|0;g=j>>>16&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){k=d[(c[957120+(g*20|0)>>2]|0)+(j&65535^1)|0]|0;l=f;m=i}else{i=fl[h&255](j&16777215)|0;k=i;l=c[240587]|0;m=c[240581]|0}i=c[962260+((l>>>9&7|8)<<2)>>2]|0;c[240581]=m+2;l=e[(c[957120+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0;m=c[962260+(l>>>12<<2)>>2]|0;if((l&2048|0)==0){n=m<<16>>16}else{n=m}m=(l<<24>>24)+i+n|0;c[240591]=k;c[240592]=k;c[240593]=0;c[240594]=0;n=m>>>16&255;i=c[957132+(n*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(n*20|0)>>2]|0)+(m&65535^1)|0]=k&255;return}else{fj[i&511](m&16777215,k);return}}function amo(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[240587]|0;f=c[962260+((b&7|8)<<2)>>2]|0;g=c[240581]|0;h=g+2|0;c[240581]=h;i=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(i>>>12<<2)>>2]|0;if((i&2048|0)==0){j=g<<16>>16}else{j=g}g=(i<<24>>24)+f+j|0;j=g>>>16&255;f=c[957124+(j*20|0)>>2]|0;if((f|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]|0;l=b;m=h}else{h=fl[f&255](g&16777215)|0;k=h;l=c[240587]|0;m=c[240581]|0}h=c[962260+((l>>>9&7|8)<<2)>>2]|0;c[240581]=m+2;l=e[(c[957120+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0;m=c[962260+(l>>>12<<2)>>2]|0;if((l&2048|0)==0){n=m<<16>>16}else{n=m}m=(l<<24>>24)+h+n|0;c[240591]=k;c[240592]=k;c[240593]=0;c[240594]=0;n=m>>>16&255;h=c[957132+(n*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(n*20|0)>>2]|0)+(m&65535^1)|0]=k&255;return}else{fj[h&511](m&16777215,k);return}}function amp(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=h>>>16&255;i=c[957124+(f*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;k=g}else{g=fl[i&255](h&16777215)|0;j=g;k=c[240581]|0}g=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=k+2;h=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;k=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){l=k<<16>>16}else{l=k}k=(h<<24>>24)+g+l|0;c[240591]=j;c[240592]=j;c[240593]=0;c[240594]=0;l=k>>>16&255;g=c[957132+(l*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(l*20|0)>>2]|0)+(k&65535^1)|0]=j&255;return}else{fj[g&511](k&16777215,j);return}}function amq(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[240581]|0;f=b+4|0;c[240581]=f;g=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;h=b+2|0;b=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=g&255;i=c[957124+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]|0;k=f}else{f=fl[i&255](b|g<<16&16711680)|0;j=f;k=c[240581]|0}f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=k+2;g=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;k=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){l=k<<16>>16}else{l=k}k=(g<<24>>24)+f+l|0;c[240591]=j;c[240592]=j;c[240593]=0;c[240594]=0;l=k>>>16&255;f=c[957132+(l*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(l*20|0)>>2]|0)+(k&65535^1)|0]=j&255;return}else{fj[f&511](k&16777215,j);return}}function amr(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;h=a[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=h&255;i=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=d+4;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){j=f<<16>>16}else{j=f}f=(d<<24>>24)+i+j|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;j=f>>>16&255;i=c[957132+(j*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f&65535^1)|0]=h;return}else{fj[i&511](f&16777215,g);return}}function ams(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[240581]|0;d=b+2|0;c[240581]=d;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+b+h|0;h=a[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=h&255;f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=b+4;b=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){i=d<<16>>16}else{i=d}d=(b<<24>>24)+f+i|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;i=d>>>16&255;f=c[957132+(i*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(d&65535^1)|0]=h;return}else{fj[f&511](d&16777215,g);return}}function amt(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;h=g&255;i=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=d+4;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){j=f<<16>>16}else{j=f}f=(d<<24>>24)+i+j|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;j=f>>>16&255;i=c[957132+(j*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[i&511](f&16777215,h);return}}function amu(){var d=0,e=0,f=0,g=0,h=0;d=c[962260+((c[240587]&7)<<2)>>2]|0;e=d&255;f=c[240581]|0;c[240581]=f+2;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=e;c[240592]=e;c[240593]=0;c[240594]=0;f=g>>>16&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=d&255;return}else{fj[h&511](g&16777215,e);return}}function amv(){var e=0,f=0,g=0,h=0;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}e=c[240581]|0;c[240581]=e+2;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;e=g>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function amw(){var e=0,f=0,g=0,h=0;e=962260+((c[240587]&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+1;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[240581]|0;c[240581]=f+2;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=g>>>16&255;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function amx(){var e=0,f=0,g=0,h=0;e=c[240580]|0;c[240580]=e+2;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}e=c[240581]|0;c[240581]=e+2;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;e=g>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function amy(){var e=0,f=0,g=0,h=0;e=962260+((c[240587]&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[240581]|0;c[240581]=f+2;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=g>>>16&255;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function amz(){var e=0,f=0,g=0,h=0;e=(c[240580]|0)-2|0;c[240580]=e;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}e=c[240581]|0;c[240581]=e+2;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;e=g>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function amA(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=h>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(h&65535^1)|0]|0;j=g}else{g=fl[f&255](h&16777215)|0;i=g;j=c[240581]|0}c[240581]=j+2;g=b[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;j=g>>>16&255;h=c[957132+(j*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function amB(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=c[240581]|0;h=g+2|0;c[240581]=h;i=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[962260+(i>>>12<<2)>>2]|0;if((i&2048|0)==0){j=g<<16>>16}else{j=g}g=(i<<24>>24)+f+j|0;j=g>>>16&255;f=c[957124+(j*20|0)>>2]|0;if((f|0)==0){k=d[(c[957120+(j*20|0)>>2]|0)+(g&65535^1)|0]|0;l=h}else{h=fl[f&255](g&16777215)|0;k=h;l=c[240581]|0}c[240581]=l+2;h=b[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;c[240591]=k;c[240592]=k;c[240593]=0;c[240594]=0;l=h>>>16&255;g=c[957132+(l*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(l*20|0)>>2]|0)+(h&65535^1)|0]=k&255;return}else{fj[g&511](h&16777215,k);return}}function amC(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240581]|0;f=e+2|0;c[240581]=f;g=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=g>>>16&255;h=c[957124+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;j=f}else{f=fl[h&255](g&16777215)|0;i=f;j=c[240581]|0}c[240581]=j+2;f=b[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;j=f>>>16&255;g=c[957132+(j*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(j*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[g&511](f&16777215,i);return}}function amD(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[240581]|0;g=f+4|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;i=f+2|0;f=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=h&255;j=c[957124+(i*20|0)>>2]|0;if((j|0)==0){k=d[(c[957120+(i*20|0)>>2]|0)+(f^1)|0]|0;l=g}else{g=fl[j&255](f|h<<16&16711680)|0;k=g;l=c[240581]|0}c[240581]=l+2;g=b[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;c[240591]=k;c[240592]=k;c[240593]=0;c[240594]=0;l=g>>>16&255;h=c[957132+(l*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(l*20|0)>>2]|0)+(g&65535^1)|0]=k&255;return}else{fj[h&511](g&16777215,k);return}}function amE(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;e=d+2|0;c[240581]=e;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;g=a[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;c[240581]=d+4;d=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;e=d>>>16&255;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=g;return}else{fj[h&511](d&16777215,f);return}}function amF(){var d=0,f=0,g=0,h=0,i=0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;h=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){i=h<<16>>16}else{i=h}h=(g<<24>>24)+d+i|0;i=a[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535^1)|0]|0;h=i&255;c[240581]=d+4;d=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=d>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(d&65535^1)|0]=i;return}else{fj[g&511](d&16777215,h);return}}function amG(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;e=d+2|0;c[240581]=e;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=f&255;c[240581]=d+4;d=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;e=d>>>16&255;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=f&255;return}else{fj[h&511](d&16777215,g);return}}function amH(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[962260+((c[240587]&7)<<2)>>2]|0;d=b&255;f=c[240581]|0;c[240581]=f+4;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;c[240591]=d;c[240592]=d;c[240593]=0;c[240594]=0;h=g&255;i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(f^1)|0]=b&255;return}else{fj[i&511](f|g<<16&16711680,d);return}}function amI(){var b=0,f=0,g=0,h=0,i=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}b=c[240581]|0;c[240581]=b+4;g=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=g&255;i=c[957132+(f*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b^1)|0]=h&255;return}else{fj[i&511](b|g<<16&16711680,h);return}}function amJ(){var b=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;b=f>>>16&255;g=c[957124+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[240581]|0;c[240581]=f+4;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;b=f+2|0;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;b=g&255;i=c[957132+(b*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f^1)|0]=h&255;return}else{fj[i&511](f|g<<16&16711680,h);return}}function amK(){var b=0,f=0,g=0,h=0,i=0;b=c[240580]|0;c[240580]=b+2;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}b=c[240581]|0;c[240581]=b+4;g=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=g&255;i=c[957132+(f*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b^1)|0]=h&255;return}else{fj[i&511](b|g<<16&16711680,h);return}}function amL(){var b=0,f=0,g=0,h=0,i=0;b=962260+((c[240587]&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;g=c[957124+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[240581]|0;c[240581]=f+4;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;b=f+2|0;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;b=g&255;i=c[957132+(b*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f^1)|0]=h&255;return}else{fj[i&511](f|g<<16&16711680,h);return}}function amM(){var b=0,f=0,g=0,h=0,i=0;b=(c[240580]|0)-2|0;c[240580]=b;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}b=c[240581]|0;c[240581]=b+4;g=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=g&255;i=c[957132+(f*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b^1)|0]=h&255;return}else{fj[i&511](b|g<<16&16711680,h);return}}function amN(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=c[240581]|0;h=g+2|0;c[240581]=h;i=(b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=i>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){j=d[(c[957120+(f*20|0)>>2]|0)+(i&65535^1)|0]|0;k=h}else{h=fl[g&255](i&16777215)|0;j=h;k=c[240581]|0}c[240581]=k+4;h=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;i=k+2|0;k=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;c[240591]=j;c[240592]=j;c[240593]=0;c[240594]=0;i=h&255;g=c[957132+(i*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(k^1)|0]=j&255;return}else{fj[g&511](k|h<<16&16711680,j);return}}function amO(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=f<<16>>16}else{i=f}f=(h<<24>>24)+b+i|0;i=f>>>16&255;b=c[957124+(i*20|0)>>2]|0;if((b|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(f&65535^1)|0]|0;k=g}else{g=fl[b&255](f&16777215)|0;j=g;k=c[240581]|0}c[240581]=k+4;g=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;f=k+2|0;k=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=j;c[240592]=j;c[240593]=0;c[240594]=0;f=g&255;b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(k^1)|0]=j&255;return}else{fj[b&511](k|g<<16&16711680,j);return}}function amP(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=h>>>16&255;i=c[957124+(f*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;k=g}else{g=fl[i&255](h&16777215)|0;j=g;k=c[240581]|0}c[240581]=k+4;g=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;h=k+2|0;k=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;c[240591]=j;c[240592]=j;c[240593]=0;c[240594]=0;h=g&255;i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(k^1)|0]=j&255;return}else{fj[i&511](k|g<<16&16711680,j);return}}function amQ(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240581]|0;f=b+4|0;c[240581]=f;g=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;h=b+2|0;b=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=g&255;i=c[957124+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]|0;k=f}else{f=fl[i&255](b|g<<16&16711680)|0;j=f;k=c[240581]|0}c[240581]=k+4;f=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;g=k+2|0;k=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;c[240591]=j;c[240592]=j;c[240593]=0;c[240594]=0;g=f&255;b=c[957132+(g*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(k^1)|0]=j&255;return}else{fj[b&511](k|f<<16&16711680,j);return}}function amR(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;h=a[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=h&255;c[240581]=d+6;i=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d+4|0;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=i&255;j=c[957132+(f*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(d^1)|0]=h;return}else{fj[j&511](d|i<<16&16711680,g);return}}function amS(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[240581]|0;d=b+2|0;c[240581]=d;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+b+h|0;h=a[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=h&255;c[240581]=b+6;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=b+4|0;b=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;d=f&255;i=c[957132+(d*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b^1)|0]=h;return}else{fj[i&511](b|f<<16&16711680,g);return}}function amT(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;h=g&255;c[240581]=d+6;i=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d+4|0;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=i&255;j=c[957132+(f*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(d^1)|0]=g&255;return}else{fj[j&511](d|i<<16&16711680,h);return}}function amU(){var b=0,d=0,e=0,f=0,g=0;b=c[962260+((c[240587]&7)<<2)>>2]|0;d=b&255;e=c[240580]|0;c[240580]=e+2;c[240591]=d;c[240592]=d;c[240593]=0;c[240594]=0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[g&511](e&16777215,d);return}}function amV(){var b=0,e=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[240580]|0;c[240580]=b+2;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=b>>>16&255;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,g);return}}function amW(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[240580]|0;c[240580]=e+2;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=e>>>16&255;b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function amX(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240580]|0;e=b+2|0;c[240580]=e;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0;i=e}else{e=fl[g&255](b&16777215)|0;h=e;i=c[240580]|0}c[240580]=i+2;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;e=i>>>16&255;b=c[957132+(e*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(i&65535^1)|0]=h&255;return}else{fj[b&511](i&16777215,h);return}}function amY(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[240580]|0;c[240580]=e+2;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=e>>>16&255;b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function amZ(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[240580]|0}c[240580]=h+2;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;e=h>>>16&255;b=c[957132+(e*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(h&65535^1)|0]=g&255;return}else{fj[b&511](h&16777215,g);return}}function am_(){var e=0,f=0,g=0,h=0;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}g=c[240580]|0;c[240580]=g+2;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=g>>>16&255;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function am$(){var b=0,f=0,g=0,h=0,i=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}f=c[240580]|0;c[240580]=f+2;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;b=f>>>16&255;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function am0(){var e=0,f=0,g=0,h=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[240580]|0;c[240580]=f+2;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;g=f>>>16&255;e=c[957132+(g*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[e&511](f&16777215,h);return}}function am1(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=c[240580]|0;c[240580]=f+2;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;b=f>>>16&255;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function am2(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=a[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=d&255;f=c[240580]|0;c[240580]=f+2;c[240591]=e;c[240592]=e;c[240593]=0;c[240594]=0;g=f>>>16&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=d;return}else{fj[h&511](f&16777215,e);return}}function am3(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=a[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;b=c[240580]|0;c[240580]=b+2;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;d=b>>>16&255;h=c[957132+(d*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=g;return}else{fj[h&511](b&16777215,f);return}}function am4(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&255;f=c[240580]|0;c[240580]=f+2;c[240591]=d;c[240592]=d;c[240593]=0;c[240594]=0;g=f>>>16&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[h&511](f&16777215,d);return}}function am5(){var a=0,b=0;a=c[240587]|0;b=c[962260+((a&7)<<2)>>2]|0;c[962260+((a>>>9&7)<<2)>>2]=b;c[240591]=b>>>24;c[240592]=b;c[240593]=0;c[240594]=0;return}function am6(){var a=0,b=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;c[962260+((a>>>9&7)<<2)>>2]=b;c[240591]=b>>>24;c[240592]=b;c[240593]=0;c[240594]=0;return}function am7(){var b=0,d=0,e=0,f=0,g=0;b=c[962260+((c[240587]&7)<<2)>>2]|0;d=b&255;e=(c[240580]|0)-2|0;c[240580]=e;c[240591]=d;c[240592]=d;c[240593]=0;c[240594]=0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[g&511](e&16777215,d);return}}function am8(){var b=0,e=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=(c[240580]|0)-2|0;c[240580]=b;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=b>>>16&255;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,g);return}}function am9(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[240580]|0)-2|0;c[240580]=e;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=e>>>16&255;b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function ana(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240580]|0;e=b+2|0;c[240580]=e;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0;i=e}else{e=fl[g&255](b&16777215)|0;h=e;i=c[240580]|0}e=i-2|0;c[240580]=e;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;i=e>>>16&255;b=c[957132+(i*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[b&511](e&16777215,h);return}}function anb(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[240580]|0)-2|0;c[240580]=e;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;f=e>>>16&255;b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function anc(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[240580]|0}e=h-2|0;c[240580]=e;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;h=e>>>16&255;b=c[957132+(h*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function and(){var e=0,f=0,g=0,h=0;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}g=(c[240580]|0)-2|0;c[240580]=g;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;f=g>>>16&255;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function ane(){var b=0,f=0,g=0,h=0,i=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}f=(c[240580]|0)-2|0;c[240580]=f;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;b=f>>>16&255;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function anf(){var e=0,f=0,g=0,h=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=(c[240580]|0)-2|0;c[240580]=f;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;g=f>>>16&255;e=c[957132+(g*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[e&511](f&16777215,h);return}}function ang(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957124+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=(c[240580]|0)-2|0;c[240580]=f;c[240591]=i;c[240592]=i;c[240593]=0;c[240594]=0;b=f>>>16&255;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function anh(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=a[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=d&255;f=(c[240580]|0)-2|0;c[240580]=f;c[240591]=e;c[240592]=e;c[240593]=0;c[240594]=0;g=f>>>16&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=d;return}else{fj[h&511](f&16777215,e);return}}function ani(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=a[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;b=(c[240580]|0)-2|0;c[240580]=b;c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;d=b>>>16&255;h=c[957132+(d*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=g;return}else{fj[h&511](b&16777215,f);return}}function anj(){var d=0,e=0,f=0,g=0,h=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&255;f=(c[240580]|0)-2|0;c[240580]=f;c[240591]=d;c[240592]=d;c[240593]=0;c[240594]=0;g=f>>>16&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[h&511](f&16777215,d);return}}function ank(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[240587]|0}c[962260+((j>>>9&7)<<2)>>2]=i;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;return}function anl(){var a=0,b=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=b>>>16&255;d=957128+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a}c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]=h;c[240591]=h>>>24;c[240592]=h;c[240593]=0;c[240594]=0;return}function anm(){var a=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;f=d+2|0;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|a<<16;c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]=d;c[240591]=a>>>8;c[240592]=d;c[240593]=0;c[240594]=0;return}function ann(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;a=d+2|0;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|f<<16;c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]=d;c[240591]=f>>>8;c[240592]=d;c[240593]=0;c[240594]=0;return}function ano(){var a=0,b=0,d=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b<<16;c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]=a;c[240591]=b>>>8;c[240592]=a;c[240593]=0;c[240594]=0;return}function anp(){var a=0;a=c[240587]|0;c[962260+((a>>>9&7|8)<<2)>>2]=c[962260+((a&7)<<2)>>2];return}function anq(){var a=0;a=c[240587]|0;c[962260+((a>>>9&7|8)<<2)>>2]=c[962260+((a&7|8)<<2)>>2];return}function anr(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a}c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]=i;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;return}function ans(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]<<16;k=a;l=k>>>9;m=l&7;n=962260+(m<<2)|0;c[n>>2]=j;o=j>>>24;c[240591]=o;c[240592]=j;c[240593]=0;c[240594]=0;return}else{a=(fl[h&255](g&16777215)|0)<<16;h=fl[c[f>>2]&255](g+2&16777215)|0|a;j=h;k=c[240587]|0;l=k>>>9;m=l&7;n=962260+(m<<2)|0;c[n>>2]=j;o=j>>>24;c[240591]=o;c[240592]=j;c[240593]=0;c[240594]=0;return}}function ant(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=957128+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=962260+(l<<2)|0;c[m>>2]=i;n=i>>>24;c[240591]=n;c[240592]=i;c[240593]=0;c[240594]=0;return}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[240587]|0;k=j>>>9;l=k&7;m=962260+(l<<2)|0;c[m>>2]=i;n=i>>>24;c[240591]=n;c[240592]=i;c[240593]=0;c[240594]=0;return}}function anu(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]=i;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;return}function anv(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;f=b&255;b=957128+(f*20|0)|0;g=c[b>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+a>>1]|0)<<16;j=c[240587]|0;k=j>>>9;l=k&7;m=962260+(l<<2)|0;c[m>>2]=i;n=i>>>24;c[240591]=n;c[240592]=i;c[240593]=0;c[240594]=0;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[b>>2]&255](d+2&16777215)|0|a;j=c[240587]|0;k=j>>>9;l=k&7;m=962260+(l<<2)|0;c[m>>2]=i;n=i>>>24;c[240591]=n;c[240592]=i;c[240593]=0;c[240594]=0;return}}function anw(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[240587]|0;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}}function anx(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=b>>>16&255;d=957128+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;i=c[240587]|0;j=i>>>9;k=j&7;l=k|8;m=962260+(l<<2)|0;c[m>>2]=h;return}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a;i=c[240587]|0;j=i>>>9;k=j&7;l=k|8;m=962260+(l<<2)|0;c[m>>2]=h;return}}function any(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=c[240587]|0;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a;j=c[240587]|0;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}}function anz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]<<16;k=a;l=k>>>9;m=l&7;n=m|8;o=962260+(n<<2)|0;c[o>>2]=j;return}else{a=(fl[h&255](g&16777215)|0)<<16;h=fl[c[f>>2]&255](g+2&16777215)|0|a;j=h;k=c[240587]|0;l=k>>>9;m=l&7;n=m|8;o=962260+(n<<2)|0;c[o>>2]=j;return}}function anA(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=957128+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[240587]|0;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}}function anB(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16;j=c[240587]|0;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a;j=c[240587]|0;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}}function anC(){var a=0,d=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=d+2|0;c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]<<16;return}function anD(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=d+2|0;c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;return}function anE(){var a=0,b=0;a=c[240581]|0;c[240581]=a+4;b=a+2|0;c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;return}function anF(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;f=b&255;b=957128+(f*20|0)|0;g=c[b>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+a>>1]|0)<<16;j=c[240587]|0;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[b>>2]&255](d+2&16777215)|0|a;j=c[240587]|0;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}}function anG(){var a=0,d=0,e=0,f=0;a=c[240587]|0;d=c[962260+((a&7)<<2)>>2]|0;e=c[962260+((a>>>9&7|8)<<2)>>2]|0;c[240591]=d>>>24;c[240592]=d;c[240593]=0;c[240594]=0;a=e>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(e&65535)>>1]=d>>>16&65535}else{fj[f&511](e&16777215,d>>>16)}f=e+2|0;e=f>>>16&255;a=c[957136+(e*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[a&511](f&16777215,d&65535);return}}function anH(){var a=0,d=0,e=0,f=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;e=c[962260+((a>>>9&7|8)<<2)>>2]|0;c[240591]=d>>>24;c[240592]=d;c[240593]=0;c[240594]=0;a=e>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(e&65535)>>1]=d>>>16&65535}else{fj[f&511](e&16777215,d>>>16)}f=e+2|0;e=f>>>16&255;a=c[957136+(e*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[a&511](f&16777215,d&65535);return}}function anI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[240587]|0}h=c[962260+((k>>>9&7|8)<<2)>>2]|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;k=h>>>16&255;a=c[957136+(k*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=j>>>16&65535}else{fj[a&511](h&16777215,j>>>16)}a=h+2|0;h=a>>>16&255;k=c[957136+(h*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[k&511](a&16777215,j&65535);return}}function anJ(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[f&511](a&16777215,i>>>16)}f=a+2|0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[d&511](f&16777215,i&65535);return}}function anK(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;d=a>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[g&511](a&16777215,j>>>16)}g=a+2|0;a=g>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[d&511](g&16777215,j&65535);return}}function anL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]<<16;k=a}else{a=(fl[h&255](g&16777215)|0)<<16;h=fl[c[f>>2]&255](g+2&16777215)|0|a;j=h;k=c[240587]|0}h=c[962260+((k>>>9&7|8)<<2)>>2]|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;k=h>>>16&255;a=c[957136+(k*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=j>>>16&65535}else{fj[a&511](h&16777215,j>>>16)}a=h+2|0;h=a>>>16&255;k=c[957136+(h*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[k&511](a&16777215,j&65535);return}}function anM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=f>>>16&255;d=957128+(h*20|0)|0;g=c[d>>2]|0;if((g|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=a}else{a=(fl[g&255](f&16777215)|0)<<16;g=fl[c[d>>2]&255](f+2&16777215)|0|a;j=g;k=c[240587]|0}g=c[962260+((k>>>9&7|8)<<2)>>2]|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;k=g>>>16&255;a=c[957136+(k*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[a&511](g&16777215,j>>>16)}a=g+2|0;g=a>>>16&255;k=c[957136+(g*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[k&511](a&16777215,j&65535);return}}function anN(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[f&511](a&16777215,i>>>16)}f=a+2|0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[d&511](f&16777215,i&65535);return}}function anO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=957128+(g*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;f=a>>>16&255;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[d&511](a&16777215,j>>>16)}d=a+2|0;a=d>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[f&511](d&16777215,j&65535);return}}function anP(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;e=a&65535;f=d+2|0;d=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&65535;g=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=e>>>8;c[240592]=f|e<<16;c[240593]=0;c[240594]=0;h=g>>>16&255;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(g&65535)>>1]=a}else{fj[i&511](g&16777215,e)}e=g+2|0;g=e>>>16&255;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(e&65535)>>1]=d;return}else{fj[i&511](e&16777215,f);return}}function anQ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;a=g&65535;d=f+2|0;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f&65535;h=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=a>>>8;c[240592]=d|a<<16;c[240593]=0;c[240594]=0;i=h>>>16&255;j=c[957136+(i*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(h&65535)>>1]=g}else{fj[j&511](h&16777215,a)}a=h+2|0;h=a>>>16&255;j=c[957136+(h*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]=f;return}else{fj[j&511](a&16777215,d);return}}function anR(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+4;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;e=d&65535;f=a+2|0;a=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a&65535;g=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=e>>>8;c[240592]=f|e<<16;c[240593]=0;c[240594]=0;h=g>>>16&255;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(g&65535)>>1]=d}else{fj[i&511](g&16777215,e)}e=g+2|0;g=e>>>16&255;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(e&65535)>>1]=a;return}else{fj[i&511](e&16777215,f);return}}function anS(){var a=0,d=0,e=0,f=0;a=c[240587]|0;d=c[962260+((a&7)<<2)>>2]|0;e=962260+((a>>>9&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+4;c[240591]=d>>>24;c[240592]=d;c[240593]=0;c[240594]=0;e=a>>>16&255;f=c[957136+(e*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535}else{fj[f&511](a&16777215,d>>>16)}f=a+2|0;a=f>>>16&255;e=c[957136+(a*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[e&511](f&16777215,d&65535);return}}function anT(){var a=0,d=0,e=0,f=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;e=962260+((a>>>9&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+4;c[240591]=d>>>24;c[240592]=d;c[240593]=0;c[240594]=0;e=a>>>16&255;f=c[957136+(e*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535}else{fj[f&511](a&16777215,d>>>16)}f=a+2|0;a=f>>>16&255;e=c[957136+(a*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[e&511](f&16777215,d&65535);return}}function anU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[240587]|0}h=962260+((k>>>9&7|8)<<2)|0;k=c[h>>2]|0;c[h>>2]=k+4;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;h=k>>>16&255;a=c[957136+(h*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(k&65535)>>1]=j>>>16&65535}else{fj[a&511](k&16777215,j>>>16)}a=k+2|0;k=a>>>16&255;h=c[957136+(k*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[h&511](a&16777215,j&65535);return}}function anV(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;a=d>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[f&511](d&16777215,i>>>16)}f=d+2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[a&511](f&16777215,i&65535);return}}function anW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;a=d>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[g&511](d&16777215,j>>>16)}g=d+2|0;d=g>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[a&511](g&16777215,j&65535);return}}function anX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]<<16;k=a}else{a=(fl[h&255](g&16777215)|0)<<16;h=fl[c[f>>2]&255](g+2&16777215)|0|a;j=h;k=c[240587]|0}h=962260+((k>>>9&7|8)<<2)|0;k=c[h>>2]|0;c[h>>2]=k+4;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;h=k>>>16&255;a=c[957136+(h*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(k&65535)>>1]=j>>>16&65535}else{fj[a&511](k&16777215,j>>>16)}a=k+2|0;k=a>>>16&255;h=c[957136+(k*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[h&511](a&16777215,j&65535);return}}function anY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=f>>>16&255;d=957128+(h*20|0)|0;g=c[d>>2]|0;if((g|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=a}else{a=(fl[g&255](f&16777215)|0)<<16;g=fl[c[d>>2]&255](f+2&16777215)|0|a;j=g;k=c[240587]|0}g=962260+((k>>>9&7|8)<<2)|0;k=c[g>>2]|0;c[g>>2]=k+4;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;g=k>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(k&65535)>>1]=j>>>16&65535}else{fj[a&511](k&16777215,j>>>16)}a=k+2|0;k=a>>>16&255;g=c[957136+(k*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[g&511](a&16777215,j&65535);return}}function anZ(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;a=d>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[f&511](d&16777215,i>>>16)}f=d+2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[a&511](f&16777215,i&65535);return}}function an_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=957128+(g*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+4;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[d&511](f&16777215,j>>>16)}d=f+2|0;f=d>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[a&511](d&16777215,j&65535);return}}function an$(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;e=a&65535;f=d+2|0;d=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&65535;g=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;h=c[g>>2]|0;c[g>>2]=h+4;c[240591]=e>>>8;c[240592]=f|e<<16;c[240593]=0;c[240594]=0;g=h>>>16&255;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(h&65535)>>1]=a}else{fj[i&511](h&16777215,e)}e=h+2|0;h=e>>>16&255;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(e&65535)>>1]=d;return}else{fj[i&511](e&16777215,f);return}}function an0(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;a=g&65535;d=f+2|0;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f&65535;h=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;i=c[h>>2]|0;c[h>>2]=i+4;c[240591]=a>>>8;c[240592]=d|a<<16;c[240593]=0;c[240594]=0;h=i>>>16&255;j=c[957136+(h*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(i&65535)>>1]=g}else{fj[j&511](i&16777215,a)}a=i+2|0;i=a>>>16&255;j=c[957136+(i*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(a&65535)>>1]=f;return}else{fj[j&511](a&16777215,d);return}}function an1(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+4;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;e=d&65535;f=a+2|0;a=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a&65535;g=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;h=c[g>>2]|0;c[g>>2]=h+4;c[240591]=e>>>8;c[240592]=f|e<<16;c[240593]=0;c[240594]=0;g=h>>>16&255;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(h&65535)>>1]=d}else{fj[i&511](h&16777215,e)}e=h+2|0;h=e>>>16&255;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(e&65535)>>1]=a;return}else{fj[i&511](e&16777215,f);return}}function an2(){var a=0,d=0,e=0,f=0,g=0;a=c[240587]|0;d=c[962260+((a&7)<<2)>>2]|0;e=962260+((a>>>9&7|8)<<2)|0;a=c[e>>2]|0;f=a-4|0;c[e>>2]=f;c[240591]=d>>>24;c[240592]=d;c[240593]=0;c[240594]=0;e=a-2|0;a=e>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(e&65535)>>1]=d&65535}else{fj[g&511](e&16777215,d&65535)}e=d>>>16;d=f>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=e&65535;return}else{fj[g&511](f&16777215,e);return}}
function Kz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=(f&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=f+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](f&16777215)|0)<<16;k=fl[c[j>>2]&255](f+2&16777215)|0|h;m=k;n=c[291688]|0}k=m-a|0;c[291677]=k>>>24;c[291678]=k;a=((k|d)&(m^-8388608)|k&d)>>>23;c[291680]=a;c[291676]=a;c[291679]=((k^m)&(m^d))>>>24;if(g&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}n=f+2|0;f=n>>>16&255;i=c[1161480+(f*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[i&511](n&16777215,k&65535);return}}function KA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=1166604+((c[291673]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+4;f=(g&1|0)!=0;h=c[291688]|0;if(f&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=g>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=g+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](g&16777215)|0)<<16;k=fl[c[j>>2]&255](g+2&16777215)|0|h;m=k;n=c[291688]|0}k=m-a|0;c[291677]=k>>>24;c[291678]=k;a=((k|d)&(m^-8388608)|k&d)>>>23;c[291680]=a;c[291676]=a;c[291679]=((k^m)&(m^d))>>>24;if(f&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}n=g+2|0;g=n>>>16&255;i=c[1161480+(g*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[i&511](n&16777215,k&65535);return}}function KB(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;c[291667]=a+4;d=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=1166604+((c[291673]&7|8)<<2)|0;g=c[f>>2]|0;h=g-4|0;c[f>>2]=h;f=(h&1|0)!=0;i=c[291688]|0;if(f&(i|0)!=0){j=c[291675]|1;c[291699]=h;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=h>>>16&255;k=1161472+(j*20|0)|0;l=c[k>>2]|0;if((l|0)==0){m=g-2|0;n=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+(h&65535)>>1]|0)<<16;o=i}else{i=(fl[l&255](h&16777215)|0)<<16;l=fl[c[k>>2]&255](g+16777214&16777215)|0|i;n=l;o=c[291688]|0}l=n-a|0;c[291677]=l>>>24;c[291678]=l;a=((l|d)&(n^-8388608)|l&d)>>>23;c[291680]=a;c[291676]=a;c[291679]=((l^n)&(n^d))>>>24;if(f&(o|0)!=0){o=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=o;eJ(1166756,1)}o=c[1161480+(j*20|0)>>2]|0;if((o|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+(h&65535)>>1]=l>>>16&65535}else{fj[o&511](h&16777215,l>>>16)}h=g-2|0;g=h>>>16&255;o=c[1161480+(g*20|0)>>2]|0;if((o|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(h&65535)>>1]=l&65535;return}else{fj[o&511](h&16777215,l&65535);return}}function KC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;g=a+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|f;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=(a&1|0)!=0;d=c[291688]|0;if(g&(d|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=a+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|e[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]<<16;n=d}else{d=(fl[k&255](a&16777215)|0)<<16;k=fl[c[j>>2]&255](a+2&16777215)|0|d;m=k;n=c[291688]|0}k=m-h|0;c[291677]=k>>>24;c[291678]=k;h=((k|f)&(m^-8388608)|k&f)>>>23;c[291680]=h;c[291676]=h;c[291679]=((k^m)&(m^f))>>>24;if(g&(n|0)!=0){n=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=k>>>16&65535}else{fj[n&511](a&16777215,k>>>16)}n=a+2|0;a=n>>>16&255;i=c[1161480+(a*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[i&511](n&16777215,k&65535);return}}function KD(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;g=a+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|f;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=d<<16>>16}else{i=d}d=(a<<24>>24)+g+i|0;i=(d&1|0)!=0;g=c[291688]|0;if(i&(g|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;j=1161472+(a*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;n=g}else{g=(fl[k&255](d&16777215)|0)<<16;k=fl[c[j>>2]&255](d+2&16777215)|0|g;m=k;n=c[291688]|0}k=m-h|0;c[291677]=k>>>24;c[291678]=k;h=((k|f)&(m^-8388608)|k&f)>>>23;c[291680]=h;c[291676]=h;c[291679]=((k^m)&(m^f))>>>24;if(i&(n|0)!=0){n=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(a*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=k>>>16&65535}else{fj[n&511](d&16777215,k>>>16)}n=d+2|0;d=n>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[a&511](n&16777215,k&65535);return}}function KE(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+((c[291673]&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=d&255;f=c[a>>2]|0;g=f&255;h=b+g|0;c[291677]=h;c[291679]=(h^b)&(h^g);c[291680]=h;c[291676]=h;h=d+f&255;c[291678]=h;c[a>>2]=c[a>>2]&-256|h;return}function KF(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;h=g>>>16&255;i=c[1161468+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(h*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[i&255](g&16777215)|0}i=j+b|0;c[291677]=i;c[291679]=(i^b)&(i^j);c[291680]=i;c[291676]=i;i=j+f|0;f=i&255;c[291678]=f;j=c[1161476+(h*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[j&511](g&16777215,f);return}}function KG(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=1166604+((c[291673]&7|8)<<2)|0;h=c[g>>2]|0;c[g>>2]=h+1;g=h>>>16&255;i=c[1161468+(g*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]|0}else{j=fl[i&255](h&16777215)|0}i=j+b|0;c[291677]=i;c[291679]=(i^b)&(i^j);c[291680]=i;c[291676]=i;i=j+f|0;f=i&255;c[291678]=f;j=c[1161476+(g*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]=i&255;return}else{fj[j&511](h&16777215,f);return}}function KH(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=c[291666]|0;c[291666]=g+2;h=g>>>16&255;i=c[1161468+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(h*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[i&255](g&16777215)|0}i=j+b|0;c[291677]=i;c[291679]=(i^b)&(i^j);c[291680]=i;c[291676]=i;i=j+f|0;f=i&255;c[291678]=f;j=c[1161476+(h*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[j&511](g&16777215,f);return}}function KI(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=1166604+((c[291673]&7|8)<<2)|0;h=(c[g>>2]|0)-1|0;c[g>>2]=h;g=h>>>16&255;i=c[1161468+(g*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]|0}else{j=fl[i&255](h&16777215)|0}i=j+b|0;c[291677]=i;c[291679]=(i^b)&(i^j);c[291680]=i;c[291676]=i;i=j+f|0;f=i&255;c[291678]=f;j=c[1161476+(g*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]=i&255;return}else{fj[j&511](h&16777215,f);return}}function KJ(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[291667]|0;c[291667]=b+2;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=f&255;g=(c[291666]|0)-2|0;c[291666]=g;h=g>>>16&255;i=c[1161468+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(h*20|0)>>2]|0)+(g&65535^1)|0]|0}else{j=fl[i&255](g&16777215)|0}i=j+b|0;c[291677]=i;c[291679]=(i^b)&(i^j);c[291680]=i;c[291676]=i;i=j+f|0;f=i&255;c[291678]=f;j=c[1161476+(h*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[j&511](g&16777215,f);return}}function KK(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;i=h&255;j=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=f+4;f=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+j|0;j=f>>>16&255;g=c[1161468+(j*20|0)>>2]|0;if((g|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(f&65535^1)|0]|0}else{k=fl[g&255](f&16777215)|0}g=k+i|0;c[291677]=g;c[291679]=(g^i)&(g^k);c[291680]=g;c[291676]=g;g=k+h|0;h=g&255;c[291678]=h;k=c[1161476+(j*20|0)>>2]|0;if((k|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[k&511](f&16777215,h);return}}function KL(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291667]|0;f=b+2|0;c[291667]=f;g=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;h=g&255;i=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=b+4;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){j=f<<16>>16}else{j=f}f=(b<<24>>24)+i+j|0;j=f>>>16&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(f&65535^1)|0]|0}else{k=fl[i&255](f&16777215)|0}i=k+h|0;c[291677]=i;c[291679]=(i^h)&(i^k);c[291680]=i;c[291676]=i;i=k+g|0;g=i&255;c[291678]=g;k=c[1161476+(j*20|0)>>2]|0;if((k|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[k&511](f&16777215,g);return}}function KM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;g=a+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|f;c[291667]=a+6;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(a&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=a+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|e[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]<<16;n=g}else{g=(fl[k&255](a&16777215)|0)<<16;k=fl[c[j>>2]&255](a+2&16777215)|0|g;m=k;n=c[291688]|0}k=m-h|0;c[291677]=k>>>24;c[291678]=k;h=((k|f)&(m^-8388608)|k&f)>>>23;c[291680]=h;c[291676]=h;c[291679]=((k^m)&(m^f))>>>24;if(d&(n|0)!=0){n=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=k>>>16&65535}else{fj[n&511](a&16777215,k>>>16)}n=a+2|0;a=n>>>16&255;i=c[1161480+(a*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[i&511](n&16777215,k&65535);return}}function KN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;g=a+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|f;c[291667]=a+8;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;i=(a&1|0)!=0;j=c[291688]|0;if(i&(j|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=k;eJ(1166756,1)}k=g&255;g=1161472+(k*20|0)|0;l=c[g>>2]|0;if((l|0)==0){m=d+2|0;n=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0|(e[(c[1161464+(k*20|0)>>2]|0)+a>>1]|0)<<16;o=j}else{j=(fl[l&255](d&16777215)|0)<<16;l=fl[c[g>>2]&255](d+2&16777215)|0|j;n=l;o=c[291688]|0}l=n-h|0;c[291677]=l>>>24;c[291678]=l;h=((l|f)&(n^-8388608)|l&f)>>>23;c[291680]=h;c[291676]=h;c[291679]=((l^n)&(n^f))>>>24;if(i&(o|0)!=0){o=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=o;eJ(1166756,1)}o=c[1161480+(k*20|0)>>2]|0;if((o|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+a>>1]=l>>>16&65535}else{fj[o&511](d&16777215,l>>>16)}o=d+2|0;d=o>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(o&65535)>>1]=l&65535;return}else{fj[a&511](o&16777215,l&65535);return}}function KO(){var a=0,b=0,d=0,f=0,g=0,h=0;a=1166604+((c[291673]&7)<<2)|0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[a>>2]|0;f=b&65535;g=f+d|0;h=g>>>8;c[291677]=h;c[291679]=((g^d)&(g^f))>>>8;c[291680]=h;c[291676]=h;h=b+d&65535;c[291678]=h;c[a>>2]=c[a>>2]&-65536|h;return}function KP(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;i=h&255;c[291667]=f+4;f=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f>>>16&255;j=c[1161468+(g*20|0)>>2]|0;if((j|0)==0){k=d[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]|0}else{k=fl[j&255](f&16777215)|0}j=k+i|0;c[291677]=j;c[291679]=(j^i)&(j^k);c[291680]=j;c[291676]=j;j=k+h|0;h=j&255;c[291678]=h;k=c[1161476+(g*20|0)>>2]|0;if((k|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=j&255;return}else{fj[k&511](f&16777215,h);return}}function KQ(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291667]|0;f=b+2|0;c[291667]=f;g=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;h=g&255;c[291667]=b+6;i=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b+4|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b|i<<16;j=i&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(b^1)|0]|0}else{k=fl[i&255](f&16777215)|0}i=k+h|0;c[291677]=i;c[291679]=(i^h)&(i^k);c[291680]=i;c[291676]=i;i=k+g|0;g=i&255;c[291678]=g;k=c[1161476+(j*20|0)>>2]|0;if((k|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(b^1)|0]=i&255;return}else{fj[k&511](f&16777215,g);return}}function KR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j+d|0;i=g>>>8;c[291677]=i;c[291679]=((g^d)&(g^j))>>>8;c[291680]=i;c[291676]=i;i=g&65535;c[291678]=i;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[k&511](a&16777215,i);return}}function KS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+2;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j+d|0;i=g>>>8;c[291677]=i;c[291679]=((g^d)&(g^j))>>>8;c[291680]=i;c[291676]=i;i=g&65535;c[291678]=i;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[k&511](f&16777215,i);return}}function KT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;f=(c[a>>2]|0)-2|0;c[a>>2]=f;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j+d|0;i=g>>>8;c[291677]=i;c[291679]=((g^d)&(g^j))>>>8;c[291680]=i;c[291676]=i;i=g&65535;c[291678]=i;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[k&511](f&16777215,i);return}}function KU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=(a&1|0)!=0;d=c[291688]|0;if(g&(d|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=d}else{d=fl[i&255](a&16777215)|0;j=d;k=c[291688]|0}d=j+f|0;i=d>>>8;c[291677]=i;c[291679]=((d^f)&(d^j))>>>8;c[291680]=i;c[291676]=i;i=d&65535;c[291678]=i;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[k&511](a&16777215,i);return}}function KV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+g+h|0;h=(d&1|0)!=0;g=c[291688]|0;if(h&(g|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;i=c[1161472+(a*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j+f|0;i=g>>>8;c[291677]=i;c[291679]=((g^f)&(g^j))>>>8;c[291680]=i;c[291676]=i;i=g&65535;c[291678]=i;if(h&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(a*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[k&511](d&16777215,i);return}}function KW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(a&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j+f|0;i=g>>>8;c[291677]=i;c[291679]=((g^f)&(g^j))>>>8;c[291680]=i;c[291676]=i;i=g&65535;c[291678]=i;if(d&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[k&511](a&16777215,i);return}}function KX(){var a=0,b=0,d=0,f=0,g=0;a=1166604+((c[291673]&7)<<2)|0;b=c[291667]|0;c[291667]=b+4;d=(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;f=b+2|0;b=c[a>>2]|0;g=(e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d)+b|0;c[291677]=g>>>24;c[291679]=((g^d)&(g^b))>>>24;f=((g^-8388608)&(b|d)|b&d)>>>23;c[291680]=f;c[291676]=f;c[291678]=g;c[a>>2]=g;return}function KY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+6;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=g&255;g=c[1161472+(j*20|0)>>2]|0;if((g|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0;l=i}else{i=fl[g&255](d&16777215)|0;k=i;l=c[291688]|0}i=k+f|0;g=i>>>8;c[291677]=g;c[291679]=((i^f)&(i^k))>>>8;c[291680]=g;c[291676]=g;g=i&65535;c[291678]=g;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=i&65535;return}else{fj[l&511](d&16777215,g);return}}function KZ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=(f&1|0)!=0;h=c[291688]|0;if(g&(h|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=f+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](f&16777215)|0)<<16;k=fl[c[j>>2]&255](f+2&16777215)|0|h;m=k;n=c[291688]|0}k=m+a|0;c[291677]=k>>>24;c[291679]=((k^d)&(k^m))>>>24;a=((k^-8388608)&(m|d)|m&d)>>>23;c[291680]=a;c[291676]=a;c[291678]=k;if(g&(n|0)!=0){n=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]=k>>>16&65535}else{fj[n&511](f&16777215,k>>>16)}n=f+2|0;f=n>>>16&255;i=c[1161480+(f*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[i&511](n&16777215,k&65535);return}}function K_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=1166604+((c[291673]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+4;f=(g&1|0)!=0;h=c[291688]|0;if(f&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=g>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=g+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](g&16777215)|0)<<16;k=fl[c[j>>2]&255](g+2&16777215)|0|h;m=k;n=c[291688]|0}k=m+a|0;c[291677]=k>>>24;c[291679]=((k^d)&(k^m))>>>24;a=((k^-8388608)&(m|d)|m&d)>>>23;c[291680]=a;c[291676]=a;c[291678]=k;if(f&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}n=g+2|0;g=n>>>16&255;i=c[1161480+(g*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[i&511](n&16777215,k&65535);return}}function K$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;c[291667]=a+4;d=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=1166604+((c[291673]&7|8)<<2)|0;g=c[f>>2]|0;h=g-4|0;c[f>>2]=h;f=(h&1|0)!=0;i=c[291688]|0;if(f&(i|0)!=0){j=c[291675]|1;c[291699]=h;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=h>>>16&255;k=1161472+(j*20|0)|0;l=c[k>>2]|0;if((l|0)==0){m=g-2|0;n=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+(h&65535)>>1]|0)<<16;o=i}else{i=(fl[l&255](h&16777215)|0)<<16;l=fl[c[k>>2]&255](g+16777214&16777215)|0|i;n=l;o=c[291688]|0}l=n+a|0;c[291677]=l>>>24;c[291679]=((l^d)&(l^n))>>>24;a=((l^-8388608)&(n|d)|n&d)>>>23;c[291680]=a;c[291676]=a;c[291678]=l;if(f&(o|0)!=0){o=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=o;eJ(1166756,1)}o=c[1161480+(j*20|0)>>2]|0;if((o|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+(h&65535)>>1]=l>>>16&65535}else{fj[o&511](h&16777215,l>>>16)}h=g-2|0;g=h>>>16&255;o=c[1161480+(g*20|0)>>2]|0;if((o|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(h&65535)>>1]=l&65535;return}else{fj[o&511](h&16777215,l&65535);return}}function K0(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;g=a+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|f;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=(a&1|0)!=0;d=c[291688]|0;if(g&(d|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=a+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|e[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]<<16;n=d}else{d=(fl[k&255](a&16777215)|0)<<16;k=fl[c[j>>2]&255](a+2&16777215)|0|d;m=k;n=c[291688]|0}k=m+h|0;c[291677]=k>>>24;c[291679]=((k^f)&(k^m))>>>24;h=((k^-8388608)&(m|f)|m&f)>>>23;c[291680]=h;c[291676]=h;c[291678]=k;if(g&(n|0)!=0){n=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=k>>>16&65535}else{fj[n&511](a&16777215,k>>>16)}n=a+2|0;a=n>>>16&255;i=c[1161480+(a*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[i&511](n&16777215,k&65535);return}}function K1(){var a=0,d=0;a=c[1166604+((c[291673]&7)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;c[291678]=1<<(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]&31)&a;return}function K2(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=a>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a&65535^1)|0]|0;i=1<<e;j=h&i;c[291678]=j;return}else{h=fl[g&255](a&16777215)|0;i=1<<e;j=h&i;c[291678]=j;return}}function K3(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;a=1166604+((c[291673]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+1;a=f>>>16&255;g=c[1161468+(a*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(a*20|0)>>2]|0)+(f&65535^1)|0]|0;i=1<<e;j=h&i;c[291678]=j;return}else{h=fl[g&255](f&16777215)|0;i=1<<e;j=h&i;c[291678]=j;return}}function K4(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;a=c[291666]|0;c[291666]=a+2;f=a>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a&65535^1)|0]|0;i=1<<e;j=h&i;c[291678]=j;return}else{h=fl[g&255](a&16777215)|0;i=1<<e;j=h&i;c[291678]=j;return}}function K5(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;a=1166604+((c[291673]&7|8)<<2)|0;f=(c[a>>2]|0)-1|0;c[a>>2]=f;a=f>>>16&255;g=c[1161468+(a*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(a*20|0)>>2]|0)+(f&65535^1)|0]|0;i=1<<e;j=h&i;c[291678]=j;return}else{h=fl[g&255](f&16777215)|0;i=1<<e;j=h&i;c[291678]=j;return}}function K6(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;a=(c[291666]|0)-2|0;c[291666]=a;f=a>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a&65535^1)|0]|0;i=1<<e;j=h&i;c[291678]=j;return}else{h=fl[g&255](a&16777215)|0;i=1<<e;j=h&i;c[291678]=j;return}}function K7(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;e=a+2|0;c[291667]=e;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+g|0;g=a>>>16&255;e=c[1161468+(g*20|0)>>2]|0;if((e|0)==0){h=d[(c[1161464+(g*20|0)>>2]|0)+(a&65535^1)|0]|0;i=1<<f;j=h&i;c[291678]=j;return}else{h=fl[e&255](a&16777215)|0;i=1<<f;j=h&i;c[291678]=j;return}}function K8(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;f=a+2|0;c[291667]=f;g=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;h=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=f<<16>>16}else{i=f}f=(a<<24>>24)+h+i|0;i=f>>>16&255;h=c[1161468+(i*20|0)>>2]|0;if((h|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(f&65535^1)|0]|0;k=1<<g;l=j&k;c[291678]=l;return}else{j=fl[h&255](f&16777215)|0;k=1<<g;l=j&k;c[291678]=l;return}}function K9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;g=a+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|f;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=d<<16>>16}else{i=d}d=(a<<24>>24)+g+i|0;i=(d&1|0)!=0;g=c[291688]|0;if(i&(g|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;j=1161472+(a*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;n=g}else{g=(fl[k&255](d&16777215)|0)<<16;k=fl[c[j>>2]&255](d+2&16777215)|0|g;m=k;n=c[291688]|0}k=m+h|0;c[291677]=k>>>24;c[291679]=((k^f)&(k^m))>>>24;h=((k^-8388608)&(m|f)|m&f)>>>23;c[291680]=h;c[291676]=h;c[291678]=k;if(i&(n|0)!=0){n=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(a*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=k>>>16&65535}else{fj[n&511](d&16777215,k>>>16)}n=d+2|0;d=n>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[a&511](n&16777215,k&65535);return}}function La(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;g=a+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|f;c[291667]=a+6;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(a&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=a+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|e[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]<<16;n=g}else{g=(fl[k&255](a&16777215)|0)<<16;k=fl[c[j>>2]&255](a+2&16777215)|0|g;m=k;n=c[291688]|0}k=m+h|0;c[291677]=k>>>24;c[291679]=((k^f)&(k^m))>>>24;h=((k^-8388608)&(m|f)|m&f)>>>23;c[291680]=h;c[291676]=h;c[291678]=k;if(d&(n|0)!=0){n=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=k>>>16&65535}else{fj[n&511](a&16777215,k>>>16)}n=a+2|0;a=n>>>16&255;i=c[1161480+(a*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(n&65535)>>1]=k&65535;return}else{fj[i&511](n&16777215,k&65535);return}}function Lb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;g=a+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|f;c[291667]=a+8;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;i=(a&1|0)!=0;j=c[291688]|0;if(i&(j|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=k;eJ(1166756,1)}k=g&255;g=1161472+(k*20|0)|0;l=c[g>>2]|0;if((l|0)==0){m=d+2|0;n=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0|(e[(c[1161464+(k*20|0)>>2]|0)+a>>1]|0)<<16;o=j}else{j=(fl[l&255](d&16777215)|0)<<16;l=fl[c[g>>2]&255](d+2&16777215)|0|j;n=l;o=c[291688]|0}l=n+h|0;c[291677]=l>>>24;c[291679]=((l^f)&(l^n))>>>24;h=((l^-8388608)&(n|f)|n&f)>>>23;c[291680]=h;c[291676]=h;c[291678]=l;if(i&(o|0)!=0){o=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=o;eJ(1166756,1)}o=c[1161480+(k*20|0)>>2]|0;if((o|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+a>>1]=l>>>16&65535}else{fj[o&511](d&16777215,l>>>16)}o=d+2|0;d=o>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(o&65535)>>1]=l&65535;return}else{fj[a&511](o&16777215,l&65535);return}}function Lc(){var a=0,e=0,f=0;a=c[291667]|0;e=a+2|0;c[291667]=e;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;c[291667]=a+4;a=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+e|0;c[291678]=d[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535^1)|0]&1<<f;return}function Ld(){var a=0,f=0,g=0,h=0,i=0;a=c[291667]|0;f=a+2|0;c[291667]=f;g=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;c[291667]=a+4;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=h<<16>>16}else{i=h}h=(a<<24>>24)+f+i|0;c[291678]=(d[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535^1)|0]|0)&1<<g;return}function Le(){var a=0,d=0,e=0;a=1166604+((c[291673]&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=1<<(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]&31);c[291678]=e&c[a>>2];c[a>>2]=e^c[a>>2];return}function Lf(){var a=0,d=0,e=0;a=1166604+((c[291673]&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=1<<(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]&31);c[291678]=e&c[a>>2];c[a>>2]=c[a>>2]&~e;return}function Lg(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;e=a+2|0;c[291667]=e;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;c[291667]=a+4;a=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=a>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(a&65535^1)|0]|0;i=1<<f;j=h&i;c[291678]=j;return}else{h=fl[g&255](a&16777215)|0;i=1<<f;j=h&i;c[291678]=j;return}}function Lh(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;f=a+2|0;c[291667]=f;g=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&7;c[291667]=a+6;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a+4|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=h&255;i=c[1161468+(f*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(f*20|0)>>2]|0)+(a^1)|0]|0;k=1<<g;l=j&k;c[291678]=l;return}else{j=fl[i&255](a|h<<16&16711680)|0;k=1<<g;l=j&k;c[291678]=l;return}}function Li(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&f;h=i^f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function Lj(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=1166604+((c[291673]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[291678]=i&f;h=i^f;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function Lk(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[291666]|0;c[291666]=e+2;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&f;h=i^f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function Ll(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=1166604+((c[291673]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[291678]=i&f;h=i^f;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function Lm(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=(c[291666]|0)-2|0;c[291666]=e;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&f;h=i^f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function Ln(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);h=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=e+4;e=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}c[291678]=i&g;f=i^g;g=c[1161476+(h*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function Lo(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=1<<(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);i=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=f+4;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[291678]=k&h;i=k^h;h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function Lp(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);c[291667]=e+4;e=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[1161468+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&g;h=i^g;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function Lq(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=1<<(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);c[291667]=f+6;i=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[291678]=k&h;i=k^h;h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function Lr(){var a=0,d=0,e=0;a=1166604+((c[291673]&7)<<2)|0;d=c[291667]|0;c[291667]=d+2;e=1<<(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]&31);c[291678]=e&c[a>>2];c[a>>2]=e|c[a>>2];return}function Ls(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&f;h=i&~f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function Lt(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=1166604+((c[291673]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[291678]=i&f;h=i&~f;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function Lu(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[291666]|0;c[291666]=e+2;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&f;h=i&~f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function Lv(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=1166604+((c[291673]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[291678]=i&f;h=i&~f;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function Lw(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=(c[291666]|0)-2|0;c[291666]=e;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&f;h=i&~f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function Lx(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);h=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=e+4;e=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}c[291678]=i&g;f=i&~g;g=c[1161476+(h*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function Ly(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=1<<(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);i=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=f+4;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[291678]=k&h;i=k&~h;h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function Lz(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);c[291667]=e+4;e=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[1161468+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&g;h=i&~g;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function LA(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=1<<(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);c[291667]=f+6;i=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[291678]=k&h;i=k&~h;h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function LB(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&f;h=i|f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function LC(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=1166604+((c[291673]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[291678]=i&f;h=i|f;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function LD(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=c[291666]|0;c[291666]=e+2;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&f;h=i|f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function LE(){var a=0,d=0,e=0;a=c[291667]|0;c[291667]=a+2;d=1166604+((c[291673]&7)<<2)|0;e=c[d>>2]^b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;c[d>>2]=e;d=e&255;c[291677]=d;c[291678]=d;c[291680]=0;c[291679]=0;return}function LF(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=1166604+((c[291673]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}c[291678]=i&f;h=i|f;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function LG(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);e=(c[291666]|0)-2|0;c[291666]=e;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&f;h=i|f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[f&511](e&16777215,h);return}}function LH(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);h=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=e+4;e=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}c[291678]=i&g;f=i|g;g=c[1161476+(h*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function LI(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=1<<(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);i=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=f+4;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[291678]=k&h;i=k|h;h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function LJ(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=1<<(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&7);c[291667]=e+4;e=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[1161468+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}c[291678]=i&g;h=i|g;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function LK(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=1<<(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&7);c[291667]=f+6;i=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}c[291678]=k&h;i=k|h;h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function LL(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i^f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[f&511](e&16777215,h);c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}}function LM(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=1166604+((c[291673]&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+1;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i^f;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[f&511](g&16777215,h);c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}}function LN(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=c[291666]|0;c[291666]=e+2;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i^f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[f&511](e&16777215,h);c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}}function LO(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=1166604+((c[291673]&7|8)<<2)|0;g=(c[e>>2]|0)-1|0;c[e>>2]=g;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i^f;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[f&511](g&16777215,h);c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}}function LP(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;e=(c[291666]|0)-2|0;c[291666]=e;g=e>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i^f;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(e&65535^1)|0]=h&255;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[f&511](e&16777215,h);c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}}function LQ(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;h=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=e+4;e=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+h|0;h=e>>>16&255;f=c[1161468+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[f&255](e&16777215)|0}f=i^g;g=c[1161476+(h*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=f&255;c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}else{fj[g&511](e&16777215,f);c[291677]=f;c[291678]=f;c[291680]=0;c[291679]=0;return}}function LR(){var a=0,b=0,d=0;a=(c[291677]|0)>>>4&8|(c[291676]|0)>>>4&16|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1;b=c[291667]|0;c[291667]=b+2;d=a^(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0);b=d<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=d>>>2&1^1;c[291679]=d<<6&128;c[291680]=d<<8&256;return}function LS(){var a=0,b=0,d=0;a=c[291667]|0;c[291667]=a+2;b=1166604+((c[291673]&7)<<2)|0;d=c[b>>2]^(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0);c[b>>2]=d;b=d&65535;c[291677]=b>>>8;c[291678]=b;c[291680]=0;c[291679]=0;return}function LT(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;i=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=f+4;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=g<<16>>16}else{j=g}g=(f<<24>>24)+i+j|0;j=g>>>16&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=k^h;h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;c[291677]=i;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[h&511](g&16777215,i);c[291677]=i;c[291678]=i;c[291680]=0;c[291679]=0;return}}function LU(){var e=0,f=0,g=0,h=0,i=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]&255;c[291667]=e+4;e=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=e>>>16&255;h=c[1161468+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{i=fl[h&255](e&16777215)|0}h=i^g;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}else{fj[g&511](e&16777215,h);c[291677]=h;c[291678]=h;c[291680]=0;c[291679]=0;return}}function LV(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]&255;c[291667]=f+6;i=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f+4|0;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f|i<<16;j=i&255;i=c[1161468+(j*20|0)>>2]|0;if((i|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]|0}else{k=fl[i&255](g&16777215)|0}i=k^h;h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f^1)|0]=i&255;c[291677]=i;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[h&511](g&16777215,i);c[291677]=i;c[291678]=i;c[291680]=0;c[291679]=0;return}}function LW(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=(a&1|0)!=0;g=c[291688]|0;if(f&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j^d;if(f&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[k&511](a&16777215,g);l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}}function LX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+2;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j^d;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[k&511](f&16777215,g);l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}}function LY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;f=(c[a>>2]|0)-2|0;c[a>>2]=f;a=(f&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;k=g}else{g=fl[i&255](f&16777215)|0;j=g;k=c[291688]|0}g=j^d;if(a&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[k&511](f&16777215,g);l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}}function LZ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=(a&1|0)!=0;d=c[291688]|0;if(g&(d|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=d}else{d=fl[i&255](a&16777215)|0;j=d;k=c[291688]|0}d=j^f;if(g&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=d&65535;l=d>>>8;c[291677]=l;c[291678]=d;c[291680]=0;c[291679]=0;return}else{fj[k&511](a&16777215,d);l=d>>>8;c[291677]=l;c[291678]=d;c[291680]=0;c[291679]=0;return}}function L_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+g+h|0;h=(d&1|0)!=0;g=c[291688]|0;if(h&(g|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;i=c[1161472+(a*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;k=g}else{g=fl[i&255](d&16777215)|0;j=g;k=c[291688]|0}g=j^f;if(h&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(a*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[k&511](d&16777215,g);l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}}function L$(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=a+2|0;d=1166604+((c[291673]&7)<<2)|0;f=c[d>>2]^(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16);c[d>>2]=f;c[291677]=f>>>24;c[291678]=f;c[291680]=0;c[291679]=0;return}function L0(){var a=0,b=0,d=0;a=c[291675]|0;if((a|0)==0){ahd();return}else{b=c[291667]|0;c[291667]=b+2;d=(c[291674]|a<<11|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1)^(e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0);c[291674]=d&32768;c[291681]=d&1792;b=d<<4;c[291676]=b&256;c[291677]=b&128;c[291678]=d>>>2&1^1;c[291679]=d<<6&128;c[291680]=d<<8&256;b=d>>>11&4;c[1166672+(a<<2)>>2]=c[291666];c[291675]=b;c[291666]=c[1166672+(b<<2)>>2];ID();return}}function L1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(a&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=c[1161472+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0;k=g}else{g=fl[i&255](a&16777215)|0;j=g;k=c[291688]|0}g=j^f;if(d&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=g&65535;l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}else{fj[k&511](a&16777215,g);l=g>>>8;c[291677]=l;c[291678]=g;c[291680]=0;c[291679]=0;return}}function L2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+6;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|g<<16;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=g&255;g=c[1161472+(j*20|0)>>2]|0;if((g|0)==0){k=e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0;l=i}else{i=fl[g&255](d&16777215)|0;k=i;l=c[291688]|0}i=k^f;if(h&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=c[1161480+(j*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=i&65535;m=i>>>8;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}else{fj[l&511](d&16777215,i);m=i>>>8;c[291677]=m;c[291678]=i;c[291680]=0;c[291679]=0;return}}function L3(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=a+2|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=(a&1|0)!=0;g=c[291688]|0;if(d&(g|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|g;l=j;m=c[291688]|0}j=l^f;if(d&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function L4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;d=a+2|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=(d&1|0)!=0;g=c[291688]|0;if(a&(g|0)!=0){h=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=g}else{g=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|g;l=j;m=c[291688]|0}j=l^f;if(a&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function L5(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;c[291667]=a+4;d=a+2|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;a=(g&1|0)!=0;h=c[291688]|0;if(a&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=g>>>16&255;j=1161472+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d-2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;n=h}else{h=(fl[k&255](g&16777215)|0)<<16;k=fl[c[j>>2]&255](d+16777214&16777215)|0|h;m=k;n=c[291688]|0}k=m^f;if(a&(n|0)!=0){n=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(i*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]=k>>>16&65535}else{fj[n&511](g&16777215,k>>>16)}g=d-2|0;d=g>>>16&255;n=c[1161480+(d*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]=k&65535;o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}else{fj[n&511](g&16777215,k&65535);o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}}function L6(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=b&255;d=c[1166604+((c[291673]&7)<<2)>>2]|0;f=d&255;g=f-a|0;c[291677]=g;c[291678]=d-b&255;c[291679]=(g^d)&(f^a);c[291680]=g;return}function L7(){var a=0,e=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=a>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a&65535^1)|0]|0}else{h=fl[g&255](a&16777215)|0}a=h-e|0;c[291677]=a;c[291678]=a&255;c[291679]=(a^h)&(h^e);c[291680]=a;return}function L8(){var a=0,e=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=1166604+((c[291673]&7|8)<<2)|0;f=c[a>>2]|0;c[a>>2]=f+1;a=f>>>16&255;g=c[1161468+(a*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(a*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=h-e|0;c[291677]=f;c[291678]=f&255;c[291679]=(f^h)&(h^e);c[291680]=f;return}function L9(){var a=0,e=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=c[291666]|0;c[291666]=a+2;f=a>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a&65535^1)|0]|0}else{h=fl[g&255](a&16777215)|0}a=h-e|0;c[291677]=a;c[291678]=a&255;c[291679]=(a^h)&(h^e);c[291680]=a;return}function Ma(){var a=0,e=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=1166604+((c[291673]&7|8)<<2)|0;f=(c[a>>2]|0)-1|0;c[a>>2]=f;a=f>>>16&255;g=c[1161468+(a*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(a*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=h-e|0;c[291677]=f;c[291678]=f&255;c[291679]=(f^h)&(h^e);c[291680]=f;return}function Mb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+f|0;f=(a&1|0)!=0;d=c[291688]|0;if(f&(d|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]<<16;m=d}else{d=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|d;l=j;m=c[291688]|0}j=l^g;if(f&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function Mc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=(a<<24>>24)+f+h|0;h=(d&1|0)!=0;f=c[291688]|0;if(h&(f|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;i=1161472+(a*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=d+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;m=f}else{f=(fl[j&255](d&16777215)|0)<<16;j=fl[c[i>>2]&255](d+2&16777215)|0|f;l=j;m=c[291688]|0}j=l^g;if(h&(m|0)!=0){m=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(a*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[m&511](d&16777215,j>>>16)}m=d+2|0;d=m>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[a&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function Md(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]<<16;c[291667]=a+6;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(a&1|0)!=0;f=c[291688]|0;if(d&(f|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;i=1161472+(h*20|0)|0;j=c[i>>2]|0;if((j|0)==0){k=a+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]<<16;m=f}else{f=(fl[j&255](a&16777215)|0)<<16;j=fl[c[i>>2]&255](a+2&16777215)|0|f;l=j;m=c[291688]|0}j=l^g;if(d&(m|0)!=0){m=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=c[1161480+(h*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[m&511](a&16777215,j>>>16)}m=a+2|0;a=m>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(m&65535)>>1]=j&65535;n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}else{fj[h&511](m&16777215,j&65535);n=j>>>24;c[291677]=n;c[291678]=j;c[291680]=0;c[291679]=0;return}}function Me(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;c[291667]=a+8;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|f<<16;h=(a&1|0)!=0;i=c[291688]|0;if(h&(i|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=j;eJ(1166756,1)}j=f&255;f=1161472+(j*20|0)|0;k=c[f>>2]|0;if((k|0)==0){l=d+2|0;m=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[1161464+(j*20|0)>>2]|0)+a>>1]|0)<<16;n=i}else{i=(fl[k&255](d&16777215)|0)<<16;k=fl[c[f>>2]&255](d+2&16777215)|0|i;m=k;n=c[291688]|0}k=m^g;if(h&(n|0)!=0){n=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=c[1161480+(j*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+a>>1]=k>>>16&65535}else{fj[n&511](d&16777215,k>>>16)}n=d+2|0;d=n>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(n&65535)>>1]=k&65535;o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}else{fj[a&511](n&16777215,k&65535);o=k>>>24;c[291677]=o;c[291678]=k;c[291680]=0;c[291679]=0;return}}function Mf(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+((c[291673]&7)<<2)>>2]|0;d=a&65535;f=d-b|0;g=f>>>8;c[291677]=g;c[291678]=a-b&65535;c[291679]=((f^a)&(d^b))>>>8;c[291680]=g;return}function Mg(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=c[1166604+((c[291673]&7)<<2)>>2]|0;f=a-(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b)|0;c[291677]=f>>>24;c[291678]=f;c[291679]=((f^a)&(a^b))>>>24;c[291680]=((f|b)&(a^-8388608)|f&b)>>>23;return}function Mh(){var a=0,e=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=(c[291666]|0)-2|0;c[291666]=a;f=a>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a&65535^1)|0]|0}else{h=fl[g&255](a&16777215)|0}a=h-e|0;c[291677]=a;c[291678]=a&255;c[291679]=(a^h)&(h^e);c[291680]=a;return}function Mi(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291667]|0;e=a+2|0;c[291667]=e;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+g|0;g=a>>>16&255;e=c[1161468+(g*20|0)>>2]|0;if((e|0)==0){h=d[(c[1161464+(g*20|0)>>2]|0)+(a&65535^1)|0]|0;i=h-f|0;c[291677]=i;j=i&255;c[291678]=j;k=h^f;l=i^h;m=l&k;c[291679]=m;c[291680]=i;return}else{h=fl[e&255](a&16777215)|0;i=h-f|0;c[291677]=i;j=i&255;c[291678]=j;k=h^f;l=i^h;m=l&k;c[291679]=m;c[291680]=i;return}}function Mj(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;f=a+2|0;c[291667]=f;g=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;h=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=f<<16>>16}else{i=f}f=(a<<24>>24)+h+i|0;i=f>>>16&255;h=c[1161468+(i*20|0)>>2]|0;if((h|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(f&65535^1)|0]|0;k=j-g|0;c[291677]=k;l=k&255;c[291678]=l;m=j^g;n=k^j;o=n&m;c[291679]=o;c[291680]=k;return}else{j=fl[h&255](f&16777215)|0;k=j-g|0;c[291677]=k;l=k&255;c[291678]=l;m=j^g;n=k^j;o=n&m;c[291679]=o;c[291680]=k;return}}function Mk(){var a=0,e=0,f=0,g=0,h=0;a=c[291667]|0;e=a+2|0;c[291667]=e;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;c[291667]=a+4;a=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=a>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(a&65535^1)|0]|0}else{h=fl[g&255](a&16777215)|0}a=h-f|0;c[291677]=a;c[291678]=a&255;c[291679]=(a^h)&(h^f);c[291680]=a;return}function Ml(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;f=a+2|0;c[291667]=f;g=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;c[291667]=a+6;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a+4|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=h&255;i=c[1161468+(f*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(f*20|0)>>2]|0)+(a^1)|0]|0;k=j-g|0;c[291677]=k;l=k&255;c[291678]=l;m=j^g;n=k^j;o=n&m;c[291679]=o;c[291680]=k;return}else{j=fl[i&255](a|h<<16&16711680)|0;k=j-g|0;c[291677]=k;l=k&255;c[291678]=l;m=j^g;n=k^j;o=n&m;c[291679]=o;c[291680]=k;return}}function Mm(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=g-b|0;f=a>>>8;c[291677]=f;c[291678]=a&65535;c[291679]=((a^g)&(g^b))>>>8;c[291680]=f;return}function Mn(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;h=g-b|0;i=h>>>8;c[291677]=i;j=h&65535;c[291678]=j;k=g^b;l=h^g;m=l&k;n=m>>>8;c[291679]=n;c[291680]=i;return}else{g=fl[f&255](d&16777215)|0;h=g-b|0;i=h>>>8;c[291677]=i;j=h&65535;c[291678]=j;k=g^b;l=h^g;m=l&k;n=m>>>8;c[291679]=n;c[291680]=i;return}}function Mo(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;h=g-b|0;i=h>>>8;c[291677]=i;j=h&65535;c[291678]=j;k=g^b;l=h^g;m=l&k;n=m>>>8;c[291679]=n;c[291680]=i;return}else{g=fl[f&255](d&16777215)|0;h=g-b|0;i=h>>>8;c[291677]=i;j=h&65535;c[291678]=j;k=g^b;l=h^g;m=l&k;n=m>>>8;c[291679]=n;c[291680]=i;return}}function Mp(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=a>>>16&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(a&65535)>>1]|0;i=h-f|0;j=i>>>8;c[291677]=j;k=i&65535;c[291678]=k;l=h^f;m=i^h;n=m&l;o=n>>>8;c[291679]=o;c[291680]=j;return}else{h=fl[d&255](a&16777215)|0;i=h-f|0;j=i>>>8;c[291677]=j;k=i&65535;c[291678]=k;l=h^f;m=i^h;n=m&l;o=n>>>8;c[291679]=o;c[291680]=j;return}}function Mq(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;b=a+2|0;c[291667]=b;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){g=b<<16>>16}else{g=b}b=(a<<24>>24)+f+g|0;if((b&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=b>>>16&255;f=c[1161472+(g*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(b&65535)>>1]|0;i=h-d|0;j=i>>>8;c[291677]=j;k=i&65535;c[291678]=k;l=h^d;m=i^h;n=m&l;o=n>>>8;c[291679]=o;c[291680]=j;return}else{h=fl[f&255](b&16777215)|0;i=h-d|0;j=i>>>8;c[291677]=j;k=i&65535;c[291678]=k;l=h^d;m=i^h;n=m&l;o=n>>>8;c[291679]=o;c[291680]=j;return}}function Mr(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]|0;i=h-f|0;j=i>>>8;c[291677]=j;k=i&65535;c[291678]=k;l=h^f;m=i^h;n=m&l;o=n>>>8;c[291679]=o;c[291680]=j;return}else{h=fl[g&255](a&16777215)|0;i=h-f|0;j=i>>>8;c[291677]=j;k=i&65535;c[291678]=k;l=h^f;m=i^h;n=m&l;o=n>>>8;c[291679]=o;c[291680]=j;return}}function Ms(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291667]|0;b=a+2|0;c[291667]=b;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[291667]=a+6;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=a+4|0;a=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=a|f<<16;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f&255;f=c[1161472+(g*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+a>>1]|0;i=h-d|0;j=i>>>8;c[291677]=j;k=i&65535;c[291678]=k;l=h^d;m=i^h;n=m&l;o=n>>>8;c[291679]=o;c[291680]=j;return}else{h=fl[f&255](b&16777215)|0;i=h-d|0;j=i>>>8;c[291677]=j;k=i&65535;c[291678]=k;l=h^d;m=i^h;n=m&l;o=n>>>8;c[291679]=o;c[291680]=j;return}}function Mt(){var a=0,b=0,d=0;a=c[291673]|0;b=c[1166604+((a&7)<<2)>>2]&255;d=1166604+((a>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-256|b;c[291677]=b;c[291678]=b;c[291679]=0;c[291680]=0;return}function Mu(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b;d=ahi()|0;f=d-a|0;c[291677]=f>>>24;c[291678]=f;c[291679]=((f^d)&(d^b))>>>24;c[291680]=((f|b)&(d^-8388608)|f&b)>>>23;return}function Mv(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b;d=ahh()|0;f=d-a|0;c[291677]=f>>>24;c[291678]=f;c[291679]=((f^d)&(d^b))>>>24;c[291680]=((f|b)&(d^-8388608)|f&b)>>>23;return}function Mw(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+4;b=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b;d=ahg()|0;f=d-a|0;c[291677]=f>>>24;c[291678]=f;c[291679]=((f^d)&(d^b))>>>24;c[291680]=((f|b)&(d^-8388608)|f&b)>>>23;return}function Mx(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0}a=1166604+((h>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|g;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;return}function My(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-256|f;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;return}function Mz(){var a=0,b=0,e=0,f=0;a=c[291666]|0;c[291666]=a+2;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|f;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;return}function MA(){var a=0,b=0,e=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[1161468+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-256|f;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;return}function MB(){var a=0,b=0,e=0,f=0;a=(c[291666]|0)-2|0;c[291666]=a;b=a>>>16&255;e=c[1161468+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[1161464+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|f;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;return}function MC(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[291673]|0;e=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=1166604+((i>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|h;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;return}function MD(){var a=0,b=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0;j=a}else{a=fl[b&255](f&16777215)|0;i=a;j=c[291673]|0}a=1166604+((j>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|i;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;return}function ME(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[291667]|0;c[291667]=a+4;b=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b;d=c[1166604+((c[291673]&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=1161472+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=j-a|0;l=k>>>24;c[291677]=l;c[291678]=k;m=j^b;n=k^j;o=n&m;p=o>>>24;c[291679]=p;q=k&b;r=j^-8388608;s=k|b;t=s&r;u=t|q;v=u>>>23;c[291680]=v;return}else{f=(fl[h&255](d&16777215)|0)<<16;j=fl[c[g>>2]&255](d+2&16777215)|0|f;k=j-a|0;l=k>>>24;c[291677]=l;c[291678]=k;m=j^b;n=k^j;o=n&m;p=o>>>24;c[291679]=p;q=k&b;r=j^-8388608;s=k|b;t=s&r;u=t|q;v=u>>>23;c[291680]=v;return}}function MF(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[291667]|0;c[291667]=a+4;b=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b;d=1166604+((c[291673]&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+4;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=1161472+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=j-a|0;l=k>>>24;c[291677]=l;c[291678]=k;m=j^b;n=k^j;o=n&m;p=o>>>24;c[291679]=p;q=k&b;r=j^-8388608;s=k|b;t=s&r;u=t|q;v=u>>>23;c[291680]=v;return}else{d=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](f+2&16777215)|0|d;k=j-a|0;l=k>>>24;c[291677]=l;c[291678]=k;m=j^b;n=k^j;o=n&m;p=o>>>24;c[291679]=p;q=k&b;r=j^-8388608;s=k|b;t=s&r;u=t|q;v=u>>>23;c[291680]=v;return}}function MG(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[291667]|0;c[291667]=a+4;b=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b;d=1166604+((c[291673]&7|8)<<2)|0;f=c[d>>2]|0;g=f-4|0;c[d>>2]=g;if((g&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;h=1161472+(d*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=f-2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0)<<16;l=k-a|0;m=l>>>24;c[291677]=m;c[291678]=l;n=k^b;o=l^k;p=o&n;q=p>>>24;c[291679]=q;r=l&b;s=k^-8388608;t=l|b;u=t&s;v=u|r;w=v>>>23;c[291680]=w;return}else{d=(fl[i&255](g&16777215)|0)<<16;k=fl[c[h>>2]&255](f+16777214&16777215)|0|d;l=k-a|0;m=l>>>24;c[291677]=m;c[291678]=l;n=k^b;o=l^k;p=o&n;q=p>>>24;c[291679]=q;r=l&b;s=k^-8388608;t=l|b;u=t&s;v=u|r;w=v>>>23;c[291680]=w;return}}function MH(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[291667]|0;b=a+4|0;c[291667]=b;d=(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;f=a+2|0;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|d;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;c[291667]=a+6;a=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=b<<16>>16}else{h=b}b=(a<<24>>24)+f+h|0;if((b&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=b>>>16&255;f=1161472+(h*20|0)|0;a=c[f>>2]|0;if((a|0)==0){i=b+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;k=j-g|0;l=k>>>24;c[291677]=l;c[291678]=k;m=j^d;n=k^j;o=n&m;p=o>>>24;c[291679]=p;q=k&d;r=j^-8388608;s=k|d;t=s&r;u=t|q;v=u>>>23;c[291680]=v;return}else{h=(fl[a&255](b&16777215)|0)<<16;j=fl[c[f>>2]&255](b+2&16777215)|0|h;k=j-g|0;l=k>>>24;c[291677]=l;c[291678]=k;m=j^d;n=k^j;o=n&m;p=o>>>24;c[291679]=p;q=k&d;r=j^-8388608;s=k|d;t=s&r;u=t|q;v=u>>>23;c[291680]=v;return}}function MI(){var a=0,e=0;a=c[291667]|0;c[291667]=a+2;e=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=d[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[e>>2]=c[e>>2]&-256|a;c[291677]=a;c[291678]=a;c[291679]=0;c[291680]=0;return}function MJ(){var a=0,b=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){g=f<<16>>16}else{g=f}f=(b<<24>>24)+a+g|0;g=d[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[f>>2]=c[f>>2]&-256|g;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;return}function MK(){var a=0,d=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]&255;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-256|d;c[291677]=d;c[291678]=d;c[291679]=0;c[291680]=0;return}function ML(){var a=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[1161468+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(a*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[e>>2]=c[e>>2]&-256|g;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;return}function MM(){var a=0,b=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(a^1)|0]|0}else{h=fl[g&255](a|b<<16&16711680)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-256|h;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;return}function MN(){var b=0,d=0,e=0,f=0,g=0;b=c[291673]|0;d=c[1166604+((b&7)<<2)>>2]|0;e=d&255;f=c[1166604+((b>>>9&7|8)<<2)>>2]|0;c[291677]=e;c[291678]=e;c[291679]=0;c[291680]=0;b=f>>>16&255;g=c[1161476+(b*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,e);return}}function MO(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[291673]|0}b=c[1166604+((i>>>9&7|8)<<2)>>2]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;i=b>>>16&255;e=c[1161476+(i*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(b&65535^1)|0]=h&255;return}else{fj[e&511](b&16777215,h);return}}function MP(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=e>>>16&255;b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function MQ(){var b=0,e=0,f=0,g=0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=b>>>16&255;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,g);return}}function MR(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=e>>>16&255;b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function MS(){var b=0,e=0,f=0,g=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=b>>>16&255;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,g);return}}function MT(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[291673]|0}e=c[1166604+((j>>>9&7|8)<<2)>>2]|0;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;j=e>>>16&255;h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(e&65535^1)|0]=i&255;return}else{fj[h&511](e&16777215,i);return}}function MU(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[1161468+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[291673]|0}b=c[1166604+((k>>>9&7|8)<<2)>>2]|0;c[291677]=j;c[291678]=j;c[291679]=0;c[291680]=0;k=b>>>16&255;g=c[1161476+(k*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(k*20|0)>>2]|0)+(b&65535^1)|0]=j&255;return}else{fj[g&511](b&16777215,j);return}}function MV(){var e=0,f=0,g=0,h=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;g=f>>>16&255;e=c[1161476+(g*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[e&511](f&16777215,h);return}}function MW(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;b=f>>>16&255;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function MX(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=a[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=d&255;f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=e;c[291678]=e;c[291679]=0;c[291680]=0;g=f>>>16&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=d;return}else{fj[h&511](f&16777215,e);return}}function MY(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=a[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;b=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;d=b>>>16&255;h=c[1161476+(d*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=g;return}else{fj[h&511](b&16777215,f);return}}function MZ(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&255;f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=d;c[291678]=d;c[291679]=0;c[291680]=0;g=f>>>16&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[h&511](f&16777215,d);return}}function M_(){var b=0,d=0,e=0,f=0,g=0;b=c[291673]|0;d=c[1166604+((b&7)<<2)>>2]|0;e=d&255;f=1166604+((b>>>9&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+1;c[291677]=e;c[291678]=e;c[291679]=0;c[291680]=0;f=b>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[g&511](b&16777215,e);return}}function M$(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[291673]|0}b=1166604+((i>>>9&7|8)<<2)|0;i=c[b>>2]|0;c[b>>2]=i+1;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;b=i>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(i&65535^1)|0]=h&255;return}else{fj[e&511](i&16777215,h);return}}function M0(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+1;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;e=f>>>16&255;b=c[1161476+(e*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[b&511](f&16777215,g);return}}function M1(){var b=0,e=0,f=0,g=0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;b=f>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function M2(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+1;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;e=f>>>16&255;b=c[1161476+(e*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[b&511](f&16777215,g);return}}function M3(){var b=0,e=0,f=0,g=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;b=f>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function M4(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[291673]|0}e=1166604+((j>>>9&7|8)<<2)|0;j=c[e>>2]|0;c[e>>2]=j+1;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;e=j>>>16&255;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(j&65535^1)|0]=i&255;return}else{fj[h&511](j&16777215,i);return}}function M5(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[1161468+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[291673]|0}b=1166604+((k>>>9&7|8)<<2)|0;k=c[b>>2]|0;c[b>>2]=k+1;c[291677]=j;c[291678]=j;c[291679]=0;c[291680]=0;b=k>>>16&255;g=c[1161476+(b*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(k&65535^1)|0]=j&255;return}else{fj[g&511](k&16777215,j);return}}function M6(){var e=0,f=0,g=0,h=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=g>>>16&255;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function M7(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+1;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;f=b>>>16&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=i&255;return}else{fj[h&511](b&16777215,i);return}}function M8(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=a[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=d&255;f=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;c[291677]=e;c[291678]=e;c[291679]=0;c[291680]=0;f=g>>>16&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=d;return}else{fj[h&511](g&16777215,e);return}}function M9(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=a[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;b=d>>>16&255;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g;return}else{fj[h&511](d&16777215,f);return}}function Na(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&255;f=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;c[291677]=d;c[291678]=d;c[291679]=0;c[291680]=0;f=g>>>16&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=e&255;return}else{fj[h&511](g&16777215,d);return}}function Nb(){var b=0,d=0,e=0,f=0,g=0;b=c[291673]|0;d=c[1166604+((b&7)<<2)>>2]|0;e=d&255;f=1166604+((b>>>9&7|8)<<2)|0;b=(c[f>>2]|0)-1|0;c[f>>2]=b;c[291677]=e;c[291678]=e;c[291679]=0;c[291680]=0;f=b>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[g&511](b&16777215,e);return}}function Nc(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291673]|0;e=c[1166604+((b&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0;i=b}else{b=fl[g&255](e&16777215)|0;h=b;i=c[291673]|0}b=1166604+((i>>>9&7|8)<<2)|0;i=(c[b>>2]|0)-1|0;c[b>>2]=i;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;b=i>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(i&65535^1)|0]=h&255;return}else{fj[e&511](i&16777215,h);return}}function Nd(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;e=f>>>16&255;b=c[1161476+(e*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[b&511](f&16777215,g);return}}function Ne(){var b=0,e=0,f=0,g=0;b=c[291666]|0;c[291666]=b+2;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;b=f>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function Nf(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;e=f>>>16&255;b=c[1161476+(e*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[b&511](f&16777215,g);return}}function Ng(){var b=0,e=0,f=0,g=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;b=f>>>16&255;e=c[1161476+(b*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function Nh(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=h>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){i=d[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;j=e}else{e=fl[g&255](h&16777215)|0;i=e;j=c[291673]|0}e=1166604+((j>>>9&7|8)<<2)|0;j=(c[e>>2]|0)-1|0;c[e>>2]=j;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;e=j>>>16&255;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(j&65535^1)|0]=i&255;return}else{fj[h&511](j&16777215,i);return}}function Ni(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=g<<16>>16}else{i=g}g=(h<<24>>24)+f+i|0;i=g>>>16&255;f=c[1161468+(i*20|0)>>2]|0;if((f|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]|0;k=b}else{b=fl[f&255](g&16777215)|0;j=b;k=c[291673]|0}b=1166604+((k>>>9&7|8)<<2)|0;k=(c[b>>2]|0)-1|0;c[b>>2]=k;c[291677]=j;c[291678]=j;c[291679]=0;c[291680]=0;b=k>>>16&255;g=c[1161476+(b*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(k&65535^1)|0]=j&255;return}else{fj[g&511](k&16777215,j);return}}function Nj(){var e=0,f=0,g=0,h=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=g>>>16&255;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function Nk(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;b=(c[f>>2]|0)-1|0;c[f>>2]=b;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;f=b>>>16&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=i&255;return}else{fj[h&511](b&16777215,i);return}}function Nl(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=a[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=d&255;f=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;c[291677]=e;c[291678]=e;c[291679]=0;c[291680]=0;f=g>>>16&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=d;return}else{fj[h&511](g&16777215,e);return}}function Nm(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=a[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;b=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;b=d>>>16&255;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(d&65535^1)|0]=g;return}else{fj[h&511](d&16777215,f);return}}function Nn(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&255;f=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;c[291677]=d;c[291678]=d;c[291679]=0;c[291680]=0;f=g>>>16&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=e&255;return}else{fj[h&511](g&16777215,d);return}}function No(){var d=0,e=0,f=0,g=0,h=0;d=c[291673]|0;e=c[1166604+((d&7)<<2)>>2]|0;f=e&255;g=c[1166604+((d>>>9&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;h=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;g=h>>>16&255;d=c[1161476+(g*20|0)>>2]|0;if((d|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]=e&255;return}else{fj[d&511](h&16777215,f);return}}function Np(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=f>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]|0;j=e}else{e=fl[h&255](f&16777215)|0;i=e;j=c[291673]|0}e=c[1166604+((j>>>9&7|8)<<2)>>2]|0;j=c[291667]|0;c[291667]=j+2;f=(b[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0)+e|0;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;e=f>>>16&255;j=c[1161476+(e*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[j&511](f&16777215,i);return}}function Nq(){var e=0,f=0,g=0,h=0;e=1166604+((c[291673]&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+1;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;e=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function Nr(){var e=0,f=0,g=0,h=0;e=c[291666]|0;c[291666]=e+2;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}e=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;f=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+e|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[g&511](f&16777215,h);return}}function Ns(){var e=0,f=0,g=0,h=0;e=1166604+((c[291673]&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;e=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[g&511](e&16777215,h);return}}function Nt(){var e=0,f=0,g=0,h=0;e=(c[291666]|0)-2|0;c[291666]=e;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}e=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;f=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+e|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;e=f>>>16&255;g=c[1161476+(e*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[g&511](f&16777215,h);return}}function Nu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[291673]|0;f=c[1166604+((e&7|8)<<2)>>2]|0;g=c[291667]|0;h=g+2|0;c[291667]=h;i=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=i>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){j=d[(c[1161464+(f*20|0)>>2]|0)+(i&65535^1)|0]|0;k=e;l=h}else{h=fl[g&255](i&16777215)|0;j=h;k=c[291673]|0;l=c[291667]|0}h=c[1166604+((k>>>9&7|8)<<2)>>2]|0;c[291667]=l+2;k=(b[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0)+h|0;c[291677]=j;c[291678]=j;c[291679]=0;c[291680]=0;h=k>>>16&255;l=c[1161476+(h*20|0)>>2]|0;if((l|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(k&65535^1)|0]=j&255;return}else{fj[l&511](k&16777215,j);return}}function Nv(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[291673]|0;g=c[1166604+((f&7|8)<<2)>>2]|0;h=c[291667]|0;i=h+2|0;c[291667]=i;j=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=c[1166604+(j>>>12<<2)>>2]|0;if((j&2048|0)==0){k=h<<16>>16}else{k=h}h=(j<<24>>24)+g+k|0;k=h>>>16&255;g=c[1161468+(k*20|0)>>2]|0;if((g|0)==0){l=d[(c[1161464+(k*20|0)>>2]|0)+(h&65535^1)|0]|0;m=f;n=i}else{i=fl[g&255](h&16777215)|0;l=i;m=c[291673]|0;n=c[291667]|0}i=c[1166604+((m>>>9&7|8)<<2)>>2]|0;c[291667]=n+2;m=(b[(c[1161464+((n>>>16&255)*20|0)>>2]|0)+(n&65535)>>1]|0)+i|0;c[291677]=l;c[291678]=l;c[291679]=0;c[291680]=0;i=m>>>16&255;n=c[1161476+(i*20|0)>>2]|0;if((n|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(m&65535^1)|0]=l&255;return}else{fj[n&511](m&16777215,l);return}}function Nw(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;j=f}else{f=fl[h&255](g&16777215)|0;i=f;j=c[291667]|0}f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=j+2;g=(b[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0)+f|0;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;f=g>>>16&255;j=c[1161476+(f*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[j&511](g&16777215,i);return}}function Nx(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[291667]|0;g=f+4|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;i=f+2|0;f=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=h&255;j=c[1161468+(i*20|0)>>2]|0;if((j|0)==0){k=d[(c[1161464+(i*20|0)>>2]|0)+(f^1)|0]|0;l=g}else{g=fl[j&255](f|h<<16&16711680)|0;k=g;l=c[291667]|0}g=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=l+2;h=(b[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0)+g|0;c[291677]=k;c[291678]=k;c[291679]=0;c[291680]=0;g=h>>>16&255;l=c[1161476+(g*20|0)>>2]|0;if((l|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(h&65535^1)|0]=k&255;return}else{fj[l&511](h&16777215,k);return}}function Ny(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;e=d+2|0;c[291667]=e;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;g=a[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;h=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=d+4;d=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+h|0;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;h=d>>>16&255;e=c[1161476+(h*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(d&65535^1)|0]=g;return}else{fj[e&511](d&16777215,f);return}}function Nz(){var d=0,f=0,g=0,h=0,i=0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;h=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){i=h<<16>>16}else{i=h}h=(g<<24>>24)+d+i|0;i=a[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535^1)|0]|0;h=i&255;g=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=d+4;d=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+g|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;g=d>>>16&255;f=c[1161476+(g*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(d&65535^1)|0]=i;return}else{fj[f&511](d&16777215,h);return}}function NA(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;e=d+2|0;c[291667]=e;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=f&255;h=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=d+4;d=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+h|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;h=d>>>16&255;e=c[1161476+(h*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(d&65535^1)|0]=f&255;return}else{fj[e&511](d&16777215,g);return}}function NB(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[291673]|0;d=c[1166604+((b&7)<<2)>>2]|0;f=d&255;g=c[1166604+((b>>>9&7|8)<<2)>>2]|0;b=c[291667]|0;c[291667]=b+2;h=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=b<<16>>16}else{i=b}b=(h<<24>>24)+g+i|0;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;i=b>>>16&255;g=c[1161476+(i*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[g&511](b&16777215,f);return}}function NC(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=f>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]|0;j=b}else{b=fl[h&255](f&16777215)|0;i=b;j=c[291673]|0}b=c[1166604+((j>>>9&7|8)<<2)>>2]|0;j=c[291667]|0;c[291667]=j+2;f=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;j=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){k=j<<16>>16}else{k=j}j=(f<<24>>24)+b+k|0;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;k=j>>>16&255;b=c[1161476+(k*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(k*20|0)>>2]|0)+(j&65535^1)|0]=i&255;return}else{fj[b&511](j&16777215,i);return}}function ND(){var b=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;b=f>>>16&255;g=c[1161468+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){i=g<<16>>16}else{i=g}g=(b<<24>>24)+f+i|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;i=g>>>16&255;f=c[1161476+(i*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function NE(){var b=0,f=0,g=0,h=0,i=0;b=c[291666]|0;c[291666]=b+2;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}b=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){i=g<<16>>16}else{i=g}g=(f<<24>>24)+b+i|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;i=g>>>16&255;b=c[1161476+(i*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[b&511](g&16777215,h);return}}function NF(){var b=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;g=c[1161468+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){i=g<<16>>16}else{i=g}g=(b<<24>>24)+f+i|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;i=g>>>16&255;f=c[1161476+(i*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function NG(){var b=0,f=0,g=0,h=0,i=0;b=(c[291666]|0)-2|0;c[291666]=b;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}b=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;g=c[291667]|0;c[291667]=g+2;f=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){i=g<<16>>16}else{i=g}g=(f<<24>>24)+b+i|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;i=g>>>16&255;b=c[1161476+(i*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[b&511](g&16777215,h);return}}function NH(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[291673]|0;g=c[1166604+((f&7|8)<<2)>>2]|0;h=c[291667]|0;i=h+2|0;c[291667]=i;j=(b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0)+g|0;g=j>>>16&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){k=d[(c[1161464+(g*20|0)>>2]|0)+(j&65535^1)|0]|0;l=f;m=i}else{i=fl[h&255](j&16777215)|0;k=i;l=c[291673]|0;m=c[291667]|0}i=c[1166604+((l>>>9&7|8)<<2)>>2]|0;c[291667]=m+2;l=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0;m=c[1166604+(l>>>12<<2)>>2]|0;if((l&2048|0)==0){n=m<<16>>16}else{n=m}m=(l<<24>>24)+i+n|0;c[291677]=k;c[291678]=k;c[291679]=0;c[291680]=0;n=m>>>16&255;i=c[1161476+(n*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(n*20|0)>>2]|0)+(m&65535^1)|0]=k&255;return}else{fj[i&511](m&16777215,k);return}}function NI(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[291673]|0;f=c[1166604+((b&7|8)<<2)>>2]|0;g=c[291667]|0;h=g+2|0;c[291667]=h;i=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(i>>>12<<2)>>2]|0;if((i&2048|0)==0){j=g<<16>>16}else{j=g}g=(i<<24>>24)+f+j|0;j=g>>>16&255;f=c[1161468+(j*20|0)>>2]|0;if((f|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]|0;l=b;m=h}else{h=fl[f&255](g&16777215)|0;k=h;l=c[291673]|0;m=c[291667]|0}h=c[1166604+((l>>>9&7|8)<<2)>>2]|0;c[291667]=m+2;l=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0;m=c[1166604+(l>>>12<<2)>>2]|0;if((l&2048|0)==0){n=m<<16>>16}else{n=m}m=(l<<24>>24)+h+n|0;c[291677]=k;c[291678]=k;c[291679]=0;c[291680]=0;n=m>>>16&255;h=c[1161476+(n*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(n*20|0)>>2]|0)+(m&65535^1)|0]=k&255;return}else{fj[h&511](m&16777215,k);return}}function NJ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=h>>>16&255;i=c[1161468+(f*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;k=g}else{g=fl[i&255](h&16777215)|0;j=g;k=c[291667]|0}g=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=k+2;h=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;k=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){l=k<<16>>16}else{l=k}k=(h<<24>>24)+g+l|0;c[291677]=j;c[291678]=j;c[291679]=0;c[291680]=0;l=k>>>16&255;g=c[1161476+(l*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(l*20|0)>>2]|0)+(k&65535^1)|0]=j&255;return}else{fj[g&511](k&16777215,j);return}}function NK(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[291667]|0;f=b+4|0;c[291667]=f;g=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;h=b+2|0;b=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=g&255;i=c[1161468+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]|0;k=f}else{f=fl[i&255](b|g<<16&16711680)|0;j=f;k=c[291667]|0}f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=k+2;g=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;k=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){l=k<<16>>16}else{l=k}k=(g<<24>>24)+f+l|0;c[291677]=j;c[291678]=j;c[291679]=0;c[291680]=0;l=k>>>16&255;f=c[1161476+(l*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(l*20|0)>>2]|0)+(k&65535^1)|0]=j&255;return}else{fj[f&511](k&16777215,j);return}}function NL(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;h=a[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=h&255;i=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=d+4;d=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){j=f<<16>>16}else{j=f}f=(d<<24>>24)+i+j|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;j=f>>>16&255;i=c[1161476+(j*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f&65535^1)|0]=h;return}else{fj[i&511](f&16777215,g);return}}function NM(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[291667]|0;d=b+2|0;c[291667]=d;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+b+h|0;h=a[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=h&255;f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=b+4;b=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){i=d<<16>>16}else{i=d}d=(b<<24>>24)+f+i|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;i=d>>>16&255;f=c[1161476+(i*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(d&65535^1)|0]=h;return}else{fj[f&511](d&16777215,g);return}}function NN(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;h=g&255;i=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=d+4;d=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){j=f<<16>>16}else{j=f}f=(d<<24>>24)+i+j|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;j=f>>>16&255;i=c[1161476+(j*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[i&511](f&16777215,h);return}}function NO(){var d=0,e=0,f=0,g=0,h=0;d=c[1166604+((c[291673]&7)<<2)>>2]|0;e=d&255;f=c[291667]|0;c[291667]=f+2;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=e;c[291678]=e;c[291679]=0;c[291680]=0;f=g>>>16&255;h=c[1161476+(f*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=d&255;return}else{fj[h&511](g&16777215,e);return}}function NP(){var e=0,f=0,g=0,h=0;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}e=c[291667]|0;c[291667]=e+2;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;e=g>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function NQ(){var e=0,f=0,g=0,h=0;e=1166604+((c[291673]&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+1;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[291667]|0;c[291667]=f+2;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=g>>>16&255;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function NR(){var e=0,f=0,g=0,h=0;e=c[291666]|0;c[291666]=e+2;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}e=c[291667]|0;c[291667]=e+2;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;e=g>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function NS(){var e=0,f=0,g=0,h=0;e=1166604+((c[291673]&7|8)<<2)|0;f=(c[e>>2]|0)-1|0;c[e>>2]=f;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[291667]|0;c[291667]=f+2;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=g>>>16&255;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function NT(){var e=0,f=0,g=0,h=0;e=(c[291666]|0)-2|0;c[291666]=e;f=e>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}e=c[291667]|0;c[291667]=e+2;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;e=g>>>16&255;f=c[1161476+(e*20|0)>>2]|0;if((f|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[f&511](g&16777215,h);return}}function NU(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=h>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(h&65535^1)|0]|0;j=g}else{g=fl[f&255](h&16777215)|0;i=g;j=c[291667]|0}c[291667]=j+2;g=b[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;j=g>>>16&255;h=c[1161476+(j*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]=i&255;return}else{fj[h&511](g&16777215,i);return}}function NV(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=c[291667]|0;h=g+2|0;c[291667]=h;i=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=c[1166604+(i>>>12<<2)>>2]|0;if((i&2048|0)==0){j=g<<16>>16}else{j=g}g=(i<<24>>24)+f+j|0;j=g>>>16&255;f=c[1161468+(j*20|0)>>2]|0;if((f|0)==0){k=d[(c[1161464+(j*20|0)>>2]|0)+(g&65535^1)|0]|0;l=h}else{h=fl[f&255](g&16777215)|0;k=h;l=c[291667]|0}c[291667]=l+2;h=b[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;c[291677]=k;c[291678]=k;c[291679]=0;c[291680]=0;l=h>>>16&255;g=c[1161476+(l*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(l*20|0)>>2]|0)+(h&65535^1)|0]=k&255;return}else{fj[g&511](h&16777215,k);return}}function NW(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[291667]|0;f=e+2|0;c[291667]=f;g=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=g>>>16&255;h=c[1161468+(e*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0;j=f}else{f=fl[h&255](g&16777215)|0;i=f;j=c[291667]|0}c[291667]=j+2;f=b[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;j=f>>>16&255;g=c[1161476+(j*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(j*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[g&511](f&16777215,i);return}}function NX(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[291667]|0;g=f+4|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;i=f+2|0;f=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=h&255;j=c[1161468+(i*20|0)>>2]|0;if((j|0)==0){k=d[(c[1161464+(i*20|0)>>2]|0)+(f^1)|0]|0;l=g}else{g=fl[j&255](f|h<<16&16711680)|0;k=g;l=c[291667]|0}c[291667]=l+2;g=b[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;c[291677]=k;c[291678]=k;c[291679]=0;c[291680]=0;l=g>>>16&255;h=c[1161476+(l*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(l*20|0)>>2]|0)+(g&65535^1)|0]=k&255;return}else{fj[h&511](g&16777215,k);return}}function NY(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;e=d+2|0;c[291667]=e;f=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;g=a[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;c[291667]=d+4;d=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;e=d>>>16&255;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=g;return}else{fj[h&511](d&16777215,f);return}}function NZ(){var d=0,f=0,g=0,h=0,i=0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;h=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){i=h<<16>>16}else{i=h}h=(g<<24>>24)+d+i|0;i=a[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535^1)|0]|0;h=i&255;c[291667]=d+4;d=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=d>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(d&65535^1)|0]=i;return}else{fj[g&511](d&16777215,h);return}}function N_(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;e=d+2|0;c[291667]=e;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=f&255;c[291667]=d+4;d=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;e=d>>>16&255;h=c[1161476+(e*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(d&65535^1)|0]=f&255;return}else{fj[h&511](d&16777215,g);return}}function N$(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[1166604+((c[291673]&7)<<2)>>2]|0;d=b&255;f=c[291667]|0;c[291667]=f+4;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;c[291677]=d;c[291678]=d;c[291679]=0;c[291680]=0;h=g&255;i=c[1161476+(h*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(f^1)|0]=b&255;return}else{fj[i&511](f|g<<16&16711680,d);return}}function N0(){var b=0,f=0,g=0,h=0,i=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}b=c[291667]|0;c[291667]=b+4;g=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=g&255;i=c[1161476+(f*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b^1)|0]=h&255;return}else{fj[i&511](b|g<<16&16711680,h);return}}function N1(){var b=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;b=f>>>16&255;g=c[1161468+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[291667]|0;c[291667]=f+4;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;b=f+2|0;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;b=g&255;i=c[1161476+(b*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f^1)|0]=h&255;return}else{fj[i&511](f|g<<16&16711680,h);return}}function N2(){var b=0,f=0,g=0,h=0,i=0;b=c[291666]|0;c[291666]=b+2;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}b=c[291667]|0;c[291667]=b+4;g=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=g&255;i=c[1161476+(f*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b^1)|0]=h&255;return}else{fj[i&511](b|g<<16&16711680,h);return}}function N3(){var b=0,f=0,g=0,h=0,i=0;b=1166604+((c[291673]&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=f>>>16&255;g=c[1161468+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[291667]|0;c[291667]=f+4;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;b=f+2|0;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;b=g&255;i=c[1161476+(b*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f^1)|0]=h&255;return}else{fj[i&511](f|g<<16&16711680,h);return}}function N4(){var b=0,f=0,g=0,h=0,i=0;b=(c[291666]|0)-2|0;c[291666]=b;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}b=c[291667]|0;c[291667]=b+4;g=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=g&255;i=c[1161476+(f*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b^1)|0]=h&255;return}else{fj[i&511](b|g<<16&16711680,h);return}}function N5(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[1166604+((c[291673]&7|8)<<2)>>2]|0;g=c[291667]|0;h=g+2|0;c[291667]=h;i=(b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0)+f|0;f=i>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){j=d[(c[1161464+(f*20|0)>>2]|0)+(i&65535^1)|0]|0;k=h}else{h=fl[g&255](i&16777215)|0;j=h;k=c[291667]|0}c[291667]=k+4;h=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;i=k+2|0;k=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;c[291677]=j;c[291678]=j;c[291679]=0;c[291680]=0;i=h&255;g=c[1161476+(i*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(k^1)|0]=j&255;return}else{fj[g&511](k|h<<16&16711680,j);return}}function N6(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=f<<16>>16}else{i=f}f=(h<<24>>24)+b+i|0;i=f>>>16&255;b=c[1161468+(i*20|0)>>2]|0;if((b|0)==0){j=d[(c[1161464+(i*20|0)>>2]|0)+(f&65535^1)|0]|0;k=g}else{g=fl[b&255](f&16777215)|0;j=g;k=c[291667]|0}c[291667]=k+4;g=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;f=k+2|0;k=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=j;c[291678]=j;c[291679]=0;c[291680]=0;f=g&255;b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(k^1)|0]=j&255;return}else{fj[b&511](k|g<<16&16711680,j);return}}function N7(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=h>>>16&255;i=c[1161468+(f*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(f*20|0)>>2]|0)+(h&65535^1)|0]|0;k=g}else{g=fl[i&255](h&16777215)|0;j=g;k=c[291667]|0}c[291667]=k+4;g=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;h=k+2|0;k=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;c[291677]=j;c[291678]=j;c[291679]=0;c[291680]=0;h=g&255;i=c[1161476+(h*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(k^1)|0]=j&255;return}else{fj[i&511](k|g<<16&16711680,j);return}}function N8(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[291667]|0;f=b+4|0;c[291667]=f;g=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;h=b+2|0;b=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=g&255;i=c[1161468+(h*20|0)>>2]|0;if((i|0)==0){j=d[(c[1161464+(h*20|0)>>2]|0)+(b^1)|0]|0;k=f}else{f=fl[i&255](b|g<<16&16711680)|0;j=f;k=c[291667]|0}c[291667]=k+4;f=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;g=k+2|0;k=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;c[291677]=j;c[291678]=j;c[291679]=0;c[291680]=0;g=f&255;b=c[1161476+(g*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(k^1)|0]=j&255;return}else{fj[b&511](k|f<<16&16711680,j);return}}function N9(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;h=a[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=h&255;c[291667]=d+6;i=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d+4|0;d=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=i&255;j=c[1161476+(f*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(d^1)|0]=h;return}else{fj[j&511](d|i<<16&16711680,g);return}}function Oa(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[291667]|0;d=b+2|0;c[291667]=d;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+b+h|0;h=a[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535^1)|0]|0;g=h&255;c[291667]=b+6;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=b+4|0;b=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;d=f&255;i=c[1161476+(d*20|0)>>2]|0;if((i|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b^1)|0]=h;return}else{fj[i&511](b|f<<16&16711680,g);return}}function Ob(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;h=g&255;c[291667]=d+6;i=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d+4|0;d=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=i&255;j=c[1161476+(f*20|0)>>2]|0;if((j|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(d^1)|0]=g&255;return}else{fj[j&511](d|i<<16&16711680,h);return}}function Oc(){var b=0,d=0,e=0,f=0,g=0;b=c[1166604+((c[291673]&7)<<2)>>2]|0;d=b&255;e=c[291666]|0;c[291666]=e+2;c[291677]=d;c[291678]=d;c[291679]=0;c[291680]=0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[g&511](e&16777215,d);return}}function Od(){var b=0,e=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=c[291666]|0;c[291666]=b+2;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=b>>>16&255;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,g);return}}function Oe(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[291666]|0;c[291666]=e+2;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=e>>>16&255;b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function Of(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291666]|0;e=b+2|0;c[291666]=e;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0;i=e}else{e=fl[g&255](b&16777215)|0;h=e;i=c[291666]|0}c[291666]=i+2;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;e=i>>>16&255;b=c[1161476+(e*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(i&65535^1)|0]=h&255;return}else{fj[b&511](i&16777215,h);return}}function Og(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=c[291666]|0;c[291666]=e+2;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=e>>>16&255;b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function Oh(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[291666]|0}c[291666]=h+2;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;e=h>>>16&255;b=c[1161476+(e*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(e*20|0)>>2]|0)+(h&65535^1)|0]=g&255;return}else{fj[b&511](h&16777215,g);return}}function Oi(){var e=0,f=0,g=0,h=0;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}g=c[291666]|0;c[291666]=g+2;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=g>>>16&255;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function Oj(){var b=0,f=0,g=0,h=0,i=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}f=c[291666]|0;c[291666]=f+2;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;b=f>>>16&255;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function Ok(){var e=0,f=0,g=0,h=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=c[291666]|0;c[291666]=f+2;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;g=f>>>16&255;e=c[1161476+(g*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[e&511](f&16777215,h);return}}function Ol(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=c[291666]|0;c[291666]=f+2;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;b=f>>>16&255;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function Om(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=a[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=d&255;f=c[291666]|0;c[291666]=f+2;c[291677]=e;c[291678]=e;c[291679]=0;c[291680]=0;g=f>>>16&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=d;return}else{fj[h&511](f&16777215,e);return}}function On(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=a[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;b=c[291666]|0;c[291666]=b+2;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;d=b>>>16&255;h=c[1161476+(d*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=g;return}else{fj[h&511](b&16777215,f);return}}function Oo(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&255;f=c[291666]|0;c[291666]=f+2;c[291677]=d;c[291678]=d;c[291679]=0;c[291680]=0;g=f>>>16&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[h&511](f&16777215,d);return}}function Op(){var b=0,d=0,e=0,f=0,g=0;b=c[1166604+((c[291673]&7)<<2)>>2]|0;d=b&255;e=(c[291666]|0)-2|0;c[291666]=e;c[291677]=d;c[291678]=d;c[291679]=0;c[291680]=0;f=e>>>16&255;g=c[1161476+(f*20|0)>>2]|0;if((g|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=b&255;return}else{fj[g&511](e&16777215,d);return}}function Oq(){var b=0,e=0,f=0,g=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}b=(c[291666]|0)-2|0;c[291666]=b;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=b>>>16&255;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,g);return}}function Or(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[291666]|0)-2|0;c[291666]=e;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=e>>>16&255;b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function Os(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[291666]|0;e=b+2|0;c[291666]=e;f=b>>>16&255;g=c[1161468+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(f*20|0)>>2]|0)+(b&65535^1)|0]|0;i=e}else{e=fl[g&255](b&16777215)|0;h=e;i=c[291666]|0}e=i-2|0;c[291666]=e;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;i=e>>>16&255;b=c[1161476+(i*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(i*20|0)>>2]|0)+(e&65535^1)|0]=h&255;return}else{fj[b&511](e&16777215,h);return}}function Ot(){var b=0,e=0,f=0,g=0;b=1166604+((c[291673]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[1161468+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}e=(c[291666]|0)-2|0;c[291666]=e;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;f=e>>>16&255;b=c[1161476+(f*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function Ou(){var b=0,e=0,f=0,g=0,h=0;b=(c[291666]|0)-2|0;c[291666]=b;e=b>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[1161464+(e*20|0)>>2]|0)+(b&65535^1)|0]|0;h=b}else{e=fl[f&255](b&16777215)|0;g=e;h=c[291666]|0}e=h-2|0;c[291666]=e;c[291677]=g;c[291678]=g;c[291679]=0;c[291680]=0;h=e>>>16&255;b=c[1161476+(h*20|0)>>2]|0;if((b|0)==0){a[(c[1161464+(h*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,g);return}}function Ov(){var e=0,f=0,g=0,h=0;e=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[1161468+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}g=(c[291666]|0)-2|0;c[291666]=g;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;f=g>>>16&255;e=c[1161476+(f*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,h);return}}function Ow(){var b=0,f=0,g=0,h=0,i=0;b=c[1166604+((c[291673]&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[1161468+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[1161464+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}f=(c[291666]|0)-2|0;c[291666]=f;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;b=f>>>16&255;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function Ox(){var e=0,f=0,g=0,h=0;e=c[291667]|0;c[291667]=e+2;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[1161468+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[1161464+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}f=(c[291666]|0)-2|0;c[291666]=f;c[291677]=h;c[291678]=h;c[291679]=0;c[291680]=0;g=f>>>16&255;e=c[1161476+(g*20|0)>>2]|0;if((e|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=h&255;return}else{fj[e&511](f&16777215,h);return}}function Oy(){var a=0,b=0;a=c[291673]|0;b=c[1166604+((a&7)<<2)>>2]|0;c[1166604+((a>>>9&7)<<2)>>2]=b;c[291677]=b>>>24;c[291678]=b;c[291679]=0;c[291680]=0;return}function Oz(){var a=0,b=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;c[1166604+((a>>>9&7)<<2)>>2]=b;c[291677]=b>>>24;c[291678]=b;c[291679]=0;c[291680]=0;return}function OA(){var a=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;f=d+2|0;d=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|a<<16;c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]=d;c[291677]=a>>>8;c[291678]=d;c[291679]=0;c[291680]=0;return}function OB(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;a=d+2|0;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|f<<16;c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]=d;c[291677]=f>>>8;c[291678]=d;c[291679]=0;c[291680]=0;return}function OC(){var a=0,b=0,d=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|b<<16;c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]=a;c[291677]=b>>>8;c[291678]=a;c[291679]=0;c[291680]=0;return}function OD(){var a=0;a=c[291673]|0;c[1166604+((a>>>9&7|8)<<2)>>2]=c[1166604+((a&7)<<2)>>2];return}function OE(){var a=0;a=c[291673]|0;c[1166604+((a>>>9&7|8)<<2)>>2]=c[1166604+((a&7|8)<<2)>>2];return}function OF(){var b=0,f=0,g=0,h=0,i=0;b=c[291667]|0;c[291667]=b+4;f=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[1161468+(g*20|0)>>2]|0;if((h|0)==0){i=d[(c[1161464+(g*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[h&255](b|f<<16&16711680)|0}f=(c[291666]|0)-2|0;c[291666]=f;c[291677]=i;c[291678]=i;c[291679]=0;c[291680]=0;b=f>>>16&255;h=c[1161476+(b*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(f&65535^1)|0]=i&255;return}else{fj[h&511](f&16777215,i);return}}function OG(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;c[291667]=d+2;e=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=a[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535^1)|0]|0;e=d&255;f=(c[291666]|0)-2|0;c[291666]=f;c[291677]=e;c[291678]=e;c[291679]=0;c[291680]=0;g=f>>>16&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=d;return}else{fj[h&511](f&16777215,e);return}}function OH(){var b=0,d=0,f=0,g=0,h=0;b=c[291667]|0;c[291667]=b+2;d=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=a[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;f=g&255;b=(c[291666]|0)-2|0;c[291666]=b;c[291677]=f;c[291678]=f;c[291679]=0;c[291680]=0;d=b>>>16&255;h=c[1161476+(d*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(d*20|0)>>2]|0)+(b&65535^1)|0]=g;return}else{fj[h&511](b&16777215,f);return}}function OI(){var d=0,e=0,f=0,g=0,h=0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e&255;f=(c[291666]|0)-2|0;c[291666]=f;c[291677]=d;c[291678]=d;c[291679]=0;c[291680]=0;g=f>>>16&255;h=c[1161476+(g*20|0)>>2]|0;if((h|0)==0){a[(c[1161464+(g*20|0)>>2]|0)+(f&65535^1)|0]=e&255;return}else{fj[h&511](f&16777215,d);return}}function OJ(){var a=0;a=ahi()|0;c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]=a;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;return}function OK(){var a=0;a=ahh()|0;c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]=a;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;return}function OL(){var a=0;a=ahg()|0;c[1166604+(((c[291673]|0)>>>9&7)<<2)>>2]=a;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;return}function OM(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=1161472+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;c[m>>2]=i;n=i>>>24;c[291677]=n;c[291678]=i;c[291679]=0;c[291680]=0;return}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[291673]|0;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;c[m>>2]=i;n=i>>>24;c[291677]=n;c[291678]=i;c[291679]=0;c[291680]=0;return}}function ON(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=1161472+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;i=c[291673]|0;j=i>>>9;k=j&7;l=1166604+(k<<2)|0;c[l>>2]=h;m=h>>>24;c[291677]=m;c[291678]=h;c[291679]=0;c[291680]=0;return}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a;i=c[291673]|0;j=i>>>9;k=j&7;l=1166604+(k<<2)|0;c[l>>2]=h;m=h>>>24;c[291677]=m;c[291678]=h;c[291679]=0;c[291680]=0;return}}function OO(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=c[291673]|0;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;c[m>>2]=i;n=i>>>24;c[291677]=n;c[291678]=i;c[291679]=0;c[291680]=0;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a;j=c[291673]|0;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;c[m>>2]=i;n=i>>>24;c[291677]=n;c[291678]=i;c[291679]=0;c[291680]=0;return}}function OP(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=1161472+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;c[m>>2]=i;n=i>>>24;c[291677]=n;c[291678]=i;c[291679]=0;c[291680]=0;return}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[291673]|0;k=j>>>9;l=k&7;m=1166604+(l<<2)|0;c[m>>2]=i;n=i>>>24;c[291677]=n;c[291678]=i;c[291679]=0;c[291680]=0;return}}function OQ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=1161472+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=i;return}else{a=(fl[g&255](b&16777215)|0)<<16;g=fl[c[f>>2]&255](b+2&16777215)|0|a;i=g;j=c[291673]|0;k=j>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=i;return}}function OR(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=1161472+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;i=c[291673]|0;j=i>>>9;k=j&7;l=k|8;m=1166604+(l<<2)|0;c[m>>2]=h;return}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a;i=c[291673]|0;j=i>>>9;k=j&7;l=k|8;m=1166604+(l<<2)|0;c[m>>2]=h;return}}function OS(){var a=0,d=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=d+2|0;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]<<16;return}function OT(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=d+2|0;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;return}function OU(){var a=0,b=0;a=c[291667]|0;c[291667]=a+4;b=a+2|0;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;return}function OV(){var a=0;a=ahi()|0;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=a;return}function OW(){var a=0;a=ahh()|0;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=a;return}function OX(){var a=0;a=ahg()|0;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=a;return}function OY(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=c[291673]|0;k=j>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=i;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a;j=c[291673]|0;k=j>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=i;return}}function OZ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=1161472+(g*20|0)|0;f=c[b>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=a;k=j>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=i;return}else{a=(fl[f&255](d&16777215)|0)<<16;f=fl[c[b>>2]&255](d+2&16777215)|0|a;i=f;j=c[291673]|0;k=j>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=i;return}}function O_(){var a=0,d=0,e=0,f=0;a=c[291673]|0;d=c[1166604+((a&7)<<2)>>2]|0;e=c[1166604+((a>>>9&7|8)<<2)>>2]|0;c[291677]=d>>>24;c[291678]=d;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=e>>>16&255;f=c[1161480+(a*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(e&65535)>>1]=d>>>16&65535}else{fj[f&511](e&16777215,d>>>16)}f=e+2|0;e=f>>>16&255;a=c[1161480+(e*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[a&511](f&16777215,d&65535);return}}function O$(){var a=0,d=0,e=0,f=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;e=c[1166604+((a>>>9&7|8)<<2)>>2]|0;c[291677]=d>>>24;c[291678]=d;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=e>>>16&255;f=c[1161480+(a*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(e&65535)>>1]=d>>>16&65535}else{fj[f&511](e&16777215,d>>>16)}f=e+2|0;e=f>>>16&255;a=c[1161480+(e*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[a&511](f&16777215,d&65535);return}}function O0(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291688]|0;if((d&1|0)!=0&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;l=a;m=f}else{f=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|f;k=i;l=c[291673]|0;m=c[291688]|0}i=c[1166604+((l>>>9&7|8)<<2)>>2]|0;c[291677]=k>>>24;c[291678]=k;c[291679]=0;c[291680]=0;if((i&1|0)!=0&(m|0)!=0){m=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=i>>>16&255;l=c[1161480+(m*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+(i&65535)>>1]=k>>>16&65535}else{fj[l&511](i&16777215,k>>>16)}l=i+2|0;i=l>>>16&255;m=c[1161480+(i*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(l&65535)>>1]=k&65535;return}else{fj[m&511](l&16777215,k&65535);return}}function O1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=1161472+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[291688]|0}h=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((h&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=h>>>16&255;a=c[1161480+(k*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(h&65535)>>1]=j>>>16&65535}else{fj[a&511](h&16777215,j>>>16)}a=h+2|0;h=a>>>16&255;k=c[1161480+(h*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[k&511](a&16777215,j&65535);return}}function O2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[291688]|0;if((f&1|0)!=0&(a|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;l=a}else{a=(fl[i&255](f&16777215)|0)<<16;f=fl[c[h>>2]&255](d+16777214&16777215)|0|a;k=f;l=c[291688]|0}f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=k>>>24;c[291678]=k;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(l|0)!=0){l=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=f>>>16&255;a=c[1161480+(l*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(f&65535)>>1]=k>>>16&65535}else{fj[a&511](f&16777215,k>>>16)}a=f+2|0;f=a>>>16&255;l=c[1161480+(f*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]=k&65535;return}else{fj[l&511](a&16777215,k&65535);return}}function O3(){var a=0,d=0,e=0,f=0;a=ahi()|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=d>>>16&255;f=c[1161480+(e*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(d&65535)>>1]=a>>>16&65535}else{fj[f&511](d&16777215,a>>>16)}f=d+2|0;d=f>>>16&255;e=c[1161480+(d*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[e&511](f&16777215,a&65535);return}}function O4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[291688]|0;if((f&1|0)!=0&(h|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=1161472+(d*20|0)|0;i=c[g>>2]|0;if((i|0)==0){j=f+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;l=a;m=h}else{h=(fl[i&255](f&16777215)|0)<<16;i=fl[c[g>>2]&255](f+2&16777215)|0|h;k=i;l=c[291673]|0;m=c[291688]|0}i=c[1166604+((l>>>9&7|8)<<2)>>2]|0;c[291677]=k>>>24;c[291678]=k;c[291679]=0;c[291680]=0;if((i&1|0)!=0&(m|0)!=0){m=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=i>>>16&255;l=c[1161480+(m*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+(i&65535)>>1]=k>>>16&65535}else{fj[l&511](i&16777215,k>>>16)}l=i+2|0;i=l>>>16&255;m=c[1161480+(i*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(l&65535)>>1]=k&65535;return}else{fj[m&511](l&16777215,k&65535);return}}function O5(){var a=0,d=0,e=0,f=0;a=ahh()|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=d>>>16&255;f=c[1161480+(e*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(d&65535)>>1]=a>>>16&65535}else{fj[f&511](d&16777215,a>>>16)}f=d+2|0;d=f>>>16&255;e=c[1161480+(d*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[e&511](f&16777215,a&65535);return}}function O6(){var a=0,d=0,e=0,f=0;a=ahg()|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=d>>>16&255;f=c[1161480+(e*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(d&65535)>>1]=a>>>16&65535}else{fj[f&511](d&16777215,a>>>16)}f=d+2|0;d=f>>>16&255;e=c[1161480+(d*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[e&511](f&16777215,a&65535);return}}function O7(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;e=a&65535;f=d+2|0;d=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&65535;g=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=e>>>8;c[291678]=f|e<<16;c[291679]=0;c[291680]=0;if((g&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=c[1161480+(h*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=a}else{fj[i&511](g&16777215,e)}e=g+2|0;g=e>>>16&255;i=c[1161480+(g*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(e&65535)>>1]=d;return}else{fj[i&511](e&16777215,f);return}}function O8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;a=g&65535;d=f+2|0;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f&65535;h=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=a>>>8;c[291678]=d|a<<16;c[291679]=0;c[291680]=0;if((h&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=h>>>16&255;j=c[1161480+(i*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(h&65535)>>1]=g}else{fj[j&511](h&16777215,a)}a=h+2|0;h=a>>>16&255;j=c[1161480+(h*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=f;return}else{fj[j&511](a&16777215,d);return}}function O9(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291667]|0;c[291667]=a+4;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;e=d&65535;f=a+2|0;a=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a&65535;g=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=e>>>8;c[291678]=f|e<<16;c[291679]=0;c[291680]=0;if((g&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;i=c[1161480+(h*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=d}else{fj[i&511](g&16777215,e)}e=g+2|0;g=e>>>16&255;i=c[1161480+(g*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(e&65535)>>1]=a;return}else{fj[i&511](e&16777215,f);return}}function Pa(){var a=0,d=0,e=0,f=0;a=c[291673]|0;d=c[1166604+((a&7)<<2)>>2]|0;e=1166604+((a>>>9&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+4;c[291677]=d>>>24;c[291678]=d;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=a>>>16&255;f=c[1161480+(e*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535}else{fj[f&511](a&16777215,d>>>16)}f=a+2|0;a=f>>>16&255;e=c[1161480+(a*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[e&511](f&16777215,d&65535);return}}function Pb(){var a=0,d=0,e=0,f=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;e=1166604+((a>>>9&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+4;c[291677]=d>>>24;c[291678]=d;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=a>>>16&255;f=c[1161480+(e*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535}else{fj[f&511](a&16777215,d>>>16)}f=a+2|0;a=f>>>16&255;e=c[1161480+(a*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[e&511](f&16777215,d&65535);return}}function Pc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=1161472+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[291673]|0}h=1166604+((k>>>9&7|8)<<2)|0;k=c[h>>2]|0;c[h>>2]=k+4;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((k&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=k;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=k>>>16&255;a=c[1161480+(h*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(k&65535)>>1]=j>>>16&65535}else{fj[a&511](k&16777215,j>>>16)}a=k+2|0;k=a>>>16&255;h=c[1161480+(k*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[h&511](a&16777215,j&65535);return}}function Pd(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;c[291677]=i>>>24;c[291678]=i;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161480+(a*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[f&511](d&16777215,i>>>16)}f=d+2|0;d=f>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[a&511](f&16777215,i&65535);return}}function Pe(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=1161472+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[g&511](d&16777215,j>>>16)}g=d+2|0;d=g>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[a&511](g&16777215,j&65535);return}}function Pf(){var a=0,d=0,e=0,f=0;a=ahi()|0;d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;e=c[d>>2]|0;c[d>>2]=e+4;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=e>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=a>>>16&65535}else{fj[f&511](e&16777215,a>>>16)}f=e+2|0;e=f>>>16&255;d=c[1161480+(e*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function Pg(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;if((f&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;d=1161472+(h*20|0)|0;g=c[d>>2]|0;if((g|0)==0){i=f+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=a}else{a=(fl[g&255](f&16777215)|0)<<16;g=fl[c[d>>2]&255](f+2&16777215)|0|a;j=g;k=c[291673]|0}g=1166604+((k>>>9&7|8)<<2)|0;k=c[g>>2]|0;c[g>>2]=k+4;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((k&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=k;c[291700]=0;c[291701]=g;eJ(1166756,1)}g=k>>>16&255;a=c[1161480+(g*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(k&65535)>>1]=j>>>16&65535}else{fj[a&511](k&16777215,j>>>16)}a=k+2|0;k=a>>>16&255;g=c[1161480+(k*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[g&511](a&16777215,j&65535);return}}function Ph(){var a=0,d=0,e=0,f=0;a=ahh()|0;d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;e=c[d>>2]|0;c[d>>2]=e+4;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=e>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=a>>>16&65535}else{fj[f&511](e&16777215,a>>>16)}f=e+2|0;e=f>>>16&255;d=c[1161480+(e*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function Pi(){var a=0,d=0,e=0,f=0;a=ahg()|0;d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;e=c[d>>2]|0;c[d>>2]=e+4;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=e>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=a>>>16&65535}else{fj[f&511](e&16777215,a>>>16)}f=e+2|0;e=f>>>16&255;d=c[1161480+(e*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function Pj(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;e=a&65535;f=d+2|0;d=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&65535;g=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;h=c[g>>2]|0;c[g>>2]=h+4;c[291677]=e>>>8;c[291678]=f|e<<16;c[291679]=0;c[291680]=0;if((h&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=g;eJ(1166756,1)}g=h>>>16&255;i=c[1161480+(g*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(h&65535)>>1]=a}else{fj[i&511](h&16777215,e)}e=h+2|0;h=e>>>16&255;i=c[1161480+(h*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(e&65535)>>1]=d;return}else{fj[i&511](e&16777215,f);return}}function Pk(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;a=g&65535;d=f+2|0;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f&65535;h=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;i=c[h>>2]|0;c[h>>2]=i+4;c[291677]=a>>>8;c[291678]=d|a<<16;c[291679]=0;c[291680]=0;if((i&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=i>>>16&255;j=c[1161480+(h*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(i&65535)>>1]=g}else{fj[j&511](i&16777215,a)}a=i+2|0;i=a>>>16&255;j=c[1161480+(i*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=f;return}else{fj[j&511](a&16777215,d);return}}function Pl(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291667]|0;c[291667]=a+4;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;e=d&65535;f=a+2|0;a=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a&65535;g=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;h=c[g>>2]|0;c[g>>2]=h+4;c[291677]=e>>>8;c[291678]=f|e<<16;c[291679]=0;c[291680]=0;if((h&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=g;eJ(1166756,1)}g=h>>>16&255;i=c[1161480+(g*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(h&65535)>>1]=d}else{fj[i&511](h&16777215,e)}e=h+2|0;h=e>>>16&255;i=c[1161480+(h*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(e&65535)>>1]=a;return}else{fj[i&511](e&16777215,f);return}}function Pm(){var a=0,d=0,e=0,f=0,g=0;a=c[291673]|0;d=c[1166604+((a&7)<<2)>>2]|0;e=1166604+((a>>>9&7|8)<<2)|0;a=c[e>>2]|0;f=a-4|0;c[e>>2]=f;c[291677]=d>>>24;c[291678]=d;c[291679]=0;c[291680]=0;e=a-2|0;if((e&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=e>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(e&65535)>>1]=d&65535}else{fj[g&511](e&16777215,d&65535)}e=d>>>16;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=e&65535;return}else{fj[g&511](f&16777215,e);return}}function Pn(){var a=0,d=0,e=0,f=0,g=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;e=1166604+((a>>>9&7|8)<<2)|0;a=c[e>>2]|0;f=a-4|0;c[e>>2]=f;c[291677]=d>>>24;c[291678]=d;c[291679]=0;c[291680]=0;e=a-2|0;if((e&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=e>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(e&65535)>>1]=d&65535}else{fj[g&511](e&16777215,d&65535)}e=d>>>16;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=e&65535;return}else{fj[g&511](f&16777215,e);return}}function Po(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=1161472+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[291673]|0}h=1166604+((k>>>9&7|8)<<2)|0;k=c[h>>2]|0;a=k-4|0;c[h>>2]=a;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;h=k-2|0;if((h&1|0)!=0&(c[291688]|0)!=0){k=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=h>>>16&255;d=c[1161480+(k*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(h&65535)>>1]=j&65535}else{fj[d&511](h&16777215,j&65535)}h=j>>>16;if((a&1|0)!=0&(c[291688]|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=a>>>16&255;d=c[1161480+(j*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[d&511](a&16777215,h);return}}function Pp(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;c[291677]=i>>>24;c[291678]=i;c[291679]=0;c[291680]=0;a=d-2|0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;g=c[1161480+(d*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535}else{fj[g&511](a&16777215,i&65535)}a=i>>>16;if((f&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;g=c[1161480+(i*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[g&511](f&16777215,a);return}}function Pq(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=1161472+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;a=d-2|0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=j&65535}else{fj[f&511](a&16777215,j&65535)}a=j>>>16;if((g&1|0)!=0&(c[291688]|0)!=0){j=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=g>>>16&255;f=c[1161480+(j*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+(g&65535)>>1]=a&65535;return}else{fj[f&511](g&16777215,a);return}}function Pr(){var a=0,d=0,e=0,f=0,g=0;a=ahi()|0;d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;e=c[d>>2]|0;f=e-4|0;c[d>>2]=f;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;d=e-2|0;if((d&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=d>>>16&255;g=c[1161480+(e*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(d&65535)>>1]=a&65535}else{fj[g&511](d&16777215,a&65535)}d=a>>>16;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[g&511](f&16777215,d);return}}function Ps(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;if((f&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;d=1161472+(h*20|0)|0;g=c[d>>2]|0;if((g|0)==0){i=f+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=a}else{a=(fl[g&255](f&16777215)|0)<<16;g=fl[c[d>>2]&255](f+2&16777215)|0|a;j=g;k=c[291673]|0}g=1166604+((k>>>9&7|8)<<2)|0;k=c[g>>2]|0;a=k-4|0;c[g>>2]=a;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;g=k-2|0;if((g&1|0)!=0&(c[291688]|0)!=0){k=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=g>>>16&255;f=c[1161480+(k*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(g&65535)>>1]=j&65535}else{fj[f&511](g&16777215,j&65535)}g=j>>>16;if((a&1|0)!=0&(c[291688]|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=a>>>16&255;f=c[1161480+(j*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[f&511](a&16777215,g);return}}function Pt(){var a=0,d=0,e=0,f=0,g=0;a=ahh()|0;d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;e=c[d>>2]|0;f=e-4|0;c[d>>2]=f;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;d=e-2|0;if((d&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=d>>>16&255;g=c[1161480+(e*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(d&65535)>>1]=a&65535}else{fj[g&511](d&16777215,a&65535)}d=a>>>16;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[g&511](f&16777215,d);return}}function Pu(){var a=0,d=0,e=0,f=0,g=0;a=ahg()|0;d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;e=c[d>>2]|0;f=e-4|0;c[d>>2]=f;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;d=e-2|0;if((d&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=d>>>16&255;g=c[1161480+(e*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(d&65535)>>1]=a&65535}else{fj[g&511](d&16777215,a&65535)}d=a>>>16;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[g&511](f&16777215,d);return}}function Pv(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;e=a&65535;f=d+2|0;d=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&65535;g=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;h=c[g>>2]|0;i=h-4|0;c[g>>2]=i;c[291677]=e>>>8;c[291678]=f|e<<16;c[291679]=0;c[291680]=0;g=h-2|0;if((g&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;j=c[1161480+(h*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=d}else{fj[j&511](g&16777215,f)}if((i&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=i>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(i&65535)>>1]=a;return}else{fj[g&511](i&16777215,e);return}}function Pw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;a=g&65535;d=f+2|0;f=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f&65535;h=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;i=c[h>>2]|0;j=i-4|0;c[h>>2]=j;c[291677]=a>>>8;c[291678]=d|a<<16;c[291679]=0;c[291680]=0;h=i-2|0;if((h&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=h>>>16&255;k=c[1161480+(i*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(h&65535)>>1]=f}else{fj[k&511](h&16777215,d)}if((j&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=j;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=j>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(j&65535)>>1]=g;return}else{fj[h&511](j&16777215,a);return}}function Px(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+4;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;e=d&65535;f=a+2|0;a=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a&65535;g=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;h=c[g>>2]|0;i=h-4|0;c[g>>2]=i;c[291677]=e>>>8;c[291678]=f|e<<16;c[291679]=0;c[291680]=0;g=h-2|0;if((g&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=g>>>16&255;j=c[1161480+(h*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(g&65535)>>1]=a}else{fj[j&511](g&16777215,f)}if((i&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=i>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(i&65535)>>1]=d;return}else{fj[g&511](i&16777215,e);return}}function Py(){var a=0,d=0,e=0,f=0;a=c[291673]|0;d=c[1166604+((a&7)<<2)>>2]|0;e=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+e|0;c[291677]=d>>>24;c[291678]=d;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=f>>>16&255;a=c[1161480+(e*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=d>>>16&65535}else{fj[a&511](f&16777215,d>>>16)}a=f+2|0;f=a>>>16&255;e=c[1161480+(f*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[e&511](a&16777215,d&65535);return}}function Pz(){var a=0,d=0,e=0,f=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;e=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;f=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+e|0;c[291677]=d>>>24;c[291678]=d;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=f>>>16&255;a=c[1161480+(e*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=d>>>16&65535}else{fj[a&511](f&16777215,d>>>16)}a=f+2|0;f=a>>>16&255;e=c[1161480+(f*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[e&511](a&16777215,d&65535);return}}function PA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291688]|0;if((d&1|0)!=0&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]<<16;l=a;m=f}else{f=(fl[i&255](d&16777215)|0)<<16;i=fl[c[h>>2]&255](d+2&16777215)|0|f;k=i;l=c[291673]|0;m=c[291688]|0}i=c[1166604+((l>>>9&7|8)<<2)>>2]|0;l=c[291667]|0;c[291667]=l+2;f=(b[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0)+i|0;c[291677]=k>>>24;c[291678]=k;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(m|0)!=0){m=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=f>>>16&255;i=c[1161480+(m*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+(f&65535)>>1]=k>>>16&65535}else{fj[i&511](f&16777215,k>>>16)}i=f+2|0;f=i>>>16&255;m=c[1161480+(f*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(i&65535)>>1]=k&65535;return}else{fj[m&511](i&16777215,k&65535);return}}function PB(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=1161472+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[291688]|0}h=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+h|0;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=d>>>16&255;h=c[1161480+(k*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[h&511](d&16777215,j>>>16)}h=d+2|0;d=h>>>16&255;k=c[1161480+(d*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[k&511](h&16777215,j&65535);return}}function PC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[291688]|0;if((f&1|0)!=0&(a|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]<<16;l=a}else{a=(fl[i&255](f&16777215)|0)<<16;f=fl[c[h>>2]&255](d+16777214&16777215)|0|a;k=f;l=c[291688]|0}f=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;c[291677]=k>>>24;c[291678]=k;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=d>>>16&255;f=c[1161480+(l*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(d&65535)>>1]=k>>>16&65535}else{fj[f&511](d&16777215,k>>>16)}f=d+2|0;d=f>>>16&255;l=c[1161480+(d*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=k&65535;return}else{fj[l&511](f&16777215,k&65535);return}}function PD(){var a=0,d=0,e=0,f=0;a=ahi()|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;e=c[1161480+(d*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=a>>>16&65535}else{fj[e&511](f&16777215,a>>>16)}e=f+2|0;f=e>>>16&255;d=c[1161480+(f*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(e&65535)>>1]=a&65535;return}else{fj[d&511](e&16777215,a&65535);return}}function PE(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=f<<16>>16}else{i=f}f=(h<<24>>24)+d+i|0;i=c[291688]|0;if((f&1|0)!=0&(i|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;h=1161472+(d*20|0)|0;j=c[h>>2]|0;if((j|0)==0){k=f+2|0;l=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]<<16;m=a;n=g;o=i}else{i=(fl[j&255](f&16777215)|0)<<16;j=fl[c[h>>2]&255](f+2&16777215)|0|i;l=j;m=c[291673]|0;n=c[291667]|0;o=c[291688]|0}j=c[1166604+((m>>>9&7|8)<<2)>>2]|0;c[291667]=n+2;m=(b[(c[1161464+((n>>>16&255)*20|0)>>2]|0)+(n&65535)>>1]|0)+j|0;c[291677]=l>>>24;c[291678]=l;c[291679]=0;c[291680]=0;if((m&1|0)!=0&(o|0)!=0){o=c[291675]|1;c[291699]=m;c[291700]=0;c[291701]=o;eJ(1166756,1)}o=m>>>16&255;j=c[1161480+(o*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(o*20|0)>>2]|0)+(m&65535)>>1]=l>>>16&65535}else{fj[j&511](m&16777215,l>>>16)}j=m+2|0;m=j>>>16&255;o=c[1161480+(m*20|0)>>2]|0;if((o|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+(j&65535)>>1]=l&65535;return}else{fj[o&511](j&16777215,l&65535);return}}function PF(){var a=0,d=0,e=0,f=0;a=ahh()|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;e=c[1161480+(d*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=a>>>16&65535}else{fj[e&511](f&16777215,a>>>16)}e=f+2|0;f=e>>>16&255;d=c[1161480+(f*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(e&65535)>>1]=a&65535;return}else{fj[d&511](e&16777215,a&65535);return}}function PG(){var a=0,d=0,e=0,f=0;a=ahg()|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;e=c[291667]|0;c[291667]=e+2;f=(b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;e=c[1161480+(d*20|0)>>2]|0;if((e|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=a>>>16&65535}else{fj[e&511](f&16777215,a>>>16)}e=f+2|0;f=e>>>16&255;d=c[1161480+(f*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(e&65535)>>1]=a&65535;return}else{fj[d&511](e&16777215,a&65535);return}}function PH(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291667]|0;d=a+2|0;c[291667]=d;e=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;g=f&65535;h=e+2|0;e=b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=e&65535;i=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+i|0;c[291677]=g>>>8;c[291678]=h|g<<16;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;d=c[1161480+(i*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=f}else{fj[d&511](a&16777215,g)}g=a+2|0;a=g>>>16&255;d=c[1161480+(a*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(g&65535)>>1]=e;return}else{fj[d&511](g&16777215,h);return}}function PI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;f=h&65535;i=g+2|0;g=b[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=g&65535;j=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+4;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+j|0;c[291677]=f>>>8;c[291678]=i|f<<16;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){j=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=a>>>16&255;d=c[1161480+(j*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+(a&65535)>>1]=h}else{fj[d&511](a&16777215,f)}f=a+2|0;a=f>>>16&255;d=c[1161480+(a*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=g;return}else{fj[d&511](f&16777215,i);return}}function PJ(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291667]|0;d=a+4|0;c[291667]=d;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=e&65535;g=a+2|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;i=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+6;a=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+i|0;c[291677]=f>>>8;c[291678]=g|f<<16;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;d=c[1161480+(i*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=e}else{fj[d&511](a&16777215,f)}f=a+2|0;a=f>>>16&255;d=c[1161480+(a*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=h;return}else{fj[d&511](f&16777215,g);return}}function PK(){var a=0,d=0,f=0,g=0,h=0;a=c[291673]|0;d=c[1166604+((a&7)<<2)>>2]|0;f=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;c[291677]=d>>>24;c[291678]=d;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;f=c[1161480+(h*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535}else{fj[f&511](a&16777215,d>>>16)}f=a+2|0;a=f>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[h&511](f&16777215,d&65535);return}}function PL(){var a=0,d=0,f=0,g=0,h=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;c[291677]=d>>>24;c[291678]=d;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=a>>>16&255;f=c[1161480+(h*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535}else{fj[f&511](a&16777215,d>>>16)}f=a+2|0;a=f>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[h&511](f&16777215,d&65535);return}}function PM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=1161472+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[291673]|0}h=c[1166604+((k>>>9&7|8)<<2)>>2]|0;k=c[291667]|0;c[291667]=k+2;a=e[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;k=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){l=k<<16>>16}else{l=k}k=(a<<24>>24)+h+l|0;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((k&1|0)!=0&(c[291688]|0)!=0){l=c[291675]|1;c[291699]=k;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=k>>>16&255;h=c[1161480+(l*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(k&65535)>>1]=j>>>16&65535}else{fj[h&511](k&16777215,j>>>16)}h=k+2|0;k=h>>>16&255;l=c[1161480+(k*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[l&511](h&16777215,j&65535);return}}function PN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=1161472+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=d<<16>>16}else{j=d}d=(f<<24>>24)+a+j|0;c[291677]=i>>>24;c[291678]=i;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){j=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=d>>>16&255;a=c[1161480+(j*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[a&511](d&16777215,i>>>16)}a=d+2|0;d=a>>>16&255;j=c[1161480+(d*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[j&511](a&16777215,i&65535);return}}function PO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=1161472+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){k=d<<16>>16}else{k=d}d=(g<<24>>24)+a+k|0;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=d>>>16&255;a=c[1161480+(k*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[a&511](d&16777215,j>>>16)}a=d+2|0;d=a>>>16&255;k=c[1161480+(d*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[k&511](a&16777215,j&65535);return}}function PP(){var a=0,d=0,f=0,g=0,h=0;a=ahi()|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;d=c[1161480+(h*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=a>>>16&65535}else{fj[d&511](f&16777215,a>>>16)}d=f+2|0;f=d>>>16&255;h=c[1161480+(f*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[h&511](d&16777215,a&65535);return}}function PQ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=f<<16>>16}else{i=f}f=(h<<24>>24)+d+i|0;if((f&1|0)!=0&(c[291688]|0)!=0){i=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f>>>16&255;d=1161472+(i*20|0)|0;h=c[d>>2]|0;if((h|0)==0){j=f+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(i*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;l=a;m=g}else{g=(fl[h&255](f&16777215)|0)<<16;h=fl[c[d>>2]&255](f+2&16777215)|0|g;k=h;l=c[291673]|0;m=c[291667]|0}h=c[1166604+((l>>>9&7|8)<<2)>>2]|0;c[291667]=m+2;l=e[(c[1161464+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0;m=c[1166604+(l>>>12<<2)>>2]|0;if((l&2048|0)==0){n=m<<16>>16}else{n=m}m=(l<<24>>24)+h+n|0;c[291677]=k>>>24;c[291678]=k;c[291679]=0;c[291680]=0;if((m&1|0)!=0&(c[291688]|0)!=0){n=c[291675]|1;c[291699]=m;c[291700]=0;c[291701]=n;eJ(1166756,1)}n=m>>>16&255;h=c[1161480+(n*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(n*20|0)>>2]|0)+(m&65535)>>1]=k>>>16&65535}else{fj[h&511](m&16777215,k>>>16)}h=m+2|0;m=h>>>16&255;n=c[1161480+(m*20|0)>>2]|0;if((n|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+(h&65535)>>1]=k&65535;return}else{fj[n&511](h&16777215,k&65535);return}}function PR(){var a=0,d=0,f=0,g=0,h=0;a=ahh()|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;d=c[1161480+(h*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=a>>>16&65535}else{fj[d&511](f&16777215,a>>>16)}d=f+2|0;f=d>>>16&255;h=c[1161480+(f*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[h&511](d&16777215,a&65535);return}}function PS(){var a=0,d=0,f=0,g=0,h=0;a=ahg()|0;d=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;d=c[1161480+(h*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]=a>>>16&65535}else{fj[d&511](f&16777215,a>>>16)}d=f+2|0;f=d>>>16&255;h=c[1161480+(f*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[h&511](d&16777215,a&65535);return}}function PT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=g&65535;i=f+2|0;f=b[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=f&65535;j=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){k=d<<16>>16}else{k=d}d=(a<<24>>24)+j+k|0;c[291677]=h>>>8;c[291678]=i|h<<16;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=d>>>16&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(d&65535)>>1]=g}else{fj[j&511](d&16777215,h)}h=d+2|0;d=h>>>16&255;j=c[1161480+(d*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(h&65535)>>1]=f;return}else{fj[j&511](h&16777215,i);return}}function PU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;f=h&65535;i=g+2|0;g=b[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=g&65535;j=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+4;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){k=d<<16>>16}else{k=d}d=(a<<24>>24)+j+k|0;c[291677]=f>>>8;c[291678]=i|f<<16;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=d>>>16&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(d&65535)>>1]=h}else{fj[j&511](d&16777215,f)}f=d+2|0;d=f>>>16&255;j=c[1161480+(d*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=g;return}else{fj[j&511](f&16777215,i);return}}function PV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=f&65535;h=a+2|0;i=b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=i&65535;j=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=a+6;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){k=d<<16>>16}else{k=d}d=(a<<24>>24)+j+k|0;c[291677]=g>>>8;c[291678]=h|g<<16;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=d>>>16&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(d&65535)>>1]=f}else{fj[j&511](d&16777215,g)}g=d+2|0;d=g>>>16&255;j=c[1161480+(d*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]=i;return}else{fj[j&511](g&16777215,h);return}}function PW(){var a=0,d=0,e=0,f=0;a=c[1166604+((c[291673]&7)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=e>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=a>>>16&65535}else{fj[f&511](e&16777215,a>>>16)}f=e+2|0;e=f>>>16&255;d=c[1161480+(e*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function PX(){var a=0,d=0,e=0,f=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=e>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=a>>>16&65535}else{fj[f&511](e&16777215,a>>>16)}f=e+2|0;e=f>>>16&255;d=c[1161480+(e*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function PY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291688]|0;if((a&1|0)!=0&(d|0)!=0){f=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=a>>>16&255;g=1161472+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]<<16;k=d}else{d=(fl[h&255](a&16777215)|0)<<16;h=fl[c[g>>2]&255](a+2&16777215)|0|d;j=h;k=c[291688]|0}h=c[291667]|0;c[291667]=h+2;d=b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=d>>>16&255;h=c[1161480+(k*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[h&511](d&16777215,j>>>16)}h=d+2|0;d=h>>>16&255;k=c[1161480+(d*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[k&511](h&16777215,j&65535);return}}function PZ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=1161472+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[291688]|0}h=c[291667]|0;c[291667]=h+2;a=b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=a>>>16&255;h=c[1161480+(k*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[h&511](a&16777215,j>>>16)}h=a+2|0;a=h>>>16&255;k=c[1161480+(a*20|0)>>2]|0;if((k|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[k&511](h&16777215,j&65535);return}}function P_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[291688]|0;if((f&1|0)!=0&(a|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]<<16;l=a}else{a=(fl[i&255](f&16777215)|0)<<16;f=fl[c[h>>2]&255](d+16777214&16777215)|0|a;k=f;l=c[291688]|0}f=c[291667]|0;c[291667]=f+2;a=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[291677]=k>>>24;c[291678]=k;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(l|0)!=0){l=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=a>>>16&255;f=c[1161480+(l*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(a&65535)>>1]=k>>>16&65535}else{fj[f&511](a&16777215,k>>>16)}f=a+2|0;a=f>>>16&255;l=c[1161480+(a*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=k&65535;return}else{fj[l&511](f&16777215,k&65535);return}}function P$(){var a=0,d=0,e=0,f=0;a=ahi()|0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=e>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=a>>>16&65535}else{fj[f&511](e&16777215,a>>>16)}f=e+2|0;e=f>>>16&255;d=c[1161480+(e*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function P0(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=d<<16>>16}else{h=d}d=(g<<24>>24)+a+h|0;h=c[291688]|0;if((d&1|0)!=0&(h|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;g=1161472+(a*20|0)|0;i=c[g>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]<<16;l=f;m=h}else{h=(fl[i&255](d&16777215)|0)<<16;i=fl[c[g>>2]&255](d+2&16777215)|0|h;k=i;l=c[291667]|0;m=c[291688]|0}c[291667]=l+2;i=b[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;c[291677]=k>>>24;c[291678]=k;c[291679]=0;c[291680]=0;if((i&1|0)!=0&(m|0)!=0){m=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=i>>>16&255;l=c[1161480+(m*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+(i&65535)>>1]=k>>>16&65535}else{fj[l&511](i&16777215,k>>>16)}l=i+2|0;i=l>>>16&255;m=c[1161480+(i*20|0)>>2]|0;if((m|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(l&65535)>>1]=k&65535;return}else{fj[m&511](l&16777215,k&65535);return}}function P1(){var a=0,d=0,e=0,f=0;a=ahh()|0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=e>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=a>>>16&65535}else{fj[f&511](e&16777215,a>>>16)}f=e+2|0;e=f>>>16&255;d=c[1161480+(e*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function P2(){var a=0,d=0,e=0,f=0;a=ahg()|0;d=c[291667]|0;c[291667]=d+2;e=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=e>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(e&65535)>>1]=a>>>16&65535}else{fj[f&511](e&16777215,a>>>16)}f=e+2|0;e=f>>>16&255;d=c[1161480+(e*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function P3(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291667]|0;d=a+2|0;c[291667]=d;e=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;f=b[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;g=f&65535;h=e+2|0;e=b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=e&65535;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=g>>>8;c[291678]=h|g<<16;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;i=c[1161480+(d*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=f}else{fj[i&511](a&16777215,g)}g=a+2|0;a=g>>>16&255;i=c[1161480+(a*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(g&65535)>>1]=e;return}else{fj[i&511](g&16777215,h);return}}function P4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;f=h&65535;i=g+2|0;g=b[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=g&65535;c[291667]=a+4;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=f>>>8;c[291678]=i|f<<16;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;j=c[1161480+(d*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=h}else{fj[j&511](a&16777215,f)}f=a+2|0;a=f>>>16&255;j=c[1161480+(a*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=g;return}else{fj[j&511](f&16777215,i);return}}function P5(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[291667]|0;d=a+4|0;c[291667]=d;e=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=e&65535;g=a+2|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;c[291667]=a+6;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[291677]=f>>>8;c[291678]=g|f<<16;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;i=c[1161480+(d*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=e}else{fj[i&511](a&16777215,f)}f=a+2|0;a=f>>>16&255;i=c[1161480+(a*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=h;return}else{fj[i&511](f&16777215,g);return}}function P6(){var a=0,d=0,f=0,g=0,h=0;a=c[1166604+((c[291673]&7)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+4;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=f&255;f=c[1161480+(h*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+d>>1]=a>>>16&65535}else{fj[f&511](g&16777215,a>>>16)}f=g+2|0;g=f>>>16&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function P7(){var a=0,d=0,f=0,g=0,h=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+4;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=f&255;f=c[1161480+(h*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+d>>1]=a>>>16&65535}else{fj[f&511](g&16777215,a>>>16)}f=g+2|0;g=f>>>16&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function P8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291688]|0;if((a&1|0)!=0&(d|0)!=0){f=c[291675]|1;c[291699]=a;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=a>>>16&255;g=1161472+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;k=d}else{d=(fl[h&255](a&16777215)|0)<<16;h=fl[c[g>>2]&255](a+2&16777215)|0|d;j=h;k=c[291688]|0}h=c[291667]|0;c[291667]=h+4;d=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;a=h+2|0;h=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=h|d<<16;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((h&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=d&255;d=c[1161480+(k*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+h>>1]=j>>>16&65535}else{fj[d&511](a&16777215,j>>>16)}d=a+2|0;a=d>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[h&511](d&16777215,j&65535);return}}function P9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=1161472+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[291688]|0}h=c[291667]|0;c[291667]=h+4;a=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;d=h+2|0;h=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=h|a<<16;c[291677]=j>>>24;c[291678]=j;c[291679]=0;c[291680]=0;if((h&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=a&255;a=c[1161480+(k*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+h>>1]=j>>>16&65535}else{fj[a&511](d&16777215,j>>>16)}a=d+2|0;d=a>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[h&511](a&16777215,j&65535);return}}function Qa(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=c[291688]|0;if((f&1|0)!=0&(a|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=1161472+(g*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=d-2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;l=a}else{a=(fl[i&255](f&16777215)|0)<<16;f=fl[c[h>>2]&255](d+16777214&16777215)|0|a;k=f;l=c[291688]|0}f=c[291667]|0;c[291667]=f+4;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;d=f+2|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f|a<<16;c[291677]=k>>>24;c[291678]=k;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(l|0)!=0){l=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=a&255;a=c[1161480+(l*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+f>>1]=k>>>16&65535}else{fj[a&511](d&16777215,k>>>16)}a=d+2|0;d=a>>>16&255;f=c[1161480+(d*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=k&65535;return}else{fj[f&511](a&16777215,k&65535);return}}function Qb(){var a=0,d=0,f=0,g=0,h=0;a=ahi()|0;d=c[291667]|0;c[291667]=d+4;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=f&255;f=c[1161480+(h*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+d>>1]=a>>>16&65535}else{fj[f&511](g&16777215,a>>>16)}f=g+2|0;g=f>>>16&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function Qc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[1166604+((c[291673]&7|8)<<2)>>2]|0;d=c[291667]|0;f=d+2|0;c[291667]=f;g=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=d<<16>>16}else{h=d}d=(g<<24>>24)+a+h|0;h=c[291688]|0;if((d&1|0)!=0&(h|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;g=1161472+(a*20|0)|0;i=c[g>>2]|0;if((i|0)==0){j=d+2|0;k=e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;l=f;m=h}else{h=(fl[i&255](d&16777215)|0)<<16;i=fl[c[g>>2]&255](d+2&16777215)|0|h;k=i;l=c[291667]|0;m=c[291688]|0}c[291667]=l+4;i=e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;h=l+2|0;l=e[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=l|i<<16;c[291677]=k>>>24;c[291678]=k;c[291679]=0;c[291680]=0;if((l&1|0)!=0&(m|0)!=0){m=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=i&255;i=c[1161480+(m*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+l>>1]=k>>>16&65535}else{fj[i&511](h&16777215,k>>>16)}i=h+2|0;h=i>>>16&255;l=c[1161480+(h*20|0)>>2]|0;if((l|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+(i&65535)>>1]=k&65535;return}else{fj[l&511](i&16777215,k&65535);return}}function Qd(){var a=0,b=0,d=0;a=c[291673]|0;b=c[1166604+((a&7)<<2)>>2]&65535;d=1166604+((a>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|b;c[291677]=b>>>8;c[291678]=b;c[291679]=0;c[291680]=0;return}function Qe(){var a=0,b=0,d=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]&65535;d=1166604+((a>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|b;c[291677]=b>>>8;c[291678]=b;c[291679]=0;c[291680]=0;return}function Qf(){var a=0,d=0,f=0,g=0,h=0;a=ahh()|0;d=c[291667]|0;c[291667]=d+4;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=f&255;f=c[1161480+(h*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+d>>1]=a>>>16&65535}else{fj[f&511](g&16777215,a>>>16)}f=g+2|0;g=f>>>16&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function Qg(){var a=0,d=0,f=0,g=0,h=0;a=ahg()|0;d=c[291667]|0;c[291667]=d+4;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;c[291677]=a>>>24;c[291678]=a;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=h;eJ(1166756,1)}h=f&255;f=c[1161480+(h*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(h*20|0)>>2]|0)+d>>1]=a>>>16&65535}else{fj[f&511](g&16777215,a>>>16)}f=g+2|0;g=f>>>16&255;d=c[1161480+(g*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function Qh(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=g&65535;i=f+2|0;f=b[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=f&65535;c[291667]=a+6;j=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|j<<16;c[291677]=h>>>8;c[291678]=i|h<<16;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=j&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+a>>1]=g}else{fj[j&511](d&16777215,h)}h=d+2|0;d=h>>>16&255;j=c[1161480+(d*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(h&65535)>>1]=f;return}else{fj[j&511](h&16777215,i);return}}function Qi(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;f=h&65535;i=g+2|0;g=b[(c[1161464+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=g&65535;c[291667]=a+6;j=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|j<<16;c[291677]=f>>>8;c[291678]=i|f<<16;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=j&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+a>>1]=h}else{fj[j&511](d&16777215,f)}f=d+2|0;d=f>>>16&255;j=c[1161480+(d*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=g;return}else{fj[j&511](f&16777215,i);return}}function Qj(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=f&65535;h=a+2|0;i=b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=i&65535;c[291667]=a+8;j=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|j<<16;c[291677]=g>>>8;c[291678]=h|g<<16;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=j&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+a>>1]=f}else{fj[j&511](d&16777215,g)}g=d+2|0;d=g>>>16&255;j=c[1161480+(d*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]=i;return}else{fj[j&511](g&16777215,h);return}}function Qk(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0}a=1166604+((h>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-65536|g;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;return}function Ql(){var a=0,b=0,d=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-65536|f;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;return}function Qm(){var a=0,b=0,d=0,f=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-65536|f;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;return}function Qn(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;if((g&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=1166604+((i>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-65536|h;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;return}function Qo(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=c[1161472+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a;j=i>>>9;k=j&7;l=1166604+(k<<2)|0;m=c[l>>2]|0;n=m&-65536;o=n|h;c[l>>2]=o;p=h>>>8;c[291677]=p;c[291678]=h;c[291679]=0;c[291680]=0;return}else{a=fl[b&255](d&16777215)|0;h=a;i=c[291673]|0;j=i>>>9;k=j&7;l=1166604+(k<<2)|0;m=c[l>>2]|0;n=m&-65536;o=n|h;c[l>>2]=o;p=h>>>8;c[291677]=p;c[291678]=h;c[291679]=0;c[291680]=0;return}}function Qp(){var a=0,d=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|a;c[291677]=a>>>8;c[291678]=a;c[291679]=0;c[291680]=0;return}function Qq(){var a=0,b=0,d=0,f=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[1166604+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|f;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;return}function Qr(){var a=0,b=0;a=c[291667]|0;c[291667]=a+2;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-65536|b;c[291677]=b>>>8;c[291678]=b;c[291679]=0;c[291680]=0;return}function Qs(){var a=0;a=c[291673]|0;c[1166604+((a>>>9&7|8)<<2)>>2]=c[1166604+((a&7)<<2)>>2]<<16>>16;return}function Qt(){var a=0;a=c[291673]|0;c[1166604+((a>>>9&7|8)<<2)>>2]=c[1166604+((a&7|8)<<2)>>2]<<16>>16;return}function Qu(){var a=0,d=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;return}function Qv(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;return}function Qw(){var a=0;a=c[291667]|0;c[291667]=a+2;c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;return}function Qx(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|g;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;return}function Qy(){var a=0,b=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b&255;b=c[1161472+(f*20|0)>>2]|0;if((b|0)==0){g=e[(c[1161464+(f*20|0)>>2]|0)+a>>1]|0}else{g=fl[b&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|g;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;return}function Qz(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;if((b&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=b>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a;i=g<<16;j=i>>16;k=h>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=j;return}else{a=fl[f&255](b&16777215)|0;g=a;h=c[291673]|0;i=g<<16;j=i>>16;k=h>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=j;return}}function QA(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+((c[291673]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0;g=f<<16;h=g>>16;i=c[291673]|0;j=i>>>9;k=j&7;l=k|8;m=1166604+(l<<2)|0;c[m>>2]=h;return}else{f=fl[d&255](b&16777215)|0;g=f<<16;h=g>>16;i=c[291673]|0;j=i>>>9;k=j&7;l=k|8;m=1166604+(l<<2)|0;c[m>>2]=h;return}}function QB(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=1166604+((c[291673]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;if((b&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=b;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=b>>>16&255;d=c[1161472+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[1161464+(a*20|0)>>2]|0)+(b&65535)>>1]|0;g=f<<16;h=g>>16;i=c[291673]|0;j=i>>>9;k=j&7;l=k|8;m=1166604+(l<<2)|0;c[m>>2]=h;return}else{f=fl[d&255](b&16777215)|0;g=f<<16;h=g>>16;i=c[291673]|0;j=i>>>9;k=j&7;l=k|8;m=1166604+(l<<2)|0;c[m>>2]=h;return}}function QC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;if((g&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a;j=h<<16;k=j>>16;l=i>>>9;m=l&7;n=m|8;o=1166604+(n<<2)|0;c[o>>2]=k;return}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0;j=h<<16;k=j>>16;l=i>>>9;m=l&7;n=m|8;o=1166604+(n<<2)|0;c[o>>2]=k;return}}function QD(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[291673]|0;b=c[1166604+((a&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;f=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[1166604+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((d&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;b=c[1161472+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a;j=h<<16;k=j>>16;l=i>>>9;m=l&7;n=m|8;o=1166604+(n<<2)|0;c[o>>2]=k;return}else{a=fl[b&255](d&16777215)|0;h=a;i=c[291673]|0;j=h<<16;k=j>>16;l=i>>>9;m=l&7;n=m|8;o=1166604+(n<<2)|0;c[o>>2]=k;return}}function QE(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0;h=g<<16;i=h>>16;j=c[291673]|0;k=j>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=i;return}else{g=fl[f&255](d&16777215)|0;h=g<<16;i=h>>16;j=c[291673]|0;k=j>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=i;return}}function QF(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[291667]|0;c[291667]=a+4;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=b&255;b=c[1161472+(f*20|0)>>2]|0;if((b|0)==0){g=e[(c[1161464+(f*20|0)>>2]|0)+a>>1]|0;h=g<<16;i=h>>16;j=c[291673]|0;k=j>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=i;return}else{g=fl[b&255](d&16777215)|0;h=g<<16;i=h>>16;j=c[291673]|0;k=j>>>9;l=k&7;m=l|8;n=1166604+(m<<2)|0;c[n>>2]=i;return}}function QG(){var a=0,d=0,e=0,f=0,g=0;a=c[291673]|0;d=c[1166604+((a&7)<<2)>>2]|0;e=d&65535;f=c[1166604+((a>>>9&7|8)<<2)>>2]|0;c[291677]=e>>>8;c[291678]=e;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[g&511](f&16777215,e);return}}function QH(){var a=0,d=0,e=0,f=0,g=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;e=d&65535;f=c[1166604+((a>>>9&7|8)<<2)>>2]|0;c[291677]=e>>>8;c[291678]=e;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=f>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[g&511](f&16777215,e);return}}function QI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291688]|0;if((d&1|0)!=0&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=a;k=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291673]|0;k=c[291688]|0}f=c[1166604+((j>>>9&7|8)<<2)>>2]|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=f>>>16&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[j&511](f&16777215,i);return}}function QJ(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291688]|0}a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;d=c[1161480+(i*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[d&511](a&16777215,h);return}}function QK(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291688]|0}a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;d=c[1161480+(i*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[d&511](a&16777215,h);return}}function QL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[291688]|0;if((g&1|0)!=0&(d|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;h=c[1161472+(f*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]|0;j=a;k=d}else{d=fl[h&255](g&16777215)|0;i=d;j=c[291673]|0;k=c[291688]|0}d=c[1166604+((j>>>9&7|8)<<2)>>2]|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=d>>>16&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[j&511](d&16777215,i);return}}function QM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=c[291688]|0;if((f&1|0)!=0&(h|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;g=c[1161472+(d*20|0)>>2]|0;if((g|0)==0){i=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0;j=a;k=h}else{h=fl[g&255](f&16777215)|0;i=h;j=c[291673]|0;k=c[291688]|0}h=c[1166604+((j>>>9&7|8)<<2)>>2]|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((h&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=h;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=h>>>16&255;j=c[1161480+(k*20|0)>>2]|0;if((j|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(h&65535)>>1]=i&65535;return}else{fj[j&511](h&16777215,i);return}}function QN(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291688]|0}a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=a>>>16&255;d=c[1161480+(i*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[d&511](a&16777215,h);return}}function QO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=c[291688]|0;if((a&1|0)!=0&(g|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=d&255;d=c[1161472+(h*20|0)>>2]|0;if((d|0)==0){i=e[(c[1161464+(h*20|0)>>2]|0)+a>>1]|0;j=g}else{g=fl[d&255](f&16777215)|0;i=g;j=c[291688]|0}g=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((g&1|0)!=0&(j|0)!=0){j=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=j;eJ(1166756,1)}j=g>>>16&255;f=c[1161480+(j*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(j*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[f&511](g&16777215,i);return}}function QP(){var a=0,d=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a&65535;e=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=d>>>8;c[291678]=d;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=e>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(e&65535)>>1]=a;return}else{fj[g&511](e&16777215,d);return}}function QQ(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g&65535;a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=a>>>16&255;h=c[1161480+(d*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(a&65535)>>1]=g;return}else{fj[h&511](a&16777215,f);return}}function QR(){var a=0,d=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d&65535;e=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291677]=a>>>8;c[291678]=a;c[291679]=0;c[291680]=0;if((e&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=e;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=e>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(e&65535)>>1]=d;return}else{fj[g&511](e&16777215,a);return}}function QS(){var a=0,d=0,e=0,f=0,g=0;a=c[291673]|0;d=c[1166604+((a&7)<<2)>>2]|0;e=d&65535;f=1166604+((a>>>9&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+2;c[291677]=e>>>8;c[291678]=e;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=a>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,e);return}}function QT(){var a=0,d=0,e=0,f=0,g=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;e=d&65535;f=1166604+((a>>>9&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+2;c[291677]=e>>>8;c[291678]=e;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=a>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,e);return}}function QU(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291673]|0}a=1166604+((i>>>9&7|8)<<2)|0;i=c[a>>2]|0;c[a>>2]=i+2;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((i&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=i>>>16&255;d=c[1161480+(a*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[d&511](i&16777215,h);return}}function QV(){var a=0,d=0,f=0,g=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+2;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function QW(){var a=0,d=0,f=0,g=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+2;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function QX(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;if((g&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=1166604+((i>>>9&7|8)<<2)|0;i=c[a>>2]|0;c[a>>2]=i+2;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((i&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=i>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[g&511](i&16777215,h);return}}function QY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;if((f&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;d=c[1161472+(h*20|0)>>2]|0;if((d|0)==0){i=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;j=a}else{a=fl[d&255](f&16777215)|0;i=a;j=c[291673]|0}a=1166604+((j>>>9&7|8)<<2)|0;j=c[a>>2]|0;c[a>>2]=j+2;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((j&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=j;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=j>>>16&255;f=c[1161480+(a*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(j&65535)>>1]=i&65535;return}else{fj[f&511](j&16777215,i);return}}function QZ(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+2;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function Q_(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}f=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[f>>2]|0;c[f>>2]=d+2;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=h&65535;return}else{fj[a&511](d&16777215,h);return}}function Q$(){var a=0,d=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a&65535;e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+2;c[291677]=d>>>8;c[291678]=d;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=f>>>16&255;g=c[1161480+(e*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a;return}else{fj[g&511](f&16777215,d);return}}function Q0(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g&65535;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=g;return}else{fj[h&511](d&16777215,f);return}}function Q1(){var a=0,d=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d&65535;e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+2;c[291677]=a>>>8;c[291678]=a;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=f>>>16&255;g=c[1161480+(e*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=d;return}else{fj[g&511](f&16777215,a);return}}function Q2(){var a=0,d=0,e=0,f=0,g=0;a=c[291673]|0;d=c[1166604+((a&7)<<2)>>2]|0;e=d&65535;f=1166604+((a>>>9&7|8)<<2)|0;a=(c[f>>2]|0)-2|0;c[f>>2]=a;c[291677]=e>>>8;c[291678]=e;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=a>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,e);return}}function Q3(){var a=0,d=0,e=0,f=0,g=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;e=d&65535;f=1166604+((a>>>9&7|8)<<2)|0;a=(c[f>>2]|0)-2|0;c[f>>2]=a;c[291677]=e>>>8;c[291678]=e;c[291679]=0;c[291680]=0;if((a&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=a;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=a>>>16&255;g=c[1161480+(f*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,e);return}}function Q4(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;if((d&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291673]|0}a=1166604+((i>>>9&7|8)<<2)|0;i=(c[a>>2]|0)-2|0;c[a>>2]=i;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((i&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=i>>>16&255;d=c[1161480+(a*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[d&511](i&16777215,h);return}}function Q5(){var a=0,d=0,f=0,g=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-2|0;c[d>>2]=f;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function Q6(){var a=0,d=0,f=0,g=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-2|0;c[d>>2]=f;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function Q7(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;if((g&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=g>>>16&255;f=c[1161472+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[1161464+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[291673]|0}a=1166604+((i>>>9&7|8)<<2)|0;i=(c[a>>2]|0)-2|0;c[a>>2]=i;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((i&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=i;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=i>>>16&255;g=c[1161480+(a*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[g&511](i&16777215,h);return}}function Q8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;c[291667]=f+2;g=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;if((f&1|0)!=0&(c[291688]|0)!=0){h=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=h;eJ(1166756,1)}h=f>>>16&255;d=c[1161472+(h*20|0)>>2]|0;if((d|0)==0){i=e[(c[1161464+(h*20|0)>>2]|0)+(f&65535)>>1]|0;j=a}else{a=fl[d&255](f&16777215)|0;i=a;j=c[291673]|0}a=1166604+((j>>>9&7|8)<<2)|0;j=(c[a>>2]|0)-2|0;c[a>>2]=j;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((j&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=j;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=j>>>16&255;f=c[1161480+(a*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(j&65535)>>1]=i&65535;return}else{fj[f&511](j&16777215,i);return}}function Q9(){var a=0,d=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;f=c[1161472+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-2|0;c[d>>2]=f;c[291677]=g>>>8;c[291678]=g;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;a=c[1161480+(d*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function Ra(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+4;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;if((a&1|0)!=0&(c[291688]|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d&255;d=c[1161472+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[1161464+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}f=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=(c[f>>2]|0)-2|0;c[f>>2]=d;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]=h&65535;return}else{fj[a&511](d&16777215,h);return}}function Rb(){var a=0,d=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a&65535;e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-2|0;c[e>>2]=f;c[291677]=d>>>8;c[291678]=d;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=f>>>16&255;g=c[1161480+(e*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=a;return}else{fj[g&511](f&16777215,d);return}}function Rc(){var a=0,d=0,f=0,g=0,h=0;a=c[291667]|0;c[291667]=a+2;d=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[1166604+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g&65535;a=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;c[291677]=f>>>8;c[291678]=f;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(c[291688]|0)!=0){a=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=a;eJ(1166756,1)}a=d>>>16&255;h=c[1161480+(a*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(a*20|0)>>2]|0)+(d&65535)>>1]=g;return}else{fj[h&511](d&16777215,f);return}}function Rd(){var a=0,d=0,e=0,f=0,g=0;a=c[291667]|0;c[291667]=a+2;d=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d&65535;e=1166604+(((c[291673]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-2|0;c[e>>2]=f;c[291677]=a>>>8;c[291678]=a;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(c[291688]|0)!=0){e=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=e;eJ(1166756,1)}e=f>>>16&255;g=c[1161480+(e*20|0)>>2]|0;if((g|0)==0){b[(c[1161464+(e*20|0)>>2]|0)+(f&65535)>>1]=d;return}else{fj[g&511](f&16777215,a);return}}function Re(){var a=0,d=0,e=0,f=0,g=0;a=c[291673]|0;d=c[1166604+((a&7)<<2)>>2]|0;e=d&65535;f=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;c[291677]=e>>>8;c[291678]=e;c[291679]=0;c[291680]=0;if((g&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]=d&65535;return}else{fj[a&511](g&16777215,e);return}}function Rf(){var a=0,d=0,e=0,f=0,g=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;e=d&65535;f=c[1166604+((a>>>9&7|8)<<2)>>2]|0;a=c[291667]|0;c[291667]=a+2;g=(b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;c[291677]=e>>>8;c[291678]=e;c[291679]=0;c[291680]=0;if((g&1|0)!=0&(c[291688]|0)!=0){f=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=f;eJ(1166756,1)}f=g>>>16&255;a=c[1161480+(f*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(f*20|0)>>2]|0)+(g&65535)>>1]=d&65535;return}else{fj[a&511](g&16777215,e);return}}function Rg(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291688]|0;if((d&1|0)!=0&(f|0)!=0){g=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=d>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(d&65535)>>1]|0;j=a;k=f}else{f=fl[h&255](d&16777215)|0;i=f;j=c[291673]|0;k=c[291688]|0}f=c[1166604+((j>>>9&7|8)<<2)>>2]|0;j=c[291667]|0;c[291667]=j+2;d=(b[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0)+f|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((d&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=d;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=d>>>16&255;f=c[1161480+(k*20|0)>>2]|0;if((f|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[f&511](d&16777215,i);return}}function Rh(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291688]|0}a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;g=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((g&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=g>>>16&255;a=c[1161480+(i*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]=h&65535;return}else{fj[a&511](g&16777215,h);return}}function Ri(){var a=0,d=0,f=0,g=0,h=0,i=0;a=1166604+((c[291673]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[291688]|0;if((d&1|0)!=0&(a|0)!=0){f=c[291675]|1;c[291699]=d;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=d>>>16&255;g=c[1161472+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[1161464+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[291688]|0}a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;d=c[291667]|0;c[291667]=d+2;g=(b[(c[1161464+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;c[291677]=h>>>8;c[291678]=h;c[291679]=0;c[291680]=0;if((g&1|0)!=0&(i|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=i;eJ(1166756,1)}i=g>>>16&255;a=c[1161480+(i*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(i*20|0)>>2]|0)+(g&65535)>>1]=h&65535;return}else{fj[a&511](g&16777215,h);return}}function Rj(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=(b[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=c[291688]|0;if((h&1|0)!=0&(d|0)!=0){f=c[291675]|1;c[291699]=h;c[291700]=16;c[291701]=f;eJ(1166756,1)}f=h>>>16&255;i=c[1161472+(f*20|0)>>2]|0;if((i|0)==0){j=e[(c[1161464+(f*20|0)>>2]|0)+(h&65535)>>1]|0;k=a;l=g;m=d}else{d=fl[i&255](h&16777215)|0;j=d;k=c[291673]|0;l=c[291667]|0;m=c[291688]|0}d=c[1166604+((k>>>9&7|8)<<2)>>2]|0;c[291667]=l+2;k=(b[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0)+d|0;c[291677]=j>>>8;c[291678]=j;c[291679]=0;c[291680]=0;if((k&1|0)!=0&(m|0)!=0){m=c[291675]|1;c[291699]=k;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=k>>>16&255;d=c[1161480+(m*20|0)>>2]|0;if((d|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+(k&65535)>>1]=j&65535;return}else{fj[d&511](k&16777215,j);return}}function Rk(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[291673]|0;d=c[1166604+((a&7|8)<<2)>>2]|0;f=c[291667]|0;g=f+2|0;c[291667]=g;h=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[1166604+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=f<<16>>16}else{i=f}f=(h<<24>>24)+d+i|0;i=c[291688]|0;if((f&1|0)!=0&(i|0)!=0){d=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=d;eJ(1166756,1)}d=f>>>16&255;h=c[1161472+(d*20|0)>>2]|0;if((h|0)==0){j=e[(c[1161464+(d*20|0)>>2]|0)+(f&65535)>>1]|0;k=a;l=g;m=i}else{i=fl[h&255](f&16777215)|0;j=i;k=c[291673]|0;l=c[291667]|0;m=c[291688]|0}i=c[1166604+((k>>>9&7|8)<<2)>>2]|0;c[291667]=l+2;k=(b[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0)+i|0;c[291677]=j>>>8;c[291678]=j;c[291679]=0;c[291680]=0;if((k&1|0)!=0&(m|0)!=0){m=c[291675]|1;c[291699]=k;c[291700]=0;c[291701]=m;eJ(1166756,1)}m=k>>>16&255;i=c[1161480+(m*20|0)>>2]|0;if((i|0)==0){b[(c[1161464+(m*20|0)>>2]|0)+(k&65535)>>1]=j&65535;return}else{fj[i&511](k&16777215,j);return}}function Rl(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[291667]|0;d=a+2|0;c[291667]=d;f=b[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[291688]|0;if((f&1|0)!=0&(a|0)!=0){g=c[291675]|1;c[291699]=f;c[291700]=16;c[291701]=g;eJ(1166756,1)}g=f>>>16&255;h=c[1161472+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[1161464+(g*20|0)>>2]|0)+(f&65535)>>1]|0;j=d;k=a}else{a=fl[h&255](f&16777215)|0;i=a;j=c[291667]|0;k=c[291688]|0}a=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=j+2;f=(b[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0)+a|0;c[291677]=i>>>8;c[291678]=i;c[291679]=0;c[291680]=0;if((f&1|0)!=0&(k|0)!=0){k=c[291675]|1;c[291699]=f;c[291700]=0;c[291701]=k;eJ(1166756,1)}k=f>>>16&255;a=c[1161480+(k*20|0)>>2]|0;if((a|0)==0){b[(c[1161464+(k*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[a&511](f&16777215,i);return}}function Rm(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[291667]|0;d=a+4|0;c[291667]=d;f=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|f<<16;h=c[291688]|0;if((a&1|0)!=0&(h|0)!=0){i=c[291675]|1;c[291699]=g;c[291700]=16;c[291701]=i;eJ(1166756,1)}i=f&255;f=c[1161472+(i*20|0)>>2]|0;if((f|0)==0){j=e[(c[1161464+(i*20|0)>>2]|0)+a>>1]|0;k=d;l=h}else{h=fl[f&255](g&16777215)|0;j=h;k=c[291667]|0;l=c[291688]|0}h=c[1166604+(((c[291673]|0)>>>9&7|8)<<2)>>2]|0;c[291667]=k+2;g=(b[(c[1161464+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0)+h|0;c[291677]=j>>>8;c[291678]=j;c[291679]=0;c[291680]=0;if((g&1|0)!=0&(l|0)!=0){l=c[291675]|1;c[291699]=g;c[291700]=0;c[291701]=l;eJ(1166756,1)}l=g>>>16&255;h=c[1161480+(l*20|0)>>2]|0;if((h|0)==0){b[(c[1161464+(l*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[h&511](g&16777215,j);return}}
function an3(){var a=0,d=0,e=0,f=0,g=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;e=962260+((a>>>9&7|8)<<2)|0;a=c[e>>2]|0;f=a-4|0;c[e>>2]=f;c[240591]=d>>>24;c[240592]=d;c[240593]=0;c[240594]=0;e=a-2|0;a=e>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(e&65535)>>1]=d&65535}else{fj[g&511](e&16777215,d&65535)}e=d>>>16;d=f>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=e&65535;return}else{fj[g&511](f&16777215,e);return}}function an4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[240587]|0}h=962260+((k>>>9&7|8)<<2)|0;k=c[h>>2]|0;a=k-4|0;c[h>>2]=a;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;h=k-2|0;k=h>>>16&255;d=c[957136+(k*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=j&65535}else{fj[d&511](h&16777215,j&65535)}h=j>>>16;j=a>>>16&255;d=c[957136+(j*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[d&511](a&16777215,h);return}}function an5(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;a=d-2|0;d=a>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535}else{fj[g&511](a&16777215,i&65535)}a=i>>>16;i=f>>>16&255;g=c[957136+(i*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[g&511](f&16777215,a);return}}function an6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;g=d-4|0;c[a>>2]=g;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;a=d-2|0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=j&65535}else{fj[f&511](a&16777215,j&65535)}a=j>>>16;j=g>>>16&255;f=c[957136+(j*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(g&65535)>>1]=a&65535;return}else{fj[f&511](g&16777215,a);return}}function an7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=957128+(d*20|0)|0;h=c[f>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]<<16;k=a}else{a=(fl[h&255](g&16777215)|0)<<16;h=fl[c[f>>2]&255](g+2&16777215)|0|a;j=h;k=c[240587]|0}h=962260+((k>>>9&7|8)<<2)|0;k=c[h>>2]|0;a=k-4|0;c[h>>2]=a;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;h=k-2|0;k=h>>>16&255;g=c[957136+(k*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=j&65535}else{fj[g&511](h&16777215,j&65535)}h=j>>>16;j=a>>>16&255;g=c[957136+(j*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[g&511](a&16777215,h);return}}function an8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=f>>>16&255;d=957128+(h*20|0)|0;g=c[d>>2]|0;if((g|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;k=a}else{a=(fl[g&255](f&16777215)|0)<<16;g=fl[c[d>>2]&255](f+2&16777215)|0|a;j=g;k=c[240587]|0}g=962260+((k>>>9&7|8)<<2)|0;k=c[g>>2]|0;a=k-4|0;c[g>>2]=a;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;g=k-2|0;k=g>>>16&255;f=c[957136+(k*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(g&65535)>>1]=j&65535}else{fj[f&511](g&16777215,j&65535)}g=j>>>16;j=a>>>16&255;f=c[957136+(j*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[f&511](a&16777215,g);return}}function an9(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;a=d-2|0;d=a>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535}else{fj[g&511](a&16777215,i&65535)}a=i>>>16;i=f>>>16&255;g=c[957136+(i*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[g&511](f&16777215,a);return}}function aoa(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=957128+(g*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|a}a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[a>>2]|0;d=f-4|0;c[a>>2]=d;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;a=f-2|0;f=a>>>16&255;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=j&65535}else{fj[h&511](a&16777215,j&65535)}a=j>>>16;j=d>>>16&255;h=c[957136+(j*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[h&511](d&16777215,a);return}}function aob(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;e=a&65535;f=d+2|0;d=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&65535;g=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;h=c[g>>2]|0;i=h-4|0;c[g>>2]=i;c[240591]=e>>>8;c[240592]=f|e<<16;c[240593]=0;c[240594]=0;g=h-2|0;h=g>>>16&255;j=c[957136+(h*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(g&65535)>>1]=d}else{fj[j&511](g&16777215,f)}f=i>>>16&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(i&65535)>>1]=a;return}else{fj[g&511](i&16777215,e);return}}function aoc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;a=g&65535;d=f+2|0;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f&65535;h=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;i=c[h>>2]|0;j=i-4|0;c[h>>2]=j;c[240591]=a>>>8;c[240592]=d|a<<16;c[240593]=0;c[240594]=0;h=i-2|0;i=h>>>16&255;k=c[957136+(i*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(h&65535)>>1]=f}else{fj[k&511](h&16777215,d)}d=j>>>16&255;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(j&65535)>>1]=g;return}else{fj[h&511](j&16777215,a);return}}function aod(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;e=d&65535;f=a+2|0;a=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a&65535;g=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;h=c[g>>2]|0;i=h-4|0;c[g>>2]=i;c[240591]=e>>>8;c[240592]=f|e<<16;c[240593]=0;c[240594]=0;g=h-2|0;h=g>>>16&255;j=c[957136+(h*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(g&65535)>>1]=a}else{fj[j&511](g&16777215,f)}f=i>>>16&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(i&65535)>>1]=d;return}else{fj[g&511](i&16777215,e);return}}function aoe(){var a=0,d=0,e=0,f=0;a=c[240587]|0;d=c[962260+((a&7)<<2)>>2]|0;e=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+e|0;c[240591]=d>>>24;c[240592]=d;c[240593]=0;c[240594]=0;e=f>>>16&255;a=c[957136+(e*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=d>>>16&65535}else{fj[a&511](f&16777215,d>>>16)}a=f+2|0;f=a>>>16&255;e=c[957136+(f*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[e&511](a&16777215,d&65535);return}}function aof(){var a=0,d=0,e=0,f=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;e=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;f=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+e|0;c[240591]=d>>>24;c[240592]=d;c[240593]=0;c[240594]=0;e=f>>>16&255;a=c[957136+(e*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=d>>>16&65535}else{fj[a&511](f&16777215,d>>>16)}a=f+2|0;f=a>>>16&255;e=c[957136+(f*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[e&511](a&16777215,d&65535);return}}function aog(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[240587]|0}h=c[962260+((k>>>9&7|8)<<2)>>2]|0;k=c[240581]|0;c[240581]=k+2;a=(b[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0)+h|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;h=a>>>16&255;k=c[957136+(h*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]=j>>>16&65535}else{fj[k&511](a&16777215,j>>>16)}k=a+2|0;a=k>>>16&255;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(k&65535)>>1]=j&65535;return}else{fj[h&511](k&16777215,j&65535);return}}function aoh(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[d&511](f&16777215,i>>>16)}d=f+2|0;f=d>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[a&511](d&16777215,i&65535);return}}function aoi(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;g=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;a=g>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[d&511](g&16777215,j>>>16)}d=g+2|0;g=d>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[a&511](d&16777215,j&65535);return}}function aoj(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=h>>>16&255;f=957128+(d*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=h+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]<<16;l=a;m=g}else{g=(fl[i&255](h&16777215)|0)<<16;i=fl[c[f>>2]&255](h+2&16777215)|0|g;k=i;l=c[240587]|0;m=c[240581]|0}i=c[962260+((l>>>9&7|8)<<2)>>2]|0;c[240581]=m+2;l=(b[(c[957120+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0)+i|0;c[240591]=k>>>24;c[240592]=k;c[240593]=0;c[240594]=0;i=l>>>16&255;m=c[957136+(i*20|0)>>2]|0;if((m|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(l&65535)>>1]=k>>>16&65535}else{fj[m&511](l&16777215,k>>>16)}m=l+2|0;l=m>>>16&255;i=c[957136+(l*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(l*20|0)>>2]|0)+(m&65535)>>1]=k&65535;return}else{fj[i&511](m&16777215,k&65535);return}}function aok(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=f<<16>>16}else{i=f}f=(h<<24>>24)+d+i|0;i=f>>>16&255;d=957128+(i*20|0)|0;h=c[d>>2]|0;if((h|0)==0){j=f+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(i*20|0)>>2]|0)+(f&65535)>>1]<<16;l=a;m=g}else{g=(fl[h&255](f&16777215)|0)<<16;h=fl[c[d>>2]&255](f+2&16777215)|0|g;k=h;l=c[240587]|0;m=c[240581]|0}h=c[962260+((l>>>9&7|8)<<2)>>2]|0;c[240581]=m+2;l=(b[(c[957120+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0)+h|0;c[240591]=k>>>24;c[240592]=k;c[240593]=0;c[240594]=0;h=l>>>16&255;m=c[957136+(h*20|0)>>2]|0;if((m|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(l&65535)>>1]=k>>>16&65535}else{fj[m&511](l&16777215,k>>>16)}m=l+2|0;l=m>>>16&255;h=c[957136+(l*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(l*20|0)>>2]|0)+(m&65535)>>1]=k&65535;return}else{fj[h&511](m&16777215,k&65535);return}}function aol(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]<<16;k=d}else{d=(fl[h&255](f&16777215)|0)<<16;h=fl[c[g>>2]&255](f+2&16777215)|0|d;j=h;k=c[240581]|0}h=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=k+2;d=(b[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0)+h|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;h=d>>>16&255;k=c[957136+(h*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[k&511](d&16777215,j>>>16)}k=d+2|0;d=k>>>16&255;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(k&65535)>>1]=j&65535;return}else{fj[h&511](k&16777215,j&65535);return}}function aom(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|f<<16;h=f&255;f=957128+(h*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=g+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(h*20|0)>>2]|0)+a>>1]<<16;l=d}else{d=(fl[i&255](g&16777215)|0)<<16;i=fl[c[f>>2]&255](g+2&16777215)|0|d;k=i;l=c[240581]|0}i=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=l+2;d=(b[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0)+i|0;c[240591]=k>>>24;c[240592]=k;c[240593]=0;c[240594]=0;i=d>>>16&255;l=c[957136+(i*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]=k>>>16&65535}else{fj[l&511](d&16777215,k>>>16)}l=d+2|0;d=l>>>16&255;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(l&65535)>>1]=k&65535;return}else{fj[i&511](l&16777215,k&65535);return}}function aon(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;e=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;g=f&65535;h=e+2|0;e=b[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=e&65535;i=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+i|0;c[240591]=g>>>8;c[240592]=h|g<<16;c[240593]=0;c[240594]=0;i=a>>>16&255;d=c[957136+(i*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(a&65535)>>1]=f}else{fj[d&511](a&16777215,g)}g=a+2|0;a=g>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=e;return}else{fj[d&511](g&16777215,h);return}}function aoo(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;f=h&65535;i=g+2|0;g=b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=g&65535;j=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+j|0;c[240591]=f>>>8;c[240592]=i|f<<16;c[240593]=0;c[240594]=0;j=a>>>16&255;d=c[957136+(j*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(a&65535)>>1]=h}else{fj[d&511](a&16777215,f)}f=a+2|0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g;return}else{fj[d&511](f&16777215,i);return}}function aop(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+4|0;c[240581]=d;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=e&65535;g=a+2|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;i=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+6;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+i|0;c[240591]=f>>>8;c[240592]=g|f<<16;c[240593]=0;c[240594]=0;i=a>>>16&255;d=c[957136+(i*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(a&65535)>>1]=e}else{fj[d&511](a&16777215,f)}f=a+2|0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=h;return}else{fj[d&511](f&16777215,g);return}}function aoq(){var a=0,d=0,f=0,g=0,h=0;a=c[240587]|0;d=c[962260+((a&7)<<2)>>2]|0;f=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;c[240591]=d>>>24;c[240592]=d;c[240593]=0;c[240594]=0;h=a>>>16&255;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535}else{fj[f&511](a&16777215,d>>>16)}f=a+2|0;a=f>>>16&255;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[h&511](f&16777215,d&65535);return}}function aor(){var a=0,d=0,f=0,g=0,h=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;c[240591]=d>>>24;c[240592]=d;c[240593]=0;c[240594]=0;h=a>>>16&255;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535}else{fj[f&511](a&16777215,d>>>16)}f=a+2|0;a=f>>>16&255;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[h&511](f&16777215,d&65535);return}}function aos(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=a}else{a=(fl[h&255](d&16777215)|0)<<16;h=fl[c[g>>2]&255](d+2&16777215)|0|a;j=h;k=c[240587]|0}h=c[962260+((k>>>9&7|8)<<2)>>2]|0;k=c[240581]|0;c[240581]=k+2;a=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;k=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){l=k<<16>>16}else{l=k}k=(a<<24>>24)+h+l|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;l=k>>>16&255;h=c[957136+(l*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(l*20|0)>>2]|0)+(k&65535)>>1]=j>>>16&65535}else{fj[h&511](k&16777215,j>>>16)}h=k+2|0;k=h>>>16&255;l=c[957136+(k*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[l&511](h&16777215,j&65535);return}}function aot(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=d<<16>>16}else{j=d}d=(f<<24>>24)+a+j|0;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;j=d>>>16&255;a=c[957136+(j*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[a&511](d&16777215,i>>>16)}a=d+2|0;d=a>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[j&511](a&16777215,i&65535);return}}function aou(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){k=d<<16>>16}else{k=d}d=(g<<24>>24)+a+k|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;k=d>>>16&255;a=c[957136+(k*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[a&511](d&16777215,j>>>16)}a=d+2|0;d=a>>>16&255;k=c[957136+(d*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[k&511](a&16777215,j&65535);return}}function aov(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=h>>>16&255;f=957128+(d*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=h+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]<<16;l=a;m=g}else{g=(fl[i&255](h&16777215)|0)<<16;i=fl[c[f>>2]&255](h+2&16777215)|0|g;k=i;l=c[240587]|0;m=c[240581]|0}i=c[962260+((l>>>9&7|8)<<2)>>2]|0;c[240581]=m+2;l=e[(c[957120+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0;m=c[962260+(l>>>12<<2)>>2]|0;if((l&2048|0)==0){n=m<<16>>16}else{n=m}m=(l<<24>>24)+i+n|0;c[240591]=k>>>24;c[240592]=k;c[240593]=0;c[240594]=0;n=m>>>16&255;i=c[957136+(n*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(n*20|0)>>2]|0)+(m&65535)>>1]=k>>>16&65535}else{fj[i&511](m&16777215,k>>>16)}i=m+2|0;m=i>>>16&255;n=c[957136+(m*20|0)>>2]|0;if((n|0)==0){b[(c[957120+(m*20|0)>>2]|0)+(i&65535)>>1]=k&65535;return}else{fj[n&511](i&16777215,k&65535);return}}function aow(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=f<<16>>16}else{i=f}f=(h<<24>>24)+d+i|0;i=f>>>16&255;d=957128+(i*20|0)|0;h=c[d>>2]|0;if((h|0)==0){j=f+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(i*20|0)>>2]|0)+(f&65535)>>1]|0)<<16;l=a;m=g}else{g=(fl[h&255](f&16777215)|0)<<16;h=fl[c[d>>2]&255](f+2&16777215)|0|g;k=h;l=c[240587]|0;m=c[240581]|0}h=c[962260+((l>>>9&7|8)<<2)>>2]|0;c[240581]=m+2;l=e[(c[957120+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0;m=c[962260+(l>>>12<<2)>>2]|0;if((l&2048|0)==0){n=m<<16>>16}else{n=m}m=(l<<24>>24)+h+n|0;c[240591]=k>>>24;c[240592]=k;c[240593]=0;c[240594]=0;n=m>>>16&255;h=c[957136+(n*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(n*20|0)>>2]|0)+(m&65535)>>1]=k>>>16&65535}else{fj[h&511](m&16777215,k>>>16)}h=m+2|0;m=h>>>16&255;n=c[957136+(m*20|0)>>2]|0;if((n|0)==0){b[(c[957120+(m*20|0)>>2]|0)+(h&65535)>>1]=k&65535;return}else{fj[n&511](h&16777215,k&65535);return}}function aox(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]<<16;k=d}else{d=(fl[h&255](f&16777215)|0)<<16;h=fl[c[g>>2]&255](f+2&16777215)|0|d;j=h;k=c[240581]|0}h=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=k+2;d=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;k=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){l=k<<16>>16}else{l=k}k=(d<<24>>24)+h+l|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;l=k>>>16&255;h=c[957136+(l*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(l*20|0)>>2]|0)+(k&65535)>>1]=j>>>16&65535}else{fj[h&511](k&16777215,j>>>16)}h=k+2|0;k=h>>>16&255;l=c[957136+(k*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[l&511](h&16777215,j&65535);return}}function aoy(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|f<<16;h=f&255;f=957128+(h*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=g+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16;l=d}else{d=(fl[i&255](g&16777215)|0)<<16;i=fl[c[f>>2]&255](g+2&16777215)|0|d;k=i;l=c[240581]|0}i=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=l+2;d=e[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;l=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){m=l<<16>>16}else{m=l}l=(d<<24>>24)+i+m|0;c[240591]=k>>>24;c[240592]=k;c[240593]=0;c[240594]=0;m=l>>>16&255;i=c[957136+(m*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(m*20|0)>>2]|0)+(l&65535)>>1]=k>>>16&65535}else{fj[i&511](l&16777215,k>>>16)}i=l+2|0;l=i>>>16&255;m=c[957136+(l*20|0)>>2]|0;if((m|0)==0){b[(c[957120+(l*20|0)>>2]|0)+(i&65535)>>1]=k&65535;return}else{fj[m&511](i&16777215,k&65535);return}}function aoz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=g&65535;i=f+2|0;f=b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=f&65535;j=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){k=d<<16>>16}else{k=d}d=(a<<24>>24)+j+k|0;c[240591]=h>>>8;c[240592]=i|h<<16;c[240593]=0;c[240594]=0;k=d>>>16&255;j=c[957136+(k*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(d&65535)>>1]=g}else{fj[j&511](d&16777215,h)}h=d+2|0;d=h>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]=f;return}else{fj[j&511](h&16777215,i);return}}function aoA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;f=h&65535;i=g+2|0;g=b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=g&65535;j=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){k=d<<16>>16}else{k=d}d=(a<<24>>24)+j+k|0;c[240591]=f>>>8;c[240592]=i|f<<16;c[240593]=0;c[240594]=0;k=d>>>16&255;j=c[957136+(k*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(d&65535)>>1]=h}else{fj[j&511](d&16777215,f)}f=d+2|0;d=f>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g;return}else{fj[j&511](f&16777215,i);return}}function aoB(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=f&65535;h=a+2|0;i=b[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=i&65535;j=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+6;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){k=d<<16>>16}else{k=d}d=(a<<24>>24)+j+k|0;c[240591]=g>>>8;c[240592]=h|g<<16;c[240593]=0;c[240594]=0;k=d>>>16&255;j=c[957136+(k*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(d&65535)>>1]=f}else{fj[j&511](d&16777215,g)}g=d+2|0;d=g>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=i;return}else{fj[j&511](g&16777215,h);return}}function aoC(){var a=0,d=0,e=0,f=0;a=c[962260+((c[240587]&7)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=a>>>24;c[240592]=a;c[240593]=0;c[240594]=0;d=e>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(e&65535)>>1]=a>>>16&65535}else{fj[f&511](e&16777215,a>>>16)}f=e+2|0;e=f>>>16&255;d=c[957136+(e*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function aoD(){var a=0,d=0,e=0,f=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=a>>>24;c[240592]=a;c[240593]=0;c[240594]=0;d=e>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(e&65535)>>1]=a>>>16&65535}else{fj[f&511](e&16777215,a>>>16)}f=e+2|0;e=f>>>16&255;d=c[957136+(e*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function aoE(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]<<16}else{d=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|d}d=c[240581]|0;c[240581]=d+2;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[f&511](a&16777215,i>>>16)}f=a+2|0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[d&511](f&16777215,i&65535);return}}function aoF(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;a=d>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i>>>16&65535}else{fj[f&511](d&16777215,i>>>16)}f=d+2|0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[a&511](f&16777215,i&65535);return}}function aoG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;a=d>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=j>>>16&65535}else{fj[g&511](d&16777215,j>>>16)}g=d+2|0;d=g>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[a&511](g&16777215,j&65535);return}}function aoH(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=g>>>16&255;d=957128+(a*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]<<16;k=f}else{f=(fl[h&255](g&16777215)|0)<<16;h=fl[c[d>>2]&255](g+2&16777215)|0|f;j=h;k=c[240581]|0}c[240581]=k+2;h=b[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;k=h>>>16&255;f=c[957136+(k*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=j>>>16&65535}else{fj[f&511](h&16777215,j>>>16)}f=h+2|0;h=f>>>16&255;k=c[957136+(h*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[k&511](f&16777215,j&65535);return}}function aoI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=d<<16>>16}else{h=d}d=(g<<24>>24)+a+h|0;h=d>>>16&255;a=957128+(h*20|0)|0;g=c[a>>2]|0;if((g|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]<<16;k=f}else{f=(fl[g&255](d&16777215)|0)<<16;g=fl[c[a>>2]&255](d+2&16777215)|0|f;j=g;k=c[240581]|0}c[240581]=k+2;g=b[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;k=g>>>16&255;f=c[957136+(k*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[f&511](g&16777215,j>>>16)}f=g+2|0;g=f>>>16&255;k=c[957136+(g*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[k&511](f&16777215,j&65535);return}}function aoJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]<<16;k=d}else{d=(fl[h&255](f&16777215)|0)<<16;h=fl[c[g>>2]&255](f+2&16777215)|0|d;j=h;k=c[240581]|0}c[240581]=k+2;h=b[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;k=h>>>16&255;d=c[957136+(k*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=j>>>16&65535}else{fj[d&511](h&16777215,j>>>16)}d=h+2|0;h=d>>>16&255;k=c[957136+(h*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[k&511](d&16777215,j&65535);return}}function aoK(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|f<<16;h=f&255;f=957128+(h*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=g+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+(h*20|0)>>2]|0)+a>>1]<<16;l=d}else{d=(fl[i&255](g&16777215)|0)<<16;i=fl[c[f>>2]&255](g+2&16777215)|0|d;k=i;l=c[240581]|0}c[240581]=l+2;i=b[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;c[240591]=k>>>24;c[240592]=k;c[240593]=0;c[240594]=0;l=i>>>16&255;d=c[957136+(l*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(l*20|0)>>2]|0)+(i&65535)>>1]=k>>>16&65535}else{fj[d&511](i&16777215,k>>>16)}d=i+2|0;i=d>>>16&255;l=c[957136+(i*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]=k&65535;return}else{fj[l&511](d&16777215,k&65535);return}}function aoL(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;e=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;g=f&65535;h=e+2|0;e=b[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=e&65535;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=g>>>8;c[240592]=h|g<<16;c[240593]=0;c[240594]=0;d=a>>>16&255;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f}else{fj[i&511](a&16777215,g)}g=a+2|0;a=g>>>16&255;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=e;return}else{fj[i&511](g&16777215,h);return}}function aoM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;f=h&65535;i=g+2|0;g=b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=g&65535;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=f>>>8;c[240592]=i|f<<16;c[240593]=0;c[240594]=0;d=a>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=h}else{fj[j&511](a&16777215,f)}f=a+2|0;a=f>>>16&255;j=c[957136+(a*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g;return}else{fj[j&511](f&16777215,i);return}}function aoN(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+4|0;c[240581]=d;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=e&65535;g=a+2|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;c[240581]=a+6;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=f>>>8;c[240592]=g|f<<16;c[240593]=0;c[240594]=0;d=a>>>16&255;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=e}else{fj[i&511](a&16777215,f)}f=a+2|0;a=f>>>16&255;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=h;return}else{fj[i&511](f&16777215,g);return}}function aoO(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+4;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;c[240591]=a>>>24;c[240592]=a;c[240593]=0;c[240594]=0;h=f&255;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+d>>1]=a>>>16&65535}else{fj[f&511](g&16777215,a>>>16)}f=g+2|0;g=f>>>16&255;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function aoP(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+4;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;c[240591]=a>>>24;c[240592]=a;c[240593]=0;c[240594]=0;h=f&255;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+d>>1]=a>>>16&65535}else{fj[f&511](g&16777215,a>>>16)}f=g+2|0;g=f>>>16&255;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[d&511](f&16777215,a&65535);return}}function aoQ(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{d=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|d}d=c[240581]|0;c[240581]=d+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;f=d+2|0;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d|a<<16;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;g=a&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+d>>1]=i>>>16&65535}else{fj[a&511](f&16777215,i>>>16)}a=f+2|0;f=a>>>16&255;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[d&511](a&16777215,i&65535);return}}function aoR(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a}a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;c[240591]=i>>>24;c[240592]=i;c[240593]=0;c[240594]=0;g=d&255;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=i>>>16&65535}else{fj[d&511](f&16777215,i>>>16)}d=f+2|0;f=d>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[a&511](d&16777215,i&65535);return}}function aoS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{a=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|a}a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|d<<16;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;f=d&255;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+a>>1]=j>>>16&65535}else{fj[d&511](g&16777215,j>>>16)}d=g+2|0;g=d>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=j&65535;return}else{fj[a&511](d&16777215,j&65535);return}}function aoT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=g>>>16&255;d=957128+(a*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]<<16;k=f}else{f=(fl[h&255](g&16777215)|0)<<16;h=fl[c[d>>2]&255](g+2&16777215)|0|f;j=h;k=c[240581]|0}c[240581]=k+4;h=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;f=k+2|0;k=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=k|h<<16;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;g=h&255;h=c[957136+(g*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(g*20|0)>>2]|0)+k>>1]=j>>>16&65535}else{fj[h&511](f&16777215,j>>>16)}h=f+2|0;f=h>>>16&255;k=c[957136+(f*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[k&511](h&16777215,j&65535);return}}function aoU(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=d<<16>>16}else{h=d}d=(g<<24>>24)+a+h|0;h=d>>>16&255;a=957128+(h*20|0)|0;g=c[a>>2]|0;if((g|0)==0){i=d+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;k=f}else{f=(fl[g&255](d&16777215)|0)<<16;g=fl[c[a>>2]&255](d+2&16777215)|0|f;j=g;k=c[240581]|0}c[240581]=k+4;g=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;f=k+2|0;k=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=k|g<<16;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;d=g&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+k>>1]=j>>>16&65535}else{fj[g&511](f&16777215,j>>>16)}g=f+2|0;f=g>>>16&255;k=c[957136+(f*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[k&511](g&16777215,j&65535);return}}function aoV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]<<16;k=d}else{d=(fl[h&255](f&16777215)|0)<<16;h=fl[c[g>>2]&255](f+2&16777215)|0|d;j=h;k=c[240581]|0}c[240581]=k+4;h=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;d=k+2|0;k=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=k|h<<16;c[240591]=j>>>24;c[240592]=j;c[240593]=0;c[240594]=0;f=h&255;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+k>>1]=j>>>16&65535}else{fj[h&511](d&16777215,j>>>16)}h=d+2|0;d=h>>>16&255;k=c[957136+(d*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]=j&65535;return}else{fj[k&511](h&16777215,j&65535);return}}function aoW(){var a=0,b=0,d=0;a=c[240587]|0;b=c[962260+((a&7)<<2)>>2]&65535;d=962260+((a>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|b;c[240591]=b>>>8;c[240592]=b;c[240593]=0;c[240594]=0;return}function aoX(){var a=0,b=0,d=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]&65535;d=962260+((a>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|b;c[240591]=b>>>8;c[240592]=b;c[240593]=0;c[240594]=0;return}function aoY(){var a=0,d=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|a;c[240591]=a>>>8;c[240592]=a;c[240593]=0;c[240594]=0;return}function aoZ(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|f;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;return}function ao_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=a|f<<16;h=f&255;f=957128+(h*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=g+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+a>>1]|0)<<16;l=d}else{d=(fl[i&255](g&16777215)|0)<<16;i=fl[c[f>>2]&255](g+2&16777215)|0|d;k=i;l=c[240581]|0}c[240581]=l+4;i=e[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;d=l+2|0;l=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=l|i<<16;c[240591]=k>>>24;c[240592]=k;c[240593]=0;c[240594]=0;g=i&255;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+l>>1]=k>>>16&65535}else{fj[i&511](d&16777215,k>>>16)}i=d+2|0;d=i>>>16&255;l=c[957136+(d*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(i&65535)>>1]=k&65535;return}else{fj[l&511](i&16777215,k&65535);return}}function ao$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=g&65535;i=f+2|0;f=b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=f&65535;c[240581]=a+6;j=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|j<<16;c[240591]=h>>>8;c[240592]=i|h<<16;c[240593]=0;c[240594]=0;k=j&255;j=c[957136+(k*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(k*20|0)>>2]|0)+a>>1]=g}else{fj[j&511](d&16777215,h)}h=d+2|0;d=h>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]=f;return}else{fj[j&511](h&16777215,i);return}}function ao0(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;f=h&65535;i=g+2|0;g=b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=g&65535;c[240581]=a+6;j=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|j<<16;c[240591]=f>>>8;c[240592]=i|f<<16;c[240593]=0;c[240594]=0;k=j&255;j=c[957136+(k*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(k*20|0)>>2]|0)+a>>1]=h}else{fj[j&511](d&16777215,f)}f=d+2|0;d=f>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g;return}else{fj[j&511](f&16777215,i);return}}function ao1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=f&65535;h=a+2|0;i=b[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=i&65535;c[240581]=a+8;j=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+6|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|j<<16;c[240591]=g>>>8;c[240592]=h|g<<16;c[240593]=0;c[240594]=0;k=j&255;j=c[957136+(k*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(k*20|0)>>2]|0)+a>>1]=f}else{fj[j&511](d&16777215,g)}g=d+2|0;d=g>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]=i;return}else{fj[j&511](g&16777215,h);return}}function ao2(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}a=962260+((h>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-65536|g;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;return}function ao3(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-65536|f;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;return}function ao4(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-65536|f;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;return}function ao5(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-65536|h;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;return}function ao6(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[957128+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[b&255](d&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-65536|h;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;return}function ao7(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|g;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;return}function ao8(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=b&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+a>>1]|0}else{g=fl[f&255](a|b<<16&16711680)|0}b=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[b>>2]=c[b>>2]&-65536|g;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;return}function ao9(){var a=0,b=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=962260+(((c[240587]|0)>>>9&7)<<2)|0;c[a>>2]=c[a>>2]&-65536|b;c[240591]=b>>>8;c[240592]=b;c[240593]=0;c[240594]=0;return}function apa(){var a=0;a=c[240587]|0;c[962260+((a>>>9&7|8)<<2)>>2]=c[962260+((a&7)<<2)>>2]<<16>>16;return}function apb(){var a=0;a=c[240587]|0;c[962260+((a>>>9&7|8)<<2)>>2]=c[962260+((a&7|8)<<2)>>2]<<16>>16;return}function apc(){var a=0,d=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;return}function apd(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;return}function ape(){var a=0;a=c[240581]|0;c[240581]=a+2;c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;return}function apf(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=b>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240587]|0}c[962260+((h>>>9&7|8)<<2)>>2]=g<<16>>16;return}function apg(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=f<<16>>16;return}function aph(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=f<<16>>16;return}function api(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a;j=h<<16;k=j>>16;l=i>>>9;m=l&7;n=m|8;o=962260+(n<<2)|0;c[o>>2]=k;return}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0;j=h<<16;k=j>>16;l=i>>>9;m=l&7;n=m|8;o=962260+(n<<2)|0;c[o>>2]=k;return}}function apj(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[957128+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a;j=h<<16;k=j>>16;l=i>>>9;m=l&7;n=m|8;o=962260+(n<<2)|0;c[o>>2]=k;return}else{a=fl[b&255](d&16777215)|0;h=a;i=c[240587]|0;j=h<<16;k=j>>16;l=i>>>9;m=l&7;n=m|8;o=962260+(n<<2)|0;c[o>>2]=k;return}}function apk(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=g<<16>>16;return}function apl(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=b&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+a>>1]|0;h=g<<16;i=h>>16;j=c[240587]|0;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}else{g=fl[f&255](a|b<<16&16711680)|0;h=g<<16;i=h>>16;j=c[240587]|0;k=j>>>9;l=k&7;m=l|8;n=962260+(m<<2)|0;c[n>>2]=i;return}}function apm(){var a=0,d=0,e=0,f=0,g=0;a=c[240587]|0;d=c[962260+((a&7)<<2)>>2]|0;e=d&65535;f=c[962260+((a>>>9&7|8)<<2)>>2]|0;c[240591]=e>>>8;c[240592]=e;c[240593]=0;c[240594]=0;a=f>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[g&511](f&16777215,e);return}}function apn(){var a=0,d=0,e=0,f=0,g=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;e=d&65535;f=c[962260+((a>>>9&7|8)<<2)>>2]|0;c[240591]=e>>>8;c[240592]=e;c[240593]=0;c[240594]=0;a=f>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[g&511](f&16777215,e);return}}function apo(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[240587]|0}a=c[962260+((i>>>9&7|8)<<2)>>2]|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;i=a>>>16&255;d=c[957136+(i*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[d&511](a&16777215,h);return}}function app(){var a=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;f=d>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[a&511](d&16777215,g);return}}function apq(){var a=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;f=d>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[a&511](d&16777215,g);return}}function apr(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=c[962260+((i>>>9&7|8)<<2)>>2]|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;i=a>>>16&255;g=c[957136+(i*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[g&511](a&16777215,h);return}}function aps(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=f>>>16&255;d=c[957128+(h*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(f&65535)>>1]|0;j=a}else{a=fl[d&255](f&16777215)|0;i=a;j=c[240587]|0}a=c[962260+((j>>>9&7|8)<<2)>>2]|0;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;j=a>>>16&255;f=c[957136+(j*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[f&511](a&16777215,i);return}}function apt(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;f=d>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[a&511](d&16777215,g);return}}function apu(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+a>>1]|0}else{h=fl[g&255](a|d<<16&16711680)|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;a=d>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h&65535;return}else{fj[g&511](d&16777215,h);return}}function apv(){var a=0,d=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a&65535;e=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=d>>>8;c[240592]=d;c[240593]=0;c[240594]=0;f=e>>>16&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(e&65535)>>1]=a;return}else{fj[g&511](e&16777215,d);return}}function apw(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g&65535;a=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;d=a>>>16&255;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=g;return}else{fj[h&511](a&16777215,f);return}}function apx(){var a=0,d=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d&65535;e=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240591]=a>>>8;c[240592]=a;c[240593]=0;c[240594]=0;f=e>>>16&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(e&65535)>>1]=d;return}else{fj[g&511](e&16777215,a);return}}function apy(){var a=0,d=0,e=0,f=0,g=0;a=c[240587]|0;d=c[962260+((a&7)<<2)>>2]|0;e=d&65535;f=962260+((a>>>9&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+2;c[240591]=e>>>8;c[240592]=e;c[240593]=0;c[240594]=0;f=a>>>16&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,e);return}}function apz(){var a=0,d=0,e=0,f=0,g=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;e=d&65535;f=962260+((a>>>9&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+2;c[240591]=e>>>8;c[240592]=e;c[240593]=0;c[240594]=0;f=a>>>16&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,e);return}}function apA(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7|8)<<2)|0;i=c[a>>2]|0;c[a>>2]=i+2;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;a=i>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[d&511](i&16777215,h);return}}function apB(){var a=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+2;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function apC(){var a=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+2;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function apD(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7|8)<<2)|0;i=c[a>>2]|0;c[a>>2]=i+2;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;a=i>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[g&511](i&16777215,h);return}}function apE(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=f>>>16&255;d=c[957128+(h*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(f&65535)>>1]|0;j=a}else{a=fl[d&255](f&16777215)|0;i=a;j=c[240587]|0}a=962260+((j>>>9&7|8)<<2)|0;j=c[a>>2]|0;c[a>>2]=j+2;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;a=j>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(j&65535)>>1]=i&65535;return}else{fj[f&511](j&16777215,i);return}}function apF(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+2;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function apG(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+a>>1]|0}else{h=fl[g&255](a|d<<16&16711680)|0}d=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;a=c[d>>2]|0;c[d>>2]=a+2;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;d=a>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[g&511](a&16777215,h);return}}function apH(){var a=0,d=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a&65535;e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+2;c[240591]=d>>>8;c[240592]=d;c[240593]=0;c[240594]=0;e=f>>>16&255;g=c[957136+(e*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=a;return}else{fj[g&511](f&16777215,d);return}}function apI(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g&65535;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;a=d>>>16&255;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=g;return}else{fj[h&511](d&16777215,f);return}}function apJ(){var a=0,d=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d&65535;e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+2;c[240591]=a>>>8;c[240592]=a;c[240593]=0;c[240594]=0;e=f>>>16&255;g=c[957136+(e*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=d;return}else{fj[g&511](f&16777215,a);return}}function apK(){var a=0,d=0,e=0,f=0,g=0;a=c[240587]|0;d=c[962260+((a&7)<<2)>>2]|0;e=d&65535;f=962260+((a>>>9&7|8)<<2)|0;a=(c[f>>2]|0)-2|0;c[f>>2]=a;c[240591]=e>>>8;c[240592]=e;c[240593]=0;c[240594]=0;f=a>>>16&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,e);return}}function apL(){var a=0,d=0,e=0,f=0,g=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;e=d&65535;f=962260+((a>>>9&7|8)<<2)|0;a=(c[f>>2]|0)-2|0;c[f>>2]=a;c[240591]=e>>>8;c[240592]=e;c[240593]=0;c[240594]=0;f=a>>>16&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,e);return}}function apM(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7|8)<<2)|0;i=(c[a>>2]|0)-2|0;c[a>>2]=i;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;a=i>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[d&511](i&16777215,h);return}}function apN(){var a=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-2|0;c[d>>2]=f;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function apO(){var a=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-2|0;c[d>>2]=f;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function apP(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240587]|0}a=962260+((i>>>9&7|8)<<2)|0;i=(c[a>>2]|0)-2|0;c[a>>2]=i;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;a=i>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[g&511](i&16777215,h);return}}function apQ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+d+h|0;h=f>>>16&255;d=c[957128+(h*20|0)>>2]|0;if((d|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(f&65535)>>1]|0;j=a}else{a=fl[d&255](f&16777215)|0;i=a;j=c[240587]|0}a=962260+((j>>>9&7|8)<<2)|0;j=(c[a>>2]|0)-2|0;c[a>>2]=j;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;a=j>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(j&65535)>>1]=i&65535;return}else{fj[f&511](j&16777215,i);return}}function apR(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-2|0;c[d>>2]=f;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function apS(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+a>>1]|0}else{h=fl[g&255](a|d<<16&16711680)|0}d=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;a=(c[d>>2]|0)-2|0;c[d>>2]=a;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;d=a>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=h&65535;return}else{fj[g&511](a&16777215,h);return}}function apT(){var a=0,d=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a&65535;e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-2|0;c[e>>2]=f;c[240591]=d>>>8;c[240592]=d;c[240593]=0;c[240594]=0;e=f>>>16&255;g=c[957136+(e*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=a;return}else{fj[g&511](f&16777215,d);return}}function apU(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g&65535;a=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;a=d>>>16&255;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=g;return}else{fj[h&511](d&16777215,f);return}}function apV(){var a=0,d=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d&65535;e=962260+(((c[240587]|0)>>>9&7|8)<<2)|0;f=(c[e>>2]|0)-2|0;c[e>>2]=f;c[240591]=a>>>8;c[240592]=a;c[240593]=0;c[240594]=0;e=f>>>16&255;g=c[957136+(e*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=d;return}else{fj[g&511](f&16777215,a);return}}function apW(){var a=0,d=0,e=0,f=0,g=0;a=c[240587]|0;d=c[962260+((a&7)<<2)>>2]|0;e=d&65535;f=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;c[240591]=e>>>8;c[240592]=e;c[240593]=0;c[240594]=0;f=g>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=d&65535;return}else{fj[a&511](g&16777215,e);return}}function apX(){var a=0,d=0,e=0,f=0,g=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;e=d&65535;f=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;c[240591]=e>>>8;c[240592]=e;c[240593]=0;c[240594]=0;f=g>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=d&65535;return}else{fj[a&511](g&16777215,e);return}}function apY(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[240587]|0}a=c[962260+((i>>>9&7|8)<<2)>>2]|0;i=c[240581]|0;c[240581]=i+2;d=(b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0)+a|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;a=d>>>16&255;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h&65535;return}else{fj[i&511](d&16777215,h);return}}function apZ(){var a=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;a=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[f&511](a&16777215,g);return}}function ap_(){var a=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;a=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[f&511](a&16777215,g);return}}function ap$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=h>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){i=e[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]|0;j=a;k=g}else{g=fl[f&255](h&16777215)|0;i=g;j=c[240587]|0;k=c[240581]|0}g=c[962260+((j>>>9&7|8)<<2)>>2]|0;c[240581]=k+2;j=(b[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0)+g|0;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;g=j>>>16&255;k=c[957136+(g*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(j&65535)>>1]=i&65535;return}else{fj[k&511](j&16777215,i);return}}function ap0(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=f<<16>>16}else{i=f}f=(h<<24>>24)+d+i|0;i=f>>>16&255;d=c[957128+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[957120+(i*20|0)>>2]|0)+(f&65535)>>1]|0;k=a;l=g}else{g=fl[d&255](f&16777215)|0;j=g;k=c[240587]|0;l=c[240581]|0}g=c[962260+((k>>>9&7|8)<<2)>>2]|0;c[240581]=l+2;k=(b[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0)+g|0;c[240591]=j>>>8;c[240592]=j;c[240593]=0;c[240594]=0;g=k>>>16&255;l=c[957136+(g*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(k&65535)>>1]=j&65535;return}else{fj[l&511](k&16777215,j);return}}function ap1(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0;i=d}else{d=fl[g&255](f&16777215)|0;h=d;i=c[240581]|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=i+2;f=(b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0)+d|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;d=f>>>16&255;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=h&65535;return}else{fj[i&511](f&16777215,h);return}}function ap2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957128+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0;j=d}else{d=fl[h&255](a|f<<16&16711680)|0;i=d;j=c[240581]|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=j+2;f=(b[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0)+d|0;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;d=f>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[j&511](f&16777215,i);return}}function ap3(){var a=0,d=0,e=0,f=0,g=0;a=c[240581]|0;d=a+2|0;c[240581]=d;e=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f&65535;g=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;c[240591]=e>>>8;c[240592]=e;c[240593]=0;c[240594]=0;g=a>>>16&255;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=f;return}else{fj[d&511](a&16777215,e);return}}function ap4(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+f|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;f=a>>>16&255;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=h;return}else{fj[d&511](a&16777215,g);return}}function ap5(){var a=0,d=0,e=0,f=0,g=0;a=c[240581]|0;d=a+2|0;c[240581]=d;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=e&65535;g=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+4;a=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;g=a>>>16&255;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=e;return}else{fj[d&511](a&16777215,f);return}}function ap6(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7)<<2)>>2]|0;f=d&65535;g=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;h=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=a<<16>>16}else{i=a}a=(h<<24>>24)+g+i|0;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;i=a>>>16&255;g=c[957136+(i*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,f);return}}function ap7(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d&65535;g=c[962260+((a>>>9&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;h=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=a<<16>>16}else{i=a}a=(h<<24>>24)+g+i|0;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;i=a>>>16&255;g=c[957136+(i*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[g&511](a&16777215,f);return}}function ap8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=d>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[g&255](d&16777215)|0;h=a;i=c[240587]|0}a=c[962260+((i>>>9&7|8)<<2)>>2]|0;i=c[240581]|0;c[240581]=i+2;d=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){j=i<<16>>16}else{j=i}i=(d<<24>>24)+a+j|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;j=i>>>16&255;a=c[957136+(j*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[a&511](i&16777215,h);return}}function ap9(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=f<<16>>16}else{h=f}f=(a<<24>>24)+d+h|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;h=f>>>16&255;d=c[957136+(h*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[d&511](f&16777215,g);return}}function aqa(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=f<<16>>16}else{h=f}f=(a<<24>>24)+d+h|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;h=f>>>16&255;d=c[957136+(h*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[d&511](f&16777215,g);return}}function aqb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=h>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){i=e[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]|0;j=a;k=g}else{g=fl[f&255](h&16777215)|0;i=g;j=c[240587]|0;k=c[240581]|0}g=c[962260+((j>>>9&7|8)<<2)>>2]|0;c[240581]=k+2;j=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;k=c[962260+(j>>>12<<2)>>2]|0;if((j&2048|0)==0){l=k<<16>>16}else{l=k}k=(j<<24>>24)+g+l|0;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;l=k>>>16&255;g=c[957136+(l*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(l*20|0)>>2]|0)+(k&65535)>>1]=i&65535;return}else{fj[g&511](k&16777215,i);return}}function aqc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;f=c[240581]|0;g=f+2|0;c[240581]=g;h=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=f<<16>>16}else{i=f}f=(h<<24>>24)+d+i|0;i=f>>>16&255;d=c[957128+(i*20|0)>>2]|0;if((d|0)==0){j=e[(c[957120+(i*20|0)>>2]|0)+(f&65535)>>1]|0;k=a;l=g}else{g=fl[d&255](f&16777215)|0;j=g;k=c[240587]|0;l=c[240581]|0}g=c[962260+((k>>>9&7|8)<<2)>>2]|0;c[240581]=l+2;k=e[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;l=c[962260+(k>>>12<<2)>>2]|0;if((k&2048|0)==0){m=l<<16>>16}else{m=l}l=(k<<24>>24)+g+m|0;c[240591]=j>>>8;c[240592]=j;c[240593]=0;c[240594]=0;m=l>>>16&255;g=c[957136+(m*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(m*20|0)>>2]|0)+(l&65535)>>1]=j&65535;return}else{fj[g&511](l&16777215,j);return}}function aqd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0;i=d}else{d=fl[g&255](f&16777215)|0;h=d;i=c[240581]|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=i+2;f=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;i=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){j=i<<16>>16}else{j=i}i=(f<<24>>24)+d+j|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;j=i>>>16&255;d=c[957136+(j*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[d&511](i&16777215,h);return}}function aqe(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957128+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0;j=d}else{d=fl[h&255](a|f<<16&16711680)|0;i=d;j=c[240581]|0}d=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=j+2;f=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;j=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){k=j<<16>>16}else{k=j}j=(f<<24>>24)+d+k|0;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;k=j>>>16&255;d=c[957136+(k*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(j&65535)>>1]=i&65535;return}else{fj[d&511](j&16777215,i);return}}function aqf(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g&65535;h=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=d<<16>>16}else{i=d}d=(a<<24>>24)+h+i|0;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;i=d>>>16&255;h=c[957136+(i*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]=g;return}else{fj[h&511](d&16777215,f);return}}function aqg(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;f=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=d<<16>>16}else{i=d}d=(a<<24>>24)+f+i|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;i=d>>>16&255;f=c[957136+(i*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]=h;return}else{fj[f&511](d&16777215,g);return}}function aqh(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=f&65535;h=c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){i=d<<16>>16}else{i=d}d=(a<<24>>24)+h+i|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;i=d>>>16&255;h=c[957136+(i*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]=f;return}else{fj[h&511](d&16777215,g);return}}function aqi(){var a=0,d=0,e=0,f=0,g=0;a=c[962260+((c[240587]&7)<<2)>>2]|0;d=a&65535;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[240591]=d>>>8;c[240592]=d;c[240593]=0;c[240594]=0;e=f>>>16&255;g=c[957136+(e*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[g&511](f&16777215,d);return}}function aqj(){var a=0,d=0,e=0,f=0,g=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a&65535;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;c[240591]=d>>>8;c[240592]=d;c[240593]=0;c[240594]=0;e=f>>>16&255;g=c[957136+(e*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(f&65535)>>1]=a&65535;return}else{fj[g&511](f&16777215,d);return}}function aqk(){var a=0,d=0,f=0,g=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=c[240581]|0;c[240581]=a+2;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;a=f>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[d&511](f&16777215,g);return}}function aql(){var a=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function aqm(){var a=0,d=0,f=0,g=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=f>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,g);return}}function aqn(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=g>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0;i=f}else{f=fl[d&255](g&16777215)|0;h=f;i=c[240581]|0}c[240581]=i+2;f=b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;i=f>>>16&255;g=c[957136+(i*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(f&65535)>>1]=h&65535;return}else{fj[g&511](f&16777215,h);return}}function aqo(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=d<<16>>16}else{h=d}d=(g<<24>>24)+a+h|0;h=d>>>16&255;a=c[957128+(h*20|0)>>2]|0;if((a|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[a&255](d&16777215)|0;i=f;j=c[240581]|0}c[240581]=j+2;f=b[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;j=f>>>16&255;d=c[957136+(j*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[d&511](f&16777215,i);return}}function aqp(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0;i=d}else{d=fl[g&255](f&16777215)|0;h=d;i=c[240581]|0}c[240581]=i+2;d=b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;i=d>>>16&255;f=c[957136+(i*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]=h&65535;return}else{fj[f&511](d&16777215,h);return}}function aqq(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957128+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0;j=d}else{d=fl[h&255](a|f<<16&16711680)|0;i=d;j=c[240581]|0}c[240581]=j+2;d=b[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;j=d>>>16&255;f=c[957136+(j*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(j*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[f&511](d&16777215,i);return}}function aqr(){var a=0,d=0,e=0,f=0,g=0;a=c[240581]|0;d=a+2|0;c[240581]=d;e=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f&65535;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=e>>>8;c[240592]=e;c[240593]=0;c[240594]=0;d=a>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f;return}else{fj[g&511](a&16777215,e);return}}function aqs(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=a>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=h;return}else{fj[f&511](a&16777215,g);return}}function aqt(){var a=0,d=0,e=0,f=0,g=0;a=c[240581]|0;d=a+2|0;c[240581]=d;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=e&65535;c[240581]=a+4;a=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;d=a>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=e;return}else{fj[g&511](a&16777215,f);return}}function aqu(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7)<<2)>>2]|0;d=a&65535;f=c[240581]|0;c[240581]=f+4;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;c[240591]=d>>>8;c[240592]=d;c[240593]=0;c[240594]=0;h=g&255;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+f>>1]=a&65535;return}else{fj[i&511](f|g<<16&16711680,d);return}}function aqv(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a&65535;f=c[240581]|0;c[240581]=f+4;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;c[240591]=d>>>8;c[240592]=d;c[240593]=0;c[240594]=0;h=g&255;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+f>>1]=a&65535;return}else{fj[i&511](f|g<<16&16711680,d);return}}function aqw(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}a=c[240581]|0;c[240581]=a+4;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=f&255;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+a>>1]=g&65535;return}else{fj[h&511](a|f<<16&16711680,g);return}}function aqx(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[240581]|0;c[240581]=d+4;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;a=d+2|0;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;a=f&255;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+d>>1]=g&65535;return}else{fj[h&511](d|f<<16&16711680,g);return}}function aqy(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=c[240581]|0;c[240581]=d+4;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;a=d+2|0;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;a=f&255;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+d>>1]=g&65535;return}else{fj[h&511](d|f<<16&16711680,g);return}}function aqz(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=g>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0;i=f}else{f=fl[d&255](g&16777215)|0;h=f;i=c[240581]|0}c[240581]=i+4;f=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;g=i+2|0;i=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;g=f&255;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+i>>1]=h&65535;return}else{fj[d&511](i|f<<16&16711680,h);return}}function aqA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=d<<16>>16}else{h=d}d=(g<<24>>24)+a+h|0;h=d>>>16&255;a=c[957128+(h*20|0)>>2]|0;if((a|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(d&65535)>>1]|0;j=f}else{f=fl[a&255](d&16777215)|0;i=f;j=c[240581]|0}c[240581]=j+4;f=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;d=j+2|0;j=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;d=f&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+j>>1]=i&65535;return}else{fj[a&511](j|f<<16&16711680,i);return}}function aqB(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0;i=d}else{d=fl[g&255](f&16777215)|0;h=d;i=c[240581]|0}c[240581]=i+4;d=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;f=i+2|0;i=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=h>>>8;c[240592]=h;c[240593]=0;c[240594]=0;f=d&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+i>>1]=h&65535;return}else{fj[g&511](i|d<<16&16711680,h);return}}function aqC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=a+2|0;a=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=f&255;h=c[957128+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0;j=d}else{d=fl[h&255](a|f<<16&16711680)|0;i=d;j=c[240581]|0}c[240581]=j+4;d=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0;f=j+2|0;j=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240591]=i>>>8;c[240592]=i;c[240593]=0;c[240594]=0;f=d&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+j>>1]=i&65535;return}else{fj[a&511](j|d<<16&16711680,i);return}}function aqD(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=-(((c[240590]|0)>>>8&1)+(c[a>>2]&255)|0)|0;c[240591]=b;c[240594]=b;c[240590]=b;c[240593]=c[a>>2]&b;d=b&255;c[240592]=d|c[240592];c[a>>2]=c[a>>2]&-256|d;return}function aqE(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=-(((c[240590]|0)>>>8&1)+(c[a>>2]&65535)|0)|0;d=b>>>8;c[240591]=d;c[240594]=d;c[240590]=d;c[240593]=(c[a>>2]&b)>>>8;d=b&65535;c[240592]=d|c[240592];c[a>>2]=c[a>>2]&-65536|d;return}function aqF(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g&65535;c[240581]=a+6;h=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;d=h&255;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+a>>1]=g;return}else{fj[i&511](a|h<<16&16711680,f);return}}function aqG(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(f<<24>>24)+a+h|0;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h&65535;c[240581]=a+6;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=f&255;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+a>>1]=h;return}else{fj[i&511](a|f<<16&16711680,g);return}}function aqH(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=f&65535;c[240581]=a+6;h=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a+4|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;d=h&255;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+a>>1]=f;return}else{fj[i&511](a|h<<16&16711680,g);return}}function aqI(){var b=0,e=0,f=0,g=0,h=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-(((c[240590]|0)>>>8&1)+g|0)|0;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=g&f;g=f&255;c[240592]=g|c[240592];h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function aqJ(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=-(((c[240590]|0)>>>8&1)+g|0)|0;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=g&f;g=f&255;c[240592]=g|c[240592];h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[h&511](e&16777215,g);return}}function aqK(){var b=0,e=0,f=0,g=0,h=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-(((c[240590]|0)>>>8&1)+g|0)|0;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=g&f;g=f&255;c[240592]=g|c[240592];h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function aqL(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=-(((c[240590]|0)>>>8&1)+g|0)|0;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=g&f;g=f&255;c[240592]=g|c[240592];h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[h&511](e&16777215,g);return}}function aqM(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-(((c[240590]|0)>>>8&1)+g|0)|0;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=g&f;g=f&255;c[240592]=g|c[240592];h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function aqN(){var e=0,f=0,g=0,h=0,i=0;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}f=-(((c[240590]|0)>>>8&1)+h|0)|0;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=h&f;h=f&255;c[240592]=h|c[240592];i=c[957132+(e*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=f&255;return}else{fj[i&511](g&16777215,h);return}}function aqO(){var b=0,f=0,g=0,h=0,i=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}b=-(((c[240590]|0)>>>8&1)+i|0)|0;c[240591]=b;c[240594]=b;c[240590]=b;c[240593]=i&b;i=b&255;c[240592]=i|c[240592];g=c[957132+(h*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[g&511](f&16777215,i);return}}function aqP(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=-(((c[240590]|0)>>>8&1)+h|0)|0;c[240591]=g;c[240594]=g;c[240590]=g;c[240593]=h&g;h=g&255;c[240592]=h|c[240592];i=c[957132+(e*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[i&511](f&16777215,h);return}}function aqQ(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=-(((c[240590]|0)>>>8&1)+i|0)|0;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=i&f;i=f&255;c[240592]=i|c[240592];j=c[957132+(h*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[j&511](g&16777215,i);return}}function aqR(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=-(((c[240590]|0)>>>8&1)+(c[a>>2]|0)|0)|0;c[240591]=b>>>24;d=(c[a>>2]|b)>>>23;c[240594]=d;c[240590]=d;c[240593]=(c[a>>2]&b)>>>24;c[240592]=c[240592]|b;c[a>>2]=b;return}function aqS(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=-(((c[240590]|0)>>>8&1)+(g&65535)|0)|0;h=f>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=(g&f)>>>8;g=f&65535;c[240592]=g|c[240592];h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f&65535;return}else{fj[h&511](a&16777215,g);return}}function aqT(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=-(((c[240590]|0)>>>8&1)+(g&65535)|0)|0;h=f>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=(g&f)>>>8;g=f&65535;c[240592]=g|c[240592];h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[h&511](d&16777215,g);return}}function aqU(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=-(((c[240590]|0)>>>8&1)+(g&65535)|0)|0;h=f>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=(g&f)>>>8;g=f&65535;c[240592]=g|c[240592];h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[h&511](d&16777215,g);return}}function aqV(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=-(((c[240590]|0)>>>8&1)+(g&65535)|0)|0;h=d>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=(g&d)>>>8;g=d&65535;c[240592]=g|c[240592];h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[h&511](f&16777215,g);return}}function aqW(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=-(((c[240590]|0)>>>8&1)+(h&65535)|0)|0;f=a>>>8;c[240591]=f;c[240594]=f;c[240590]=f;c[240593]=(h&a)>>>8;h=a&65535;c[240592]=h|c[240592];f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[f&511](d&16777215,h);return}}function aqX(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=-(((c[240590]|0)>>>8&1)+(g&65535)|0)|0;h=f>>>8;c[240591]=h;c[240594]=h;c[240590]=h;c[240593]=(g&f)>>>8;g=f&65535;c[240592]=g|c[240592];h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[h&511](d&16777215,g);return}}function aqY(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=-(((c[240590]|0)>>>8&1)+(h&65535)|0)|0;i=d>>>8;c[240591]=i;c[240594]=i;c[240590]=i;c[240593]=(h&d)>>>8;h=d&65535;c[240592]=h|c[240592];i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=d&65535;return}else{fj[i&511](f&16777215,h);return}}function aqZ(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{h=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|h}h=-(((c[240590]|0)>>>8&1)+i|0)|0;c[240591]=h>>>24;f=(i|h)>>>23;c[240594]=f;c[240590]=f;c[240593]=(i&h)>>>24;c[240592]=c[240592]|h;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=h>>>16&65535}else{fj[i&511](a&16777215,h>>>16)}i=a+2|0;a=i>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[d&511](i&16777215,h&65535);return}}function aq_(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{h=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|h}h=-(((c[240590]|0)>>>8&1)+i|0)|0;c[240591]=h>>>24;f=(i|h)>>>23;c[240594]=f;c[240590]=f;c[240593]=(i&h)>>>24;c[240592]=c[240592]|h;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h>>>16&65535}else{fj[i&511](d&16777215,h>>>16)}i=d+2|0;d=i>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[a&511](i&16777215,h&65535);return}}function aq$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{i=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|i}i=-(((c[240590]|0)>>>8&1)+j|0)|0;c[240591]=i>>>24;g=(j|i)>>>23;c[240594]=g;c[240590]=g;c[240593]=(j&i)>>>24;c[240592]=c[240592]|i;j=c[957136+(a*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[j&511](f&16777215,i>>>16)}f=d-2|0;d=f>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[j&511](f&16777215,i&65535);return}}function aq0(){var a=0;a=962260+((c[240587]&7)<<2)|0;c[a>>2]=c[a>>2]&-65536|c[240588]|c[240589]<<11|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;return}function aq1(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=957128+(a*20|0)|0;g=c[d>>2]|0;if((g|0)==0){h=f+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]<<16}else{h=(fl[g&255](f&16777215)|0)<<16;i=fl[c[d>>2]&255](f+2&16777215)|0|h}h=-(((c[240590]|0)>>>8&1)+i|0)|0;c[240591]=h>>>24;d=(i|h)>>>23;c[240594]=d;c[240590]=d;c[240593]=(i&h)>>>24;c[240592]=c[240592]|h;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=h>>>16&65535}else{fj[i&511](f&16777215,h>>>16)}i=f+2|0;f=i>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[a&511](i&16777215,h&65535);return}}function aq2(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=957128+(g*20|0)|0;f=c[a>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{h=(fl[f&255](d&16777215)|0)<<16;i=fl[c[a>>2]&255](d+2&16777215)|0|h}h=-(((c[240590]|0)>>>8&1)+i|0)|0;c[240591]=h>>>24;a=(i|h)>>>23;c[240594]=a;c[240590]=a;c[240593]=(i&h)>>>24;c[240592]=c[240592]|h;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=h>>>16&65535}else{fj[i&511](d&16777215,h>>>16)}i=d+2|0;d=i>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[g&511](i&16777215,h&65535);return}}function aq3(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{h=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|h}h=-(((c[240590]|0)>>>8&1)+i|0)|0;c[240591]=h>>>24;f=(i|h)>>>23;c[240594]=f;c[240590]=f;c[240593]=(i&h)>>>24;c[240592]=c[240592]|h;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h>>>16&65535}else{fj[i&511](d&16777215,h>>>16)}i=d+2|0;d=i>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[a&511](i&16777215,h&65535);return}}function aq4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=957128+(g*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0)<<16}else{i=(fl[h&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|i}i=-(((c[240590]|0)>>>8&1)+j|0)|0;c[240591]=i>>>24;d=(j|i)>>>23;c[240594]=d;c[240590]=d;c[240593]=(j&i)>>>24;c[240592]=c[240592]|i;j=c[957136+(g*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=i>>>16&65535}else{fj[j&511](f&16777215,i>>>16)}j=f+2|0;f=j>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(j&65535)>>1]=i&65535;return}else{fj[a&511](j&16777215,i&65535);return}}function aq5(){var a=0,d=0,e=0,f=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240588]|c[240589]<<11|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;e=a>>>16&255;f=c[957136+(e*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}else{fj[f&511](a&16777215,d);return}}function aq6(){var a=0,d=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=c[240588]|c[240589]<<11|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;e=d>>>16&255;f=c[957136+(e*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[f&511](d&16777215,a);return}}function aq7(){var a=0,d=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=c[240588]|c[240589]<<11|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;e=d>>>16&255;f=c[957136+(e*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[f&511](d&16777215,a);return}}function aq8(){var a=0,d=0,e=0,f=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=c[240588]|c[240589]<<11|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;d=e>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(e&65535)>>1]=a&65535;return}else{fj[f&511](e&16777215,a);return}}function aq9(){var a=0,d=0,f=0,g=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=c[240588]|c[240589]<<11|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;a=d>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;return}else{fj[f&511](d&16777215,g);return}}function ara(){var a=0,d=0,e=0,f=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[240588]|c[240589]<<11|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;e=d>>>16&255;f=c[957136+(e*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[f&511](d&16777215,a);return}}function arb(){var a=0;a=c[240587]|0;c[962260+((a>>>9&7|8)<<2)>>2]=c[962260+((a&7|8)<<2)>>2];return}function arc(){var a=0,d=0,e=0;a=c[240587]|0;d=c[962260+((a&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;c[962260+((a>>>9&7|8)<<2)>>2]=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d;return}function ard(){var a=0,b=0,d=0,f=0,g=0;a=c[240587]|0;b=c[962260+((a&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}c[962260+((a>>>9&7|8)<<2)>>2]=(f<<24>>24)+b+g;return}function are(){var a=0;a=c[240581]|0;c[240581]=a+2;c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;return}function arf(){var a=0,b=0;a=c[240581]|0;c[240581]=a+4;b=a+2|0;c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;return}function arg(){var a=0;a=c[240581]|0;c[240581]=a+2;c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a;return}function arh(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}c[962260+(((c[240587]|0)>>>9&7|8)<<2)>>2]=(b<<24>>24)+a+f;return}function ari(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[240588]|c[240589]<<11|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;g=d&255;h=c[957136+(g*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=f&65535;return}else{fj[h&511](a|d<<16&16711680,f);return}}function arj(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=c[962260+((a>>>9&7)<<2)>>2]|0;d=b<<16;e=d>>16;f=c[962260+((a&7)<<2)>>2]|0;c[240592]=e&65535;c[240593]=0;c[240594]=0;do{if((d|0)>-65536){if((e|0)>(f<<16>>16|0)){break}return}}while(0);c[240591]=b>>>15<<7&128;aH3(6);return}function ark(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=c[962260+((a>>>9&7)<<2)>>2]|0;d=b<<16;f=d>>16;g=c[962260+((a&7|8)<<2)>>2]|0;a=g>>>16&255;h=c[957128+(a*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]|0}else{i=fl[h&255](g&16777215)|0}c[240592]=f&65535;c[240593]=0;c[240594]=0;do{if((d|0)>-65536){if((f|0)>(i<<16>>16|0)){break}return}}while(0);c[240591]=b>>>15<<7&128;aH3(6);return}function arl(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=c[962260+((a>>>9&7)<<2)>>2]|0;d=b<<16;f=d>>16;g=962260+((a&7|8)<<2)|0;a=c[g>>2]|0;c[g>>2]=a+2;g=a>>>16&255;h=c[957128+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{i=fl[h&255](a&16777215)|0}c[240592]=f&65535;c[240593]=0;c[240594]=0;do{if((d|0)>-65536){if((f|0)>(i<<16>>16|0)){break}return}}while(0);c[240591]=b>>>15<<7&128;aH3(6);return}function arm(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=c[962260+((a>>>9&7)<<2)>>2]|0;d=b<<16;f=d>>16;g=962260+((a&7|8)<<2)|0;a=(c[g>>2]|0)-2|0;c[g>>2]=a;g=a>>>16&255;h=c[957128+(g*20|0)>>2]|0;if((h|0)==0){i=e[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]|0}else{i=fl[h&255](a&16777215)|0}c[240592]=f&65535;c[240593]=0;c[240594]=0;do{if((d|0)>-65536){if((f|0)>(i<<16>>16|0)){break}return}}while(0);c[240591]=b>>>15<<7&128;aH3(6);return}function arn(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;f=d<<16;g=f>>16;h=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;i=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+h|0;h=i>>>16&255;a=c[957128+(h*20|0)>>2]|0;if((a|0)==0){j=e[(c[957120+(h*20|0)>>2]|0)+(i&65535)>>1]|0}else{j=fl[a&255](i&16777215)|0}c[240592]=g&65535;c[240593]=0;c[240594]=0;do{if((f|0)>-65536){if((g|0)>(j<<16>>16|0)){break}return}}while(0);c[240591]=d>>>15<<7&128;aH3(6);return}function aro(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=c[962260+((a>>>9&7)<<2)>>2]|0;d=b<<16;f=d>>16;g=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;h=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=a<<16>>16}else{i=a}a=(h<<24>>24)+g+i|0;i=a>>>16&255;g=c[957128+(i*20|0)>>2]|0;if((g|0)==0){j=e[(c[957120+(i*20|0)>>2]|0)+(a&65535)>>1]|0}else{j=fl[g&255](a&16777215)|0}c[240592]=f&65535;c[240593]=0;c[240594]=0;do{if((d|0)>-65536){if((f|0)>(j<<16>>16|0)){break}return}}while(0);c[240591]=b>>>15<<7&128;aH3(6);return}function arp(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;d=a<<16;f=d>>16;g=c[240581]|0;c[240581]=g+2;h=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=h>>>16&255;i=c[957128+(g*20|0)>>2]|0;if((i|0)==0){j=e[(c[957120+(g*20|0)>>2]|0)+(h&65535)>>1]|0}else{j=fl[i&255](h&16777215)|0}c[240592]=f&65535;c[240593]=0;c[240594]=0;do{if((d|0)>-65536){if((f|0)>(j<<16>>16|0)){break}return}}while(0);c[240591]=a>>>15<<7&128;aH3(6);return}function arq(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;b=a<<16;d=b>>16;f=c[240581]|0;c[240581]=f+4;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=g&255;i=c[957128+(h*20|0)>>2]|0;if((i|0)==0){j=e[(c[957120+(h*20|0)>>2]|0)+f>>1]|0}else{j=fl[i&255](f|g<<16&16711680)|0}c[240592]=d&65535;c[240593]=0;c[240594]=0;do{if((b|0)>-65536){if((d|0)>(j<<16>>16|0)){break}return}}while(0);c[240591]=a>>>15<<7&128;aH3(6);return}function arr(){var a=0,d=0,e=0,f=0,g=0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;d=a<<16;e=d>>16;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+f|0;f=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;c[240592]=e&65535;c[240593]=0;c[240594]=0;do{if((d|0)>-65536){if((e|0)>(f<<16>>16|0)){break}return}}while(0);c[240591]=a>>>15<<7&128;aH3(6);return}function ars(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;d=a<<16;f=d>>16;g=c[240581]|0;c[240581]=g+2;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;i=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){j=i<<16>>16}else{j=i}i=(h<<24>>24)+g+j|0;j=b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;c[240592]=f&65535;c[240593]=0;c[240594]=0;do{if((d|0)>-65536){if((f|0)>(j<<16>>16|0)){break}return}}while(0);c[240591]=a>>>15<<7&128;aH3(6);return}function art(){var a=0,d=0,e=0,f=0,g=0;a=c[962260+(((c[240587]|0)>>>9&7)<<2)>>2]|0;d=a<<16;e=d>>16;f=c[240581]|0;c[240581]=f+2;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240592]=e&65535;c[240593]=0;c[240594]=0;do{if((d|0)>-65536){if((e|0)>(g<<16>>16|0)){break}return}}while(0);c[240591]=a>>>15<<7&128;aH3(6);return}function aru(){var a=0;a=962260+((c[240587]&7)<<2)|0;c[a>>2]=c[a>>2]&-256;aIv(962364,0,16);return}function arv(){var b=0,d=0,e=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=b>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;aIv(962364,0,16);return}else{fj[e&511](b&16777215,0);aIv(962364,0,16);return}}function arw(){var b=0,d=0,e=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=d>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=0;aIv(962364,0,16);return}else{fj[e&511](d&16777215,0);aIv(962364,0,16);return}}function arx(){var b=0,d=0,e=0;b=c[240580]|0;c[240580]=b+2;d=b>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;aIv(962364,0,16);return}else{fj[e&511](b&16777215,0);aIv(962364,0,16);return}}function ary(){var b=0,d=0,e=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=d>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=0;aIv(962364,0,16);return}else{fj[e&511](d&16777215,0);aIv(962364,0,16);return}}function arz(){var b=0,d=0,e=0;b=(c[240580]|0)-2|0;c[240580]=b;d=b>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;aIv(962364,0,16);return}else{fj[e&511](b&16777215,0);aIv(962364,0,16);return}}function arA(){var d=0,e=0,f=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=f>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(f&65535^1)|0]=0;aIv(962364,0,16);return}else{fj[e&511](f&16777215,0);aIv(962364,0,16);return}}function arB(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[957132+(g*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(d&65535^1)|0]=0;aIv(962364,0,16);return}else{fj[b&511](d&16777215,0);aIv(962364,0,16);return}}function arC(){var d=0,e=0,f=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e>>>16&255;f=c[957132+(d*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(e&65535^1)|0]=0;aIv(962364,0,16);return}else{fj[f&511](e&16777215,0);aIv(962364,0,16);return}}function arD(){var b=0,d=0,f=0,g=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b^1)|0]=0;aIv(962364,0,16);return}else{fj[g&511](b|d<<16&16711680,0);aIv(962364,0,16);return}}function arE(){var a=0;a=962260+((c[240587]&7)<<2)|0;c[a>>2]=c[a>>2]&-65536;aIv(962364,0,16);return}function arF(){var a=0,d=0,e=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;e=c[957136+(d*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=0;aIv(962364,0,16);return}else{fj[e&511](a&16777215,0);aIv(962364,0,16);return}}function arG(){var a=0,d=0,e=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;e=c[957136+(a*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(962364,0,16);return}else{fj[e&511](d&16777215,0);aIv(962364,0,16);return}}function arH(){var a=0,d=0,e=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;e=c[957136+(a*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(962364,0,16);return}else{fj[e&511](d&16777215,0);aIv(962364,0,16);return}}function arI(){var a=0,d=0,e=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=e>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(e&65535)>>1]=0;aIv(962364,0,16);return}else{fj[d&511](e&16777215,0);aIv(962364,0,16);return}}function arJ(){var a=0,d=0,f=0,g=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(962364,0,16);return}else{fj[a&511](d&16777215,0);aIv(962364,0,16);return}}function arK(){var a=0,d=0,e=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;e=c[957136+(a*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(962364,0,16);return}else{fj[e&511](d&16777215,0);aIv(962364,0,16);return}}function arL(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+a>>1]=0;aIv(962364,0,16);return}else{fj[g&511](a|d<<16&16711680,0);aIv(962364,0,16);return}}function arM(){c[962260+((c[240587]&7)<<2)>>2]=0;aIv(962364,0,16);return}function arN(){var a=0,d=0,e=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;e=c[957136+(d*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=0}else{fj[e&511](a&16777215,0)}e=a+2|0;a=e>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(e&65535)>>1]=0;aIv(962364,0,16);return}else{fj[d&511](e&16777215,0);aIv(962364,0,16);return}}function arO(){var a=0,d=0,e=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;e=c[957136+(a*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=0}else{fj[e&511](d&16777215,0)}e=d+2|0;d=e>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(e&65535)>>1]=0;aIv(962364,0,16);return}else{fj[a&511](e&16777215,0);aIv(962364,0,16);return}}function arP(){var a=0,d=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;e=d-4|0;c[a>>2]=e;a=e>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(e&65535)>>1]=0}else{fj[f&511](e&16777215,0)}e=d-2|0;d=e>>>16&255;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(e&65535)>>1]=0;aIv(962364,0,16);return}else{fj[f&511](e&16777215,0);aIv(962364,0,16);return}}function arQ(){var a=0,d=0,e=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=e>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(e&65535)>>1]=0}else{fj[d&511](e&16777215,0)}d=e+2|0;e=d>>>16&255;a=c[957136+(e*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(e*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(962364,0,16);return}else{fj[a&511](d&16777215,0);aIv(962364,0,16);return}}function arR(){var a=0,d=0,f=0,g=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=0}else{fj[a&511](d&16777215,0)}a=d+2|0;d=a>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=0;aIv(962364,0,16);return}else{fj[g&511](a&16777215,0);aIv(962364,0,16);return}}function arS(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=-(c[a>>2]&255)|0;c[240591]=b;c[240590]=b;c[240594]=b;c[240593]=c[a>>2]&b;d=b&255;c[240592]=d;c[a>>2]=c[a>>2]&-256|d;return}function arT(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=-(c[a>>2]&65535)|0;d=b>>>8;c[240591]=d;c[240590]=d;c[240594]=d;c[240593]=(c[a>>2]&b)>>>8;d=b&65535;c[240592]=d;c[a>>2]=c[a>>2]&-65536|d;return}function arU(){var a=0,d=0,e=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;e=c[957136+(a*20|0)>>2]|0;if((e|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=0}else{fj[e&511](d&16777215,0)}e=d+2|0;d=e>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(e&65535)>>1]=0;aIv(962364,0,16);return}else{fj[a&511](e&16777215,0);aIv(962364,0,16);return}}function arV(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=0}else{fj[d&511](f&16777215,0)}d=f+2|0;f=d>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=0;aIv(962364,0,16);return}else{fj[a&511](d&16777215,0);aIv(962364,0,16);return}}function arW(){var b=0,e=0,f=0,g=0,h=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-g|0;c[240591]=f;c[240590]=f;c[240594]=f;c[240593]=g&f;g=f&255;c[240592]=g;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function arX(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=-g|0;c[240591]=f;c[240590]=f;c[240594]=f;c[240593]=g&f;g=f&255;c[240592]=g;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[h&511](e&16777215,g);return}}function arY(){var b=0,e=0,f=0,g=0,h=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-g|0;c[240591]=f;c[240590]=f;c[240594]=f;c[240593]=g&f;g=f&255;c[240592]=g;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function arZ(){var b=0,e=0,f=0,g=0,h=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=-g|0;c[240591]=f;c[240590]=f;c[240594]=f;c[240593]=g&f;g=f&255;c[240592]=g;h=c[957132+(b*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[h&511](e&16777215,g);return}}function ar_(){var b=0,e=0,f=0,g=0,h=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=-g|0;c[240591]=f;c[240590]=f;c[240594]=f;c[240593]=g&f;g=f&255;c[240592]=g;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[h&511](b&16777215,g);return}}function ar$(){var e=0,f=0,g=0,h=0,i=0;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}f=-h|0;c[240591]=f;c[240590]=f;c[240594]=f;c[240593]=h&f;h=f&255;c[240592]=h;i=c[957132+(e*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=f&255;return}else{fj[i&511](g&16777215,h);return}}function ar0(){var b=0,f=0,g=0,h=0,i=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}b=-i|0;c[240591]=b;c[240590]=b;c[240594]=b;c[240593]=i&b;i=b&255;c[240592]=i;g=c[957132+(h*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[g&511](f&16777215,i);return}}function ar1(){var e=0,f=0,g=0,h=0,i=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=-h|0;c[240591]=g;c[240590]=g;c[240594]=g;c[240593]=h&g;h=g&255;c[240592]=h;i=c[957132+(e*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[i&511](f&16777215,h);return}}function ar2(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=-i|0;c[240591]=f;c[240590]=f;c[240594]=f;c[240593]=i&f;i=f&255;c[240592]=i;j=c[957132+(h*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[j&511](g&16777215,i);return}}function ar3(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=-g|0;h=f>>>8;c[240591]=h;c[240590]=h;c[240594]=h;c[240593]=(g&f)>>>8;g=f&65535;c[240592]=g;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f&65535;return}else{fj[h&511](a&16777215,g);return}}function ar4(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=-g|0;h=f>>>8;c[240591]=h;c[240590]=h;c[240594]=h;c[240593]=(g&f)>>>8;g=f&65535;c[240592]=g;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[h&511](d&16777215,g);return}}function ar5(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=-g|0;h=f>>>8;c[240591]=h;c[240590]=h;c[240594]=h;c[240593]=(g&f)>>>8;g=f&65535;c[240592]=g;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[h&511](d&16777215,g);return}}function ar6(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=-(c[a>>2]|0)|0;c[240591]=b>>>24;d=(c[a>>2]|b)>>>23;c[240590]=d;c[240594]=d;c[240593]=(c[a>>2]&b)>>>24;c[240592]=b;c[a>>2]=b;return}function ar7(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=-g|0;h=d>>>8;c[240591]=h;c[240590]=h;c[240594]=h;c[240593]=(g&d)>>>8;g=d&65535;c[240592]=g;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;return}else{fj[h&511](f&16777215,g);return}}function ar8(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=-h|0;f=a>>>8;c[240591]=f;c[240590]=f;c[240594]=f;c[240593]=(h&a)>>>8;h=a&65535;c[240592]=h;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}else{fj[f&511](d&16777215,h);return}}function ar9(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=-g|0;h=f>>>8;c[240591]=h;c[240590]=h;c[240594]=h;c[240593]=(g&f)>>>8;g=f&65535;c[240592]=g;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;return}else{fj[h&511](d&16777215,g);return}}function asa(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=-h|0;i=d>>>8;c[240591]=i;c[240590]=i;c[240594]=i;c[240593]=(h&d)>>>8;h=d&65535;c[240592]=h;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=d&65535;return}else{fj[i&511](f&16777215,h);return}}function asb(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{h=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|h}h=-i|0;c[240591]=h>>>24;f=(i|h)>>>23;c[240590]=f;c[240594]=f;c[240593]=(i&h)>>>24;c[240592]=h;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=h>>>16&65535}else{fj[i&511](a&16777215,h>>>16)}i=a+2|0;a=i>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[d&511](i&16777215,h&65535);return}}function asc(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{h=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|h}h=-i|0;c[240591]=h>>>24;f=(i|h)>>>23;c[240590]=f;c[240594]=f;c[240593]=(i&h)>>>24;c[240592]=h;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h>>>16&65535}else{fj[i&511](d&16777215,h>>>16)}i=d+2|0;d=i>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[a&511](i&16777215,h&65535);return}}function asd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{i=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|i}i=-j|0;c[240591]=i>>>24;g=(j|i)>>>23;c[240590]=g;c[240594]=g;c[240593]=(j&i)>>>24;c[240592]=i;j=c[957136+(a*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[j&511](f&16777215,i>>>16)}f=d-2|0;d=f>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[j&511](f&16777215,i&65535);return}}function ase(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=957128+(a*20|0)|0;g=c[d>>2]|0;if((g|0)==0){h=f+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]<<16}else{h=(fl[g&255](f&16777215)|0)<<16;i=fl[c[d>>2]&255](f+2&16777215)|0|h}h=-i|0;c[240591]=h>>>24;d=(i|h)>>>23;c[240590]=d;c[240594]=d;c[240593]=(i&h)>>>24;c[240592]=h;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=h>>>16&65535}else{fj[i&511](f&16777215,h>>>16)}i=f+2|0;f=i>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[a&511](i&16777215,h&65535);return}}function asf(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=957128+(g*20|0)|0;f=c[a>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{h=(fl[f&255](d&16777215)|0)<<16;i=fl[c[a>>2]&255](d+2&16777215)|0|h}h=-i|0;c[240591]=h>>>24;a=(i|h)>>>23;c[240590]=a;c[240594]=a;c[240593]=(i&h)>>>24;c[240592]=h;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=h>>>16&65535}else{fj[i&511](d&16777215,h>>>16)}i=d+2|0;d=i>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[g&511](i&16777215,h&65535);return}}function asg(){var a=0,b=0;a=c[962260+((c[240587]&7)<<2)>>2]|0;b=a<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=a>>>2&1^1;c[240593]=a<<6&128;c[240594]=a<<8&256;return}function ash(){var a=0,d=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a<<4;c[240590]=d&256;c[240591]=d&128;c[240592]=a>>>2&1^1;c[240593]=a<<6&128;c[240594]=a<<8&256;return}function asi(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}d=(b<<24>>24)+a+f|0;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f<<4;c[240590]=d&256;c[240591]=d&128;c[240592]=f>>>2&1^1;c[240593]=f<<6&128;c[240594]=f<<8&256;return}function asj(){var a=0,b=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=b<<4;c[240590]=a&256;c[240591]=a&128;c[240592]=b>>>2&1^1;c[240593]=b<<6&128;c[240594]=b<<8&256;return}function ask(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;d=b&255^255;c[a>>2]=d|b&-256;c[240591]=d;c[240592]=d;c[240594]=0;c[240593]=0;return}function asl(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{h=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|h}h=-i|0;c[240591]=h>>>24;f=(i|h)>>>23;c[240590]=f;c[240594]=f;c[240593]=(i&h)>>>24;c[240592]=h;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h>>>16&65535}else{fj[i&511](d&16777215,h>>>16)}i=d+2|0;d=i>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(i&65535)>>1]=h&65535;return}else{fj[a&511](i&16777215,h&65535);return}}function asm(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=957128+(g*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0)<<16}else{i=(fl[h&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|i}i=-j|0;c[240591]=i>>>24;d=(j|i)>>>23;c[240590]=d;c[240594]=d;c[240593]=(j&i)>>>24;c[240592]=i;j=c[957136+(g*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=i>>>16&65535}else{fj[j&511](f&16777215,i>>>16)}j=f+2|0;f=j>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(j&65535)>>1]=i&65535;return}else{fj[a&511](j&16777215,i&65535);return}}function asn(){var a=0,b=0,d=0,f=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;b=a>>>16&255;d=c[957128+(b*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(b*20|0)>>2]|0)+(a&65535)>>1]|0}else{f=fl[d&255](a&16777215)|0}a=f<<4;c[240590]=a&256;c[240591]=a&128;c[240592]=f>>>2&1^1;c[240593]=f<<6&128;c[240594]=f<<8&256;return}function aso(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=f<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=f>>>2&1^1;c[240593]=f<<6&128;c[240594]=f<<8&256;return}function asp(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}b=f<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=f>>>2&1^1;c[240593]=f<<6&128;c[240594]=f<<8&256;return}function asq(){var a=0,d=0,f=0,g=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}f=g<<4;c[240590]=f&256;c[240591]=f&128;c[240592]=g>>>2&1^1;c[240593]=g<<6&128;c[240594]=g<<8&256;return}function asr(){var a=0,b=0,d=0,f=0,g=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){f=b<<16>>16}else{f=b}b=(d<<24>>24)+a+f|0;f=b>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){g=e[(c[957120+(f*20|0)>>2]|0)+(b&65535)>>1]|0}else{g=fl[a&255](b&16777215)|0}b=g<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=g>>>2&1^1;c[240593]=g<<6&128;c[240594]=g<<8&256;return}function ass(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}d=g<<4;c[240590]=d&256;c[240591]=d&128;c[240592]=g>>>2&1^1;c[240593]=g<<6&128;c[240594]=g<<8&256;return}function ast(){var a=0,b=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=b&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+a>>1]|0}else{g=fl[f&255](a|b<<16&16711680)|0}b=g<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=g>>>2&1^1;c[240593]=g<<6&128;c[240594]=g<<8&256;return}function asu(){var b=0,e=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=g&255^255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[g&511](b&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asv(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=g&255^255;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[g&511](e&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asw(){var b=0,e=0,f=0,g=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=g&255^255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[g&511](b&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asx(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;d=b&65535^65535;c[a>>2]=d|b&-65536;c[240591]=d>>>8;c[240592]=d;c[240594]=0;c[240593]=0;return}function asy(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=~c[a>>2];c[a>>2]=b;c[240591]=b>>>24;c[240592]=b;c[240594]=0;c[240593]=0;return}function asz(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=g&255^255;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[g&511](e&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asA(){var b=0,e=0,f=0,g=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=g&255^255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[g&511](b&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asB(){var e=0,f=0,g=0,h=0;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}f=h&255^255;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=f&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[h&511](g&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asC(){var b=0,f=0,g=0,h=0,i=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}b=i&255^255;i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]=b&255;c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}else{fj[i&511](f&16777215,b);c[240591]=b;c[240592]=b;c[240594]=0;c[240593]=0;return}}function asD(){var e=0,f=0,g=0,h=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=h&255^255;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;c[240591]=g;c[240592]=g;c[240594]=0;c[240593]=0;return}else{fj[h&511](f&16777215,g);c[240591]=g;c[240592]=g;c[240594]=0;c[240593]=0;return}}function asE(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=i&255^255;i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]=f&255;c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[i&511](g&16777215,f);c[240591]=f;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asF(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=g&65535^65535;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f&65535;h=f>>>8;c[240591]=h;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[g&511](a&16777215,f);h=f>>>8;c[240591]=h;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asG(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g&65535^65535;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;h=f>>>8;c[240591]=h;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[g&511](d&16777215,f);h=f>>>8;c[240591]=h;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asH(){var a=0,d=0,f=0,g=0,h=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g&65535^65535;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;h=f>>>8;c[240591]=h;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[g&511](d&16777215,f);h=f>>>8;c[240591]=h;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asI(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=g&65535^65535;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;h=d>>>8;c[240591]=h;c[240592]=d;c[240594]=0;c[240593]=0;return}else{fj[g&511](f&16777215,d);h=d>>>8;c[240591]=h;c[240592]=d;c[240594]=0;c[240593]=0;return}}function asJ(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=h&65535^65535;h=c[957136+(g*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=a&65535;i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}else{fj[h&511](d&16777215,a);i=a>>>8;c[240591]=i;c[240592]=a;c[240594]=0;c[240593]=0;return}}function asK(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g&65535^65535;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;h=f>>>8;c[240591]=h;c[240592]=f;c[240594]=0;c[240593]=0;return}else{fj[g&511](d&16777215,f);h=f>>>8;c[240591]=h;c[240592]=f;c[240594]=0;c[240593]=0;return}}function asL(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=h&65535^65535;h=c[957136+(g*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=d&65535;i=d>>>8;c[240591]=i;c[240592]=d;c[240594]=0;c[240593]=0;return}else{fj[h&511](f&16777215,d);i=d>>>8;c[240591]=i;c[240592]=d;c[240594]=0;c[240593]=0;return}}function asM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=957128+(d*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=a+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{h=(fl[g&255](a&16777215)|0)<<16;i=fl[c[f>>2]&255](a+2&16777215)|0|h}h=~i;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=h>>>16&65535}else{fj[i&511](a&16777215,h>>>16)}i=a+2|0;a=i>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(i&65535)>>1]=h&65535;j=h>>>24;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[d&511](i&16777215,h&65535);j=h>>>24;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}}function asN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+4;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{h=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|h}h=~i;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h>>>16&65535}else{fj[i&511](d&16777215,h>>>16)}i=d+2|0;d=i>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(i&65535)>>1]=h&65535;j=h>>>24;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[a&511](i&16777215,h&65535);j=h>>>24;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}}function asO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;f=d-4|0;c[a>>2]=f;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=d-2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{i=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](d+16777214&16777215)|0|i}i=~j;j=c[957136+(a*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[j&511](f&16777215,i>>>16)}f=d-2|0;d=f>>>16&255;j=c[957136+(d*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[j&511](f&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function asP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=957128+(a*20|0)|0;g=c[d>>2]|0;if((g|0)==0){h=f+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]<<16}else{h=(fl[g&255](f&16777215)|0)<<16;i=fl[c[d>>2]&255](f+2&16777215)|0|h}h=~i;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=h>>>16&65535}else{fj[i&511](f&16777215,h>>>16)}i=f+2|0;f=i>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(i&65535)>>1]=h&65535;j=h>>>24;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[a&511](i&16777215,h&65535);j=h>>>24;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}}function asQ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=957128+(g*20|0)|0;f=c[a>>2]|0;if((f|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{h=(fl[f&255](d&16777215)|0)<<16;i=fl[c[a>>2]&255](d+2&16777215)|0|h}h=~i;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=h>>>16&65535}else{fj[i&511](d&16777215,h>>>16)}i=d+2|0;d=i>>>16&255;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(i&65535)>>1]=h&65535;j=h>>>24;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[g&511](i&16777215,h&65535);j=h>>>24;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}}function asR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16}else{h=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|h}h=~i;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h>>>16&65535}else{fj[i&511](d&16777215,h>>>16)}i=d+2|0;d=i>>>16&255;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(i&65535)>>1]=h&65535;j=h>>>24;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}else{fj[a&511](i&16777215,h&65535);j=h>>>24;c[240591]=j;c[240592]=h;c[240594]=0;c[240593]=0;return}}function asS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=957128+(g*20|0)|0;h=c[d>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0)<<16}else{i=(fl[h&255](f&16777215)|0)<<16;j=fl[c[d>>2]&255](f+2&16777215)|0|i}i=~j;j=c[957136+(g*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=i>>>16&65535}else{fj[j&511](f&16777215,i>>>16)}j=f+2|0;f=j>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(j&65535)>>1]=i&65535;k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}else{fj[a&511](j&16777215,i&65535);k=i>>>24;c[240591]=k;c[240592]=i;c[240594]=0;c[240593]=0;return}}function asT(){var a=0,b=0,d=0;a=c[240589]|0;if((a|0)==0){aH4();return}else{b=c[962260+((c[240587]&7)<<2)>>2]|0;c[240588]=b&32768;c[240595]=b&1792;d=b<<4;c[240590]=d&256;c[240591]=d&128;c[240592]=b>>>2&1^1;c[240593]=b<<6&128;c[240594]=b<<8&256;d=b>>>11&4;c[962328+(a<<2)>>2]=c[240580];c[240589]=d;c[240580]=c[962328+(d<<2)>>2];ahk();return}}function asU(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240589]|0;if((a|0)==0){aH4();return}b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=b>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(b&65535)>>1]|0;h=a}else{a=fl[f&255](b&16777215)|0;g=a;h=c[240589]|0}c[240588]=g&32768;c[240595]=g&1792;a=g<<4;c[240590]=a&256;c[240591]=a&128;c[240592]=g>>>2&1^1;c[240593]=g<<6&128;c[240594]=g<<8&256;a=g>>>11&4;c[962328+(h<<2)>>2]=c[240580];c[240589]=a;c[240580]=c[962328+(a<<2)>>2];ahk();return}function asV(){var a=0,b=0,d=0,f=0;if((c[240589]|0)==0){aH4();return}a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}c[240588]=f&32768;c[240595]=f&1792;b=f<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=f>>>2&1^1;c[240593]=f<<6&128;c[240594]=f<<8&256;b=f>>>11&4;c[962328+(c[240589]<<2)>>2]=c[240580];c[240589]=b;c[240580]=c[962328+(b<<2)>>2];ahk();return}function asW(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=962260+((c[240587]&7)<<2)|0;b=154-(c[a>>2]|0)-((c[240590]|0)>>>8&1)|0;d=b&255;if((d|0)==154){c[240593]=0;e=154;f=0;c[240594]=f;c[240590]=f;c[240591]=e;return}g=(b|-256)^255;c[240593]=g;if((b&15|0)==10){h=(b&240)+16|0}else{h=d}d=h&255;c[240593]=d&g;c[a>>2]=c[a>>2]&-256|d;c[240592]=c[240592]|d;e=d;f=256;c[240594]=f;c[240590]=f;c[240591]=e;return}function asX(){var a=0,b=0,d=0,f=0;if((c[240589]|0)==0){aH4();return}a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}c[240588]=f&32768;c[240595]=f&1792;b=f<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=f>>>2&1^1;c[240593]=f<<6&128;c[240594]=f<<8&256;b=f>>>11&4;c[962328+(c[240589]<<2)>>2]=c[240580];c[240589]=b;c[240580]=c[962328+(b<<2)>>2];ahk();return}function asY(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240589]|0;if((a|0)==0){aH4();return}d=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+d|0;d=g>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(g&65535)>>1]|0;i=a}else{a=fl[f&255](g&16777215)|0;h=a;i=c[240589]|0}c[240588]=h&32768;c[240595]=h&1792;a=h<<4;c[240590]=a&256;c[240591]=a&128;c[240592]=h>>>2&1^1;c[240593]=h<<6&128;c[240594]=h<<8&256;a=h>>>11&4;c[962328+(i<<2)>>2]=c[240580];c[240589]=a;c[240580]=c[962328+(a<<2)>>2];ahk();return}function asZ(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240589]|0;if((a|0)==0){aH4();return}b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[957128+(g*20|0)>>2]|0;if((b|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0;i=a}else{a=fl[b&255](d&16777215)|0;h=a;i=c[240589]|0}c[240588]=h&32768;c[240595]=h&1792;a=h<<4;c[240590]=a&256;c[240591]=a&128;c[240592]=h>>>2&1^1;c[240593]=h<<6&128;c[240594]=h<<8&256;a=h>>>11&4;c[962328+(i<<2)>>2]=c[240580];c[240589]=a;c[240580]=c[962328+(a<<2)>>2];ahk();return}function as_(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240589]|0;if((a|0)==0){aH4();return}d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0;i=a}else{a=fl[g&255](f&16777215)|0;h=a;i=c[240589]|0}c[240588]=h&32768;c[240595]=h&1792;a=h<<4;c[240590]=a&256;c[240591]=a&128;c[240592]=h>>>2&1^1;c[240593]=h<<6&128;c[240594]=h<<8&256;a=h>>>11&4;c[962328+(i<<2)>>2]=c[240580];c[240589]=a;c[240580]=c[962328+(a<<2)>>2];ahk();return}function as$(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240589]|0;if((a|0)==0){aH4();return}b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+b>>1]|0;i=a}else{a=fl[g&255](b|d<<16&16711680)|0;h=a;i=c[240589]|0}c[240588]=h&32768;c[240595]=h&1792;a=h<<4;c[240590]=a&256;c[240591]=a&128;c[240592]=h>>>2&1^1;c[240593]=h<<6&128;c[240594]=h<<8&256;a=h>>>11&4;c[962328+(i<<2)>>2]=c[240580];c[240589]=a;c[240580]=c[962328+(a<<2)>>2];ahk();return}function as0(){var a=0,d=0,f=0;a=c[240589]|0;if((a|0)==0){aH4();return}else{d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240588]=d&32768;c[240595]=d&1792;f=d<<4;c[240590]=f&256;c[240591]=f&128;c[240592]=d>>>2&1^1;c[240593]=d<<6&128;c[240594]=d<<8&256;f=d>>>11&4;c[962328+(a<<2)>>2]=c[240580];c[240589]=f;c[240580]=c[962328+(f<<2)>>2];ahk();return}}function as1(){var a=0,b=0,d=0,f=0,g=0;a=c[240589]|0;if((a|0)==0){aH4();return}b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+b+g|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;c[240588]=g&32768;c[240595]=g&1792;f=g<<4;c[240590]=f&256;c[240591]=f&128;c[240592]=g>>>2&1^1;c[240593]=g<<6&128;c[240594]=g<<8&256;f=g>>>11&4;c[962328+(a<<2)>>2]=c[240580];c[240589]=f;c[240580]=c[962328+(f<<2)>>2];ahk();return}function as2(){var a=0,b=0,d=0;a=c[240589]|0;if((a|0)==0){aH4();return}else{b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;c[240588]=d&32768;c[240595]=d&1792;b=d<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=d>>>2&1^1;c[240593]=d<<6&128;c[240594]=d<<8&256;b=d>>>11&4;c[962328+(a<<2)>>2]=c[240580];c[240589]=b;c[240580]=c[962328+(b<<2)>>2];ahk();return}}function as3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=154-g-((c[240590]|0)>>>8&1)|0;g=f&255;if((g|0)==154){c[240593]=0;h=154;i=0;c[240594]=i;c[240590]=i;c[240591]=h;return}j=(f|-256)^255;c[240593]=j;if((f&15|0)==10){k=(f&240)+16|0}else{k=g}g=k&255;c[240593]=g&j;j=c[957132+(e*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=k&255}else{fj[j&511](b&16777215,g)}c[240592]=c[240592]|g;h=g;i=256;c[240594]=i;c[240590]=i;c[240591]=h;return}function as4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=154-g-((c[240590]|0)>>>8&1)|0;g=f&255;if((g|0)==154){c[240593]=0;h=154;i=0;c[240594]=i;c[240590]=i;c[240591]=h;return}j=(f|-256)^255;c[240593]=j;if((f&15|0)==10){k=(f&240)+16|0}else{k=g}g=k&255;c[240593]=g&j;j=c[957132+(b*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=k&255}else{fj[j&511](e&16777215,g)}c[240592]=c[240592]|g;h=g;i=256;c[240594]=i;c[240590]=i;c[240591]=h;return}function as5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=154-g-((c[240590]|0)>>>8&1)|0;g=f&255;if((g|0)==154){c[240593]=0;h=154;i=0;c[240594]=i;c[240590]=i;c[240591]=h;return}j=(f|-256)^255;c[240593]=j;if((f&15|0)==10){k=(f&240)+16|0}else{k=g}g=k&255;c[240593]=g&j;j=c[957132+(e*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=k&255}else{fj[j&511](b&16777215,g)}c[240592]=c[240592]|g;h=g;i=256;c[240594]=i;c[240590]=i;c[240591]=h;return}function as6(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]<<16;c[240592]=b;d=(c[a>>2]|0)>>>16|b;c[a>>2]=d;c[240592]=d;c[240591]=(c[a>>2]|0)>>>24;c[240594]=0;c[240593]=0;return}function as7(){var a=0,d=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=(c[240580]|0)-4|0;c[240580]=d;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a>>>16&65535;d=(c[240580]|0)+2|0;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a&65535;return}function as8(){var a=0,d=0,e=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;e=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(c[240580]|0)-4|0;c[240580]=a;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=e>>>16&65535;a=(c[240580]|0)+2|0;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=e&65535;return}function as9(){var a=0,d=0,f=0,g=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=(c[240580]|0)-4|0;c[240580]=g;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[240580]|0)+2|0;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;return}function ata(){var a=0,d=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(c[240580]|0)-4|0;c[240580]=a;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d<<16>>16>>>16&65535;a=(c[240580]|0)+2|0;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d;return}function atb(){var a=0,d=0,e=0;a=c[240581]|0;c[240581]=a+4;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;e=a+2|0;a=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=(c[240580]|0)-4|0;c[240580]=e;b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]=d;d=(c[240580]|0)+2|0;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=a;return}function atc(){var a=0,d=0;a=c[240581]|0;c[240581]=a+2;d=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=(c[240580]|0)-4|0;c[240580]=a;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535;a=(c[240580]|0)+2|0;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d&65535;return}function atd(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){g=f<<16>>16}else{g=f}f=(d<<24>>24)+a+g|0;g=(c[240580]|0)-4|0;c[240580]=g;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=f>>>16&65535;g=(c[240580]|0)+2|0;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=f&65535;return}function ate(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;d=((b&128|0)!=0?65280:0)|b&-65281;c[a>>2]=d;c[240591]=d>>>8;c[240592]=c[a>>2]&65535;c[240593]=0;c[240594]=0;return}function atf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}f=154-g-((c[240590]|0)>>>8&1)|0;g=f&255;if((g|0)==154){c[240593]=0;h=154;i=0;c[240594]=i;c[240590]=i;c[240591]=h;return}j=(f|-256)^255;c[240593]=j;if((f&15|0)==10){k=(f&240)+16|0}else{k=g}g=k&255;c[240593]=g&j;j=c[957132+(b*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=k&255}else{fj[j&511](e&16777215,g)}c[240592]=c[240592]|g;h=g;i=256;c[240594]=i;c[240590]=i;c[240591]=h;return}function atg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}f=154-g-((c[240590]|0)>>>8&1)|0;g=f&255;if((g|0)==154){c[240593]=0;h=154;i=0;c[240594]=i;c[240590]=i;c[240591]=h;return}j=(f|-256)^255;c[240593]=j;if((f&15|0)==10){k=(f&240)+16|0}else{k=g}g=k&255;c[240593]=g&j;j=c[957132+(e*20|0)>>2]|0;if((j|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=k&255}else{fj[j&511](b&16777215,g)}c[240592]=c[240592]|g;h=g;i=256;c[240594]=i;c[240590]=i;c[240591]=h;return}function ath(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}f=154-h-((c[240590]|0)>>>8&1)|0;h=f&255;if((h|0)==154){c[240593]=0;i=154;j=0;c[240594]=j;c[240590]=j;c[240591]=i;return}k=(f|-256)^255;c[240593]=k;if((f&15|0)==10){l=(f&240)+16|0}else{l=h}h=l&255;c[240593]=h&k;k=c[957132+(e*20|0)>>2]|0;if((k|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=l&255}else{fj[k&511](g&16777215,h)}c[240592]=c[240592]|h;i=h;j=256;c[240594]=j;c[240590]=j;c[240591]=i;return}function ati(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}b=154-i-((c[240590]|0)>>>8&1)|0;i=b&255;if((i|0)==154){c[240593]=0;j=154;k=0;c[240594]=k;c[240590]=k;c[240591]=j;return}g=(b|-256)^255;c[240593]=g;if((b&15|0)==10){l=(b&240)+16|0}else{l=i}i=l&255;c[240593]=i&g;g=c[957132+(h*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]=l&255}else{fj[g&511](f&16777215,i)}c[240592]=c[240592]|i;j=i;k=256;c[240594]=k;c[240590]=k;c[240591]=j;return}function atj(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=154-h-((c[240590]|0)>>>8&1)|0;h=g&255;if((h|0)==154){c[240593]=0;i=154;j=0;c[240594]=j;c[240590]=j;c[240591]=i;return}k=(g|-256)^255;c[240593]=k;if((g&15|0)==10){l=(g&240)+16|0}else{l=h}h=l&255;c[240593]=h&k;k=c[957132+(e*20|0)>>2]|0;if((k|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=l&255}else{fj[k&511](f&16777215,h)}c[240592]=c[240592]|h;i=h;j=256;c[240594]=j;c[240590]=j;c[240591]=i;return}function atk(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}f=154-i-((c[240590]|0)>>>8&1)|0;i=f&255;if((i|0)==154){c[240593]=0;j=154;k=0;c[240594]=k;c[240590]=k;c[240591]=j;return}l=(f|-256)^255;c[240593]=l;if((f&15|0)==10){m=(f&240)+16|0}else{m=i}i=m&255;c[240593]=i&l;l=c[957132+(h*20|0)>>2]|0;if((l|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]=m&255}else{fj[l&511](g&16777215,i)}c[240592]=c[240592]|i;j=i;k=256;c[240594]=k;c[240590]=k;c[240591]=j;return}function atl(){var a=0,b=0,d=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;d=(b&32768|0)!=0?-65536:0;c[a>>2]=d|b&65535;c[240591]=d>>>24;c[240592]=c[a>>2];c[240593]=0;c[240594]=0;return}function atm(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=0;while(1){if((1<<a&d|0)==0){h=g;i=f}else{j=c[962260+(a<<2)>>2]|0;k=f>>>16&255;l=c[957136+(k*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(f&65535)>>1]=j&65535}else{fj[l&511](f&16777215,j&65535)}h=g+1|0;i=f+2|0}j=a+1|0;if(j>>>0<16){a=j;f=i;g=h}else{break}}c[240563]=(c[240563]|0)+(h<<4);return}function atn(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=0;while(1){if((1<<a&d|0)==0){h=g;i=f}else{j=f-2|0;k=c[962260+(15-a<<2)>>2]|0;l=j>>>16&255;m=c[957136+(l*20|0)>>2]|0;if((m|0)==0){b[(c[957120+(l*20|0)>>2]|0)+(j&65535)>>1]=k&65535}else{fj[m&511](j&16777215,k&65535)}h=g+1|0;i=j}j=a+1|0;if(j>>>0<16){a=j;f=i;g=h}else{break}}c[962260+((c[240587]&7|8)<<2)>>2]=i;c[240563]=(c[240563]|0)+(h<<4);return}function ato(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=0;h=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=0;while(1){if((1<<a&f|0)==0){i=g;j=h}else{d=c[962260+(a<<2)>>2]|0;k=h>>>16&255;l=c[957136+(k*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=d&65535}else{fj[l&511](h&16777215,d&65535)}i=g+1|0;j=h+2|0}d=a+1|0;if(d>>>0<16){a=d;h=j;g=i}else{break}}c[240563]=(c[240563]|0)+(i<<4);return}function atp(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=0;i=(a<<24>>24)+g+h|0;h=0;while(1){if((1<<d&f|0)==0){j=h;k=i}else{g=c[962260+(d<<2)>>2]|0;a=i>>>16&255;l=c[957136+(a*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(i&65535)>>1]=g&65535}else{fj[l&511](i&16777215,g&65535)}j=h+1|0;k=i+2|0}g=d+1|0;if(g>>>0<16){d=g;i=k;h=j}else{break}}c[240563]=(c[240563]|0)+(j<<4);return}function atq(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=0;g=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{j=c[962260+(a<<2)>>2]|0;k=g>>>16&255;l=c[957136+(k*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(g&65535)>>1]=j&65535}else{fj[l&511](g&16777215,j&65535)}h=d+1|0;i=g+2|0}j=a+1|0;if(j>>>0<16){a=j;g=i;d=h}else{break}}c[240563]=(c[240563]|0)+(h<<4);return}function atr(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+6;g=a+4|0;a=0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;d=0;while(1){if((1<<a&f|0)==0){i=d;j=h}else{g=c[962260+(a<<2)>>2]|0;k=h>>>16&255;l=c[957136+(k*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=g&65535}else{fj[l&511](h&16777215,g&65535)}i=d+1|0;j=h+2|0}g=a+1|0;if(g>>>0<16){a=g;h=j;d=i}else{break}}c[240563]=(c[240563]|0)+(i<<4);return}function ats(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=0;while(1){if((1<<a&d|0)==0){h=g;i=f}else{j=c[962260+(a<<2)>>2]|0;k=f>>>16&255;l=c[957136+(k*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(f&65535)>>1]=j>>>16&65535}else{fj[l&511](f&16777215,j>>>16)}l=f+2|0;k=l>>>16&255;m=c[957136+(k*20|0)>>2]|0;if((m|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(l&65535)>>1]=j&65535}else{fj[m&511](l&16777215,j&65535)}h=g+1|0;i=f+4|0}j=a+1|0;if(j>>>0<16){a=j;f=i;g=h}else{break}}c[240563]=(c[240563]|0)+(h<<5);return}function att(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[240581]|0;c[240581]=a+2;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;g=0;while(1){if((1<<a&d|0)==0){h=g;i=f}else{j=f-4|0;k=f-2|0;l=962260+(15-a<<2)|0;m=c[l>>2]|0;n=k>>>16&255;o=c[957136+(n*20|0)>>2]|0;if((o|0)==0){b[(c[957120+(n*20|0)>>2]|0)+(k&65535)>>1]=m&65535}else{fj[o&511](k&16777215,m&65535)}m=(c[l>>2]|0)>>>16;l=j>>>16&255;k=c[957136+(l*20|0)>>2]|0;if((k|0)==0){b[(c[957120+(l*20|0)>>2]|0)+(j&65535)>>1]=m&65535}else{fj[k&511](j&16777215,m)}h=g+1|0;i=j}j=a+1|0;if(j>>>0<16){a=j;f=i;g=h}else{break}}c[962260+((c[240587]&7|8)<<2)>>2]=i;c[240563]=(c[240563]|0)+(h<<5);return}function atu(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=0;h=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=0;while(1){if((1<<a&f|0)==0){i=g;j=h}else{d=c[962260+(a<<2)>>2]|0;k=h>>>16&255;l=c[957136+(k*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=d>>>16&65535}else{fj[l&511](h&16777215,d>>>16)}l=h+2|0;k=l>>>16&255;m=c[957136+(k*20|0)>>2]|0;if((m|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(l&65535)>>1]=d&65535}else{fj[m&511](l&16777215,d&65535)}i=g+1|0;j=h+4|0}d=a+1|0;if(d>>>0<16){a=d;h=j;g=i}else{break}}c[240563]=(c[240563]|0)+(i<<5);return}function atv(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=d<<16>>16}else{h=d}d=0;i=(a<<24>>24)+g+h|0;h=0;while(1){if((1<<d&f|0)==0){j=h;k=i}else{g=c[962260+(d<<2)>>2]|0;a=i>>>16&255;l=c[957136+(a*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(i&65535)>>1]=g>>>16&65535}else{fj[l&511](i&16777215,g>>>16)}l=i+2|0;a=l>>>16&255;m=c[957136+(a*20|0)>>2]|0;if((m|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(l&65535)>>1]=g&65535}else{fj[m&511](l&16777215,g&65535)}j=h+1|0;k=i+4|0}g=d+1|0;if(g>>>0<16){d=g;i=k;h=j}else{break}}c[240563]=(c[240563]|0)+(j<<5);return}function atw(){var a=0;a=c[962260+((c[240587]&7)<<2)>>2]&255;c[240591]=a;c[240592]=a;c[240593]=0;c[240594]=0;return}function atx(){var a=0;a=c[962260+((c[240587]&7)<<2)>>2]&65535;c[240591]=a>>>8;c[240592]=a;c[240593]=0;c[240594]=0;return}function aty(){var a=0;a=c[962260+((c[240587]&7)<<2)>>2]|0;c[240591]=a>>>24;c[240592]=a;c[240593]=0;c[240594]=0;return}function atz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=0;g=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{j=c[962260+(a<<2)>>2]|0;k=g>>>16&255;l=c[957136+(k*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[l&511](g&16777215,j>>>16)}l=g+2|0;k=l>>>16&255;m=c[957136+(k*20|0)>>2]|0;if((m|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(l&65535)>>1]=j&65535}else{fj[m&511](l&16777215,j&65535)}h=d+1|0;i=g+4|0}j=a+1|0;if(j>>>0<16){a=j;g=i;d=h}else{break}}c[240563]=(c[240563]|0)+(h<<5);return}function atA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+6;g=a+4|0;a=0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;d=0;while(1){if((1<<a&f|0)==0){i=d;j=h}else{g=c[962260+(a<<2)>>2]|0;k=h>>>16&255;l=c[957136+(k*20|0)>>2]|0;if((l|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(h&65535)>>1]=g>>>16&65535}else{fj[l&511](h&16777215,g>>>16)}l=h+2|0;k=l>>>16&255;m=c[957136+(k*20|0)>>2]|0;if((m|0)==0){b[(c[957120+(k*20|0)>>2]|0)+(l&65535)>>1]=g&65535}else{fj[m&511](l&16777215,g&65535)}i=d+1|0;j=h+4|0}g=a+1|0;if(g>>>0<16){a=g;h=j;d=i}else{break}}c[240563]=(c[240563]|0)+(i<<5);return}function atB(){var a=0,b=0,e=0,f=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;return}function atC(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+1;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;return}function atD(){var a=0,b=0,e=0,f=0;a=c[240580]|0;c[240580]=a+2;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;return}function atE(){var a=0,b=0,e=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-1|0;c[a>>2]=b;a=b>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(a*20|0)>>2]|0)+(b&65535^1)|0]|0}else{f=fl[e&255](b&16777215)|0}c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;return}function atF(){var a=0,b=0,e=0,f=0;a=(c[240580]|0)-2|0;c[240580]=a;b=a>>>16&255;e=c[957124+(b*20|0)>>2]|0;if((e|0)==0){f=d[(c[957120+(b*20|0)>>2]|0)+(a&65535^1)|0]|0}else{f=fl[e&255](a&16777215)|0}c[240591]=f;c[240592]=f;c[240593]=0;c[240594]=0;return}function atG(){var a=0,e=0,f=0,g=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+a|0;a=f>>>16&255;e=c[957124+(a*20|0)>>2]|0;if((e|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(f&65535^1)|0]|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;return}else{g=fl[e&255](f&16777215)|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;return}}function atH(){var a=0,b=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;b=c[240581]|0;c[240581]=b+2;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=b<<16>>16}else{g=b}b=(f<<24>>24)+a+g|0;g=b>>>16&255;a=c[957124+(g*20|0)>>2]|0;if((a|0)==0){h=d[(c[957120+(g*20|0)>>2]|0)+(b&65535^1)|0]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;return}else{h=fl[a&255](b&16777215)|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;return}}function atI(){var a=0,e=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=e>>>16&255;f=c[957124+(a*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(a*20|0)>>2]|0)+(e&65535^1)|0]|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;return}else{g=fl[f&255](e&16777215)|0;c[240591]=g;c[240592]=g;c[240593]=0;c[240594]=0;return}}function atJ(){var a=0,b=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=b&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(a^1)|0]|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;return}else{h=fl[g&255](a|b<<16&16711680)|0;c[240591]=h;c[240592]=h;c[240593]=0;c[240594]=0;return}}function atK(){var a=0,b=0,d=0,f=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;b=a>>>16&255;d=c[957128+(b*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(b*20|0)>>2]|0)+(a&65535)>>1]|0}else{f=fl[d&255](a&16777215)|0}c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;return}function atL(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;return}function atM(){var a=0,b=0,d=0,f=0;a=962260+((c[240587]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=b>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){f=e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0}else{f=fl[d&255](b&16777215)|0}c[240591]=f>>>8;c[240592]=f;c[240593]=0;c[240594]=0;return}function atN(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0;h=g>>>8;c[240591]=h;c[240592]=g;c[240593]=0;c[240594]=0;return}else{g=fl[d&255](f&16777215)|0;h=g>>>8;c[240591]=h;c[240592]=g;c[240593]=0;c[240594]=0;return}}function atO(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){f=b<<16>>16}else{f=b}b=(d<<24>>24)+a+f|0;f=b>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){g=e[(c[957120+(f*20|0)>>2]|0)+(b&65535)>>1]|0;h=g>>>8;c[240591]=h;c[240592]=g;c[240593]=0;c[240594]=0;return}else{g=fl[a&255](b&16777215)|0;h=g>>>8;c[240591]=h;c[240592]=g;c[240593]=0;c[240594]=0;return}}function atP(){var a=0,d=0,f=0,g=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}c[240591]=g>>>8;c[240592]=g;c[240593]=0;c[240594]=0;return}function atQ(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=b&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+a>>1]|0;h=g>>>8;c[240591]=h;c[240592]=g;c[240593]=0;c[240594]=0;return}else{g=fl[f&255](a|b<<16&16711680)|0;h=g>>>8;c[240591]=h;c[240592]=g;c[240593]=0;c[240594]=0;return}}function atR(){var a=0;a=962260+((c[240587]&7)<<2)|0;c[240592]=c[a>>2]&255;c[240591]=c[a>>2];c[240593]=0;c[240594]=0;c[a>>2]=c[a>>2]|128;return}function atS(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;b=a>>>16&255;d=957128+(b*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(b*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;i=h>>>24;c[240591]=i;c[240592]=h;c[240593]=0;c[240594]=0;return}else{b=(fl[f&255](a&16777215)|0)<<16;h=fl[c[d>>2]&255](a+2&16777215)|0|b;i=h>>>24;c[240591]=i;c[240592]=h;c[240593]=0;c[240594]=0;return}}function atT(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=b>>>16&255;d=957128+(a*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=b+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;i=h>>>24;c[240591]=i;c[240592]=h;c[240593]=0;c[240594]=0;return}else{a=(fl[f&255](b&16777215)|0)<<16;h=fl[c[d>>2]&255](b+2&16777215)|0|a;i=h>>>24;c[240591]=i;c[240592]=h;c[240593]=0;c[240594]=0;return}}function atU(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;d=b-4|0;c[a>>2]=d;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=b-2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;j=i>>>24;c[240591]=j;c[240592]=i;c[240593]=0;c[240594]=0;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](b+16777214&16777215)|0|a;j=i>>>24;c[240591]=j;c[240592]=i;c[240593]=0;c[240594]=0;return}}function atV(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=957128+(a*20|0)|0;g=c[d>>2]|0;if((g|0)==0){h=f+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]<<16;j=i>>>24;c[240591]=j;c[240592]=i;c[240593]=0;c[240594]=0;return}else{a=(fl[g&255](f&16777215)|0)<<16;i=fl[c[d>>2]&255](f+2&16777215)|0|a;j=i>>>24;c[240591]=j;c[240592]=i;c[240593]=0;c[240594]=0;return}}function atW(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)==0){f=b<<16>>16}else{f=b}b=(d<<24>>24)+a+f|0;f=b>>>16&255;a=957128+(f*20|0)|0;d=c[a>>2]|0;if((d|0)==0){g=b+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;i=h>>>24;c[240591]=i;c[240592]=h;c[240593]=0;c[240594]=0;return}else{f=(fl[d&255](b&16777215)|0)<<16;h=fl[c[a>>2]&255](b+2&16777215)|0|f;i=h>>>24;c[240591]=i;c[240592]=h;c[240593]=0;c[240594]=0;return}}function atX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=957128+(a*20|0)|0;g=c[f>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]<<16;j=i>>>24;c[240591]=j;c[240592]=i;c[240593]=0;c[240594]=0;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[f>>2]&255](d+2&16777215)|0|a;j=i>>>24;c[240591]=j;c[240592]=i;c[240593]=0;c[240594]=0;return}}function atY(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=a+2|0;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=a|b<<16;f=b&255;b=957128+(f*20|0)|0;g=c[b>>2]|0;if((g|0)==0){h=d+2|0;i=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+a>>1]|0)<<16;j=i>>>24;c[240591]=j;c[240592]=i;c[240593]=0;c[240594]=0;return}else{a=(fl[g&255](d&16777215)|0)<<16;i=fl[c[b>>2]&255](d+2&16777215)|0|a;j=i>>>24;c[240591]=j;c[240592]=i;c[240593]=0;c[240594]=0;return}}function atZ(){var b=0,e=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}c[240592]=g;c[240591]=g;c[240593]=0;c[240594]=0;f=g|128;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[g&511](b&16777215,f);return}}function at_(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}c[240592]=g;c[240591]=g;c[240593]=0;c[240594]=0;f=g|128;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function at$(){var b=0,e=0,f=0,g=0;b=c[240580]|0;c[240580]=b+2;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}c[240592]=g;c[240591]=g;c[240593]=0;c[240594]=0;f=g|128;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[g&511](b&16777215,f);return}}function at0(){var b=0,e=0,f=0,g=0;b=962260+((c[240587]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=e>>>16&255;f=c[957124+(b*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]|0}else{g=fl[f&255](e&16777215)|0}c[240592]=g;c[240591]=g;c[240593]=0;c[240594]=0;f=g|128;g=c[957132+(b*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function at1(){var b=0,e=0,f=0,g=0;b=(c[240580]|0)-2|0;c[240580]=b;e=b>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){g=d[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]|0}else{g=fl[f&255](b&16777215)|0}c[240592]=g;c[240591]=g;c[240593]=0;c[240594]=0;f=g|128;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=f&255;return}else{fj[g&511](b&16777215,f);return}}function at2(){var e=0,f=0,g=0,h=0;e=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=(b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0)+e|0;e=g>>>16&255;f=c[957124+(e*20|0)>>2]|0;if((f|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]|0}else{h=fl[f&255](g&16777215)|0}c[240592]=h;c[240591]=h;c[240593]=0;c[240594]=0;f=h|128;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(g&65535^1)|0]=f&255;return}else{fj[h&511](g&16777215,f);return}}function at3(){var b=0,f=0,g=0,h=0,i=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=c[240581]|0;c[240581]=f+2;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=f<<16>>16}else{h=f}f=(g<<24>>24)+b+h|0;h=f>>>16&255;b=c[957124+(h*20|0)>>2]|0;if((b|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]|0}else{i=fl[b&255](f&16777215)|0}c[240592]=i;c[240591]=i;c[240593]=0;c[240594]=0;b=i|128;i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(f&65535^1)|0]=b&255;return}else{fj[i&511](f&16777215,b);return}}function at4(){var e=0,f=0,g=0,h=0;e=c[240581]|0;c[240581]=e+2;f=b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0;e=f>>>16&255;g=c[957124+(e*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}c[240592]=h;c[240591]=h;c[240593]=0;c[240594]=0;g=h|128;h=c[957132+(e*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[h&511](f&16777215,g);return}}function at5(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=0;g=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{c[962260+(a<<2)>>2]=b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;h=d+1|0;i=g+2|0}j=a+1|0;if(j>>>0<16){a=j;g=i;d=h}else{break}}c[240563]=(c[240563]|0)+(h<<4);return}function at6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){h=g<<16>>16}else{h=g}g=0;i=(a<<24>>24)+d+h|0;h=0;while(1){if((1<<g&f|0)==0){j=h;k=i}else{c[962260+(g<<2)>>2]=b[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;j=h+1|0;k=i+2|0}d=g+1|0;if(d>>>0<16){g=d;i=k;h=j}else{break}}c[240563]=(c[240563]|0)+(j<<4);return}function at7(){var b=0,f=0,g=0,h=0,i=0;b=c[240581]|0;c[240581]=b+4;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+2|0;b=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=b|f<<16;h=f&255;f=c[957124+(h*20|0)>>2]|0;if((f|0)==0){i=d[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]|0}else{i=fl[f&255](g&16777215)|0}c[240592]=i;c[240591]=i;c[240593]=0;c[240594]=0;f=i|128;i=c[957132+(h*20|0)>>2]|0;if((i|0)==0){a[(c[957120+(h*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[i&511](g&16777215,f);return}}function at8(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=0;while(1){if((1<<a&b|0)==0){g=f;h=d}else{i=d>>>16&255;j=c[957128+(i*20|0)>>2]|0;if((j|0)==0){k=e[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]|0}else{k=fl[j&255](d&16777215)|0}c[962260+(a<<2)>>2]=k<<16>>16;g=f+1|0;h=d+2|0}j=a+1|0;if(j>>>0<16){a=j;d=h;f=g}else{break}}c[240563]=(c[240563]|0)+(g<<4);return}function at9(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=0;while(1){if((1<<a&b|0)==0){g=f;h=d}else{i=d>>>16&255;j=c[957128+(i*20|0)>>2]|0;if((j|0)==0){k=e[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]|0}else{k=fl[j&255](d&16777215)|0}c[962260+(a<<2)>>2]=k<<16>>16;g=f+1|0;h=d+2|0}j=a+1|0;if(j>>>0<16){a=j;d=h;f=g}else{break}}c[962260+((c[240587]&7|8)<<2)>>2]=h;c[240563]=(c[240563]|0)+(g<<4);return}function aua(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=0;h=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=0;while(1){if((1<<a&f|0)==0){i=g;j=h}else{d=h>>>16&255;k=c[957128+(d*20|0)>>2]|0;if((k|0)==0){l=e[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]|0}else{l=fl[k&255](h&16777215)|0}c[962260+(a<<2)>>2]=l<<16>>16;i=g+1|0;j=h+2|0}k=a+1|0;if(k>>>0<16){a=k;h=j;g=i}else{break}}c[240563]=(c[240563]|0)+(i<<4);return}function aub(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;b=a+2|0;c[240581]=b;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){g=b<<16>>16}else{g=b}b=0;h=(a<<24>>24)+f+g|0;g=0;while(1){if((1<<b&d|0)==0){i=g;j=h}else{f=h>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){k=e[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]|0}else{k=fl[a&255](h&16777215)|0}c[962260+(b<<2)>>2]=k<<16>>16;i=g+1|0;j=h+2|0}a=b+1|0;if(a>>>0<16){b=a;h=j;g=i}else{break}}c[240563]=(c[240563]|0)+(i<<4);return}function auc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=0;g=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{j=g>>>16&255;k=c[957128+(j*20|0)>>2]|0;if((k|0)==0){l=e[(c[957120+(j*20|0)>>2]|0)+(g&65535)>>1]|0}else{l=fl[k&255](g&16777215)|0}c[962260+(a<<2)>>2]=l<<16>>16;h=d+1|0;i=g+2|0}k=a+1|0;if(k>>>0<16){a=k;g=i;d=h}else{break}}c[240563]=(c[240563]|0)+(h<<4);return}function aud(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;b=a+2|0;c[240581]=b;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+6;f=a+4|0;a=0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;b=0;while(1){if((1<<a&d|0)==0){h=b;i=g}else{f=g>>>16&255;j=c[957128+(f*20|0)>>2]|0;if((j|0)==0){k=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{k=fl[j&255](g&16777215)|0}c[962260+(a<<2)>>2]=k<<16>>16;h=b+1|0;i=g+2|0}j=a+1|0;if(j>>>0<16){a=j;g=i;b=h}else{break}}c[240563]=(c[240563]|0)+(h<<4);return}function aue(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=0;while(1){if((1<<a&b|0)==0){g=f;h=d}else{i=d>>>16&255;j=957128+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d+2|0;m=e[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[k&255](d&16777215)|0)<<16;m=fl[c[j>>2]&255](d+2&16777215)|0|i}c[962260+(a<<2)>>2]=m;g=f+1|0;h=d+4|0}i=a+1|0;if(i>>>0<16){a=i;d=h;f=g}else{break}}c[240563]=(c[240563]|0)+(g<<5);return}function auf(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;f=0;while(1){if((1<<a&b|0)==0){g=f;h=d}else{i=d>>>16&255;j=957128+(i*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=d+2|0;m=e[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[957120+(i*20|0)>>2]|0)+(d&65535)>>1]|0)<<16}else{i=(fl[k&255](d&16777215)|0)<<16;m=fl[c[j>>2]&255](d+2&16777215)|0|i}c[962260+(a<<2)>>2]=m;g=f+1|0;h=d+4|0}i=a+1|0;if(i>>>0<16){a=i;d=h;f=g}else{break}}c[962260+((c[240587]&7|8)<<2)>>2]=h;c[240563]=(c[240563]|0)+(g<<5);return}function aug(){return}function auh(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=0;g=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{j=g+2|0;c[962260+(a<<2)>>2]=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]<<16;h=d+1|0;i=g+4|0}j=a+1|0;if(j>>>0<16){a=j;g=i;d=h}else{break}}c[240563]=(c[240563]|0)+(h<<5);return}function aui(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;b=a+2|0;c[240581]=b;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){g=f<<16>>16}else{g=f}f=0;h=(a<<24>>24)+b+g|0;g=0;while(1){if((1<<f&d|0)==0){i=g;j=h}else{b=h+2|0;c[962260+(f<<2)>>2]=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0)<<16;i=g+1|0;j=h+4|0}b=f+1|0;if(b>>>0<16){f=b;h=j;g=i}else{break}}c[240563]=(c[240563]|0)+(i<<5);return}function auj(){var a=0,d=0,e=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;e=(c[240580]|0)-4|0;c[240580]=e;b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]=d>>>16&65535;e=(c[240580]|0)+2|0;b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]=d&65535;c[a>>2]=c[240580];a=c[240580]|0;d=c[240581]|0;c[240581]=d+2;c[240580]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a;return}function auk(){var a=0,b=0,d=0;a=962260+((c[240587]&7|8)<<2)|0;b=c[a>>2]|0;c[240580]=b+4;d=b+2|0;c[a>>2]=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;return}function aul(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=0;h=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+g|0;g=0;while(1){if((1<<a&f|0)==0){i=g;j=h}else{d=h>>>16&255;k=957128+(d*20|0)|0;l=c[k>>2]|0;if((l|0)==0){m=h+2|0;n=e[(c[957120+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(h&65535)>>1]<<16}else{d=(fl[l&255](h&16777215)|0)<<16;n=fl[c[k>>2]&255](h+2&16777215)|0|d}c[962260+(a<<2)>>2]=n;i=g+1|0;j=h+4|0}d=a+1|0;if(d>>>0<16){a=d;h=j;g=i}else{break}}c[240563]=(c[240563]|0)+(i<<5);return}function aum(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;b=a+2|0;c[240581]=b;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=c[962260+((c[240587]&7|8)<<2)>>2]|0;c[240581]=a+4;a=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(a>>>12<<2)>>2]|0;if((a&2048|0)==0){g=b<<16>>16}else{g=b}b=0;h=(a<<24>>24)+f+g|0;g=0;while(1){if((1<<b&d|0)==0){i=g;j=h}else{f=h>>>16&255;a=957128+(f*20|0)|0;k=c[a>>2]|0;if((k|0)==0){l=h+2|0;m=e[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(h&65535)>>1]|0)<<16}else{f=(fl[k&255](h&16777215)|0)<<16;m=fl[c[a>>2]&255](h+2&16777215)|0|f}c[962260+(b<<2)>>2]=m;i=g+1|0;j=h+4|0}f=b+1|0;if(f>>>0<16){b=f;h=j;g=i}else{break}}c[240563]=(c[240563]|0)+(i<<5);return}function aun(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+4;a=0;g=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=0;while(1){if((1<<a&f|0)==0){h=d;i=g}else{j=g>>>16&255;k=957128+(j*20|0)|0;l=c[k>>2]|0;if((l|0)==0){m=g+2|0;n=e[(c[957120+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|e[(c[957120+(j*20|0)>>2]|0)+(g&65535)>>1]<<16}else{j=(fl[l&255](g&16777215)|0)<<16;n=fl[c[k>>2]&255](g+2&16777215)|0|j}c[962260+(a<<2)>>2]=n;h=d+1|0;i=g+4|0}j=a+1|0;if(j>>>0<16){a=j;g=i;d=h}else{break}}c[240563]=(c[240563]|0)+(h<<5);return}function auo(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240581]|0;b=a+2|0;c[240581]=b;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;c[240581]=a+6;f=a+4|0;a=0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;b=0;while(1){if((1<<a&d|0)==0){h=b;i=g}else{f=g>>>16&255;j=957128+(f*20|0)|0;k=c[j>>2]|0;if((k|0)==0){l=g+2|0;m=e[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{f=(fl[k&255](g&16777215)|0)<<16;m=fl[c[j>>2]&255](g+2&16777215)|0|f}c[962260+(a<<2)>>2]=m;h=b+1|0;i=g+4|0}f=a+1|0;if(f>>>0<16){a=f;g=i;b=h}else{break}}c[240563]=(c[240563]|0)+(h<<5);return}function aup(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[240587]&15|32;d=c[240589]|0;f=d<<11|c[240588]|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;c[240588]=0;c[962328+(d<<2)>>2]=c[240580];c[240589]=4;d=c[240581]|0;g=(c[240586]|0)-4|0;c[240580]=g;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[240580]|0)+2|0;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;d=(c[240580]|0)-2|0;c[240580]=d;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;f=a<<2;d=c[239282]|0;if((d|0)==0){g=c[239280]|0;h=e[g+(f|2)>>1]|0|(e[g+f>>1]|0)<<16;c[240581]=h;i=536264+(a<<1)|0;j=b[i>>1]|0;k=j&65535;l=c[240563]|0;m=l+k|0;c[240563]=m;return}else{g=(fl[d&255](f)|0)<<16;h=fl[c[239282]&255](f|2)|0|g;c[240581]=h;i=536264+(a<<1)|0;j=b[i>>1]|0;k=j&65535;l=c[240563]|0;m=l+k|0;c[240563]=m;return}}function auq(){var a=0,d=0,e=0,f=0,g=0;a=c[240580]|0;d=a-4|0;c[240580]=d;e=d>>>16;f=e&255;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=e&65535}else{fj[g&511](d&16777215,e)}e=a-2|0;a=e>>>16&255;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(e&65535)>>1]=d&65535}else{fj[g&511](e&16777215,d&65535)}d=c[240580]|0;e=c[240581]|0;c[240581]=e+2;c[240580]=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d;return}function aur(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240580]|0;b=a>>>16&255;d=957128+(b*20|0)|0;f=c[d>>2]|0;if((f|0)==0){g=a+2|0;h=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0|(e[(c[957120+(b*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;c[240580]=h;return}else{b=(fl[f&255](a&16777215)|0)<<16;h=fl[c[d>>2]&255](a+2&16777215)|0|b;c[240580]=h;return}}function aus(){if((c[240589]|0)==0){aH4();return}else{c[240582]=c[962260+((c[240587]&7|8)<<2)>>2];return}}function aut(){if((c[240589]|0)==0){aH4();return}else{c[962260+((c[240587]&7|8)<<2)>>2]=c[240582];return}}function auu(){if((c[240589]|0)==0){aH4();return}else{c[240563]=(c[240563]|0)+528;return}}function auv(){var a=0,b=0;a=c[240580]|0;c[240580]=a+4;b=a+2|0;c[240581]=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;return}function auw(){var a=0,b=0,d=0,f=0;a=c[240580]|0;b=a+2|0;c[240580]=b;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=d<<4;c[240590]=f&256;c[240591]=f&128;c[240592]=d>>>2&1^1;c[240593]=d<<6&128;c[240594]=d<<8&256;c[240580]=a+6;d=a+4|0;c[240581]=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0|(e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0)<<16;return}function aux(){var a=0,d=0,e=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;e=(c[240580]|0)-4|0;c[240580]=e;b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]=d>>>16&65535;e=(c[240580]|0)+2|0;b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]=d&65535;c[240581]=a;return}function auy(){var a=0,d=0,e=0,f=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;e=d+2|0;c[240581]=e;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=(c[240580]|0)-4|0;c[240580]=a;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=e>>>16&65535;a=(c[240580]|0)+2|0;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=e&65535;c[240581]=f;return}function auz(){var a=0,d=0,f=0,g=0,h=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;f=d+2|0;c[240581]=f;g=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=d<<16>>16}else{h=d}d=(c[240580]|0)-4|0;c[240580]=d;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f>>>16&65535;d=(c[240580]|0)+2|0;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;c[240581]=(g<<24>>24)+a+h;return}function auA(){var a=0,d=0,e=0;a=c[240581]|0;d=a+2|0;c[240581]=d;e=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=(c[240580]|0)-4|0;c[240580]=a;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535;a=(c[240580]|0)+2|0;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d&65535;c[240581]=e;return}function auB(){var a=0,d=0,f=0,g=0;a=c[240581]|0;d=a+4|0;c[240581]=d;f=a+2|0;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;a=(c[240580]|0)-4|0;c[240580]=a;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535;a=(c[240580]|0)+2|0;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d&65535;c[240581]=g;return}function auC(){var a=0,d=0,e=0;a=c[240581]|0;d=a+2|0;c[240581]=d;e=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a|0;a=(c[240580]|0)-4|0;c[240580]=a;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d>>>16&65535;a=(c[240580]|0)+2|0;b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]=d&65535;c[240581]=e;return}function auD(){var a=0,d=0,f=0,g=0,h=0;a=c[240581]|0;d=a+2|0;c[240581]=d;f=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;g=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){h=g<<16>>16}else{h=g}g=(c[240580]|0)-4|0;c[240580]=g;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[240580]|0)+2|0;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;c[240581]=(f<<24>>24)+a+h;return}function auE(){c[240581]=c[962260+((c[240587]&7|8)<<2)>>2];return}function auF(){var a=0,d=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a;return}function auG(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(d>>>12<<2)>>2]|0;if((d&2048|0)!=0){f=b;g=d<<24;h=g>>24;i=h+a|0;j=i+f|0;c[240581]=j;return}f=b<<16>>16;g=d<<24;h=g>>24;i=h+a|0;j=i+f|0;c[240581]=j;return}function auH(){var a=0;a=c[240581]|0;c[240581]=a+2;c[240581]=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;return}function auI(){var a=0,b=0;a=c[240581]|0;c[240581]=a+4;b=a+2|0;c[240581]=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0|(e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)<<16;return}function auJ(){var a=0;a=c[240581]|0;c[240581]=a+2;c[240581]=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+a;return}function auK(){var a=0,b=0,d=0,f=0;a=c[240581]|0;c[240581]=a+2;b=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;d=c[962260+(b>>>12<<2)>>2]|0;if((b&2048|0)==0){f=d<<16>>16}else{f=d}c[240581]=(b<<24>>24)+a+f;return}function auL(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&255;f=d+e|0;c[240591]=f;c[240593]=(f^d)&(f^e);c[240594]=f;c[240590]=f;f=d+a&255;c[240592]=f;c[b>>2]=f|c[b>>2]&-256;return}function auM(){var a=0,b=0,d=0;a=c[240589]|0;if((a|0)==0){aH4();return}else{b=c[240581]|0;c[240581]=b+2;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;c[240597]=c[240597]|1;c[240588]=d&32768;c[240595]=d&1792;b=d<<4;c[240590]=b&256;c[240591]=b&128;c[240592]=d>>>2&1^1;c[240593]=d<<6&128;c[240594]=d<<8&256;b=d>>>11&4;c[962328+(a<<2)>>2]=c[240580];c[240589]=b;c[240580]=c[962328+(b<<2)>>2];ahk();c[240563]=(c[240564]|0)-16;return}}function auN(){var a=0,b=0,d=0,f=0,g=0,h=0;a=c[240589]|0;if((a|0)==0){aH4();return}else{b=c[240580]|0;d=b+2|0;c[240580]=d;f=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;g=b+6|0;c[240580]=g;h=b+4|0;c[240581]=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0|(e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)<<16;c[240588]=f&32768;c[240595]=f&1792;d=f<<4;c[240590]=d&256;c[240591]=d&128;c[240592]=f>>>2&1^1;c[240593]=f<<6&128;c[240594]=f<<8&256;d=f>>>11&4;c[962328+(a<<2)>>2]=g;c[240589]=d;c[240580]=c[962328+(d<<2)>>2];ahk();return}}function auO(){if((c[240593]&128|0)==0){return}aH3(7);return}function auP(){var b=0,e=0,f=0,g=0,h=0;b=c[240587]|0;e=((b>>>9)+7&7)+1|0;f=c[962260+((b&7|8)<<2)>>2]|0;b=f>>>16&255;g=c[957124+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=h+e|0;c[240591]=g;c[240593]=(g^e)&(g^h);c[240594]=g;c[240590]=g;h=g&255;c[240592]=h;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,h);return}}function auQ(){var b=0,e=0,f=0,g=0,h=0;b=c[240587]|0;e=((b>>>9)+7&7)+1|0;f=962260+((b&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+1;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h+e|0;c[240591]=g;c[240593]=(g^e)&(g^h);c[240594]=g;c[240590]=g;h=g&255;c[240592]=h;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,h);return}}function auR(){var b=0,e=0,f=0,g=0,h=0;b=(((c[240587]|0)>>>9)+7&7)+1|0;e=c[240580]|0;c[240580]=e+2;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h+b|0;c[240591]=g;c[240593]=(g^b)&(g^h);c[240594]=g;c[240590]=g;h=g&255;c[240592]=h;b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,h);return}}function auS(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&65535;f=d+e|0;g=f>>>8;c[240591]=g;c[240593]=((f^d)&(f^e))>>>8;c[240594]=g;c[240590]=g;g=d+a&65535;c[240592]=g;c[b>>2]=g|c[b>>2]&-65536;return}function auT(){var a=0,b=0;a=c[240587]|0;b=962260+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)+1+((a>>>9)+7&7);return}function auU(){var b=0,e=0,f=0,g=0,h=0;b=c[240587]|0;e=((b>>>9)+7&7)+1|0;f=962260+((b&7|8)<<2)|0;b=(c[f>>2]|0)-1|0;c[f>>2]=b;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h+e|0;c[240591]=g;c[240593]=(g^e)&(g^h);c[240594]=g;c[240590]=g;h=g&255;c[240592]=h;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,h);return}}function auV(){var b=0,e=0,f=0,g=0,h=0;b=(((c[240587]|0)>>>9)+7&7)+1|0;e=(c[240580]|0)-2|0;c[240580]=e;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h+b|0;c[240591]=g;c[240593]=(g^b)&(g^h);c[240594]=g;c[240590]=g;h=g&255;c[240592]=h;b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,h);return}}function auW(){var e=0,f=0,g=0,h=0,i=0;e=c[240587]|0;f=((e>>>9)+7&7)+1|0;g=c[962260+((e&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;h=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+g|0;g=h>>>16&255;e=c[957124+(g*20|0)>>2]|0;if((e|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[e&255](h&16777215)|0}e=i+f|0;c[240591]=e;c[240593]=(e^f)&(e^i);c[240594]=e;c[240590]=e;i=e&255;c[240592]=i;f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]=e&255;return}else{fj[f&511](h&16777215,i);return}}function auX(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240587]|0;f=((b>>>9)+7&7)+1|0;g=c[962260+((b&7|8)<<2)>>2]|0;b=c[240581]|0;c[240581]=b+2;h=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=b<<16>>16}else{i=b}b=(h<<24>>24)+g+i|0;i=b>>>16&255;g=c[957124+(i*20|0)>>2]|0;if((g|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(b&65535^1)|0]|0}else{j=fl[g&255](b&16777215)|0}g=j+f|0;c[240591]=g;c[240593]=(g^f)&(g^j);c[240594]=g;c[240590]=g;j=g&255;c[240592]=j;f=c[957132+(i*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[f&511](b&16777215,j);return}}function auY(){var e=0,f=0,g=0,h=0,i=0;e=(((c[240587]|0)>>>9)+7&7)+1|0;f=c[240581]|0;c[240581]=f+2;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g>>>16&255;h=c[957124+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i+e|0;c[240591]=h;c[240593]=(h^e)&(h^i);c[240594]=h;c[240590]=h;i=h&255;c[240592]=i;e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,i);return}}function auZ(){var b=0,f=0,g=0,h=0,i=0,j=0;b=(((c[240587]|0)>>>9)+7&7)+1|0;f=c[240581]|0;c[240581]=f+4;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=f|g<<16;i=g&255;g=c[957124+(i*20|0)>>2]|0;if((g|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(f^1)|0]|0}else{j=fl[g&255](h&16777215)|0}g=j+b|0;c[240591]=g;c[240593]=(g^b)&(g^j);c[240594]=g;c[240590]=g;j=g&255;c[240592]=j;b=c[957132+(i*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(f^1)|0]=g&255;return}else{fj[b&511](h&16777215,j);return}}function au_(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h+d|0;i=g>>>8;c[240591]=i;c[240593]=((g^d)&(g^h))>>>8;c[240594]=i;c[240590]=i;i=g&65535;c[240592]=i;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[h&511](f&16777215,i);return}}function au$(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=962260+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+2;f=a>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h+d|0;i=g>>>8;c[240591]=i;c[240593]=((g^d)&(g^h))>>>8;c[240594]=i;c[240590]=i;i=g&65535;c[240592]=i;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[h&511](a&16777215,i);return}}function au0(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=962260+((a&7|8)<<2)|0;a=(c[f>>2]|0)-2|0;c[f>>2]=a;f=a>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h+d|0;i=g>>>8;c[240591]=i;c[240593]=((g^d)&(g^h))>>>8;c[240594]=i;c[240590]=i;i=g&65535;c[240592]=i;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[h&511](a&16777215,i);return}}function au1(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}a=h+d|0;i=a>>>8;c[240591]=i;c[240593]=((a^d)&(a^h))>>>8;c[240594]=i;c[240590]=i;i=a&65535;c[240592]=i;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=a&65535;return}else{fj[h&511](g&16777215,i);return}}function au2(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=a>>>16&255;f=c[957128+(h*20|0)>>2]|0;if((f|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]|0}else{i=fl[f&255](a&16777215)|0}f=i+d|0;g=f>>>8;c[240591]=g;c[240593]=((f^d)&(f^i))>>>8;c[240594]=g;c[240590]=g;g=f&65535;c[240592]=g;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]=f&65535;return}else{fj[i&511](a&16777215,g);return}}function au3(){var a=0,d=0,f=0,g=0,h=0,i=0;a=(((c[240587]|0)>>>9)+7&7)+1|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h+a|0;i=g>>>8;c[240591]=i;c[240593]=((g^a)&(g^h))>>>8;c[240594]=i;c[240590]=i;i=g&65535;c[240592]=i;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[h&511](f&16777215,i);return}}function au4(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=d+a|0;c[240591]=e>>>24;c[240593]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(d|a)|d&a)>>>23;c[240594]=f;c[240590]=f;c[240592]=e;c[b>>2]=e;return}function au5(){var a=0,b=0;a=c[240587]|0;b=962260+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)+1+((a>>>9)+7&7);return}function au6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=(((c[240587]|0)>>>9)+7&7)+1|0;d=c[240581]|0;c[240581]=d+4;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;h=f&255;f=c[957128+(h*20|0)>>2]|0;if((f|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+d>>1]|0}else{i=fl[f&255](g&16777215)|0}f=i+a|0;j=f>>>8;c[240591]=j;c[240593]=((f^a)&(f^i))>>>8;c[240594]=j;c[240590]=j;j=f&65535;c[240592]=j;i=c[957136+(h*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(h*20|0)>>2]|0)+d>>1]=f&65535;return}else{fj[i&511](g&16777215,j);return}}function au7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{i=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](f+2&16777215)|0|i}i=j+d|0;c[240591]=i>>>24;c[240593]=((i^d)&(i^j))>>>24;g=((i^-8388608)&(j|d)|j&d)>>>23;c[240594]=g;c[240590]=g;c[240592]=i;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[g&511](f&16777215,i>>>16)}g=f+2|0;f=g>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[a&511](g&16777215,i&65535);return}}function au8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=962260+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+4;f=a>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[g>>2]&255](a+2&16777215)|0|i}i=j+d|0;c[240591]=i>>>24;c[240593]=((i^d)&(i^j))>>>24;g=((i^-8388608)&(j|d)|j&d)>>>23;c[240594]=g;c[240590]=g;c[240592]=i;g=c[957136+(f*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[g&511](a&16777215,i>>>16)}g=a+2|0;a=g>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[f&511](g&16777215,i&65535);return}}function au9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=962260+((a&7|8)<<2)|0;a=c[f>>2]|0;g=a-4|0;c[f>>2]=g;f=g>>>16&255;h=957128+(f*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=a-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{j=(fl[i&255](g&16777215)|0)<<16;k=fl[c[h>>2]&255](a+16777214&16777215)|0|j}j=k+d|0;c[240591]=j>>>24;c[240593]=((j^d)&(j^k))>>>24;h=((j^-8388608)&(k|d)|k&d)>>>23;c[240594]=h;c[240590]=h;c[240592]=j;h=c[957136+(f*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[h&511](g&16777215,j>>>16)}g=a-2|0;a=g>>>16&255;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[h&511](g&16777215,j&65535);return}}function ava(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=957128+(f*20|0)|0;h=c[a>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]<<16}else{i=(fl[h&255](g&16777215)|0)<<16;j=fl[c[a>>2]&255](g+2&16777215)|0|i}i=j+d|0;c[240591]=i>>>24;c[240593]=((i^d)&(i^j))>>>24;a=((i^-8388608)&(j|d)|j&d)>>>23;c[240594]=a;c[240590]=a;c[240592]=i;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=i>>>16&65535}else{fj[a&511](g&16777215,i>>>16)}a=g+2|0;g=a>>>16&255;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[f&511](a&16777215,i&65535);return}}function avb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=a>>>16&255;f=957128+(h*20|0)|0;g=c[f>>2]|0;if((g|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{i=(fl[g&255](a&16777215)|0)<<16;j=fl[c[f>>2]&255](a+2&16777215)|0|i}i=j+d|0;c[240591]=i>>>24;c[240593]=((i^d)&(i^j))>>>24;f=((i^-8388608)&(j|d)|j&d)>>>23;c[240594]=f;c[240590]=f;c[240592]=i;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[f&511](a&16777215,i>>>16)}f=a+2|0;a=f>>>16&255;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i&65535;return}else{fj[h&511](f&16777215,i&65535);return}}function avc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=(((c[240587]|0)>>>9)+7&7)+1|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]<<16}else{i=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](f+2&16777215)|0|i}i=j+a|0;c[240591]=i>>>24;c[240593]=((i^a)&(i^j))>>>24;g=((i^-8388608)&(j|a)|j&a)>>>23;c[240594]=g;c[240590]=g;c[240592]=i;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[g&511](f&16777215,i>>>16)}g=f+2|0;f=g>>>16&255;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=i&65535;return}else{fj[d&511](g&16777215,i&65535);return}}function avd(){c[240581]=(c[240581]|0)+2;return}function ave(){var a=0;a=962260+((c[240587]&7)<<2)|0;c[a>>2]=c[a>>2]|255;return}function avf(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&255;f=e-d|0;c[240591]=f;g=a-d&255;c[240592]=g;c[240594]=f;c[240590]=f;c[240593]=(f^e)&(d^e);c[b>>2]=g|c[b>>2]&-256;return}function avg(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=(((c[240587]|0)>>>9)+7&7)+1|0;d=c[240581]|0;c[240581]=d+4;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;h=f&255;f=957128+(h*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=g+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+d>>1]|0)<<16}else{j=(fl[i&255](g&16777215)|0)<<16;k=fl[c[f>>2]&255](g+2&16777215)|0|j}j=k+a|0;c[240591]=j>>>24;c[240593]=((j^a)&(j^k))>>>24;f=((j^-8388608)&(k|a)|k&a)>>>23;c[240594]=f;c[240590]=f;c[240592]=j;f=c[957136+(h*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(h*20|0)>>2]|0)+d>>1]=j>>>16&65535}else{fj[f&511](g&16777215,j>>>16)}f=g+2|0;g=f>>>16&255;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(f&65535)>>1]=j&65535;return}else{fj[d&511](f&16777215,j&65535);return}}function avh(){var b=0,d=0,e=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=b>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=-1;return}else{fj[e&511](b&16777215,255);return}}function avi(){var b=0,d=0,e=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=d>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=-1;return}else{fj[e&511](d&16777215,255);return}}function avj(){var b=0,d=0,e=0;b=c[240580]|0;c[240580]=b+2;d=b>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=-1;return}else{fj[e&511](b&16777215,255);return}}function avk(){var b=0,d=0,e=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=d>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=-1;return}else{fj[e&511](d&16777215,255);return}}function avl(){var b=0,d=0,e=0;b=(c[240580]|0)-2|0;c[240580]=b;d=b>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=-1;return}else{fj[e&511](b&16777215,255);return}}function avm(){var d=0,e=0,f=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=f>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(f&65535^1)|0]=-1;return}else{fj[e&511](f&16777215,255);return}}function avn(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[957132+(g*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(d&65535^1)|0]=-1;return}else{fj[b&511](d&16777215,255);return}}function avo(){var d=0,e=0,f=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e>>>16&255;f=c[957132+(d*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(e&65535^1)|0]=-1;return}else{fj[f&511](e&16777215,255);return}}function avp(){var b=0,d=0,f=0,g=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b^1)|0]=-1;return}else{fj[g&511](b|d<<16&16711680,255);return}}function avq(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=((b>>>9)+7&7)+1|0;f=c[962260+((b&7|8)<<2)>>2]|0;b=f>>>16&255;g=c[957124+(b*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]|0}else{h=fl[g&255](f&16777215)|0}g=h-e|0;c[240591]=g;i=g&255;c[240592]=i;c[240594]=g;c[240590]=g;c[240593]=(g^h)&(h^e);e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,i);return}}function avr(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=((b>>>9)+7&7)+1|0;f=962260+((b&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+1;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h-e|0;c[240591]=g;i=g&255;c[240592]=i;c[240594]=g;c[240590]=g;c[240593]=(g^h)&(h^e);e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,i);return}}function avs(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(((c[240587]|0)>>>9)+7&7)+1|0;e=c[240580]|0;c[240580]=e+2;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h-b|0;c[240591]=g;i=g&255;c[240592]=i;c[240594]=g;c[240590]=g;c[240593]=(g^h)&(h^b);b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,i);return}}function avt(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[240587]|0;e=((b>>>9)+7&7)+1|0;f=962260+((b&7|8)<<2)|0;b=(c[f>>2]|0)-1|0;c[f>>2]=b;f=b>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]|0}else{h=fl[g&255](b&16777215)|0}g=h-e|0;c[240591]=g;i=g&255;c[240592]=i;c[240594]=g;c[240590]=g;c[240593]=(g^h)&(h^e);e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[e&511](b&16777215,i);return}}function avu(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(((c[240587]|0)>>>9)+7&7)+1|0;e=(c[240580]|0)-2|0;c[240580]=e;f=e>>>16&255;g=c[957124+(f*20|0)>>2]|0;if((g|0)==0){h=d[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]|0}else{h=fl[g&255](e&16777215)|0}g=h-b|0;c[240591]=g;i=g&255;c[240592]=i;c[240594]=g;c[240590]=g;c[240593]=(g^h)&(h^b);b=c[957132+(f*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=g&255;return}else{fj[b&511](e&16777215,i);return}}function avv(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[240587]|0;f=((e>>>9)+7&7)+1|0;g=c[962260+((e&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;h=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+g|0;g=h>>>16&255;e=c[957124+(g*20|0)>>2]|0;if((e|0)==0){i=d[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]|0}else{i=fl[e&255](h&16777215)|0}e=i-f|0;c[240591]=e;j=e&255;c[240592]=j;c[240594]=e;c[240590]=e;c[240593]=(e^i)&(i^f);f=c[957132+(g*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(h&65535^1)|0]=e&255;return}else{fj[f&511](h&16777215,j);return}}function avw(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&65535;f=e-d|0;g=f>>>8;c[240591]=g;h=a-d&65535;c[240592]=h;c[240594]=g;c[240590]=g;c[240593]=((f^e)&(d^e))>>>8;c[b>>2]=h|c[b>>2]&-65536;return}function avx(){var a=0,b=0;a=c[240587]|0;b=962260+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-1-((a>>>9)+7&7);return}function avy(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a-d|0;c[240591]=e>>>24;c[240592]=e;f=((e|d)&(a^-8388608)|e&d)>>>23;c[240594]=f;c[240590]=f;c[240593]=((e^a)&(d^a))>>>24;c[b>>2]=e;return}function avz(){var a=0,b=0;a=c[240587]|0;b=962260+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-1-((a>>>9)+7&7);return}function avA(){var b=0,f=0,g=0,h=0,i=0,j=0;b=c[240587]|0;f=((b>>>9)+7&7)+1|0;g=c[962260+((b&7|8)<<2)>>2]|0;b=c[240581]|0;c[240581]=b+2;h=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;b=c[962260+(h>>>12<<2)>>2]|0;if((h&2048|0)==0){i=b<<16>>16}else{i=b}b=(h<<24>>24)+g+i|0;i=b>>>16&255;g=c[957124+(i*20|0)>>2]|0;if((g|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(b&65535^1)|0]|0}else{j=fl[g&255](b&16777215)|0}g=j-f|0;c[240591]=g;h=g&255;c[240592]=h;c[240594]=g;c[240590]=g;c[240593]=(g^j)&(j^f);f=c[957132+(i*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(b&65535^1)|0]=g&255;return}else{fj[f&511](b&16777215,h);return}}function avB(){var e=0,f=0,g=0,h=0,i=0,j=0;e=(((c[240587]|0)>>>9)+7&7)+1|0;f=c[240581]|0;c[240581]=f+2;g=b[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=g>>>16&255;h=c[957124+(f*20|0)>>2]|0;if((h|0)==0){i=d[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]|0}else{i=fl[h&255](g&16777215)|0}h=i-e|0;c[240591]=h;j=h&255;c[240592]=j;c[240594]=h;c[240590]=h;c[240593]=(h^i)&(i^e);e=c[957132+(f*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(g&65535^1)|0]=h&255;return}else{fj[e&511](g&16777215,j);return}}function avC(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(((c[240587]|0)>>>9)+7&7)+1|0;f=c[240581]|0;c[240581]=f+4;g=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;h=f+2|0;f=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;h=f|g<<16;i=g&255;g=c[957124+(i*20|0)>>2]|0;if((g|0)==0){j=d[(c[957120+(i*20|0)>>2]|0)+(f^1)|0]|0}else{j=fl[g&255](h&16777215)|0}g=j-b|0;c[240591]=g;k=g&255;c[240592]=k;c[240594]=g;c[240590]=g;c[240593]=(g^j)&(j^b);b=c[957132+(i*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(i*20|0)>>2]|0)+(f^1)|0]=g&255;return}else{fj[b&511](h&16777215,k);return}}function avD(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=f>>>16&255;g=c[957128+(a*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h-d|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^d))>>>8;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[d&511](f&16777215,j);return}}function avE(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=962260+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+2;f=a>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h-d|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^d))>>>8;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[d&511](a&16777215,j);return}}function avF(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=962260+((a&7|8)<<2)|0;a=(c[f>>2]|0)-2|0;c[f>>2]=a;f=a>>>16&255;g=c[957128+(f*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0}else{h=fl[g&255](a&16777215)|0}g=h-d|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^d))>>>8;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=g&65535;return}else{fj[d&511](a&16777215,j);return}}function avG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=c[957128+(f*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0}else{h=fl[a&255](g&16777215)|0}a=h-d|0;i=a>>>8;c[240591]=i;j=a&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((a^h)&(h^d))>>>8;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=a&65535;return}else{fj[d&511](g&16777215,j);return}}function avH(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=a>>>16&255;f=c[957128+(h*20|0)>>2]|0;if((f|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]|0}else{i=fl[f&255](a&16777215)|0}f=i-d|0;g=f>>>8;c[240591]=g;j=f&65535;c[240592]=j;c[240594]=g;c[240590]=g;c[240593]=((f^i)&(i^d))>>>8;d=c[957136+(h*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]=f&65535;return}else{fj[d&511](a&16777215,j);return}}function avI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=(((c[240587]|0)>>>9)+7&7)+1|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=c[957128+(d*20|0)>>2]|0;if((g|0)==0){h=e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]|0}else{h=fl[g&255](f&16777215)|0}g=h-a|0;i=g>>>8;c[240591]=i;j=g&65535;c[240592]=j;c[240594]=i;c[240590]=i;c[240593]=((g^h)&(h^a))>>>8;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=g&65535;return}else{fj[a&511](f&16777215,j);return}}function avJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=(((c[240587]|0)>>>9)+7&7)+1|0;d=c[240581]|0;c[240581]=d+4;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;h=f&255;f=c[957128+(h*20|0)>>2]|0;if((f|0)==0){i=e[(c[957120+(h*20|0)>>2]|0)+d>>1]|0}else{i=fl[f&255](g&16777215)|0}f=i-a|0;j=f>>>8;c[240591]=j;k=f&65535;c[240592]=k;c[240594]=j;c[240590]=j;c[240593]=((f^i)&(i^a))>>>8;a=c[957136+(h*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(h*20|0)>>2]|0)+d>>1]=f&65535;return}else{fj[a&511](g&16777215,k);return}}function avK(){var a=0;a=962260+((c[240587]&7)<<2)|0;c[a>>2]=c[a>>2]&-256;return}function avL(){var a=0,d=0,e=0,f=0;a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;c[240562]=0;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){f=(c[240563]|0)+8|0;c[240563]=f;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;f=(c[240563]|0)-8|0;c[240563]=f;return}}function avM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=f>>>16&255;g=957128+(a*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0)<<16}else{i=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](f+2&16777215)|0|i}i=j-d|0;c[240591]=i>>>24;c[240592]=i;g=((i|d)&(j^-8388608)|i&d)>>>23;c[240594]=g;c[240590]=g;c[240593]=((i^j)&(j^d))>>>24;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[d&511](f&16777215,i>>>16)}d=f+2|0;f=d>>>16&255;a=c[957136+(f*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[a&511](d&16777215,i&65535);return}}function avN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=962260+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+4;f=a>>>16&255;g=957128+(f*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{i=(fl[h&255](a&16777215)|0)<<16;j=fl[c[g>>2]&255](a+2&16777215)|0|i}i=j-d|0;c[240591]=i>>>24;c[240592]=i;g=((i|d)&(j^-8388608)|i&d)>>>23;c[240594]=g;c[240590]=g;c[240593]=((i^j)&(j^d))>>>24;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[d&511](a&16777215,i>>>16)}d=a+2|0;a=d>>>16&255;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[f&511](d&16777215,i&65535);return}}function avO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=962260+((a&7|8)<<2)|0;a=c[f>>2]|0;g=a-4|0;c[f>>2]=g;f=g>>>16&255;h=957128+(f*20|0)|0;i=c[h>>2]|0;if((i|0)==0){j=a-2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]|0)<<16}else{j=(fl[i&255](g&16777215)|0)<<16;k=fl[c[h>>2]&255](a+16777214&16777215)|0|j}j=k-d|0;c[240591]=j>>>24;c[240592]=j;h=((j|d)&(k^-8388608)|j&d)>>>23;c[240594]=h;c[240590]=h;c[240593]=((j^k)&(k^d))>>>24;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=j>>>16&65535}else{fj[d&511](g&16777215,j>>>16)}g=a-2|0;a=g>>>16&255;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(g&65535)>>1]=j&65535;return}else{fj[d&511](g&16777215,j&65535);return}}function avP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=(b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0)+f|0;f=g>>>16&255;a=957128+(f*20|0)|0;h=c[a>>2]|0;if((h|0)==0){i=g+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]<<16}else{i=(fl[h&255](g&16777215)|0)<<16;j=fl[c[a>>2]&255](g+2&16777215)|0|i}i=j-d|0;c[240591]=i>>>24;c[240592]=i;a=((i|d)&(j^-8388608)|i&d)>>>23;c[240594]=a;c[240590]=a;c[240593]=((i^j)&(j^d))>>>24;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(g&65535)>>1]=i>>>16&65535}else{fj[d&511](g&16777215,i>>>16)}d=g+2|0;g=d>>>16&255;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[f&511](d&16777215,i&65535);return}}function avQ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;d=((a>>>9)+7&7)+1|0;f=c[962260+((a&7|8)<<2)>>2]|0;a=c[240581]|0;c[240581]=a+2;g=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=c[962260+(g>>>12<<2)>>2]|0;if((g&2048|0)==0){h=a<<16>>16}else{h=a}a=(g<<24>>24)+f+h|0;h=a>>>16&255;f=957128+(h*20|0)|0;g=c[f>>2]|0;if((g|0)==0){i=a+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]|0)<<16}else{i=(fl[g&255](a&16777215)|0)<<16;j=fl[c[f>>2]&255](a+2&16777215)|0|i}i=j-d|0;c[240591]=i>>>24;c[240592]=i;f=((i|d)&(j^-8388608)|i&d)>>>23;c[240594]=f;c[240590]=f;c[240593]=((i^j)&(j^d))>>>24;d=c[957136+(h*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(h*20|0)>>2]|0)+(a&65535)>>1]=i>>>16&65535}else{fj[d&511](a&16777215,i>>>16)}d=a+2|0;a=d>>>16&255;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=i&65535;return}else{fj[h&511](d&16777215,i&65535);return}}function avR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=(((c[240587]|0)>>>9)+7&7)+1|0;d=c[240581]|0;c[240581]=d+2;f=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=f>>>16&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=f+2|0;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|e[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]<<16}else{i=(fl[h&255](f&16777215)|0)<<16;j=fl[c[g>>2]&255](f+2&16777215)|0|i}i=j-a|0;c[240591]=i>>>24;c[240592]=i;g=((i|a)&(j^-8388608)|i&a)>>>23;c[240594]=g;c[240590]=g;c[240593]=((i^j)&(j^a))>>>24;a=c[957136+(d*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(f&65535)>>1]=i>>>16&65535}else{fj[a&511](f&16777215,i>>>16)}a=f+2|0;f=a>>>16&255;d=c[957136+(f*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(f*20|0)>>2]|0)+(a&65535)>>1]=i&65535;return}else{fj[d&511](a&16777215,i&65535);return}}function avS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=(((c[240587]|0)>>>9)+7&7)+1|0;d=c[240581]|0;c[240581]=d+4;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;g=d+2|0;d=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;g=d|f<<16;h=f&255;f=957128+(h*20|0)|0;i=c[f>>2]|0;if((i|0)==0){j=g+2|0;k=e[(c[957120+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0|(e[(c[957120+(h*20|0)>>2]|0)+d>>1]|0)<<16}else{j=(fl[i&255](g&16777215)|0)<<16;k=fl[c[f>>2]&255](g+2&16777215)|0|j}j=k-a|0;c[240591]=j>>>24;c[240592]=j;f=((j|a)&(k^-8388608)|j&a)>>>23;c[240594]=f;c[240590]=f;c[240593]=((j^k)&(k^a))>>>24;a=c[957136+(h*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(h*20|0)>>2]|0)+d>>1]=j>>>16&65535}else{fj[a&511](g&16777215,j>>>16)}a=g+2|0;g=a>>>16&255;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(a&65535)>>1]=j&65535;return}else{fj[d&511](a&16777215,j&65535);return}}function avT(){var b=0,d=0,e=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=b>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;return}else{fj[e&511](b&16777215,0);return}}function avU(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if((c[240594]&256|0)==0&(c[240592]|0)!=0){c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}else{c[a>>2]=b&-256;return}}function avV(){var a=0,d=0,e=0;if((c[240594]&256|0)==0&(c[240592]|0)!=0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function avW(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if((c[240594]&256|0)==0&(c[240592]|0)!=0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}}function avX(){var a=0,d=0,e=0;if(!((c[240594]&256|0)==0&(c[240592]|0)!=0)){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function avY(){var b=0,d=0,e=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=d>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=0;return}else{fj[e&511](d&16777215,0);return}}function avZ(){var b=0,d=0,e=0;b=c[240580]|0;c[240580]=b+2;d=b>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;return}else{fj[e&511](b&16777215,0);return}}function av_(){var b=0,d=0,e=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=d>>>16&255;e=c[957132+(b*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=0;return}else{fj[e&511](d&16777215,0);return}}function av$(){var b=0,d=0,e=0;b=(c[240580]|0)-2|0;c[240580]=b;d=b>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(b&65535^1)|0]=0;return}else{fj[e&511](b&16777215,0);return}}function av0(){var d=0,e=0,f=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=f>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(f&65535^1)|0]=0;return}else{fj[e&511](f&16777215,0);return}}function av1(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=d>>>16&255;b=c[957132+(g*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(d&65535^1)|0]=0;return}else{fj[b&511](d&16777215,0);return}}function av2(){var d=0,e=0,f=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=e>>>16&255;f=c[957132+(d*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(e&65535^1)|0]=0;return}else{fj[f&511](e&16777215,0);return}}function av3(){var b=0,d=0,f=0,g=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=d&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b^1)|0]=0;return}else{fj[g&511](b|d<<16&16711680,0);return}}function av4(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;if((c[240594]&256|0)==0){d=(c[240592]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function av5(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if((c[240594]&256|0)==0){e=(c[240592]|0)!=0?255:0}else{e=0}b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function av6(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;if((c[240594]&256|0)==0){d=(c[240592]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function av7(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if((c[240594]&256|0)==0){e=(c[240592]|0)!=0?255:0}else{e=0}b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function av8(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;if((c[240594]&256|0)==0){d=(c[240592]|0)!=0?255:0}else{d=0}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function av9(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;if((c[240594]&256|0)==0){g=(c[240592]|0)!=0?255:0}else{g=0}d=f>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function awa(){var b=0,d=0,f=0,g=0,h=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((c[240594]&256|0)==0){h=(c[240592]|0)!=0?255:0}else{h=0}g=d>>>16&255;b=c[957132+(g*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(d&65535^1)|0]=h&255;return}else{fj[b&511](d&16777215,h);return}}function awb(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((c[240594]&256|0)==0){f=(c[240592]|0)!=0?255:0}else{f=0}d=e>>>16&255;g=c[957132+(d*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function awc(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;if((c[240594]&256|0)==0){g=(c[240592]|0)!=0?255:0}else{g=0}f=d&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b^1)|0]=g&255;return}else{fj[h&511](b|d<<16&16711680,g);return}}function awd(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;if((c[240594]&256|0)==0){d=(c[240592]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awe(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if((c[240594]&256|0)==0){c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}else{c[a>>2]=b&-256;return}}function awf(){var a=0,d=0,e=0;if((c[240594]&256|0)==0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function awg(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if((c[240594]&256|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}}function awh(){var a=0,d=0,e=0;if((c[240594]&256|0)!=0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function awi(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if((c[240594]&256|0)==0){e=(c[240592]|0)==0?255:0}else{e=255}b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function awj(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;if((c[240594]&256|0)==0){d=(c[240592]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awk(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if((c[240594]&256|0)==0){e=(c[240592]|0)==0?255:0}else{e=255}b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=e&255;return}else{fj[f&511](d&16777215,e);return}}function awl(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;if((c[240594]&256|0)==0){d=(c[240592]|0)==0?255:0}else{d=255}e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awm(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;if((c[240594]&256|0)==0){g=(c[240592]|0)==0?255:0}else{g=255}d=f>>>16&255;e=c[957132+(d*20|0)>>2]|0;if((e|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(f&65535^1)|0]=g&255;return}else{fj[e&511](f&16777215,g);return}}function awn(){var b=0,d=0,f=0,g=0,h=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;if((c[240594]&256|0)==0){h=(c[240592]|0)==0?255:0}else{h=255}g=d>>>16&255;b=c[957132+(g*20|0)>>2]|0;if((b|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(d&65535^1)|0]=h&255;return}else{fj[b&511](d&16777215,h);return}}function awo(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;if((c[240594]&256|0)==0){f=(c[240592]|0)==0?255:0}else{f=255}d=e>>>16&255;g=c[957132+(d*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(d*20|0)>>2]|0)+(e&65535^1)|0]=f&255;return}else{fj[g&511](e&16777215,f);return}}function awp(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;if((c[240594]&256|0)==0){g=(c[240592]|0)==0?255:0}else{g=255}f=d&255;h=c[957132+(f*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(b^1)|0]=g&255;return}else{fj[h&511](b|d<<16&16711680,g);return}}function awq(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=(c[240594]&256|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awr(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[240594]&256|0)==0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function aws(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;d=(c[240594]&256|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awt(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[240594]&256|0)==0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function awu(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;d=(c[240594]&256|0)==0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awv(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[240594]&256|0)==0?255:0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}function aww(){var b=0,d=0,f=0,g=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+b+g|0;g=(c[240594]&256|0)==0?255:0;b=d>>>16&255;f=c[957132+(b*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(b*20|0)>>2]|0)+(d&65535^1)|0]=g&255;return}else{fj[f&511](d&16777215,g);return}}function awx(){var d=0,e=0,f=0,g=0;d=c[240581]|0;c[240581]=d+2;e=b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=(c[240594]&256|0)==0?255:0;f=e>>>16&255;g=c[957132+(f*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(f*20|0)>>2]|0)+(e&65535^1)|0]=d&255;return}else{fj[g&511](e&16777215,d);return}}function awy(){var b=0,d=0,f=0,g=0,h=0;b=c[240581]|0;c[240581]=b+4;d=e[(c[957120+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0;f=b+2|0;b=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=(c[240594]&256|0)==0?255:0;g=d&255;h=c[957132+(g*20|0)>>2]|0;if((h|0)==0){a[(c[957120+(g*20|0)>>2]|0)+(b^1)|0]=f&255;return}else{fj[h&511](b|d<<16&16711680,f);return}}function awz(){var b=0,d=0,e=0,f=0;b=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=(c[240594]&256|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awA(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if((c[240592]|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}}function awB(){var a=0,d=0,e=0;if((c[240592]|0)!=0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function awC(){var a=0,b=0;a=962260+((c[240587]&7)<<2)|0;b=c[a>>2]|0;if((c[240592]|0)==0){c[a>>2]=b|255;c[240563]=(c[240563]|0)+8;return}else{c[a>>2]=b&-256;return}}function awD(){var a=0,d=0,e=0;if((c[240592]|0)==0){c[240581]=(c[240581]|0)+2;return}a=962260+((c[240587]&7)<<2)|0;d=c[a>>2]|0;e=d+65535&65535;c[a>>2]=e|d&-65536;d=c[240581]|0;c[240581]=d+2;if((e|0)==65535){c[240563]=(c[240563]|0)+8;return}else{c[240581]=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+d;c[240563]=(c[240563]|0)-8;return}}function awE(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=(c[240594]&256|0)!=0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function awF(){var b=0,d=0,e=0,f=0;b=c[240580]|0;c[240580]=b+2;d=(c[240594]&256|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awG(){var b=0,d=0,e=0,f=0;b=962260+((c[240587]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=(c[240594]&256|0)!=0?255:0;e=d>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(d&65535^1)|0]=b&255;return}else{fj[f&511](d&16777215,b);return}}function awH(){var b=0,d=0,e=0,f=0;b=(c[240580]|0)-2|0;c[240580]=b;d=(c[240594]&256|0)!=0?255:0;e=b>>>16&255;f=c[957132+(e*20|0)>>2]|0;if((f|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(b&65535^1)|0]=d&255;return}else{fj[f&511](b&16777215,d);return}}function awI(){var d=0,e=0,f=0,g=0;d=c[962260+((c[240587]&7|8)<<2)>>2]|0;e=c[240581]|0;c[240581]=e+2;f=(b[(c[957120+((e>>>16&255)*20|0)>>2]|0)+(e&65535)>>1]|0)+d|0;d=(c[240594]&256|0)!=0?255:0;e=f>>>16&255;g=c[957132+(e*20|0)>>2]|0;if((g|0)==0){a[(c[957120+(e*20|0)>>2]|0)+(f&65535^1)|0]=d&255;return}else{fj[g&511](f&16777215,d);return}}
function fI(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7>>3<<3;return b|0}function fJ(){return i|0}function fK(a){a=a|0;i=a}function fL(a,b){a=a|0;b=b|0;if((s|0)==0){s=a;t=b}}function fM(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function fN(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function fO(a){a=a|0;F=a}function fP(a){a=a|0;G=a}function fQ(a){a=a|0;H=a}function fR(a){a=a|0;I=a}function fS(a){a=a|0;J=a}function fT(a){a=a|0;K=a}function fU(a){a=a|0;L=a}function fV(a){a=a|0;M=a}function fW(a){a=a|0;N=a}function fX(a){a=a|0;O=a}function fY(){}function fZ(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+20480|0;f=e|0;h=e+12288|0;e8(800,600);aIv(1717304,0,102392);j=c[494446]|0;if((j|0)!=0){aS(j|0)|0}aIv(1820736,0,158128);a[1820738]=1;a[1820737]=1;c[456218]=0;c[455185]=1;c[455186]=1;c[455187]=1;c[455188]=1;c[455189]=1;c[455190]=1;c[455191]=1;c[455192]=1;f8();j=gh(b,d)|0;if((j|0)!=0){k=j;i=e;return k|0}j=e+16384|0;d=aIp(113728)|0;b=(d|0)==0;do{if(!b){if((c[d-4>>2]&3|0)==0){break}aIv(d|0,0,113728)}}while(0);l=d;c[d+28>>2]=969352;c[d+32>>2]=640;c[d+4152>>2]=687656;m=4096;n=d+54|0;o=1815593;while(1){q=m-1|0;if((q|0)==0){r=10;break}s=a[o]|0;a[n]=s;if(s<<24>>24==0){break}else{m=q;n=n+1|0;o=o+1|0}}do{if((r|0)==10){a[n]=0;if((a[o]|0)==0){break}else{t=o}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);t=aIp(12)|0;o=(t|0)==0;do{if(!o){if((c[t-4>>2]&3|0)==0){break}aIv(t|0,0,12)}}while(0);c[d+40>>2]=t;n=aIp(12)|0;do{if((n|0)!=0){if((c[n-4>>2]&3|0)==0){break}aIv(n|0,0,12)}}while(0);c[d+44>>2]=n;if(!o){o=t+8|0;n=t+4|0;m=c[n>>2]|0;if((c[o>>2]|0)>>>0<m>>>0){u=t}else{q=(m<<1)+2|0;c[n>>2]=q;n=t;c[n>>2]=aIr(c[n>>2]|0,q*12|0)|0;u=n}n=dv(14317944)|0;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)>>2]=n;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=4;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1}c[d+48>>2]=0;iu(l);o=c[3118440]|0;do{if((o|0)==0){v=1.3333333730697632}else{if(!((c[494433]|0)==0|(c[494434]|0)==0)){v=1.3333333730697632;break}fj[c[(c[3118437]|0)+44>>2]&511](o,1977724);v=+((c[494433]|0)>>>0>>>0)/+((c[494434]|0)>>>0>>>0)}}while(0);g[172559]=v;c[240672]=l;if(b){b=c[494446]|0;l=(b|0)!=0?b:c[p>>2]|0;a5(719016,48,1,l|0)|0;l=c[494446]|0;b=(l|0)!=0?l:c[p>>2]|0;a_(b|0)|0;if((a[1977789]&1)==0){b=c[494446]|0;l=(b|0)!=0?b:c[p>>2]|0;ei(l|0,712776,(w=i,i=i+16|0,c[w>>2]=711640,c[w+8>>2]=832,w)|0)|0;i=w;l=c[494446]|0;b=(l|0)!=0?l:c[p>>2]|0;a_(b|0)|0;ch(2);return 0}else{a[1977791]=109;a[1977792]=101;a[1977793]=110;a[1977794]=117;a[1977795]=95;a[1977796]=105;a[1977797]=110;a[1977798]=105;a[1977799]=116;a[1977800]=40;a[1977801]=41;a[1977802]=0;eJ(1978816,1);return 0}}aIv(d|0,0,17);a[d+36|0]=1;c[d+113708>>2]=0;c[d+4160>>2]=726120;c[d+4164>>2]=724688;c[d+4168>>2]=723656;a[d+4173|0]=0;a[d+4172|0]=1;b=h|0;h=ck(1717420,46)|0;l=(h|0)==0?14317944:h+1|0;L44:do{if((cP(l|0,727016)|0)==0){r=32}else{if((cP(l|0,727520)|0)==0){r=32;break}do{if((cP(l|0,719736)|0)!=0){if((cP(l|0,707480)|0)==0){break}h=(a[1725621]|0)!=0?1725621:1811460;gz(b,h,724368);o=gP(b,0)|0;if((o|0)==0){gz(b,h,724280);h=gP(b,0)|0;if((h|0)==0){break L44}else{x=h}}else{x=o}o=d+4180|0;if(h6(x,o)|0){ia(o,b)}gN(x);break L44}}while(0);o=4096;h=d+4256|0;u=1717420;while(1){n=o-1|0;if((n|0)==0){r=41;break}q=a[u]|0;a[h]=q;if(q<<24>>24==0){break}else{o=n;h=h+1|0;u=u+1|0}}do{if((r|0)==41){a[h]=0;if((a[u]|0)==0){break}else{y=u}do{y=y+1|0;}while((a[y]|0)!=0)}}while(0);c[d+4252>>2]=1}}while(0);do{if((r|0)==32){y=gP(1717420,0)|0;if((y|0)==0){break}x=d+4180|0;if(h6(y,x)|0){ia(x,1717420)}gN(y)}}while(0);if((a[1841266]|0)!=0){L74:do{if((a[1790976]|0)==0){gJ(j,1841266,717072)}else{d=4096;y=j;x=1790976;while(1){l=d-1|0;if((l|0)==0){break}u=a[x]|0;a[y]=u;if(u<<24>>24==0){break L74}else{d=l;y=y+1|0;x=x+1|0}}a[y]=0;if((a[x]|0)==0){break}else{z=x}do{z=z+1|0;}while((a[z]|0)!=0)}}while(0);if((a[1820736]&1)!=0){z=c[494446]|0;x=(z|0)!=0?z:c[p>>2]|0;ei(x|0,715800,(w=i,i=i+8|0,c[w>>2]=j,w)|0)|0;i=w;x=c[494446]|0;z=(x|0)!=0?x:c[p>>2]|0;a_(z|0)|0}z=c[448768]|0;x=aIp(16)|0;do{if((x|0)==0){A=0}else{if((c[x-4>>2]&3|0)!=0){aIv(x|0,0,16)}y=x;do{if((z|0)==0){B=0}else{d=z*12|0;if(z>>>0<=65535){B=d;break}B=((d>>>0)/(z>>>0)|0|0)==12?d:-1}}while(0);d=aIp(B)|0;if((d|0)==0){c[x>>2]=0;iB(y);A=0;break}if((c[d-4>>2]&3|0)==0){l=x;c[l>>2]=d;C=l}else{aIv(d|0,0,B|0);l=x;c[l>>2]=d;C=l}l=x+8|0;c[l>>2]=z;d=f|0;u=c9(j|0,720728)|0;if((u|0)!=0){h=x+4|0;c[h>>2]=0;L104:do{if((c[l>>2]|0)!=0){o=f+4096|0;n=f+8192|0;do{a[d]=0;if((b_(d|0,4096,u|0)|0)==0){break L104}q=ck(d|0,10)|0;if((q|0)!=0){a[q]=0}a[o]=0;if((b_(o|0,4096,u|0)|0)==0){break L104}q=ck(o|0,10)|0;if((q|0)!=0){a[q]=0}a[n]=0;if((b_(n|0,4096,u|0)|0)==0){break L104}q=ck(n|0,10)|0;if((q|0)!=0){a[q]=0}q=c[h>>2]|0;t=c[C>>2]|0;if((a[o]|0)==0){break L104}if((a[n]|0)==0){break L104}if((a[d]|0)!=0){c[t+(q*12|0)>>2]=dv(d|0)|0}c[t+(q*12|0)+4>>2]=dv(o|0)|0;c[t+(q*12|0)+8>>2]=dv(n|0)|0;q=(c[h>>2]|0)+1|0;c[h>>2]=q;}while(q>>>0<(c[l>>2]|0)>>>0)}}while(0);aS(u|0)|0}c[x+12>>2]=dv(j|0)|0;A=y}}while(0);c[(c[240672]|0)+113712>>2]=A}v=+bb()*1.0e3;A=+Q(v)>=1.0?v>0.0?(ag(+P(v/4294967296.0),4294967295.0)|0)>>>0:~~+aa((v- +(~~v>>>0))/4294967296.0)>>>0:0;x=(c[240672]|0)+113720|0;c[x>>2]=~~v>>>0;c[x+4>>2]=A;A=1977776;x=c[A+4>>2]|0;C=1977776;c[C>>2]=c[A>>2]|1;c[C+4>>2]=x;do{if((a[1978861]&1)==0){L131:do{if((a[1820772]&1)==0){x=4096;C=j;A=1857650;while(1){f=x-1|0;if((f|0)==0){break}z=a[A]|0;a[C]=z;if(z<<24>>24==0){break L131}else{x=f;C=C+1|0;A=A+1|0}}a[C]=0;if((a[A]|0)==0){break}else{D=A}do{D=D+1|0;}while((a[D]|0)!=0)}else{bQ(j|0,4096,726328,(w=i,i=i+8|0,c[w>>2]=1853554,w)|0)|0;i=w}}while(0);L140:do{if((a[j]|0)!=0){y=4096;u=b;A=j;while(1){C=y-1|0;if((C|0)==0){r=99;break}x=a[A]|0;a[u]=x;if(x<<24>>24==0){break}else{y=C;u=u+1|0;A=A+1|0}}do{if((r|0)==99){a[u]=0;if((a[A]|0)==0){break}else{E=A}do{E=E+1|0;}while((a[E]|0)!=0)}}while(0);if((eH(b|0,j|0)|0)==0){F=4096;G=j;H=b}else{break}while(1){A=F-1|0;if((A|0)==0){break}u=a[H]|0;a[G]=u;if(u<<24>>24==0){break L140}else{F=A;G=G+1|0;H=H+1|0}}a[G]=0;if((a[H]|0)==0){break}else{I=H}do{I=I+1|0;}while((a[I]|0)!=0)}}while(0);A=c[(c[240672]|0)+113712>>2]|0;if((A|0)==0){break}iA(A,(a[j]|0)!=0?j:0,c[478756]|0)}}while(0);eL(9418,((a[1717392]&1)!=0?0:2147483647)|0,1);k=0;i=e;return k|0}function f_(){var b=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=i;i=i+8664|0;e=b|0;f=b+8|0;j=b+136|0;k=b+264|0;l=b+4360|0;m=b+8456|0;n=b+8464|0;o=b+8592|0;q=b+8656|0;if((a[1915088]&1)!=0){a[1915088]=0;r=c[240672]|0;if((a[r+4156|0]&1)!=0){aIq(c[r+4152>>2]|0)}s=c[r+40>>2]|0;t=s+8|0;u=s|0;v=c[u>>2]|0;if((c[t>>2]|0)==0){w=v}else{x=0;y=v;while(1){aIq(c[y+(x*12|0)>>2]|0);v=x+1|0;z=c[u>>2]|0;if(v>>>0<(c[t>>2]|0)>>>0){x=v;y=z}else{w=z;break}}}aIq(w);aIq(s);s=c[r+44>>2]|0;r=s+8|0;w=s|0;y=c[w>>2]|0;if((c[r>>2]|0)==0){A=y}else{x=0;t=y;while(1){aIq(c[t+(x*12|0)>>2]|0);y=x+1|0;u=c[w>>2]|0;if(y>>>0<(c[r>>2]|0)>>>0){x=y;t=u}else{A=u;break}}}aIq(A);aIq(s);iB(c[(c[240672]|0)+113712>>2]|0);aIq(c[240672]|0);L173:do{if(!((a[1977790]&1)==0|(a[1841266]|0)==0)){s=o|0;A=gP(1841266,0)|0;do{if((A|0)==0){t=aIp(20)|0;if((t|0)==0){break L173}if((c[t-4>>2]&3|0)==0){B=t;break}else{aIv(t|0,0,20);B=t;break}}else{B=A}}while(0);if((a[1820736]&1)!=0){A=c[494446]|0;t=(A|0)!=0?A:c[p>>2]|0;ei(t|0,728544,(C=i,i=i+8|0,c[C>>2]=1841266,C)|0)|0;i=C;t=c[494446]|0;A=(t|0)!=0?t:c[p>>2]|0;a_(A|0)|0}gS(B,696088,1795076);gS(B,692536,1799172);gS(B,694280,(a[1815556]&1)!=0?729656:698704);A=c[453891]|0;t=n|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,693816,t);gS(B,706376,1717420);gS(B,705976,(a[1721516]&1)!=0?729656:698704);D=+g[429352];bQ(t|0,128,692808,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gS(B,708520,t);D=+g[429342];bQ(t|0,128,692808,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gS(B,727504,t);D=+g[429343];bQ(t|0,128,692808,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gS(B,725536,t);gS(B,708880,(a[1717406]&1)!=0?729656:698704);gS(B,709296,(a[1717413]&1)!=0?729656:698704);gS(B,710648,(a[1717404]&1)!=0?729656:698704);D=+g[431404];bQ(t|0,128,692808,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gS(B,706816,t);gS(B,717616,(a[1717392]&1)!=0?729656:698704);gS(B,716648,(a[1717393]&1)!=0?729656:698704);A=c[429350]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,715216,t);gS(B,713576,(a[1717394]&1)!=0?729656:698704);A=c[429349]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,712248,t);A=c[429354]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,708056,t);gS(B,698248,1733900);gS(B,697712,(a[1742097]&1)!=0?729656:698704);D=+g[435525];bQ(t|0,128,692808,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gS(B,697448,t);if((a[1811460]|0)==0){gS(B,729104,699904)}else{gS(B,729104,1811460)}if((a[1890418]|0)==0){gS(B,730224,699904)}else{gS(B,730224,1890418)}if((a[1894514]|0)==0){gS(B,729760,699904)}else{gS(B,729760,1894514)}if((a[1725621]|0)==0){gS(B,700408,699904)}else{gS(B,700408,1725621)}if((a[1815593]|0)==0){gS(B,694880,699904)}else{gS(B,694880,1815593)}if((a[1898610]|0)==0){gS(B,694768,699904)}else{gS(B,694768,1898610)}gS(B,694664,1778680);D=+g[445694];bQ(t|0,128,692808,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gS(B,694528,t);D=+g[445695];bQ(t|0,128,692808,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gS(B,694384,t);gS(B,728104,(c[494438]|0)!=0?729656:698704);A=1977776;if((c[A>>2]&16384|0)==0&(c[A+4>>2]&0|0)==0){gS(B,727824,698704)}else{gS(B,727824,729656)}A=1977776;if((c[A>>2]&128|0)==0&(c[A+4>>2]&0|0)==0){gS(B,727488,698704)}else{gS(B,727488,729656)}A=1977776;if((c[A>>2]&65536|0)==0&(c[A+4>>2]&0|0)==0){gS(B,727392,698704)}else{gS(B,727392,729656)}A=1977776;if((c[A>>2]&32768|0)==0&(c[A+4>>2]&0|0)==0){gS(B,727216,698704)}else{gS(B,727216,729656)}A=d[1977756]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,726992,t);A=d[1977757]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,726800,t);A=c[494425]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,726688,t);A=c[494433]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,702024,t);A=c[494434]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,701744,t);A=c[494431]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,702504,t);A=c[494432]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,702248,t);D=+g[433454];bQ(t|0,128,692808,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gS(B,704944,t);gS(B,730392,(a[1977790]&1)!=0?729656:698704);A=c[494440]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,726576,t);A=c[478750]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,726312,t);A=a[1919865]&1;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,694584,t);A=c[494437]|0;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gS(B,725704,t);A=1977776;if((c[A>>2]&524288|0)==0&(c[A+4>>2]&0|0)==0){gS(B,725512,698704);E=0}else{gS(B,725512,729656);E=0}while(1){A=E+1|0;bQ(s|0,64,725440,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=c[1778636+(E<<2)>>2],C)|0)|0;i=C;gS(B,s,t);bQ(s|0,64,725368,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=c[1778092+(E<<2)>>2],C)|0)|0;i=C;gS(B,s,t);bQ(s|0,64,698664,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;bQ(t|0,128,706248,(C=i,i=i+8|0,c[C>>2]=c[1778060+(E<<2)>>2],C)|0)|0;i=C;gS(B,s,t);if(A>>>0<8){E=A}else{break}}gT(B,1841266)|0;gN(B)}}while(0);if((a[1977788]&1)!=0){gk()}B=c[492315]|0;if((B|0)!=0){E=B+4|0;n=c[E>>2]|0;o=B|0;if(n>>>0>1){t=1;s=n;while(1){n=c[(c[o>>2]|0)+(t<<2)>>2]|0;if((n|0)==0){G=s}else{aIq(c[n+8>>2]|0);aIq(c[(c[o>>2]|0)+(t<<2)>>2]|0);c[(c[o>>2]|0)+(t<<2)>>2]=0;G=c[E>>2]|0}n=t+1|0;if(n>>>0<G>>>0){t=n;s=G}else{break}}}c[E>>2]=1;E=B+12|0;aIq(c[E>>2]|0);c[E>>2]=0;aIq(c[o>>2]|0);aIq(B);c[492315]=0}aIv(1717304,0,102392);B=c[494446]|0;if((B|0)==0){aIv(1820736,0,158128);a[1820738]=1;a[1820737]=1;c[456218]=0;c[455185]=1;c[455186]=1;c[455187]=1;c[455188]=1;c[455189]=1;c[455190]=1;c[455191]=1;c[455192]=1;ch(0)}aS(B|0)|0;aIv(1820736,0,158128);a[1820738]=1;a[1820737]=1;c[456218]=0;c[455185]=1;c[455186]=1;c[455187]=1;c[455188]=1;c[455189]=1;c[455190]=1;c[455191]=1;c[455192]=1;ch(0)}B=1977776;o=c[B>>2]|0;E=c[B+4>>2]|0;if(a[11168]|0){if(!((o&32|0)==0&(E&0|0)==0)){B=c[240672]|0;a[B+52|0]=1;G=1977776;s=c[G+4>>2]|0;t=1977776;c[t>>2]=c[G>>2]&-33;c[t+4>>2]=s;s=B|0;B=c[s+4>>2]|0;c[s>>2]=c[s>>2]|256;c[s+4>>2]=B}f5();if((c[3118482]|0)!=0){do{if((a[12473775]&1)==0){B=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,51)|0;s=12473936;if((c[s>>2]&0|B&1|0)==0&(c[s+4>>2]&524288|0)==0){H=0;break}if((a[964040]&1)!=0){H=1;break}s=c[3118482]|0;B=s+28|0;t=c[B>>2]|0;G=s+20|0;c[G>>2]=t;n=c[s+12>>2]|0;A=s+16|0;c[A>>2]=n+(t*136|0);x=s+4|0;r=c[(c[x>>2]|0)+4>>2]|0;w=s|0;u=c[w>>2]|0;y=c[n+(t*136|0)+8>>2]|0;z=c[n+(t*136|0)+12>>2]|0;v=c[n+(t*136|0)+16>>2]|0;fE[r&15](u,y,z,v)|0;v=c[A>>2]|0;fn[c[(c[x>>2]|0)+12>>2]&7](c[w>>2]|0,+g[v+24>>2],+g[v+28>>2],+g[v+32>>2],+g[v+36>>2]);fj[c[(c[x>>2]|0)+16>>2]&511](c[w>>2]|0,(a[(c[A>>2]|0)+68|0]&1)!=0);a[s+9|0]=1;c[B>>2]=(((c[G>>2]|0)+1|0)>>>0)%((c[s+24>>2]|0)>>>0)|0;H=1}else{H=0}}while(0);a[964040]=H}if((a[12473775]&1)==0){H=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,30)|0;s=12473936;if((c[s>>2]&1073741824|H&1|0)==0&(c[s+4>>2]&0|0)==0){I=184}else{I=185}}else{I=184}do{if((I|0)==184){if(fl[c[(c[3118437]|0)+12>>2]&255](c[3118440]|0)|0){J=0;K=0;L=0}else{I=185;break}do{s=c[6168+(L<<2)>>2]|0;if((fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,6232,0,1,0,s)|0)<<16>>16==0){M=0;N=0}else{H=aIH(1,0,c[6168+((L|1)<<2)>>2]|0)|0;G=F;M=G;N=H}H=12473936;G=c[H>>2]|0;B=c[H+4>>2]|0;H=aIH(1,0,s|0)|0;s=F;if((G&H|0)==0&(B&s|0)==0){O=0;R=0}else{s=aIH(1,0,c[6168+((L|1)<<2)>>2]|0)|0;B=F;O=B;R=s}K=N|K|R;J=M|J|O;L=L+2|0;}while(L>>>0<16);if((a[12473775]&1)==0){s=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,55)|0;B=12473936;H=(c[B>>2]&0|s&1|0)!=0|(c[B+4>>2]&8388608|0)!=0;S=H?0:0;T=H?256:0}else{S=0;T=0}H=T|K;B=S|J;s=c[240672]|0;G=s|0;A=B&~c[G+4>>2];w=s+8|0;c[w>>2]=H&~c[G>>2];c[w+4>>2]=A;do{if((K&15|0)==0&(J&0|0)==0){a[s+16|0]=0;I=200}else{A=((H>>>8|B<<24)&1^1)&255;a[s+16|0]=A;if((A&1)==0){I=200;break}if(!(a[11184]|0)){a[11184]=1;c[s+20>>2]=a[11176]|0?6:12;c[s+24>>2]=0;U=1;V=0;break}A=c[s+24>>2]|0;if(A>>>0<(c[s+20>>2]|0)>>>0){U=1;V=A;break}a[11184]=0;c[w>>2]=H;c[w+4>>2]=B;U=1;V=A}}while(0);if((I|0)==200){a[11184]=0;U=0;V=c[s+24>>2]|0}a[11176]=U;c[s+24>>2]=V+1;c[G>>2]=H;c[G+4>>2]=B;w=iv(s)|0;A=c[3118488]|0;do{if((A|0)!=0){x=c[A+24>>2]|0;if((x|0)==0){break}fF[x&127](c[3118440]|0,(a[(c[240672]|0)+36|0]&1)!=0,0)}}while(0);f1();D=+bb()*1.0e3;A=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;s=(c[240672]|0)+113720|0;B=aIG(~~D>>>0,A,c[s>>2]|0,c[s+4>>2]|0)|0;s=aIN(B,F,1e3,0)|0;B=F;D=750.0/+g[431404];A=aIG(~~D>>>0,+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0,s,B)|0;B=F;s=0;if((B|0)>(s|0)|(B|0)==(s|0)&A>>>0>0>>>0){s=A;A=m;c[m>>2]=0;c[m+4>>2]=0;c[m>>2]=(s>>>0)/1e3|0;c[A+4>>2]=((s>>>0)%1e3|0)*1e6|0;dk(A|0,0)|0}D=+bb()*1.0e3;A=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;s=c[240672]|0;B=s+113720|0;c[B>>2]=~~D>>>0;c[B+4>>2]=A;A=c[3118488]|0;do{if((A|0)==0){W=s}else{B=c[A+24>>2]|0;if((B|0)==0){W=s;break}fF[B&127](c[3118440]|0,0,0);W=c[240672]|0}}while(0);s=W+8|0;do{if((c[s>>2]&256|0)==0&(c[s+4>>2]&0|0)==0){X=0}else{if((a[1977788]&1)==0){X=0;break}if((a[1978861]&1)!=0){X=0;break}A=1977776;B=c[A+4>>2]|0;G=1977776;c[G>>2]=c[A>>2]|65;c[G+4>>2]=B;X=-1}}while(0);s=1977776;B=c[s>>2]|0;G=c[s+4>>2]|0;if(!((B&64|0)==0&(G&0|0)==0)){s=1977776;c[s>>2]=B&-65;c[s+4>>2]=G|0}do{if((X|0)<0){G=c[W+40>>2]|0;s=c[G+8>>2]|0;if((s|0)==0){Y=0;Z=W;_=G;$=0}else{B=c[(c[G>>2]|0)+((s-1|0)*12|0)+4>>2]|0;if((B|0)==4){break}else{Y=B;Z=W;_=G;$=s}}while(1){s=Z+48|0;G=_+8|0;if(($|0)!=0){B=$-1|0;c[G>>2]=B;aIq(c[(c[_>>2]|0)+(B*12|0)>>2]|0)}if((s|0)!=0){c[s>>2]=c[(c[_>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]}G=c[240672]|0;s=c[G+40>>2]|0;B=c[s+8>>2]|0;if((B|0)==0){ab=Y}else{ab=c[(c[s>>2]|0)+((B-1|0)*12|0)+4>>2]|0}if((ab|0)==4){break}else{Y=ab;Z=G;_=s;$=B}}}}while(0);if((X|w|0)!=0){break}i=b;return}}while(0);if((I|0)==185){X=1977776;$=c[X+4>>2]|0;_=1977776;c[_>>2]=c[X>>2]|1;c[_+4>>2]=$}a[11168]=0;$=(a[12473776]&1)!=0;_=c[3118440]|0;if((a[1820738]&1)!=0&(_|0)!=0){if((a[1717392]&1)==0){I=229}else{if((a[1915101]&1)==0){ac=$}else{I=229}}if((I|0)==229){ac=1}fj[c[(c[3118437]|0)+8>>2]&511](_,ac)}ac=c[3118439]|0;if((a[1820737]&1)!=0&(ac|0)!=0){fj[c[(c[3118436]|0)+16>>2]&511](ac,(a[1738e3]&1)==0|$);ad=c[3118439]|0}else{ad=ac}c[479960]=$?c[479961]|0:c[479962]|0;do{if((ad|0)!=0){if(fl[c[(c[3118436]|0)+12>>2]&255](ad)|0){break}$=c[494446]|0;ac=($|0)!=0?$:c[p>>2]|0;a5(691744,81,1,ac|0)|0;ac=c[494446]|0;$=(ac|0)!=0?ac:c[p>>2]|0;a_($|0)|0;a[1820737]=0}}while(0);ad=1977776;$=c[ad+4>>2]|0;ac=1977776;c[ac>>2]=c[ad>>2]&-5;c[ac+4>>2]=$;i=b;return}if((o&2|0)==0&(E&0|0)==0){if((o&1|0)==0&(E&0|0)==0){if((o&4|0)==0&(E&0|0)==0){a[1915088]=1;i=b;return}$=1977776;c[$>>2]=o|32;c[$+4>>2]=E;fj[c[(c[3118437]|0)+8>>2]&511](c[3118440]|0,0);$=c[3118439]|0;if(($|0)!=0){ac=c[(c[3118436]|0)+8>>2]|0;fl[ac&255]($)|0}a[11168]=1;i=b;return}do{if((a[1977487]&1)==0){I=295}else{if((a[1977488]&1)!=0){I=295;break}if((a[12473775]&1)==0){$=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,30)|0;ac=12473936;if(!((c[ac>>2]&1073741824|$&1|0)==0&(c[ac+4>>2]&0|0)==0)){break}}if(!(fl[c[(c[3118437]|0)+12>>2]&255](c[3118440]|0)|0)){break}gi();f5();ac=q;c[q>>2]=0;c[q+4>>2]=0;c[q>>2]=0;c[ac+4>>2]=1e7;dk(ac|0,0)|0;i=b;return}}while(0);L367:do{if((I|0)==295){if((a[12473775]&1)==0){q=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,30)|0;ac=12473936;if(!((c[ac>>2]&1073741824|q&1|0)==0&(c[ac+4>>2]&0|0)==0)){break}}if(!(fl[c[(c[3118437]|0)+12>>2]&255](c[3118440]|0)|0)){break}do{if((a[12473775]&1)==0){ac=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,55)|0;q=12473936;if((c[q>>2]&0|ac&1|0)==0&(c[q+4>>2]&8388608|0)==0){I=301;break}ae=a[684472]|0;I=303}else{I=301}}while(0);do{if((I|0)==301){if((a[1978861]&1)==0){af=0;break}w=a[684472]|0;if((w&1)==0){ae=w;I=303}else{af=0}}}while(0);do{if((I|0)==303){if((ae&1)!=0){af=1;break}w=1977776;q=c[w+4>>2]|0;ac=1977776;c[ac>>2]=c[w>>2]|4;c[ac+4>>2]=q;a[684472]=1;q=1919808;c[q>>2]=0;c[q+4>>2]=0;break L367}}while(0);a[684472]=af;if((a[1969264]&1)!=0){a[1969264]=0;break}gi();q=c[492321]|0;if((q|0)!=0){ac=cf(c[q>>2]|0)|0;c[(c[q+12>>2]|0)+(c[q+20>>2]<<2)>>2]=ac}if((c[479948]|0)!=0){D=+bb()*1.0e3;ac=~~D>>>0;q=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;do{if((a[1977487]&1)==0){w=(a[12473776]&1)!=0;$=1919808;ad=c[$>>2]|0;_=c[$+4>>2]|0;$=(ad|0)==0&(_|0)==0|w;X=1919800;Z=c[X>>2]|0;ab=c[X+4>>2]|0;X=aIG(ac,q,ad,_)|0;_=$?Z:X;X=$?ab:F;if(w){ah=X;ai=_;aj=0;ak=0;break}if((a[1977489]&1)==0){ah=X;ai=_;aj=q;ak=ac;break}D=(+(_>>>0)+ +(X|0)*4294967296.0)/+g[453892];ah=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;ai=~~D>>>0;aj=q;ak=ac}else{X=1919800;ah=c[X+4>>2]|0;ai=c[X>>2]|0;aj=0;ak=0}}while(0);ac=1919808;c[ac>>2]=ak;c[ac+4>>2]=aj;fj[c[479948]&511](ai,ah)}fG[c[241034]&16383]();do{if(+g[453893]>=0.0){D=+bb()*1.0e3;ac=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;q=1915016;X=1915008;_=c[X>>2]|0;w=c[X+4>>2]|0;X=aIG(c[q>>2]|0,c[q+4>>2]|0,~~D>>>0,ac)|0;ac=aIF(X,F,_,w)|0;w=F;_=0;if((w|0)>(_|0)|(w|0)==(_|0)&ac>>>0>999>>>0){_=aIN(ac,w,1e3,0)|0;w=_;_=e;c[e>>2]=0;c[e+4>>2]=0;c[e>>2]=(w>>>0)/1e3|0;c[_+4>>2]=((w>>>0)%1e3|0)*1e6|0;dk(_|0,0)|0;_=1915008;w=1915016;ac=aIF(c[w>>2]|0,c[w+4>>2]|0,c[_>>2]|0,c[_+4>>2]|0)|0;_=1915016;c[_>>2]=ac;c[_+4>>2]=F;break}else{D=+bb()*1.0e3;_=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;ac=1915016;c[ac>>2]=~~D>>>0;c[ac+4>>2]=_;break}}}while(0);_=c[492321]|0;if((_|0)==0){i=b;return}ac=_+20|0;c[ac>>2]=(c[ac>>2]|0)+1&c[_+16>>2];ac=_+33|0;a[_+32|0]=a[ac]&1^1;a[ac]=0;i=b;return}}while(0);e=1977776;ah=c[e+4>>2]|0;ai=1977776;c[ai>>2]=c[e>>2]&-2;c[ai+4>>2]=ah;i=b;return}ah=k|0;k=l|0;L411:do{if((a[1857650]|0)==0){l=c[240672]|0;if((a[l+4176|0]&1)==0){al=l}else{I=248}}else{if((o&128|0)==0&(E&0|0)==0){I=248;break}gH(ah,1857650,4096);bQ(k|0,4096,724816,(C=i,i=i+8|0,c[C>>2]=ah,C)|0)|0;i=C;l=c[492315]|0;ai=l+4|0;if((c[ai>>2]|0)>>>0>=(c[l+8>>2]|0)>>>0){I=248;break}e=aIp(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}aIv(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=1;aj=dv(k|0)|0;ak=c[ai>>2]|0;c[e+8>>2]=aj;aj=l|0;c[(c[aj>>2]|0)+(ak<<2)>>2]=e;ak=c[ai>>2]|0;c[ai>>2]=ak+1;if(ak>>>0>1){am=ak}else{I=248;break}while(1){ak=am>>>1;af=c[aj>>2]|0;ae=af+(ak<<2)|0;ac=c[ae>>2]|0;_=c[af+(am<<2)>>2]|0;if((c[_+4>>2]|0)>>>0<=(c[ac+4>>2]|0)>>>0){I=248;break L411}c[ae>>2]=_;c[(c[aj>>2]|0)+(am<<2)>>2]=ac;if(am>>>0>3){am=ak}else{I=248;break}}}}while(0);do{if((I|0)==248){am=c[240672]|0;E=c[am+4160>>2]|0;o=c[am+113712>>2]|0;if((o|0)==0){al=am;break}iA(o,(a[1857650]|0)!=0?1857650:0,(E|0)==0?14317944:E);al=c[240672]|0}}while(0);aIv(al|0,0,17);a[al+53|0]=1;iv(al)|0;al=c[3118488]|0;do{if((al|0)!=0){I=c[al+24>>2]|0;if((I|0)==0){break}fF[I&127](c[3118440]|0,(a[(c[240672]|0)+36|0]&1)!=0,0)}}while(0);if((c[3118437]|0)!=0){f1()}al=c[3118488]|0;do{if((al|0)!=0){I=c[al+24>>2]|0;if((I|0)==0){break}fF[I&127](c[3118440]|0,0,0)}}while(0);if((a[1977788]&1)!=0){gk()}al=a[1820736]&1;I=(a[1841266]|0)!=0;E=I?1841266:0;o=(a[1890418]|0)!=0;am=o?1890418:0;aj=(a[1894514]|0)!=0;ai=aj?1894514:0;e=(a[1857650]|0)!=0;l=e?1857650:0;ak=(c[240672]|0)+4176|0;ac=a[ak]&1;a[ak]=0;ak=f;_=j;if((a[1977788]&1)!=0){gk()}aIv(ak|0,0,128);ae=f|0;c[ae>>2]=dv(701672)|0;do{if(ac<<24>>24==0){af=(a[1820736]&1)!=0;if(e){if(af){w=c[494446]|0;X=(w|0)!=0?w:c[p>>2]|0;ei(X|0,701360,(C=i,i=i+8|0,c[C>>2]=l,C)|0)|0;i=C;X=c[494446]|0;w=(X|0)!=0?X:c[p>>2]|0;a_(w|0)|0}c[f+4>>2]=dv(l|0)|0;an=2;break}else{if(af){af=c[494446]|0;w=(af|0)!=0?af:c[p>>2]|0;a5(701144,40,1,w|0)|0;w=c[494446]|0;af=(w|0)!=0?w:c[p>>2]|0;a_(af|0)|0}c[f+4>>2]=dv(700880)|0;an=2;break}}else{an=1}}while(0);if(o){c[f+(an<<2)>>2]=dv(700744)|0;c[f+(an+1<<2)>>2]=dv(am|0)|0;ao=an+2|0}else{ao=an}if(aj){c[f+(ao<<2)>>2]=dv(700376)|0;c[f+(ao+1<<2)>>2]=dv(ai|0)|0;ap=ao+2|0}else{ap=ao}if(I){c[f+(ap<<2)>>2]=dv(699664)|0;c[f+(ap+1<<2)>>2]=dv(E|0)|0;aq=ap+2|0}else{aq=ap}if(al<<24>>24==0){ar=aq}else{c[f+(aq<<2)>>2]=dv(699232)|0;ar=aq+1|0}aIy(_|0,ak|0,128)|0;ak=gh(ar,ae)|0;ae=0;do{aIq(c[j+(ae<<2)>>2]|0);ae=ae+1|0;}while(ae>>>0<32);if((ak|0)==0){if((a[1820736]&1)!=0){ak=c[494446]|0;ae=(ak|0)!=0?ak:c[p>>2]|0;a5(722472,45,1,ae|0)|0;ae=c[494446]|0;ak=(ae|0)!=0?ae:c[p>>2]|0;a_(ak|0)|0}ak=1977776;ae=c[ak+4>>2]|0|0;j=1977776;c[j>>2]=c[ak>>2]&-4|1;c[j+4>>2]=ae;i=b;return}gH(ah,1857650,4096);bQ(k|0,4096,721072,(C=i,i=i+8|0,c[C>>2]=ah,C)|0)|0;i=C;C=c[492315]|0;ah=C+4|0;L478:do{if((c[ah>>2]|0)>>>0<(c[C+8>>2]|0)>>>0){ae=aIp(12)|0;do{if((ae|0)!=0){if((c[ae-4>>2]&3|0)==0){break}aIv(ae|0,0,12)}}while(0);c[ae+4>>2]=1;c[ae>>2]=90;j=dv(k|0)|0;ak=c[ah>>2]|0;c[ae+8>>2]=j;j=C|0;c[(c[j>>2]|0)+(ak<<2)>>2]=ae;ak=c[ah>>2]|0;c[ah>>2]=ak+1;if(ak>>>0>1){as=ak}else{break}while(1){ak=as>>>1;ar=c[j>>2]|0;_=ar+(ak<<2)|0;aq=c[_>>2]|0;f=c[ar+(as<<2)>>2]|0;if((c[f+4>>2]|0)>>>0<=(c[aq+4>>2]|0)>>>0){break L478}c[_>>2]=f;c[(c[j>>2]|0)+(as<<2)>>2]=aq;if(as>>>0>3){as=ak}else{break}}}}while(0);a[(c[240672]|0)+53|0]=1;as=c[494446]|0;a5(720024,52,1,((as|0)!=0?as:c[p>>2]|0)|0)|0;as=c[494446]|0;a_(((as|0)!=0?as:c[p>>2]|0)|0)|0;i=b;return}function f$(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=d<<1;if((e|0)==0){return d|0}else{f=0}do{g=b[a+(f<<1)>>1]|0;h=(c[479970]|0)-1|0;c[479970]=h;b[(c[479969]|0)+(h<<1)>>1]=g;f=f+1|0;}while(f>>>0<e>>>0);return d|0}function f0(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=i;i=i+24|0;d=b|0;if((a[1807364]|0)==0){i=b;return}do{if((a[1733847]&1)!=0|(c[479937]|0)!=0){e=c[3118437]|0;if((c[e+48>>2]|0)==0){f=360;break}g=e+44|0;if((c[g>>2]|0)==0){f=360;break}aIv(d|0,0,24);fj[c[g>>2]&511](c[3118440]|0,d);g=d+8|0;e=c[g>>2]|0;if((e|0)==0){f=365;break}h=d+12|0;j=c[h>>2]|0;if((j|0)==0){f=365;break}k=aIp(ab(e*3|0,j)|0)|0;if((k|0)==0){f=365;break}if(fA[c[(c[3118437]|0)+48>>2]&63](c[3118440]|0,k)|0){j=c[g>>2]|0;g=hE(k,j,c[h>>2]|0,j*3|0,1)|0;aIq(k);if(g){f=363;break}else{f=365;break}}else{aIq(k);f=365;break}}else{f=360}}while(0);do{if((f|0)==360){d=c[494382]|0;k=d;if((k|0)==(-1|0)|(k|0)==0){k=c[494446]|0;g=(k|0)!=0?k:c[p>>2]|0;a5(731248,103,1,g|0)|0;g=c[494446]|0;k=(g|0)!=0?g:c[p>>2]|0;a_(k|0)|0;f=365;break}else{k=c[494383]|0;g=c[494384]|0;j=c[494385]|0;if(hE(d+(ab(g-1|0,j)|0)|0,k,g,-j|0,0)|0){f=363;break}else{f=365;break}}}}while(0);do{if((f|0)==363){if((a[1820736]&1)==0){l=717336;break}j=c[494446]|0;g=(j|0)!=0?j:c[p>>2]|0;a5(726648,30,1,g|0)|0;g=c[494446]|0;j=(g|0)!=0?g:c[p>>2]|0;a_(j|0)|0;l=717336}else if((f|0)==365){j=c[494446]|0;a5(708464,50,1,((j|0)!=0?j:c[p>>2]|0)|0)|0;j=c[494446]|0;a_(((j|0)!=0?j:c[p>>2]|0)|0)|0;l=704144}}while(0);j=c[492315]|0;g=j+4|0;k=c[g>>2]|0;if(k>>>0>1){d=j|0;h=1;e=k;while(1){k=c[(c[d>>2]|0)+(h<<2)>>2]|0;if((k|0)==0){m=e}else{aIq(c[k+8>>2]|0);aIq(c[(c[d>>2]|0)+(h<<2)>>2]|0);c[(c[d>>2]|0)+(h<<2)>>2]=0;m=c[g>>2]|0}k=h+1|0;if(k>>>0<m>>>0){h=k;e=m}else{break}}}c[g>>2]=1;g=j+12|0;aIq(c[g>>2]|0);c[g>>2]=0;g=c[492315]|0;j=g+4|0;m=(c[j>>2]|0)>>>0<(c[g+8>>2]|0)>>>0;if((a[1977487]&1)!=0){L529:do{if(m){e=aIp(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}aIv(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=1;h=dv(l|0)|0;d=c[j>>2]|0;c[e+8>>2]=h;h=g|0;c[(c[h>>2]|0)+(d<<2)>>2]=e;d=c[j>>2]|0;c[j>>2]=d+1;if(d>>>0>1){n=d}else{break}while(1){d=n>>>1;k=c[h>>2]|0;o=k+(d<<2)|0;q=c[o>>2]|0;r=c[k+(n<<2)>>2]|0;if((c[r+4>>2]|0)>>>0<=(c[q+4>>2]|0)>>>0){break L529}c[o>>2]=r;c[(c[h>>2]|0)+(n<<2)>>2]=q;if(n>>>0>3){n=d}else{break}}}}while(0);f1();i=b;return}if(!m){i=b;return}m=aIp(12)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}aIv(m|0,0,12)}}while(0);c[m+4>>2]=1;c[m>>2]=180;n=dv(l|0)|0;l=c[j>>2]|0;c[m+8>>2]=n;n=g|0;c[(c[n>>2]|0)+(l<<2)>>2]=m;m=c[j>>2]|0;c[j>>2]=m+1;if(m>>>0>1){s=m}else{i=b;return}while(1){m=s>>>1;j=c[n>>2]|0;l=j+(m<<2)|0;g=c[l>>2]|0;h=c[j+(s<<2)>>2]|0;if((c[h+4>>2]|0)>>>0<=(c[g+4>>2]|0)>>>0){f=389;break}c[l>>2]=h;c[(c[n>>2]|0)+(s<<2)>>2]=g;if(s>>>0>3){s=m}else{f=390;break}}if((f|0)==389){i=b;return}else if((f|0)==390){i=b;return}}function f1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[494382]|0;d=(b|0)==-1?0:b;b=c[494383]|0;e=c[494384]|0;f=c[494385]|0;if((a[1820738]&1)==0){return}c[494382]=d;c[494383]=b;c[494384]=e;c[494385]=f;do{if((c[478774]|0)==0){g=d;if((g|0)==(-1|0)|(g|0)==0){h=d;i=f;break}c[3118448]=b;c[3118449]=e;c[3118451]=b;c[3118452]=e;c[3118450]=f;c[3118453]=b<<1;h1(12473792,c[3118480]|0,d);h=c[3118480]|0;i=c[3118453]|0}else{h=d;i=f}}while(0);f=hk(c[492315]|0)|0;c[3118489]=f;if(fk[c[(c[3118437]|0)+4>>2]&15](c[3118440]|0,h,b,e,i,f)|0){return}a[1820738]=0;return}function f2(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[1820738]&1)==0){return}c[494382]=b;c[494383]=d;c[494384]=e;c[494385]=f;do{if((c[478774]|0)==0){g=b;if((g|0)==(-1|0)|(g|0)==0){h=b;i=f;break}c[3118448]=d;c[3118449]=e;c[3118451]=d;c[3118452]=e;c[3118450]=f;c[3118453]=d<<1;h1(12473792,c[3118480]|0,b);h=c[3118480]|0;i=c[3118453]|0}else{h=b;i=f}}while(0);f=hk(c[492315]|0)|0;c[3118489]=f;if(fk[c[(c[3118437]|0)+4>>2]&15](c[3118440]|0,h,d,e,i,f)|0){return}a[1820738]=0;return}function f3(b,c){b=b|0;c=c|0;var d=0,e=0;d=c>>>0>1024?1024:c;if(f4(b,d<<1)|0){e=a[1820737]&1}else{e=0}a[1820737]=e;return d|0}function f4(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0.0,n=0,o=0,q=0.0,r=0,s=0;f=i;i=i+24|0;j=f|0;if((a[1977487]&1)!=0){k=1;i=f;return k|0}if((a[1919865]&1)!=0){k=1;i=f;return k|0}if((a[1820737]&1)==0){k=0;i=f;return k|0}aIv(j|0,0,24);l=c[479958]|0;m=+g[479980]*30517578125.0e-15;if((e|0)==0){n=l}else{o=0;do{g[l+(o<<2)>>2]=m*+(b[d+(o<<1)>>1]|0);o=o+1|0;}while(o>>>0<e>>>0);n=c[479958]|0}c[j>>2]=n;c[j+8>>2]=e>>>1;c[j+4>>2]=c[479967];if((a[1919900]&1)==0){q=+h[239982]}else{e=fl[c[(c[3118436]|0)+32>>2]&255](c[3118439]|0)|0;n=1952696;o=c[n>>2]|0;d=aIF(o,c[n+4>>2]|0,1,0)|0;n=1952696;c[n>>2]=d;c[n+4>>2]=F;c[1919928+((o&8191)<<2)>>2]=e;o=(c[479978]|0)>>>1;m=+h[239988]*(+(e-o|0)/+(o|0)*+g[435525]+1.0);h[239982]=m;q=m}o=j+16|0;h[o>>3]=q;if((a[1977489]&1)!=0){h[o>>3]=q*+g[453892]}fj[c[(c[479957]|0)+4>>2]&511](c[479956]|0,j);o=c[479967]|0;e=c[j+12>>2]|0;if((a[1919864]&1)!=0){if((fp[c[(c[3118436]|0)+4>>2]&63](c[3118439]|0,o,e<<3)|0)>=0){k=1;i=f;return k|0}j=c[494446]|0;n=(j|0)!=0?j:c[p>>2]|0;a5(709744,81,1,n|0)|0;n=c[494446]|0;j=(n|0)!=0?n:c[p>>2]|0;a_(j|0)|0;k=0;i=f;return k|0}j=c[479968]|0;n=e<<1;if((n|0)==0){r=j}else{d=0;do{l=~~(+g[o+(d<<2)>>2]*32768.0);if((l|0)>32767){s=32767}else{s=(l|0)<-32768?-32768:l&65535}b[j+(d<<1)>>1]=s;d=d+1|0;}while(d>>>0<n>>>0);r=c[479968]|0}if((fp[c[(c[3118436]|0)+4>>2]&63](c[3118439]|0,r,e<<2)|0)>=0){k=1;i=f;return k|0}e=c[494446]|0;a5(709744,81,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[494446]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;k=0;i=f;return k|0}function f5(){var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0.0,P=0.0,R=0.0,S=0.0,T=0,U=0,V=0,W=0.0,X=0.0;d=i;i=i+16|0;e=d|0;fi[c[(c[3118438]|0)+4>>2]&255](c[3118441]|0);f=c[3118482]|0;if((f|0)==0){i=d;return}h=e;aIv(12473936,0,16);j=(a[(c[f+16>>2]|0)+68|0]&1)!=0?65542:6;if((fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,0,0,j,0,2)|0)<<16>>16==0){a[(c[3118482]|0)+9|0]=0;i=d;return}f=e|0;k=e+8|0;l=e+10|0;m=e+12|0;n=e+14|0;o=0;do{p=fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,0,0,j,o,0)|0;q=fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,0,0,j,o,1)|0;r=c[3118482]|0;aIv(h|0,0,16);L635:do{if((a[r+8|0]&1)==0){a[r+9|0]=0;s=0;t=0}else{u=c[r+16>>2]|0;v=(+((p<<16>>16)+32767|0)/65535.0- +g[u+24>>2])/+g[u+32>>2];w=(+((q<<16>>16)+32767|0)/65535.0- +g[u+28>>2])/+g[u+36>>2];x=u+4|0;y=c[x>>2]|0;do{if((y|0)==0){z=r+9|0}else{A=r+28|0;B=0;C=y;while(1){D=u|0;E=c[D>>2]|0;F=E+(B*104|0)|0;G=c[E+(B*104|0)+8>>2]|0;do{if((G|0)==0){H=+g[F>>2];I=+g[E+(B*104|0)+12>>2];J=(v-H)/I;K=+g[E+(B*104|0)+4>>2];L=+g[E+(B*104|0)+16>>2];M=(w-K)/L;if(J*J+M*M>1.0){N=C}else{O=H;P=I;R=K;S=L;T=458}}else if((G|0)==1){L=+g[F>>2];K=+Q(+(v-L));I=+g[E+(B*104|0)+12>>2];if(K>I){N=C;break}K=+g[E+(B*104|0)+4>>2];H=+Q(+(w-K));M=+g[E+(B*104|0)+16>>2];if(H>M){N=C}else{O=L;P=I;R=K;S=M;T=458}}else{N=C}}while(0);do{if((T|0)==458){T=0;F=c[E+(B*104|0)+20>>2]|0;if((F|0)==0){G=E+(B*104|0)+24|0;U=c[G>>2]|0;V=c[G+4>>2]|0;G=c[f+4>>2]|V;c[f>>2]=c[f>>2]|U;c[f+4>>2]=G;if((U&0|0)==0&(V&524288|0)==0){N=C;break}c[A>>2]=c[(c[D>>2]|0)+(B*104|0)+36>>2];N=c[x>>2]|0;break}M=+g[E+(B*104|0)+32>>2];K=(v-O)/P/M;I=(w-R)/S/M;if(+Q(+K)>1.0){W=K>0.0?1.0:-1.0}else{W=K}if(+Q(+I)>1.0){X=I>0.0?1.0:-1.0}else{X=I}V=(F|0)==2?2:0;b[e+8+(V<<1)>>1]=~~(W*32767.0);b[e+8+((V|1)<<1)>>1]=~~(X*32767.0);N=C}}while(0);E=B+1|0;if(E>>>0<N>>>0){B=E;C=N}else{break}}C=c[f>>2]|0;B=c[f+4>>2]|0;A=r+9|0;if((C|0)==0&(B|0)==0){z=A;break}if((a[A]&1)==0){s=B;t=C;break L635}aIv(h|0,0,16);s=0;t=0;break L635}}while(0);a[z]=0;s=0;t=0}}while(0);r=12473936;q=c[r+4>>2]|s;p=12473936;c[p>>2]=c[r>>2]|t;c[p+4>>2]=q;if((b[6236972]|0)==0){b[6236972]=b[k>>1]|0}if((b[6236973]|0)==0){b[6236973]=b[l>>1]|0}if((b[6236974]|0)==0){b[6236974]=b[m>>1]|0}if((b[6236975]|0)==0){b[6236975]=b[n>>1]|0}o=o+1|0;}while((fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,0,0,j,o,2)|0)<<16>>16!=0);i=d;return}function f6(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;b=i;if((a[1815556]&1)==0|(c[492317]|0)!=0){i=b;return}if((c[479929]|0)!=0){d=c[494446]|0;e=(d|0)!=0?d:c[p>>2]|0;a5(696192,76,1,e|0)|0;e=c[494446]|0;d=(e|0)!=0?e:c[p>>2]|0;a_(d|0)|0;i=b;return}d=fD[c[241030]&127]()|0;c[492319]=d;if((d|0)==0){e=c[494446]|0;f=(e|0)!=0?e:c[p>>2]|0;a5(694192,85,1,f|0)|0;f=c[494446]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0;i=b;return}e=d+3|0;f=e&-4;g=aIp(f)|0;if((g|0)==0){c[492318]=0;h=c[494446]|0;j=(h|0)!=0?h:c[p>>2]|0;a5(691928,66,1,j|0)|0;j=c[494446]|0;h=(j|0)!=0?j:c[p>>2]|0;a_(h|0)|0;i=b;return}if((c[g-4>>2]&3|0)!=0){aIv(g|0,0,f|0)}c[492318]=g;if(!(fA[c[241032]&63](g,d)|0)){d=c[494446]|0;g=(d|0)!=0?d:c[p>>2]|0;a5(731168,73,1,g|0)|0;g=c[494446]|0;d=(g|0)!=0?g:c[p>>2]|0;a_(d|0)|0;aIq(c[492318]|0);c[492318]=0;i=b;return}if((a[1820736]&1)!=0){d=c[494446]|0;g=(d|0)!=0?d:c[p>>2]|0;d=((c[453890]|0)>>>0)/1e6|0;ei(g|0,729040,(k=i,i=i+8|0,c[k>>2]=d,k)|0)|0;i=k;d=c[494446]|0;g=(d|0)!=0?d:c[p>>2]|0;a_(g|0)|0}g=c[453890]|0;d=c[492318]|0;L704:do{if(f<<2>>>0<g>>>0){h=aIp(32)|0;if((h|0)==0){l=514;break}if((c[h-4>>2]&3|0)!=0){aIv(h|0,0,32)}j=h;c[h+16>>2]=1;m=e>>>2;c[h+24>>2]=m;n=g-1|0;o=n>>>1|n;n=o>>>2|o;o=n>>>4|n;n=o>>>8|o;o=(n>>>16|n)+1|0;n=o>>>1;q=(o-g|0)>>>0<(g-n|0)>>>0?o:n;n=q>>>3;c[h+4>>2]=n;c[h+8>>2]=n-1;if((a[1820736]&1)!=0){o=c[494446]|0;r=(o|0)!=0?o:c[p>>2]|0;o=q>>>23<<3;ei(r|0,709232,(k=i,i=i+8|0,c[k>>2]=o,k)|0)|0;i=k;o=c[494446]|0;r=(o|0)!=0?o:c[p>>2]|0;a_(r|0)|0}r=n<<3;n=aIp(r)|0;do{if((n|0)==0){c[h>>2]=0;s=h+12|0}else{if((c[n-4>>2]&3|0)==0){c[h>>2]=n}else{aIv(n|0,0,r|0);c[h>>2]=n}o=m<<2;q=aIp(o)|0;if((q|0)==0){t=h+12|0;c[t>>2]=0;s=t;break}if((c[q-4>>2]&3|0)==0){c[h+12>>2]=q;aIy(q|0,d|0,f)|0;c[492317]=j;if((h|0)==0){break L704}i=b;return}else{aIv(q|0,0,o|0);c[h+12>>2]=q;aIy(q|0,d|0,f)|0;c[492317]=j;i=b;return}}}while(0);aIq(n);aIq(c[s>>2]|0);aIq(h);l=514}else{l=514}}while(0);if((l|0)==514){c[492317]=0}l=c[494446]|0;a5(725968,78,1,((l|0)!=0?l:c[p>>2]|0)|0)|0;l=c[494446]|0;a_(((l|0)!=0?l:c[p>>2]|0)|0)|0;i=b;return}function f7(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;a=i;i=i+4608|0;b=c[478750]|0;d=a|0;if((b|0)==0){bQ(d|0,4096,710232,(e=i,i=i+8|0,c[e>>2]=1882226,e)|0)|0;i=e}else{bQ(d|0,4096,725056,(e=i,i=i+16|0,c[e>>2]=1882226,c[e+8>>2]=b,e)|0)|0;i=e}b=a+4096|0;if(gr(d)|0){f=c[478750]|0;bQ(b|0,512,722672,(e=i,i=i+8|0,c[e>>2]=f,e)|0)|0;i=e}else{bQ(b|0,512,721336,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e}e=c[492315]|0;d=e+4|0;f=c[d>>2]|0;if(f>>>0>1){g=e|0;h=1;j=f;while(1){f=c[(c[g>>2]|0)+(h<<2)>>2]|0;if((f|0)==0){k=j}else{aIq(c[f+8>>2]|0);aIq(c[(c[g>>2]|0)+(h<<2)>>2]|0);c[(c[g>>2]|0)+(h<<2)>>2]=0;k=c[d>>2]|0}f=h+1|0;if(f>>>0<k>>>0){h=f;j=k}else{break}}}c[d>>2]=1;d=e+12|0;aIq(c[d>>2]|0);c[d>>2]=0;d=c[492315]|0;e=d+4|0;if((c[e>>2]|0)>>>0>=(c[d+8>>2]|0)>>>0){i=a;return}k=aIp(12)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}aIv(k|0,0,12)}}while(0);c[k+4>>2]=2;c[k>>2]=180;j=dv(b|0)|0;b=c[e>>2]|0;c[k+8>>2]=j;j=d|0;c[(c[j>>2]|0)+(b<<2)>>2]=k;k=c[e>>2]|0;c[e>>2]=k+1;if(k>>>0>1){l=k}else{i=a;return}while(1){k=l>>>1;e=c[j>>2]|0;b=e+(k<<2)|0;d=c[b>>2]|0;h=c[e+(l<<2)>>2]|0;if((c[h+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){m=547;break}c[b>>2]=h;c[(c[j>>2]|0)+(l<<2)>>2]=d;if(l>>>0>3){l=k}else{m=548;break}}if((m|0)==548){i=a;return}else if((m|0)==547){i=a;return}}function f8(){var a=0,b=0,d=0;a=i;if((c[492315]|0)!=0){i=a;return}b=aIp(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)!=0){aIv(b|0,0,16)}c[b+8>>2]=9;d=aIp(36)|0;if((d|0)==0){c[b>>2]=0;aIq(b);break}if((c[d-4>>2]&3|0)!=0){aIv(d|0,0,36)}c[b>>2]=d;c[b+4>>2]=1;c[492315]=b;i=a;return}}while(0);c[492315]=0;a=c[494446]|0;ei(((a|0)!=0?a:c[p>>2]|0)|0,712776,(a=i,i=i+16|0,c[a>>2]=698136,c[a+8>>2]=1408,a)|0)|0;i=a;a=c[494446]|0;a_(((a|0)!=0?a:c[p>>2]|0)|0)|0;ch(2)}function f9(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+4608|0;d=c[478750]|0;if((a[1815585]&1)==0){e=d}else{f=d+1|0;c[478750]=f;e=f}f=b|0;if((e|0)==0){bQ(f|0,4096,710232,(g=i,i=i+8|0,c[g>>2]=1882226,g)|0)|0;i=g}else{bQ(f|0,4096,725056,(g=i,i=i+16|0,c[g>>2]=1882226,c[g+8>>2]=e,g)|0)|0;i=g}e=b+4096|0;if(gq(f)|0){d=c[478750]|0;bQ(e|0,512,720264,(g=i,i=i+8|0,c[g>>2]=d,g)|0)|0;i=g}else{bQ(e|0,512,719296,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g}g=c[492315]|0;f=g+4|0;d=c[f>>2]|0;if(d>>>0>1){h=g|0;j=1;k=d;while(1){d=c[(c[h>>2]|0)+(j<<2)>>2]|0;if((d|0)==0){l=k}else{aIq(c[d+8>>2]|0);aIq(c[(c[h>>2]|0)+(j<<2)>>2]|0);c[(c[h>>2]|0)+(j<<2)>>2]=0;l=c[f>>2]|0}d=j+1|0;if(d>>>0<l>>>0){j=d;k=l}else{break}}}c[f>>2]=1;f=g+12|0;aIq(c[f>>2]|0);c[f>>2]=0;f=c[492315]|0;g=f+4|0;if((c[g>>2]|0)>>>0>=(c[f+8>>2]|0)>>>0){i=b;return}l=aIp(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}aIv(l|0,0,12)}}while(0);c[l+4>>2]=2;c[l>>2]=180;k=dv(e|0)|0;e=c[g>>2]|0;c[l+8>>2]=k;k=f|0;c[(c[k>>2]|0)+(e<<2)>>2]=l;l=c[g>>2]|0;c[g>>2]=l+1;if(l>>>0>1){m=l}else{i=b;return}while(1){l=m>>>1;g=c[k>>2]|0;e=g+(l<<2)|0;f=c[e>>2]|0;j=c[g+(m<<2)>>2]|0;if((c[j+4>>2]|0)>>>0<=(c[f+4>>2]|0)>>>0){n=585;break}c[e>>2]=j;c[(c[k>>2]|0)+(m<<2)>>2]=f;if(m>>>0>3){m=l}else{n=586;break}}if((n|0)==586){i=b;return}else if((n|0)==585){i=b;return}}function ga(b){b=b|0;a[1717376]=b&1;a[12473769]=a[1919776]&1;a[12473770]=0;gL();b=c[479945]|0;do{if((b|0)!=0){if((a[12473769]&1)!=0){break}fG[b&16383]()}}while(0);gM();if((a[12473771]&1)!=0){c[3118440]=0}if((a[12473772]&1)!=0){c[3118439]=0}if((a[12473773]&1)!=0){c[3118441]=0}a[12473771]=0;a[12473772]=0;a[12473773]=0;gK();a[12473769]=0;b=c[3118438]|0;if((b|0)==0){return}fi[c[b+4>>2]&255](c[3118441]|0);return}function gb(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[1820736]&1)!=0){b=c[494446]|0;d=(b|0)!=0?b:c[p>>2]|0;a5(716312,27,1,d|0)|0;d=c[494446]|0;b=(d|0)!=0?d:c[p>>2]|0;a_(b|0)|0}b=c[492315]|0;d=b+4|0;e=c[d>>2]|0;if(e>>>0>1){f=b|0;g=1;h=e;while(1){e=c[(c[f>>2]|0)+(g<<2)>>2]|0;if((e|0)==0){i=h}else{aIq(c[e+8>>2]|0);aIq(c[(c[f>>2]|0)+(g<<2)>>2]|0);c[(c[f>>2]|0)+(g<<2)>>2]=0;i=c[d>>2]|0}e=g+1|0;if(e>>>0<i>>>0){g=e;h=i}else{break}}}c[d>>2]=1;d=b+12|0;aIq(c[d>>2]|0);c[d>>2]=0;d=c[492315]|0;b=d+4|0;if((c[b>>2]|0)>>>0>=(c[d+8>>2]|0)>>>0){j=c[241036]|0;fG[j&16383]();gc();return}i=aIp(12)|0;do{if((i|0)!=0){if((c[i-4>>2]&3|0)==0){break}aIv(i|0,0,12)}}while(0);c[i+4>>2]=1;c[i>>2]=120;h=dv(714400)|0;g=c[b>>2]|0;c[i+8>>2]=h;h=d|0;c[(c[h>>2]|0)+(g<<2)>>2]=i;i=c[b>>2]|0;c[b>>2]=i+1;if(i>>>0>1){k=i}else{j=c[241036]|0;fG[j&16383]();gc();return}while(1){i=k>>>1;b=c[h>>2]|0;g=b+(i<<2)|0;d=c[g>>2]|0;f=c[b+(k<<2)>>2]|0;if((c[f+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){l=618;break}c[g>>2]=f;c[(c[h>>2]|0)+(k<<2)>>2]=d;if(k>>>0>3){k=i}else{l=619;break}}if((l|0)==619){j=c[241036]|0;fG[j&16383]();gc();return}else if((l|0)==618){j=c[241036]|0;fG[j&16383]();gc();return}}function gc(){var b=0,d=0,e=0,f=0,g=0;b=i;d=0;do{e=c[1820740+(d<<2)>>2]|0;L865:do{if((e|0)!=1){fj[c[241024]&511](d,e);switch(e|0){case 260:{if((a[1820736]&1)==0){break L865}f=c[494446]|0;ei(((f|0)!=0?f:c[p>>2]|0)|0,709928,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[494446]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L865;break};case 2:{if((a[1820736]&1)==0){break L865}f=c[494446]|0;ei(((f|0)!=0?f:c[p>>2]|0)|0,710384,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[494446]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L865;break};case 0:{if((a[1820736]&1)==0){break L865}f=c[494446]|0;ei(((f|0)!=0?f:c[p>>2]|0)|0,710480,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[494446]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L865;break};case 5:{if((a[1820736]&1)==0){break L865}f=c[494446]|0;ei(((f|0)!=0?f:c[p>>2]|0)|0,710432,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[494446]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L865;break};case 516:{if((a[1820736]&1)==0){break L865}f=c[494446]|0;ei(((f|0)!=0?f:c[p>>2]|0)|0,710328,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[494446]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L865;break};case 772:{if((a[1820736]&1)==0){break L865}f=c[494446]|0;ei(((f|0)!=0?f:c[p>>2]|0)|0,710280,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[494446]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L865;break};case 257:{if((a[1820736]&1)==0){break L865}f=c[494446]|0;ei(((f|0)!=0?f:c[p>>2]|0)|0,710096,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[494446]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L865;break};default:{break L865}}}}while(0);d=d+1|0;}while(d>>>0<8);i=b;return}function gd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+256|0;if((c[479934]|0)==0){i=e;return}f=e|0;a[f]=0;if(fl[c[479930]&255](b)|0){g=b?711104:710376;bQ(f|0,256,711872,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=0}else{g=b?709288:708840;bQ(f|0,256,709616,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=1}if((a[f]|0)==0){i=e;return}do{if(j){g=c[494446]|0;b=(g|0)!=0?g:c[p>>2]|0;ei(b|0,708432,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[494446]|0;g=(b|0)!=0?b:c[p>>2]|0;a_(g|0)|0}else{if((a[1820736]&1)==0){break}g=c[494446]|0;b=(g|0)!=0?g:c[p>>2]|0;ei(b|0,727024,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[494446]|0;g=(b|0)!=0?b:c[p>>2]|0;a_(g|0)|0}}while(0);if(!d){i=e;return}d=c[492315]|0;h=d+4|0;j=c[h>>2]|0;if(j>>>0>1){g=d|0;b=1;k=j;while(1){j=c[(c[g>>2]|0)+(b<<2)>>2]|0;if((j|0)==0){l=k}else{aIq(c[j+8>>2]|0);aIq(c[(c[g>>2]|0)+(b<<2)>>2]|0);c[(c[g>>2]|0)+(b<<2)>>2]=0;l=c[h>>2]|0}j=b+1|0;if(j>>>0<l>>>0){b=j;k=l}else{break}}}c[h>>2]=1;h=d+12|0;aIq(c[h>>2]|0);c[h>>2]=0;h=c[492315]|0;d=h+4|0;if((c[d>>2]|0)>>>0>=(c[h+8>>2]|0)>>>0){i=e;return}l=aIp(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}aIv(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;k=dv(f|0)|0;f=c[d>>2]|0;c[l+8>>2]=k;k=h|0;c[(c[k>>2]|0)+(f<<2)>>2]=l;l=c[d>>2]|0;c[d>>2]=l+1;if(l>>>0>1){m=l}else{i=e;return}while(1){l=m>>>1;d=c[k>>2]|0;f=d+(l<<2)|0;h=c[f>>2]|0;b=c[d+(m<<2)>>2]|0;if((c[b+4>>2]|0)>>>0<=(c[h+4>>2]|0)>>>0){n=663;break}c[f>>2]=b;c[(c[k>>2]|0)+(m<<2)>>2]=h;if(m>>>0>3){m=l}else{n=662;break}}if((n|0)==662){i=e;return}else if((n|0)==663){i=e;return}}function ge(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+256|0;e=c[479934]|0;if((e|0)==0){i=d;return}f=d|0;a[f]=0;g=fD[e&127]()|0;e=g>>>0>b>>>0;do{if(fl[c[479933]&255](b)|0){if(e){h=b+1|0;bQ(f|0,256,707992,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=0;break}else{bQ(f|0,256,707112,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=0;break}}else{if(e){h=b+1|0;bQ(f|0,256,706648,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=1;break}else{bQ(f|0,256,706280,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=1;break}}}while(0);if((a[f]|0)==0){i=d;return}do{if(k){g=c[494446]|0;b=(g|0)!=0?g:c[p>>2]|0;ei(b|0,708432,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[494446]|0;g=(b|0)!=0?b:c[p>>2]|0;a_(g|0)|0}else{if((a[1820736]&1)==0){break}g=c[494446]|0;b=(g|0)!=0?g:c[p>>2]|0;ei(b|0,727024,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[494446]|0;g=(b|0)!=0?b:c[p>>2]|0;a_(g|0)|0}}while(0);j=c[492315]|0;k=j+4|0;g=c[k>>2]|0;if(g>>>0>1){b=j|0;e=1;h=g;while(1){g=c[(c[b>>2]|0)+(e<<2)>>2]|0;if((g|0)==0){l=h}else{aIq(c[g+8>>2]|0);aIq(c[(c[b>>2]|0)+(e<<2)>>2]|0);c[(c[b>>2]|0)+(e<<2)>>2]=0;l=c[k>>2]|0}g=e+1|0;if(g>>>0<l>>>0){e=g;h=l}else{break}}}c[k>>2]=1;k=j+12|0;aIq(c[k>>2]|0);c[k>>2]=0;k=c[492315]|0;j=k+4|0;if((c[j>>2]|0)>>>0>=(c[k+8>>2]|0)>>>0){i=d;return}l=aIp(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}aIv(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;h=dv(f|0)|0;f=c[j>>2]|0;c[l+8>>2]=h;h=k|0;c[(c[h>>2]|0)+(f<<2)>>2]=l;l=c[j>>2]|0;c[j>>2]=l+1;if(l>>>0>1){m=l}else{i=d;return}while(1){l=m>>>1;j=c[h>>2]|0;f=j+(l<<2)|0;k=c[f>>2]|0;e=c[j+(m<<2)>>2]|0;if((c[e+4>>2]|0)>>>0<=(c[k+4>>2]|0)>>>0){n=695;break}c[f>>2]=e;c[(c[h>>2]|0)+(m<<2)>>2]=k;if(m>>>0>3){m=l}else{n=696;break}}if((n|0)==695){i=d;return}else if((n|0)==696){i=d;return}}function gf(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+216|0;e=d|0;f=d+72|0;g=d+144|0;h=4096;j=1857650;k=b;while(1){l=h-1|0;if((l|0)==0){m=704;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=4096;q=1853554;r=b;break}else{h=l;j=j+1|0;k=k+1|0}}do{if((m|0)==704){a[j]=0;if((a[k]|0)==0){o=4096;q=1853554;r=b;break}else{s=k}while(1){h=s+1|0;if((a[h]|0)==0){o=4096;q=1853554;r=b;break}else{s=h}}}}while(0);while(1){s=o-1|0;if((s|0)==0){m=708;break}k=a[r]|0;a[q]=k;if(k<<24>>24==0){break}else{o=s;q=q+1|0;r=r+1|0}}do{if((m|0)==708){a[q]=0;if((a[r]|0)==0){break}else{t=r}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);t=ck(1853554,46)|0;if((t|0)!=0){a[t]=0}if((a[1841264]&1)==0){gB(1861746,1853554,730072)}if((a[1841265]&1)==0){gB(1882226,1853554,729624)}do{if((eI(1861746,g|0)|0)>=0){if((c[g+8>>2]&61440|0)!=16384){break}gC(1861746,730072);if((a[1820736]&1)==0){break}t=c[494446]|0;r=(t|0)!=0?t:c[p>>2]|0;ei(r|0,710912,(u=i,i=i+8|0,c[u>>2]=1861746,u)|0)|0;i=u;r=c[494446]|0;t=(r|0)!=0?r:c[p>>2]|0;a_(t|0)|0}}while(0);do{if((eI(1882226,f|0)|0)>=0){if((c[f+8>>2]&61440|0)!=16384){break}gC(1882226,729624);if((a[1820736]&1)==0){break}g=c[494446]|0;t=(g|0)!=0?g:c[p>>2]|0;ei(t|0,710776,(u=i,i=i+8|0,c[u>>2]=1882226,u)|0)|0;i=u;t=c[494446]|0;g=(t|0)!=0?t:c[p>>2]|0;a_(g|0)|0}}while(0);if((a[1811460]|0)==0){gI(1811460,b)}if((a[1841266]|0)==0){i=d;return}if((eI(1841266,e|0)|0)<0){i=d;return}if((c[e+8>>2]&61440|0)!=16384){i=d;return}gC(1841266,710664);if((a[1820736]&1)!=0){e=c[494446]|0;b=(e|0)!=0?e:c[p>>2]|0;ei(b|0,710600,(u=i,i=i+8|0,c[u>>2]=1841266,u)|0)|0;i=u;u=c[494446]|0;b=(u|0)!=0?u:c[p>>2]|0;a_(b|0)|0}b=c9(1841266,697480)|0;if((b|0)!=0){aS(b|0)|0;i=d;return}a[1841266]=0;if((a[1820736]&1)==0){i=d;return}b=c[494446]|0;a5(710536,59,1,((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[494446]|0;a_(((b|0)!=0?b:c[p>>2]|0)|0)|0;i=d;return}function gg(){var b=0,d=0,e=0;b=c[456218]|0;do{if((b|0)==2|(b|0)==3){if((a[1841264]&1)==0){gA(1861746,1828976,730072)}gA(1869938,1861746,711304);if((a[1841265]&1)!=0){break}gA(1882226,1828976,729624)}else if((b|0)==4){if(!((a[1841264]&1)==0|(a[1833072]|0)==0|(a[1837168]|0)==0)){d=c[494446]|0;e=(d|0)!=0?d:c[p>>2]|0;a5(711176,109,1,e|0)|0;e=c[494446]|0;d=(e|0)!=0?e:c[p>>2]|0;a_(d|0)|0}gA(1874034,1833072,730072);gA(1878130,1837168,730072);if((a[1841265]&1)!=0){break}gA(1882226,(a[1833072]|0)!=0?1833072:1837168,729624)}else if((b|0)==1){if((a[1841264]&1)==0){gA(1861746,1824880,730072)}if((a[1841265]&1)==0){gA(1882226,1824880,729624)}gA(1865842,1861746,702288)}else{gA(1865842,1861746,702288)}}while(0);gA(1969288,1861746,14317944);if((a[1853554]|0)==0){return}if((a[1902710]|0)==0){gB(1902710,1853554,711152)}if((a[1906806]|0)==0){gB(1906806,1853554,711112)}if((a[1910902]|0)==0){gB(1910902,1853554,711096)}if((a[1886322]|0)==0){gB(1886322,1853554,711088)}if((a[1807364]|0)!=0){return}gI(1807364,1853554);return}function gh(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,am=0,ao=0,ap=0,aq=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aB=0,aD=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0.0,dV=0.0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0;f=i;i=i+13008|0;j=1;k=0;l=i;i=i+168|0;c[l>>2]=0;while(1)switch(j|0){case 1:m=f|0;n=f+8|0;o=f+16|0;q=f+24|0;r=f+32|0;u=f+40|0;v=f+48|0;w=f+56|0;x=f+64|0;y=f+72|0;z=f+144|0;A=f+216|0;B=f+4312|0;C=f+8408|0;D=f+12504|0;E=f+12512|0;a[1820738]=1;a[1820737]=1;c[456218]=0;c[455185]=1;c[455186]=1;c[455187]=1;c[455188]=1;c[455189]=1;c[455190]=1;c[455191]=1;c[455192]=1;F=aIw(1978816,j,l)|0;j=510;break;case 510:if((F|0)>0){j=2;break}else{j=3;break};case 2:G=c[494446]|0;ar(32,((G|0)!=0?G:c[p>>2]|0)|0,704464,(H=i,i=i+8|0,c[H>>2]=1977791,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;I=F;j=509;break;case 3:a[1977789]=1;a[1978860]=0;a[1978861]=0;a[1841264]=0;a[1841265]=0;if((d|0)<2){j=4;break}else{j=5;break};case 4:a[1978861]=1;j=182;break;case 5:c[2776]=0;c[D>>2]=0;c[E>>2]=727464;c[E+4>>2]=0;c[E+8>>2]=D;c[E+12>>2]=77;c[E+16>>2]=727376;c[E+20>>2]=0;c[E+24>>2]=0;c[E+28>>2]=104;c[E+32>>2]=727152;c[E+36>>2]=1;c[E+40>>2]=0;c[E+44>>2]=115;c[E+48>>2]=726928;c[E+52>>2]=0;c[E+56>>2]=0;c[E+60>>2]=102;c[E+64>>2]=726776;c[E+68>>2]=0;c[E+72>>2]=0;c[E+76>>2]=118;c[E+80>>2]=726640;c[E+84>>2]=1;c[E+88>>2]=0;c[E+92>>2]=103;c[E+96>>2]=726560;c[E+100>>2]=1;c[E+104>>2]=0;c[E+108>>2]=99;c[E+112>>2]=726208;c[E+116>>2]=1;c[E+120>>2]=D;c[E+124>>2]=67;c[E+128>>2]=725728;c[E+132>>2]=1;c[E+136>>2]=0;c[E+140>>2]=109;c[E+144>>2]=725624;c[E+148>>2]=1;c[E+152>>2]=0;c[E+156>>2]=78;c[E+160>>2]=725496;c[E+164>>2]=0;c[E+168>>2]=0;c[E+172>>2]=112;c[E+176>>2]=725416;c[E+180>>2]=0;c[E+184>>2]=0;c[E+188>>2]=106;c[E+192>>2]=725296;c[E+196>>2]=0;c[E+200>>2]=0;c[E+204>>2]=74;c[E+208>>2]=725200;c[E+212>>2]=1;c[E+216>>2]=0;c[E+220>>2]=65;c[E+224>>2]=725096;c[E+228>>2]=1;c[E+232>>2]=0;c[E+236>>2]=83;c[E+240>>2]=725048;c[E+244>>2]=1;c[E+248>>2]=0;c[E+252>>2]=98;c[E+256>>2]=725008;c[E+260>>2]=1;c[E+264>>2]=0;c[E+268>>2]=66;c[E+272>>2]=724704;c[E+276>>2]=0;c[E+280>>2]=0;c[E+284>>2]=52;c[E+288>>2]=724600;c[E+292>>2]=1;c[E+296>>2]=0;c[E+300>>2]=89;c[E+304>>2]=724528;c[E+308>>2]=1;c[E+312>>2]=0;c[E+316>>2]=90;c[E+320>>2]=724440;c[E+324>>2]=1;c[E+328>>2]=0;c[E+332>>2]=80;c[E+336>>2]=724384;c[E+340>>2]=1;c[E+344>>2]=0;c[E+348>>2]=82;c[E+352>>2]=724296;c[E+356>>2]=1;c[E+360>>2]=0;c[E+364>>2]=77;c[E+368>>2]=724248;c[E+372>>2]=1;c[E+376>>2]=0;c[E+380>>2]=85;c[E+384>>2]=724200;c[E+388>>2]=1;c[E+392>>2]=D;c[E+396>>2]=66;c[E+400>>2]=724136;c[E+404>>2]=1;c[E+408>>2]=D;c[E+412>>2]=73;c[E+416>>2]=724048;c[E+420>>2]=0;c[E+424>>2]=D;c[E+428>>2]=110;c[E+432>>2]=723712;c[E+436>>2]=1;c[E+440>>2]=0;c[E+444>>2]=88;c[E+448>>2]=723536;c[E+452>>2]=0;c[E+456>>2]=0;c[E+460>>2]=68;c[E+464>>2]=723400;c[E+468>>2]=0;c[E+472>>2]=D;c[E+476>>2]=102;aIv(E+480|0,0,16);J=e+(d<<2)|0;K=0;j=6;break;case 6:c[D>>2]=0;if((K|0)==0){j=7;break}else{L=K;j=8;break};case 7:c[2776]=1;L=1;j=8;break;case 8:if((d|0)==1){M=L;j=162;break}else{j=9;break};case 9:N=e+(L<<2)|0;O=c[N>>2]|0;if((O|0)==0){R=-1;S=-1;j=17;break}else{T=0;U=O;j=10;break};case 10:if((a[U]|0)==45){j=11;break}else{j=12;break};case 11:if((a[U+1|0]|0)==45){j=12;break}else{V=T;j=13;break};case 12:G=T+1|0;W=c[e+(G+L<<2)>>2]|0;if((W|0)==0){V=-1;j=13;break}else{T=G;U=W;j=10;break};case 13:X=0;Y=O;j=14;break;case 14:if((a[Y]|0)==45){j=15;break}else{j=16;break};case 15:if((a[Y+1|0]|0)==45){R=X;S=V;j=17;break}else{j=16;break};case 16:W=X+1|0;G=c[e+(W+L<<2)>>2]|0;if((G|0)==0){R=-1;S=V;j=17;break}else{X=W;Y=G;j=14;break};case 17:Z=(S|0)==-1;_=(R|0)==-1;if(Z&_){M=L;j=162;break}else{j=18;break};case 18:if((S|0)>0){j=19;break}else{j=21;break};case 19:if((S|0)<(R|0)|_){j=20;break}else{j=21;break};case 20:aH(30,N|0,e+(S+L<<2)|0,J|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=28;break;case 21:if((R|0)>0){j=22;break}else{j=25;break};case 22:if((R|0)<(S|0)|Z){j=23;break}else{j=25;break};case 23:aH(30,N|0,e+(R+L<<2)|0,J|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((S|0)==0){j=28;break}else{j=24;break};case 24:$=c[2776]|0;j=40;break;case 25:ab=(S|0)==0;ac=(R|0)==0;if(ab|ac){j=27;break}else{j=26;break};case 26:G=c[494446]|0;ar(32,((G|0)!=0?G:c[p>>2]|0)|0,712776,(H=i,i=i+16|0,c[H>>2]=728824,c[H+8>>2]=190,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(202,2);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 27:if(ab){j=28;break}else{j=39;break};case 28:ad=c[2776]|0;ae=c[e+(ad<<2)>>2]|0;af=ae+1|0;ah=a[af]|0;if(ah<<24>>24==58){j=160;break}else{j=29;break};case 29:ai=ar(24,723272,ah<<24>>24|0,41)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((ai|0)==0){j=160;break}else{j=30;break};case 30:aj=ae+2|0;G=(a[ai+1|0]|0)==58;am=G&(a[aj]|0)!=0;if(G){j=31;break}else{j=36;break};case 31:if(am){j=32;break}else{j=33;break};case 32:c[242018]=aj;ao=ad+1|0;ap=aj;j=34;break;case 33:G=c[e+(ad+1<<2)>>2]|0;c[242018]=G;ao=ad+2|0;ap=G;j=34;break;case 34:c[2776]=ao;if((ap|0)==0){j=160;break}else{j=35;break};case 35:aq=a[ai]|0;as=ao;j=49;break;case 36:if(am){j=37;break}else{j=38;break};case 37:G=an(18,aj|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aH(78,af|0,aj|0,G+1|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aq=a[ai]|0;as=ad;j=49;break;case 38:G=ad+1|0;c[2776]=G;aq=a[ai]|0;as=G;j=49;break;case 39:if(ac){$=L;j=40;break}else{j=160;break};case 40:at=0;j=41;break;case 41:au=c[E+(at<<4)>>2]|0;if((au|0)==0){j=160;break}else{j=42;break};case 42:G=aC(12,au|0,(c[e+($<<2)>>2]|0)+2|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=44;break}else{j=43;break};case 43:at=at+1|0;j=41;break;case 44:av=$+1|0;if((c[E+(at<<4)+4>>2]|0)==0){aw=av;j=47;break}else{j=45;break};case 45:ax=c[e+(av<<2)>>2]|0;if((ax|0)==0){j=160;break}else{j=46;break};case 46:c[242018]=ax;aw=$+2|0;j=47;break;case 47:c[2776]=aw;ay=c[E+(at<<4)+8>>2]|0;az=c[E+(at<<4)+12>>2]|0;if((ay|0)==0){aq=az;as=aw;j=49;break}else{j=48;break};case 48:c[ay>>2]=az;j=139;break;case 49:switch(aq|0){case 68:{j=50;break};case 104:{j=51;break};case 52:{j=52;break};case 106:{j=53;break};case 74:{j=54;break};case 65:{j=55;break};case 115:{j=58;break};case 102:{j=64;break};case 103:{j=65;break};case 98:{j=71;break};case 66:{j=77;break};case 89:{j=83;break};case 90:{j=89;break};case 83:{j=95;break};case 118:{j=101;break};case 109:{j=102;break};case 78:{j=105;break};case 112:{j=108;break};case 99:{j=109;break};case 80:case 82:{j=114;break};case 77:{j=120;break};case 85:{j=128;break};case 88:{j=134;break};case 0:{j=139;break};case 63:{j=160;break};case-1:{M=as;j=162;break};default:{j=161;break}}break;case 50:K=c[2776]|0;j=6;break;case 51:aI(1106);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(202,0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 52:c[455186]=257;j=50;break;case 53:c[455186]=516;j=50;break;case 54:c[455186]=772;j=50;break;case 55:G=ar(8,c[242018]|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aB=G-1|0;if(aB>>>0>7){j=56;break}else{j=57;break};case 56:G=c[494446]|0;aG(4,723144,57,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(1106);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(38,723016);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 57:c[1820740+(aB<<2)>>2]=5;j=50;break;case 58:aD=4096;aJ=1861746;aK=c[242018]|0;j=59;break;case 59:aL=aD-1|0;if((aL|0)==0){j=61;break}else{j=60;break};case 60:G=a[aK]|0;a[aJ]=G;if(G<<24>>24==0){j=63;break}else{aD=aL;aJ=aJ+1|0;aK=aK+1|0;j=59;break};case 61:a[aJ]=0;if((a[aK]|0)==0){j=63;break}else{aM=aK;j=62;break};case 62:G=aM+1|0;if((a[G]|0)==0){j=63;break}else{aM=G;j=62;break};case 63:a[1841264]=1;j=50;break;case 64:a[1820739]=1;j=50;break;case 65:aN=4096;aO=1824880;aP=c[242018]|0;j=66;break;case 66:aQ=aN-1|0;if((aQ|0)==0){j=68;break}else{j=67;break};case 67:G=a[aP]|0;a[aO]=G;if(G<<24>>24==0){j=70;break}else{aN=aQ;aO=aO+1|0;aP=aP+1|0;j=66;break};case 68:a[aO]=0;if((a[aP]|0)==0){j=70;break}else{aR=aP;j=69;break};case 69:G=aR+1|0;if((a[G]|0)==0){j=70;break}else{aR=G;j=69;break};case 70:c[456218]=1;j=50;break;case 71:aS=4096;aT=1828976;aU=c[242018]|0;j=72;break;case 72:aV=aS-1|0;if((aV|0)==0){j=74;break}else{j=73;break};case 73:G=a[aU]|0;a[aT]=G;if(G<<24>>24==0){j=76;break}else{aS=aV;aT=aT+1|0;aU=aU+1|0;j=72;break};case 74:a[aT]=0;if((a[aU]|0)==0){j=76;break}else{aW=aU;j=75;break};case 75:G=aW+1|0;if((a[G]|0)==0){j=76;break}else{aW=G;j=75;break};case 76:c[456218]=2;j=50;break;case 77:aX=4096;aY=1828976;aZ=c[242018]|0;j=78;break;case 78:a_=aX-1|0;if((a_|0)==0){j=80;break}else{j=79;break};case 79:G=a[aZ]|0;a[aY]=G;if(G<<24>>24==0){j=82;break}else{aX=a_;aY=aY+1|0;aZ=aZ+1|0;j=78;break};case 80:a[aY]=0;if((a[aZ]|0)==0){j=82;break}else{a$=aZ;j=81;break};case 81:G=a$+1|0;if((a[G]|0)==0){j=82;break}else{a$=G;j=81;break};case 82:c[456218]=3;j=50;break;case 83:a0=4096;a1=1833072;a2=c[242018]|0;j=84;break;case 84:a3=a0-1|0;if((a3|0)==0){j=86;break}else{j=85;break};case 85:G=a[a2]|0;a[a1]=G;if(G<<24>>24==0){j=88;break}else{a0=a3;a1=a1+1|0;a2=a2+1|0;j=84;break};case 86:a[a1]=0;if((a[a2]|0)==0){j=88;break}else{a4=a2;j=87;break};case 87:G=a4+1|0;if((a[G]|0)==0){j=88;break}else{a4=G;j=87;break};case 88:c[456218]=4;j=50;break;case 89:a5=4096;a6=1837168;a7=c[242018]|0;j=90;break;case 90:a8=a5-1|0;if((a8|0)==0){j=92;break}else{j=91;break};case 91:G=a[a7]|0;a[a6]=G;if(G<<24>>24==0){j=94;break}else{a5=a8;a6=a6+1|0;a7=a7+1|0;j=90;break};case 92:a[a6]=0;if((a[a7]|0)==0){j=94;break}else{a9=a7;j=93;break};case 93:G=a9+1|0;if((a[G]|0)==0){j=94;break}else{a9=G;j=93;break};case 94:c[456218]=4;j=50;break;case 95:ba=4096;bb=1882226;bc=c[242018]|0;j=96;break;case 96:bd=ba-1|0;if((bd|0)==0){j=98;break}else{j=97;break};case 97:G=a[bc]|0;a[bb]=G;if(G<<24>>24==0){j=100;break}else{ba=bd;bb=bb+1|0;bc=bc+1|0;j=96;break};case 98:a[bb]=0;if((a[bc]|0)==0){j=100;break}else{be=bc;j=99;break};case 99:G=be+1|0;if((a[G]|0)==0){j=100;break}else{be=G;j=99;break};case 100:a[1841265]=1;j=50;break;case 101:a[1820736]=1;j=50;break;case 102:G=ar(8,c[242018]|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;bf=G-1|0;if(bf>>>0>7){j=103;break}else{j=104;break};case 103:G=c[494446]|0;aG(4,722896,52,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(1106);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(38,723016);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 104:c[1820740+(bf<<2)>>2]=2;j=50;break;case 105:G=ar(8,c[242018]|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;bg=G-1|0;if(bg>>>0>7){j=106;break}else{j=107;break};case 106:G=c[494446]|0;aG(4,722728,58,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(1106);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(38,723016);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 107:c[1820740+(bg<<2)>>2]=0;j=50;break;case 108:c[455186]=260;j=50;break;case 109:bh=4096;bi=1841266;bj=c[242018]|0;j=110;break;case 110:bk=bh-1|0;if((bk|0)==0){j=112;break}else{j=111;break};case 111:G=a[bj]|0;a[bi]=G;if(G<<24>>24==0){j=50;break}else{bh=bk;bi=bi+1|0;bj=bj+1|0;j=110;break};case 112:a[bi]=0;if((a[bj]|0)==0){j=50;break}else{bl=bj;j=113;break};case 113:G=bl+1|0;if((a[G]|0)==0){j=50;break}else{bl=G;j=113;break};case 114:bm=4096;bn=1973385;bo=c[242018]|0;j=115;break;case 115:bp=bm-1|0;if((bp|0)==0){j=117;break}else{j=116;break};case 116:G=a[bo]|0;a[bn]=G;if(G<<24>>24==0){j=119;break}else{bm=bp;bn=bn+1|0;bo=bo+1|0;j=115;break};case 117:a[bn]=0;if((a[bo]|0)==0){j=119;break}else{bq=bo;j=118;break};case 118:G=bq+1|0;if((a[G]|0)==0){j=119;break}else{bq=G;j=118;break};case 119:a[1977482]=(aq|0)==80|0;a[1977481]=(aq|0)==82|0;j=50;break;case 120:br=c[242018]|0;G=aC(12,br|0,722656)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=121;break}else{j=122;break};case 121:a[1977484]=1;a[1977485]=1;j=50;break;case 122:G=aC(12,br|0,722600)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=123;break}else{j=124;break};case 123:a[1977484]=1;j=50;break;case 124:G=aC(12,br|0,722280)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=125;break}else{j=126;break};case 125:a[1977485]=1;j=50;break;case 126:G=aC(12,br|0,722096)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=50;break}else{j=127;break};case 127:G=c[494446]|0;aG(4,721800,54,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(1106);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(38,723016);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 128:bs=4096;bt=1902710;bu=c[242018]|0;j=129;break;case 129:bv=bs-1|0;if((bv|0)==0){j=131;break}else{j=130;break};case 130:G=a[bu]|0;a[bt]=G;if(G<<24>>24==0){j=133;break}else{bs=bv;bt=bt+1|0;bu=bu+1|0;j=129;break};case 131:a[bt]=0;if((a[bu]|0)==0){j=133;break}else{bw=bu;j=132;break};case 132:G=bw+1|0;if((a[G]|0)==0){j=133;break}else{bw=G;j=132;break};case 133:a[1902707]=1;j=50;break;case 134:bx=4096;by=1886322;bz=c[242018]|0;j=135;break;case 135:bA=bx-1|0;if((bA|0)==0){j=137;break}else{j=136;break};case 136:G=a[bz]|0;a[by]=G;if(G<<24>>24==0){j=50;break}else{bx=bA;by=by+1|0;bz=bz+1|0;j=135;break};case 137:a[by]=0;if((a[bz]|0)==0){j=50;break}else{bB=bz;j=138;break};case 138:G=bB+1|0;if((a[G]|0)==0){j=50;break}else{bB=G;j=138;break};case 139:switch(c[D>>2]|0){case 77:{j=140;break};case 67:{j=141;break};case 66:{j=146;break};case 73:{j=152;break};case 110:{j=158;break};case 102:{j=159;break};default:{j=50;break}}break;case 140:a[1978861]=1;j=50;break;case 141:bC=4096;bD=1845362;bE=c[242018]|0;j=142;break;case 142:bF=bC-1|0;if((bF|0)==0){j=144;break}else{j=143;break};case 143:G=a[bE]|0;a[bD]=G;if(G<<24>>24==0){j=50;break}else{bC=bF;bD=bD+1|0;bE=bE+1|0;j=142;break};case 144:a[bD]=0;if((a[bE]|0)==0){j=50;break}else{bG=bE;j=145;break};case 145:G=bG+1|0;if((a[G]|0)==0){j=50;break}else{bG=G;j=145;break};case 146:bH=4096;bI=1906806;bJ=c[242018]|0;j=147;break;case 147:bK=bH-1|0;if((bK|0)==0){j=149;break}else{j=148;break};case 148:G=a[bJ]|0;a[bI]=G;if(G<<24>>24==0){j=151;break}else{bH=bK;bI=bI+1|0;bJ=bJ+1|0;j=147;break};case 149:a[bI]=0;if((a[bJ]|0)==0){j=151;break}else{bL=bJ;j=150;break};case 150:G=bL+1|0;if((a[G]|0)==0){j=151;break}else{bL=G;j=150;break};case 151:a[1902708]=1;j=50;break;case 152:bM=4096;bN=1910902;bO=c[242018]|0;j=153;break;case 153:bP=bM-1|0;if((bP|0)==0){j=155;break}else{j=154;break};case 154:G=a[bO]|0;a[bN]=G;if(G<<24>>24==0){j=157;break}else{bM=bP;bN=bN+1|0;bO=bO+1|0;j=153;break};case 155:a[bN]=0;if((a[bO]|0)==0){j=157;break}else{bQ=bO;j=156;break};case 156:G=bQ+1|0;if((a[G]|0)==0){j=157;break}else{bQ=G;j=156;break};case 157:a[1902709]=1;j=50;break;case 158:a[1902706]=1;j=50;break;case 159:an(38,10)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;an(154,721448)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=721328,c[H+8>>2]=721280,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=720936,c[H+8>>2]=720840,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=720736,c[H+8>>2]=720632,c[H+16>>2]=702496,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=720504,c[H+8>>2]=720432,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=720392,c[H+8>>2]=720320,c[H+16>>2]=702496,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=720256,c[H+8>>2]=720200,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=719920,c[H+8>>2]=719744,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=719624,c[H+8>>2]=719536,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=719496,c[H+8>>2]=719536,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=719448,c[H+8>>2]=719536,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=719408,c[H+8>>2]=719536,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=719344,c[H+8>>2]=719536,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=719280,c[H+8>>2]=719536,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=719240,c[H+8>>2]=719536,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=718856,c[H+8>>2]=719536,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=718736,c[H+8>>2]=718600,c[H+16>>2]=702496,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=718560,c[H+8>>2]=719536,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=718464,c[H+8>>2]=718392,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=718352,c[H+8>>2]=718280,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=718208,c[H+8>>2]=718152,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=717928,c[H+8>>2]=717792,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=717632,c[H+8>>2]=717552,c[H+16>>2]=702496,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=717528,c[H+8>>2]=717480,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=717448,c[H+8>>2]=717376,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=717320,c[H+8>>2]=717264,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=716928,c[H+8>>2]=716816,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,721400,(H=i,i=i+24|0,c[H>>2]=716680,c[H+8>>2]=716600,c[H+16>>2]=702224,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;ak(202,0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 160:aI(1106);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(38,723016);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 161:G=c[494446]|0;aG(4,721680,46,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(38,723016);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 162:bR=(M|0)<(d|0);if((a[1978861]&1)==0){j=165;break}else{j=163;break};case 163:if(bR){j=164;break}else{j=168;break};case 164:G=c[494446]|0;aG(4,721576,71,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(38,723016);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 165:if(bR){j=166;break}else{j=167;break};case 166:ak(8,c[e+(M<<2)>>2]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=168;break;case 167:a[1978860]=1;j=168;break;case 168:if((a[1841264]&1)==0){j=175;break}else{j=169;break};case 169:G=aC(28,1861746,z|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)<0){j=175;break}else{j=170;break};case 170:if((c[z+8>>2]&61440|0)==16384){bS=4096;bT=1890418;bU=1861746;j=171;break}else{j=175;break};case 171:bV=bS-1|0;if((bV|0)==0){j=173;break}else{j=172;break};case 172:G=a[bU]|0;a[bT]=G;if(G<<24>>24==0){j=175;break}else{bS=bV;bT=bT+1|0;bU=bU+1|0;j=171;break};case 173:a[bT]=0;if((a[bU]|0)==0){j=175;break}else{bW=bU;j=174;break};case 174:G=bW+1|0;if((a[G]|0)==0){j=175;break}else{bW=G;j=174;break};case 175:if((a[1841265]&1)==0){j=182;break}else{j=176;break};case 176:G=aC(28,1882226,y|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)<0){j=182;break}else{j=177;break};case 177:if((c[y+8>>2]&61440|0)==16384){bX=4096;bY=1894514;bZ=1882226;j=178;break}else{j=182;break};case 178:b_=bX-1|0;if((b_|0)==0){j=180;break}else{j=179;break};case 179:G=a[bZ]|0;a[bY]=G;if(G<<24>>24==0){j=182;break}else{bX=b_;bY=bY+1|0;bZ=bZ+1|0;j=178;break};case 180:a[bY]=0;if((a[bZ]|0)==0){j=182;break}else{b$=bZ;j=181;break};case 181:G=b$+1|0;if((a[G]|0)==0){j=182;break}else{b$=G;j=181;break};case 182:if((a[1820736]&1)==0){j=185;break}else{j=183;break};case 183:G=c[494446]|0;aG(4,704088,49,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[p>>2]|0;aG(4,729024,11,1,G|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ar(32,G|0,728776,(H=i,i=i+16|0,c[H>>2]=728200,c[H+8>>2]=32,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;ar(32,G|0,727912,(H=i,i=i+8|0,c[H>>2]=727768,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;if((a[1820736]&1)==0){j=185;break}else{j=184;break};case 184:G=c[494446]|0;aG(4,703704,50,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=185;break;case 185:if((a[1977692]&1)==0){j=186;break}else{j=233;break};case 186:a[1717304]=103;a[1717305]=108;a[1717306]=0;a[1733852]=114;a[1733853]=119;a[1733854]=101;a[1733855]=98;a[1733856]=97;a[1733857]=117;a[1733858]=100;a[1733859]=105;a[1733860]=111;a[1733861]=0;a[1742144]=114;a[1742145]=119;a[1742146]=101;a[1742147]=98;a[1742148]=105;a[1742149]=110;a[1742150]=112;a[1742151]=117;a[1742152]=116;a[1742153]=0;g[429342]=3.0;g[429343]=3.0;a[1717376]=a[1820739]&1;a[1717377]=1;c[429345]=0;c[429346]=0;c[429347]=0;a[1733844]=0;a[1717392]=1;a[1717393]=0;c[429350]=0;a[1717394]=0;c[429349]=1;a[1725620]=0;a[1717404]=1;a[1717405]=1;a[1717413]=0;a[1717406]=1;g[429352]=-1.0;a[1717412]=0;c[429354]=4;a[1721516]=0;a[1733848]=1;a[1733820]=1;g[433454]=48.0;a[1733821]=1;g[433456]=.05000000074505806;g[433457]=.05000000074505806;g[433458]=1.0;g[433459]=1.0;g[433460]=0.0;g[431404]=59.95000076293945;a[1733845]=0;a[1733846]=0;a[1733847]=1;a[1733884]=1;c[433472]=48e3;c[433473]=0;g[433474]=48.0e3;c[434499]=64;a[1738e3]=1;a[1742097]=1;g[435525]=.004999999888241291;g[435526]=0.0;a[1815556]=0;c[453890]=20971520;c[453891]=1;g[453892]=3.0;g[453893]=-1.0;a[1815576]=0;aIv(1815580,0,7);a[1815587]=1;a[1815588]=0;b[907795]=-10181;a[1815592]=0;c[448768]=100;aIy(1742208,7568,2240)|0;aIy(1744448,6568,1e3)|0;aIy(1746688,6568,1e3)|0;aIy(1748928,6568,1e3)|0;aIy(1751168,6568,1e3)|0;aIy(1753408,6568,1e3)|0;aIy(1755648,6568,1e3)|0;aIy(1757888,6568,1e3)|0;b0=0;j=187;break;case 187:G=1760144+(b0*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[1760160+(b0*40|0)>>2]=-1;G=b0+1|0;if(G>>>0<56){b0=G;j=187;break}else{b1=0;j=213;break};case 188:if((a[1742208+(b2*40|0)|0]&1)==0){j=191;break}else{j=189;break};case 189:if((b2|0)==(c[1742212+(b2*40|0)>>2]|0)){j=191;break}else{j=190;break};case 190:G=c[494446]|0;ar(32,((G|0)!=0?G:c[p>>2]|0)|0,712776,(H=i,i=i+16|0,c[H>>2]=702048,c[H+8>>2]=251,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(202,2);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 191:G=b2+1|0;if((G|0)<56){b2=G;j=188;break}else{b3=0;j=192;break};case 192:if((a[1744448+(b3*40|0)|0]&1)==0){j=194;break}else{j=193;break};case 193:if((b3|0)==(c[1744452+(b3*40|0)>>2]|0)){j=194;break}else{j=190;break};case 194:G=b3+1|0;if((G|0)<56){b3=G;j=192;break}else{b4=0;j=195;break};case 195:if((a[1746688+(b4*40|0)|0]&1)==0){j=197;break}else{j=196;break};case 196:if((b4|0)==(c[1746692+(b4*40|0)>>2]|0)){j=197;break}else{j=190;break};case 197:G=b4+1|0;if((G|0)<56){b4=G;j=195;break}else{b5=0;j=198;break};case 198:if((a[1748928+(b5*40|0)|0]&1)==0){j=200;break}else{j=199;break};case 199:if((b5|0)==(c[1748932+(b5*40|0)>>2]|0)){j=200;break}else{j=190;break};case 200:G=b5+1|0;if((G|0)<56){b5=G;j=198;break}else{b6=0;j=201;break};case 201:if((a[1751168+(b6*40|0)|0]&1)==0){j=203;break}else{j=202;break};case 202:if((b6|0)==(c[1751172+(b6*40|0)>>2]|0)){j=203;break}else{j=190;break};case 203:G=b6+1|0;if((G|0)<56){b6=G;j=201;break}else{b7=0;j=204;break};case 204:if((a[1753408+(b7*40|0)|0]&1)==0){j=206;break}else{j=205;break};case 205:if((b7|0)==(c[1753412+(b7*40|0)>>2]|0)){j=206;break}else{j=190;break};case 206:G=b7+1|0;if((G|0)<56){b7=G;j=204;break}else{b8=0;j=207;break};case 207:if((a[1755648+(b8*40|0)|0]&1)==0){j=209;break}else{j=208;break};case 208:if((b8|0)==(c[1755652+(b8*40|0)>>2]|0)){j=209;break}else{j=190;break};case 209:G=b8+1|0;if((G|0)<56){b8=G;j=207;break}else{b9=0;j=210;break};case 210:if((a[1757888+(b9*40|0)|0]&1)==0){j=212;break}else{j=211;break};case 211:if((b9|0)==(c[1757892+(b9*40|0)>>2]|0)){j=212;break}else{j=190;break};case 212:G=b9+1|0;if((G|0)<56){b9=G;j=210;break}else{j=220;break};case 213:G=1762384+(b1*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[1762400+(b1*40|0)>>2]=-1;G=b1+1|0;if(G>>>0<56){b1=G;j=213;break}else{ca=0;j=214;break};case 214:G=1764624+(ca*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[1764640+(ca*40|0)>>2]=-1;G=ca+1|0;if(G>>>0<56){ca=G;j=214;break}else{cb=0;j=215;break};case 215:G=1766864+(cb*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[1766880+(cb*40|0)>>2]=-1;G=cb+1|0;if(G>>>0<56){cb=G;j=215;break}else{cc=0;j=216;break};case 216:G=1769104+(cc*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[1769120+(cc*40|0)>>2]=-1;G=cc+1|0;if(G>>>0<56){cc=G;j=216;break}else{cd=0;j=217;break};case 217:G=1771344+(cd*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[1771360+(cd*40|0)>>2]=-1;G=cd+1|0;if(G>>>0<56){cd=G;j=217;break}else{ce=0;j=218;break};case 218:G=1773584+(ce*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[1773600+(ce*40|0)>>2]=-1;G=ce+1|0;if(G>>>0<56){ce=G;j=218;break}else{cf=0;j=219;break};case 219:G=1775824+(cf*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[1775840+(cf*40|0)>>2]=-1;G=cf+1|0;if(G>>>0<56){cf=G;j=219;break}else{b2=0;j=188;break};case 220:g[444514]=.5;a[1778670]=1;c[444668]=6;c[444669]=3;g[445694]=1.0;g[445695]=1.0;a[1778668]=0;a[1778669]=1;c[444515]=0;c[444516]=1;c[444517]=2;c[444518]=3;c[444519]=4;c[444520]=5;c[444521]=6;c[444522]=7;a[1977790]=0;aIv(1977724,0,16);a[1977692]=1;aI(6984);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cg=(a[1820736]&1)!=0;if((a[1841266]|0)==0){j=224;break}else{j=221;break};case 221:if(cg){j=222;break}else{j=223;break};case 222:G=c[494446]|0;ar(32,((G|0)!=0?G:c[p>>2]|0)|0,723216,(H=i,i=i+8|0,c[H>>2]=1841266,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=223;break;case 223:G=an(184,1841266)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if(G){j=233;break}else{j=230;break};case 224:if(cg){j=225;break}else{j=226;break};case 225:G=c[494446]|0;aG(4,723088,35,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=226;break;case 226:ch=an(184,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((a[1841266]|0)==0){j=229;break}else{j=227;break};case 227:if((a[1820736]&1)==0){j=229;break}else{j=228;break};case 228:G=c[494446]|0;ar(32,((G|0)!=0?G:c[p>>2]|0)|0,722960,(H=i,i=i+8|0,c[H>>2]=1841266,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if(ch){j=233;break}else{j=230;break};case 229:if(ch){j=233;break}else{j=230;break};case 230:G=c[494446]|0;ar(32,((G|0)!=0?G:c[p>>2]|0)|0,722800,(H=i,i=i+8|0,c[H>>2]=1841266,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((a[1977789]&1)==0){j=231;break}else{j=232;break};case 231:G=c[494446]|0;ar(32,((G|0)!=0?G:c[p>>2]|0)|0,712776,(H=i,i=i+16|0,c[H>>2]=722624,c[H+8>>2]=832,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[494446]|0;an(140,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(202,2);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 232:a[1977791]=112;a[1977792]=97;a[1977793]=114;a[1977794]=115;a[1977795]=101;a[1977796]=95;a[1977797]=99;a[1977798]=111;a[1977799]=110;a[1977800]=102;a[1977801]=105;a[1977802]=103;a[1977803]=95;a[1977804]=102;a[1977805]=105;a[1977806]=108;a[1977807]=101;a[1977808]=40;a[1977809]=41;a[1977810]=0;al(36,1978816,1);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 233:G=(a[1978861]&1)!=0;W=G?44:142;c[241042]=G?3890:6376;c[241054]=G?4954:5950;c[241060]=G?54:40;c[241044]=G?170:150;c[241046]=G?144:168;c[241022]=W;c[241016]=G?154:174;c[241028]=G?118:16;c[241026]=G?64:130;c[241020]=G?60:176;c[241018]=G?48:70;c[241024]=G?148:236;c[241036]=G?2362:1252;c[241034]=G?5164:8020;c[241030]=G?50:48;c[241032]=G?14:46;c[241012]=G?48:26;c[241058]=G?888:4168;c[241056]=G?22:10;c[241040]=G?26:148;c[241038]=G?30:20;c[241014]=G?5734:790;c[241048]=G?16:2;c[241052]=G?102:162;c[241050]=G?196:60;ak(W|0,34);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[241044]|0,1915024);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[478756]|0;if((W|0)==0){j=234;break}else{ci=W;j=235;break};case 234:c[478756]=698568;ci=698568;j=235;break;case 235:W=c[478757]|0;if((W|0)==0){j=236;break}else{cj=W;j=237;break};case 236:c[478757]=705616;cj=705616;j=237;break;case 237:aG(6,1977548,64,705168,(H=i,i=i+16|0,c[H>>2]=ci,c[H+8>>2]=cj,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[478758]|0;ck=4096;cl=1915616;cm=(W|0)==0?704896:W;j=238;break;case 238:cn=ck-1|0;if((cn|0)==0){j=240;break}else{j=239;break};case 239:W=a[cm]|0;a[cl]=W;if(W<<24>>24==0){j=242;break}else{ck=cn;cl=cl+1|0;cm=cm+1|0;j=238;break};case 240:a[cl]=0;if((a[cm]|0)==0){j=242;break}else{co=cm;j=241;break};case 241:W=co+1|0;if((a[W]|0)==0){j=242;break}else{co=W;j=241;break};case 242:a[1915100]=a[1915037]&1;cp=0;j=243;break;case 243:if(cp>>>0<2){j=244;break}else{j=245;break};case 244:cq=c[689656+(cp<<2)>>2]|0;W=aC(20,1733852,c[cq+28>>2]|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=252;break}else{cp=cp+1|0;j=243;break};case 245:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,704960,(H=i,i=i+8|0,c[H>>2]=1733852,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=a[1820736]|0;if((W&1)==0){cr=W;j=247;break}else{j=246;break};case 246:W=c[494446]|0;aG(4,704616,29,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cr=a[1820736]|0;j=247;break;case 247:if((cr&1)==0){cs=cr;j=249;break}else{j=248;break};case 248:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,706840,(H=i,i=i+8|0,c[H>>2]=727752,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cs=a[1820736]|0;j=249;break;case 249:if((cs&1)==0){j=251;break}else{j=250;break};case 250:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,706840,(H=i,i=i+8|0,c[H>>2]=723496,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=251;break;case 251:ak(204,704320);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 252:c[3118436]=cq;W=aC(20,1717304,714872)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=258;break}else{j=253;break};case 253:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,706e3,(H=i,i=i+8|0,c[H>>2]=1717304,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=a[1820736]|0;if((W&1)==0){ct=W;j=255;break}else{j=254;break};case 254:W=c[494446]|0;aG(4,705696,29,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ct=a[1820736]|0;j=255;break;case 255:if((ct&1)==0){j=257;break}else{j=256;break};case 256:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,706840,(H=i,i=i+8|0,c[H>>2]=714872,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=257;break;case 257:ak(204,705312);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 258:c[3118437]=168;W=aC(20,1742144,730056)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=264;break}else{j=259;break};case 259:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,708080,(H=i,i=i+8|0,c[H>>2]=1742144,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=a[1820736]|0;if((W&1)==0){cu=W;j=261;break}else{j=260;break};case 260:W=c[494446]|0;aG(4,707536,29,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cu=a[1820736]|0;j=261;break;case 261:if((cu&1)==0){j=263;break}else{j=262;break};case 262:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,706840,(H=i,i=i+8|0,c[H>>2]=730056,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=263;break;case 263:ak(204,706408);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 264:c[3118438]=670112;W=a[1820736]|0;if((W&1)==0){cv=W;j=266;break}else{j=265;break};case 265:W=c[494446]|0;G=(W|0)!=0?W:c[p>>2]|0;W=aF(c[241060]|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ar(32,G|0,729664,(H=i,i=i+8|0,c[H>>2]=W,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cv=a[1820736]|0;j=266;break;case 266:if((cv&1)==0){j=268;break}else{j=267;break};case 267:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,729584,(H=i,i=i+8|0,c[H>>2]=1,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=268;break;case 268:W=aF(c[241060]|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==1){j=270;break}else{j=269;break};case 269:W=c[494446]|0;aG(4,729192,117,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=270;break;case 270:aI(c[241042]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cw=(a[1978861]&1)==0;W=a[1978860]&1;a[1977486]=cw?W^1:0;if(W<<24>>24==0){j=273;break}else{j=271;break};case 271:if(cw){j=272;break}else{j=369;break};case 272:W=an(212,c[456218]|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if(W){j=369;break}else{j=493;break};case 273:if(cw){j=274;break}else{j=369;break};case 274:aI(6662);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=an(212,c[456218]|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if(W){j=275;break}else{j=493;break};case 275:cx=A|0;cy=B|0;cz=C|0;if((a[1815585]&1)==0){j=289;break}else{j=276;break};case 276:al(254,cx|0,1882226);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aH(60,cy|0,1882226,4096);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cA=ar(28,cx|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((cA|0)==0){j=289;break}else{j=277;break};case 277:cB=cA+4|0;cC=cA|0;if((c[cB>>2]|0)==0){j=278;break}else{cD=0;cE=0;j=279;break};case 278:cF=c[cC>>2]|0;cG=0;j=287;break;case 279:cH=c[(c[cC>>2]|0)+(cD<<3)>>2]|0;aH(60,cz|0,cH|0,4096);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=an(18,cy|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=ar(2,cz|0,cy|0,W|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=280;break}else{cI=cE;j=284;break};case 280:G=an(18,cH|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cJ=cH+G|0;j=281;break;case 281:if(cJ>>>0>cH>>>0){j=282;break}else{j=283;break};case 282:G=cJ-1|0;if(((a[G]|0)-48|0)>>>0<10){cJ=G;j=281;break}else{j=283;break};case 283:G=ar(16,cJ|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cI=G>>>0>cE>>>0?G:cE;j=284;break;case 284:G=cD+1|0;cK=c[cB>>2]|0;if(G>>>0<cK>>>0){cD=G;cE=cI;j=279;break}else{j=285;break};case 285:G=c[cC>>2]|0;if((cK|0)==0){cF=G;cG=cI;j=287;break}else{cL=0;cM=G;j=286;break};case 286:ak(198,c[cM+(cL<<3)>>2]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=cL+1|0;W=c[cC>>2]|0;if(G>>>0<(c[cB>>2]|0)>>>0){cL=G;cM=W;j=286;break}else{cF=W;cG=cI;j=287;break};case 287:ak(198,cF|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(198,cA|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c[478750]=cG;if((a[1820736]&1)==0){j=289;break}else{j=288;break};case 288:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,729832,(H=i,i=i+8|0,c[H>>2]=cG,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=289;break;case 289:if((a[1977484]&1)==0){j=290;break}else{j=323;break};case 290:switch(c[456218]|0){case 0:{j=291;break};case 1:{j=299;break};case 2:case 3:{j=307;break};case 4:{j=315;break};default:{j=325;break}}break;case 291:cN=an(c[241050]|0,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cO=an(c[241052]|0,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((cN|0)==0|(cO|0)==0){j=295;break}else{j=292;break};case 292:c[x>>2]=0;cP=aC(16,1861746,x|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cQ=c[x>>2]|0;if((cP|0)<1|(cP|0)>(cN|0)){j=294;break}else{j=293;break};case 293:aIy(cO|0,cQ|0,cP)|0;j=294;break;case 294:ak(198,cQ|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=295;break;case 295:cR=an(c[241050]|0,1)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cS=an(c[241052]|0,1)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((cR|0)==0|(cS|0)==0){j=325;break}else{j=296;break};case 296:c[w>>2]=0;cT=aC(16,1865842,w|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cU=c[w>>2]|0;if((cT|0)<1|(cT|0)>(cR|0)){j=298;break}else{j=297;break};case 297:aIy(cS|0,cU|0,cT)|0;j=298;break;case 298:ak(198,cU|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=325;break;case 299:cV=an(c[241050]|0,1280)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cW=an(c[241052]|0,1280)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((cV|0)==0|(cW|0)==0){j=303;break}else{j=300;break};case 300:c[v>>2]=0;cX=aC(16,1861746,v|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cY=c[v>>2]|0;if((cX|0)<1|(cX|0)>(cV|0)){j=302;break}else{j=301;break};case 301:aIy(cW|0,cY|0,cX)|0;j=302;break;case 302:ak(198,cY|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=303;break;case 303:cZ=an(c[241050]|0,1537)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c_=an(c[241052]|0,1537)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((cZ|0)==0|(c_|0)==0){j=325;break}else{j=304;break};case 304:c[u>>2]=0;c$=aC(16,1865842,u|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c0=c[u>>2]|0;if((c$|0)<1|(c$|0)>(cZ|0)){j=306;break}else{j=305;break};case 305:aIy(c_|0,c0|0,c$)|0;j=306;break;case 306:ak(198,c0|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=325;break;case 307:c1=an(c[241050]|0,256)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c2=an(c[241052]|0,256)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((c1|0)==0|(c2|0)==0){j=311;break}else{j=308;break};case 308:c[r>>2]=0;c3=aC(16,1861746,r|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c4=c[r>>2]|0;if((c3|0)<1|(c3|0)>(c1|0)){j=310;break}else{j=309;break};case 309:aIy(c2|0,c4|0,c3)|0;j=310;break;case 310:ak(198,c4|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=311;break;case 311:c5=an(c[241050]|0,512)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c6=an(c[241052]|0,512)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((c5|0)==0|(c6|0)==0){j=325;break}else{j=312;break};case 312:c[q>>2]=0;c7=aC(16,1869938,q|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c8=c[q>>2]|0;if((c7|0)<1|(c7|0)>(c5|0)){j=314;break}else{j=313;break};case 313:aIy(c6|0,c8|0,c7)|0;j=314;break;case 314:ak(198,c8|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=325;break;case 315:c9=an(c[241050]|0,768)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;da=an(c[241052]|0,768)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((c9|0)==0|(da|0)==0){j=319;break}else{j=316;break};case 316:c[o>>2]=0;db=aC(16,1874034,o|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dc=c[o>>2]|0;if((db|0)<1|(db|0)>(c9|0)){j=318;break}else{j=317;break};case 317:aIy(da|0,dc|0,db)|0;j=318;break;case 318:ak(198,dc|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=319;break;case 319:dd=an(c[241050]|0,1024)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;de=an(c[241052]|0,1024)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dd|0)==0|(de|0)==0){j=325;break}else{j=320;break};case 320:c[n>>2]=0;df=aC(16,1878130,n|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dg=c[n>>2]|0;if((df|0)<1|(df|0)>(dd|0)){j=322;break}else{j=321;break};case 321:aIy(de|0,dg|0,df)|0;j=322;break;case 322:ak(198,dg|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=325;break;case 323:if((a[1820736]&1)==0){j=325;break}else{j=324;break};case 324:W=c[494446]|0;aG(4,702664,31,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=325;break;case 325:if((a[1815587]&1)==0){j=338;break}else{j=326;break};case 326:aH(16,cx|0,1882226,698776);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dh=aC(2,cx|0,697480)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dh|0)==0){j=338;break}else{j=327;break};case 327:an(174,dh|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((a[1820736]&1)==0){j=329;break}else{j=328;break};case 328:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,730152,(H=i,i=i+8|0,c[H>>2]=cx,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=329;break;case 329:W=an(94,cx|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aG(6,cy|0,4096,73e4,(H=i,i=i+16|0,c[H>>2]=cx,c[H+8>>2]=W?698536:698472,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;di=c[492315]|0;dj=di+4|0;if((c[dj>>2]|0)>>>0<(c[di+8>>2]|0)>>>0){j=330;break}else{j=336;break};case 330:dk=an(172,12)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dk|0)==0){j=333;break}else{j=331;break};case 331:if((c[dk-4>>2]&3|0)==0){j=333;break}else{j=332;break};case 332:aIv(dk|0,0,12);j=333;break;case 333:W=dk;c[dk+4>>2]=1;c[dk>>2]=180;G=an(186,cy|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dl=c[dj>>2]|0;c[dk+8>>2]=G;dm=di|0;c[(c[dm>>2]|0)+(dl<<2)>>2]=W;W=c[dj>>2]|0;c[dj>>2]=W+1;if(W>>>0>1){dn=W;j=334;break}else{j=336;break};case 334:dp=dn>>>1;W=c[dm>>2]|0;dq=W+(dp<<2)|0;dr=c[dq>>2]|0;ds=c[W+(dn<<2)>>2]|0;if((c[ds+4>>2]|0)>>>0>(c[dr+4>>2]|0)>>>0){j=335;break}else{j=336;break};case 335:c[dq>>2]=ds;c[(c[dm>>2]|0)+(dn<<2)>>2]=dr;if(dn>>>0>3){dn=dp;j=334;break}else{j=336;break};case 336:if((a[1820736]&1)==0){j=338;break}else{j=337;break};case 337:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,727024,(H=i,i=i+8|0,c[H>>2]=cy,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=338;break;case 338:if((a[1977482]&1)==0){j=351;break}else{j=339;break};case 339:W=aC(30,1973385,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c[492321]=W;if((W|0)==0){j=340;break}else{j=341;break};case 340:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,690288,(H=i,i=i+8|0,c[H>>2]=1973385,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(38,731152);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 341:a[1973384]=1;dt=c[492315]|0;du=dt+4|0;if((c[du>>2]|0)>>>0<(c[dt+8>>2]|0)>>>0){j=342;break}else{j=348;break};case 342:dv=an(172,12)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dv|0)==0){j=345;break}else{j=343;break};case 343:if((c[dv-4>>2]&3|0)==0){j=345;break}else{j=344;break};case 344:aIv(dv|0,0,12);j=345;break;case 345:W=dv;c[dv+4>>2]=2;c[dv>>2]=180;dl=an(186,731048)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[du>>2]|0;c[dv+8>>2]=dl;dw=dt|0;c[(c[dw>>2]|0)+(G<<2)>>2]=W;W=c[du>>2]|0;c[du>>2]=W+1;if(W>>>0>1){dx=W;j=346;break}else{j=348;break};case 346:dy=dx>>>1;W=c[dw>>2]|0;dz=W+(dy<<2)|0;dA=c[dz>>2]|0;dB=c[W+(dx<<2)>>2]|0;if((c[dB+4>>2]|0)>>>0>(c[dA+4>>2]|0)>>>0){j=347;break}else{j=348;break};case 347:c[dz>>2]=dB;c[(c[dw>>2]|0)+(dx<<2)>>2]=dA;if(dx>>>0>3){dx=dy;j=346;break}else{j=348;break};case 348:if((a[1820736]&1)==0){j=350;break}else{j=349;break};case 349:W=c[494446]|0;aG(4,730464,36,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=350;break;case 350:c[453891]=1;j=369;break;case 351:if((a[1977481]&1)==0){j=369;break}else{j=352;break};case 352:aG(6,cx|0,4096,694336,(H=i,i=i+8|0,c[H>>2]=1973385,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=aC(30,1973385,1)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c[492321]=W;dC=c[492315]|0;dD=dC+4|0;dE=c[dD>>2]|0;if(dE>>>0>1){j=353;break}else{j=357;break};case 353:dF=dC|0;dG=1;dH=dE;j=354;break;case 354:dI=c[(c[dF>>2]|0)+(dG<<2)>>2]|0;if((dI|0)==0){dJ=dH;j=356;break}else{j=355;break};case 355:ak(198,c[dI+8>>2]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(198,c[(c[dF>>2]|0)+(dG<<2)>>2]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c[(c[dF>>2]|0)+(dG<<2)>>2]=0;dJ=c[dD>>2]|0;j=356;break;case 356:W=dG+1|0;if(W>>>0<dJ>>>0){dG=W;dH=dJ;j=354;break}else{j=357;break};case 357:c[dD>>2]=1;W=dC+12|0;ak(198,c[W>>2]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c[W>>2]=0;dK=c[492315]|0;dL=dK+4|0;if((c[dL>>2]|0)>>>0<(c[dK+8>>2]|0)>>>0){j=358;break}else{j=364;break};case 358:dM=(c[492321]|0)!=0?cx:694160;dN=an(172,12)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dN|0)==0){j=361;break}else{j=359;break};case 359:if((c[dN-4>>2]&3|0)==0){j=361;break}else{j=360;break};case 360:aIv(dN|0,0,12);j=361;break;case 361:W=dN;c[dN+4>>2]=1;c[dN>>2]=180;G=an(186,dM|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dl=c[dL>>2]|0;c[dN+8>>2]=G;dO=dK|0;c[(c[dO>>2]|0)+(dl<<2)>>2]=W;W=c[dL>>2]|0;c[dL>>2]=W+1;if(W>>>0>1){dP=W;j=362;break}else{j=364;break};case 362:dQ=dP>>>1;W=c[dO>>2]|0;dR=W+(dQ<<2)|0;dS=c[dR>>2]|0;dT=c[W+(dP<<2)>>2]|0;if((c[dT+4>>2]|0)>>>0>(c[dS+4>>2]|0)>>>0){j=363;break}else{j=364;break};case 363:c[dR>>2]=dT;c[(c[dO>>2]|0)+(dP<<2)>>2]=dS;if(dP>>>0>3){dP=dQ;j=362;break}else{j=364;break};case 364:if((c[492321]|0)==0){j=368;break}else{j=365;break};case 365:if((a[1820736]&1)==0){j=367;break}else{j=366;break};case 366:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,694024,(H=i,i=i+8|0,c[H>>2]=1973385,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=367;break;case 367:c[453891]=1;j=369;break;case 368:W=c[494446]|0;aG(4,693488,51,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=369;break;case 369:ak(c[241016]|0,28);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[241028]|0,38);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[241026]|0,38);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[241018]|0,2);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[241020]|0,1186);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[241046]|0,1915040);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dU=+aE(2);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dV=dU*1.0e3;W=+Q(dV)>=1.0?dV>0.0?(ag(+P(dV/4294967296.0),4294967295.0)|0)>>>0:~~+aa((dV- +(~~dV>>>0))/4294967296.0)>>>0:0;dl=1915016;c[dl>>2]=~~dV>>>0;c[dl+4>>2]=W;dV=+aA(2,+(1.0e6/(+h[239383]*+g[453893])));if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=+Q(dV)>=1.0?dV>0.0?(ag(+P(dV/4294967296.0),4294967295.0)|0)>>>0:~~+aa((dV- +(~~dV>>>0))/4294967296.0)>>>0:0;dl=1915008;c[dl>>2]=~~dV>>>0;c[dl+4>>2]=W;aI(5844);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(1724);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(1030);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((a[1977486]&1)==0){j=370;break}else{j=371;break};case 370:a[1977486]=0;j=372;break;case 371:W=a[1977485]&1;a[1977486]=W^1;if(W<<24>>24==0){j=374;break}else{j=372;break};case 372:if((a[1820736]&1)==0){j=374;break}else{j=373;break};case 373:W=c[494446]|0;aG(4,702424,35,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=374;break;case 374:if((c[492321]|0)!=0|(a[1799172]|0)==0){j=492;break}else{j=375;break};case 375:aI(c[241058]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dW=an(172,16)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dW|0)==0){dX=0;j=491;break}else{j=376;break};case 376:if((c[dW-4>>2]&3|0)==0){j=378;break}else{j=377;break};case 377:aIv(dW|0,0,16);j=378;break;case 378:dY=dW;dZ=dW+12|0;c[dZ>>2]=1;d_=an(172,12)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((d_|0)==0){j=382;break}else{j=379;break};case 379:if((c[d_-4>>2]&3|0)==0){j=380;break}else{j=381;break};case 380:W=dW;c[W>>2]=d_;d$=W;j=383;break;case 381:aIv(d_|0,0,12);W=dW;c[W>>2]=d_;d$=W;j=383;break;case 382:c[dW>>2]=0;c[dZ>>2]=0;j=484;break;case 383:d0=an(188,1799172)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((d0|0)==0){j=384;break}else{j=385;break};case 384:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,699960,(H=i,i=i+8|0,c[H>>2]=1799172,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=484;break;case 385:d1=d0|0;W=c[d1>>2]|0;if((W|0)==0){j=386;break}else{d2=W;j=387;break};case 386:ak(4,dY|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=486;break;case 387:if((c[d2+20>>2]|0)==0){j=388;break}else{j=389;break};case 388:W=aC(12,c[d2>>2]|0,728760)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=390;break}else{j=389;break};case 389:W=c[d2+16>>2]|0;if((W|0)==0){j=485;break}else{d2=W;j=387;break};case 390:d3=c[d2+12>>2]|0;if((d3|0)==0){j=485;break}else{j=391;break};case 391:if((a[1977620]|0)==0){d4=d3;j=392;break}else{d5=d3;j=398;break};case 392:if((c[d4+20>>2]|0)==0){j=393;break}else{j=397;break};case 393:W=aC(12,c[d4>>2]|0,716008)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=394;break}else{j=397;break};case 394:d6=d4+8|0;j=395;break;case 395:d7=c[d6>>2]|0;if((d7|0)==0){j=397;break}else{j=396;break};case 396:W=aC(12,707888,c[d7>>2]|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=397;break}else{d6=d7+8|0;j=395;break};case 397:W=c[d4+16>>2]|0;if((W|0)==0){j=485;break}else{d4=W;j=392;break};case 398:if((c[d5+20>>2]|0)==0){j=399;break}else{j=405;break};case 399:W=aC(12,c[d5>>2]|0,716008)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=400;break}else{j=405;break};case 400:d8=d5+8|0;j=401;break;case 401:d9=c[d8>>2]|0;if((d9|0)==0){j=405;break}else{j=402;break};case 402:W=aC(12,707888,c[d9>>2]|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=403;break}else{d8=d9+8|0;j=401;break};case 403:ea=c[d9+4>>2]|0;if((ea|0)==0){j=405;break}else{j=404;break};case 404:W=aC(12,ea|0,1977620)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=406;break}else{j=405;break};case 405:W=c[d5+16>>2]|0;if((W|0)==0){j=485;break}else{d5=W;j=398;break};case 406:W=c[d5+12>>2]|0;eb=dW+8|0;if((W|0)==0){j=465;break}else{ec=W;j=407;break};case 407:ed=c[ec>>2]|0;W=aC(12,ed|0,723992)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=408;break}else{j=411;break};case 408:ee=c[ec+4>>2]|0;if((ee|0)==0){j=463;break}else{j=409;break};case 409:if((a[1820736]&1)==0){j=463;break}else{j=410;break};case 410:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,722560,(H=i,i=i+8|0,c[H>>2]=ee,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=463;break;case 411:W=aC(12,ed|0,721264)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=412;break}else{j=463;break};case 412:ef=c[eb>>2]|0;if((ef|0)==(c[dZ>>2]|0)){j=414;break}else{j=413;break};case 413:eg=ef;eh=c[d$>>2]|0;j=416;break;case 414:c[dZ>>2]=ef<<1;W=aC(40,c[d$>>2]|0,ef*24|0|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ei=W;c[d$>>2]=ei;if((W|0)==0){j=464;break}else{j=415;break};case 415:eg=c[eb>>2]|0;eh=ei;j=416;break;case 416:ej=eh+(eg*12|0)|0;ek=c[ec+12>>2]|0;if((ek|0)==0){j=463;break}else{j=417;break};case 417:aIv(ej|0,0,12);el=ej|0;em=eh+(eg*12|0)+8|0;en=ek;eo=1;ep=0;eq=0;j=418;break;case 418:er=c[en>>2]|0;W=aC(12,er|0,720168)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=419;break}else{j=420;break};case 419:c[el>>2]=c[en+4>>2];es=eo;et=ep;eu=eq;j=461;break;case 420:W=aC(12,er|0,719232)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=421;break}else{es=eo;et=ep;eu=eq;j=461;break};case 421:if(eo){ev=ep;j=440;break}else{j=422;break};case 422:ew=(eq|0)!=0;if(ew){j=423;break}else{ex=2;j=424;break};case 423:W=an(18,eq|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ex=W+2|0;j=424;break;case 424:ey=aC(40,eq|0,ex|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((ey|0)==0){j=425;break}else{j=426;break};case 425:c[em>>2]=0;j=463;break;case 426:if(ew){j=427;break}else{j=434;break};case 427:ez=an(18,ey|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;eA=ez>>>0>ex>>>0?0:ex-ez|0;if((eA|0)==0){eB=718128;j=431;break}else{j=428;break};case 428:eC=ey+ez|0;if((eA|0)==1){eD=718128;eE=eC;j=430;break}else{j=429;break};case 429:eF=ey+(ez+1)|0;a[eC]=43;if((eA|0)==2){eD=718129;eE=eF;j=430;break}else{j=490;break};case 430:a[eE]=0;eB=eD;j=431;break;case 431:if((a[eB]|0)==0){j=433;break}else{eG=eB;j=432;break};case 432:W=eG+1|0;if((a[W]|0)==0){j=433;break}else{eG=W;j=432;break};case 433:c[em>>2]=ey;ev=ey;j=440;break;case 434:if((ex|0)==1){eH=718128;eI=ey;j=436;break}else if((ex|0)==0){eJ=718128;j=437;break}else{j=435;break};case 435:eK=ey+1|0;a[ey]=43;if((ex|0)==2){eH=718129;eI=eK;j=436;break}else{j=489;break};case 436:a[eI]=0;eJ=eH;j=437;break;case 437:if((a[eJ]|0)==0){j=439;break}else{eL=eJ;j=438;break};case 438:W=eL+1|0;if((a[W]|0)==0){j=439;break}else{eL=W;j=438;break};case 439:c[em>>2]=ey;ev=ey;j=440;break;case 440:eM=c[en+4>>2]|0;if((eM|0)==0){j=463;break}else{j=441;break};case 441:eN=(ev|0)!=0;if(eN){j=442;break}else{eO=1;j=443;break};case 442:W=an(18,ev|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;eO=W+1|0;j=443;break;case 443:W=an(18,eM|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;eP=W+eO|0;eQ=aC(40,ev|0,eP|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((eQ|0)==0){j=444;break}else{j=445;break};case 444:c[em>>2]=0;j=463;break;case 445:if(eN){j=446;break}else{j=454;break};case 446:eR=an(18,eQ|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;eS=eR>>>0>eP>>>0?0:eP-eR|0;if((eS|0)==0){eT=eM;j=451;break}else{j=447;break};case 447:eU=eS;eV=eQ+eR|0;eW=eM;j=448;break;case 448:eX=eU-1|0;if((eX|0)==0){j=450;break}else{j=449;break};case 449:W=a[eW]|0;a[eV]=W;if(W<<24>>24==0){j=453;break}else{eU=eX;eV=eV+1|0;eW=eW+1|0;j=448;break};case 450:a[eV]=0;eT=eW;j=451;break;case 451:if((a[eT]|0)==0){j=453;break}else{eY=eT;j=452;break};case 452:W=eY+1|0;if((a[W]|0)==0){j=453;break}else{eY=W;j=452;break};case 453:c[em>>2]=eQ;es=0;et=eQ;eu=eQ;j=461;break;case 454:if((eP|0)==0){eZ=eM;j=458;break}else{e_=eP;e$=eQ;e0=eM;j=455;break};case 455:e1=e_-1|0;if((e1|0)==0){j=457;break}else{j=456;break};case 456:W=a[e0]|0;a[e$]=W;if(W<<24>>24==0){j=460;break}else{e_=e1;e$=e$+1|0;e0=e0+1|0;j=455;break};case 457:a[e$]=0;eZ=e0;j=458;break;case 458:if((a[eZ]|0)==0){j=460;break}else{e2=eZ;j=459;break};case 459:W=e2+1|0;if((a[W]|0)==0){j=460;break}else{e2=W;j=459;break};case 460:c[em>>2]=eQ;es=0;et=eQ;eu=eQ;j=461;break;case 461:W=c[en+16>>2]|0;if((W|0)==0){j=462;break}else{en=W;eo=es;ep=et;eq=eu;j=418;break};case 462:c[eb>>2]=(c[eb>>2]|0)+1;j=463;break;case 463:W=c[ec+16>>2]|0;if((W|0)==0){j=465;break}else{ec=W;j=407;break};case 464:W=c[494446]|0;aG(4,703592,68,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=485;break;case 465:if((c[eb>>2]|0)==0){j=466;break}else{j=467;break};case 466:W=c[494446]|0;ar(32,((W|0)!=0?W:c[p>>2]|0)|0,700272,(H=i,i=i+8|0,c[H>>2]=1799172,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[494446]|0;an(140,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=485;break;case 467:if((a[1803268]|0)==0){j=481;break}else{j=468;break};case 468:e3=aC(18,1803268,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((e3|0)==0){j=481;break}else{j=469;break};case 469:e4=e3+4|0;j=470;break;case 470:e5=c[e4>>2]|0;if((e5|0)==0){j=472;break}else{j=471;break};case 471:W=aC(12,1977620,c[e5+4>>2]|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=473;break}else{e4=e5+12|0;j=470;break};case 472:ak(112,e3|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=481;break;case 473:e6=an(186,c[e5+8>>2]|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=ar(22,e6|0,706256,m|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=477;break}else{e7=W;j=474;break};case 474:e8=ar(16,e7|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if(e8>>>0<(c[eb>>2]|0)>>>0){j=475;break}else{j=476;break};case 475:a[(c[d$>>2]|0)+(e8*12|0)+4|0]=1;j=476;break;case 476:W=ar(22,0,706256,m|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=477;break}else{e7=W;j=474;break};case 477:ak(198,e6|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(112,e3|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(c[241058]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[eb>>2]|0;if((W|0)==0){j=481;break}else{e9=0;fa=0;fb=W;j=478;break};case 478:fc=c[d$>>2]|0;if((a[fc+(fa*12|0)+4|0]&1)==0){fd=e9;fe=fb;j=480;break}else{j=479;break};case 479:W=e9+1|0;aH(c[241056]|0,e9|0,1,c[fc+(fa*12|0)+8>>2]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;fd=W;fe=c[eb>>2]|0;j=480;break;case 480:W=fa+1|0;if(W>>>0<fe>>>0){e9=fd;fa=W;fb=fe;j=478;break}else{j=481;break};case 481:ff=c[d1>>2]|0;if((ff|0)==0){j=483;break}else{j=482;break};case 482:ak(46,ff|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=483;break;case 483:ak(198,d0|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dX=dY;j=491;break;case 484:ak(4,dY|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dX=0;j=491;break;case 485:ak(4,dY|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=486;break;case 486:fg=c[d1>>2]|0;if((fg|0)==0){j=488;break}else{j=487;break};case 487:ak(46,fg|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=488;break;case 488:ak(198,d0|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dX=0;j=491;break;case 489:a[eK]=0;j=439;break;case 490:a[eF]=0;j=433;break;case 491:c[494422]=dX;j=492;break;case 492:a[1977789]=0;a[1977788]=1;I=0;j=509;break;case 493:aI(2472);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;fh=c[479945]|0;if((fh|0)==0){j=496;break}else{j=494;break};case 494:if((a[12473769]&1)==0){j=495;break}else{j=496;break};case 495:aI(fh|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=496;break;case 496:aI(3472);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((a[12473771]&1)==0){j=498;break}else{j=497;break};case 497:c[3118440]=0;j=498;break;case 498:if((a[12473772]&1)==0){j=500;break}else{j=499;break};case 499:c[3118439]=0;j=500;break;case 500:if((a[12473773]&1)==0){j=502;break}else{j=501;break};case 501:c[3118441]=0;j=502;break;case 502:a[12473771]=0;a[12473772]=0;a[12473773]=0;aI(c[241014]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(c[241054]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;fi=c[479954]|0;if((fi|0)==0){j=508;break}else{j=503;break};case 503:fj=fi+4104|0;if((c[fj>>2]|0)==0){j=504;break}else{j=505;break};case 504:fk=fi|0;j=507;break;case 505:fl=fi|0;fm=0;j=506;break;case 506:W=c[fi+4100>>2]|0;aH(44,c[fl>>2]|0,c[W+(fm<<4)+4>>2]|0,c[(c[c[W+(fm<<4)+8>>2]>>2]|0)+(c[W+(fm<<4)+12>>2]<<3)>>2]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=fm+1|0;if(W>>>0<(c[fj>>2]|0)>>>0){fm=W;j=506;break}else{fk=fl;j=507;break};case 507:aC(36,c[fk>>2]|0,fi+4|0)|0;if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(20,c[479954]|0);if((s|0)!=0&(t|0)!=0){k=aIx(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=508;break;case 508:aIv(1915024,0,4800);a[1977788]=0;I=1;j=509;break;case 509:i=f;return I|0;case-1:if((k|0)==1){F=t;j=510}s=t=0;break}return 0}function gi(){var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0;d=i;i=i+9216|0;e=d|0;f=d+256|0;j=d+768|0;k=d+4864|0;l=d+8960|0;a[12473775]=0;m=1744144;if((c[436035]|0)==0&((c[m>>2]|0)==65535&(c[m+4>>2]|0)==0)&(c[436040]|0)==-1){n=774}else{m=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,48)|0;o=12473936;q=(c[o>>2]&0|m&1|0)==0&(c[o+4>>2]&65536|0)==0;a[12473775]=q&1;if(q){r=0}else{n=774}}do{if((n|0)==774){q=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,43)|0;o=12473936;if((c[o>>2]&0|q&1|0)==0&(c[o+4>>2]&2048|0)==0){r=0;break}if((a[12474256]&1)!=0){r=1;break}f0();r=1}}while(0);a[12474256]=r;r=a[1820737]|0;if((r&1)==0){s=r}else{do{if((a[12473775]&1)==0){r=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,45)|0;o=12473936;if((c[o>>2]&0|r&1|0)==0&(c[o+4>>2]&8192|0)==0){t=0;break}if((a[12474320]&1)!=0){t=1;break}o=a[1919865]&1;a[1919865]=o^1;r=o<<24>>24==0?690640:690512;o=c[492315]|0;q=o+4|0;m=c[q>>2]|0;if(m>>>0>1){u=o|0;v=1;w=m;while(1){m=c[(c[u>>2]|0)+(v<<2)>>2]|0;if((m|0)==0){x=w}else{aIq(c[m+8>>2]|0);aIq(c[(c[u>>2]|0)+(v<<2)>>2]|0);c[(c[u>>2]|0)+(v<<2)>>2]=0;x=c[q>>2]|0}m=v+1|0;if(m>>>0<x>>>0){v=m;w=x}else{break}}}c[q>>2]=1;w=o+12|0;aIq(c[w>>2]|0);c[w>>2]=0;w=c[492315]|0;v=w+4|0;L1091:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){u=aIp(12)|0;do{if((u|0)!=0){if((c[u-4>>2]&3|0)==0){break}aIv(u|0,0,12)}}while(0);c[u+4>>2]=1;c[u>>2]=180;m=dv(r|0)|0;y=c[v>>2]|0;c[u+8>>2]=m;m=w|0;c[(c[m>>2]|0)+(y<<2)>>2]=u;y=c[v>>2]|0;c[v>>2]=y+1;if(y>>>0>1){z=y}else{break}while(1){y=z>>>1;A=c[m>>2]|0;B=A+(y<<2)|0;C=c[B>>2]|0;D=c[A+(z<<2)>>2]|0;if((c[D+4>>2]|0)>>>0<=(c[C+4>>2]|0)>>>0){break L1091}c[B>>2]=D;c[(c[m>>2]|0)+(z<<2)>>2]=C;if(z>>>0>3){z=y}else{break}}}}while(0);v=c[3118439]|0;do{if((v|0)!=0){w=c[3118436]|0;if((a[1919865]&1)!=0){o=c[w+8>>2]|0;fl[o&255](v)|0;break}if(fl[c[w+12>>2]&255](v)|0){break}w=c[494446]|0;o=(w|0)!=0?w:c[p>>2]|0;a5(690416,45,1,o|0)|0;o=c[494446]|0;w=(o|0)!=0?o:c[p>>2]|0;a_(w|0)|0;a[1820737]=0}}while(0);if((a[1820736]&1)==0){t=1;break}v=c[494446]|0;w=(v|0)!=0?v:c[p>>2]|0;ei(w|0,727024,(E=i,i=i+8|0,c[E>>2]=r,E)|0)|0;i=E;w=c[494446]|0;v=(w|0)!=0?w:c[p>>2]|0;a_(v|0)|0;t=1}else{t=0}}while(0);a[12474320]=t;s=a[1820737]|0}t=l|0;do{if((s&1)!=0){l=a[12473775]|0;if((l&1)==0){z=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,49)|0;x=12473936;G=(c[x>>2]&0|z&1|0)!=0|(c[x+4>>2]&131072|0)!=0;H=a[12473775]|0}else{G=0;H=l}if((H&1)==0){l=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,50)|0;x=12473936;I=(c[x>>2]&0|l&1|0)!=0|(c[x+4>>2]&262144|0)!=0}else{I=0}if(!(G|I)){break}J=G?.5:0.0;if(I){K=J+-.5}else{K=J}J=K+ +g[479979];g[479979]=J;do{if(J>12.0){g[479979]=12.0;L=12.0}else{if(J>=-80.0){L=J;break}g[479979]=-80.0;L=-80.0}}while(0);J=L;bQ(t|0,256,690760,(E=i,i=i+8|0,h[E>>3]=J,E)|0)|0;i=E;r=c[492315]|0;x=r+4|0;l=c[x>>2]|0;if(l>>>0>1){z=r|0;v=1;w=l;while(1){l=c[(c[z>>2]|0)+(v<<2)>>2]|0;if((l|0)==0){M=w}else{aIq(c[l+8>>2]|0);aIq(c[(c[z>>2]|0)+(v<<2)>>2]|0);c[(c[z>>2]|0)+(v<<2)>>2]=0;M=c[x>>2]|0}l=v+1|0;if(l>>>0<M>>>0){v=l;w=M}else{break}}}c[x>>2]=1;w=r+12|0;aIq(c[w>>2]|0);c[w>>2]=0;w=c[492315]|0;v=w+4|0;L1136:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){z=aIp(12)|0;do{if((z|0)!=0){if((c[z-4>>2]&3|0)==0){break}aIv(z|0,0,12)}}while(0);c[z+4>>2]=1;c[z>>2]=180;l=dv(t|0)|0;o=c[v>>2]|0;c[z+8>>2]=l;l=w|0;c[(c[l>>2]|0)+(o<<2)>>2]=z;o=c[v>>2]|0;c[v>>2]=o+1;if(o>>>0>1){N=o}else{break}while(1){o=N>>>1;q=c[l>>2]|0;m=q+(o<<2)|0;u=c[m>>2]|0;y=c[q+(N<<2)>>2]|0;if((c[y+4>>2]|0)>>>0<=(c[u+4>>2]|0)>>>0){break L1136}c[m>>2]=y;c[(c[l>>2]|0)+(N<<2)>>2]=u;if(N>>>0>3){N=o}else{break}}}}while(0);if((a[1820736]&1)!=0){v=c[494446]|0;w=(v|0)!=0?v:c[p>>2]|0;ei(w|0,727024,(E=i,i=i+8|0,c[E>>2]=t,E)|0)|0;i=E;w=c[494446]|0;v=(w|0)!=0?w:c[p>>2]|0;a_(v|0)|0}g[479980]=+S(10.0,+(+g[479979]/20.0))}}while(0);c[494379]=(c[494379]|0)+1;a[1977490]=(fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,684424,0,1,0,16)|0)<<16>>16!=0|0;a[1977491]=(fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,684424,1,1,0,16)|0)<<16>>16!=0|0;a[1977492]=(fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,684424,2,1,0,16)|0)<<16>>16!=0|0;a[1977493]=(fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,684424,3,1,0,16)|0)<<16>>16!=0|0;a[1977494]=(fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,684424,4,1,0,16)|0)<<16>>16!=0|0;a[1977495]=(fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,684424,5,1,0,16)|0)<<16>>16!=0|0;a[1977496]=(fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,684424,6,1,0,16)|0)<<16>>16!=0|0;a[1977497]=(fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,684424,7,1,0,16)|0)<<16>>16!=0|0;do{if((a[12473775]&1)==0){t=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,54)|0;N=12473936;if((c[N>>2]&0|t&1|0)==0&(c[N+4>>2]&4194304|0)==0){O=0;break}N=c[(c[3118438]|0)+28>>2]|0;if((N|0)==0){O=0;break}if((a[12474336]&1)!=0){O=1;break}t=a[12474344]&1;M=t^1;a[12474344]=M;if((a[1820736]&1)==0){P=N;Q=M}else{M=c[494446]|0;N=(M|0)!=0?M:c[p>>2]|0;M=t<<24>>24==0?702496:702224;ei(N|0,691344,(E=i,i=i+8|0,c[E>>2]=M,E)|0)|0;i=E;M=c[494446]|0;N=(M|0)!=0?M:c[p>>2]|0;a_(N|0)|0;P=c[(c[3118438]|0)+28>>2]|0;Q=a[12474344]|0}fj[P&511](c[3118441]|0,(Q&1)!=0);N=c[3118488]|0;if((N|0)==0){O=1;break}M=c[N+32>>2]|0;if((M|0)==0){O=1;break}fj[M&511](c[3118440]|0,(a[12474344]&1)==0);O=1}else{O=0}}while(0);a[12474336]=O;if((c[3118482]|0)!=0){do{if((a[12473775]&1)==0){O=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,51)|0;Q=12473936;if((c[Q>>2]&0|O&1|0)==0&(c[Q+4>>2]&524288|0)==0){R=0;break}if((a[964040]&1)!=0){R=1;break}Q=c[3118482]|0;O=Q+28|0;P=c[O>>2]|0;M=Q+20|0;c[M>>2]=P;N=c[Q+12>>2]|0;t=Q+16|0;c[t>>2]=N+(P*136|0);I=Q+4|0;G=c[(c[I>>2]|0)+4>>2]|0;H=Q|0;s=c[H>>2]|0;v=c[N+(P*136|0)+8>>2]|0;w=c[N+(P*136|0)+12>>2]|0;r=c[N+(P*136|0)+16>>2]|0;fE[G&15](s,v,w,r)|0;r=c[t>>2]|0;fn[c[(c[I>>2]|0)+12>>2]&7](c[H>>2]|0,+g[r+24>>2],+g[r+28>>2],+g[r+32>>2],+g[r+36>>2]);fj[c[(c[I>>2]|0)+16>>2]&511](c[H>>2]|0,(a[(c[t>>2]|0)+68|0]&1)!=0);a[Q+9|0]=1;c[O>>2]=(((c[M>>2]|0)+1|0)>>>0)%((c[Q+24>>2]|0)>>>0)|0;R=1}else{R=0}}while(0);a[964040]=R}if((a[12473775]&1)==0){R=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,35)|0;Q=12473936;T=((c[Q>>2]&0|R&1|0)!=0|(c[Q+4>>2]&8|0)!=0)&1}else{T=0}do{if((a[1977487]&1)==0){if((a[12473775]&1)!=0){U=0;break}Q=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,36)|0;R=12473936;U=((c[R>>2]&0|Q&1|0)!=0|(c[R+4>>2]&16|0)!=0)&1}else{U=0}}while(0);R=U|T;if((a[1815576]&1)==0){V=1}else{V=fl[c[(c[3118437]|0)+16>>2]&255](c[3118440]|0)|0}do{if(R<<24>>24==0|V^1){n=863}else{if((a[12474296]&1)!=0){n=863;break}T=a[1977487]&1;a[1977487]=T^1;U=(a[1820736]&1)!=0;if(T<<24>>24==0){if(U){T=c[494446]|0;Q=(T|0)!=0?T:c[p>>2]|0;a5(692120,19,1,Q|0)|0;Q=c[494446]|0;T=(Q|0)!=0?Q:c[p>>2]|0;a_(T|0)|0}T=c[3118439]|0;if((T|0)==0){break}Q=c[(c[3118436]|0)+8>>2]|0;fl[Q&255](T)|0;break}if(U){U=c[494446]|0;T=(U|0)!=0?U:c[p>>2]|0;a5(691904,21,1,T|0)|0;T=c[494446]|0;U=(T|0)!=0?T:c[p>>2]|0;a_(U|0)|0}U=c[3118439]|0;if((U|0)==0){break}if((a[1919865]&1)!=0){break}if(fl[c[(c[3118436]|0)+12>>2]&255](U)|0){break}U=c[494446]|0;T=(U|0)!=0?U:c[p>>2]|0;a5(691744,81,1,T|0)|0;T=c[494446]|0;U=(T|0)!=0?T:c[p>>2]|0;a_(U|0)|0;a[1820737]=0}}while(0);do{if((n|0)==863){U=(a[684464]&1)==0;if(!V){if(U){break}if((a[1820736]&1)!=0){T=c[494446]|0;Q=(T|0)!=0?T:c[p>>2]|0;a5(692120,19,1,Q|0)|0;Q=c[494446]|0;T=(Q|0)!=0?Q:c[p>>2]|0;a_(T|0)|0}a[1977487]=1;T=c[3118439]|0;if((T|0)==0){break}Q=c[(c[3118436]|0)+8>>2]|0;fl[Q&255](T)|0;break}if(!U){break}if((a[1820736]&1)!=0){U=c[494446]|0;T=(U|0)!=0?U:c[p>>2]|0;a5(691904,21,1,T|0)|0;T=c[494446]|0;U=(T|0)!=0?T:c[p>>2]|0;a_(U|0)|0}a[1977487]=0;U=c[3118439]|0;if((U|0)==0){break}if((a[1919865]&1)!=0){break}if(fl[c[(c[3118436]|0)+12>>2]&255](U)|0){break}U=c[494446]|0;T=(U|0)!=0?U:c[p>>2]|0;a5(691744,81,1,T|0)|0;T=c[494446]|0;U=(T|0)!=0?T:c[p>>2]|0;a_(U|0)|0;a[1820737]=0}}while(0);a[684464]=V&1;a[12474296]=R;do{if((a[12473775]&1)==0){R=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,36)|0;V=12473936;if((c[V>>2]&0|R&1|0)==0&(c[V+4>>2]&16|0)==0){W=0;X=0;break}W=a[12474304]&1^1;X=1}else{W=0;X=0}}while(0);a[1977488]=W;a[12474304]=X;do{if((a[12473775]&1)==0){X=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,33)|0;W=12473936;if((c[W>>2]&0|X&1|0)==0&(c[W+4>>2]&2|0)==0){Y=0;Z=0;break}Y=a[12474312]&1^1;Z=1}else{Y=0;Z=0}}while(0);a[1977488]=(a[1977488]&1|Y|0)!=0|0;a[12474312]=Z;do{if((a[12473775]&1)==0){Z=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,29)|0;Y=12473936;if((c[Y>>2]&536870912|Z&1|0)==0&(c[Y+4>>2]&0|0)==0){_=0;n=896;break}if((a[12474352]&1)!=0){_=1;n=896;break}a[1717376]=a[1717376]&1^1;a[12473769]=a[1919776]&1;a[12473770]=0;gL();Y=c[479945]|0;do{if((Y|0)!=0){if((a[12473769]&1)!=0){break}fG[Y&16383]()}}while(0);gM();if((a[12473771]&1)!=0){c[3118440]=0}if((a[12473772]&1)!=0){c[3118439]=0}if((a[12473773]&1)!=0){c[3118441]=0}a[12473771]=0;a[12473772]=0;a[12473773]=0;gK();a[12473769]=0;Y=c[3118438]|0;if((Y|0)!=0){fi[c[Y+4>>2]&255](c[3118441]|0)}a[12474352]=1;if((a[1977487]&1)==0){break}f1()}else{_=0;n=896}}while(0);if((n|0)==896){a[12474352]=_}do{if((a[1977487]&1)!=0){if((a[1977488]&1)!=0){break}i=d;return}}while(0);_=a[12473775]|0;if((_&1)==0){Y=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,25)|0;Z=12473936;$=(c[Z>>2]&33554432|Y&1|0)!=0|(c[Z+4>>2]&0|0)!=0;aa=a[12473775]|0}else{$=0;aa=_}if((aa&1)==0){aa=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,26)|0;_=12473936;ab=(c[_>>2]&67108864|aa&1|0)!=0|(c[_+4>>2]&0|0)!=0}else{ab=0}do{if($){if((a[12474368]&1)!=0){n=915;break}_=a[12473776]&1;a[12473776]=_^1;aa=_<<24>>24==0;Z=c[3118440]|0;if((a[1820738]&1)!=0&(Z|0)!=0){if((a[1717392]&1)==0){n=910}else{if((a[1915101]&1)==0){ac=aa}else{n=910}}if((n|0)==910){ac=1}fj[c[(c[3118437]|0)+8>>2]&511](Z,ac)}Z=c[3118439]|0;if((a[1820737]&1)!=0&(Z|0)!=0){fj[c[(c[3118436]|0)+16>>2]&511](Z,(_&a[1738e3])<<24>>24==0)}c[479960]=aa?c[479961]|0:c[479962]|0}else{n=915}}while(0);do{if((n|0)==915){if((a[12474360]&1|0)==(ab&1|0)){break}a[12473776]=ab&1;ac=c[3118440]|0;if((a[1820738]&1)!=0&(ac|0)!=0){if((a[1717392]&1)==0){n=919}else{if((a[1915101]&1)==0){ad=ab}else{n=919}}if((n|0)==919){ad=1}fj[c[(c[3118437]|0)+8>>2]&511](ac,ad)}ac=c[3118439]|0;if((a[1820737]&1)!=0&(ac|0)!=0){fj[c[(c[3118436]|0)+16>>2]&511](ac,(a[1738e3]&1)==0|ab)}c[479960]=ab?c[479961]|0:c[479962]|0}}while(0);a[12474368]=$&1;a[12474360]=ab&1;do{if((a[12473775]&1)==0){ab=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,31)|0;$=12473936;if((c[$>>2]&-2147483648|ab&1|0)==0&(c[$+4>>2]&0|0)==0){ae=0;break}if((a[12474224]&1)!=0){ae=1;break}$=e|0;ab=(c[478750]|0)+1|0;c[478750]=ab;ad=c[492315]|0;if((ad|0)==0){af=ab}else{ab=ad+4|0;ac=c[ab>>2]|0;if(ac>>>0>1){aa=ad|0;_=1;Z=ac;while(1){ac=c[(c[aa>>2]|0)+(_<<2)>>2]|0;if((ac|0)==0){ag=Z}else{aIq(c[ac+8>>2]|0);aIq(c[(c[aa>>2]|0)+(_<<2)>>2]|0);c[(c[aa>>2]|0)+(_<<2)>>2]=0;ag=c[ab>>2]|0}ac=_+1|0;if(ac>>>0<ag>>>0){_=ac;Z=ag}else{break}}}c[ab>>2]=1;Z=ad+12|0;aIq(c[Z>>2]|0);c[Z>>2]=0;af=c[478750]|0}bQ($|0,256,718216,(E=i,i=i+8|0,c[E>>2]=af,E)|0)|0;i=E;Z=c[492315]|0;L1299:do{if((Z|0)!=0){_=Z+4|0;if((c[_>>2]|0)>>>0>=(c[Z+8>>2]|0)>>>0){break}aa=aIp(12)|0;do{if((aa|0)!=0){if((c[aa-4>>2]&3|0)==0){break}aIv(aa|0,0,12)}}while(0);c[aa+4>>2]=1;c[aa>>2]=180;ac=dv($|0)|0;Y=c[_>>2]|0;c[aa+8>>2]=ac;ac=Z|0;c[(c[ac>>2]|0)+(Y<<2)>>2]=aa;Y=c[_>>2]|0;c[_>>2]=Y+1;if(Y>>>0>1){ah=Y}else{break}while(1){Y=ah>>>1;W=c[ac>>2]|0;X=W+(Y<<2)|0;V=c[X>>2]|0;R=c[W+(ah<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[V+4>>2]|0)>>>0){break L1299}c[X>>2]=R;c[(c[ac>>2]|0)+(ah<<2)>>2]=V;if(ah>>>0>3){ah=Y}else{break}}}}while(0);if((a[1820736]&1)==0){ae=1;break}Z=c[494446]|0;ad=(Z|0)!=0?Z:c[p>>2]|0;ei(ad|0,727024,(E=i,i=i+8|0,c[E>>2]=$,E)|0)|0;i=E;ad=c[494446]|0;Z=(ad|0)!=0?ad:c[p>>2]|0;a_(Z|0)|0;ae=1}else{ae=0}}while(0);a[12474224]=ae;do{if((a[12473775]&1)==0){ae=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,32)|0;ah=12473936;if((c[ah>>2]&0|ae&1|0)==0&(c[ah+4>>2]&1|0)==0){ai=0;break}if((a[12474232]&1)!=0){ai=1;break}ah=e|0;ae=c[478750]|0;if((ae|0)==0){aj=0}else{af=ae-1|0;c[478750]=af;aj=af}af=c[492315]|0;if((af|0)==0){ak=aj}else{ae=af+4|0;ag=c[ae>>2]|0;if(ag>>>0>1){Z=af|0;ad=1;ab=ag;while(1){ag=c[(c[Z>>2]|0)+(ad<<2)>>2]|0;if((ag|0)==0){al=ab}else{aIq(c[ag+8>>2]|0);aIq(c[(c[Z>>2]|0)+(ad<<2)>>2]|0);c[(c[Z>>2]|0)+(ad<<2)>>2]=0;al=c[ae>>2]|0}ag=ad+1|0;if(ag>>>0<al>>>0){ad=ag;ab=al}else{break}}}c[ae>>2]=1;ab=af+12|0;aIq(c[ab>>2]|0);c[ab>>2]=0;ak=c[478750]|0}bQ(ah|0,256,718216,(E=i,i=i+8|0,c[E>>2]=ak,E)|0)|0;i=E;ab=c[492315]|0;L1330:do{if((ab|0)!=0){ad=ab+4|0;if((c[ad>>2]|0)>>>0>=(c[ab+8>>2]|0)>>>0){break}Z=aIp(12)|0;do{if((Z|0)!=0){if((c[Z-4>>2]&3|0)==0){break}aIv(Z|0,0,12)}}while(0);c[Z+4>>2]=1;c[Z>>2]=180;$=dv(ah|0)|0;ag=c[ad>>2]|0;c[Z+8>>2]=$;$=ab|0;c[(c[$>>2]|0)+(ag<<2)>>2]=Z;ag=c[ad>>2]|0;c[ad>>2]=ag+1;if(ag>>>0>1){am=ag}else{break}while(1){ag=am>>>1;ac=c[$>>2]|0;_=ac+(ag<<2)|0;aa=c[_>>2]|0;Y=c[ac+(am<<2)>>2]|0;if((c[Y+4>>2]|0)>>>0<=(c[aa+4>>2]|0)>>>0){break L1330}c[_>>2]=Y;c[(c[$>>2]|0)+(am<<2)>>2]=aa;if(am>>>0>3){am=ag}else{break}}}}while(0);if((a[1820736]&1)==0){ai=1;break}ab=c[494446]|0;af=(ab|0)!=0?ab:c[p>>2]|0;ei(af|0,727024,(E=i,i=i+8|0,c[E>>2]=ah,E)|0)|0;i=E;af=c[494446]|0;ab=(af|0)!=0?af:c[p>>2]|0;a_(ab|0)|0;ai=1}else{ai=0}}while(0);a[12474232]=ai;ai=(c[492321]|0)==0;do{if((a[12473775]&1)==0){am=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,28)|0;ak=12473936;if((c[ak>>2]&268435456|am&1|0)==0&(c[ak+4>>2]&0|0)==0){an=0;break}if((a[12474264]&1)!=0){an=1;break}f9();an=1}else{an=0}}while(0);a[12474264]=an&1;if(ai){do{if((a[12473775]&1)==0){ai=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,27)|0;ak=12473936;am=(c[ak>>2]&134217728|ai&1|0)!=0|(c[ak+4>>2]&0|0)!=0;if(an|am^1){ao=am;break}if((a[12474272]&1)!=0){ao=am;break}f7();ao=am}else{ao=0}}while(0);a[12474272]=ao&1}if((a[1969280]&1)!=0){ao=c[479970]|0;if(f4((c[479969]|0)+(ao<<1)|0,(c[479971]|0)-ao|0)|0){ap=a[1820737]&1}else{ap=0}a[1820737]=ap}a[1969280]=0;do{if(a[684456]|0){if((c[492317]|0)==0){break}L1366:do{if((a[12473775]&1)==0){ap=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,33)|0;ao=12473936;if((c[ao>>2]&0|ap&1|0)==0&(c[ao+4>>2]&2|0)==0){n=1027;break}ao=c[492315]|0;ap=ao+4|0;an=c[ap>>2]|0;if(an>>>0>1){am=ao|0;ak=1;ai=an;while(1){an=c[(c[am>>2]|0)+(ak<<2)>>2]|0;if((an|0)==0){aq=ai}else{aIq(c[an+8>>2]|0);aIq(c[(c[am>>2]|0)+(ak<<2)>>2]|0);c[(c[am>>2]|0)+(ak<<2)>>2]=0;aq=c[ap>>2]|0}an=ak+1|0;if(an>>>0<aq>>>0){ak=an;ai=aq}else{break}}}c[ap>>2]=1;ai=ao+12|0;aIq(c[ai>>2]|0);c[ai>>2]=0;ai=c[492317]|0;ak=ai+12|0;am=c[ak>>2]|0;an=am;al=ai+28|0;do{if((a[al]&1)==0){aj=ai+16|0;e=ai+8|0;ab=c[e>>2]|0;af=(c[aj>>2]|0)-1&ab;c[aj>>2]=af;ae=ai+20|0;$=c[ae>>2]|0;if((af|0)==($|0)){c[aj>>2]=af+1&ab;ad=c[492315]|0;Z=ad+4|0;if((c[Z>>2]|0)>>>0>=(c[ad+8>>2]|0)>>>0){break L1366}ag=aIp(12)|0;do{if((ag|0)!=0){if((c[ag-4>>2]&3|0)==0){break}aIv(ag|0,0,12)}}while(0);c[ag+4>>2]=0;c[ag>>2]=30;aa=dv(692368)|0;Y=c[Z>>2]|0;c[ag+8>>2]=aa;aa=ad|0;c[(c[aa>>2]|0)+(Y<<2)>>2]=ag;Y=c[Z>>2]|0;c[Z>>2]=Y+1;if(Y>>>0>1){ar=Y}else{break L1366}while(1){Y=ar>>>1;_=c[aa>>2]|0;ac=_+(Y<<2)|0;V=c[ac>>2]|0;R=c[_+(ar<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[V+4>>2]|0)>>>0){break L1366}c[ac>>2]=R;c[(c[aa>>2]|0)+(ar<<2)>>2]=V;if(ar>>>0>3){ar=Y}else{break L1366}}}else{aa=ai|0;Z=(c[aa>>2]|0)+(af<<3)|0;ag=c[Z>>2]|0;ad=c[Z+4>>2]|0;if((ag|0)==0&(ad|0)==0){as=af;at=$;au=ab}else{Z=ad;ad=ag;ag=am;while(1){Y=ag+(Z<<2)|0;c[Y>>2]=c[Y>>2]^ad;av=c[e>>2]|0;aw=(c[aj>>2]|0)-1&av;c[aj>>2]=aw;Y=(c[aa>>2]|0)+(aw<<3)|0;V=c[Y>>2]|0;R=c[Y+4>>2]|0;if((V|0)==0&(R|0)==0){break}Z=R;ad=V;ag=c[ak>>2]|0}as=aw;at=c[ae>>2]|0;au=av}if((as|0)!=(at|0)){break}c[aj>>2]=at+1&au;break}}else{a[al]=0}}while(0);a[1969280]=1;al=c[479971]|0;c[479970]=al;L1400:do{if((c[479959]|0)!=0){ak=0;am=al;while(1){ai=b[(c[479968]|0)+((ak|1)<<1)>>1]|0;ao=am-1|0;c[479970]=ao;b[(c[479969]|0)+(ao<<1)>>1]=ai;ai=b[(c[479968]|0)+(ak<<1)>>1]|0;ao=(c[479970]|0)-1|0;c[479970]=ao;b[(c[479969]|0)+(ao<<1)>>1]=ai;ai=ak+2|0;if(ai>>>0>=(c[479959]|0)>>>0){break L1400}ak=ai;am=c[479970]|0}}}while(0);c[479959]=0;al=c[492315]|0;am=al+4|0;L1405:do{if((c[am>>2]|0)>>>0<(c[al+8>>2]|0)>>>0){ak=(a[1977487]&1)!=0?1:30;aj=aIp(12)|0;do{if((aj|0)!=0){if((c[aj-4>>2]&3|0)==0){break}aIv(aj|0,0,12)}}while(0);c[aj+4>>2]=0;c[aj>>2]=ak;ae=dv(692464)|0;ai=c[am>>2]|0;c[aj+8>>2]=ae;ae=al|0;c[(c[ae>>2]|0)+(ai<<2)>>2]=aj;ai=c[am>>2]|0;c[am>>2]=ai+1;if(ai>>>0>1){ax=ai}else{break}while(1){ai=ax>>>1;ao=c[ae>>2]|0;ap=ao+(ai<<2)|0;ag=c[ap>>2]|0;ad=c[ao+(ax<<2)>>2]|0;if((c[ad+4>>2]|0)>>>0<=(c[ag+4>>2]|0)>>>0){break L1405}c[ap>>2]=ad;c[(c[ae>>2]|0)+(ax<<2)>>2]=ag;if(ax>>>0>3){ax=ai}else{break}}}}while(0);am=c[241012]|0;al=c[492319]|0;fA[am&63](an,al)|0;al=c[492321]|0;if((al|0)==0){break}a[al+33|0]=1;am=al+20|0;ae=c[am>>2]|0;aj=c[al+12>>2]|0;do{if(ae>>>0<2){ak=c[aj>>2]|0;ai=al+28|0;if((ak|0)!=(c[ai>>2]|0)){ay=ai;n=1015;break}c[am>>2]=0;ag=c[al>>2]|0;ev(ag|0,ak|0,0)|0;az=ai}else{ay=al+28|0;n=1015}}while(0);if((n|0)==1015){an=ae-((a[al+32|0]&1)!=0?1:2)&c[al+16>>2];c[am>>2]=an;ai=c[al>>2]|0;ak=c[aj+(an<<2)>>2]|0;ev(ai|0,ak|0,0)|0;az=ay}ak=al|0;ai=cf(c[ak>>2]|0)|0;an=c[az>>2]|0;if((ai|0)>(an|0)){break}ai=c[ak>>2]|0;if((a[al+24|0]&1)==0){ev(ai|0,16,0)|0;ag=c[241032]|0;ad=al+4|0;ap=c[ad>>2]|0;ao=al+8|0;Z=c[ao>>2]|0;fA[ag&63](ap,Z)|0;Z=c[ad>>2]|0;ad=c[ao>>2]|0;ao=c[ak>>2]|0;a5(Z|0,1,ad|0,ao|0)|0;break}else{ev(ai|0,an|0,0)|0;break}}else{n=1027}}while(0);do{if((n|0)==1027){ah=c[453891]|0;an=(((c[3118570]|0)+1|0)>>>0)%(((ah|0)!=0?ah:1)>>>0)|0;c[3118570]=an;if(!((an|0)==0|(c[492321]|0)!=0)){break}an=c[241032]|0;ah=c[492318]|0;ai=c[492319]|0;fA[an&63](ah,ai)|0;ai=c[492317]|0;ah=c[492318]|0;an=ai+12|0;ao=c[an>>2]|0;ad=ah;Z=ai+16|0;ak=c[Z>>2]|0;c[Z>>2]=ak+1;ap=ai|0;ag=(c[ap>>2]|0)+(ak<<3)|0;c[ag>>2]=0;c[ag+4>>2]=0;ag=ai+8|0;ak=c[ag>>2]|0;aa=c[Z>>2]&ak;c[Z>>2]=aa;e=ai+20|0;ab=(aa|0)==(c[e>>2]|0);$=ai+24|0;af=c[$>>2]|0;if((af|0)==0){aA=ab;aB=aa;aC=ak;aD=0}else{V=0;R=0;Y=ab;ab=aa;aa=ak;ak=af;while(1){af=R;ac=c[ao+(af<<2)>>2]|0;_=c[ad+(af<<2)>>2]|0;if((ac|0)==(_|0)){aE=Y;aF=ab;aG=aa;aH=ak}else{af=(c[ap>>2]|0)+(ab<<3)|0;c[af>>2]=_^ac;c[af+4>>2]=R;af=c[ag>>2]|0;ac=(c[Z>>2]|0)+1&af;c[Z>>2]=ac;aE=(ac|0)==(c[e>>2]|0)|Y;aF=ac;aG=af;aH=c[$>>2]|0}af=aIF(R,V,1,0)|0;ac=F;_=0;if(ac>>>0<_>>>0|ac>>>0==_>>>0&af>>>0<aH>>>0){V=ac;R=af;Y=aE;ab=aF;aa=aG;ak=aH}else{aA=aE;aB=aF;aC=aG;aD=aH;break}}}do{if(aA){ak=aB+1&aC;c[e>>2]=ak;aa=c[ap>>2]|0;ab=aa+(ak<<3)|0;if((c[ab>>2]|0)==0&(c[ab+4>>2]|0)==0){break}else{aI=ak}do{aI=aI+1&aC;c[e>>2]=aI;ak=aa+(aI<<3)|0;}while(!((c[ak>>2]|0)==0&(c[ak+4>>2]|0)==0))}}while(0);e=c[an>>2]|0;ap=aD<<2;aIy(e|0,ah|0,ap)|0;a[ai+28|0]=1}}while(0);fi[c[241028]&255]((a[1969280]&1)!=0?242:38);fi[c[241026]&255]((a[1969280]&1)!=0?10:38)}else{a[684456]=1}}while(0);L1444:do{if((a[12473775]&1)==0){aD=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,47)|0;aI=12473936;aC=(c[aI>>2]&0|aD&1|0)!=0|(c[aI+4>>2]&32768|0)!=0;a[1977489]=aC&1;if(!aC){break}aC=c[492315]|0;aI=aC+4|0;aD=c[aI>>2]|0;if(aD>>>0>1){aB=aC|0;aA=1;aH=aD;while(1){aD=c[(c[aB>>2]|0)+(aA<<2)>>2]|0;if((aD|0)==0){aJ=aH}else{aIq(c[aD+8>>2]|0);aIq(c[(c[aB>>2]|0)+(aA<<2)>>2]|0);c[(c[aB>>2]|0)+(aA<<2)>>2]=0;aJ=c[aI>>2]|0}aD=aA+1|0;if(aD>>>0<aJ>>>0){aA=aD;aH=aJ}else{break}}}c[aI>>2]=1;aH=aC+12|0;aIq(c[aH>>2]|0);c[aH>>2]=0;aH=c[492315]|0;aA=aH+4|0;if((c[aA>>2]|0)>>>0>=(c[aH+8>>2]|0)>>>0){break}aB=(a[1969280]&1)!=0?692752:692616;aD=aIp(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}aIv(aD|0,0,12)}}while(0);c[aD+4>>2]=0;c[aD>>2]=30;aC=dv(aB|0)|0;aI=c[aA>>2]|0;c[aD+8>>2]=aC;aC=aH|0;c[(c[aC>>2]|0)+(aI<<2)>>2]=aD;aI=c[aA>>2]|0;c[aA>>2]=aI+1;if(aI>>>0>1){aK=aI}else{break}while(1){aI=aK>>>1;aG=c[aC>>2]|0;aF=aG+(aI<<2)|0;aE=c[aF>>2]|0;az=c[aG+(aK<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[aE+4>>2]|0)>>>0){break L1444}c[aF>>2]=az;c[(c[aC>>2]|0)+(aK<<2)>>2]=aE;if(aK>>>0>3){aK=aI}else{break}}}else{a[1977489]=0}}while(0);do{if((a[12473775]&1)==0){aK=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,34)|0;aJ=12473936;if((c[aJ>>2]&0|aK&1|0)==0&(c[aJ+4>>2]&4|0)==0){aL=0;aM=0;break}aL=(a[12474328]&1)==0;aM=1}else{aL=0;aM=0}}while(0);do{if((a[1973384]&1)==0){if(!aL){break}aJ=j|0;aK=k|0;if((c[492321]|0)==0){c[453891]=1;aC=c[478750]|0;if((aC|0)==0){bQ(aJ|0,4096,694520,(E=i,i=i+8|0,c[E>>2]=1969288,E)|0)|0;i=E}else{bQ(aJ|0,4096,694600,(E=i,i=i+16|0,c[E>>2]=1969288,c[E+8>>2]=aC,E)|0)|0;i=E}bQ(aK|0,4096,694336,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;c[492321]=hl(aJ,1)|0;aC=c[492315]|0;aA=aC+4|0;aD=c[aA>>2]|0;if(aD>>>0>1){aH=aC|0;aB=1;aI=aD;while(1){aD=c[(c[aH>>2]|0)+(aB<<2)>>2]|0;if((aD|0)==0){aN=aI}else{aIq(c[aD+8>>2]|0);aIq(c[(c[aH>>2]|0)+(aB<<2)>>2]|0);c[(c[aH>>2]|0)+(aB<<2)>>2]=0;aN=c[aA>>2]|0}aD=aB+1|0;if(aD>>>0<aN>>>0){aB=aD;aI=aN}else{break}}}c[aA>>2]=1;aI=aC+12|0;aIq(c[aI>>2]|0);c[aI>>2]=0;aI=c[492315]|0;aB=aI+4|0;L1535:do{if((c[aB>>2]|0)>>>0<(c[aI+8>>2]|0)>>>0){aH=(c[492321]|0)!=0?aK:694160;aD=aIp(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}aIv(aD|0,0,12)}}while(0);c[aD+4>>2]=1;c[aD>>2]=180;ai=dv(aH|0)|0;ah=c[aB>>2]|0;c[aD+8>>2]=ai;ai=aI|0;c[(c[ai>>2]|0)+(ah<<2)>>2]=aD;ah=c[aB>>2]|0;c[aB>>2]=ah+1;if(ah>>>0>1){aO=ah}else{break}while(1){ah=aO>>>1;an=c[ai>>2]|0;aE=an+(ah<<2)|0;az=c[aE>>2]|0;aF=c[an+(aO<<2)>>2]|0;if((c[aF+4>>2]|0)>>>0<=(c[az+4>>2]|0)>>>0){break L1535}c[aE>>2]=aF;c[(c[ai>>2]|0)+(aO<<2)>>2]=az;if(aO>>>0>3){aO=ah}else{break}}}}while(0);if((c[492321]|0)==0){aB=c[494446]|0;aI=(aB|0)!=0?aB:c[p>>2]|0;a5(693488,51,1,aI|0)|0;aI=c[494446]|0;aB=(aI|0)!=0?aI:c[p>>2]|0;a_(aB|0)|0;break}if((a[1820736]&1)==0){break}aB=c[494446]|0;aI=(aB|0)!=0?aB:c[p>>2]|0;ei(aI|0,694024,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;aI=c[494446]|0;aB=(aI|0)!=0?aI:c[p>>2]|0;a_(aB|0)|0;break}else{aB=c[492315]|0;aI=aB+4|0;aK=c[aI>>2]|0;if(aK>>>0>1){aC=aB|0;aA=1;ai=aK;while(1){aK=c[(c[aC>>2]|0)+(aA<<2)>>2]|0;if((aK|0)==0){aP=ai}else{aIq(c[aK+8>>2]|0);aIq(c[(c[aC>>2]|0)+(aA<<2)>>2]|0);c[(c[aC>>2]|0)+(aA<<2)>>2]=0;aP=c[aI>>2]|0}aK=aA+1|0;if(aK>>>0<aP>>>0){aA=aK;ai=aP}else{break}}}c[aI>>2]=1;ai=aB+12|0;aIq(c[ai>>2]|0);c[ai>>2]=0;ai=c[492315]|0;aA=ai+4|0;L1503:do{if((c[aA>>2]|0)>>>0<(c[ai+8>>2]|0)>>>0){aC=aIp(12)|0;do{if((aC|0)!=0){if((c[aC-4>>2]&3|0)==0){break}aIv(aC|0,0,12)}}while(0);c[aC+4>>2]=2;c[aC>>2]=180;aJ=dv(694840)|0;aK=c[aA>>2]|0;c[aC+8>>2]=aJ;aJ=ai|0;c[(c[aJ>>2]|0)+(aK<<2)>>2]=aC;aK=c[aA>>2]|0;c[aA>>2]=aK+1;if(aK>>>0>1){aQ=aK}else{break}while(1){aK=aQ>>>1;aD=c[aJ>>2]|0;aH=aD+(aK<<2)|0;ah=c[aH>>2]|0;az=c[aD+(aQ<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1503}c[aH>>2]=az;c[(c[aJ>>2]|0)+(aQ<<2)>>2]=ah;if(aQ>>>0>3){aQ=aK}else{break}}}}while(0);if((a[1820736]&1)!=0){aA=c[494446]|0;ai=(aA|0)!=0?aA:c[p>>2]|0;a5(694728,34,1,ai|0)|0;ai=c[494446]|0;aA=(ai|0)!=0?ai:c[p>>2]|0;a_(aA|0)|0}aA=c[492321]|0;if((aA|0)!=0){ai=c[aA>>2]|0;if((ai|0)!=0){aS(ai|0)|0}aIq(c[aA+4>>2]|0);aIq(c[aA+12>>2]|0);aIq(aA)}c[492321]=0;break}}else{if(!((a[1977483]&1)!=0|aL)){break}aA=c[492315]|0;ai=aA+4|0;L1472:do{if((c[ai>>2]|0)>>>0<(c[aA+8>>2]|0)>>>0){aB=aIp(12)|0;do{if((aB|0)!=0){if((c[aB-4>>2]&3|0)==0){break}aIv(aB|0,0,12)}}while(0);c[aB+4>>2]=1;c[aB>>2]=180;aI=dv(693248)|0;aJ=c[ai>>2]|0;c[aB+8>>2]=aI;aI=aA|0;c[(c[aI>>2]|0)+(aJ<<2)>>2]=aB;aJ=c[ai>>2]|0;c[ai>>2]=aJ+1;if(aJ>>>0>1){aR=aJ}else{break}while(1){aJ=aR>>>1;aC=c[aI>>2]|0;aK=aC+(aJ<<2)|0;ah=c[aK>>2]|0;az=c[aC+(aR<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1472}c[aK>>2]=az;c[(c[aI>>2]|0)+(aR<<2)>>2]=ah;if(aR>>>0>3){aR=aJ}else{break}}}}while(0);if((a[1820736]&1)!=0){ai=c[494446]|0;aA=(ai|0)!=0?ai:c[p>>2]|0;a5(692944,33,1,aA|0)|0;aA=c[494446]|0;ai=(aA|0)!=0?aA:c[p>>2]|0;a_(ai|0)|0}ai=c[492321]|0;if((ai|0)!=0){aA=c[ai>>2]|0;if((aA|0)!=0){aS(aA|0)|0}aIq(c[ai+4>>2]|0);aIq(c[ai+12>>2]|0);aIq(ai)}c[492321]=0;a[1977483]=0;a[1973384]=0}}while(0);a[12474328]=aM;aM=f|0;L1550:do{if((c[494403]|0)!=0){if((c[(c[3118437]|0)+20>>2]|0)==0){break}f=a[12473775]|0;if((f&1)==0){aR=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,38)|0;aL=12473936;aT=(c[aL>>2]&0|aR&1|0)!=0|(c[aL+4>>2]&64|0)!=0;aU=a[12473775]|0}else{aT=0;aU=f}if((aU&1)==0){f=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,39)|0;aL=12473936;aV=(c[aL>>2]&0|f&1|0)!=0|(c[aL+4>>2]&128|0)!=0}else{aV=0}do{if(aT){if((a[12474248]&1)!=0){n=1120;break}aL=c[494403]|0;f=(((c[494404]|0)+1|0)>>>0)%((c[aL+4>>2]|0)>>>0)|0;c[494404]=f;aW=f;aX=aL;n=1125}else{n=1120}}while(0);do{if((n|0)==1120){if(!aV){break}if((a[12474240]&1)!=0){break}aL=c[494404]|0;if((aL|0)==0){f=c[494403]|0;aR=(c[f+4>>2]|0)-1|0;c[494404]=aR;aW=aR;aX=f;n=1125;break}else{f=aL-1|0;c[494404]=f;aW=f;aX=c[494403]|0;n=1125;break}}}while(0);do{if((n|0)==1125){f=c[(c[aX>>2]|0)+(aW<<3)>>2]|0;aL=ck(f|0,46)|0;if((aL|0)==0){break L1550}do{if((cP(aL|0,696360)|0)==0){aY=2}else{if((cP(aL|0,696184)|0)==0){aY=0;break}if((cP(aL|0,696056)|0)==0){aY=0}else{break L1550}}}while(0);aL=c[492315]|0;aR=aL+4|0;aQ=c[aR>>2]|0;if(aQ>>>0>1){aP=aL|0;aO=1;aN=aQ;while(1){aQ=c[(c[aP>>2]|0)+(aO<<2)>>2]|0;if((aQ|0)==0){aZ=aN}else{aIq(c[aQ+8>>2]|0);aIq(c[(c[aP>>2]|0)+(aO<<2)>>2]|0);c[(c[aP>>2]|0)+(aO<<2)>>2]=0;aZ=c[aR>>2]|0}aQ=aO+1|0;if(aQ>>>0<aZ>>>0){aO=aQ;aN=aZ}else{break}}}c[aR>>2]=1;aN=aL+12|0;aIq(c[aN>>2]|0);c[aN>>2]=0;aN=c[494404]|0;bQ(aM|0,512,695616,(E=i,i=i+16|0,c[E>>2]=aN,c[E+8>>2]=f,E)|0)|0;i=E;aN=c[492315]|0;aO=aN+4|0;L1584:do{if((c[aO>>2]|0)>>>0<(c[aN+8>>2]|0)>>>0){aP=aIp(12)|0;do{if((aP|0)!=0){if((c[aP-4>>2]&3|0)==0){break}aIv(aP|0,0,12)}}while(0);c[aP+4>>2]=1;c[aP>>2]=120;aQ=dv(aM|0)|0;k=c[aO>>2]|0;c[aP+8>>2]=aQ;aQ=aN|0;c[(c[aQ>>2]|0)+(k<<2)>>2]=aP;k=c[aO>>2]|0;c[aO>>2]=k+1;if(k>>>0>1){a$=k}else{break}while(1){k=a$>>>1;j=c[aQ>>2]|0;ai=j+(k<<2)|0;aA=c[ai>>2]|0;aI=c[j+(a$<<2)>>2]|0;if((c[aI+4>>2]|0)>>>0<=(c[aA+4>>2]|0)>>>0){break L1584}c[ai>>2]=aI;c[(c[aQ>>2]|0)+(a$<<2)>>2]=aA;if(a$>>>0>3){a$=k}else{break}}}}while(0);if((a[1820736]&1)!=0){aO=c[494446]|0;aN=(aO|0)!=0?aO:c[p>>2]|0;ei(aN|0,695352,(E=i,i=i+8|0,c[E>>2]=f,E)|0)|0;i=E;aN=c[494446]|0;aO=(aN|0)!=0?aN:c[p>>2]|0;a_(aO|0)|0}if(fp[c[(c[3118437]|0)+20>>2]&63](c[3118440]|0,aY,f)|0){break}aO=c[494446]|0;aN=(aO|0)!=0?aO:c[p>>2]|0;a5(695080,44,1,aN|0)|0;aN=c[494446]|0;aO=(aN|0)!=0?aN:c[p>>2]|0;a_(aO|0)|0}}while(0);a[12474248]=aT&1;a[12474240]=aV&1}}while(0);if((c[494422]|0)!=0){aV=a[12473775]|0;if((aV&1)==0){aT=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,40)|0;aY=12473936;a0=(c[aY>>2]&0|aT&1|0)!=0|(c[aY+4>>2]&256|0)!=0;a1=a[12473775]|0}else{a0=0;a1=aV}if((a1&1)==0){aV=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,41)|0;aY=12473936;a2=(c[aY>>2]&0|aV&1|0)!=0|(c[aY+4>>2]&512|0)!=0;a3=a[12473775]|0}else{a2=0;a3=a1}if((a3&1)==0){a3=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,42)|0;a1=12473936;a4=(c[a1>>2]&0|a3&1|0)!=0|(c[a1+4>>2]&1024|0)!=0}else{a4=0}do{if(a0){if((a[12474408]&1)!=0){n=1156;break}a1=c[494422]|0;a3=a1+4|0;c[a3>>2]=(((c[a3>>2]|0)+1|0)>>>0)%((c[a1+8>>2]|0)>>>0)|0;hG(a1)}else{n=1156}}while(0);L1614:do{if((n|0)==1156){do{if(a2){if((a[12474400]&1)!=0){break}a1=c[494422]|0;a3=a1+4|0;aY=c[a3>>2]|0;if((aY|0)==0){a6=c[a1+8>>2]|0}else{a6=aY}c[a3>>2]=a6-1;hG(a1);break L1614}}while(0);if(!a4){break}if((a[12474392]&1)!=0){break}a1=c[494422]|0;a3=a1|0;aY=(c[a3>>2]|0)+((c[a1+4>>2]|0)*12|0)+4|0;a[aY]=a[aY]&1^1;fG[c[241058]&16383]();aY=a1+8|0;aV=c[aY>>2]|0;if((aV|0)!=0){aT=0;E=0;a$=aV;while(1){aV=c[a3>>2]|0;if((a[aV+(E*12|0)+4|0]&1)==0){a7=aT;a8=a$}else{fF[c[241056]&127](aT,1,c[aV+(E*12|0)+8>>2]|0);a7=aT+1|0;a8=c[aY>>2]|0}aV=E+1|0;if(aV>>>0<a8>>>0){aT=a7;E=aV;a$=a8}else{break}}}hG(a1)}}while(0);a[12474400]=a2&1;a[12474408]=a0&1;a[12474392]=a4&1}if((c[479934]|0)!=0){a4=a[12473775]|0;if((a4&1)==0){a0=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,52)|0;a2=12473936;a9=(c[a2>>2]&0|a0&1|0)!=0|(c[a2+4>>2]&1048576|0)!=0;ba=a[12473775]|0}else{a9=0;ba=a4}if((ba&1)==0){ba=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,53)|0;a4=12473936;bb=(c[a4>>2]&0|ba&1|0)!=0|(c[a4+4>>2]&2097152|0)!=0}else{bb=0}do{if(a9){if((a[12474384]&1)!=0){n=1177;break}gd((fD[c[479931]&127]()|0)^1,1)}else{n=1177}}while(0);do{if((n|0)==1177){if(!bb){break}if((a[12474376]&1)!=0){break}a4=fD[c[479934]&127]()|0;ba=fD[c[479932]&127]()|0;if((a4|0)==(-1|0)|(a4|0)==0){a2=c[494446]|0;a0=(a2|0)!=0?a2:c[p>>2]|0;a5(696584,59,1,a0|0)|0;a0=c[494446]|0;a2=(a0|0)!=0?a0:c[p>>2]|0;a_(a2|0)|0;break}if(ba>>>0<a4>>>0){bc=((ba+1|0)>>>0)%((a4+1|0)>>>0)|0}else{bc=0}ge(bc)}}while(0);a[12474384]=a9&1;a[12474376]=bb&1}do{if((a[12473775]&1)==0){bb=fA[c[(c[3118438]|0)+12>>2]&63](c[3118441]|0,37)|0;a9=12473936;if((c[a9>>2]&0|bb&1|0)==0&(c[a9+4>>2]&32|0)==0){bd=0;break}if((a[12474288]&1)!=0){bd=1;break}gb();bd=1}else{bd=0}}while(0);a[12474288]=bd;i=d;return}function gj(a,d){a=a|0;d=d|0;var e=0;e=(c[479970]|0)-1|0;c[479970]=e;b[(c[479969]|0)+(e<<1)>>1]=d;d=(c[479970]|0)-1|0;c[479970]=d;b[(c[479969]|0)+(d<<1)>>1]=a;return}function gk(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;b=i;i=i+4096|0;d=b|0;L1665:do{if((a[1977486]&1)!=0){switch(c[456218]|0){case 0:{e=a[1820736]|0;if((e&1)==0){f=e}else{e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;a5(698360,32,1,g|0)|0;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;f=a[1820736]|0}if((f&1)==0){h=f}else{e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;ei(g|0,698208,(j=i,i=i+8|0,c[j>>2]=1861746,j)|0)|0;i=j;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;h=a[1820736]|0}if((h&1)!=0){e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;ei(g|0,698112,(j=i,i=i+8|0,c[j>>2]=1865842,j)|0)|0;i=j;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0}gs(1861746,0);gs(1865842,1);break L1665;break};case 2:case 3:{e=a[1820736]|0;if((e&1)==0){k=e}else{e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;a5(697520,30,1,g|0)|0;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;k=a[1820736]|0}if((k&1)==0){l=k}else{e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;ei(g|0,697336,(j=i,i=i+8|0,c[j>>2]=1861746,j)|0)|0;i=j;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;l=a[1820736]|0}if((l&1)!=0){e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;ei(g|0,697168,(j=i,i=i+8|0,c[j>>2]=1869938,j)|0)|0;i=j;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0}gs(1861746,256);gs(1869938,512);break L1665;break};case 1:{e=a[1820736]|0;if((e&1)==0){m=e}else{e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;a5(697992,32,1,g|0)|0;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;m=a[1820736]|0}if((m&1)==0){n=m}else{e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;ei(g|0,698208,(j=i,i=i+8|0,c[j>>2]=1861746,j)|0)|0;i=j;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;n=a[1820736]|0}if((n&1)!=0){e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;ei(g|0,698112,(j=i,i=i+8|0,c[j>>2]=1865842,j)|0)|0;i=j;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0}gs(1861746,1280);gs(1865842,1537);break L1665;break};case 4:{e=a[1820736]|0;if((e&1)==0){o=e}else{e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;a5(696984,40,1,g|0)|0;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;o=a[1820736]|0}if((o&1)==0){q=o}else{e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;ei(g|0,696888,(j=i,i=i+8|0,c[j>>2]=1874034,j)|0)|0;i=j;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;q=a[1820736]|0}if((q&1)!=0){e=c[494446]|0;g=(e|0)!=0?e:c[p>>2]|0;ei(g|0,696736,(j=i,i=i+8|0,c[j>>2]=1878130,j)|0)|0;i=j;g=c[494446]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0}gs(1874034,768);gs(1878130,1024);break L1665;break};default:{break L1665}}}}while(0);q=c[492317]|0;if((q|0)!=0){aIq(c[q>>2]|0);aIq(c[q+12>>2]|0);aIq(q)}c[492317]=0;aIq(c[492318]|0);c[492318]=0;q=c[494422]|0;if((q|0)!=0){hF(q)}q=c[492321]|0;if((q|0)!=0){o=c[q>>2]|0;if((o|0)!=0){aS(o|0)|0}aIq(c[q+4>>2]|0);aIq(c[q+12>>2]|0);aIq(q)}do{if((a[1978861]&1)==0){if((a[1978860]&1)!=0){break}q=d|0;if((a[1815586]&1)==0){break}gB(q,1882226,698776);o=gq(q)|0;if((a[1820736]&1)==0){break}n=c[494446]|0;m=(n|0)!=0?n:c[p>>2]|0;n=o?698536:698472;ei(m|0,698600,(j=i,i=i+16|0,c[j>>2]=q,c[j+8>>2]=n,j)|0)|0;i=j;n=c[494446]|0;q=(n|0)!=0?n:c[p>>2]|0;a_(q|0)|0}}while(0);gL();d=c[479945]|0;do{if((d|0)!=0){if((a[12473769]&1)!=0){break}fG[d&16383]()}}while(0);gM();if((a[12473771]&1)!=0){c[3118440]=0}if((a[12473772]&1)!=0){c[3118439]=0}if((a[12473773]&1)!=0){c[3118441]=0}a[12473771]=0;a[12473772]=0;a[12473773]=0;fG[c[241014]&16383]();fG[c[241054]&16383]();d=c[479954]|0;if((d|0)!=0){q=d+4104|0;if((c[q>>2]|0)==0){r=d|0}else{n=d+4100|0;m=d|0;o=0;while(1){l=c[n>>2]|0;gS(c[m>>2]|0,c[l+(o<<4)+4>>2]|0,c[(c[c[l+(o<<4)+8>>2]>>2]|0)+(c[l+(o<<4)+12>>2]<<3)>>2]|0);l=o+1|0;if(l>>>0<(c[q>>2]|0)>>>0){o=l}else{r=m;break}}}m=c[r>>2]|0;r=d+4|0;gT(m,r)|0;hv(c[479954]|0)}aIv(1915024,0,4800);if((a[1820772]&1)==0){a[1977788]=0;i=b;return}if((a[1820736]&1)!=0){r=c[494446]|0;m=(r|0)!=0?r:c[p>>2]|0;ei(m|0,702176,(j=i,i=i+8|0,c[j>>2]=1820773,j)|0)|0;i=j;m=c[494446]|0;r=(m|0)!=0?m:c[p>>2]|0;a_(r|0)|0}if((bC(1820773)|0)<0){r=c[494446]|0;m=(r|0)!=0?r:c[p>>2]|0;ei(m|0,701888,(j=i,i=i+8|0,c[j>>2]=1820773,j)|0)|0;i=j;j=c[494446]|0;m=(j|0)!=0?j:c[p>>2]|0;a_(m|0)|0}a[1820772]=0;a[1977788]=0;i=b;return}function gl(d,e){d=d|0;e=e|0;var f=0,g=0;f=c[479959]|0;c[479959]=f+1;b[(c[479968]|0)+(f<<1)>>1]=d;d=c[479959]|0;c[479959]=d+1;b[(c[479968]|0)+(d<<1)>>1]=e;e=c[479959]|0;if(e>>>0<(c[479960]|0)>>>0){return}if(f4(c[479968]|0,e)|0){g=a[1820737]&1}else{g=0}a[1820737]=g;c[479959]=0;return}function gm(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=f&255;f=c[492321]|0;do{if((f|0)!=0){if((a[1973384]&1)==0){break}if((ec(l|0,2,1,c[f>>2]|0)|0)!=1){a[1977483]=1;break}n=b[l>>1]|0;i=j;return n|0}}while(0);if(h>>>0<25|(m|0)==3){o=fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,670080,d,m,g,h)|0}else{o=0}l=(m|0)==1;f=(d|0)==0;do{if(l&f){p=12473936;q=c[p>>2]|0;r=c[p+4>>2]|0;p=aIH(1,0,h|0)|0;s=F;t=((q&p|0)!=0|(r&s|0)!=0)&1|o}else{if(!((m|0)==5&f)){t=o;break}t=(b[12473944+(((h|0)==1|((g|0)==1?2:0))<<1)>>1]|0)+o&65535}}while(0);do{if(l){if((h-4|0)>>>0<=3){u=t;break}o=t<<16>>16!=0;do{if(o){if((a[1977490+d|0]&1)==0){v=b[1977498+(d<<1)>>1]|0;w=1<<h;break}else{g=1<<h;f=1977498+(d<<1)|0;m=(e[f>>1]|0|g)&65535;b[f>>1]=m;v=m;w=g;break}}else{g=1<<h;m=1977498+(d<<1)|0;f=(e[m>>1]|0)&(g^65535)&65535;b[m>>1]=f;v=f;w=g}}while(0);if((v&65535&w|0)==0){x=o}else{x=(((c[494379]|0)>>>0)%((c[444668]|0)>>>0)|0)>>>0<(c[444669]|0)>>>0&o}u=x&1}else{u=t}}while(0);t=c[492321]|0;if((t|0)==0){n=u;i=j;return n|0}if((a[1973384]&1)!=0){n=u;i=j;return n|0}b[k>>1]=u;a5(k|0,2,1,c[t>>2]|0)|0;n=u;i=j;return n|0}function gn(){var a=0,b=0,d=0;a=i;dh(716528|0)|0;dh(716448|0)|0;b=c[o>>2]|0;a5(729024|0,11,1,b|0)|0;ei(b|0,728776|0,(d=i,i=i+16|0,c[d>>2]=728200,c[d+8>>2]=32,d)|0)|0;i=d;ei(b|0,727912|0,(d=i,i=i+8|0,c[d>>2]=727768,d)|0)|0;i=d;dh(716528|0)|0;dh(716400|0)|0;dh(716344|0)|0;dh(716224|0)|0;dh(716088|0)|0;dh(715632|0)|0;dh(715480|0)|0;dh(715400|0)|0;dh(715080|0)|0;dh(714896|0)|0;dh(714744|0)|0;dh(714560|0)|0;dh(714408|0)|0;dh(714336|0)|0;dh(714256|0)|0;dh(713968|0)|0;dh(713840|0)|0;c6(713616|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;c6(713504|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;c6(713432|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;dh(713296|0)|0;dh(713208|0)|0;dh(713072|0)|0;dh(712976|0)|0;dh(712904|0)|0;dh(712608|0)|0;dh(712416|0)|0;dh(712296|0)|0;dh(712160|0)|0;dh(712128|0)|0;dh(712040|0)|0;dh(711968|0)|0;dh(711896|0)|0;dh(711816|0)|0;dh(711760|0)|0;dh(711440|0)|0;i=a;return}function go(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c9(b|0,697480|0)|0;do{if((e|0)!=0){ev(e|0,0,2)|0;b=cf(e|0)|0;eD(e|0);f=aIp(b+1|0)|0;if((f|0)==0){g=c[494446]|0;h=(g|0)!=0?g:c[p>>2]|0;a5(713384|0,47,1,h|0)|0;h=c[494446]|0;g=(h|0)!=0?h:c[p>>2]|0;a_(g|0)|0;aS(e|0)|0;break}g=ec(f|0,1,b|0,e|0)|0;if((g|0)<(b|0)){h=c[494446]|0;i=(h|0)!=0?h:c[p>>2]|0;a5(706768|0,44,1,i|0)|0;i=c[494446]|0;h=(i|0)!=0?i:c[p>>2]|0;a_(h|0)|0}c[d>>2]=f;a[f+b|0]=0;aS(e|0)|0;j=g;return j|0}}while(0);c[d>>2]=0;j=-1;return j|0}function gp(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[1977789]&1)==0){d=c[494446]|0;e=(d|0)!=0?d:c[p>>2]|0;ei(e|0,712776,(e=i,i=i+16|0,c[e>>2]=722624,c[e+8>>2]=832,e)|0)|0;i=e;e=c[494446]|0;d=(e|0)!=0?e:c[p>>2]|0;a_(d|0)|0;ch(2)}else{f=1024;g=1977791;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=1315;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==1315){eJ(1978816,1)}a[g]=0;if((a[h]|0)==0){eJ(1978816,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);eJ(1978816,1)}function gq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a[1820736]&1)!=0){e=c[494446]|0;f=(e|0)!=0?e:c[p>>2]|0;ei(f|0,699280,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;f=c[494446]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0}e=fD[c[241030]&127]()|0;if((e|0)==0){h=0;i=d;return h|0}f=aIp(e)|0;if((f|0)==0){j=c[494446]|0;k=(j|0)!=0?j:c[p>>2]|0;a5(697376,70,1,k|0)|0;k=c[494446]|0;j=(k|0)!=0?k:c[p>>2]|0;a_(j|0)|0;h=0;i=d;return h|0}if((a[1820736]&1)!=0){j=c[494446]|0;k=(j|0)!=0?j:c[p>>2]|0;ei(k|0,695416,(g=i,i=i+8|0,c[g>>2]=e,g)|0)|0;i=g;k=c[494446]|0;j=(k|0)!=0?k:c[p>>2]|0;a_(j|0)|0}do{if(fA[c[241032]&63](f,e)|0){j=c9(b|0,707632)|0;if((j|0)==0){l=1328;break}k=(a5(f|0,1,e|0,j|0)|0)==(e|0);aS(j|0)|0;if(k){m=1}else{l=1328}}else{l=1328}}while(0);if((l|0)==1328){l=c[494446]|0;e=(l|0)!=0?l:c[p>>2]|0;ei(e|0,693296,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;g=c[494446]|0;b=(g|0)!=0?g:c[p>>2]|0;a_(b|0)|0;m=0}aIq(f);h=m;i=d;return h|0}function gr(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+16|0;e=d|0;f=d+8|0;if((a[1820736]&1)!=0){g=c[494446]|0;h=(g|0)!=0?g:c[p>>2]|0;ei(h|0,691176,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;h=c[494446]|0;g=(h|0)!=0?h:c[p>>2]|0;a_(g|0)|0}c[e>>2]=0;g=go(b,e)|0;if((g|0)<0){h=c[494446]|0;k=(h|0)!=0?h:c[p>>2]|0;ei(k|0,730336,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;b=c[494446]|0;k=(b|0)!=0?b:c[p>>2]|0;a_(k|0)|0;l=0;i=d;return l|0}if((a[1820736]&1)!=0){k=c[494446]|0;b=(k|0)!=0?k:c[p>>2]|0;ei(b|0,728064,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;j=c[494446]|0;b=(j|0)!=0?j:c[p>>2]|0;a_(b|0)|0}c[f>>2]=0;L1864:do{if((a[1815584]&1)==0){m=1351}else{if((a[1820736]&1)!=0){b=c[494446]|0;j=(b|0)!=0?b:c[p>>2]|0;a5(726080,36,1,j|0)|0;j=c[494446]|0;b=(j|0)!=0?j:c[p>>2]|0;a_(b|0)|0}switch(c[456218]|0){case 2:case 3:{n=256;o=512;break};case 4:{n=768;o=1024;break};case 1:{n=1280;o=1537;break};case 0:{n=0;o=1;break};default:{m=1351;break L1864}}b=fl[c[241050]&255](n)|0;j=fl[c[241050]&255](o)|0;if((b|0)==0){q=0;r=0}else{q=aIp(b)|0;r=b}if((j|0)==0){s=0;t=0}else{b=aIp(j)|0;c[f>>2]=b;s=b;t=j}do{if((q|0)!=0){j=fl[c[241052]&255](n)|0;if((j|0)==0){break}aIy(q|0,j|0,r)|0}}while(0);j=f;if((s|0)==0){u=0;v=t;w=n;x=o;y=r;z=q;A=j;break}b=fl[c[241052]&255](o)|0;if((b|0)==0){u=s;v=t;w=n;x=o;y=r;z=q;A=j;break}aIy(s|0,b|0,t)|0;u=s;v=t;w=n;x=o;y=r;z=q;A=j}}while(0);if((m|0)==1351){u=0;v=0;w=-1;x=-1;y=0;z=0;A=f}f=c[e>>2]|0;e=fA[c[241012]&63](f,g)|0;do{if(e){do{if((z|0)!=0){g=fl[c[241052]&255](w)|0;if((g|0)==0){break}aIy(g|0,z|0,y)|0}}while(0);if((u|0)==0){break}g=fl[c[241052]&255](x)|0;if((g|0)==0){break}aIy(g|0,u|0,v)|0}}while(0);if((z|0)==0){B=u}else{aIq(z);B=c[A>>2]|0}if((B|0)!=0){aIq(B)}aIq(f);l=e;i=d;return l|0}function gs(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+8200|0;f=e|0;g=e+4096|0;h=e+8192|0;j=fl[c[241050]&255](d)|0;k=fl[c[241052]&255](d)|0;if((k|0)==0|(j|0)==0){i=e;return}l=c9(b|0,707632)|0;do{if((l|0)!=0){m=(a5(k|0,1,j|0,l|0)|0)==(j|0);aS(l|0)|0;if(!m){break}if((a[1820736]&1)==0){i=e;return}m=c[494446]|0;n=(m|0)!=0?m:c[p>>2]|0;ei(n|0,722144,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;n=c[494446]|0;m=(n|0)!=0?n:c[p>>2]|0;a_(m|0)|0;i=e;return}}while(0);b=c[494446]|0;a5(724640,42,1,((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[494446]|0;a_(((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[494446]|0;a5(723584,46,1,((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[494446]|0;a_(((b|0)!=0?b:c[p>>2]|0)|0)|0;b=f|0;l=g|0;g=dJ(724216)|0;do{if((g|0)!=0){bQ(b|0,4096,704648,(o=i,i=i+8|0,c[o>>2]=g,o)|0)|0;i=o;eM(h|0)|0;m=bg(h|0)|0;cX(l|0,4096,704344,m|0)|0;m=aIu(b|0)|0;n=m>>>0>4096?0:4096-m|0;L1919:do{if((n|0)==0){q=l;r=1382}else{s=n;t=f+m|0;u=l;while(1){v=s-1|0;if((v|0)==0){break}w=a[u]|0;a[t]=w;if(w<<24>>24==0){break L1919}else{s=v;t=t+1|0;u=u+1|0}}a[t]=0;q=u;r=1382}}while(0);do{if((r|0)==1382){if((a[q]|0)==0){break}else{x=q}do{x=x+1|0;}while((a[x]|0)!=0)}}while(0);switch(d|0){case 1:case 1537:{y=702288;break};case 512:{y=702064;break};case 768:{y=701768;break};case 1024:{y=701504;break};case 0:case 1280:case 256:{y=730072;break};default:{y=14317944}}u=aIu(b|0)|0;t=u>>>0>4096?0:4096-u|0;L1937:do{if((t|0)==0){z=y;r=1395}else{m=t;n=f+u|0;s=y;while(1){v=m-1|0;if((v|0)==0){break}w=a[s]|0;a[n]=w;if(w<<24>>24==0){break L1937}else{m=v;n=n+1|0;s=s+1|0}}a[n]=0;z=s;r=1395}}while(0);do{if((r|0)==1395){if((a[z]|0)==0){break}else{A=z}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);s=c9(b|0,707632)|0;if((s|0)==0){break}n=(a5(k|0,1,j|0,s|0)|0)==(j|0);aS(s|0)|0;if(!n){break}n=c[494446]|0;s=(n|0)!=0?n:c[p>>2]|0;ei(s|0,703848,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;s=c[494446]|0;n=(s|0)!=0?s:c[p>>2]|0;a_(n|0)|0;i=e;return}}while(0);o=c[494446]|0;a5(703224,57,1,((o|0)!=0?o:c[p>>2]|0)|0)|0;o=c[494446]|0;a_(((o|0)!=0?o:c[p>>2]|0)|0)|0;i=e;return}function gt(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;e=i;i=i+8280|0;f=e|0;g=e+48|0;h=e+56|0;j=e+4152|0;k=e+8248|0;l=e+8264|0;m=e+8272|0;L1954:do{if((a[1857650]|0)!=0){if((a[1915100]&1)!=0){break}n=ck(1857650,46)|0;o=(n|0)==0?14317944:n+1|0;if((o|0)==0){break}if((aIB(o|0,720872)|0)!=0){break}a[1820772]=1;o=h|0;n=j|0;q=gx(1915616,726824)|0;do{if((q|0)!=0){c[g>>2]=0;r=go(1857650,g)|0;if((r|0)<22){s=c[494446]|0;t=(s|0)!=0?s:c[p>>2]|0;ei(t|0,714496,(u=i,i=i+8|0,c[u>>2]=107,u)|0)|0;i=u;t=c[494446]|0;s=(t|0)!=0?t:c[p>>2]|0;a_(s|0)|0;aIq(c[g>>2]|0);v=0}else{s=r-22|0;L1963:do{if((s|0)>22){t=c[g>>2]|0;w=t+r|0;x=t+22|0;y=t+s|0;while(1){if((d[y+1|0]<<8|d[y]|d[y+2|0]<<16|d[y+3|0]<<24|0)==101010256){if((y+((d[y+21|0]<<8|d[y+20|0])+22)|0)==(w|0)){break}}z=y-1|0;if(z>>>0>x>>>0){y=z}else{A=1419;break L1963}}x=d[y+17|0]<<8|d[y+16|0]|d[y+18|0]<<16|d[y+19|0]<<24;w=t+x|0;L1971:do{if((d[t+(x+1)|0]<<8|d[w]|d[t+(x+2)|0]<<16|d[t+(x+3)|0]<<24|0)==33639248){z=q|0;B=q+4|0;C=w;L1973:while(1){D=a[C+10|0]|0;E=a[C+11|0]|0;F=a[C+16|0]|0;G=a[C+17|0]|0;H=a[C+18|0]|0;I=a[C+19|0]|0;J=d[C+21|0]<<8|d[C+20|0]|d[C+22|0]<<16|d[C+23|0]<<24;K=d[C+25|0]<<8|d[C+24|0]|d[C+26|0]<<16|d[C+27|0]<<24;L=d[C+29|0]<<8|d[C+28|0];M=d[C+33|0]<<8|d[C+32|0];N=d[C+31|0]<<8|d[C+30|0];aIv(o|0,0,4096);if(L>>>0>4095){A=1425;break}O=C+46|0;aIy(o|0,O|0,L)|0;O=d[C+43|0]<<8|d[C+42|0]|d[C+44|0]<<16|d[C+45|0]<<24;P=O+30+(d[t+(O+27)|0]<<8|d[t+(O+26)|0])+(d[t+(O+29)|0]<<8|d[t+(O+28)|0])|0;if((a[1820736]&1)!=0){O=c[494446]|0;Q=(O|0)!=0?O:c[p>>2]|0;ei(Q|0,707144,(u=i,i=i+24|0,c[u>>2]=P,c[u+8>>2]=J,c[u+16>>2]=K,u)|0)|0;i=u;Q=c[494446]|0;O=(Q|0)!=0?Q:c[p>>2]|0;a_(O|0)|0}O=ck(o|0,46)|0;Q=(O|0)==0?14317944:O+1|0;L1979:do{if((Q|0)!=0){O=c[B>>2]|0;R=0;while(1){if(R>>>0>=O>>>0){break L1979}if((aIB(c[(c[z>>2]|0)+(R<<3)>>2]|0,Q|0)|0)==0){break L1973}else{R=R+1|0}}}}while(0);Q=L+46+N+M|0;R=C+Q|0;if((d[C+(Q+1)|0]<<8|d[R]|d[C+(Q+2)|0]<<16|d[C+(Q+3)|0]<<24|0)==33639248){C=R}else{break L1971}}if((A|0)==1425){C=c[494446]|0;z=(C|0)!=0?C:c[p>>2]|0;ei(z|0,714496,(u=i,i=i+8|0,c[u>>2]=141,u)|0)|0;i=u;z=c[494446]|0;C=(z|0)!=0?z:c[p>>2]|0;a_(C|0)|0;S=0;break L1963}C=(G&255)<<8|F&255|(H&255)<<16|(I&255)<<24;z=(E&255)<<8|D&255;B=t+P|0;R=ck(o|0,47)|0;gJ(n,1857650,(R|0)==0?o:R+1|0);if((z|0)==8){R=aIp(K)|0;if((R|0)!=0){aIv(f|0,0,48);Q=aIp(43784)|0;do{if((Q|0)==0){O=c[494446]|0;T=(O|0)!=0?O:c[p>>2]|0;ei(T|0,714496,(u=i,i=i+8|0,c[u>>2]=61,u)|0)|0;i=u;T=c[494446]|0;O=(T|0)!=0?T:c[p>>2]|0;a_(O|0)|0}else{O=f+28|0;c[O>>2]=Q;c[Q>>2]=0;c[Q+10992>>2]=0;c[Q+10996>>2]=0;c[Q+43780>>2]=1;c[Q+11e3>>2]=1;c[Q+11004>>2]=0;c[Q+11008>>2]=-15;c[f>>2]=B;c[f+4>>2]=J;c[f+12>>2]=R;c[f+16>>2]=K;T=(jI(f)|0)==1;U=c[O>>2]|0;if((U|0)!=0){aIq(U);c[O>>2]=0}if(!T){T=c[494446]|0;O=(T|0)!=0?T:c[p>>2]|0;ei(O|0,714496,(u=i,i=i+8|0,c[u>>2]=71,u)|0)|0;i=u;O=c[494446]|0;T=(O|0)!=0?O:c[p>>2]|0;a_(T|0)|0;break}if((K|0)==0){V=0}else{T=K;O=R;U=-1;while(1){W=T-1|0;X=d[O]|0;Y=c[684280+(((X^U)&15)<<2)>>2]^U>>>4;Z=Y>>>4^c[684280+((Y&15^X>>>4)<<2)>>2];if((W|0)==0){break}else{T=W;O=O+1|0;U=Z}}V=~Z}if((V|0)!=(C|0)){U=c[494446]|0;O=(U|0)!=0?U:c[p>>2]|0;ei(O|0,699688,(u=i,i=i+16|0,c[u>>2]=V,c[u+8>>2]=C,u)|0)|0;i=u;O=c[494446]|0;U=(O|0)!=0?O:c[p>>2]|0;a_(U|0)|0}U=c9(n|0,707632)|0;do{if((U|0)!=0){O=(a5(R|0,1,K|0,U|0)|0)==(K|0);aS(U|0)|0;if(!O){break}aIq(R);O=4096;T=1857650;M=n;while(1){N=O-1|0;if((N|0)==0){break}L=a[M]|0;a[T]=L;if(L<<24>>24==0){S=1;break L1963}else{O=N;T=T+1|0;M=M+1|0}}a[T]=0;if((a[M]|0)==0){S=1;break L1963}else{_=M}while(1){O=_+1|0;if((a[O]|0)==0){S=1;break L1963}else{_=O}}}}while(0);U=c[494446]|0;M=(U|0)!=0?U:c[p>>2]|0;ei(M|0,714496,(u=i,i=i+8|0,c[u>>2]=81,u)|0)|0;i=u;M=c[494446]|0;U=(M|0)!=0?M:c[p>>2]|0;a_(U|0)|0}}while(0);aIq(R)}C=c[494446]|0;Q=(C|0)!=0?C:c[p>>2]|0;ei(Q|0,714496,(u=i,i=i+8|0,c[u>>2]=175,u)|0)|0;i=u;Q=c[494446]|0;C=(Q|0)!=0?Q:c[p>>2]|0;a_(C|0)|0;S=0;break L1963}else if((z|0)==0){C=c9(n|0,707632)|0;if((C|0)!=0){Q=(a5(B|0,1,K|0,C|0)|0)==(K|0);aS(C|0)|0;if(Q){S=1;break L1963}}Q=c[494446]|0;ei(((Q|0)!=0?Q:c[p>>2]|0)|0,714496,(u=i,i=i+8|0,c[u>>2]=165,u)|0)|0;i=u;Q=c[494446]|0;a_(((Q|0)!=0?Q:c[p>>2]|0)|0)|0;S=0;break L1963}else{Q=c[494446]|0;ei(((Q|0)!=0?Q:c[p>>2]|0)|0,714496,(u=i,i=i+8|0,c[u>>2]=178,u)|0)|0;i=u;Q=c[494446]|0;a_(((Q|0)!=0?Q:c[p>>2]|0)|0)|0;S=0;break L1963}}}while(0);t=c[494446]|0;a5(702712,101,1,((t|0)!=0?t:c[p>>2]|0)|0)|0;t=c[494446]|0;a_(((t|0)!=0?t:c[p>>2]|0)|0)|0;t=c[494446]|0;ei(((t|0)!=0?t:c[p>>2]|0)|0,714496,(u=i,i=i+8|0,c[u>>2]=186,u)|0)|0;i=u;t=c[494446]|0;a_(((t|0)!=0?t:c[p>>2]|0)|0)|0;S=0}else{A=1419}}while(0);if((A|0)==1419){s=c[494446]|0;r=(s|0)!=0?s:c[p>>2]|0;ei(r|0,714496,(u=i,i=i+8|0,c[u>>2]=113,u)|0)|0;i=u;r=c[494446]|0;s=(r|0)!=0?r:c[p>>2]|0;a_(s|0)|0;S=0}aIq(c[g>>2]|0);v=S}s=q+4|0;r=q|0;t=c[r>>2]|0;if((c[s>>2]|0)==0){$=t}else{w=0;x=t;while(1){aIq(c[x+(w<<3)>>2]|0);t=w+1|0;y=c[r>>2]|0;if(t>>>0<(c[s>>2]|0)>>>0){w=t;x=y}else{$=y;break}}}aIq($);aIq(q);if(v){aa=4096;ab=1820773;ac=1857650}else{break}while(1){x=aa-1|0;if((x|0)==0){break}w=a[ac]|0;a[ab]=w;if(w<<24>>24==0){break L1954}else{aa=x;ab=ab+1|0;ac=ac+1|0}}a[ab]=0;if((a[ac]|0)==0){break L1954}else{ad=ac}while(1){ad=ad+1|0;if((a[ad]|0)==0){break L1954}}}}while(0);q=c[494446]|0;n=(q|0)!=0?q:c[p>>2]|0;ei(n|0,719776,(u=i,i=i+8|0,c[u>>2]=1857650,u)|0)|0;i=u;n=c[494446]|0;q=(n|0)!=0?n:c[p>>2]|0;a_(q|0)|0;a[1820772]=0;ae=0;i=e;return ae|0}}while(0);L2045:do{switch(b|0){case 2:{u=m|0;c[u>>2]=(a[1857650]|0)!=0?1857650:0;c[m+4>>2]=1828976;if(gu(257,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 3:{u=m|0;c[u>>2]=(a[1857650]|0)!=0?1857650:0;c[m+4>>2]=1828976;if(gu(258,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 4:{u=k|0;c[u>>2]=(a[1857650]|0)!=0?1857650:0;c[k+4>>2]=(a[1833072]|0)!=0?1833072:0;c[k+8>>2]=(a[1837168]|0)!=0?1837168:0;if(gu(259,u,3)|0){break L2045}else{ae=0}i=e;return ae|0};case 1:{u=m|0;c[u>>2]=(a[1857650]|0)!=0?1857650:0;c[m+4>>2]=1824880;if(gu(260,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 0:{if((a[1978860]&1)==0){c[l>>2]=1857650;if(gu(0,l,1)|0){break L2045}else{ae=0}i=e;return ae|0}if((a[1915102]&1)==0){u=c[494446]|0;ad=(u|0)!=0?u:c[p>>2]|0;a5(705336,78,1,ad|0)|0;ad=c[494446]|0;u=(ad|0)!=0?ad:c[p>>2]|0;a_(u|0)|0;ae=0;i=e;return ae|0}else{if(fl[c[241040]&255](0)|0){break L2045}else{ae=0}i=e;return ae|0}break};default:{u=c[494446]|0;a5(718760,39,1,((u|0)!=0?u:c[p>>2]|0)|0)|0;u=c[494446]|0;a_(((u|0)!=0?u:c[p>>2]|0)|0)|0;ae=0;i=e;return ae|0}}}while(0);ae=1;i=e;return ae|0}function gu(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=i;i=i+520|0;h=g|0;j=g+368|0;k=g+400|0;l=g+408|0;m=g+416|0;n=g+424|0;o=g+440|0;q=g+456|0;if((f|0)==0|f>>>0>4){r=0;i=g;return r|0}aIv(n|0,0,16);aIv(o|0,0,16);aIv(q|0,0,64);do{if((a[1886322]|0)==0){s=0}else{t=c9(1886322,720728)|0;if((t|0)==0){s=0;break}ev(t|0,0,2)|0;u=(cf(t|0)|0)+2|0;eD(t|0);v=(u|0)==0?0:u;w=aIp(v)|0;if((w|0)==0){aS(t|0)|0;s=0;break}if((c[w-4>>2]&3|0)!=0){aIv(w|0,0,v|0)}v=w;x=w;while(1){if((en(t|0)|0)!=0){y=x;break}b_(x|0,u-x+v|0,t|0)|0;z=x+(aIu(x|0)|0)|0;if((z|0)==0){y=0;break}else{x=z}}x=b4(y|0,-1|0)|0;if((x|0)!=0){a[x]=0}aS(t|0)|0;if((a[1820736]&1)==0){s=w;break}x=c[494446]|0;ei(((x|0)!=0?x:c[p>>2]|0)|0,705728,(A=i,i=i+8|0,c[A>>2]=1886322,A)|0)|0;i=A;x=c[494446]|0;a_(((x|0)!=0?x:c[p>>2]|0)|0)|0;s=w}}while(0);y=(a[1820736]&1)!=0;do{if((a[1915036]&1)==0){if(y){x=c[494446]|0;v=(x|0)!=0?x:c[p>>2]|0;x=c[e>>2]|0;ei(v|0,717832,(A=i,i=i+8|0,c[A>>2]=x,A)|0)|0;i=A;x=c[494446]|0;v=(x|0)!=0?x:c[p>>2]|0;a_(v|0)|0}v=c[e>>2]|0;x=n|0;c[m>>2]=0;u=go(v,m)|0;if((u|0)<1){B=u;C=0}else{L2097:do{if((a[1902706]&1)==0){v=c[m>>2]|0;c[k>>2]=0;z=a[1902707]|0;D=a[1902708]|0;E=a[1902709]|0;if(((D&1)+(z&1)+(E&1)|0)>1){F=c[494446]|0;G=(F|0)!=0?F:c[p>>2]|0;a5(709976,77,1,G|0)|0;G=c[494446]|0;F=(G|0)!=0?G:c[p>>2]|0;a_(F|0)|0;H=u;I=v;break}F=(E|z)&1;G=((D|z)&1)!=0;if(((E|D)&1)!=0|(a[1902710]|0)==0){J=1517}else{D=go(1902710,k)|0;if((D|0)>-1){K=709416;L=1902710;M=4;N=D}else{J=1517}}do{if((J|0)==1517){if(!(F<<24>>24!=0|(a[1906806]|0)==0)){D=go(1906806,k)|0;if((D|0)>-1){K=709e3;L=1906806;M=10;N=D;break}}if(!(G|(a[1910902]|0)==0)){D=go(1910902,k)|0;if((D|0)>-1){K=708592;L=1910902;M=8;N=D;break}}if((a[1820736]&1)==0){H=u;I=v;break L2097}D=c[494446]|0;E=(D|0)!=0?D:c[p>>2]|0;a5(708144,43,1,E|0)|0;E=c[494446]|0;D=(E|0)!=0?E:c[p>>2]|0;a_(D|0)|0;H=u;I=v;break L2097}}while(0);if((a[1820736]&1)!=0){G=c[494446]|0;F=(G|0)!=0?G:c[p>>2]|0;ei(F|0,707568,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=L,A)|0)|0;i=A;F=c[494446]|0;G=(F|0)!=0?F:c[p>>2]|0;a_(G|0)|0}G=u<<2;c[l>>2]=G;F=aIp(G)|0;if((F|0)==0){G=c[494446]|0;D=(G|0)!=0?G:c[p>>2]|0;a5(706872,67,1,D|0)|0;D=c[494446]|0;G=(D|0)!=0?D:c[p>>2]|0;a_(G|0)|0;c[m>>2]=v;aIq(c[k>>2]|0);H=u;I=v;break}G=c[k>>2]|0;D=fk[M&15](G,N,v,u,F,l)|0;if((D|0)==1){if((a[1820736]&1)!=0){E=c[494446]|0;z=(E|0)!=0?E:c[p>>2]|0;ei(z|0,706432,(A=i,i=i+8|0,c[A>>2]=K,A)|0)|0;i=A;z=c[494446]|0;E=(z|0)!=0?z:c[p>>2]|0;a_(E|0)|0}aIq(v);c[m>>2]=F;O=c[l>>2]|0;P=F}else{F=c[494446]|0;E=(F|0)!=0?F:c[p>>2]|0;ei(E|0,706064,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=D,A)|0)|0;i=A;D=c[494446]|0;E=(D|0)!=0?D:c[p>>2]|0;a_(E|0)|0;O=u;P=v}aIq(G);H=O;I=P}else{H=u;I=c[m>>2]|0}}while(0);u=(H|0)==0;if((I|0)==0|u){Q=0}else{w=H;t=I;G=-1;while(1){E=w-1|0;D=d[t]|0;F=c[684280+(((D^G)&15)<<2)>>2]^G>>>4;R=F>>>4^c[684280+((F&15^D>>>4)<<2)>>2];if((E|0)==0){break}else{w=E;t=t+1|0;G=R}}Q=~R}c[456219]=Q;G=h;aIv(G|0,0,360);t=h+324|0;aIy(t|0,736728,32)|0;t=h+360|0;c[t>>2]=H;c[t+4>>2]=0;w=h+64|0;if(u){S=0}else{E=H;D=I;F=0;while(1){z=64-F|0;T=E>>>0<z>>>0?E:z;z=G+F|0;aIy(z|0,D|0,T)|0;z=T+(c[w>>2]|0)|0;c[w>>2]=z;if((z|0)==64){gV(h);U=c[w>>2]|0}else{U=z}if((E|0)==(T|0)){S=U;break}else{E=E-T|0;D=D+T|0;F=U}}}c[w>>2]=S+1;a[h+S|0]=-128;F=c[w>>2]|0;if(F>>>0>56){aIv(G+F|0,0,64-F|0);gV(h);V=c[w>>2]|0}else{V=F}aIv(G+V|0,0,56-V|0);F=c[t>>2]|0;c[h+56>>2]=d0(F>>>29|c[t+4>>2]<<3|0)|0;c[h+60>>2]=d0(F<<3|0>>>29|0)|0;gV(h);c[j>>2]=d0(c[h+324>>2]|0)|0;c[j+4>>2]=d0(c[h+328>>2]|0)|0;c[j+8>>2]=d0(c[h+332>>2]|0)|0;c[j+12>>2]=d0(c[h+336>>2]|0)|0;c[j+16>>2]=d0(c[h+340>>2]|0)|0;c[j+20>>2]=d0(c[h+344>>2]|0)|0;c[j+24>>2]=d0(c[h+348>>2]|0)|0;c[j+28>>2]=d0(c[h+352>>2]|0)|0;F=j;D=0;do{bQ(1977620+(D<<1)|0,3,714488,(A=i,i=i+8|0,c[A>>2]=d[F+D|0]|0,A)|0)|0;i=A;D=D+1|0;}while(D>>>0<32);if((a[1820736]&1)!=0){D=c[494446]|0;F=(D|0)!=0?D:c[p>>2]|0;D=c[456219]|0;ei(F|0,710824,(A=i,i=i+16|0,c[A>>2]=D,c[A+8>>2]=1977620,A)|0)|0;i=A;D=c[494446]|0;F=(D|0)!=0?D:c[p>>2]|0;a_(F|0)|0}c[x>>2]=I;B=H;C=I}c[o>>2]=B;if((B|0)==-1){F=c[494446]|0;D=(F|0)!=0?F:c[p>>2]|0;a5(716848,46,1,D|0)|0;D=c[494446]|0;F=(D|0)!=0?D:c[p>>2]|0;a_(F|0)|0;W=0;break}if((a[1820736]&1)==0){X=C;Y=B;J=1553;break}F=c[494446]|0;D=(F|0)!=0?F:c[p>>2]|0;ei(D|0,715528,(A=i,i=i+8|0,c[A>>2]=B,A)|0)|0;i=A;D=c[494446]|0;F=(D|0)!=0?D:c[p>>2]|0;a_(F|0)|0;X=C;Y=B;J=1553}else{if(!y){X=0;Y=0;J=1553;break}F=c[494446]|0;D=(F|0)!=0?F:c[p>>2]|0;a5(713888,72,1,D|0)|0;D=c[494446]|0;F=(D|0)!=0?D:c[p>>2]|0;a_(F|0)|0;X=0;Y=0;J=1553}}while(0);L2157:do{if((J|0)==1553){y=q|0;c[q>>2]=c[e>>2];c[q+4>>2]=X;c[q+8>>2]=Y;c[q+12>>2]=s;L2159:do{if(f>>>0>1){B=1;L2160:while(1){Z=e+(B<<2)|0;C=c[Z>>2]|0;do{if((C|0)==0){_=0}else{if((a[1915036]&1)!=0){_=C;break}I=go(C,n+(B<<2)|0)|0;c[o+(B<<2)>>2]=I;if((I|0)==-1){break L2160}_=c[Z>>2]|0}}while(0);c[q+(B<<4)>>2]=_;c[q+(B<<4)+4>>2]=c[n+(B<<2)>>2];c[q+(B<<4)+8>>2]=c[o+(B<<2)>>2];B=B+1|0;if(B>>>0>=f>>>0){break L2159}}B=c[494446]|0;ei(((B|0)!=0?B:c[p>>2]|0)|0,712504,(A=i,i=i+8|0,c[A>>2]=c[Z>>2],A)|0)|0;i=A;B=c[494446]|0;a_(((B|0)!=0?B:c[p>>2]|0)|0)|0;W=0;break L2157}}while(0);if((b|0)==0){if(fl[c[241040]&255](y)|0){W=1;break}}else{if(fp[c[241038]&63](b,y,f)|0){W=1;break}}x=c[494446]|0;B=(x|0)!=0?x:c[p>>2]|0;a5(711344,42,1,B|0)|0;B=c[494446]|0;x=(B|0)!=0?B:c[p>>2]|0;a_(x|0)|0;W=0}}while(0);aIq(c[n>>2]|0);aIq(c[n+4>>2]|0);aIq(c[n+8>>2]|0);aIq(c[n+12>>2]|0);aIq(s);r=W;i=g;return r|0}function gv(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=a[b+4|0]&1;f=a[d+4|0]&1;if(e<<24>>24==f<<24>>24){g=aIB(c[b>>2]|0,c[d>>2]|0)|0;return g|0}else{g=(f&255)-(e&255)|0;return g|0}return 0}function gw(a,b){a=a|0;b=b|0;return aIB(c[a>>2]|0,c[b>>2]|0)|0}function gx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+8|0;e=d|0;f=aIp(12)|0;do{if((f|0)==0){g=0}else{do{if((c[f-4>>2]&3|0)==0){h=f+4|0;j=c[h>>2]|0;if(j>>>0<32){k=h;l=j;m=f;break}j=c[494446]|0;h=(j|0)!=0?j:c[p>>2]|0;ei(h|0,712776,(n=i,i=i+16|0,c[n>>2]=693144,c[n+8>>2]=69,n)|0)|0;i=n;h=c[494446]|0;j=(h|0)!=0?h:c[p>>2]|0;a_(j|0)|0;ch(2);return 0}else{aIv(f|0,0,12);k=f+4|0;l=0;m=f}}while(0);j=f;h=c[j>>2]|0;o=h;q=aIr(o,256)|0;if((q|0)==0){if((l|0)!=0){r=0;do{aIq(c[h+(r<<3)>>2]|0);r=r+1|0;}while(r>>>0<l>>>0)}aIq(o);aIq(f);g=0;break}r=q;c[j>>2]=r;h=f+8|0;c[h>>2]=32;s=dv(a|0)|0;L2197:do{if((s|0)==0){t=0;u=l;v=r}else{w=ee(s|0,b|0,e|0)|0;L2199:do{if((w|0)!=0){x=w;y=r;z=l;A=32;while(1){if(z>>>0<A>>>0){B=y;C=A}else{D=A<<1;if(z>>>0>=D>>>0){break}E=aIr(y,A<<4)|0;if((E|0)==0){t=s;u=z;v=y;break L2197}F=E;c[j>>2]=F;c[h>>2]=D;B=F;C=D}D=dv(x|0)|0;if((D|0)==0){t=s;u=z;v=B;break L2197}c[B+(z<<3)>>2]=D;D=c[k>>2]|0;F=c[j>>2]|0;c[F+(D<<3)+4>>2]=0;E=D+1|0;c[k>>2]=E;D=ee(0,b|0,e|0)|0;if((D|0)==0){break L2199}else{x=D;y=F;z=E;A=C}}A=c[494446]|0;ei(((A|0)!=0?A:c[p>>2]|0)|0,712776,(n=i,i=i+16|0,c[n>>2]=693144,c[n+8>>2]=69,n)|0)|0;i=n;A=c[494446]|0;a_(((A|0)!=0?A:c[p>>2]|0)|0)|0;ch(2);return 0}}while(0);aIq(s);G=m;i=d;return G|0}}while(0);if((u|0)!=0){s=0;do{aIq(c[v+(s<<3)>>2]|0);s=s+1|0;}while(s>>>0<u>>>0)}aIq(v);aIq(f);g=t}}while(0);aIq(g);G=0;i=d;return G|0}function gy(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;i=i+8264|0;g=f|0;h=f+4096|0;j=f+4168|0;k=aIp(12)|0;if((k|0)==0){l=0;i=f;return l|0}do{if((c[k-4>>2]&3|0)==0){m=k+4|0;n=c[m>>2]|0;if(n>>>0<32){o=m;q=n;r=k;break}n=c[494446]|0;m=(n|0)!=0?n:c[p>>2]|0;ei(m|0,712776,(s=i,i=i+16|0,c[s>>2]=693144,c[s+8>>2]=69,s)|0)|0;i=s;m=c[494446]|0;n=(m|0)!=0?m:c[p>>2]|0;a_(n|0)|0;ch(2);return 0}else{aIv(k|0,0,12);o=k+4|0;q=0;r=k}}while(0);n=k;m=c[n>>2]|0;t=m;u=aIr(t,256)|0;if((u|0)==0){if((q|0)!=0){v=0;do{aIq(c[m+(v<<3)>>2]|0);v=v+1|0;}while(v>>>0<q>>>0)}aIq(t);aIq(k);l=0;i=f;return l|0}t=u;c[n>>2]=t;u=k+8|0;c[u>>2]=32;if((d|0)==0){w=0}else{w=gx(d,726824)|0}d=bF(b|0)|0;L2238:do{if((d|0)==0){v=c[494446]|0;m=(v|0)!=0?v:c[p>>2]|0;ei(m|0,698920,(s=i,i=i+8|0,c[s>>2]=b,s)|0)|0;i=s;m=c[494446]|0;v=(m|0)!=0?m:c[p>>2]|0;a_(v|0)|0;x=q;y=t}else{v=bV(d|0)|0;L2240:do{if((v|0)!=0){m=j|0;z=(w|0)==0;A=g|0;B=w|0;C=w+4|0;D=h+8|0;E=v;F=t;G=q;H=32;L2242:while(1){I=E+4|0;J=ck(I|0,46)|0;K=(J|0)==0?14317944:J+1|0;gz(m,b,I);J=a[E+1036|0]|0;do{if((J<<24>>24|0)==0|(J<<24>>24|0)==10){if((eI(m|0,h|0)|0)<0){L=0;M=1619;break}N=(c[D>>2]&61440|0)==16384;M=1618}else if((J<<24>>24|0)==4){N=1;M=1618}else{L=0;M=1619}}while(0);if((M|0)==1618){M=0;if(e|N^1){L=N;M=1619}else{O=F;P=G;Q=H}}L2249:do{if((M|0)==1619){M=0;if((cP(I|0,706480)|0)==0){O=F;P=G;Q=H;break}if((cP(I|0,702296)|0)==0){O=F;P=G;Q=H;break}L2253:do{if(!(L|z)){bQ(A|0,4096,709496,(s=i,i=i+16|0,c[s>>2]=706480,c[s+8>>2]=K,s)|0)|0;i=s;J=c[C>>2]|0;R=0;while(1){if(R>>>0>=J>>>0){O=F;P=G;Q=H;break L2249}S=c[(c[B>>2]|0)+(R<<3)>>2]|0;if((aIB(S|0,K|0)|0)==0){break L2253}if((aIB(S|0,A|0)|0)==0){break}else{R=R+1|0}}}}while(0);R=L&1;if(G>>>0<H>>>0){T=F;U=H}else{J=H<<1;if(G>>>0>=J>>>0){M=1629;break L2242}S=aIr(F,H<<4)|0;if((S|0)==0){V=F;M=1638;break L2242}W=S;c[n>>2]=W;c[u>>2]=J;T=W;U=J}J=dv(m|0)|0;if((J|0)==0){V=T;M=1638;break L2242}c[T+(G<<3)>>2]=J;J=c[o>>2]|0;W=c[n>>2]|0;c[W+(J<<3)+4>>2]=R;R=J+1|0;c[o>>2]=R;O=W;P=R;Q=U}}while(0);K=bV(d|0)|0;if((K|0)==0){break L2240}else{E=K;F=O;G=P;H=Q}}if((M|0)==1629){H=c[494446]|0;F=(H|0)!=0?H:c[p>>2]|0;ei(F|0,712776,(s=i,i=i+16|0,c[s>>2]=693144,c[s+8>>2]=69,s)|0)|0;i=s;F=c[494446]|0;H=(F|0)!=0?F:c[p>>2]|0;a_(H|0)|0;ch(2);return 0}else if((M|0)==1638){H=c[494446]|0;ei(((H|0)!=0?H:c[p>>2]|0)|0,698920,(s=i,i=i+8|0,c[s>>2]=b,s)|0)|0;i=s;H=c[494446]|0;a_(((H|0)!=0?H:c[p>>2]|0)|0)|0;eO(d|0)|0;x=G;y=V;break L2238}}}while(0);eO(d|0)|0;if((w|0)==0){l=r;i=f;return l|0}v=w+4|0;H=w|0;F=c[H>>2]|0;if((c[v>>2]|0)==0){X=F}else{E=0;m=F;while(1){aIq(c[m+(E<<3)>>2]|0);F=E+1|0;A=c[H>>2]|0;if(F>>>0<(c[v>>2]|0)>>>0){E=F;m=A}else{X=A;break}}}aIq(X);aIq(w);l=r;i=f;return l|0}}while(0);if((x|0)!=0){r=0;do{aIq(c[y+(r<<3)>>2]|0);r=r+1|0;}while(r>>>0<x>>>0)}aIq(y);aIq(k);if((w|0)==0){l=0;i=f;return l|0}k=w+4|0;y=w|0;x=c[y>>2]|0;if((c[k>>2]|0)==0){Y=x}else{r=0;X=x;while(1){aIq(c[X+(r<<3)>>2]|0);x=r+1|0;d=c[y>>2]|0;if(x>>>0<(c[k>>2]|0)>>>0){r=x;X=d}else{Y=d;break}}}aIq(Y);aIq(w);l=0;i=f;return l|0}function gz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1656;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1656){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;q=h}while(1){g=o+1|0;d=q+1|0;if((a[g]|0)==0){n=d;break}else{o=g;q=d}}}}while(0);if(n>>>0>=4096){n=c[494446]|0;q=(n|0)!=0?n:c[p>>2]|0;ei(q|0,712776,(r=i,i=i+16|0,c[r>>2]=693144,c[r+8>>2]=573,r)|0)|0;i=r;q=c[494446]|0;n=(q|0)!=0?q:c[p>>2]|0;a_(n|0)|0;ch(2)}if((a[b]|0)!=0){gG(b)}n=aIu(b|0)|0;q=n>>>0>4096?0:4096-n|0;L2308:do{if((q|0)==0){s=0;t=e;l=1667}else{o=q;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){u=h;break L2308}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;s=h;t=j;l=1667}}while(0);do{if((l|0)==1667){if((a[t]|0)==0){u=s;break}else{v=t;w=s}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){u=b;break}else{v=e;w=b}}}}while(0);if((u+n|0)>>>0<4096){i=f;return}else{f=c[494446]|0;n=(f|0)!=0?f:c[p>>2]|0;ei(n|0,712776,(r=i,i=i+16|0,c[r>>2]=693144,c[r+8>>2]=578,r)|0)|0;i=r;r=c[494446]|0;n=(r|0)!=0?r:c[p>>2]|0;a_(n|0)|0;ch(2)}}function gA(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+4096|0;g=f|0;h=4096;j=0;k=g;l=d;while(1){d=h-1|0;if((d|0)==0){m=1675;break}n=a[l]|0;a[k]=n;if(n<<24>>24==0){o=j;break}else{h=d;j=j+1|0;k=k+1|0;l=l+1|0}}do{if((m|0)==1675){a[k]=0;if((a[l]|0)==0){o=j;break}else{q=l;r=j}while(1){h=q+1|0;d=r+1|0;if((a[h]|0)==0){o=d;break}else{q=h;r=d}}}}while(0);if(o>>>0>=4096){o=c[494446]|0;r=(o|0)!=0?o:c[p>>2]|0;ei(r|0,712776,(s=i,i=i+16|0,c[s>>2]=693144,c[s+8>>2]=409,s)|0)|0;i=s;r=c[494446]|0;o=(r|0)!=0?r:c[p>>2]|0;a_(o|0)|0;ch(2)}o=ck(g|0,46)|0;if((o|0)==0){t=4096;u=0;v=b;w=g}else{a[o]=0;t=4096;u=0;v=b;w=g}while(1){g=t-1|0;if((g|0)==0){m=1683;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=u;break}else{t=g;u=u+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1683){a[v]=0;if((a[w]|0)==0){x=u;break}else{y=w;z=u}while(1){t=y+1|0;g=z+1|0;if((a[t]|0)==0){x=g;break}else{y=t;z=g}}}}while(0);if(x>>>0>=4096){x=c[494446]|0;z=(x|0)!=0?x:c[p>>2]|0;ei(z|0,712776,(s=i,i=i+16|0,c[s>>2]=693144,c[s+8>>2]=414,s)|0)|0;i=s;z=c[494446]|0;x=(z|0)!=0?z:c[p>>2]|0;a_(x|0)|0;ch(2)}x=aIu(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2347:do{if((z|0)==0){A=0;B=e;m=1692}else{y=z;u=0;w=b+x|0;v=e;while(1){g=y-1|0;if((g|0)==0){break}t=a[v]|0;a[w]=t;if(t<<24>>24==0){C=u;break L2347}else{y=g;u=u+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=u;B=v;m=1692}}while(0);do{if((m|0)==1692){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[494446]|0;x=(f|0)!=0?f:c[p>>2]|0;ei(x|0,712776,(s=i,i=i+16|0,c[s>>2]=693144,c[s+8>>2]=415,s)|0)|0;i=s;s=c[494446]|0;x=(s|0)!=0?s:c[p>>2]|0;a_(x|0)|0;ch(2)}}function gB(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1700;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1700){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;q=h}while(1){g=o+1|0;d=q+1|0;if((a[g]|0)==0){n=d;break}else{o=g;q=d}}}}while(0);if(n>>>0>=4096){n=c[494446]|0;q=(n|0)!=0?n:c[p>>2]|0;ei(q|0,712776,(r=i,i=i+16|0,c[r>>2]=693144,c[r+8>>2]=420,r)|0)|0;i=r;q=c[494446]|0;n=(q|0)!=0?q:c[p>>2]|0;a_(n|0)|0;ch(2)}n=aIu(b|0)|0;q=n>>>0>4096?0:4096-n|0;L2373:do{if((q|0)==0){s=0;t=e;l=1709}else{o=q;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){u=h;break L2373}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;s=h;t=j;l=1709}}while(0);do{if((l|0)==1709){if((a[t]|0)==0){u=s;break}else{v=t;w=s}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){u=b;break}else{v=e;w=b}}}}while(0);if((u+n|0)>>>0<4096){i=f;return}else{f=c[494446]|0;n=(f|0)!=0?f:c[p>>2]|0;ei(n|0,712776,(r=i,i=i+16|0,c[r>>2]=693144,c[r+8>>2]=421,r)|0)|0;i=r;r=c[494446]|0;n=(r|0)!=0?r:c[p>>2]|0;a_(n|0)|0;ch(2)}}function gC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;gG(b);f=ck(1853554,47)|0;g=(f|0)==0?1853554:f+1|0;f=aIu(b|0)|0;h=f>>>0>4096?0:4096-f|0;L2388:do{if((h|0)==0){j=0;k=g;l=1719}else{m=h;n=0;o=b+f|0;q=g;while(1){r=m-1|0;if((r|0)==0){break}s=a[q]|0;a[o]=s;if(s<<24>>24==0){t=n;break L2388}else{m=r;n=n+1|0;o=o+1|0;q=q+1|0}}a[o]=0;j=n;k=q;l=1719}}while(0);do{if((l|0)==1719){if((a[k]|0)==0){t=j;break}else{u=k;v=j}while(1){g=u+1|0;h=v+1|0;if((a[g]|0)==0){t=h;break}else{u=g;v=h}}}}while(0);if((t+f|0)>>>0>=4096){f=c[494446]|0;t=(f|0)!=0?f:c[p>>2]|0;ei(t|0,712776,(w=i,i=i+16|0,c[w>>2]=693144,c[w+8>>2]=457,w)|0)|0;i=w;t=c[494446]|0;f=(t|0)!=0?t:c[p>>2]|0;a_(f|0)|0;ch(2)}f=aIu(b|0)|0;t=f>>>0>4096?0:4096-f|0;L2402:do{if((t|0)==0){x=0;y=d;l=1728}else{v=t;u=0;j=b+f|0;k=d;while(1){q=v-1|0;if((q|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=u;break L2402}else{v=q;u=u+1|0;j=j+1|0;k=k+1|0}}a[j]=0;x=u;y=k;l=1728}}while(0);do{if((l|0)==1728){if((a[y]|0)==0){z=x;break}else{A=y;B=x}while(1){d=A+1|0;b=B+1|0;if((a[d]|0)==0){z=b;break}else{A=d;B=b}}}}while(0);if((z+f|0)>>>0<4096){i=e;return}else{e=c[494446]|0;f=(e|0)!=0?e:c[p>>2]|0;ei(f|0,712776,(w=i,i=i+16|0,c[w>>2]=693144,c[w+8>>2]=458,w)|0)|0;i=w;w=c[494446]|0;f=(w|0)!=0?w:c[p>>2]|0;a_(f|0)|0;ch(2)}}function gD(){var b=0,d=0.0,e=0.0,f=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0,q=0.0;b=i;a[1915101]=0;d=+h[239383];if(d<=0.0){i=b;return}e=+h[239384];if(e<=0.0){i=b;return}f=+g[431404];j=f;if(+Q(+(1.0-d/j))>.05000000074505806){if((a[1820736]&1)==0){k=d;l=f}else{m=c[494446]|0;n=(m|0)!=0?m:c[p>>2]|0;f=d;ei(n|0,709320,(o=i,i=i+16|0,h[o>>3]=j,h[o+8>>3]=f,o)|0)|0;i=o;n=c[494446]|0;m=(n|0)!=0?n:c[p>>2]|0;a_(m|0)|0;k=+h[239383];l=+g[431404]}do{if(k>l){a[1915101]=1;if((a[1820736]&1)==0){break}m=c[494446]|0;n=(m|0)!=0?m:c[p>>2]|0;a5(708936,57,1,n|0)|0;n=c[494446]|0;m=(n|0)!=0?n:c[p>>2]|0;a_(m|0)|0}}while(0);q=+h[239384]}else{q=e*(j/d)}d=q;g[433474]=d;if((a[1820736]&1)!=0){m=c[494446]|0;n=(m|0)!=0?m:c[p>>2]|0;q=d;ei(n|0,708544,(o=i,i=i+8|0,h[o>>3]=q,o)|0)|0;i=o;o=c[494446]|0;n=(o|0)!=0?o:c[p>>2]|0;a_(n|0)|0}n=c[3118440]|0;if((n|0)==0){i=b;return}if((a[1915101]&1)!=0){fj[c[(c[3118437]|0)+8>>2]&511](n,1);i=b;return}o=(a[12473776]&1)!=0;if((a[1820738]&1)!=0){fj[c[(c[3118437]|0)+8>>2]&511](n,(a[1717392]&1)==0|o)}n=c[3118439]|0;if((a[1820737]&1)!=0&(n|0)!=0){fj[c[(c[3118436]|0)+16>>2]&511](n,(a[1738e3]&1)==0|o)}c[479960]=o?c[479961]|0:c[479962]|0;i=b;return}function gE(){var a=0,b=0,d=0;a=c[3118488]|0;if((a|0)==0){b=0;return b|0}d=c[a+4>>2]|0;if((d|0)==0){b=0;return b|0}b=fl[d&255](c[3118440]|0)|0;return b|0}function gF(a){a=a|0;var b=0,d=0,e=0;b=c[3118488]|0;if((b|0)==0){d=0;return d|0}e=c[b+8>>2]|0;if((e|0)==0){d=0;return d|0}d=fA[e&63](c[3118440]|0,a)|0;return d|0}function gG(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=ck(b|0,47)|0;g=aIu(b|0)|0;if((f|0)==0){h=g>>>0>4096?0:4096-g|0;L2470:do{if((h|0)==0){j=0;k=698072;l=1788}else{m=b+g|0;do{if((h|0)==1){n=698072;o=m;q=0}else{r=b+(g+1)|0;a[m]=47;if((h|0)==2){n=698073;o=r;q=1;break}a[r]=0;s=1;break L2470}}while(0);a[o]=0;j=q;k=n;l=1788}}while(0);do{if((l|0)==1788){if((a[k]|0)==0){s=j;break}else{t=k;u=j}while(1){n=t+1|0;q=u+1|0;if((a[n]|0)==0){s=q;break}else{t=n;u=q}}}}while(0);if((s+g|0)>>>0<4096){i=d;return}else{s=c[494446]|0;u=(s|0)!=0?s:c[p>>2]|0;ei(u|0,712776,(v=i,i=i+16|0,c[v>>2]=693144,c[v+8>>2]=450,v)|0)|0;i=v;u=c[494446]|0;s=(u|0)!=0?u:c[p>>2]|0;a_(s|0)|0;ch(2)}}if((f|0)==(b+(g-1)|0)){i=d;return}g=e|0;s=a[f]|0;a[g]=s;a[e+1|0]=0;e=aIu(b|0)|0;f=e>>>0>4096?0:4096-e|0;L2488:do{if((f|0)==0){w=0;x=g;y=s;l=1780}else{u=f;t=0;j=b+e|0;k=g;while(1){q=u-1|0;if((q|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=t;break L2488}else{u=q;t=t+1|0;j=j+1|0;k=k+1|0}}a[j]=0;w=t;x=k;y=a[k]|0;l=1780}}while(0);do{if((l|0)==1780){if(y<<24>>24==0){z=w;break}else{A=x;B=w}while(1){g=A+1|0;b=B+1|0;if((a[g]|0)==0){z=b;break}else{A=g;B=b}}}}while(0);if((z+e|0)>>>0<4096){i=d;return}else{d=c[494446]|0;e=(d|0)!=0?d:c[p>>2]|0;ei(e|0,712776,(v=i,i=i+16|0,c[v>>2]=693144,c[v+8>>2]=447,v)|0)|0;i=v;v=c[494446]|0;e=(v|0)!=0?v:c[p>>2]|0;a_(e|0)|0;ch(2)}}function gH(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;f=i;g=ck(d|0,47)|0;h=(g|0)==0?d:g+1|0;L2503:do{if((e|0)==0){j=0;k=h;l=1801}else{g=e;d=0;m=b;n=h;while(1){o=g-1|0;if((o|0)==0){break}q=a[n]|0;a[m]=q;if(q<<24>>24==0){r=d;break L2503}else{g=o;d=d+1|0;m=m+1|0;n=n+1|0}}a[m]=0;j=d;k=n;l=1801}}while(0);do{if((l|0)==1801){if((a[k]|0)==0){r=j;break}else{s=k;t=j}while(1){h=s+1|0;b=t+1|0;if((a[h]|0)==0){r=b;break}else{s=h;t=b}}}}while(0);if(r>>>0<e>>>0){i=f;return}else{f=c[494446]|0;e=(f|0)!=0?f:c[p>>2]|0;ei(e|0,712776,(e=i,i=i+16|0,c[e>>2]=693144,c[e+8>>2]=470,e)|0)|0;i=e;e=c[494446]|0;f=(e|0)!=0?e:c[p>>2]|0;a_(f|0)|0;ch(2)}}function gI(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=i;f=4096;g=0;h=b;j=d;while(1){d=f-1|0;if((d|0)==0){k=1809;break}l=a[j]|0;a[h]=l;if(l<<24>>24==0){m=g;break}else{f=d;g=g+1|0;h=h+1|0;j=j+1|0}}do{if((k|0)==1809){a[h]=0;if((a[j]|0)==0){m=g;break}else{n=j;o=g}while(1){f=n+1|0;d=o+1|0;if((a[f]|0)==0){m=d;break}else{n=f;o=d}}}}while(0);if(m>>>0>=4096){m=c[494446]|0;o=(m|0)!=0?m:c[p>>2]|0;ei(o|0,712776,(q=i,i=i+16|0,c[q>>2]=693144,c[q+8>>2]=475,q)|0)|0;i=q;o=c[494446]|0;m=(o|0)!=0?o:c[p>>2]|0;a_(m|0)|0;ch(2)}if((aIu(b|0)|0)>>>0<2){i=e;return}m=ck(b|0,47)|0;if((m|0)==0){bQ(b|0,3,730256,(q=i,i=i+8|0,c[q>>2]=698072,q)|0)|0;i=q;i=e;return}else{a[m+1|0]=0;i=e;return}}function gJ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;if((a[e]|0)==47){g=4096;h=0;j=b;k=e;while(1){l=g-1|0;if((l|0)==0){m=1824;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=h;break}else{g=l;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((m|0)==1824){a[j]=0;if((a[k]|0)==0){o=h;break}else{q=k;r=h}while(1){g=q+1|0;l=r+1|0;if((a[g]|0)==0){o=l;break}else{q=g;r=l}}}}while(0);if(o>>>0<4096){i=f;return}else{o=c[494446]|0;r=(o|0)!=0?o:c[p>>2]|0;ei(r|0,712776,(s=i,i=i+16|0,c[s>>2]=693144,c[s+8>>2]=562,s)|0)|0;i=s;r=c[494446]|0;o=(r|0)!=0?r:c[p>>2]|0;a_(o|0)|0;ch(2)}}else{t=4096;u=0;v=b;w=d}while(1){d=t-1|0;if((d|0)==0){m=1830;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=u;break}else{t=d;u=u+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1830){a[v]=0;if((a[w]|0)==0){x=u;break}else{y=w;z=u}while(1){t=y+1|0;d=z+1|0;if((a[t]|0)==0){x=d;break}else{y=t;z=d}}}}while(0);if(x>>>0>=4096){x=c[494446]|0;z=(x|0)!=0?x:c[p>>2]|0;ei(z|0,712776,(s=i,i=i+16|0,c[s>>2]=693144,c[s+8>>2]=565,s)|0)|0;i=s;z=c[494446]|0;x=(z|0)!=0?z:c[p>>2]|0;a_(x|0)|0;ch(2)}do{if((aIu(b|0)|0)>>>0>=2){x=ck(b|0,47)|0;if((x|0)==0){bQ(b|0,3,730256,(s=i,i=i+8|0,c[s>>2]=698072,s)|0)|0;i=s;break}else{a[x+1|0]=0;break}}}while(0);x=aIu(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2566:do{if((z|0)==0){A=0;B=e;m=1843}else{y=z;u=0;w=b+x|0;v=e;while(1){d=y-1|0;if((d|0)==0){break}t=a[v]|0;a[w]=t;if(t<<24>>24==0){C=u;break L2566}else{y=d;u=u+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=u;B=v;m=1843}}while(0);do{if((m|0)==1843){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[494446]|0;x=(f|0)!=0?f:c[p>>2]|0;ei(x|0,712776,(s=i,i=i+16|0,c[s>>2]=693144,c[s+8>>2]=567,s)|0)|0;i=s;s=c[494446]|0;x=(s|0)!=0?s:c[p>>2]|0;a_(x|0)|0;ch(2)}}function gK(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0.0,r=0.0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+24|0;d=b|0;a[12473771]=(c[3118440]|0)==0|0;a[12473772]=(c[3118439]|0)==0|0;a[12473773]=(c[3118441]|0)==0|0;gD();c[494386]=0;e=d;L2581:do{if((a[1725621]|0)!=0){f=gy(1725621,712384,0)|0;c[494403]=f;do{if((f|0)!=0){j=f+4|0;if((c[j>>2]|0)==0){aIq(c[f>>2]|0);aIq(f);break}c[494404]=0;dm(c[f>>2]|0,c[j>>2]|0,8,4);j=c[494403]|0;if((c[j+4>>2]|0)==0){break L2581}else{k=0;l=j}while(1){if((a[1820736]&1)==0){m=l}else{j=c[494446]|0;n=(j|0)!=0?j:c[p>>2]|0;j=c[(c[l>>2]|0)+(k<<3)>>2]|0;ei(n|0,711312,(o=i,i=i+8|0,c[o>>2]=j,o)|0)|0;i=o;j=c[494446]|0;n=(j|0)!=0?j:c[p>>2]|0;a_(n|0)|0;m=c[494403]|0}n=k+1|0;if(n>>>0<(c[m+4>>2]|0)>>>0){k=n;l=m}else{break L2581}}}}while(0);c[494403]=0;c[494404]=0}}while(0);m=c[478762]|0;l=c[478763]|0;k=(m>>>0>l>>>0?m:l)-1|0;l=k>>>1|k;k=l>>>2|l;l=k>>>4|k;k=l>>>8|l;l=((k>>>16|k)+1|0)>>>8;k=(a[1969096]&1)==0?l>>>0>1?l:1:c[492279]|0;q=+g[429352];g[478770]=q;do{if(q<0.0){r=+g[478764];if(r>0.0){if((a[1717412]&1)==0){s=1862}else{t=r}}else{s=1862}if((s|0)==1862){t=+((c[478760]|0)>>>0>>>0)/+((c[478761]|0)>>>0>>>0)}g[478770]=t;if((a[1820736]&1)==0){break}l=c[494446]|0;m=(l|0)!=0?l:c[p>>2]|0;r=t;ei(m|0,690936,(o=i,i=i+8|0,h[o>>3]=r,o)|0)|0;i=o;m=c[494446]|0;l=(m|0)!=0?m:c[p>>2]|0;a_(l|0)|0}}while(0);do{if((a[1717376]&1)==0){if((a[1717405]&1)==0){s=~~+bK(+(+((c[478760]|0)>>>0>>>0)*+g[429342]));u=s;v=~~+bK(+(+((c[478761]|0)>>>0>>>0)*+g[429343]));break}else{t=+((c[478761]|0)>>>0>>>0);q=+(~~+bK(+(t*+g[478770]))>>>0>>>0);s=~~+bK(+(+g[429342]*q));u=s;v=~~+bK(+(t*+g[429343]));break}}else{u=c[429346]|0;v=c[429347]|0}}while(0);s=(a[1820736]&1)==0;do{if((u|0)==0|(v|0)==0){if(s){break}l=c[494446]|0;m=(l|0)!=0?l:c[p>>2]|0;a5(727792,30,1,m|0)|0;m=c[494446]|0;l=(m|0)!=0?m:c[p>>2]|0;a_(l|0)|0}else{if(s){break}l=c[494446]|0;m=(l|0)!=0?l:c[p>>2]|0;ei(m|0,730192,(o=i,i=i+16|0,c[o>>2]=u,c[o+8>>2]=v,o)|0)|0;i=o;m=c[494446]|0;l=(m|0)!=0?m:c[p>>2]|0;a_(l|0)|0}}while(0);c[3118447]=0;c[3118445]=0;c[3118446]=0;s=k<<8;aIq(c[3118464]|0);aIq(c[3118467]|0);aIq(c[3118468]|0);aIq(c[3118471]|0);aIq(c[3118474]|0);aIq(c[3118472]|0);aIq(c[3118478]|0);aIv(12473792,0,128);aIq(c[3118480]|0);c[3118480]=0;if((c[478774]|0)==0){l=c[494446]|0;m=(l|0)!=0?l:c[p>>2]|0;a5(713696,120,1,m|0)|0;m=c[494446]|0;l=(m|0)!=0?m:c[p>>2]|0;a_(l|0)|0;c[3118456]=1;c[3118454]=2;c[3118455]=3;if(!(hR(12473792)|0)){l=c[494446]|0;m=(l|0)!=0?l:c[p>>2]|0;a5(725648,53,1,m|0)|0;m=c[494446]|0;l=(m|0)!=0?m:c[p>>2]|0;a_(l|0)|0;gO(724544)}l=ab(s,s)|0;s=l<<1;if(l>>>0>65535){w=(l&2147418112|0)==(l|0)?s:-1}else{w=s}s=aIp(w)|0;do{if((s|0)!=0){if((c[s-4>>2]&3|0)==0){break}aIv(s|0,0,w|0)}}while(0);c[3118480]=s}c[e>>2]=c[168062];c[e+4>>2]=c[168063];c[e+8>>2]=c[168064];c[e+12>>2]=c[168065];c[e+16>>2]=c[168066];c[d>>2]=u;c[d+4>>2]=v;a[d+8|0]=a[1717376]&1;if((a[1717392]&1)==0){x=0}else{x=a[1915101]&1^1}a[d+9|0]=x;a[d+10|0]=a[1717405]&1;a[d+11|0]=a[1717404]&1;c[d+12>>2]=k;if((a[1969096]&1)==0){y=(c[478774]|0)==1|0}else{y=1}a[d+16|0]=y;y=c[3118438]|0;k=fp[c[c[3118437]>>2]&63](d,12473752,12473764)|0;c[3118440]=k;if((k|0)==0){d=c[494446]|0;x=(d|0)!=0?d:c[p>>2]|0;a5(723424,62,1,x|0)|0;x=c[494446]|0;d=(x|0)!=0?x:c[p>>2]|0;a_(d|0)|0;gO(724544)}c[3118488]=0;d=c[3118437]|0;x=c[d+56>>2]|0;if((x|0)==0){z=d}else{fj[x&511](k,12473952);z=c[3118437]|0}k=c[z+40>>2]|0;z=c[478771]|0;if((k|0)!=0&(z|0)!=0){fj[k&511](c[3118440]|0,z)}z=c[3118488]|0;do{if((z|0)!=0){k=c[z+12>>2]|0;x=c[429354]|0;if(!((k|0)!=0&(x|0)!=4)){break}fj[k&511](c[3118440]|0,x)}}while(0);do{if((c[3118438]|0)==0){if((a[1820736]&1)!=0){z=c[494446]|0;x=(z|0)!=0?z:c[p>>2]|0;a5(721872,101,1,x|0)|0;x=c[494446]|0;z=(x|0)!=0?x:c[p>>2]|0;a_(z|0)|0}c[3118438]=y;if((y|0)==0){z=c[494446]|0;x=(z|0)!=0?z:c[p>>2]|0;a5(719632,59,1,x|0)|0;x=c[494446]|0;z=(x|0)!=0?x:c[p>>2]|0;a_(z|0)|0;gO(724544)}z=fD[c[y>>2]&127]()|0;c[3118441]=z;if((z|0)!=0){break}z=c[494446]|0;x=(z|0)!=0?z:c[p>>2]|0;a5(720744,59,1,x|0)|0;x=c[494446]|0;z=(x|0)!=0?x:c[p>>2]|0;a_(z|0)|0;gO(724544)}}while(0);y=c[3118482]|0;if((y|0)!=0){z=y+24|0;x=y+12|0;k=c[x>>2]|0;if((c[z>>2]|0)==0){A=k}else{d=0;v=k;while(1){aIq(c[v+(d*136|0)>>2]|0);aIq(c[v+(d*136|0)+8>>2]|0);k=d+1|0;u=c[x>>2]|0;if(k>>>0<(c[z>>2]|0)>>>0){d=k;v=u}else{A=u;break}}}aIq(A);A=c[y+4>>2]|0;if((A|0)!=0){fj[c[A>>2]&511](c[y>>2]|0,0)}aIq(y);c[3118482]=0}do{if((a[1778680]|0)!=0){y=hQ()|0;c[3118482]=y;if((y|0)!=0){break}y=c[494446]|0;A=(y|0)!=0?y:c[p>>2]|0;a5(715168,45,1,A|0)|0;A=c[494446]|0;y=(A|0)!=0?A:c[p>>2]|0;a_(y|0)|0}}while(0);y=1969088;c[y>>2]=0;c[y+4>>2]=0;y=c[479938]|0;if((a[12473770]&1)==0&(y|0)!=0){fG[y&16383]()}a[12473770]=0;do{if((c[3118439]|0)==0){y=~~(+g[453892]*65536.0);A=aIp(y<<1)|0;c[479968]=A;if((A|0)==0){A=c[494446]|0;v=(A|0)!=0?A:c[p>>2]|0;ei(v|0,712776,(o=i,i=i+16|0,c[o>>2]=702232,c[o+8>>2]=497,o)|0)|0;i=o;v=c[494446]|0;A=(v|0)!=0?v:c[p>>2]|0;a_(A|0)|0;ch(2)}c[479962]=512;c[479961]=2048;c[479960]=512;A=aIp(8192)|0;c[479969]=A;if((A|0)==0){A=c[494446]|0;v=(A|0)!=0?A:c[p>>2]|0;ei(v|0,712776,(o=i,i=i+16|0,c[o>>2]=702232,c[o+8>>2]=504,o)|0)|0;i=o;v=c[494446]|0;A=(v|0)!=0?v:c[p>>2]|0;a_(A|0)|0;ch(2)}c[479971]=4096;if((a[1733884]&1)==0){a[1820737]=0;break}A=fp[c[c[3118436]>>2]&63]((a[1733900]|0)!=0?1733900:0,c[433472]|0,c[434499]|0)|0;c[3118439]=A;do{if((A|0)==0){v=c[494446]|0;d=(v|0)!=0?v:c[p>>2]|0;a5(698784,85,1,d|0)|0;d=c[494446]|0;v=(d|0)!=0?d:c[p>>2]|0;a_(v|0)|0;a[1820737]=0}else{if((a[1820737]&1)==0){break}v=c[(c[3118436]|0)+24>>2]|0;if((v|0)==0){break}if(!(fl[v&255](A)|0)){break}a[1919864]=1}}while(0);do{if((a[1738e3]&1)==0){if((a[1820737]&1)==0){break}fj[c[(c[3118436]|0)+16>>2]&511](c[3118439]|0,1);c[479960]=c[479961]}}while(0);t=+((c[433472]|0)>>>0>>>0)/+g[433474];h[239982]=t;h[239988]=t;A=a[1742108]|0;v=c[479956]|0;do{if((v|0)!=0){d=c[479957]|0;if((d|0)==0){break}fi[c[d+8>>2]&255](v)}}while(0);c[479957]=2504;v=ir(t)|0;c[479956]=v;if((v|0)==0){c[479957]=0;v=c[494446]|0;d=(v|0)!=0?v:c[p>>2]|0;v=A<<24>>24!=0?1742108:695128;ei(d|0,697192,(o=i,i=i+8|0,c[o>>2]=v,o)|0)|0;i=o;v=c[494446]|0;d=(v|0)!=0?v:c[p>>2]|0;a_(d|0)|0;a[1820737]=0}d=aIp(16384)|0;c[479958]=d;if((d|0)==0){d=c[494446]|0;v=(d|0)!=0?d:c[p>>2]|0;ei(v|0,712776,(o=i,i=i+16|0,c[o>>2]=702232,c[o+8>>2]=561,o)|0)|0;i=o;v=c[494446]|0;d=(v|0)!=0?v:c[p>>2]|0;a_(d|0)|0;ch(2)}c[479959]=0;if(+((c[433472]|0)>>>0>>>0)>=+g[433474]*16.0){d=c[494446]|0;v=(d|0)!=0?d:c[p>>2]|0;ei(v|0,712776,(o=i,i=i+16|0,c[o>>2]=702232,c[o+8>>2]=565,o)|0)|0;i=o;v=c[494446]|0;d=(v|0)!=0?v:c[p>>2]|0;a_(d|0)|0;ch(2)}d=aIp(y<<2)|0;c[479967]=d;if((d|0)==0){d=c[494446]|0;v=(d|0)!=0?d:c[p>>2]|0;ei(v|0,712776,(o=i,i=i+16|0,c[o>>2]=702232,c[o+8>>2]=566,o)|0)|0;i=o;v=c[494446]|0;d=(v|0)!=0?v:c[p>>2]|0;a_(d|0)|0;ch(2)}a[1919900]=0;L2714:do{if((c[479929]|0)==0){if((a[1820737]&1)==0){break}if((a[1742097]&1)==0){break}d=c[3118436]|0;v=c[d+36>>2]|0;do{if((v|0)!=0){if((c[d+32>>2]|0)==0){break}c[479978]=fl[v&255](c[3118439]|0)|0;a[1919900]=1;break L2714}}while(0);v=c[494446]|0;d=(v|0)!=0?v:c[p>>2]|0;a5(693016,97,1,d|0)|0;d=c[494446]|0;v=(d|0)!=0?d:c[p>>2]|0;a_(v|0)|0}}while(0);t=+g[435526];g[479979]=t;g[479980]=+S(10.0,+(t/20.0));y=1952696;c[y>>2]=0;c[y+4>>2]=0;if((a[1820737]&1)==0){break}if(!((a[1919865]&1)==0&(c[479929]|0)!=0)){break}y=c[(c[3118436]|0)+12>>2]|0;A=c[3118439]|0;fl[y&255](A)|0}}while(0);if((a[12473776]&1)==0){B=1919808;C=0;D=0;E=B|0;c[E>>2]=C;F=B+4|0;c[F>>2]=D;i=b;return}o=c[3118440]|0;if((a[1820738]&1)!=0&(o|0)!=0){fj[c[(c[3118437]|0)+8>>2]&511](o,1)}o=c[3118439]|0;if((a[1820737]&1)!=0&(o|0)!=0){fj[c[(c[3118436]|0)+16>>2]&511](o,1)}c[479960]=c[479961];B=1919808;C=0;D=0;E=B|0;c[E>>2]=C;F=B+4|0;c[F>>2]=D;i=b;return}function gL(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,q=0,r=0,s=0,t=0,u=0.0,v=0;b=i;d=c[3118439]|0;e=c[3118436]|0;if((d|0)!=0&(e|0)!=0){fi[c[e+20>>2]&255](d)}aIq(c[479968]|0);c[479968]=0;c[479959]=0;aIq(c[479969]|0);c[479969]=0;if((a[1733884]&1)==0){a[1820737]=0;i=b;return}d=c[479957]|0;e=c[479956]|0;if((d|0)!=0&(e|0)!=0){fi[c[d+8>>2]&255](e)}c[479957]=0;c[479956]=0;aIq(c[479958]|0);c[479958]=0;aIq(c[479967]|0);c[479967]=0;e=1952696;d=c[e>>2]|0;f=c[e+4>>2]|0;e=0;g=f>>>0<e>>>0|f>>>0==e>>>0&d>>>0<8192>>>0?d:8192;if(g>>>0<3){i=b;return}else{j=1;k=0;l=0}do{l=aIF(c[1919928+(j<<2)>>2]|0,0,l,k)|0;k=F;j=j+1|0;}while(j>>>0<g>>>0);j=g-1|0;d=aIQ(l,k,j,0)|0;k=d;d=1;l=0;e=0;do{f=k-(c[1919928+(d<<2)>>2]|0)|0;e=aIF(ab(f,f)|0,0,e,l)|0;l=F;d=d+1|0;}while(d>>>0<g>>>0);m=+R(+((+(e>>>0)+ +(l>>>0)*4294967296.0)/+((g-2|0)>>>0>>>0)));l=c[479978]|0;n=+(l>>>0>>>0);o=+(k|0)/n;k=(l*3|0)>>>2;e=l>>>2;l=0;d=0;f=1;while(1){q=c[1919928+(f<<2)>>2]|0;if(q>>>0<k>>>0){r=(q>>>0<=e>>>0)+d|0;s=l}else{r=d;s=l+1|0}q=f+1|0;if(q>>>0<g>>>0){l=s;d=r;f=q}else{break}}f=a[1820736]|0;if((f&1)==0){t=f}else{f=c[494446]|0;d=(f|0)!=0?f:c[p>>2]|0;u=(1.0-o)*100.0;o=+(~~m>>>0>>>0)/n*100.0;ei(d|0,710672,(v=i,i=i+16|0,h[v>>3]=u,h[v+8>>3]=o,v)|0)|0;i=v;d=c[494446]|0;f=(d|0)!=0?d:c[p>>2]|0;a_(f|0)|0;t=a[1820736]|0}if((t&1)==0){i=b;return}t=c[494446]|0;o=+(j>>>0>>>0);ei(((t|0)!=0?t:c[p>>2]|0)|0,709832,(v=i,i=i+16|0,h[v>>3]=+(s>>>0>>>0)*100.0/o,h[v+8>>3]=+(r>>>0>>>0)*100.0/o,v)|0)|0;i=v;v=c[494446]|0;a_(((v|0)!=0?v:c[p>>2]|0)|0)|0;i=b;return}function gM(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0;b=i;d=c[3118482]|0;if((d|0)!=0){e=d+24|0;f=d+12|0;g=c[f>>2]|0;if((c[e>>2]|0)==0){j=g}else{k=0;l=g;while(1){aIq(c[l+(k*136|0)>>2]|0);aIq(c[l+(k*136|0)+8>>2]|0);g=k+1|0;m=c[f>>2]|0;if(g>>>0<(c[e>>2]|0)>>>0){k=g;l=m}else{j=m;break}}}aIq(j);j=c[d+4>>2]|0;if((j|0)!=0){fj[c[j>>2]&511](c[d>>2]|0,0)}aIq(d);c[3118482]=0;aIv(12473936,0,16)}d=c[3118441]|0;j=c[3118440]|0;l=c[3118438]|0;if((d|0)!=(j|0)&(l|0)!=0){fi[c[l+16>>2]&255](d);n=c[3118440]|0}else{n=j}j=c[3118437]|0;if((n|0)!=0&(j|0)!=0){fi[c[j+24>>2]&255](n)}aIq(c[3118464]|0);aIq(c[3118467]|0);aIq(c[3118468]|0);aIq(c[3118471]|0);aIq(c[3118474]|0);aIq(c[3118472]|0);aIq(c[3118478]|0);aIv(12473792,0,128);aIq(c[3118480]|0);c[3118480]=0;n=c[494403]|0;if((n|0)!=0){j=n+4|0;d=n|0;l=c[d>>2]|0;if((c[j>>2]|0)==0){o=l}else{k=0;e=l;while(1){aIq(c[e+(k<<3)>>2]|0);l=k+1|0;f=c[d>>2]|0;if(l>>>0<(c[j>>2]|0)>>>0){k=l;e=f}else{o=f;break}}}aIq(o);aIq(n)}c[494403]=0;c[494404]=0;if((a[1725620]&1)!=0){if((a[1820736]&1)==0){i=b;return}n=c[494446]|0;o=(n|0)!=0?n:c[p>>2]|0;a5(718640,66,1,o|0)|0;o=c[494446]|0;n=(o|0)!=0?o:c[p>>2]|0;a_(n|0)|0;i=b;return}n=1969088;o=c[n+4>>2]|0;e=0;if(o>>>0<e>>>0|o>>>0==e>>>0&(c[n>>2]|0)>>>0<4096>>>0){if((a[1820736]&1)==0){i=b;return}n=c[494446]|0;e=(n|0)!=0?n:c[p>>2]|0;ei(e|0,717640,(q=i,i=i+8|0,c[q>>2]=4096,q)|0)|0;i=q;e=c[494446]|0;n=(e|0)!=0?e:c[p>>2]|0;a_(n|0)|0;i=b;return}else{r=0;s=0;t=0}do{n=1952704+(r<<3)|0;t=aIF(c[n>>2]|0,c[n+4>>2]|0,t,s)|0;s=F;r=r+1|0;}while(r>>>0<2048);r=aIN(t,s,2048,0)|0;s=F;t=0;n=0;e=0;do{o=1952704+(e<<3)|0;k=aIG(c[o>>2]|0,c[o+4>>2]|0,r,s)|0;o=F;j=aIP(k,o,k,o)|0;n=aIF(j,F,n,t)|0;t=F;e=e+1|0;}while(e>>>0<2048);u=+(r>>>0)+ +(s|0)*4294967296.0;if((a[1820736]&1)==0){i=b;return}v=+R(+((+(n>>>0)+ +(t|0)*4294967296.0)/2047.0))/u;t=c[494446]|0;ei(((t|0)!=0?t:c[p>>2]|0)|0,716688,(q=i,i=i+24|0,h[q>>3]=1.0e6/u,h[q+8>>3]=v*100.0,c[q+16>>2]=2048,q)|0)|0;i=q;q=c[494446]|0;a_(((q|0)!=0?q:c[p>>2]|0)|0)|0;i=b;return}function gN(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=c[a+4>>2]|0;if((b|0)!=0){d=b;while(1){aIq(c[d+4>>2]|0);aIq(c[d+8>>2]|0);b=c[d+12>>2]|0;aIq(d|0);if((b|0)==0){break}else{d=b}}}d=c[a+16>>2]|0;if((d|0)!=0){b=d;while(1){aIq(c[b>>2]|0);d=c[b+4>>2]|0;aIq(b);if((d|0)==0){break}else{b=d}}}aIq(c[a>>2]|0);aIq(a);return}function gO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[1977789]&1)==0){d=c[494446]|0;e=(d|0)!=0?d:c[p>>2]|0;ei(e|0,712776,(e=i,i=i+16|0,c[e>>2]=722624,c[e+8>>2]=832,e)|0)|0;i=e;e=c[494446]|0;d=(e|0)!=0?e:c[p>>2]|0;a_(d|0)|0;ch(2)}else{f=1024;g=1977791;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=2033;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==2033){eJ(1978816,1)}a[g]=0;if((a[h]|0)==0){eJ(1978816,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);eJ(1978816,1)}function gP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+4112|0;f=e|0;g=e+8|0;h=e+4104|0;j=aIp(20)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){aIv(j|0,0,20)}l=j;if((b|0)==0){k=l;i=e;return k|0}m=dv(b|0)|0;n=j;c[n>>2]=m;if((m|0)==0){aIq(j);k=0;i=e;return k|0}o=j+12|0;c[o>>2]=d;d=c9(b|0,720728)|0;if((d|0)==0){aIq(m);aIq(j);k=0;i=e;return k|0}if((en(d|0)|0)==0){m=j+8|0;b=j+4|0;q=g|0;r=j+16|0;do{j=aIp(16)|0;do{if((j|0)!=0){if((c[j-4>>2]&3|0)==0){break}aIv(j|0,0,16)}}while(0);s=j;t=aIp(9)|0;u=bS(d|0)|0;v=0;w=8;y=t;while(1){if((u|0)==(-1|0)|(u|0)==10){break}if((v|0)==(w|0)){t=w<<1;z=t;A=aIr(y,t|1)|0}else{z=w;A=y}a[A+v|0]=u&255;u=bS(d|0)|0;v=v+1|0;w=z;y=A}a[y+v|0]=0;if((y|0)!=0){w=b4(y|0,35)|0;if((w|0)!=0){a[w]=0}u=c[o>>2]|0;do{if((w|0)==(y|0)){if(u>>>0>=16){B=2105;break}if((bM(y+1|0,716664,8)|0)!=0){C=y;B=2106;break}t=y+9|0;while(1){D=t+1|0;if((bf(a[t]|0)|0)==0){break}else{t=D}}E=a[t]|0;if((E<<24>>24|0)==0){break}else if((E<<24>>24|0)==34){E=ee(D|0,713608,f|0)|0;if((E|0)==0){break}F=dv(E|0)|0}else{E=ee(t|0,712272,f|0)|0;if((E|0)==0){break}F=dv(E|0)|0}if((F|0)==0){break}E=c[r>>2]|0;G=aIp(8)|0;do{if((G|0)!=0){if((c[G-4>>2]&3|0)==0){break}H=G;I=H|0;x=0;a[I]=x&255;x=x>>8;a[I+1|0]=x&255;x=x>>8;a[I+2|0]=x&255;x=x>>8;a[I+3|0]=x&255;I=H+4|0;x=0;a[I]=x&255;x=x>>8;a[I+1|0]=x&255;x=x>>8;a[I+2|0]=x&255;x=x>>8;a[I+3|0]=x&255}}while(0);t=G;c[G>>2]=dv(F|0)|0;if((E|0)==0){c[r>>2]=t}else{I=E;do{J=I+4|0;I=c[J>>2]|0;}while((I|0)!=0);c[J>>2]=t}L2906:do{if((a[F]|0)==126){I=dJ(724216)|0;E=4096;G=q;H=(I|0)!=0?I:14317944;while(1){I=E-1|0;if((I|0)==0){B=2079;break}K=a[H]|0;a[G]=K;if(K<<24>>24==0){break}else{E=I;G=G+1|0;H=H+1|0}}do{if((B|0)==2079){B=0;a[G]=0;if((a[H]|0)==0){break}else{L=H}do{L=L+1|0;}while((a[L]|0)!=0)}}while(0);H=F+1|0;G=aIu(q|0)|0;E=G>>>0>4096?0:4096-G|0;if((E|0)==0){M=H}else{I=E;E=g+G|0;G=H;while(1){H=I-1|0;if((H|0)==0){break}K=a[G]|0;a[E]=K;if(K<<24>>24==0){break L2906}else{I=H;E=E+1|0;G=G+1|0}}a[E]=0;M=G}if((a[M]|0)==0){break}else{N=M}do{N=N+1|0;}while((a[N]|0)!=0)}else{gJ(q,c[n>>2]|0,F)}}while(0);t=gP(q,(c[o>>2]|0)+1|0)|0;if((t|0)==0){aIq(F);break}G=c[b>>2]|0;if((G|0)==0){E=t+4|0;I=c[E>>2]|0;if((I|0)==0){O=0}else{H=I;do{a[H|0]=1;H=c[H+12>>2]|0;}while((H|0)!=0);O=c[E>>2]|0}c[b>>2]=O;P=O}else{H=G;do{Q=H+12|0;H=c[Q>>2]|0;}while((H|0)!=0);H=t+4|0;G=c[H>>2]|0;if((G|0)==0){R=0}else{E=G;do{a[E|0]=1;E=c[E+12>>2]|0;}while((E|0)!=0);R=c[H>>2]|0}c[Q>>2]=R;P=c[b>>2]|0}c[t+4>>2]=0;if((P|0)==0){S=0}else{E=P;while(1){G=c[E+12>>2]|0;if((G|0)==0){S=E;break}else{E=G}}}c[m>>2]=S;gN(t);aIq(F)}else{if(u>>>0>15){B=2105}else{C=y;B=2106}}}while(0);if((B|0)==2105){B=0;u=c[p>>2]|0;a5(715296,58,1,u|0)|0;C=y;B=2106}L2952:do{if((B|0)==2106){while(1){B=0;if((bf(a[C]|0)|0)==0){break}else{C=C+1|0;B=2106}}t=aIp(9)|0;if((eP(a[C]|0)|0)==0){T=C;U=t;V=0}else{u=C;w=t;t=8;v=0;while(1){if((v|0)==(t|0)){E=v<<1;W=E;X=aIr(w,E|1)|0}else{W=t;X=w}E=u+1|0;H=v+1|0;a[X+v|0]=a[u]|0;if((eP(a[E]|0)|0)==0){T=E;U=X;V=H;break}else{u=E;w=X;t=W;v=H}}}a[U+V|0]=0;v=j+4|0;c[v>>2]=U;t=T;while(1){Y=t+1|0;if((bf(a[t]|0)|0)==0){break}else{t=Y}}do{if((a[t]|0)==61){w=Y;while(1){Z=w+1|0;if((bf(a[w]|0)|0)==0){break}else{w=Z}}u=a[w]|0;if((u<<24>>24|0)==34){H=ee(Z|0,713608,h|0)|0;if((H|0)==0){B=2120;break}_=dv(H|0)|0}else if((u<<24>>24|0)==0){B=2120;break}else{u=ee(w|0,712272,h|0)|0;if((u|0)==0){B=2120;break}_=dv(u|0)|0}c[j+8>>2]=_;if((_|0)==0){break}if((c[b>>2]|0)==0){c[b>>2]=s;c[m>>2]=s;break L2952}else{c[(c[m>>2]|0)+12>>2]=s;c[m>>2]=s;break L2952}}else{B=2120}}while(0);if((B|0)==2120){B=0;c[j+8>>2]=0}c[v>>2]=0;aIq(U)}}while(0);aIq(y)}if((s|0)!=(c[m>>2]|0)){aIq(j)}}while((en(d|0)|0)==0)}aS(d|0)|0;k=l;i=e;return k|0}function gQ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+8192|0;g=f|0;h=f+4096|0;j=b+4|0;while(1){k=c[j>>2]|0;if((k|0)==0){l=0;m=2175;break}if((cP(d|0,c[k+4>>2]|0)|0)==0){break}else{j=k+12|0}}if((m|0)==2175){i=f;return l|0}j=c[k+8>>2]|0;k=a[j]|0;do{if((k<<24>>24|0)==58){if((a[j+1|0]|0)!=47){n=e;o=j;q=4096;m=2167;break}d=h|0;b=g|0;a[d]=0;r=b0()|0;s=0;while(1){if(s>>>0>=3){m=2153;break}t=c[675080+(s<<2)>>2]|0;bQ(b|0,4096,723504,(u=i,i=i+16|0,c[u>>2]=r,c[u+8>>2]=t,u)|0)|0;i=u;v=eQ(b|0,d|0,4095)|0;if((v|0)>-1){m=2152;break}else{s=s+1|0}}if((m|0)==2152){a[h+v|0]=0}else if((m|0)==2153){s=c[494446]|0;a5(722e3,78,1,((s|0)!=0?s:c[p>>2]|0)|0)|0;s=c[494446]|0;a_(((s|0)!=0?s:c[p>>2]|0)|0)|0}if((a[1820736]&1)!=0){s=c[494446]|0;b=(s|0)!=0?s:c[p>>2]|0;ei(b|0,711688,(u=i,i=i+8|0,c[u>>2]=d,u)|0)|0;i=u;b=c[494446]|0;s=(b|0)!=0?b:c[p>>2]|0;a_(s|0)|0}do{if((aIu(d|0)|0)>>>0<2){w=4096;x=0;y=e;z=d}else{s=ck(d|0,47)|0;if((s|0)==0){bQ(d|0,3,730256,(u=i,i=i+8|0,c[u>>2]=698072,u)|0)|0;i=u;w=4096;x=0;y=e;z=d;break}else{a[s+1|0]=0;w=4096;x=0;y=e;z=d;break}}}while(0);while(1){d=w-1|0;if((d|0)==0){m=2162;break}s=a[z]|0;a[y]=s;if(s<<24>>24==0){A=x;break}else{w=d;x=x+1|0;y=y+1|0;z=z+1|0}}do{if((m|0)==2162){a[y]=0;if((a[z]|0)==0){A=x;break}else{B=z;C=x}while(1){d=B+1|0;s=C+1|0;if((a[d]|0)==0){A=s;break}else{B=d;C=s}}}}while(0);if(A>>>0<4096){D=A;E=j+2|0;m=2166;break}else{l=0;i=f;return l|0}}else if((k<<24>>24|0)==126){s=dJ(724216)|0;if((s|0)==0){n=e;o=j;q=4096;m=2167;break}else{F=4096;G=0;H=e;I=s}while(1){s=F-1|0;if((s|0)==0){m=2144;break}d=a[I]|0;a[H]=d;if(d<<24>>24==0){J=G;break}else{F=s;G=G+1|0;H=H+1|0;I=I+1|0}}do{if((m|0)==2144){a[H]=0;if((a[I]|0)==0){J=G;break}else{K=I;L=G}while(1){s=K+1|0;d=L+1|0;if((a[s]|0)==0){J=d;break}else{K=s;L=d}}}}while(0);if(J>>>0<4096){D=J;E=j+1|0;m=2166;break}else{l=0;i=f;return l|0}}else{n=e;o=j;q=4096;m=2167}}while(0);if((m|0)==2166){if((D|0)==4096){M=0;N=E;O=0;m=2171}else{n=e+D|0;o=E;q=4096-D|0;m=2167}}L3040:do{if((m|0)==2167){D=q;E=0;e=n;j=o;while(1){J=D-1|0;if((J|0)==0){break}L=a[j]|0;a[e]=L;if(L<<24>>24==0){P=E;Q=q;break L3040}else{D=J;E=E+1|0;e=e+1|0;j=j+1|0}}a[e]=0;M=E;N=j;O=q;m=2171}}while(0);do{if((m|0)==2171){if((a[N]|0)==0){P=M;Q=O;break}else{R=N;S=M}while(1){q=R+1|0;o=S+1|0;if((a[q]|0)==0){P=o;Q=O;break}else{R=q;S=o}}}}while(0);l=P>>>0<Q>>>0;i=f;return l|0}function gR(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;while(1){g=c[f>>2]|0;if((g|0)==0){h=0;i=2193;break}if((cP(d|0,c[g+4>>2]|0)|0)==0){break}else{f=g+12|0}}if((i|0)==2193){return h|0}i=c[g+8>>2]|0;if((aIB(i|0,729656)|0)==0){a[e]=1;h=1;return h|0}if((aIB(i|0,704672)|0)==0){a[e]=1;h=1;return h|0}if((aIB(i|0,698704)|0)==0){a[e]=0;h=1;return h|0}if((aIB(i|0,705024)|0)!=0){h=0;return h|0}a[e]=0;h=1;return h|0}function gS(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;b=c[f>>2]|0;L3076:do{if((b|0)==0){g=0}else{h=b;while(1){if((a[h|0]&1)==0){if((cP(d|0,c[h+4>>2]|0)|0)==0){break}}i=c[h+12>>2]|0;if((i|0)==0){g=h;break L3076}else{h=i}}i=h+8|0;aIq(c[i>>2]|0);c[i>>2]=dv(e|0)|0;return}}while(0);b=aIp(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)==0){break}aIv(b|0,0,16)}}while(0);i=b;c[b+4>>2]=dv(d|0)|0;c[b+8>>2]=dv(e|0)|0;if((g|0)==0){c[f>>2]=i;return}else{c[g+12>>2]=i;return}}function gT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=(d|0)!=0;do{if(f){g=c9(d|0,727320)|0;if((g|0)==0){h=0}else{j=g;break}i=e;return h|0}else{j=c[o>>2]|0}}while(0);d=c[b+16>>2]|0;if((d|0)!=0){g=d;do{ei(j|0,723368,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0)|0;i=k;g=c[g+4>>2]|0;}while((g|0)!=0)}g=c[b+4>>2]|0;if((g|0)!=0){b=g;do{if((a[b|0]&1)==0){g=c[b+4>>2]|0;d=c[b+8>>2]|0;ei(j|0,721784,(k=i,i=i+16|0,c[k>>2]=g,c[k+8>>2]=d,k)|0)|0;i=k}b=c[b+12>>2]|0;}while((b|0)!=0)}if(!f){h=1;i=e;return h|0}aS(j|0)|0;h=1;i=e;return h|0}function gU(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aY=0,aZ=0,a$=0,a0=0,a1=0,a3=0,a4=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0.0,bI=0.0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0;e=i;i=i+12848|0;f=e|0;h=e+72|0;j=e+144|0;k=e+4312|0;l=e+4320|0;m=e+8416|0;n=e+12512|0;o=e+12520|0;q=e+12528|0;r=e+12536|0;s=e+12544|0;t=e+12552|0;u=e+12560|0;v=e+12568|0;w=e+12576|0;x=e+12584|0;y=e+12592|0;z=e+12600|0;A=e+12608|0;B=e+12616|0;C=e+12624|0;D=e+12632|0;E=e+12640|0;F=e+12648|0;G=e+12656|0;H=e+12664|0;I=e+12672|0;J=e+12736|0;K=e+12744|0;L=e+12752|0;M=e+12760|0;N=e+12768|0;O=e+12776|0;P=e+12784|0;Q=e+12792|0;R=e+12800|0;S=e+12808|0;T=e+12816|0;U=e+12824|0;V=e+12832|0;W=e+12840|0;do{if((d|0)==0){X=e+216|0;Y=dJ(724264)|0;Z=dJ(724216)|0;do{if((Y|0)==0){if((Z|0)==0){_=2240;break}bQ(X|0,4096,724072,($=i,i=i+8|0,c[$>>2]=Z,$)|0)|0;i=$;_=2233}else{bQ(X|0,4096,724152,($=i,i=i+8|0,c[$>>2]=Y,$)|0)|0;i=$;_=2233}}while(0);if((_|0)==2233){if((a[1820736]&1)!=0){Y=c[494446]|0;aa=(Y|0)!=0?Y:c[p>>2]|0;ei(aa|0,723816,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[494446]|0;Y=(aa|0)!=0?aa:c[p>>2]|0;a_(Y|0)|0}Y=gP(X,0)|0;if((Y|0)!=0|(Z|0)==0){ab=Y}else{bQ(X|0,4096,723632,($=i,i=i+8|0,c[$>>2]=Z,$)|0)|0;i=$;if((a[1820736]&1)!=0){Y=c[494446]|0;aa=(Y|0)!=0?Y:c[p>>2]|0;ei(aa|0,723816,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[494446]|0;Y=(aa|0)!=0?aa:c[p>>2]|0;a_(Y|0)|0}ab=gP(X,0)|0}if((ab|0)==0){_=2240}else{ac=ab}}do{if((_|0)==2240){gz(X,723488,723328);if((a[1820736]&1)!=0){Y=c[494446]|0;aa=(Y|0)!=0?Y:c[p>>2]|0;ei(aa|0,723816,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[494446]|0;Y=(aa|0)!=0?aa:c[p>>2]|0;a_(Y|0)|0}Y=gP(X,0)|0;if((Y|0)==0){ad=1}else{ac=Y;break}i=e;return ad|0}}while(0);Z=4096;Y=1841266;aa=X;while(1){ae=Z-1|0;if((ae|0)==0){_=2246;break}af=a[aa]|0;a[Y]=af;if(af<<24>>24==0){break}else{Z=ae;Y=Y+1|0;aa=aa+1|0}}do{if((_|0)==2246){a[Y]=0;if((a[aa]|0)==0){break}else{ag=aa}do{ag=ag+1|0;}while((a[ag]|0)!=0)}}while(0);if((ac|0)==0){ad=1}else{ah=ac;break}i=e;return ad|0}else{aa=gP(d,0)|0;if((aa|0)==0){ad=0}else{ah=aa;break}i=e;return ad|0}}while(0);d=l|0;l=4096;ac=d;ag=1845362;while(1){ab=l-1|0;if((ab|0)==0){_=2252;break}aa=a[ag]|0;a[ac]=aa;if(aa<<24>>24==0){break}else{l=ab;ac=ac+1|0;ag=ag+1|0}}do{if((_|0)==2252){a[ac]=0;if((a[ag]|0)==0){break}else{ai=ag}do{ai=ai+1|0;}while((a[ai]|0)!=0)}}while(0);ai=ee(d|0,698696,k|0)|0;d=(a[1820736]&1)!=0;if((ai|0)==0){aj=d}else{ag=ah+4|0;ac=ai;ai=d;while(1){if(ai){d=c[494446]|0;l=(d|0)!=0?d:c[p>>2]|0;ei(l|0,697072,($=i,i=i+8|0,c[$>>2]=ac,$)|0)|0;i=$;l=c[494446]|0;d=(l|0)!=0?l:c[p>>2]|0;a_(d|0)|0}d=gP(ac,0)|0;if((d|0)==0){l=c[494446]|0;ab=(l|0)!=0?l:c[p>>2]|0;ei(ab|0,694904,($=i,i=i+8|0,c[$>>2]=ac,$)|0)|0;i=$;ab=c[494446]|0;l=(ab|0)!=0?ab:c[p>>2]|0;a_(l|0)|0}else{l=c[d+8>>2]|0;if((l|0)!=0){c[l+12>>2]=c[ag>>2];l=d+4|0;c[ag>>2]=c[l>>2];c[l>>2]=0}gN(d)}d=ee(0,706256,k|0)|0;l=(a[1820736]&1)!=0;if((d|0)==0){aj=l;break}else{ac=d;ai=l}}}do{if(aj){ai=c[494446]|0;ac=(ai|0)!=0?ai:c[p>>2]|0;a5(690824,15,1,ac|0)|0;ac=c[494446]|0;ai=(ac|0)!=0?ac:c[p>>2]|0;a_(ai|0)|0;ai=c[p>>2]|0;ac=c[ah+16>>2]|0;if((ac|0)!=0){k=ac;do{ei(ai|0,723368,($=i,i=i+8|0,c[$>>2]=c[k>>2],$)|0)|0;i=$;k=c[k+4>>2]|0;}while((k|0)!=0)}k=ah+4|0;ac=c[k>>2]|0;if((ac|0)!=0){ag=ac;do{ac=c[ag+8>>2]|0;l=(a[ag|0]&1)!=0?719600:14317944;ei(ai|0,720704,($=i,i=i+24|0,c[$>>2]=c[ag+4>>2],c[$+8>>2]=ac,c[$+16>>2]=l,$)|0)|0;i=$;ag=c[ag+12>>2]|0;}while((ag|0)!=0)}if((a[1820736]&1)==0){ak=k;break}ag=c[494446]|0;ai=(ag|0)!=0?ag:c[p>>2]|0;a5(730080,19,1,ai|0)|0;ai=c[494446]|0;ag=(ai|0)!=0?ai:c[p>>2]|0;a_(ag|0)|0;ak=k}else{ak=ah+4|0}}while(0);aj=ak;while(1){al=c[aj>>2]|0;if((al|0)==0){am=ak;break}if((cP(727504,c[al+4>>2]|0)|0)==0){_=2276;break}aj=al+12|0}if((_|0)==2276){g[429342]=+aIt(c[al+8>>2]|0);am=ak}while(1){an=c[am>>2]|0;if((an|0)==0){ao=ak;break}if((cP(725536,c[an+4>>2]|0)|0)==0){_=2280;break}am=an+12|0}if((_|0)==2280){g[429343]=+aIt(c[an+8>>2]|0);ao=ak}while(1){ap=c[ao>>2]|0;if((ap|0)==0){aq=ak;break}if((cP(724456,c[ap+4>>2]|0)|0)==0){_=2284;break}ao=ap+12|0}do{if((_|0)==2284){c[(dX()|0)>>2]=0;ao=a2(c[ap+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){aq=ak;break}c[429346]=ao;aq=ak}}while(0);while(1){ar=c[aq>>2]|0;if((ar|0)==0){break}if((cP(723344,c[ar+4>>2]|0)|0)==0){_=2289;break}aq=ar+12|0}do{if((_|0)==2289){c[(dX()|0)>>2]=0;aq=a2(c[ar+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[429347]=aq}}while(0);do{if((a[1820739]&1)==0){a[n]=0;if(!(gR(ah,721760,n)|0)){break}a[1717376]=a[n]&1}}while(0);a[o]=0;if(gR(ah,720672,o)|0){a[1717377]=a[o]&1;as=ak}else{as=ak}while(1){at=c[as>>2]|0;if((at|0)==0){break}if((cP(719576,c[at+4>>2]|0)|0)==0){_=2298;break}else{as=at+12|0}}do{if((_|0)==2298){c[(dX()|0)>>2]=0;as=a2(c[at+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[429345]=as}}while(0);a[q]=0;if(gR(ah,718568,q)|0){a[1733844]=a[q]&1}a[r]=0;if(gR(ah,717616,r)|0){a[1717392]=a[r]&1}a[s]=0;if(gR(ah,716648,s)|0){a[1717393]=a[s]&1;au=ak}else{au=ak}while(1){av=c[au>>2]|0;if((av|0)==0){_=2310;break}if((cP(715216,c[av+4>>2]|0)|0)==0){_=2308;break}else{au=av+12|0}}do{if((_|0)==2308){c[(dX()|0)>>2]=0;au=a2(c[av+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){_=2310;break}c[429350]=au;aw=au}}while(0);if((_|0)==2310){aw=c[429350]|0}if(aw>>>0>3){c[429350]=3}a[t]=0;if(gR(ah,713576,t)|0){a[1717394]=a[t]&1;ax=ak}else{ax=ak}while(1){ay=c[ax>>2]|0;if((ay|0)==0){_=2318;break}if((cP(712248,c[ay+4>>2]|0)|0)==0){_=2317;break}else{ax=ay+12|0}}do{if((_|0)==2317){c[(dX()|0)>>2]=0;ax=a2(c[ay+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){_=2318;break}c[429349]=ax;az=ax}}while(0);if((_|0)==2318){az=c[429349]|0}ay=az>>>0>1?az:1;c[429349]=ay>>>0<4?ay:4;a[u]=0;if(gR(ah,711288,u)|0){a[1725620]=a[u]&1}a[v]=0;if(gR(ah,710648,v)|0){a[1717404]=a[v]&1}a[w]=0;if(gR(ah,709720,w)|0){a[1717405]=a[w]&1}a[x]=0;if(gR(ah,709296,x)|0){a[1717413]=a[x]&1}a[y]=0;if(gR(ah,708880,y)|0){a[1717406]=a[y]&1;aA=ak}else{aA=ak}while(1){aB=c[aA>>2]|0;if((aB|0)==0){aC=ak;break}if((cP(708520,c[aB+4>>2]|0)|0)==0){_=2332;break}else{aA=aB+12|0}}if((_|0)==2332){g[429352]=+aIt(c[aB+8>>2]|0);aC=ak}while(1){aD=c[aC>>2]|0;if((aD|0)==0){break}if((cP(708056,c[aD+4>>2]|0)|0)==0){_=2335;break}else{aC=aD+12|0}}do{if((_|0)==2335){c[(dX()|0)>>2]=0;aC=a2(c[aD+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[429354]=aC}}while(0);a[z]=0;if(gR(ah,707456,z)|0){a[1717412]=a[z]&1;aE=ak}else{aE=ak}while(1){aF=c[aE>>2]|0;if((aF|0)==0){break}if((cP(706816,c[aF+4>>2]|0)|0)==0){_=2341;break}else{aE=aF+12|0}}if((_|0)==2341){g[431404]=+aIt(c[aF+8>>2]|0)}gQ(ah,706376,1717420)|0;a[A]=0;if(gR(ah,705976,A)|0){a[1721516]=a[A]&1}a[B]=0;if(gR(ah,705672,B)|0){a[1733848]=a[B]&1}gQ(ah,705296,1729717)|0;B=ak;while(1){aG=c[B>>2]|0;if((aG|0)==0){break}if((cP(704944,c[aG+4>>2]|0)|0)==0){_=2349;break}else{B=aG+12|0}}if((_|0)==2349){g[433454]=+aIt(c[aG+8>>2]|0)}a[C]=0;if(gR(ah,704592,C)|0){a[1733820]=a[C]&1}a[D]=0;if(gR(ah,704296,D)|0){a[1733821]=a[D]&1;aH=ak}else{aH=ak}while(1){aI=c[aH>>2]|0;if((aI|0)==0){aJ=ak;break}if((cP(703824,c[aI+4>>2]|0)|0)==0){_=2356;break}else{aH=aI+12|0}}if((_|0)==2356){g[433456]=+aIt(c[aI+8>>2]|0);aJ=ak}while(1){aK=c[aJ>>2]|0;if((aK|0)==0){aL=ak;break}if((cP(703136,c[aK+4>>2]|0)|0)==0){_=2359;break}else{aJ=aK+12|0}}if((_|0)==2359){g[433457]=+aIt(c[aK+8>>2]|0);aL=ak}while(1){aM=c[aL>>2]|0;if((aM|0)==0){aN=ak;break}if((cP(702504,c[aM+4>>2]|0)|0)==0){_=2362;break}else{aL=aM+12|0}}do{if((_|0)==2362){c[(dX()|0)>>2]=0;aL=a2(c[aM+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){aN=ak;break}c[494431]=aL;aN=ak}}while(0);while(1){aO=c[aN>>2]|0;if((aO|0)==0){aP=ak;break}if((cP(702248,c[aO+4>>2]|0)|0)==0){_=2366;break}else{aN=aO+12|0}}do{if((_|0)==2366){c[(dX()|0)>>2]=0;aN=a2(c[aO+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){aP=ak;break}c[494432]=aN;aP=ak}}while(0);while(1){aQ=c[aP>>2]|0;if((aQ|0)==0){aR=ak;break}if((cP(702024,c[aQ+4>>2]|0)|0)==0){_=2370;break}else{aP=aQ+12|0}}do{if((_|0)==2370){c[(dX()|0)>>2]=0;aP=a2(c[aQ+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){aR=ak;break}c[494433]=aP;aR=ak}}while(0);while(1){aS=c[aR>>2]|0;if((aS|0)==0){aT=ak;break}if((cP(701744,c[aS+4>>2]|0)|0)==0){_=2374;break}else{aR=aS+12|0}}do{if((_|0)==2374){c[(dX()|0)>>2]=0;aR=a2(c[aS+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){aT=ak;break}c[494434]=aR;aT=ak}}while(0);while(1){aU=c[aT>>2]|0;if((aU|0)==0){break}if((cP(701480,c[aU+4>>2]|0)|0)==0){_=2378;break}else{aT=aU+12|0}}do{if((_|0)==2378){c[(dX()|0)>>2]=0;aT=aX(c[aU+8>>2]|0,0,16)|0;if((c[(dX()|0)>>2]|0)!=0){break}g[433458]=+((aT>>>16&255)>>>0>>>0)/255.0;g[433459]=+((aT>>>8&255)>>>0>>>0)/255.0;g[433460]=+((aT&255)>>>0>>>0)/255.0}}while(0);a[E]=0;if(gR(ah,701232,E)|0){a[1733845]=a[E]&1}a[F]=0;if(gR(ah,700952,F)|0){a[1733846]=a[F]&1}a[G]=0;if(gR(ah,700752,G)|0){a[1733847]=a[G]&1}gQ(ah,700408,1725621)|0;if((cP(1725621,699904)|0)==0){a[1725621]=0;aV=ak}else{aV=ak}while(1){aW=c[aV>>2]|0;if((aW|0)==0){break}if((cP(699312,c[aW+4>>2]|0)|0)==0){_=2390;break}else{aV=aW+12|0}}if((_|0)==2390){g[444514]=+aIt(c[aW+8>>2]|0)}a[H]=0;if(gR(ah,698872,H)|0){a[1778670]=a[H]&1}H=I|0;bQ(H|0,64,698664,($=i,i=i+8|0,c[$>>2]=1,$)|0)|0;i=$;I=ak;while(1){aY=c[I>>2]|0;if((aY|0)==0){break}if((cP(H|0,c[aY+4>>2]|0)|0)==0){_=2396;break}else{I=aY+12|0}}do{if((_|0)==2396){c[(dX()|0)>>2]=0;I=a2(c[aY+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[444515]=I}}while(0);bQ(H|0,64,698664,($=i,i=i+8|0,c[$>>2]=2,$)|0)|0;i=$;aY=ak;while(1){aZ=c[aY>>2]|0;if((aZ|0)==0){break}if((cP(H|0,c[aZ+4>>2]|0)|0)==0){_=2401;break}else{aY=aZ+12|0}}do{if((_|0)==2401){c[(dX()|0)>>2]=0;aY=a2(c[aZ+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[444516]=aY}}while(0);bQ(H|0,64,698664,($=i,i=i+8|0,c[$>>2]=3,$)|0)|0;i=$;aZ=ak;while(1){a$=c[aZ>>2]|0;if((a$|0)==0){break}if((cP(H|0,c[a$+4>>2]|0)|0)==0){_=2606;break}else{aZ=a$+12|0}}do{if((_|0)==2606){c[(dX()|0)>>2]=0;aZ=a2(c[a$+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[444517]=aZ}}while(0);bQ(H|0,64,698664,($=i,i=i+8|0,c[$>>2]=4,$)|0)|0;i=$;a$=ak;while(1){a0=c[a$>>2]|0;if((a0|0)==0){break}if((cP(H|0,c[a0+4>>2]|0)|0)==0){_=2611;break}else{a$=a0+12|0}}do{if((_|0)==2611){c[(dX()|0)>>2]=0;a$=a2(c[a0+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[444518]=a$}}while(0);bQ(H|0,64,698664,($=i,i=i+8|0,c[$>>2]=5,$)|0)|0;i=$;a0=ak;while(1){a1=c[a0>>2]|0;if((a1|0)==0){break}if((cP(H|0,c[a1+4>>2]|0)|0)==0){_=2616;break}else{a0=a1+12|0}}do{if((_|0)==2616){c[(dX()|0)>>2]=0;a0=a2(c[a1+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[444519]=a0}}while(0);bQ(H|0,64,698664,($=i,i=i+8|0,c[$>>2]=6,$)|0)|0;i=$;a1=ak;while(1){a3=c[a1>>2]|0;if((a3|0)==0){break}if((cP(H|0,c[a3+4>>2]|0)|0)==0){_=2621;break}else{a1=a3+12|0}}do{if((_|0)==2621){c[(dX()|0)>>2]=0;a1=a2(c[a3+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[444520]=a1}}while(0);bQ(H|0,64,698664,($=i,i=i+8|0,c[$>>2]=7,$)|0)|0;i=$;a3=ak;while(1){a4=c[a3>>2]|0;if((a4|0)==0){break}if((cP(H|0,c[a4+4>>2]|0)|0)==0){_=2626;break}else{a3=a4+12|0}}do{if((_|0)==2626){c[(dX()|0)>>2]=0;a3=a2(c[a4+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[444521]=a3}}while(0);bQ(H|0,64,698664,($=i,i=i+8|0,c[$>>2]=8,$)|0)|0;i=$;a4=ak;while(1){a6=c[a4>>2]|0;if((a6|0)==0){break}if((cP(H|0,c[a6+4>>2]|0)|0)==0){_=2631;break}else{a4=a6+12|0}}do{if((_|0)==2631){c[(dX()|0)>>2]=0;a4=a2(c[a6+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[444522]=a4}}while(0);a[J]=0;if(gR(ah,698552,J)|0){a[1733884]=a[J]&1;a7=ak}else{a7=ak}while(1){a8=c[a7>>2]|0;if((a8|0)==0){a9=ak;break}if((cP(698496,c[a8+4>>2]|0)|0)==0){_=2405;break}else{a7=a8+12|0}}do{if((_|0)==2405){c[(dX()|0)>>2]=0;a7=a2(c[a8+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){a9=ak;break}c[433472]=a7;a9=ak}}while(0);while(1){ba=c[a9>>2]|0;if((ba|0)==0){bb=ak;break}if((cP(698400,c[ba+4>>2]|0)|0)==0){_=2409;break}else{a9=ba+12|0}}do{if((_|0)==2409){c[(dX()|0)>>2]=0;a9=a2(c[ba+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){bb=ak;break}c[433473]=a9;bb=ak}}while(0);while(1){bc=c[bb>>2]|0;if((bc|0)==0){bd=ak;break}if((cP(698248,c[bc+4>>2]|0)|0)==0){_=2413;break}else{bb=bc+12|0}}L3444:do{if((_|0)==2413){bb=4096;ba=1733900;a9=c[bc+8>>2]|0;while(1){a8=bb-1|0;if((a8|0)==0){break}a7=a[a9]|0;a[ba]=a7;if(a7<<24>>24==0){bd=ak;break L3444}else{bb=a8;ba=ba+1|0;a9=a9+1|0}}a[ba]=0;if((a[a9]|0)==0){bd=ak;break}else{be=a9}while(1){bb=be+1|0;if((a[bb]|0)==0){bd=ak;break}else{be=bb}}}}while(0);while(1){bf=c[bd>>2]|0;if((bf|0)==0){break}if((cP(698152,c[bf+4>>2]|0)|0)==0){_=2420;break}else{bd=bf+12|0}}do{if((_|0)==2420){c[(dX()|0)>>2]=0;bd=a2(c[bf+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[434499]=bd}}while(0);a[K]=0;if(gR(ah,698056,K)|0){a[1738e3]=a[K]&1}a[L]=0;if(gR(ah,697712,L)|0){a[1742097]=a[L]&1;bg=ak}else{bg=ak}while(1){bh=c[bg>>2]|0;if((bh|0)==0){bi=ak;break}if((cP(697448,c[bh+4>>2]|0)|0)==0){_=2428;break}else{bg=bh+12|0}}if((_|0)==2428){g[435525]=+aIt(c[bh+8>>2]|0);bi=ak}while(1){bj=c[bi>>2]|0;if((bj|0)==0){bk=ak;break}if((cP(697256,c[bj+4>>2]|0)|0)==0){_=2431;break}else{bi=bj+12|0}}if((_|0)==2431){g[435526]=+aIt(c[bj+8>>2]|0);bk=ak}while(1){bl=c[bk>>2]|0;if((bl|0)==0){bm=ak;break}if((cP(697056,c[bl+4>>2]|0)|0)==0){_=2434;break}else{bk=bl+12|0}}L3477:do{if((_|0)==2434){bk=32;bj=1717304;bi=c[bl+8>>2]|0;while(1){bh=bk-1|0;if((bh|0)==0){break}bg=a[bi]|0;a[bj]=bg;if(bg<<24>>24==0){bm=ak;break L3477}else{bk=bh;bj=bj+1|0;bi=bi+1|0}}a[bj]=0;if((a[bi]|0)==0){bm=ak;break}else{bn=bi}while(1){bk=bn+1|0;if((a[bk]|0)==0){bm=ak;break}else{bn=bk}}}}while(0);while(1){bo=c[bm>>2]|0;if((bo|0)==0){bp=ak;break}if((cP(696912,c[bo+4>>2]|0)|0)==0){_=2441;break}else{bm=bo+12|0}}L3488:do{if((_|0)==2441){bm=32;bn=1717336;bl=c[bo+8>>2]|0;while(1){bi=bm-1|0;if((bi|0)==0){break}bj=a[bl]|0;a[bn]=bj;if(bj<<24>>24==0){bp=ak;break L3488}else{bm=bi;bn=bn+1|0;bl=bl+1|0}}a[bn]=0;if((a[bl]|0)==0){bp=ak;break}else{bq=bl}while(1){bm=bq+1|0;if((a[bm]|0)==0){bp=ak;break}else{bq=bm}}}}while(0);while(1){br=c[bp>>2]|0;if((br|0)==0){break}if((cP(696824,c[br+4>>2]|0)|0)==0){_=2448;break}else{bp=br+12|0}}L3499:do{if((_|0)==2448){bp=32;bq=1733852;bo=c[br+8>>2]|0;while(1){bl=bp-1|0;if((bl|0)==0){break}bn=a[bo]|0;a[bq]=bn;if(bn<<24>>24==0){break L3499}else{bp=bl;bq=bq+1|0;bo=bo+1|0}}a[bq]=0;if((a[bo]|0)==0){break}else{bs=bo}do{bs=bs+1|0;}while((a[bs]|0)!=0)}}while(0);gQ(ah,696648,1738001)|0;bs=ak;while(1){bt=c[bs>>2]|0;if((bt|0)==0){bu=ak;break}if((cP(718840,c[bt+4>>2]|0)|0)==0){_=2456;break}else{bs=bt+12|0}}L3511:do{if((_|0)==2456){bs=32;br=1742144;bo=c[bt+8>>2]|0;while(1){bq=bs-1|0;if((bq|0)==0){break}bp=a[bo]|0;a[br]=bp;if(bp<<24>>24==0){bu=ak;break L3511}else{bs=bq;br=br+1|0;bo=bo+1|0}}a[br]=0;if((a[bo]|0)==0){bu=ak;break}else{bv=bo}while(1){bs=bv+1|0;if((a[bs]|0)==0){bu=ak;break}else{bv=bs}}}}while(0);while(1){bw=c[bu>>2]|0;if((bw|0)==0){break}if((cP(696272,c[bw+4>>2]|0)|0)==0){_=2463;break}else{bu=bw+12|0}}L3522:do{if((_|0)==2463){bu=32;bv=1742176;bt=c[bw+8>>2]|0;while(1){bo=bu-1|0;if((bo|0)==0){break}br=a[bt]|0;a[bv]=br;if(br<<24>>24==0){break L3522}else{bu=bo;bv=bv+1|0;bt=bt+1|0}}a[bv]=0;if((a[bt]|0)==0){break}else{bx=bt}do{bx=bx+1|0;}while((a[bx]|0)!=0)}}while(0);if((a[1795076]|0)==0){gQ(ah,696088,1795076)|0}gQ(ah,695800,1786880)|0;gQ(ah,695456,1807364)|0;do{if((a[1807364]|0)!=0){if((eI(1807364,j|0)|0)>=0){if((c[j+8>>2]&61440|0)==16384){break}}bx=c[494446]|0;bw=(bx|0)!=0?bx:c[p>>2]|0;a5(695144,84,1,bw|0)|0;bw=c[494446]|0;bx=(bw|0)!=0?bw:c[p>>2]|0;a_(bx|0)|0;a[1807364]=0}}while(0);gQ(ah,694880,1815593)|0;if((cP(1815593,699904)|0)==0){a[1815593]=0}gQ(ah,694768,1898610)|0;if((cP(1898610,699904)|0)==0){a[1898610]=0}gQ(ah,694664,1778680)|0;j=ak;while(1){by=c[j>>2]|0;if((by|0)==0){bz=ak;break}if((cP(694528,c[by+4>>2]|0)|0)==0){_=2481;break}else{j=by+12|0}}if((_|0)==2481){g[445694]=+aIt(c[by+8>>2]|0);bz=ak}while(1){bA=c[bz>>2]|0;if((bA|0)==0){break}if((cP(694384,c[bA+4>>2]|0)|0)==0){_=2484;break}else{bz=bA+12|0}}if((_|0)==2484){g[445695]=+aIt(c[bA+8>>2]|0)}a[M]=0;if(gR(ah,694280,M)|0){a[1815556]=a[M]&1;bB=ak}else{bB=ak}while(1){bC=c[bB>>2]|0;if((bC|0)==0){bD=ak;break}if((cP(694088,c[bC+4>>2]|0)|0)==0){_=2489;break}else{bB=bC+12|0}}do{if((_|0)==2489){c[(dX()|0)>>2]=0;bB=a2(c[bC+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){bD=ak;break}c[453890]=bB*1e6|0;bD=ak}}while(0);while(1){bE=c[bD>>2]|0;if((bE|0)==0){bF=ak;break}if((cP(693816,c[bE+4>>2]|0)|0)==0){_=2493;break}else{bD=bE+12|0}}do{if((_|0)==2493){c[(dX()|0)>>2]=0;bD=a2(c[bE+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){bF=ak;break}c[453891]=bD;bF=ak}}while(0);while(1){bG=c[bF>>2]|0;if((bG|0)==0){_=2498;break}if((cP(693352,c[bG+4>>2]|0)|0)==0){_=2497;break}else{bF=bG+12|0}}if((_|0)==2497){bH=+aIt(c[bG+8>>2]|0);g[453892]=bH;bI=bH}else if((_|0)==2498){bI=+g[453892]}if(bI<1.0){g[453892]=1.0;bJ=ak}else{bJ=ak}while(1){bK=c[bJ>>2]|0;if((bK|0)==0){break}if((cP(693120,c[bK+4>>2]|0)|0)==0){_=2503;break}else{bJ=bK+12|0}}if((_|0)==2503){g[453893]=+aIt(c[bK+8>>2]|0)}a[N]=0;if(gR(ah,692792,N)|0){a[1815576]=a[N]&1;bL=ak}else{bL=ak}while(1){bM=c[bL>>2]|0;if((bM|0)==0){break}if((cP(692632,c[bM+4>>2]|0)|0)==0){_=2508;break}else{bL=bM+12|0}}do{if((_|0)==2508){c[(dX()|0)>>2]=0;bL=a2(c[bM+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[453895]=bL}}while(0);gQ(ah,692536,1799172)|0;gQ(ah,692400,1803268)|0;a[O]=0;if(gR(ah,692160,O)|0){a[1815584]=a[O]&1}a[P]=0;if(gR(ah,692e3,P)|0){a[1815585]=a[P]&1}a[Q]=0;if(gR(ah,691848,Q)|0){a[1815586]=a[Q]&1}a[R]=0;if(gR(ah,691656,R)|0){a[1815587]=a[R]&1}a[S]=0;if(gR(ah,691216,S)|0){a[1815588]=a[S]&1;bN=ak}else{bN=ak}while(1){bO=c[bN>>2]|0;if((bO|0)==0){break}if((cP(690984,c[bO+4>>2]|0)|0)==0){_=2522;break}else{bN=bO+12|0}}do{if((_|0)==2522){c[(dX()|0)>>2]=0;bN=a2(c[bO+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}b[907795]=bN&65535}}while(0);a[T]=0;if(gR(ah,690800,T)|0){a[1815592]=a[T]&1}gQ(ah,690656,1790976)|0;T=ak;while(1){bP=c[T>>2]|0;if((bP|0)==0){bR=ak;break}if((cP(690584,c[bP+4>>2]|0)|0)==0){_=2529;break}else{T=bP+12|0}}do{if((_|0)==2529){c[(dX()|0)>>2]=0;T=a2(c[bP+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){bR=ak;break}c[448768]=T;bR=ak}}while(0);while(1){bS=c[bR>>2]|0;if((bS|0)==0){bT=ak;break}if((cP(690464,c[bS+4>>2]|0)|0)==0){_=2533;break}else{bR=bS+12|0}}do{if((_|0)==2533){c[(dX()|0)>>2]=0;bR=a2(c[bS+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){bT=ak;break}c[444668]=bR;bT=ak}}while(0);while(1){bU=c[bT>>2]|0;if((bU|0)==0){break}if((cP(690360,c[bU+4>>2]|0)|0)==0){_=2537;break}else{bT=bU+12|0}}do{if((_|0)==2537){c[(dX()|0)>>2]=0;bT=a2(c[bU+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[444669]=bT}}while(0);a[U]=0;if(gR(ah,690240,U)|0){a[1778668]=a[U]&1}a[V]=0;if(gR(ah,731096,V)|0){a[1778669]=a[V]&1}gQ(ah,730856,1782784)|0;a[W]=0;if(gR(ah,730392,W)|0){a[1977790]=a[W]&1}L3647:do{if((a[1841264]&1)==0){W=m|0;if(!(gQ(ah,730224,W)|0)){break}if((cP(W|0,699904)|0)==0){a[1890418]=0;break}do{if((eI(W|0,h|0)|0)>=0){if((c[h+8>>2]&61440|0)==16384){bV=4096;bW=1890418;bX=W}else{break}while(1){V=bV-1|0;if((V|0)==0){_=2553;break}U=a[bX]|0;a[bW]=U;if(U<<24>>24==0){bY=4096;bZ=1861746;b_=W;break}else{bV=V;bW=bW+1|0;bX=bX+1|0}}do{if((_|0)==2553){a[bW]=0;if((a[bX]|0)==0){bY=4096;bZ=1861746;b_=W;break}else{b$=bX}while(1){V=b$+1|0;if((a[V]|0)==0){bY=4096;bZ=1861746;b_=W;break}else{b$=V}}}}while(0);while(1){V=bY-1|0;if((V|0)==0){_=2557;break}U=a[b_]|0;a[bZ]=U;if(U<<24>>24==0){break}else{bY=V;bZ=bZ+1|0;b_=b_+1|0}}do{if((_|0)==2557){a[bZ]=0;if((a[b_]|0)==0){break}else{b0=b_}do{b0=b0+1|0;}while((a[b0]|0)!=0)}}while(0);gC(1861746,730072);break L3647}}while(0);W=c[494446]|0;V=(W|0)!=0?W:c[p>>2]|0;a5(729872,72,1,V|0)|0;V=c[494446]|0;W=(V|0)!=0?V:c[p>>2]|0;a_(W|0)|0}}while(0);L3672:do{if((a[1841265]&1)==0){b0=m|0;if(!(gQ(ah,729760,b0)|0)){break}if((cP(b0|0,699904)|0)==0){a[1894514]=0;break}do{if((eI(b0|0,f|0)|0)>=0){if((c[f+8>>2]&61440|0)==16384){b1=4096;b2=1894514;b3=b0}else{break}while(1){b_=b1-1|0;if((b_|0)==0){_=2569;break}bZ=a[b3]|0;a[b2]=bZ;if(bZ<<24>>24==0){b4=4096;b5=1882226;b6=b0;break}else{b1=b_;b2=b2+1|0;b3=b3+1|0}}do{if((_|0)==2569){a[b2]=0;if((a[b3]|0)==0){b4=4096;b5=1882226;b6=b0;break}else{b7=b3}while(1){b_=b7+1|0;if((a[b_]|0)==0){b4=4096;b5=1882226;b6=b0;break}else{b7=b_}}}}while(0);while(1){b_=b4-1|0;if((b_|0)==0){_=2573;break}bZ=a[b6]|0;a[b5]=bZ;if(bZ<<24>>24==0){break}else{b4=b_;b5=b5+1|0;b6=b6+1|0}}do{if((_|0)==2573){a[b5]=0;if((a[b6]|0)==0){break}else{b8=b6}do{b8=b8+1|0;}while((a[b8]|0)!=0)}}while(0);gC(1882226,729624);break L3672}}while(0);b0=c[494446]|0;b_=(b0|0)!=0?b0:c[p>>2]|0;a5(729416,73,1,b_|0)|0;b_=c[494446]|0;b0=(b_|0)!=0?b_:c[p>>2]|0;a_(b0|0)|0}}while(0);if(!(gQ(ah,729104,1811460)|0)){b8=c[494446]|0;b6=(b8|0)!=0?b8:c[p>>2]|0;ei(b6|0,728840,($=i,i=i+8|0,c[$>>2]=1811460,$)|0)|0;i=$;$=c[494446]|0;b6=($|0)!=0?$:c[p>>2]|0;a_(b6|0)|0}if((cP(1811460,699904)|0)==0){a[1811460]=0;b9=0}else{b9=0}do{b6=689544+(b9<<2)|0;L3704:do{if((b9|0)==0){$=0;b8=670688;while(1){b5=1742208+($*40|0)|0;do{if((a[b5|0]&1)==0){_=2588}else{b4=c[670696+($*20|0)>>2]|0;if(($|0)==56){ca=57;break}b7=($-25|0)>>>0<31?719440:718448;hm(ah,b7,b4,b5);b3=a[b8]|0;if((b3&1)==0){cb=b3}else{hn(ah,b7,b4,b5);cb=a[b8]|0}if((cb&1)==0){_=2588;break}ho(ah,b7,b4,b5);_=2588}}while(0);if((_|0)==2588){_=0;b5=$+1|0;if((b5|0)==56){break L3704}else{ca=b5}}$=ca;b8=670688+(ca*20|0)|0}}else{b8=0;$=670688;while(1){b5=1742208+(b9*2240|0)+(b8*40|0)|0;do{if((a[b5|0]&1)==0){_=2597}else{b4=c[670696+(b8*20|0)>>2]|0;if((b8|0)==56){cc=57;break}if((b8-25|0)>>>0<31){_=2597;break}b7=c[b6>>2]|0;hm(ah,b7,b4,b5);b3=a[$]|0;if((b3&1)==0){cd=b3}else{hn(ah,b7,b4,b5);cd=a[$]|0}if((cd&1)==0){_=2597;break}ho(ah,b7,b4,b5);_=2597}}while(0);if((_|0)==2597){_=0;b5=b8+1|0;if((b5|0)==56){break L3704}else{cc=b5}}b8=cc;$=670688+(cc*20|0)|0}}}while(0);b9=b9+1|0;}while(b9>>>0<8);gN(ah);ad=1;i=e;return ad|0}function gV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=d0(c[a>>2]|0)|0;c[a+68>>2]=b;c[a+72>>2]=d0(c[a+4>>2]|0)|0;c[a+76>>2]=d0(c[a+8>>2]|0)|0;c[a+80>>2]=d0(c[a+12>>2]|0)|0;c[a+84>>2]=d0(c[a+16>>2]|0)|0;c[a+88>>2]=d0(c[a+20>>2]|0)|0;c[a+92>>2]=d0(c[a+24>>2]|0)|0;c[a+96>>2]=d0(c[a+28>>2]|0)|0;c[a+100>>2]=d0(c[a+32>>2]|0)|0;c[a+104>>2]=d0(c[a+36>>2]|0)|0;c[a+108>>2]=d0(c[a+40>>2]|0)|0;c[a+112>>2]=d0(c[a+44>>2]|0)|0;c[a+116>>2]=d0(c[a+48>>2]|0)|0;c[a+120>>2]=d0(c[a+52>>2]|0)|0;c[a+124>>2]=d0(c[a+56>>2]|0)|0;c[a+128>>2]=d0(c[a+60>>2]|0)|0;d=16;e=b;while(1){b=c[a+68+(d-15<<2)>>2]|0;f=c[a+68+(d-2<<2)>>2]|0;c[a+68+(d<<2)>>2]=(c[a+68+(d-7<<2)>>2]|0)+e+((b>>>18|b<<14)^b>>>3^(b>>>7|b<<25))+((f>>>19|f<<13)^f>>>10^(f>>>17|f<<15));f=d+1|0;if(f>>>0<64){d=f;e=b}else{break}}e=a+324|0;d=c[e>>2]|0;b=a+328|0;f=c[b>>2]|0;g=a+332|0;h=c[g>>2]|0;i=a+336|0;j=c[i>>2]|0;k=a+340|0;l=c[k>>2]|0;m=a+344|0;n=c[m>>2]|0;o=a+348|0;p=c[o>>2]|0;q=a+352|0;r=c[q>>2]|0;s=f;t=h;u=j;v=l;w=n;x=p;y=r;z=d;A=0;while(1){B=(x&~v^v&w)+y+((v>>>6|v<<26)^(v>>>11|v<<21)^(v>>>25|v<<7))+(c[736472+(A<<2)>>2]|0)+(c[a+68+(A<<2)>>2]|0)|0;C=B+u|0;D=((s^t)&z^s&t)+((z>>>2|z<<30)^(z>>>13|z<<19)^(z>>>22|z<<10))+B|0;B=A+1|0;if(B>>>0<64){u=t;t=s;s=z;y=x;x=w;w=v;v=C;z=D;A=B}else{break}}c[e>>2]=D+d;c[b>>2]=z+f;c[g>>2]=s+h;c[i>>2]=t+j;c[k>>2]=C+l;c[m>>2]=v+n;c[o>>2]=w+p;c[q>>2]=x+r;c[a+64>>2]=0;return}function gW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+4096|0;f=e|0;if((b|0)==11){aIv(1915104,0,512);g=c[d+16>>2]|0;if((g|0)!=0){h=d;j=g;while(1){g=c[h>>2]|0;do{if(g>>>0<=7){if((c[h+4>>2]|0)!=1){break}k=c[h+12>>2]|0;if(k>>>0>15){break}c[1915104+(g<<6)+(k<<2)>>2]=j}}while(0);g=c[h+36>>2]|0;if((g|0)==0){break}else{h=h+20|0;j=g}}}if((a[1820736]&1)==0){l=0}else{j=c[494446]|0;h=(j|0)!=0?j:c[p>>2]|0;a5(706720,42,1,h|0)|0;h=c[494446]|0;j=(h|0)!=0?h:c[p>>2]|0;a_(j|0)|0;l=0}while(1){j=l+1|0;h=0;do{g=c[1915104+(l<<6)+(h<<2)>>2]|0;do{if((g|0)!=0){if((a[1820736]&1)==0){break}k=c[494446]|0;m=(k|0)!=0?k:c[p>>2]|0;k=c[10560+(h<<2)>>2]|0;ei(m|0,706320,(n=i,i=i+24|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=g,n)|0)|0;i=n;k=c[494446]|0;m=(k|0)!=0?k:c[p>>2]|0;a_(m|0)|0}}while(0);h=h+1|0;}while(h>>>0<16);if(j>>>0<8){l=j}else{o=1;break}}i=e;return o|0}else if((b|0)==12){if((a[1820736]&1)!=0){l=c[494446]|0;h=(l|0)!=0?l:c[p>>2]|0;a5(705928,42,1,h|0)|0;h=c[494446]|0;l=(h|0)!=0?h:c[p>>2]|0;a_(l|0)|0}c[479928]=c[d>>2];o=1;i=e;return o|0}else if((b|0)==9){c[d>>2]=(a[1811460]|0)!=0?1811460:0;if((a[1820736]&1)==0){o=1;i=e;return o|0}l=c[494446]|0;ei(((l|0)!=0?l:c[p>>2]|0)|0,725320,(n=i,i=i+8|0,c[n>>2]=1811460,n)|0)|0;i=n;l=c[494446]|0;a_(((l|0)!=0?l:c[p>>2]|0)|0)|0;o=1;i=e;return o|0}else if((b|0)==10){l=c[d>>2]|0;do{if((l|0)==0){if((a[1820736]&1)==0){break}h=c[494446]|0;g=(h|0)!=0?h:c[p>>2]|0;a5(724320,47,1,g|0)|0;g=c[494446]|0;h=(g|0)!=0?g:c[p>>2]|0;a_(h|0)|0}else if((l|0)==2){if((a[1820736]&1)==0){break}h=c[494446]|0;a5(723040,45,1,((h|0)!=0?h:c[p>>2]|0)|0)|0;h=c[494446]|0;a_(((h|0)!=0?h:c[p>>2]|0)|0)|0}else if((l|0)==1){if((a[1820736]&1)==0){break}h=c[494446]|0;a5(721504,47,1,((h|0)!=0?h:c[p>>2]|0)|0)|0;h=c[494446]|0;a_(((h|0)!=0?h:c[p>>2]|0)|0)|0}else{o=0;i=e;return o|0}}while(0);c[478774]=l;o=1;i=e;return o|0}else if((b|0)==7){if((a[1820736]&1)!=0){l=c[494446]|0;h=(l|0)!=0?l:c[p>>2]|0;a5(729728,29,1,h|0)|0;h=c[494446]|0;l=(h|0)!=0?h:c[p>>2]|0;a_(l|0)|0}a[1915088]=1;o=1;i=e;return o|0}else if((b|0)==8){l=c[d>>2]|0;c[478773]=l;if((a[1820736]&1)==0){o=1;i=e;return o|0}h=c[494446]|0;ei(((h|0)!=0?h:c[p>>2]|0)|0,727168,(n=i,i=i+8|0,c[n>>2]=l,n)|0)|0;i=n;l=c[494446]|0;a_(((l|0)!=0?l:c[p>>2]|0)|0)|0;o=1;i=e;return o|0}else if((b|0)==13){if((a[1820736]&1)!=0){l=c[494446]|0;h=(l|0)!=0?l:c[p>>2]|0;a5(705624,47,1,h|0)|0;h=c[494446]|0;l=(h|0)!=0?h:c[p>>2]|0;a_(l|0)|0}c[479930]=c[d>>2];c[1919724>>2]=c[d+4>>2];c[1919728>>2]=c[d+8>>2];c[1919732>>2]=c[d+12>>2];c[1919736>>2]=c[d+16>>2];c[1919740>>2]=c[d+20>>2];c[1919744>>2]=c[d+24>>2];o=1;i=e;return o|0}else if((b|0)==14|(b|0)==65550){if((a[1820736]&1)!=0){l=c[494446]|0;h=(l|0)!=0?l:c[p>>2]|0;a5(705216,34,1,h|0)|0;h=c[494446]|0;l=(h|0)!=0?h:c[p>>2]|0;a_(l|0)|0}l=c[d>>2]|0;do{if((l|0)==0){if((a[1820736]&1)==0){break}h=c[494446]|0;g=(h|0)!=0?h:c[p>>2]|0;a5(704904,37,1,g|0)|0;g=c[494446]|0;h=(g|0)!=0?g:c[p>>2]|0;a_(h|0)|0}else if((l|0)==2){if((a[1820736]&1)!=0){h=c[494446]|0;g=(h|0)!=0?h:c[p>>2]|0;a5(704544,41,1,g|0)|0;g=c[494446]|0;h=(g|0)!=0?g:c[p>>2]|0;a_(h|0)|0}c[3118437]=168}else if((l|0)==1|(l|0)==3){h=c[494446]|0;a5(704176,116,1,((h|0)!=0?h:c[p>>2]|0)|0)|0;h=c[494446]|0;a_(((h|0)!=0?h:c[p>>2]|0)|0)|0;o=0;i=e;return o|0}else{if((a[1820736]&1)==0){o=0;i=e;return o|0}h=c[494446]|0;a5(703784,39,1,((h|0)!=0?h:c[p>>2]|0)|0)|0;h=c[494446]|0;a_(((h|0)!=0?h:c[p>>2]|0)|0)|0;o=0;i=e;return o|0}}while(0);c[d+8>>2]=62;c[d+12>>2]=190;if((b&65536|0)==0){aIy(1919748,d|0,40)|0;o=1;i=e;return o|0}else{c[479937]=c[d>>2];c[1919752>>2]=c[d+4>>2];c[1919756>>2]=c[d+8>>2];c[1919760>>2]=c[d+12>>2];a[1919764|0]=a[d+16|0]|0;o=1;i=e;return o|0}}else if((b|0)==2){a[d]=a[1717406]&1^1;if((a[1820736]&1)==0){o=1;i=e;return o|0}l=c[494446]|0;ei(((l|0)!=0?l:c[p>>2]|0)|0,720592,(n=i,i=i+8|0,c[n>>2]=(a[1717406]&1^1)&255,n)|0)|0;i=n;l=c[494446]|0;a_(((l|0)!=0?l:c[p>>2]|0)|0)|0;o=1;i=e;return o|0}else if((b|0)==15){if((a[1820736]&1)!=0){l=c[494446]|0;h=(l|0)!=0?l:c[p>>2]|0;l=c[d>>2]|0;ei(h|0,705256,(n=i,i=i+8|0,c[n>>2]=l,n)|0)|0;i=n;l=c[494446]|0;h=(l|0)!=0?l:c[p>>2]|0;a_(h|0)|0}h=c[479954]|0;do{if((h|0)==0){c[d+4>>2]=0;q=0}else{a[h+4108|0]=0;l=c[h+4104>>2]|0;g=h+4100|0;m=d;k=0;while(1){if(k>>>0>=l>>>0){r=2655;break}s=c[g>>2]|0;if((cP(c[s+(k<<4)+4>>2]|0,c[m>>2]|0)|0)==0){r=2654;break}else{k=k+1|0}}if((r|0)==2655){c[d+4>>2]=0;q=0;break}else if((r|0)==2654){m=c[(c[c[s+(k<<4)+8>>2]>>2]|0)+(c[s+(k<<4)+12>>2]<<3)>>2]|0;c[d+4>>2]=m;q=m;break}}}while(0);if((a[1820736]&1)==0){o=1;i=e;return o|0}s=c[494446]|0;ei(((s|0)!=0?s:c[p>>2]|0)|0,701464,(n=i,i=i+8|0,c[n>>2]=(q|0)==0?695824:q,n)|0)|0;i=n;q=c[494446]|0;a_(((q|0)!=0?q:c[p>>2]|0)|0)|0;o=1;i=e;return o|0}else if((b|0)==1){q=c[d>>2]|0;if((a[1820736]&1)!=0){s=c[494446]|0;h=(s|0)!=0?s:c[p>>2]|0;ei(h|0,690544,(n=i,i=i+8|0,c[n>>2]=q,n)|0)|0;i=n;h=c[494446]|0;s=(h|0)!=0?h:c[p>>2]|0;a_(s|0)|0}if((a[1733848]&1)==0){o=1;i=e;return o|0}c[478771]=q;s=c[3118437]|0;if((s|0)==0){o=0;i=e;return o|0}h=c[s+40>>2]|0;if((h|0)==0){o=0;i=e;return o|0}s=c[3118440]|0;if((s|0)==0){o=1;i=e;return o|0}fj[h&511](s,q);o=1;i=e;return o|0}else if((b|0)==16){if((a[1820736]&1)!=0){q=c[494446]|0;s=(q|0)!=0?q:c[p>>2]|0;a5(696784,34,1,s|0)|0;s=c[494446]|0;q=(s|0)!=0?s:c[p>>2]|0;a_(q|0)|0}q=c[479954]|0;if((q|0)!=0){s=q+4104|0;if((c[s>>2]|0)==0){t=q|0}else{h=q+4100|0;m=q|0;g=0;while(1){l=c[h>>2]|0;gS(c[m>>2]|0,c[l+(g<<4)+4>>2]|0,c[(c[c[l+(g<<4)+8>>2]>>2]|0)+(c[l+(g<<4)+12>>2]<<3)>>2]|0);l=g+1|0;if(l>>>0<(c[s>>2]|0)>>>0){g=l}else{t=m;break}}}m=c[t>>2]|0;t=q+4|0;gT(m,t)|0;hv(c[479954]|0)}t=d;if((a[1786880]|0)!=0|(a[1841266]|0)==0){u=1786880}else{m=f|0;gJ(m,1841266,694632);u=m}m=aIp(4112)|0;L3881:do{if((m|0)==0){v=0}else{if((c[m-4>>2]&3|0)!=0){aIv(m|0,0,4112)}f=m;if((a[u]|0)==0){w=c[m>>2]|0}else{q=gP(u,0)|0;c[m>>2]=q;w=q}q=m;if((w|0)==0){g=aIp(20)|0;do{if((g|0)!=0){if((c[g-4>>2]&3|0)==0){break}aIv(g|0,0,20)}}while(0);c[q>>2]=g}k=4096;s=m+4|0;h=u;while(1){l=k-1|0;if((l|0)==0){r=2686;break}j=a[h]|0;a[s]=j;if(j<<24>>24==0){break}else{k=l;s=s+1|0;h=h+1|0}}do{if((r|0)==2686){a[s]=0;if((a[h]|0)==0){break}else{x=h}do{x=x+1|0;}while((a[x]|0)!=0)}}while(0);do{if((c[q>>2]|0)!=0){h=d;s=c[h>>2]|0;k=(s|0)==0;do{if(k){y=0;z=0}else{g=0;l=t;while(1){if((c[l+4>>2]|0)==0){A=g;break}j=g+1|0;B=l+8|0;if((c[B>>2]|0)==0){A=j;break}else{g=j;l=B}}if((A|0)==0){y=0;z=0;break}l=A<<4;if(A>>>0<=65535){y=l;z=A;break}y=((l>>>0)/(A>>>0)|0|0)==16?l:-1;z=A}}while(0);l=aIp(y)|0;if((l|0)==0){c[m+4100>>2]=0;break}if((c[l-4>>2]&3|0)==0){g=m+4100|0;c[g>>2]=l;C=g}else{aIv(l|0,0,y|0);g=m+4100|0;c[g>>2]=l;C=g}c[m+4104>>2]=z;if(k){v=f;break L3881}else{D=0;E=h;F=s}while(1){g=E+4|0;if((c[g>>2]|0)==0){v=f;break L3881}l=c[C>>2]|0;B=l+(D<<4)+4|0;c[B>>2]=dv(F|0)|0;G=dv(c[g>>2]|0)|0;g=bx(G|0,729992)|0;if((g|0)==0){r=2703;break}a[g]=0;j=l+(D<<4)|0;c[j>>2]=dv(G|0)|0;H=gx(g+2|0,726824)|0;g=l+(D<<4)+8|0;c[g>>2]=H;if((H|0)==0){r=2705;break}H=c[B>>2]|0;I=(c[q>>2]|0)+4|0;while(1){J=c[I>>2]|0;if((J|0)==0){break}if((cP(H|0,c[J+4>>2]|0)|0)==0){r=2709;break}else{I=J+12|0}}if((r|0)==2709){r=0;I=dv(c[J+8>>2]|0)|0;H=c[g>>2]|0;K=c[H+4>>2]|0;L=H|0;H=0;while(1){if(H>>>0>=K>>>0){break}if((cP(c[(c[L>>2]|0)+(H<<3)>>2]|0,I|0)|0)==0){r=2712;break}else{H=H+1|0}}if((r|0)==2712){r=0;c[l+(D<<4)+12>>2]=H}aIq(I)}aIq(G);L=a[1820736]|0;if((L&1)==0){M=L}else{L=c[494446]|0;K=(L|0)!=0?L:c[p>>2]|0;a5(716192,24,1,K|0)|0;K=c[494446]|0;L=(K|0)!=0?K:c[p>>2]|0;a_(L|0)|0;M=a[1820736]|0}if((M&1)==0){N=M}else{L=c[494446]|0;K=(L|0)!=0?L:c[p>>2]|0;L=c[j>>2]|0;ei(K|0,707960,(n=i,i=i+8|0,c[n>>2]=L,n)|0)|0;i=n;L=c[494446]|0;K=(L|0)!=0?L:c[p>>2]|0;a_(K|0)|0;N=a[1820736]|0}if((N&1)==0){O=N}else{K=c[494446]|0;L=(K|0)!=0?K:c[p>>2]|0;K=c[B>>2]|0;ei(L|0,703680,(n=i,i=i+8|0,c[n>>2]=K,n)|0)|0;i=n;K=c[494446]|0;L=(K|0)!=0?K:c[p>>2]|0;a_(L|0)|0;O=a[1820736]|0}if((O&1)==0){P=O}else{L=c[494446]|0;K=(L|0)!=0?L:c[p>>2]|0;L=c[C>>2]|0;Q=c[(c[c[L+(D<<4)+8>>2]>>2]|0)+(c[L+(D<<4)+12>>2]<<3)>>2]|0;ei(K|0,700344,(n=i,i=i+8|0,c[n>>2]=Q,n)|0)|0;i=n;Q=c[494446]|0;K=(Q|0)!=0?Q:c[p>>2]|0;a_(K|0)|0;P=a[1820736]|0}if((P&1)!=0){K=c[494446]|0;Q=(K|0)!=0?K:c[p>>2]|0;a5(697960,29,1,Q|0)|0;Q=c[494446]|0;K=(Q|0)!=0?Q:c[p>>2]|0;a_(K|0)|0}K=c[g>>2]|0;if((c[K+4>>2]|0)!=0){Q=0;L=K;while(1){if((a[1820736]&1)==0){R=L}else{K=c[494446]|0;S=(K|0)!=0?K:c[p>>2]|0;K=c[(c[L>>2]|0)+(Q<<3)>>2]|0;ei(S|0,696032,(n=i,i=i+8|0,c[n>>2]=K,n)|0)|0;i=n;K=c[494446]|0;S=(K|0)!=0?K:c[p>>2]|0;a_(S|0)|0;R=c[g>>2]|0}S=Q+1|0;if(S>>>0<(c[R+4>>2]|0)>>>0){Q=S;L=R}else{break}}}L=E+8|0;Q=c[L>>2]|0;if((Q|0)==0){v=f;break L3881}else{D=D+1|0;E=L;F=Q}}if((r|0)==2703){aIq(G);break}else if((r|0)==2705){aIq(G);break}}}while(0);hv(f);v=0}}while(0);c[479954]=v;o=1;i=e;return o|0}else if((b|0)==3){a[d]=1;if((a[1820736]&1)==0){o=1;i=e;return o|0}v=c[494446]|0;a5(709680,38,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;v=c[494446]|0;a_(((v|0)!=0?v:c[p>>2]|0)|0)|0;o=1;i=e;return o|0}else if((b|0)==6){if((a[1820736]&1)!=0){v=c[494446]|0;G=(v|0)!=0?v:c[p>>2]|0;v=c[d>>2]|0;ei(G|0,692496,(n=i,i=i+8|0,c[n>>2]=v,n)|0)|0;i=n;v=c[494446]|0;G=(v|0)!=0?v:c[p>>2]|0;a_(G|0)|0}G=c[492315]|0;if((G|0)==0){o=1;i=e;return o|0}v=G+4|0;F=c[v>>2]|0;if(F>>>0>1){E=G|0;D=1;R=F;while(1){F=c[(c[E>>2]|0)+(D<<2)>>2]|0;if((F|0)==0){T=R}else{aIq(c[F+8>>2]|0);aIq(c[(c[E>>2]|0)+(D<<2)>>2]|0);c[(c[E>>2]|0)+(D<<2)>>2]=0;T=c[v>>2]|0}F=D+1|0;if(F>>>0<T>>>0){D=F;R=T}else{break}}}c[v>>2]=1;v=G+12|0;aIq(c[v>>2]|0);c[v>>2]=0;v=c[492315]|0;G=c[d>>2]|0;T=v+4|0;R=c[T>>2]|0;if(R>>>0>=(c[v+8>>2]|0)>>>0){o=1;i=e;return o|0}D=c[d+4>>2]|0;E=aIp(12)|0;do{if((E|0)!=0){if((c[E-4>>2]&3|0)==0){break}aIv(E|0,0,12)}}while(0);c[E+4>>2]=1;c[E>>2]=D;if((G|0)==0){U=0;V=R}else{R=dv(G|0)|0;U=R;V=c[T>>2]|0}c[E+8>>2]=U;U=v|0;c[(c[U>>2]|0)+(V<<2)>>2]=E;E=c[T>>2]|0;c[T>>2]=E+1;if(E>>>0>1){W=E}else{o=1;i=e;return o|0}while(1){E=W>>>1;T=c[U>>2]|0;V=T+(E<<2)|0;v=c[V>>2]|0;R=c[T+(W<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[v+4>>2]|0)>>>0){o=1;r=2858;break}c[V>>2]=R;c[(c[U>>2]|0)+(W<<2)>>2]=v;if(W>>>0>3){W=E}else{o=1;r=2859;break}}if((r|0)==2858){i=e;return o|0}else if((r|0)==2859){i=e;return o|0}}else if((b|0)==131073|(b|0)==131074){L4006:do{if((d|0)==0){a[1857650]=0}else{W=4096;U=1857650;E=d;while(1){v=W-1|0;if((v|0)==0){break}R=a[E]|0;a[U]=R;if(R<<24>>24==0){break L4006}else{W=v;U=U+1|0;E=E+1|0}}a[U]=0;if((a[E]|0)==0){break}else{X=E}do{X=X+1|0;}while((a[X]|0)!=0)}}while(0);X=(a[1820736]&1)!=0;if((b|0)==131074){if(X){E=c[494446]|0;U=(E|0)!=0?E:c[p>>2]|0;a5(701416,42,1,U|0)|0;U=c[494446]|0;E=(U|0)!=0?U:c[p>>2]|0;a_(E|0)|0}a[1969264]=1;o=1;i=e;return o|0}else{if(!X){o=1;i=e;return o|0}X=c[494446]|0;E=(X|0)!=0?X:c[p>>2]|0;a5(701192,35,1,E|0)|0;E=c[494446]|0;X=(E|0)!=0?E:c[p>>2]|0;a_(X|0)|0;o=1;i=e;return o|0}}else if((b|0)==17){X=c[479954]|0;if((X|0)==0){Y=0}else{Y=a[X+4108|0]&1}a[d]=Y;o=1;i=e;return o|0}else if((b|0)==18){Y=a[d]|0;if((a[1820736]&1)==0){Z=Y&1}else{X=c[494446]|0;E=(X|0)!=0?X:c[p>>2]|0;X=Y&1;Y=X<<24>>24!=0?702496:702224;ei(E|0,702984,(n=i,i=i+8|0,c[n>>2]=Y,n)|0)|0;i=n;Y=c[494446]|0;E=(Y|0)!=0?Y:c[p>>2]|0;a_(E|0)|0;Z=X}a[1915102]=Z;o=1;i=e;return o|0}else if((b|0)==19){c[d>>2]=0;o=1;i=e;return o|0}else if((b|0)==21){if((a[1820736]&1)!=0){Z=c[494446]|0;X=(Z|0)!=0?Z:c[p>>2]|0;a5(701976,44,1,X|0)|0;X=c[494446]|0;Z=(X|0)!=0?X:c[p>>2]|0;a_(Z|0)|0}c[479948]=c[d>>2];c[1919796>>2]=c[d+4>>2];c[1919800>>2]=c[d+8>>2];c[1919804>>2]=c[d+12>>2];o=1;i=e;return o|0}else if((b|0)==131072){if((a[1820736]&1)!=0){Z=c[494446]|0;X=(Z|0)!=0?Z:c[p>>2]|0;a5(701688,48,1,X|0)|0;X=c[494446]|0;Z=(X|0)!=0?X:c[p>>2]|0;a_(Z|0)|0}Z=c9(d|0,697480)|0;if((Z|0)==0){o=0;i=e;return o|0}aS(Z|0)|0;Z=4096;X=1795076;E=d;while(1){d=Z-1|0;if((d|0)==0){break}Y=a[E]|0;a[X]=Y;if(Y<<24>>24==0){o=1;r=2866;break}else{Z=d;X=X+1|0;E=E+1|0}}if((r|0)==2866){i=e;return o|0}a[X]=0;if((a[E]|0)==0){o=1;i=e;return o|0}else{_=E}while(1){E=_+1|0;if((a[E]|0)==0){o=1;break}else{_=E}}i=e;return o|0}else{if((a[1820736]&1)==0){o=0;i=e;return o|0}_=c[494446]|0;ei(((_|0)!=0?_:c[p>>2]|0)|0,700912,(n=i,i=i+8|0,c[n>>2]=b,n)|0)|0;i=n;n=c[494446]|0;a_(((n|0)!=0?n:c[p>>2]|0)|0)|0;o=0;i=e;return o|0}return 0}function gX(){return 1}function gY(a,b){a=a|0;b=b|0;return}function gZ(a){a=a|0;c[3118432]=a;return}function g_(a){a=a|0;c[3118434]=a;return}function g$(a){a=a|0;c[3118428]=a;return}function g0(a){a=a|0;c[3118426]=a;return}function g1(a){a=a|0;c[3118424]=a;return}function g2(){return}function g3(a){a=a|0;return 0}function g4(){return}function g5(){return 0}function g6(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function g7(){return 0}function g8(a,b){a=a|0;b=b|0;return 0}function g9(a,b){a=a|0;b=b|0;return 0}function ha(a){a=a|0;return 0}function hb(a){a=a|0;return 0}function hc(){return}function hd(a,b,c){a=a|0;b=b|0;c=c|0;return}function he(a){a=a|0;h[a+24>>3]=60.0;h[a+32>>3]=3.0e4;c[a>>2]=320;c[a+4>>2]=240;c[a+8>>2]=320;c[a+12>>2]=240;g[a+16>>2]=1.3333333730697632;return}function hf(){var a=0;a=aIp(153600)|0;do{if((a|0)!=0){if((c[a-4>>2]&3|0)==0){break}aIv(a|0,0,153600)}}while(0);c[494736]=a;return}function hg(){aIq(c[494736]|0);c[494736]=0;return}function hh(b){b=b|0;aIv(b|0,0,16);c[b>>2]=717064;c[b+4>>2]=14317944;a[b+12|0]=0;c[b+8>>2]=14317944;return}function hi(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[3118430]=a;c[d>>2]=2;fA[a&63](10,d)|0;i=b;return}function hj(){var a=0,d=0;fG[c[3118428]&16383]();a=c[494736]|0;d=0;do{b[a+(d<<1)>>1]=128;d=d+1|0;}while(d>>>0<76800);fH[c[3118424]&63](a,320,240,640);return}function hk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+4|0;if((c[b>>2]|0)==1){d=0;return d|0}e=a|0;f=c[(c[e>>2]|0)+4>>2]|0;g=f|0;h=(c[g>>2]|0)-1|0;c[g>>2]=h;if((h|0)!=0){d=c[f+8>>2]|0;return d|0}h=a+12|0;aIq(c[h>>2]|0);a=f+8|0;c[h>>2]=c[a>>2];c[a>>2]=0;a=c[e>>2]|0;f=a+4|0;g=c[f>>2]|0;i=(c[b>>2]|0)-1|0;c[b>>2]=i;c[f>>2]=c[a+(i<<2)>>2];aIq(g);g=1;while(1){i=g<<1;a=c[b>>2]|0;if(i>>>0>a>>>0){j=0}else{f=c[e>>2]|0;j=(c[f+(g<<2)>>2]|0)>>>0<(c[f+(i<<2)>>2]|0)>>>0}f=i|1;if(f>>>0>a>>>0){k=0}else{a=c[e>>2]|0;k=(c[a+(g<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0}if(!(j|k)){break}do{if(k|j^1){if(!(j|k^1)){l=f;break}a=c[e>>2]|0;l=(c[a+(i<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0?f:i}else{l=i}}while(0);i=c[e>>2]|0;f=i+(g<<2)|0;a=c[f>>2]|0;c[f>>2]=c[i+(l<<2)>>2];c[(c[e>>2]|0)+(l<<2)>>2]=a;g=l}d=c[h>>2]|0;return d|0}function hl(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+16|0;f=e|0;g=f|0;h=f;j=aIp(36)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){aIv(j|0,0,36)}l=j;m=f;L4129:do{if((d|0)==0){a[j+24|0]=1;n=c9(b|0,697480)|0;c[j>>2]=n;if((n|0)==0){o=c[494446]|0;q=(o|0)!=0?o:c[p>>2]|0;ei(q|0,704688,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;q=c[494446]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;break}aIv(m|0,0,16);if((ec(m|0,4,4,n|0)|0)!=4){o=c[494446]|0;q=(o|0)!=0?o:c[p>>2]|0;a5(700992,49,1,q|0)|0;q=c[494446]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;s=n;t=2960;break}o=c[f>>2]|0;if(!((o|0)==1112757809|(o|0)==827740994)){o=c[494446]|0;q=(o|0)!=0?o:c[p>>2]|0;a5(698264,58,1,q|0)|0;q=c[494446]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;u=n;t=2959;break}if((c[f+8>>2]|0)!=(c[456219]|0)){o=c[494446]|0;q=(o|0)!=0?o:c[p>>2]|0;a5(696384,151,1,q|0)|0;q=c[494446]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0}o=c[h+12>>2]|0;do{if((o|0)!=0){q=aIp(o)|0;c[j+4>>2]=q;c[j+8>>2]=o;if((q|0)==0){u=n;t=2959;break L4129}if((ec(q|0,1,o|0,n|0)|0)!=(o|0)){v=c[494446]|0;w=(v|0)!=0?v:c[p>>2]|0;a5(694408,53,1,w|0)|0;w=c[494446]|0;v=(w|0)!=0?w:c[p>>2]|0;a_(v|0)|0;u=n;t=2959;break L4129}if((fD[c[241030]&127]()|0)==(o|0)){v=c[241012]|0;fA[v&63](q,o)|0;break}else{q=c[494446]|0;v=(q|0)!=0?q:c[p>>2]|0;a5(692200,102,1,v|0)|0;v=c[494446]|0;q=(v|0)!=0?v:c[p>>2]|0;a_(q|0)|0;break}}}while(0);q=o+16|0;c[j+28>>2]=q;x=n;y=q;t=2954}else{q=c9(b|0,707632)|0;c[j>>2]=q;if((q|0)==0){v=c[494446]|0;w=(v|0)!=0?v:c[p>>2]|0;ei(w|0,718912,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;w=c[494446]|0;v=(w|0)!=0?w:c[p>>2]|0;a_(v|0)|0;break}c[g>>2]=0;c[g+4>>2]=0;c[f>>2]=827740994;c[f+8>>2]=c[456219];v=fD[c[241030]&127]()|0;c[h+12>>2]=v;a5(m|0,4,4,q|0)|0;w=v+16|0;c[j+28>>2]=w;c[j+8>>2]=v;if((v|0)==0){x=q;y=w;t=2954;break}z=aIp(v)|0;c[j+4>>2]=z;if((z|0)==0){u=q;t=2959;break}A=c[241032]|0;fA[A&63](z,v)|0;a5(z|0,1,v|0,q|0)|0;x=q;y=w;t=2954}}while(0);do{if((t|0)==2954){m=aIp(4194304)|0;if((m|0)==0){c[j+12>>2]=0;u=x;t=2959;break}if((c[m-4>>2]&3|0)!=0){aIv(m|0,0,4194304)}h=m;c[j+12>>2]=h;c[h>>2]=y;c[j+16>>2]=1048575;k=l;i=e;return k|0}}while(0);if((t|0)==2959){if((u|0)!=0){s=u;t=2960}}if((t|0)==2960){aS(s|0)|0}aIq(c[j+4>>2]|0);aIq(c[j+12>>2]|0);aIq(j);k=0;i=e;return k|0}function hm(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+128|0;h=g+64|0;bQ(h|0,64,719488,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=e,j)|0)|0;i=j;j=g|0;e=b+4|0;while(1){k=c[e>>2]|0;if((k|0)==0){l=2985;break}if((cP(h|0,c[k+4>>2]|0)|0)==0){break}else{e=k+12|0}}if((l|0)==2985){i=g;return}e=64;h=0;b=j;d=c[k+8>>2]|0;while(1){k=e-1|0;if((k|0)==0){l=2972;break}m=a[d]|0;a[b]=m;if(m<<24>>24==0){n=h;break}else{e=k;h=h+1|0;b=b+1|0;d=d+1|0}}do{if((l|0)==2972){a[b]=0;if((a[d]|0)==0){n=h;break}else{o=d;p=h}while(1){e=o+1|0;k=p+1|0;if((a[e]|0)==0){n=k;break}else{o=e;p=k}}}}while(0);if(n>>>0>=64){i=g;return}do{if((aIu(j|0)|0)==1){n=a[j]|0;if((dq(n|0)|0)==0){q=0;l=2978;break}r=aIz(n|0)|0}else{q=0;l=2978}}while(0);L4195:do{if((l|0)==2978){while(1){l=0;if((q|0)==67){r=0;break L4195}if((aIB(c[670144+(q<<3)>>2]|0,j|0)|0)==0){break}else{q=q+1|0;l=2978}}r=c[670148+(q<<3)>>2]|0}}while(0);c[f+12>>2]=r;i=g;return}function hn(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;g=i;i=i+136|0;h=g|0;j=g+8|0;k=g+72|0;bQ(k|0,64,719392,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;l=j|0;e=b+4|0;while(1){m=c[e>>2]|0;if((m|0)==0){n=3008;break}if((cP(k|0,c[m+4>>2]|0)|0)==0){break}else{e=m+12|0}}if((n|0)==3008){i=g;return}e=64;k=0;b=l;d=c[m+8>>2]|0;while(1){m=e-1|0;if((m|0)==0){n=2992;break}o=a[d]|0;a[b]=o;if(o<<24>>24==0){q=k;break}else{e=m;k=k+1|0;b=b+1|0;d=d+1|0}}do{if((n|0)==2992){a[b]=0;if((a[d]|0)==0){q=k;break}else{r=d;s=k}while(1){e=r+1|0;m=s+1|0;if((a[e]|0)==0){q=m;break}else{r=e;s=m}}}}while(0);if(q>>>0>=64){i=g;return}if((cP(l|0,719528)|0)==0){q=f+16|0;c[q>>2]=65535;c[q+4>>2]=0;i=g;return}if((a[l]|0)!=104){q=aY(l|0,0,0)|0;l=f+16|0;c[l>>2]=q;c[l+4>>2]=F;i=g;return}l=j+1|0;if(((a[l]|0)-48|0)>>>0>=10){i=g;return}c[h>>2]=0;j=aX(l|0,h|0,0)|0;l=c[h>>2]|0;if((l|0)==0){h=c[494446]|0;q=(h|0)!=0?h:c[p>>2]|0;a5(718504,49,1,q|0)|0;q=c[494446]|0;h=(q|0)!=0?q:c[p>>2]|0;a_(h|0)|0;i=g;return}do{if((aIB(l|0,705568)|0)==0){t=-32768}else{if((aIB(l|0,705160)|0)==0){t=16384;break}if((aIB(l|0,704888)|0)==0){t=8192;break}h=(aIB(l|0,704456)|0)==0;if(h){t=h?4096:0;break}i=g;return}}while(0);l=f+16|0;c[l>>2]=t&65535|j&4095;c[l+4>>2]=0;i=g;return}function ho(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+128|0;h=g|0;j=g+64|0;bQ(j|0,64,719328,(k=i,i=i+16|0,c[k>>2]=d,c[k+8>>2]=e,k)|0)|0;i=k;k=h|0;e=b+4|0;while(1){l=c[e>>2]|0;if((l|0)==0){m=3033;break}if((cP(j|0,c[l+4>>2]|0)|0)==0){break}else{e=l+12|0}}if((m|0)==3033){i=g;return}e=64;j=0;b=k;d=c[l+8>>2]|0;while(1){l=e-1|0;if((l|0)==0){m=3022;break}n=a[d]|0;a[b]=n;if(n<<24>>24==0){o=j;break}else{e=l;j=j+1|0;b=b+1|0;d=d+1|0}}do{if((m|0)==3022){a[b]=0;if((a[d]|0)==0){o=j;break}else{p=d;q=j}while(1){e=p+1|0;l=q+1|0;if((a[e]|0)==0){o=l;break}else{p=e;q=l}}}}while(0);if(o>>>0>=64){i=g;return}if((cP(k|0,719528)|0)==0){c[f+32>>2]=-1;i=g;return}if((aIu(k|0)|0)>>>0<=1){i=g;return}o=a[k]|0;if(!((o<<24>>24|0)==43|(o<<24>>24|0)==45)){i=g;return}o=a2(h+1|0,0,0)|0;if((a[k]|0)==43){c[f+32>>2]=o|-65536;i=g;return}else{c[f+32>>2]=o<<16|65535;i=g;return}}function hp(){var a=0,b=0,d=0,e=0,f=0;a=aIp(48)|0;if((a|0)==0){b=0;return b|0}if((c[a-4>>2]&3|0)!=0){aIv(a|0,0,48)}d=bo()|0;c[a+44>>2]=d;if((d|0)==0){aIq(a);b=0;return b|0}aIv(962744,0,1292);d=9880;e=276;while(1){c[962744+(e<<2)>>2]=c[d>>2];f=c[d+12>>2]|0;if((f|0)==0){b=a;break}else{d=d+8|0;e=f}}return b|0}function hq(a){a=a|0;var b=0;b=cm(c[a+44>>2]|0)|0;aIy(a|0,b|0,44)|0;return}function hr(a,b){a=a|0;b=b|0;return}function hs(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;g=b;do{if((f|0)==2){if((h|0)==1){i=c[b+36>>2]&65535;break}else if((h|0)==3){i=a[b+41|0]|0;break}else if((h|0)==0){i=c[b+32>>2]&65535;break}else if((h|0)==2){i=a[b+40|0]|0;break}else{i=0;break}}else if((f|0)==3){if((h|0)>322){i=0;break}j=c[962744+(h<<2)>>2]|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else if((f|0)==1){j=c[d+(e<<2)>>2]|0;if(h>>>0>=56){i=0;break}if((a[j+(h*40|0)|0]&1)==0){i=0;break}k=c[j+(h*40|0)+12>>2]|0;if((k|0)>322){i=0;break}j=c[962744+(k<<2)>>2]|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else{i=0}}while(0);return i|0}function ht(b,d){b=b|0;d=d|0;var e=0,f=0;if(d>>>0>=56){e=0;return e|0}if((a[1742208+(d*40|0)|0]&1)==0){e=0;return e|0}f=c[1742220+(d*40|0)>>2]|0;if((f|0)>322){e=0;return e|0}d=c[962744+(f<<2)>>2]|0;e=(a[b+(d>>>3)|0]&1<<(d&7)|0)!=0;return e|0}function hu(a){a=a|0;aM(c[a+44>>2]|0);aIq(a);return}function hv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)==0){return}b=a+4104|0;if((c[b>>2]|0)!=0){d=a+4100|0;e=0;do{aIq(c[(c[d>>2]|0)+(e<<4)>>2]|0);aIq(c[(c[d>>2]|0)+(e<<4)+4>>2]|0);f=c[(c[d>>2]|0)+(e<<4)+8>>2]|0;if((f|0)!=0){g=f+4|0;h=f|0;i=c[h>>2]|0;if((c[g>>2]|0)==0){j=i}else{k=0;l=i;while(1){aIq(c[l+(k<<3)>>2]|0);i=k+1|0;m=c[h>>2]|0;if(i>>>0<(c[g>>2]|0)>>>0){k=i;l=m}else{j=m;break}}}aIq(j);aIq(f)}e=e+1|0;}while(e>>>0<(c[b>>2]|0)>>>0)}b=c[a>>2]|0;if((b|0)!=0){gN(b)}aIq(c[a+4100>>2]|0);aIq(a);return}
function k8(f){f=f|0;var g=0,h=0,i=0,j=0;switch(f&193|0){case 129:{g=(jY(c[3579678]|0)|0)&255;return g|0};case 64:{h=c[3579678]|0;i=c[423080]|0;do{if((i|0)!=0){if((a[962713]&4)==0){break}g=i>>>8&255;return g|0}}while(0);i=((h>>>0)/3420|0)-1|0;if((i|0)>(e[444100]|0)){j=i-(e[780032]|0)|0}else{j=i}if((a[1692200]|0)==0){g=j&255;return g|0}i=j<<d[1692312];g=(i>>>8&1|i&254)&255;return g|0};case 65:{i=c[423080]|0;if((i|0)==0){g=a[(c[423088]|0)+(((c[3579678]|0)>>>0)%3420|0)|0]|0;return g|0}else{g=i&255;return g|0}break};case 128:{g=(fD[c[222042]&127]()|0)&255;return g|0};case 0:case 1:{i=f&255;j=a[937424]|0;if(!(i>>>0<7&j<<24>>24==64)){if(j<<24>>24!=32){g=-1;return g|0}j=(e[7159324]|0)+65535|0;g=a[(c[747336+((j>>>10&63)<<2)>>2]|0)+(j&1023)|0]|0;return g|0}switch(i|0){case 5:{g=a[1692189]|0;return g|0};case 2:{g=a[1692186]|0;return g|0};case 4:{g=a[1692188]|0;return g|0};case 0:{g=((b[846136]&255|127)^-128)&a[1692184];return g|0};case 1:{i=a[1692186]|0;g=((i|-128)^127)&a[1692185]|i&127;return g|0};case 3:{g=a[1692187]|0;return g|0};default:{g=-1;return g|0}}break};default:{i=f&255;if((i-192|0)>>>0<2|(i|0)==220|(i|0)==221){g=(kE(f&1)|0)&255;return g|0}if((a[937424]|0)!=32){g=-1;return g|0}f=(e[7159324]|0)+65535|0;g=a[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0;return g|0}}return 0}function k9(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;switch(b&193|0){case 128:{fi[c[222040]&255](d&255);return};case 129:{jU(d&255);return};case 0:case 1:{kD(b&1,d&255,(c[3579678]|0)+520|0);return};case 64:case 65:{ox(c[3579678]|0,d&255);return};default:{if((b&4|0)!=0){return}if((a[12474148]&1)==0){return}e=c[3579678]|0;f=b&3;g=d&255;do{if((b&1|0)!=0){d=c[494748]|0;if(d>>>0>=e>>>0){break}h=c[494746]|0;i=((e-1-d+h|0)>>>0)/(h>>>0)|0;fj[c[3579684]&511](c[494738]|0,i);c[494738]=(c[494738]|0)+(i<<1<<2);h=ab(c[494746]|0,i)|0;c[494748]=(c[494748]|0)+h}}while(0);fj[c[3579682]&511](f,g);return}}}function la(a){a=a|0;return 255}function lb(a,b){a=a|0;b=b|0;return}function lc(b){b=b|0;if((a[12474170]|0)!=0){return 255}c[3579678]=-1;a[736792]=0;return 255}function ld(b,d){b=b|0;d=d|0;if((a[12474170]|0)!=0){return}c[3579678]=-1;a[736792]=0;return}function le(b){b=b|0;var f=0,g=0,h=0,i=0;switch(b&193|0){case 129:{f=(jY(c[3579678]|0)|0)&255;return f|0};case 64:{g=c[3579678]|0;h=c[423080]|0;do{if((h|0)!=0){if((a[962713]&4)==0){break}f=h>>>8&255;return f|0}}while(0);h=((g>>>0)/3420|0)-1|0;if((h|0)>(e[444100]|0)){i=h-(e[780032]|0)|0}else{i=h}if((a[1692200]|0)==0){f=i&255;return f|0}h=i<<d[1692312];f=(h>>>8&1|h&254)&255;return f|0};case 65:{h=c[423080]|0;if((h|0)==0){f=a[(c[423088]|0)+(((c[3579678]|0)>>>0)%3420|0)|0]|0;return f|0}else{f=h&255;return f|0}break};case 128:{f=(fD[c[222042]&127]()|0)&255;return f|0};case 0:case 1:{if((a[937424]|0)!=32){f=-1;return f|0}h=(e[7159324]|0)+65535|0;f=a[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0;return f|0};default:{do{if((b&4|0)==0){if((a[12474148]&1)==0){break}h=d[756893]|248;if((a[1692198]&4)==0){f=(kE(b&1)|0)&h&255;return f|0}else{f=h&255;return f|0}}}while(0);if((a[1692198]&4)==0){f=(kE(b&1)|0)&255;return f|0}if((a[937424]|0)!=32){f=-1;return f|0}b=(e[7159324]|0)+65535|0;f=a[(c[747336+((b>>>10&63)<<2)>>2]|0)+(b&1023)|0]|0;return f|0}}return 0}function lf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;switch(b&193|0){case 64:case 65:{ox(c[3579678]|0,d&255);return};case 128:{fi[c[222040]&255](d&255);return};case 0:case 1:{return};case 129:{jU(d&255);return};default:{if((b&4|0)!=0){return}if((a[12474148]&1)==0){return}e=c[3579678]|0;f=b&3;g=d&255;do{if((b&1|0)!=0){d=c[494748]|0;if(d>>>0>=e>>>0){break}h=c[494746]|0;i=((e-1-d+h|0)>>>0)/(h>>>0)|0;fj[c[3579684]&511](c[494738]|0,i);c[494738]=(c[494738]|0)+(i<<1<<2);h=ab(c[494746]|0,i)|0;c[494748]=(c[494748]|0)+h}}while(0);fj[c[3579682]&511](f,g);return}}}function lg(b){b=b|0;var f=0,g=0,h=0,i=0;switch(b&193|0){case 65:{f=c[423080]|0;if((f|0)==0){g=a[(c[423088]|0)+(((c[3579678]|0)>>>0)%3420|0)|0]|0;return g|0}else{g=f&255;return g|0}break};case 0:case 1:{if((a[937424]|0)!=32){g=-1;return g|0}f=(e[7159324]|0)+65535|0;g=a[(c[747336+((f>>>10&63)<<2)>>2]|0)+(f&1023)|0]|0;return g|0};case 129:{g=(jY(c[3579678]|0)|0)&255;return g|0};case 128:{g=(fD[c[222042]&127]()|0)&255;return g|0};case 64:{f=c[3579678]|0;h=c[423080]|0;do{if((h|0)!=0){if((a[962713]&4)==0){break}g=h>>>8&255;return g|0}}while(0);h=((f>>>0)/3420|0)-1|0;if((h|0)>(e[444100]|0)){i=h-(e[780032]|0)|0}else{i=h}if((a[1692200]|0)==0){g=i&255;return g|0}h=i<<d[1692312];g=(h>>>8&1|h&254)&255;return g|0};default:{do{if((b&4|0)==0){if((a[12474148]&1)==0){break}g=a[756893]|-8;return g|0}}while(0);g=(kE(b&1)|0)&255;return g|0}}return 0}function lh(a,b){a=a|0;b=b|0;var d=0;d=a&193;if((d|0)==128){fi[c[222040]&255](b&255);return}else if((d|0)==64|(d|0)==65){ox(c[3579678]|0,b&255);return}else if((d|0)==129){jV(b&255);return}else{return}}function li(b){b=b|0;var d=0,f=0;d=b&193;if((d|0)==128){f=(fD[c[222042]&127]()|0)&255;return f|0}else if((d|0)==192|(d|0)==193){f=(kE(b&1)|0)&255;return f|0}else if((d|0)==129){f=(jY(c[3579678]|0)|0)&255;return f|0}else{if((a[937424]|0)!=32){f=-1;return f|0}d=(e[7159324]|0)+65535|0;f=a[(c[747336+((d>>>10&63)<<2)>>2]|0)+(d&1023)|0]|0;return f|0}return 0}function lj(b){b=b|0;var e=0,f=0,g=0,h=0;switch(b>>>8&255|0){case 65:{if(!((b&1|0)!=0&(a[937440]|0)<0)){e=255;return e|0}e=(c[290366]|0)==(c[3118358]|0)|254;return e|0};case 48:{f=c[3118372]|0;if((f|0)==0){e=255;return e|0}g=fl[f&255](b)|0;if((b&1|0)==0){e=g>>>8;return e|0}else{e=g&255;return e|0}break};case 0:{if((b&224|0)!=0){e=255;return e|0}g=b>>>1&15;b=g-1|0;if(b>>>0<3){f=d[g+1692187|0]|0;h=(fD[c[964252+(b<<3)>>2]&127]()|0)&255;e=d[1692184+g|0]&(f|128)|h&(f&127^-129);return e|0}else{e=d[1692184+g|0]|0;return e|0}break};case 17:case 16:case 18:case 32:case 64:case 68:case 80:{e=255;return e|0};default:{if((a[12474170]|0)!=0){e=255;return e|0}c[3579678]=-1;a[736792]=0;e=255;return e|0}}return 0}function lk(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;switch(b>>>8&255|0){case 16:case 32:case 64:case 68:case 80:{return};case 17:{if((b&1|0)!=0){return}f=c[3579678]|0;g=a[736792]|0;if((e&1|0)==0){if(g<<24>>24==3){c[3579678]=f;c[291167]=100;c[291168]=92;c[291169]=278;c[291170]=84}h=g&1}else{if(g<<24>>24==1){oy(f);c[291167]=2;c[291168]=206;c[291169]=22;c[291170]=26;i=a[736792]|0}else{i=g}h=i|2}a[736792]=h;return};case 65:{if((a[12474172]&1)==0){return}if(!((b&1|0)!=0&(a[937440]|0)<0)){return}if((e&1|0)==0){c[290366]=12736656;return}else{c[290366]=c[3118358];return}break};case 0:{if((b&225|0)!=1){return}h=b>>>1&15;switch(h|0){case 1:case 2:case 3:{i=e&255;a[1692184+h|0]=i;fj[c[964248+(h-1<<3)>>2]&511](i,a[h+1692187|0]|0);return};case 9:case 12:case 15:{a[1692184+h|0]=e&255&-8;return};case 7:case 10:case 13:{a[1692184+h|0]=e&255;return};case 4:case 5:case 6:{i=1692184+h|0;if((d[i]|0)==(e|0)){return}g=e&255;a[i]=g;fj[c[964248+(h-4<<3)>>2]&511](a[1692184+(h-3)|0]|0,g);return};default:{return}}break};case 48:{fj[c[3118373]&511](b,e);return};case 18:{if((b&1|0)!=0){return}jO(e&1,c[3579678]|0);return};default:{if((a[12474170]|0)!=0){return}c[3579678]=-1;a[736792]=0;return}}}function ll(){return 127}function lm(){var c=0,e=0,f=0;c=~b[846136];e=a[14317864]<<1&2;switch(d[14317865]|0|0){case 4:{f=(e&255|(c&65535)>>>10&60)&255;break};case 1:{f=e|(c&255)<<2&60;break};case 0:{f=e|4;break};case 3:{f=(e&255|(c&65535)>>>6&60)&255;break};case 2:{f=(e&255|(c&65535)>>>2&60)&255;break};default:{f=e}}return f|0}function ln(){var c=0,e=0,f=0;c=~b[846140];e=a[14317866]<<1&2;switch(d[14317867]|0|0){case 1:{f=e|(c&255)<<2&60;break};case 4:{f=(e&255|(c&65535)>>>10&60)&255;break};case 0:{f=e|4;break};case 2:{f=(e&255|(c&65535)>>>2&60)&255;break};case 3:{f=(e&255|(c&65535)>>>6&60)&255;break};default:{f=e}}return f|0}function lo(b,c){b=b|0;c=c|0;var d=0,e=0;d=a[14317864|0]|0;e=d&~c|c&b;b=(e^d)&255;do{if((b&64|0)==0){if((b&1|0)==0){break}d=a[14317865|0]|0;if((d&255)>=4){break}a[14317865|0]=d+1&255}else{a[14317865|0]=0}}while(0);a[14317864|0]=e;return}function lp(b,c){b=b|0;c=c|0;var d=0,e=0;d=a[14317866|0]|0;e=d&~c|c&b;b=(e^d)&255;do{if((b&64|0)==0){if((b&1|0)==0){break}d=a[14317867|0]|0;if((d&255)>=4){break}a[14317867|0]=d+1&255}else{a[14317867|0]=0}}while(0);a[14317866|0]=e;return}function lq(){var b=0,c=0,f=0,g=0;b=a[1717280]&64;c=b|63;f=e[846136]|0;switch(d[1717281]|0|b>>>6|0){case 6:{g=(f>>>2&48^c)&255;break};case 4:{g=(f>>>2&48^112)&c&255;break};case 1:case 3:case 5:{g=(f&63^c)&255;break};case 7:{g=((f|79)^48)&c&((f>>>8|240)^15)&255;break};case 0:case 2:{g=(f&3^115)&c&(f>>>2&48^115)&255;break};default:{g=c&255}}return g|0}function lr(){var b=0,c=0,f=0,g=0;b=a[1717292]&64;c=b|63;f=e[846140]|0;switch(d[1717293]|0|b>>>6|0){case 1:case 3:case 5:{g=(f&63^c)&255;break};case 6:{g=(f>>>2&48^c)&255;break};case 0:case 2:{g=(f&3^115)&c&(f>>>2&48^115)&255;break};case 4:{g=(f>>>2&48^112)&c&255;break};case 7:{g=((f|79)^48)&c&((f>>>8|240)^15)&255;break};default:{g=c&255}}return g|0}function ls(b,c){b=b|0;c=c|0;var d=0,e=0;d=a[1717280]|0;e=d&~c|c&b;do{if((a[1692288]|0)==1){if((d&64)!=0){break}if((e&64)==0){break}a[1717281]=(a[1717281]|0)+2&6;a[1717282]=0}}while(0);a[1717280]=e;return}function lt(b,c){b=b|0;c=c|0;var d=0,e=0;d=a[1717292]|0;e=d&~c|c&b;do{if((a[1692292]|0)==1){if((d&64)!=0){break}if((e&64)==0){break}a[1717293]=(a[1717293]|0)+2&6;a[1717294]=0}}while(0);a[1717292]=e;return}function lu(b,c){b=b|0;c=c|0;if((c&112)!=112){return}a[968032]=(b&255)>>>4&7;return}function lv(){var b=0,c=0,f=0,g=0,h=0;b=a[968032]|0;if((b&255)>=4){c=112;return c|0}f=b&255;b=a[1717280+(f*3|0)|0]&64;g=b|63;h=e[1692272+(f<<1)>>1]|0;switch(d[1717281+(f*3|0)|0]|0|b>>>6|0){case 0:case 2:{c=(h&3^115)&g&(h>>>2&48^115)&255;return c|0};case 7:{c=((h|79)^48)&g&((h>>>8|240)^15)&255;return c|0};case 6:{c=(h>>>2&48^g)&255;return c|0};case 4:{c=(h>>>2&48^112)&g&255;return c|0};case 1:case 3:case 5:{c=(h&63^g)&255;return c|0};default:{c=g&255;return c|0}}return 0}function lw(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a[968032]|0;if((d&255)>=4){return}e=d&255;d=1717280+(e*3|0)|0;f=a[d]|0;g=f&~c|c&b;do{if((a[1692288+e|0]|0)==1){if((f&64)!=0){break}if((g&64)==0){break}b=1717281+(e*3|0)|0;a[b]=(a[b]|0)+2&6;a[1717282+(e*3|0)|0]=0}}while(0);a[d]=g;return}function lx(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;switch(f&253|0){case 24:case 25:case 28:case 29:{g=255;return g|0};case 5:{f=c[3579678]|0;h=c[496910]|0;do{if((h|0)>0){i=c[496914]|0;j=c[496912]|0;k=((f-i|0)>>>0)/(j>>>0)|0;if((k|0)<=0){break}l=h-k|0;c[496910]=l;m=b[468728]&-257;b[468728]=m;if((l|0)<1){b[468728]=m|512;c[496910]=0}c[496914]=(ab(k,j)|0)+i}}while(0);h=b[468728]|0;if((h&2)==0|(c[3118496]|0)!=0|(c[3118498]|0)>>>0>f>>>0){n=h}else{i=h&-3;b[468728]=i;n=i}i=n&65535;a[968008]=0;b[468728]=n&-97;n=(a[962713]&64)==0?i|8:i;g=(((f>>>0)%3420|0)>>>0<588?n|4:n)&255;return g|0};case 0:{g=(fD[c[222048]&127]()|0)>>>8;return g|0};case 4:{n=c[3579678]|0;f=c[496910]|0;do{if((f|0)>0){i=c[496914]|0;h=c[496912]|0;j=((n-i|0)>>>0)/(h>>>0)|0;if((j|0)<=0){break}k=f-j|0;c[496910]=k;m=b[468728]&-257;b[468728]=m;if((k|0)<1){b[468728]=m|512;c[496910]=0}c[496914]=(ab(j,h)|0)+i}}while(0);f=b[468728]|0;if((f&2)==0|(c[3118496]|0)!=0|(c[3118498]|0)>>>0>n>>>0){o=f}else{n=f&-3;b[468728]=n;o=n}a[968008]=0;b[468728]=o&-97;g=(o&65535)>>>8|252;return g|0};case 1:{g=(fD[c[222048]&127]()|0)&255;return g|0};case 9:case 13:{o=c[3579678]|0;n=c[423080]|0;do{if((n|0)==0){p=d[(c[423088]|0)+((o>>>0)%3420|0)|0]|0;q=10609}else{if((a[962713]&4)==0){p=n&255;q=10609;break}else{r=n&65535;break}}}while(0);if((q|0)==10609){n=((o>>>0)/3420|0)-1|0;if((n|0)>(e[444100]|0)){s=n-(e[780032]|0)|0}else{s=n}if((a[1692200]|0)==0){t=s}else{n=s<<d[1692312];t=n>>>8&1|n&-2}r=t<<8&65280|p}g=r&255;return g|0};case 8:case 12:{r=c[3579678]|0;p=c[423080]|0;do{if((p|0)==0){u=d[(c[423088]|0)+((r>>>0)%3420|0)|0]|0;q=10598}else{if((a[962713]&4)==0){u=p&255;q=10598;break}else{v=p&65535;break}}}while(0);if((q|0)==10598){q=((r>>>0)/3420|0)-1|0;if((q|0)>(e[444100]|0)){w=q-(e[780032]|0)|0}else{w=q}if((a[1692200]|0)==0){x=w}else{q=w<<d[1692312];x=q>>>8&1|q&-2}v=x<<8&65280|u}g=v>>>8;return g|0};default:{if((a[12474170]|0)!=0){g=255;return g|0}c[3579678]=-1;a[736792]=0;g=255;return g|0}}return 0}function ly(b,d){b=b|0;d=d|0;switch(b&252|0){case 16:case 20:{if((b&1|0)==0){return}ox(c[3579678]|0,d);return};case 4:{jX(d<<8|d);return};case 24:case 28:{return};case 0:{fi[c[222046]&255](d<<8|d);return};default:{if((a[12474170]|0)!=0){return}c[3579678]=-1;a[736792]=0;return}}}function lz(b){b=b|0;var c=0,f=0,g=0,h=0;b=a[1717295]&64;c=b|63;f=e[846141]|0;switch(d[1717296]|0|b>>>6|0){case 0:case 2:{g=(f&3^115)&c&(f>>>2&48^115)&255;break};case 6:{g=(f>>>2&48^c)&255;break};case 4:{g=(f>>>2&48^112)&c&255;break};case 1:case 3:case 5:{g=(f&63^c)&255;break};case 7:{g=((f|79)^48)&c&((f>>>8|240)^15)&255;break};default:{g=c&255}}c=a[1717298]&64;f=c|63;b=e[846142]|0;switch(d[1717299]|0|c>>>6|0){case 6:{h=(b>>>2&48^f)&255;break};case 1:case 3:case 5:{h=(b&63^f)&255;break};case 0:case 2:{h=(b&3^115)&f&(b>>>2&48^115)&255;break};case 4:{h=(b>>>2&48^112)&f&255;break};case 7:{h=((b|79)^48)&f&((b>>>8|240)^15)&255;break};default:{h=f&255}}return(h&255)<<8&16128|g&127|0}function lA(b,c){b=b|0;c=c|0;var d=0;b=c<<6&64;c=a[1717295]|0;d=c&-65|b;do{if((a[1692293]|0)==1){if((c&64)!=0|b<<24>>24==0){break}a[1717296]=(a[1717296]|0)+2&6;a[1717297]=0}}while(0);a[1717295]=d;d=a[1717298]|0;c=d&-65|b;if((a[1692294]|0)!=1){a[1717298]=c;return}if((d&64)!=0|b<<24>>24==0){a[1717298]=c;return}a[1717299]=(a[1717299]|0)+2&6;a[1717300]=0;a[1717298]=c;return}function lB(){var a=0,b=0;a=e[846140]|0;b=a>>>4;return(b&9|a>>>5&2|b<<1&4|64)&255|0}function lC(b,c){b=b|0;c=c|0;var d=0;d=c&b;a[1561096]=(d&255)>>>5&1|4;a[1561104]=d;return}function lD(b,c){b=b|0;c=c|0;var d=0,e=0;d=a[969344]|0;e=d&~c|c&b;b=e^d;if((b&64)!=0){a[969336]=(e&255)>>>6&1^1}if((b&32)==0){a[969344]=e;return}b=a[969336]|0;if(b<<24>>24!=0&(b&255)<10){a[969336]=b+1&255}a[11160]=1;a[969344]=e;return}function lE(){var c=0,d=0,e=0,f=0,g=0,h=0;c=b[846136]&16^112;d=a[968024]|0;if((a[9808]|0)>-1){e=d^64;a[968024]=e;f=e}else{f=d}d=b[846120]|0;if((f&64)==0){g=d&15|c&80;h=g&255;return h|0}else{g=d>>>4&15|c&255;h=g&255;return h|0}return 0}function lF(){var c=0,d=0,e=0,f=0,g=0,h=0;c=b[846140]&16^112;d=a[968025]|0;if((a[9808]|0)>-1){e=d^64;a[968025]=e;f=e}else{f=d}d=b[846128]|0;if((f&64)==0){g=d&15|c&80;h=g&255;return h|0}else{g=d>>>4&15|c&255;h=g&255;return h|0}return 0}function lG(b,c){b=b|0;c=c|0;a[968024]=a[968024]&~c|c&b;return}function lH(b,c){b=b|0;c=c|0;a[968025]=a[968025]&~c|c&b;return}function lI(){var c=0,d=0,f=0;c=b[846136]&48^112;d=a[937521]&3;if((d|0)==2){f=b[846120]&15|c;return f|0}else if((d|0)==3){f=((e[846121]|0)>>>4&15|c&255)&255;return f|0}else if((d|0)==1){f=((e[846120]|0)>>>4&15|c&255)&255;return f|0}else{f=b[846121]&15|c;return f|0}return 0}function lJ(f){f=f|0;var g=0,h=0,i=0;if((d[1561096]|0)!=(f|0)){return}g=(b[1692242+(f<<2)>>1]|0)+(c[423056]|0)|0;if(!((g|0)==(e[444104]|0)&(g|0)<(c[3446841]|0))){if((c[423080]&131072|0)==0){return}c[423080]=0;return}if((a[1692189]|0)>=0){return}h=b[1692240+(f<<2)>>1]|0;do{if((a[1692296]|0)==3){if((a[937424]|0)==-124){i=(h*304|0|0)/320|0;break}else{i=(h*289|0|0)/320|0;break}}else{i=h}}while(0);if((a[962723]&8)!=0){c[291682]=c[291682]|512}h=((a[962712]&2)==0?131072:65536)|g<<8;c[423080]=h;g=(c[423058]|0)+((i|0)/2|0)|0;if((a[962724]&1)==0){c[423080]=d[672056+((g|0)%171|0)|0]|h;return}else{c[423080]=d[671840+((g|0)%210|0)|0]|h;return}}function lK(){var f=0,g=0,h=0,i=0,j=0;f=(((e[846136]|0)>>>2|239)^16)&255;if((a[1692199]&2)==0){g=f;h=g&127;return h|0}i=(b[846121]|0)-(e[444104]|0)|0;if((((i|0)>-1?i:-i|0)|0)>=6){g=f;h=g&127;return h|0}i=b[846120]|0;j=i-(d[(c[423088]|0)+((((c[3579678]|0)+520|0)>>>0)%3420|0)|0]<<1)|0;if((((j|0)>-1?j:-j|0)|0)>=61){g=f;h=g&127;return h|0}j=f&-65;if((a[1561104]|0)==0){a[1561104]=1;g=j;h=g&127;return h|0}else{c[423080]=(c[423058]|0)+(i>>1)|65536;a[1561104]=0;g=j;h=g&127;return h|0}return 0}function lL(){var f=0,g=0,h=0,i=0,j=0;f=(((e[846140]|0)>>>2|239)^16)&255;if((a[1692199]&8)==0){g=f;h=g&127;return h|0}i=(b[846129]|0)-(e[444104]|0)|0;if((((i|0)>-1?i:-i|0)|0)>=6){g=f;h=g&127;return h|0}i=b[846128]|0;j=i-(d[(c[423088]|0)+((((c[3579678]|0)+520|0)>>>0)%3420|0)|0]<<1)|0;if((((j|0)>-1?j:-j|0)|0)>=61){g=f;h=g&127;return h|0}j=f&-65;if((a[1561104]|0)==0){a[1561104]=1;g=j;h=g&127;return h|0}else{c[423080]=(c[423058]|0)+(i>>1)|65536;a[1561104]=0;g=j;h=g&127;return h|0}return 0}function lM(){var b=0;if((a[1561104]&64)!=0){b=48;return b|0}b=((e[1692272+((d[1561096]|0)<<1)>>1]|0)>>>6&3^115)&255;return b|0}function lN(){var c=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=d[969328]|0;f=b[1692240+(c<<2)>>1]|0;g=f<<16>>16;h=b[1692242+(c<<2)>>1]|0;i=h<<16>>16;switch(d[969336]|0|0){case 6:{j=g>>>4&15;break};case 3:{j=15;break};case 1:{j=11;break};case 4:{j=((h&65535)>>>15&65535)<<1|(f&65535)>>>15&65535;break};case 8:{j=i>>>4&15;break};case 7:{j=g&15;break};case 9:{j=i&15;break};case 5:{j=(e[1692272+(c<<1)>>1]|0)>>>4&15;break};case 2:{j=15;break};default:{j=0}}if(a[11160]|0){a[11160]=0;k=(d[969344]|0)>>>1&16^16;l=k|j;m=l&255;return m|0}else{k=(d[969344]|0)>>>1&16;l=k|j;m=l&255;return m|0}return 0}function lO(){var b=0,c=0;b=d[1692288]|0;do{if((b|0)==4){lJ(0)}else if((b|0)==1){c=a[1717282]|0;a[1717282]=c+1&255;if((c&255)<=25){break}a[1717281]=0;a[1717282]=0}}while(0);b=d[1692289]|0;do{if((b|0)==4){lJ(1)}else if((b|0)==1){c=a[1717285]|0;a[1717285]=c+1&255;if((c&255)<=25){break}a[1717284]=0;a[1717285]=0}}while(0);b=d[1692290]|0;do{if((b|0)==4){lJ(2)}else if((b|0)==1){c=a[1717288]|0;a[1717288]=c+1&255;if((c&255)<=25){break}a[1717287]=0;a[1717288]=0}}while(0);b=d[1692291]|0;do{if((b|0)==4){lJ(3)}else if((b|0)==1){c=a[1717291]|0;a[1717291]=c+1&255;if((c&255)<=25){break}a[1717290]=0;a[1717291]=0}}while(0);b=d[1692292]|0;do{if((b|0)==4){lJ(4)}else if((b|0)==1){c=a[1717294]|0;a[1717294]=c+1&255;if((c&255)<=25){break}a[1717293]=0;a[1717294]=0}}while(0);b=d[1692293]|0;do{if((b|0)==1){c=a[1717297]|0;a[1717297]=c+1&255;if((c&255)<=25){break}a[1717296]=0;a[1717297]=0}else if((b|0)==4){lJ(5)}}while(0);b=d[1692294]|0;do{if((b|0)==1){c=a[1717300]|0;a[1717300]=c+1&255;if((c&255)<=25){break}a[1717299]=0;a[1717300]=0}else if((b|0)==4){lJ(6)}}while(0);b=d[1692295]|0;if((b|0)==4){lJ(7);return}else if((b|0)==1){b=a[1717303]|0;a[1717303]=b+1&255;if((b&255)<=25){return}a[1717302]=0;a[1717303]=0;return}else{return}}function lP(){var c=0,d=0,f=0;c=b[846140]&48^112;d=a[937523]&3;if((d|0)==3){f=((e[846129]|0)>>>4&15|c&255)&255;return f|0}else if((d|0)==1){f=((e[846128]|0)>>>4&15|c&255)&255;return f|0}else if((d|0)==2){f=b[846128]&15|c;return f|0}else{f=b[846129]&15|c;return f|0}return 0}function lQ(b,c){b=b|0;c=c|0;var d=0,e=0;d=a[937520|0]|0;e=d&~c|c&b;if(((e^d)&64)==0){a[937520|0]=e;return}a[937521|0]=(a[937521|0]|0)+1&255;a[937520|0]=e;return}function lR(b,c){b=b|0;c=c|0;var d=0,e=0;d=a[937522|0]|0;e=d&~c|c&b;if(((e^d)&64)==0){a[937522|0]=e;return}a[937523|0]=(a[937523|0]|0)+1&255;a[937522|0]=e;return}function lS(b,c){b=b|0;c=c|0;var e=0,f=0,g=0;e=d[937384]|0;f=e&~(c&255)|c&b&255;if(((f^e)&96|0)==0){return}if((f&64|0)==0){g=(a[937385]|0)+1&255}else{g=0}a[937385]=g;a[937384]=f&255;return}function lT(b,c){b=b|0;c=c|0;var e=0,f=0,g=0;e=d[937398]|0;f=e&~(c&255)|c&b&255;if(((f^e)&96|0)==0){return}if((f&64|0)==0){g=(a[937399]|0)+1&255}else{g=0}a[937399]=g;a[937398]=f&255;return}function lU(){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=b[846120]|0;d=b[846121]|0;e=b[846122]|0;f=~b[846136];g=a[756913]|0;h=g&255;switch(h>>>2|0){case 6:{i=c&15|64;break};case 0:{i=(f&65535)>>>8&15|64;break};case 3:{i=d>>>4&15|64;break};case 7:{i=d&15|64;break};case 9:{i=e&15|64;break};case 5:{i=e>>>4&15|64;break};case 1:{i=(f&65535)>>>4&15|64;break};case 2:{i=c>>>4&15|64;break};default:{i=64}}a[756913]=g+1&7|g&-8;a[756914]=(a[756914]|0)+1&255;return(((h&3|0)==0)<<5|h<<2&16|i)&255|0}function lV(){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=b[846128]|0;d=b[846129]|0;e=b[846130]|0;f=~b[846140];g=a[756916]|0;h=g&255;switch(h>>>2|0){case 7:{i=d&15|64;break};case 0:{i=(f&65535)>>>8&15|64;break};case 9:{i=e&15|64;break};case 3:{i=d>>>4&15|64;break};case 1:{i=(f&65535)>>>4&15|64;break};case 2:{i=c>>>4&15|64;break};case 6:{i=c&15|64;break};case 5:{i=e>>>4&15|64;break};default:{i=64}}a[756916]=g+1&7|g&-8;a[756917]=(a[756917]|0)+1&255;return(((h&3|0)==0)<<5|h<<2&16|i)&255|0}function lW(b,c){b=b|0;c=c|0;var e=0,f=0,g=0;e=a[756912]|0;f=e&~c|c&b;do{if((f&64)==0){if((e&64)==0){g=10864;break}a[756913]=0;a[756914]=0}else{g=10864}}while(0);do{if((g|0)==10864){if((d[756914]|0)<=2){break}e=(a[756913]|0)+8&255&-8;a[756913]=e;if((e&255)<=32){break}a[756913]=32}}while(0);a[756912]=f;return}function lX(b,c){b=b|0;c=c|0;var e=0,f=0,g=0;e=a[756915]|0;f=e&~c|c&b;do{if((f&64)==0){if((e&64)==0){g=10871;break}a[756916]=0;a[756917]=0}else{g=10871}}while(0);do{if((g|0)==10871){if((d[756917]|0)<=2){break}e=(a[756916]|0)+8&255&-8;a[756916]=e;if((e&255)<=32){break}a[756916]=32}}while(0);a[756915]=f;return}function lY(a){a=a|0;var b=0;if((a&1|0)==0){b=255;return b|0}b=d[10441817]|0;return b|0}function lZ(a){a=a|0;return d[10441817]|0|65280|0}function l_(a){a=a|0;var b=0;if((a&1|0)==0){b=255;return b|0}b=d[10441818]|0;return b|0}function l$(a){a=a|0;return d[10441818]|0|65280|0}function l0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b&1|0)==0){return}b=(d&1|0)==0;e=b?278:284;f=b?84:196;g=b?268:284;c[290849]=e;c[290850]=f;c[186441]=g;c[290854]=e;c[290855]=f;c[186443]=g;c[290859]=e;c[290860]=f;c[186445]=g;c[290864]=e;c[290865]=f;c[186447]=g;c[290869]=e;c[290870]=f;c[186449]=g;c[290874]=e;c[290875]=f;c[186451]=g;c[290879]=e;c[290880]=f;c[186453]=g;c[290884]=e;c[290885]=f;c[186455]=g;c[290889]=e;c[290890]=f;c[186457]=g;c[290894]=e;c[290895]=f;c[186459]=g;c[290899]=e;c[290900]=f;c[186461]=g;c[290904]=e;c[290905]=f;c[186463]=g;c[290909]=e;c[290910]=f;c[186465]=g;c[290914]=e;c[290915]=f;c[186467]=g;c[290919]=e;c[290920]=f;c[186469]=g;c[290924]=e;c[290925]=f;c[186471]=g;a[10441818|0]=d&255;return}function l1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;b=(d&1|0)==0;e=b?278:284;f=b?84:196;g=b?268:284;c[290849]=e;c[290850]=f;c[186441]=g;c[290854]=e;c[290855]=f;c[186443]=g;c[290859]=e;c[290860]=f;c[186445]=g;c[290864]=e;c[290865]=f;c[186447]=g;c[290869]=e;c[290870]=f;c[186449]=g;c[290874]=e;c[290875]=f;c[186451]=g;c[290879]=e;c[290880]=f;c[186453]=g;c[290884]=e;c[290885]=f;c[186455]=g;c[290889]=e;c[290890]=f;c[186457]=g;c[290894]=e;c[290895]=f;c[186459]=g;c[290899]=e;c[290900]=f;c[186461]=g;c[290904]=e;c[290905]=f;c[186463]=g;c[290909]=e;c[290910]=f;c[186465]=g;c[290914]=e;c[290915]=f;c[186467]=g;c[290919]=e;c[290920]=f;c[186469]=g;c[290924]=e;c[290925]=f;c[186471]=g;a[10441818|0]=d&255;return}function l2(b){b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=b<<2;d=(a[1692288+c|0]|0)==0;e=b<<6;a[937386+(b*14|0)|0]=e&255;a[937387+(b*14|0)|0]=(e|4)&255;if(d){f=2}else{a[937388+(b*14|0)|0]=(e|8)&255;f=3}e=c|1;d=(a[1692288+e|0]|0)==0;g=e<<4;a[937386+(b*14|0)+f|0]=g&255;e=f+2|0;a[f+1+(937386+(b*14|0))|0]=(g|4)&255;if(d){h=e}else{a[937386+(b*14|0)+e|0]=(g|8)&255;h=f+3|0}f=c|2;g=(a[1692288+f|0]|0)==0;e=f<<4;a[937386+(b*14|0)+h|0]=e&255;f=h+2|0;a[h+1+(937386+(b*14|0))|0]=(e|4)&255;if(g){i=f}else{a[937386+(b*14|0)+f|0]=(e|8)&255;i=h+3|0}h=c|3;c=(a[1692288+h|0]|0)==0;e=h<<4;a[937386+(b*14|0)+i|0]=e&255;a[i+1+(937386+(b*14|0))|0]=(e|4)&255;if(c){return}a[i+2+(937386+(b*14|0))|0]=(e|8)&255;return}function l3(){var b=0,c=0,f=0;b=d[937385]|0;switch(b|0){case 1:{c=63;return c|0};case 0:{c=115;return c|0};case 4:case 5:case 6:case 7:{c=(d[937384]|0)>>>1&16|a[1692288+(b-4)|0];return c|0};case 2:case 3:{c=(d[937384]|0)>>>1&16;return c|0};default:{f=d[937386+(b-8)|0]|0;c=(((d[937384]|0)>>>1&16|(e[1692272+(f>>>4<<1)>>1]|0)>>>((f&15)>>>0)&15)^15)&255;return c|0}}return 0}function l4(){var b=0,c=0,f=0;b=d[937399]|0;switch(b|0){case 4:case 5:case 6:case 7:{c=(d[937398]|0)>>>1&16|a[1692288+b|0];return c|0};case 1:{c=63;return c|0};case 0:{c=115;return c|0};case 2:case 3:{c=(d[937398]|0)>>>1&16;return c|0};default:{f=d[937400+(b-8)|0]|0;c=(((d[937398]|0)>>>1&16|(e[1692272+(f>>>4<<1)>>1]|0)>>>((f&15)>>>0)&15)^15)&255;return c|0}}return 0}function l5(a){a=a|0;var b=0;if((a&1|0)==0){b=255;return b|0}b=d[1987672+(c[2610455]&a>>>1)|0]|0;return b|0}function l6(a){a=a|0;return d[1987672+(c[2610455]&a>>>1)|0]|0|65280|0}function l7(b,d){b=b|0;d=d|0;if((b&1|0)==0){return}a[1987672+(c[2610455]&b>>>1)|0]=d&255;return}function l8(b,d){b=b|0;d=d|0;a[1987672+(c[2610455]&b>>>1)|0]=d&255;return}function l9(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=a[11958678]|0;if(f<<24>>24>=0){g=0;return g|0}c[2989670]=e;a[11958691]=0;a[11958668]=a[11958668]&-33;do{if((a[11958669]&32)!=0){h=a[11630188]|32;a[11630188]=h;i=a[11629714]|0;if((i&32)==0){break}c[240596]=d[670008+((h&i&255)>>>1)|0]<<8}}while(0);if((f&4)==0){g=0;return g|0}f=(b[5979337]|0)+2352&65535;b[5979337]=f;b[5979338]=(b[5979338]|0)+2352&65535;i=f&16383;f=i&65535;c[f+11958700>>2]=e;e=f+11958704|0;h=c[2994363]|0;do{if((h|0)>-1){if((h|0)>=(c[2994372]|0)){break}if((b[5988733]|0)==2352){j=c[2994369]|0;k=(h*2352|0)+16|0;ev(j|0,k|0,0)|0}k=c[2994369]|0;ec(e|0,2048,1,k|0)|0}}while(0);if((i&65535)<=14332){g=1;return g|0}i=f-14332|0;aIy(11958700,11975084,i)|0;g=1;return g|0}function ma(b){b=b|0;var e=0,f=0,g=0,h=0;switch(a[11629668]&15|0){case 3:{a[11958671]=b;a[11629668]=4;return};case 9:{a[11958677]=b;a[11629668]=10;return};case 13:{a[11958675]=b;a[11629668]=14;return};case 14:{a[11629668]=15;return};case 4:{a[11958672]=b;a[11629668]=5;return};case 12:{a[11958674]=b;a[11629668]=13;return};case 5:{a[11958673]=b;a[11629668]=6;return};case 10:{a[11958688]=b&-128;a[11958690]=a[11958679]&((b&255)>>>2&4^12);a[11958678]=b;a[11629668]=11;return};case 11:{a[11958690]=((d[11958678]|0)>>>2&4^12)&b;a[11958679]=b;a[11629668]=12;return};case 15:{a[11629668]=0;a[11958668]=-1;a[11958669]=0;a[11958678]=0;a[11958679]=0;a[11958688]=0;a[11958689]=0;a[11958690]=0;a[11958691]=-128;a[11958680]=0;a[11958681]=0;a[11958682]=0;a[11958683]=1;c[2989673]=0;c[2989674]=0;c[2989671]=0;e=a[11630188]|0;if((e&32)==0){return}f=e&-33;a[11630188]=f;c[240596]=(d[670008+((a[11629714]&f&255)>>>1)|0]|0)<<8;return};case 6:{L14915:do{if((a[11958669]&2)!=0){f=a[11958668]|0;a[11958668]=f&-9;a[11958671]=a[11958671]&15;e=a[11629669]|0;g=e&7;a[11629669]=g;switch(e&7|0){case 7:{e=d[11629666]|0;if((e&4|0)==0){if((e&2|0)==0){break L14915}c[2989674]=42;break L14915}if((e&1|0)==0){c[2989674]=196;break L14915}else{c[2989674]=74;break L14915}break};case 5:{c[2989674]=34;break L14915;break};case 2:case 3:{a[11958668]=f&-11;a[11629669]=g|64;break L14915;break};case 4:{c[2989674]=194;break L14915;break};default:{break L14915}}}}while(0);a[11629668]=7;return};case 7:{a[11958668]=a[11958668]|64;a[11958671]=a[11958671]&15;a[11629668]=8;return};case 2:{a[11958670]=b;a[11629668]=3;return};case 1:{g=b&255;if((g&64|0)==0){h=10958}else{if((a[11958668]&64)==0){h=10960}else{h=10958}}do{if((h|0)==10958){if((g&32|0)!=0){if((a[11958668]&32)==0){h=10960;break}}f=a[11630188]|0;if((f&32)==0){break}e=f&-33;a[11630188]=e;c[240596]=(d[670008+((a[11629714]&e&255)>>>1)|0]|0)<<8}}while(0);do{if((h|0)==10960){e=a[11630188]|32;a[11630188]=e;f=a[11629714]|0;if((f&32)==0){break}c[240596]=(d[670008+((e&f&255)>>>1)|0]|0)<<8}}while(0);if((g&2|0)==0){a[11958668]=a[11958668]|10}a[11958669]=b;a[11629668]=2;return};case 8:{a[11958676]=b;a[11629668]=9;return};default:{return}}}function mb(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;g=i;i=i+472|0;h=g|0;j=g+256|0;k=g+384|0;l=g+392|0;m=g+400|0;n=g+408|0;o=g+440|0;p=o|0;if((c[2994361]|0)!=0){q=c[2994368]|0;if((q|0)>0){r=0;s=q;while(1){q=11977476+(r<<4)|0;t=c[q>>2]|0;if((t|0)==0){u=r;v=s}else{aS(t|0)|0;t=c[2994368]|0;u=(c[11977476+(r+1<<4)>>2]|0)==(c[q>>2]|0)?t:r;v=t}t=u+1|0;if((t|0)<(v|0)){r=t;s=v}else{break}}}c[2994361]=0}aIv(11977466,0,1610);v=c9(d|0,697480)|0;s=h|0;aIE(s|0,d|0,256)|0;r=d+((aIu(d|0)|0)-4)|0;do{if((aID(725232,r|0,4)|0)==0){w=11019}else{if((aID(713200,r|0,4)|0)==0){w=11019;break}c[2994369]=v;d=h+((aIu(s|0)|0)-4)|0;x=1702191918;a[d]=x&255;x=x>>8;a[d+1|0]=x&255;x=x>>8;a[d+2|0]=x&255;x=x>>8;a[d+3|0]=x&255;y=c9(s|0,697480)|0;w=11036}}while(0);L14968:do{if((w|0)==11019){if((v|0)==0){y=0;w=11036;break}r=j|0;while(1){if((b_(r|0,128,v|0)|0)==0){break}z=bx(r|0,706712)|0;if((z|0)!=0){w=11023;break}}do{if((w|0)==11023){if((bx(r|0,702488)|0)==0){break}d=z+4|0;while(1){A=a[d]|0;if(!((A<<24>>24|0)==32|(A<<24>>24|0)==34)){break}d=d+1|0}u=(aIu(s|0)|0)-1|0;t=h+u|0;L14981:do{if((u|0)==0){B=t;C=0}else{q=t;while(1){D=a[q]|0;if((D<<24>>24|0)==92|(D<<24>>24|0)==47){B=q;C=1;break L14981}D=q-1|0;if((D|0)==(s|0)){B=s;C=0;break}else{q=D}}}}while(0);t=C?B+1|0:B;u=h+255|0;L14986:do{if(A<<24>>24==34){E=t}else{q=t;D=d;F=A;while(1){if(!((aID(D|0,702488,7)|0)!=0&q>>>0<u>>>0)){E=q;break L14986}G=D+1|0;H=q+1|0;a[q]=F;I=a[G]|0;if(I<<24>>24==34){E=H;break}else{q=H;D=G;F=I}}}}while(0);a[E]=0;u=c9(s|0,697480)|0;c[2994369]=u;J=v;K=u;break L14968}}while(0);aS(v|0)|0;L=-1;i=g;return L|0}}while(0);if((w|0)==11036){J=y;K=c[2994369]|0}if((K|0)==0){if((J|0)==0){L=-1;i=g;return L|0}aS(J|0)|0;L=-1;i=g;return L|0}ec(f|0,16,1,K|0)|0;do{if((aID(699264,f|0,14)|0)==0){M=2048}else{K=c[2994369]|0;ec(f|0,16,1,K|0)|0;if((aID(699264,f|0,14)|0)==0){M=2352;break}if((J|0)!=0){aS(J|0)|0}K=c[2994369]|0;aS(K|0)|0;c[2994369]=0;L=0;i=g;return L|0}}while(0);b[5988733]=M;ec(f+16|0,512,1,c[2994369]|0)|0;ev(c[2994369]|0,0,2)|0;M=cf(c[2994369]|0)|0;c[2994372]=(M|0)/(e[5988733]|0)|0;ev(c[2994369]|0,0,0)|0;c[2994371]=0;c[2994367]=c[2994372];c[2994368]=1;L15011:do{if((J|0)==0){if((b[5988733]|0)!=2048){break}M=h+((aIu(s|0)|0)-4)|0;K=0;while(1){if((K|0)>=10){break L15011}N=675096+(K<<4)|0;ci(M|0,N|0,(O=i,i=i+8|0,c[O>>2]=1,O)|0)|0;i=O;y=c9(s|0,697480)|0;if((y|0)!=0){P=0;Q=y;break}ci(M|0,N|0,(O=i,i=i+8|0,c[O>>2]=2,O)|0)|0;i=O;y=c9(s|0,697480)|0;if((y|0)==0){K=K+1|0}else{P=1;Q=y;break}}K=o;y=Q;while(1){ev(y|0,8,0)|0;ec(K|0,32,1,y|0)|0;ev(y|0,0,0)|0;if((aID(K|0,136,32)|0)!=0){break}v=c[2994368]|0;c[11977476+(v<<4)>>2]=y;c[11977484+(v<<4)>>2]=(c[2994367]|0)+150;ev(y|0,0,2)|0;v=c[11977484+(c[2994368]<<4)>>2]|0;E=(((cf(y|0)|0)+2351|0)/2352|0)+v|0;c[11977488+(c[2994368]<<4)>>2]=E;E=c[2994368]|0;c[11977480+(E<<4)>>2]=(c[11977484+(E<<4)>>2]|0)*2352|0;ev(y|0,235200,0)|0;ec(K|0,4,1,y|0)|0;ev(y|0,0,0)|0;if((c[p>>2]|0)==0){E=c[2994368]|0;v=11977480+(E<<4)|0;c[v>>2]=(c[v>>2]|0)-352800;v=11977488+(E<<4)|0;c[v>>2]=(c[v>>2]|0)-150}v=c[2994368]|0;c[2994367]=c[11977488+(v<<4)>>2];E=11977480+(v<<4)|0;c[E>>2]=(c[E>>2]|0)-44;E=v+1|0;c[2994368]=E;ci(M|0,N|0,(O=i,i=i+8|0,c[O>>2]=E+P,O)|0)|0;i=O;E=c9(s|0,697480)|0;if((E|0)==0){break L15011}else{y=E}}aS(y|0)|0}else{M=j|0;do{if((bx(M|0,697360)|0)!=0){break}if((bx(M|0,695408)|0)!=0){break}}while((b_(M|0,128,J|0)|0)!=0);L15032:do{if((b_(M|0,128,J|0)|0)==0){R=0;w=11089}else{y=j+128|0;K=h+255|0;E=n|0;v=0;L15034:while(1){A=M;while(1){if((a[A]|0)==32){A=A+1|0}else{break}}L15039:do{if((aID(A|0,706712,4)|0)==0){B=A+4|0;while(1){S=a[B]|0;if(!((S<<24>>24|0)==32|(S<<24>>24|0)==34)){break}B=B+1|0}C=(aIu(s|0)|0)-1|0;z=h+C|0;L15068:do{if((C|0)==0){T=z;U=0}else{r=z;while(1){u=a[r]|0;if((u<<24>>24|0)==92|(u<<24>>24|0)==47){T=r;U=1;break L15068}u=r-1|0;if((u|0)==(s|0)){T=s;U=0;break}else{r=u}}}}while(0);z=U?T+1|0:T;if(B>>>0<=y>>>0&S<<24>>24!=34&z>>>0<K>>>0){C=z;r=B;u=S;while(1){d=r+1|0;t=C+1|0;a[C]=u;F=a[d]|0;if(d>>>0<=y>>>0&F<<24>>24!=34&t>>>0<K>>>0){C=t;r=d;u=F}else{V=t;W=d;break}}}else{V=z;W=B}a[V]=0;u=c9(s|0,697480)|0;r=c[2994368]|0;c[11977476+(r<<4)>>2]=u;if((u|0)==0){R=v;w=11089;break L15032}c[11977480+(r<<4)>>2]=0;if((bx(W|0,693288)|0)!=0){X=0;break}ev(u|0,8,0)|0;ec(E|0,32,1,c[11977476+(c[2994368]<<4)>>2]|0)|0;ev(c[11977476+(c[2994368]<<4)>>2]|0,0,0)|0;u=(aID(E|0,136,32)|0)==0;Y=c[2994368]|0;if(!u){w=11067;break L15034}u=11977480+(Y<<4)|0;c[u>>2]=(c[u>>2]|0)-44;X=0}else{u=d7(A|0,691152,(O=i,i=i+8|0,c[O>>2]=m,O)|0)|0;i=O;do{if((u|0)==0){r=d7(A|0,730320,(O=i,i=i+8|0,c[O>>2]=m,O)|0)|0;i=O;if((r|0)!=0){break}r=d7(A|0,727952,(O=i,i=i+24|0,c[O>>2]=k,c[O+8>>2]=l,c[O+16>>2]=m,O)|0)|0;i=O;if((r|0)==3){X=(c[m>>2]|0)+v+((c[l>>2]|0)*75|0)+((c[k>>2]|0)*4500|0)|0;break L15039}r=d7(A|0,726056,(O=i,i=i+24|0,c[O>>2]=k,c[O+8>>2]=l,c[O+16>>2]=m,O)|0)|0;i=O;do{if((r|0)!=3){C=d7(A|0,724616,(O=i,i=i+24|0,c[O>>2]=k,c[O+8>>2]=l,c[O+16>>2]=m,O)|0)|0;i=O;if((C|0)==3){break}C=d7(A|0,723552,(O=i,i=i+24|0,c[O>>2]=k,c[O+8>>2]=l,c[O+16>>2]=m,O)|0)|0;i=O;if((C|0)!=3){C=d7(A|0,722120,(O=i,i=i+24|0,c[O>>2]=k,c[O+8>>2]=l,c[O+16>>2]=m,O)|0)|0;i=O;if((C|0)!=3){X=v;break L15039}}C=c[2994368]|0;d=11977480+(C<<4)|0;t=(c[d>>2]|0)+(v*2352|0)|0;c[d>>2]=t;F=11977476+(C<<4)|0;D=c[F>>2]|0;do{if((D|0)==0){c[F>>2]=c[2994369];q=c[m>>2]|0;I=(c[l>>2]|0)*75|0;G=(c[k>>2]|0)*4500|0;c[11977484+(C<<4)>>2]=q+v+I+G;H=11977488+(C-1<<4)|0;if((c[H>>2]|0)!=0){Z=C;break}c[H>>2]=I+q+G;Z=c[2994368]|0}else{c[11977484+(C<<4)>>2]=(c[2994367]|0)+v+(c[m>>2]|0)+((c[l>>2]|0)*75|0)+((c[k>>2]|0)*4500|0);c[d>>2]=((c[2994367]|0)*2352|0)+t;ev(D|0,0,2)|0;G=c[2994368]|0;q=c[11977484+(G<<4)>>2]|0;I=(((cf(c[11977476+(G<<4)>>2]|0)|0)+2351|0)/2352|0)+q|0;c[11977488+(c[2994368]<<4)>>2]=I;I=c[11977476+(c[2994368]<<4)>>2]|0;ev(I|0,0,0)|0;I=c[2994368]|0;c[2994367]=c[11977488+(I<<4)>>2];Z=I}}while(0);c[2994368]=Z+1;X=v;break L15039}}while(0);r=c[2994368]|0;if((c[11977476+(r<<4)>>2]|0)!=0){X=v;break L15039}c[11977488+(r-1<<4)>>2]=(c[m>>2]|0)+v+((c[l>>2]|0)*75|0)+((c[k>>2]|0)*4500|0);X=v;break L15039}}while(0);_=c[2994368]|0;$=c[11977476+(_<<4)>>2]|0;aa=($|0)!=0;if((c[m>>2]|0)!=(_+1|0)){break L15034}if(aa){X=v;break}c[11977488+(_-1<<4)>>2]=0;X=v}}while(0);if((b_(M|0,128,J|0)|0)==0){R=X;w=11089;break L15032}else{v=X}}if((w|0)==11067){E=c[11977476+(Y<<4)>>2]|0;aS(E|0)|0;E=c[2994368]|0;c[11977476+(E<<4)>>2]=0;ab=0;ac=E;break}if(!aa){ab=v;ac=_;break}aS($|0)|0;E=c[2994368]|0;c[11977476+(E<<4)>>2]=0;ab=v;ac=E}}while(0);if((w|0)==11089){ab=R;ac=c[2994368]|0}M=ac-1|0;if((c[11977476+(M<<4)>>2]|0)==(c[2994369]|0)){E=(c[2994367]|0)+ab|0;c[2994367]=E;c[11977488+(M<<4)>>2]=E}aS(J|0)|0}}while(0);J=c[2994368]|0;L15092:do{if((J|0)==1){ab=f+384|0;if((bx(ab|0,720864)|0)!=0){c[2994367]=0;c[2994368]=0;ac=0;R=0;while(1){c[11977484+(R<<4)>>2]=ac;c[11977488+(R<<4)>>2]=(e[368+(R<<1)>>1]|0)+ac;w=c[2994368]|0;$=c[11977488+(w<<4)>>2]|0;c[2994367]=$;_=w+1|0;c[2994368]=_;if((_|0)<21){ac=$;R=_}else{ad=_;ae=$;break L15092}}}if((bx(ab|0,719760)|0)!=0){c[2994367]=0;c[2994368]=0;R=0;ac=0;while(1){c[11977484+(ac<<4)>>2]=R;c[11977488+(ac<<4)>>2]=(e[480+(ac<<1)>>1]|0)+R;$=c[2994368]|0;_=c[11977488+($<<4)>>2]|0;c[2994367]=_;w=$+1|0;c[2994368]=w;if((w|0)<52){R=_;ac=w}else{ad=w;ae=_;break L15092}}}if((bx(ab|0,718744)|0)!=0){c[2994367]=0;c[2994368]=0;ac=0;R=0;while(1){c[11977484+(R<<4)>>2]=ac;c[11977488+(R<<4)>>2]=(c[416+(R<<2)>>2]|0)+ac;_=c[2994368]|0;w=c[11977488+(_<<4)>>2]|0;c[2994367]=w;$=_+1|0;c[2994368]=$;if(($|0)<15){ac=w;R=$}else{ad=$;ae=w;break L15092}}}if((bx(ab|0,717816)|0)!=0){c[2994367]=0;c[2994368]=0;R=0;ac=0;while(1){c[11977484+(ac<<4)>>2]=R;c[11977488+(ac<<4)>>2]=(c[808+(ac<<2)>>2]|0)+R;w=c[2994368]|0;$=c[11977488+(w<<4)>>2]|0;c[2994367]=$;_=w+1|0;c[2994368]=_;if((_|0)<13){R=$;ac=_}else{ad=_;ae=$;break L15092}}}if((bx(ab|0,716840)|0)!=0){c[2994367]=0;c[2994368]=0;ac=0;R=0;while(1){c[11977484+(R<<4)>>2]=ac;c[11977488+(R<<4)>>2]=(c[704+(R<<2)>>2]|0)+ac;$=c[2994368]|0;_=c[11977488+($<<4)>>2]|0;c[2994367]=_;w=$+1|0;c[2994368]=w;if((w|0)<26){ac=_;R=w}else{ad=w;ae=_;break L15092}}}if((bx(ab|0,715520)|0)==0){R=c[2994367]|0;ac=1;while(1){c[11977484+(ac<<4)>>2]=R+150;c[11977488+(ac<<4)>>2]=R+300;_=c[2994368]|0;w=c[11977488+(_<<4)>>2]|0;c[2994367]=w;$=_+1|0;c[2994368]=$;if(($|0)<99&(w|0)<252e3){R=w;ac=$}else{ad=$;ae=w;break}}}else{c[2994367]=0;c[2994368]=0;ac=0;R=0;while(1){c[11977484+(R<<4)>>2]=ac;c[11977488+(R<<4)>>2]=(c[584+(R<<2)>>2]|0)+ac;ab=c[2994368]|0;w=c[11977488+(ab<<4)>>2]|0;c[2994367]=w;$=ab+1|0;c[2994368]=$;if(($|0)<29){ac=w;R=$}else{ad=$;ae=w;break}}}}else{ad=J;ae=c[2994367]|0}}while(0);c[11977484+(ad<<4)>>2]=ae;c[2994361]=1;L=1;i=g;return L|0}function mc(a){a=a|0;var c=0,d=0,f=0,g=0;c=b[5979336]|0;d=e[5814837]|0;b[5814837]=d+(a>>>2)&65535;b[5979336]=(c&65535)+(a<<1)&65535;if((a|0)==0){return}f=a;a=d<<3&131064;d=c;while(1){c=d&16382;g=f-1|0;b[a+11097184>>1]=b5(b[(c&65535)+11958700>>1]|0)|0;if((g|0)==0){break}else{f=g;a=a+2&131070;d=c+2&65535}}return}function md(a){a=a|0;var b=0;b=d[(a>>>1&131071^1)+11097184|0]|0;return b<<4&3840|b&15|0}function me(a){a=a|0;var b=0;b=d[(a>>>1&131071^1)+11228256|0]|0;return b<<4&3840|b&15|0}function mf(b,c){b=b|0;c=c|0;var f=0;f=(b>>>1&131071^1)+11097184|0;a[f]=a[(c>>>4&240|c&15)+(11695756+(((e[5814833]|0)>>>3&3)<<16)+((d[f]|0)<<8))|0]|0;return}function mg(b,c){b=b|0;c=c|0;var f=0;f=(b>>>1&131071^1)+11228256|0;a[f]=a[(c>>>4&240|c&15)+(11695756+(((e[5814833]|0)>>>3&3)<<16)+((d[f]|0)<<8))|0]|0;return}function mh(a){a=a|0;var b=0;b=d[(a>>>1&131071^1)+11097184|0]|0;return((a&1|0)==0?b>>>4:b&15)|0}function mi(a){a=a|0;var b=0;b=d[(a>>>1&131071^1)+11228256|0]|0;return((a&1|0)==0?b>>>4:b&15)|0}function mj(b,c){b=b|0;c=c|0;var f=0,g=0,h=0;f=(b>>>1&131071^1)+11097184|0;g=d[f]|0;if((b&1|0)==0){h=g&15|c<<4}else{h=g&240|c&15}a[f]=a[11695756+(((e[5814833]|0)>>>3&3)<<16)+(g<<8)+h|0]|0;return}function mk(b,c){b=b|0;c=c|0;var f=0,g=0,h=0;f=(b>>>1&131071^1)+11228256|0;g=d[f]|0;if((b&1|0)==0){h=g&15|c<<4}else{h=g&240|c&15}a[f]=a[11695756+(((e[5814833]|0)>>>3&3)<<16)+(g<<8)+h|0]|0;return}function ml(a){a=a|0;return e[(e[11630220+((a>>>2&32767)<<1)>>1]|0|a&65538)+11097184>>1]|0|0}function mm(a){a=a|0;return e[(e[11630220+((a>>>2&32767)<<1)>>1]|0|a&65538)+11228256>>1]|0|0}function mn(a,c){a=a|0;c=c|0;b[(e[11630220+((a>>>2&32767)<<1)>>1]|0|a&65538)+11097184>>1]=c&65535;return}function mo(a,c){a=a|0;c=c|0;b[(e[11630220+((a>>>2&32767)<<1)>>1]|0|a&65538)+11228256>>1]=c&65535;return}function mp(a){a=a|0;return d[((e[11630220+((a>>>2&32767)<<1)>>1]|0|a&65539)^1)+11097184|0]|0|0}function mq(a){a=a|0;return d[((e[11630220+((a>>>2&32767)<<1)>>1]|0|a&65539)^1)+11228256|0]|0|0}function mr(b,c){b=b|0;c=c|0;a[((e[11630220+((b>>>2&32767)<<1)>>1]|0|b&65539)^1)+11097184|0]=c&255;return}function ms(b,c){b=b|0;c=c|0;a[((e[11630220+((b>>>2&32767)<<1)>>1]|0|b&65539)^1)+11228256|0]=c&255;return}function mt(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;do{if((a[11979216]|0)==0){g=b[5989604]|0;if(g<<16>>16!=0){h=c[3184684]|0;i=-(g<<16>>16)|0;g=c[h+12>>2]|0;j=h+24|0;h=g>>>20|0<<12;k=ab((g>>>5|0<<27)&32767,i)|0;g=j+(h+7<<2)|0;c[g>>2]=(c[g>>2]|0)+(i<<15)-k;i=j+(h+8<<2)|0;c[i>>2]=k+(c[i>>2]|0);b[5989604]=0}i=b[5989605]|0;if(i<<16>>16==0){break}k=c[3184678]|0;h=-(i<<16>>16)|0;i=c[k+12>>2]|0;j=k+24|0;k=i>>>20|0<<12;g=ab((i>>>5|0<<27)&32767,h)|0;i=j+(k+7<<2)|0;c[i>>2]=(c[i>>2]|0)+(h<<15)-g;h=j+(k+8<<2)|0;c[h>>2]=g+(c[h>>2]|0);b[5989605]=0}else{if((f|0)==0){break}h=c[3184678]|0;g=h|0;k=h+8|0;j=h+24|0;h=c[3184684]|0;i=h|0;l=h+8|0;m=h+24|0;h=0;do{n=d[11979217]|0;o=0;p=0;q=0;while(1){do{if((1<<o&n|0)==0){r=q;s=p}else{t=11979080+(o<<4)|0;u=c[t>>2]|0;v=a[(u>>>11&65535)+11979219|0]|0;if(v<<24>>24==-1){w=e[11979088+(o<<4)>>1]|0;c[t>>2]=w<<11;x=a[w+11979219|0]|0;if(x<<24>>24==-1){r=q;s=p;break}else{y=x}}else{c[t>>2]=(e[11979090+(o<<4)>>1]|0)+u;y=v}v=y&255;u=v&127;t=ab((v&128|0)==0?-u|0:u,d[11979092+(o<<4)|0]|0)|0;u=d[11979093+(o<<4)|0]|0;v=((ab(t,u&15)|0)>>5)+p|0;r=((ab(t,u>>>4)|0)>>5)+q|0;s=v}}while(0);v=o+1|0;if((v|0)<8){o=v;p=s;q=r}else{break}}if((s|0)<-32768){z=-32768}else{z=(s|0)>32767?32767:s}if((r|0)<-32768){A=-32768}else{A=(r|0)>32767?32767:r}q=b[5989604]|0;if((q|0)!=(z|0)){p=z-q|0;q=aIP(c[i>>2]|0,c[i+4>>2]|0,h,0)|0;o=F;n=c[l>>2]|0;v=c[l+4>>2]|0;aIF(q,o,n,v)|0;v=F;n=v>>>20|0<<12;o=ab((v>>>5|0<<27)&32767,p)|0;v=m+(n+7<<2)|0;c[v>>2]=(c[v>>2]|0)+(p<<15)-o;p=m+(n+8<<2)|0;c[p>>2]=o+(c[p>>2]|0);b[5989604]=z&65535}p=b[5989605]|0;if((p|0)!=(A|0)){o=A-p|0;p=aIP(c[g>>2]|0,c[g+4>>2]|0,h,0)|0;n=F;v=c[k>>2]|0;q=c[k+4>>2]|0;aIF(p,n,v,q)|0;q=F;v=q>>>20|0<<12;n=ab((q>>>5|0<<27)&32767,o)|0;q=j+(v+7<<2)|0;c[q>>2]=(c[q>>2]|0)+(o<<15)-n;o=j+(v+8<<2)|0;c[o>>2]=n+(c[o>>2]|0);b[5989605]=A&65535}h=h+1|0;}while(h>>>0<f>>>0)}}while(0);A=c[3184684]|0;z=f;r=0;s=A|0;y=aIP(c[s>>2]|0,c[s+4>>2]|0,z,r)|0;s=A+8|0;A=aIF(c[s>>2]|0,c[s+4>>2]|0,y,F)|0;c[s>>2]=A;c[s+4>>2]=F;s=c[3184678]|0;A=s|0;y=aIP(c[A>>2]|0,c[A+4>>2]|0,z,r)|0;r=s+8|0;s=aIF(c[r>>2]|0,c[r+4>>2]|0,y,F)|0;c[r>>2]=s;c[r+4>>2]=F;c[3011189]=(c[3011189]|0)+(f*1536|0);return}function mu(a){a=a|0;var d=0,e=0,f=0,g=0;d=b[5979336]|0;e=b[5814837]|0;b[5814837]=(e&65535)+(a>>>1)&65535;b[5979336]=(d&65535)+(a<<1)&65535;if((a|0)==0){return}f=a;a=e<<2&4092;e=d;while(1){d=e&16382;g=f-1|0;b[(c[2994803]|0)+(a&65535)>>1]=b[(d&65535)+11958700>>1]|0;if((g|0)==0){break}else{f=g;a=a+2&4094;e=d+2&65535}}return}function mv(b,c){b=b|0;c=c|0;var e=0;e=b&524287;if(e>>>0<(d[11629667]|0)<<9>>>0){return}a[(e^1)+10572896|0]=c&255;return}function mw(a){a=a|0;var c=0,d=0,f=0,g=0;c=b[5979336]|0;d=e[5814837]|0;b[5814837]=d+(a>>>2)&65535;b[5979336]=(c&65535)+(a<<1)&65535;if((a|0)==0){return}f=a;a=d<<3&131064;d=c;while(1){c=d&16382;g=f-1|0;b[a+11228256>>1]=b5(b[(c&65535)+11958700>>1]|0)|0;if((g|0)==0){break}else{f=g;a=a+2&131070;d=c+2&65535}}return}function mx(a){a=a|0;var c=0,d=0,f=0,g=0;c=b[5979336]|0;d=e[5814837]|0;b[5814837]=d+(a>>>2)&65535;b[5979336]=(c&65535)+(a<<1)&65535;if((a|0)==0){return}f=a;a=d<<3&262136;d=c;while(1){c=d&16382;g=f-1|0;b[a+11359328>>1]=b5(b[(c&65535)+11958700>>1]|0)|0;if((g|0)==0){break}else{f=g;a=a+2&262142;d=c+2&65535}}return}function my(b,e){b=b|0;e=e|0;var f=0;f=(c[240563]|0)-(c[3011189]|0)|0;if((f|0)>0){mt((f+1535|0)/1536|0)}if(b>>>0>4095){a[(c[2994803]|0)+(b&4095)|0]=e;return}switch(b|0){case 4:{a[11979088+((d[11979218]|0)<<4)|0]=e;return};case 6:{b=(e&255)<<19;f=d[11979218]|0;c[11979084+(f<<4)>>2]=b;if((1<<f&(d[11979217]|0)|0)!=0){return}c[11979080+(f<<4)>>2]=b;return};case 0:{a[11979092+((d[11979218]|0)<<4)|0]=e;return};case 1:{a[11979093+((d[11979218]|0)<<4)|0]=e;return};case 3:{a[11979091+((d[11979218]|0)<<4)|0]=e;return};case 5:{a[11979089+((d[11979218]|0)<<4)|0]=e;return};case 7:{b=e&255;if((b&64|0)==0){c[2994803]=(b<<12&61440)+11979219}else{a[11979218]=e&7}a[11979216]=e&-128;return};case 8:{b=e&255;a[11979217]=~e;if((b&1|0)!=0){c[2994770]=c[2994771]}if((b&2|0)!=0){c[2994774]=c[2994775]}if((b&4|0)!=0){c[2994778]=c[2994779]}if((b&8|0)!=0){c[2994782]=c[2994783]}if((b&16|0)!=0){c[2994786]=c[2994787]}if((b&32|0)!=0){c[2994790]=c[2994791]}if((b&64|0)!=0){c[2994794]=c[2994795]}if((b&128|0)==0){return}c[2994798]=c[2994799];return};case 2:{a[11979090+((d[11979218]|0)<<4)|0]=e;return};default:{return}}}function mz(a){a=a|0;var c=0,f=0,g=0,h=0,i=0,j=0;c=b[5979336]|0;f=e[5814837]|0;g=f<<3;b[5814837]=f+(a>>>2)&65535;b[5979336]=(c&65535)+(a<<1)&65535;if(g>>>0<(d[11629667]|0)<<9>>>0|(a|0)==0){return}else{h=a;i=g;j=c}while(1){c=j&16382;g=h-1|0;b[i+10572896>>1]=b5(b[(c&65535)+11958700>>1]|0)|0;if((g|0)==0){break}else{h=g;i=i+2&524286;j=c+2&65535}}return}function mA(a,b){a=a|0;b=b|0;return}function mB(a,b){a=a|0;b=b|0;return}function mC(a,c){a=a|0;c=c|0;var e=0;e=a&524286;if(e>>>0<(d[11629667]|0)<<9>>>0){return}b[e+10572896>>1]=c&65535;return}function mD(a){a=a|0;var b=0;b=c[240581]|0;return d[(c[957120+((b>>>16&255)*20|0)>>2]|0)+((b&65535|a&1)^1)|0]|0|0}function mE(a){a=a|0;a=c[240581]|0;return e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|0}function mF(a){a=a|0;var b=0;if((a&1|0)==0){b=255;return b|0}b=d[(a>>>1&8191)+11621472|0]|0;return b|0}function mG(a){a=a|0;return d[(a>>>1&8191)+11621472|0]|0|65280|0}function mH(b,c){b=b|0;c=c|0;if((b&1|0)==0){return}a[(b>>>1&8191)+11621472|0]=c&255;return}function mI(b,c){b=b|0;c=c|0;a[(b>>>1&8191)+11621472|0]=c&255;return}function mJ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(b>>>0<16744448){if((b&1|0)==0){f=c[240581]|0;g=d[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]|0;return g|0}f=b>>>1;h=f&8191;i=(c[240563]|0)-(c[3011189]|0)|0;if((i|0)>0){mt((i+1535|0)/1536|0)}do{if(h>>>0>4095){j=a[(c[2994803]|0)+(f&4095)|0]|0}else{if((h-16|0)>>>0>=16){j=-1;break}i=c[11979080+((b>>>2&7)<<4)>>2]|0;if((f&1|0)==0){j=i>>>11&255;break}else{j=i>>>19&255;break}}}while(0);g=j&255;return g|0}switch(b|0){case 16744448:{g=d[11629671]|0;return g|0};case 16744451:{do{if((c[240562]|0)==8){j=c[240563]|0;if(j>>>0>(c[240561]|0)>>>0){k=j;l=11299;break}if((c[240581]|0)!=(c[240560]|0)){break}c[240563]=c[240564];c[240597]=8}else{c[240562]=8;k=c[240563]|0;l=11299}}while(0);if((l|0)==11299){c[240561]=k+392;c[240560]=c[240581]}g=d[11629666]|0;return g|0};case 16744455:{switch(a[11629668]&15|0){case 1:{a[11629668]=2;m=a[11958668]|0;break};case 2:{a[11629668]=3;m=a[11958670]|0;break};case 3:{a[11629668]=4;m=a[11958671]|0;break};case 7:{a[11629668]=8;m=a[11958683+((a[11958679]&1)<<2)|0]|0;break};case 8:{a[11629668]=9;m=a[11958674]|0;break};case 9:{a[11629668]=10;m=a[11958675]|0;break};case 12:{a[11629668]=13;m=a[11958688]|0;break};case 13:{a[11629668]=14;m=0;break};case 14:{a[11629668]=15;m=a[11958690]|0;break};case 15:{k=a[11958691]|0;a[11958691]=-128;a[11958668]=a[11958668]|32;a[11629668]=0;m=k;break};case 11:{a[11629668]=12;m=a[11958677]|0;break};case 5:{a[11629668]=6;m=a[11958681+((a[11958679]&1)<<2)|0]|0;break};case 6:{a[11629668]=7;m=a[11958682+((a[11958679]&1)<<2)|0]|0;break};case 4:{a[11629668]=5;m=a[11958680+((a[11958679]&1)<<2)|0]|0;break};case 10:{a[11629668]=11;m=a[11958676]|0;break};default:{m=-1}}g=m&255;return g|0};case 16744462:{do{if((c[240562]|0)==16384){m=c[240563]|0;if(m>>>0>(c[240561]|0)>>>0){n=m;l=11306;break}if((c[240581]|0)!=(c[240560]|0)){break}c[240563]=c[240564];c[240597]=16384}else{c[240562]=16384;n=c[240563]|0;l=11306}}while(0);if((l|0)==11306){c[240561]=n+392;c[240560]=c[240581]}g=d[11629679]|0;return g|0};case 16744449:{g=1;return g|0};default:{if((b-16744528|0)>>>0<7){n=(e[5814871]|0)>>>((b<<1&12^12)>>>0);l=d[11629740]|0;g=(b&1|0)!=0?l>>>((n<<1&4)>>>0)<<4&240|l>>>((n<<2&4)>>>0)&15:(l>>>((n>>>1&4)>>>0)<<12&61440|l>>>((n&4)>>>0)<<8&3840)>>>8;return g|0}L15334:do{if((b&496|0)==16){n=c[240562]|0;l=1<<(b&31);do{if((n|0)==(l|0)){m=c[240563]|0;if(m>>>0>(c[240561]|0)>>>0){o=m;break}if((c[240581]|0)!=(c[240560]|0)){break L15334}c[240563]=c[240564];c[240597]=n;break L15334}else{c[240562]=l;o=c[240563]|0}}while(0);c[240561]=o+392;c[240560]=c[240581]}}while(0);o=11629664+((b>>>1&255)<<1)|0;if((b&1|0)==0){g=d[o+1|0]|0;return g|0}else{g=d[o]|0;return g|0}}}return 0}function mK(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(f>>>0<16744448){g=f>>>1;h=g&8191;i=(c[240563]|0)-(c[3011189]|0)|0;if((i|0)>0){mt((i+1535|0)/1536|0)}do{if(h>>>0>4095){j=a[(c[2994803]|0)+(g&4095)|0]|0}else{if((h-16|0)>>>0>=16){j=-1;break}i=c[11979080+((f>>>2&7)<<4)>>2]|0;if((g&1|0)==0){j=i>>>11&255;break}else{j=i>>>19&255;break}}}while(0);k=j&255;return k|0}if((f|0)==16744448){k=e[5814835]|0;return k|0}else if((f|0)==16744456){j=a[11958668]|0;do{if((j&2)==0){g=b[5979336]|0;h=b5(b[(g&16382)+11958700>>1]|0)|0;b[5979336]=g+2&65535;g=(b[5979335]|0)-2&65535;b[5979335]=g;if(g<<16>>16>=1){l=h;break}b[5979335]=-4096;a[11958668]=j&-75|10;do{if((a[11958669]&64)!=0){g=a[11630188]|32;a[11630188]=g;i=a[11629714]|0;if((i&32)==0){break}c[240596]=(d[670008+((g&i&255)>>>1)|0]|0)<<8}}while(0);a[11629669]=a[11629669]&7|-128;l=h}else{l=-1}}while(0);k=l&65535;return k|0}else if((f|0)==16744460){k=((((c[240563]|0)-(c[2907545]|0)|0)>>>0)/1536|0)+(e[5814838]|0)&4095;return k|0}else if((f|0)==16744450){do{if((c[240562]|0)==8){l=c[240563]|0;if(l>>>0>(c[240561]|0)>>>0){m=l;n=11365;break}if((c[240581]|0)!=(c[240560]|0)){break}c[240563]=c[240564];c[240597]=8}else{c[240562]=8;m=c[240563]|0;n=11365}}while(0);if((n|0)==11365){c[240561]=m+392;c[240560]=c[240581]}k=e[5814833]|0;return k|0}else{if((f-16744528|0)>>>0<7){m=(e[5814871]|0)>>>((f<<1&12^12)>>>0);n=d[11629740]|0;k=n>>>((m&4)>>>0)<<8&3840|n>>>((m<<2&4)>>>0)&15|n>>>((m<<1&4)>>>0)<<4&240|n>>>((m>>>1&4)>>>0)<<12&61440;return k|0}L15410:do{if((f&496|0)==16){m=(((c[240563]|0)*3420|0)>>>0)/3184|0;if((c[291683]|0)==0&(c[291649]|0)>>>0<m>>>0){IE(m)}m=c[240562]|0;n=1<<(f&30);do{if((m|0)==(n|0)){l=c[240563]|0;if(l>>>0>(c[240561]|0)>>>0){o=l;break}if((c[240581]|0)!=(c[240560]|0)){break L15410}c[240563]=c[240564];c[240597]=m;break L15410}else{c[240562]=n;o=c[240563]|0}}while(0);c[240561]=o+392;c[240560]=c[240581]}}while(0);k=e[11629664+((f>>>1&255)<<1)>>1]|0;return k|0}return 0}function mL(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if(e>>>0<16744448){if((e&1|0)==0){return}my(e>>>1&8191,f&255);return}g=f&255;switch(e&511|0){case 49:{h=f*1536|0;c[2907546]=h;if((f|0)!=0){c[2907546]=(c[240563]|0)+h-(c[2907544]|0)}a[11629712]=g;return};case 51:{a[11629714]=g;a[11629665]=(a[11629665]&127|f<<5&128)&255;c[240596]=(d[670008+(((d[11630188]|0)&f)>>>1)|0]|0)<<8;return};case 1:{if((f&1|0)!=0){return}aIv(11629668,0,508);b[5814836]=-1;b[5814837]=-1;b[5814859]=256;b[5814864]=15;aIv(11629730,-1|0,10);a[11629670]=1;aIv(11630176,0,13);aIv(1166584,0,12);aIv(962240,0,12);c[2994359]=0;c[2994360]=0;c[2994362]=0;c[2994363]=0;a[11977464]=(c[2994361]|0)!=0?9:0;c[2994365]=1024;b[5989539]=0;b[5989538]=0;a[11629668]=0;a[11958668]=-1;a[11958669]=0;a[11958678]=0;a[11958679]=0;a[11958688]=0;a[11958689]=0;a[11958690]=0;a[11958691]=-128;a[11958680]=0;a[11958681]=0;a[11958682]=0;a[11958683]=1;c[2989673]=0;c[2989674]=0;c[2989671]=0;c[2907548]=0;aIv(11979080,0,65676);c[2994803]=11979219;a[11979093]=-1;a[11979109]=-1;a[11979125]=-1;a[11979141]=-1;a[11979157]=-1;a[11979173]=-1;a[11979189]=-1;a[11979205]=-1;c[3011189]=0;h=c[3184684]|0;i=h|0;j=c[i+4>>2]|0;k=h+8|0;c[k>>2]=(c[i>>2]|0)>>>1|j<<31;c[k+4>>2]=j>>>1|0<<31;c[h+20>>2]=0;aIv(h+24|0,0,(c[h+16>>2]<<2)+72|0);h=c[3184678]|0;j=h|0;k=c[j+4>>2]|0;i=h+8|0;c[i>>2]=(c[j>>2]|0)>>>1|k<<31;c[i+4>>2]=k>>>1|0<<31;c[h+20>>2]=0;aIv(h+24|0,0,(c[h+16>>2]<<2)+72|0);return};case 0:{a[11629671]=g;return};case 3:{h=(((c[240563]|0)*3420|0)>>>0)/3184|0;k=c[291683]|0;if((k|0)==0&(c[291649]|0)>>>0<h>>>0){IE(h);l=c[291683]|0}else{l=k}if((l&12|0)!=0){c[291649]=h;c[291683]=0}c[291648]=c[291648]&-13;c[240562]=c[240562]&-13;h=a[11629666]|0;l=h&255;do{if(((l^f)&5|0)==0){m=f;n=h}else{k=(l&4|0)!=0;if((f&4|0)==0){do{if(k){i=0;j=11359328;o=11097184;p=11228256;while(1){b[j>>1]=b[o>>1]|0;b[j+2>>1]=b[p>>1]|0;q=i+1|0;if((q|0)<65536){i=q;j=j+4|0;o=o+2|0;p=p+2|0}else{break}}p=d[10441816]|0;o=p+32|0;j=p+36|0;if(o>>>0<j>>>0){p=o;do{c[1161464+(p*20|0)>>2]=(p<<16&196608)+11359328;aIv(1161468+(p*20|0)|0,0,16);c[744992+(p<<3)>>2]=0;c[744996+(p<<3)>>2]=0;p=p+1|0;}while((p|0)<(j|0))}aIv(957284,0,16);aIv(957304,0,16);aIv(957324,0,16);aIv(957344,0,16);c[239341]=166;c[239342]=58;c[239343]=164;c[239344]=224;c[239346]=166;c[239347]=58;c[239348]=164;c[239349]=224;j=a[11630189]&1^1|f;if((j&1|0)!=0){r=j;break}a[11629666]=(j&29|a[11629666]&224|2)&255;return}else{r=f}}while(0);if((r&1|0)==0){m=r;n=a[11629666]|0;break}a[11630189]=0;a[11629666]=(a[11629666]&224|r&29)&255;return}if(!k){j=0;p=11359328;o=11097184;i=11228256;while(1){b[o>>1]=b[p>>1]|0;b[i>>1]=b[p+2>>1]|0;q=j+1|0;if((q|0)<65536){j=q;p=p+4|0;o=o+2|0;i=i+2|0}else{break}}}i=d[10441816]|0;o=i+32|0;p=i+34|0;j=o>>>0<p>>>0;if((f&1|0)==0){if(j){k=o;do{c[1161464+(k*20|0)>>2]=(k<<16&65536)+11097184;k=k+1|0;}while((k|0)<(p|0))}k=i+36|0;q=p;do{c[1161468+(q*20|0)>>2]=124;c[1161472+(q*20|0)>>2]=122;c[1161476+(q*20|0)>>2]=220;c[1161480+(q*20|0)>>2]=182;c[744992+(q<<3)>>2]=124;c[744996+(q<<3)>>2]=220;q=q+1|0;}while((q|0)<(k|0));c[239321]=78;c[239322]=14;c[239323]=314;c[239324]=150;c[239326]=78;c[239327]=14;c[239328]=314;c[239329]=150;c[239331]=78;c[239332]=14;c[239333]=314;c[239334]=150;c[239336]=78;c[239337]=14;c[239338]=314;c[239339]=150;c[239340]=11228256;aIv(957364,0,16);c[239345]=11293792;aIv(957384,0,16)}else{if(j){k=o;do{c[1161464+(k*20|0)>>2]=(k<<16&65536)+11228256;k=k+1|0;}while((k|0)<(p|0))}k=i+36|0;o=p;do{c[1161468+(o*20|0)>>2]=24;c[1161472+(o*20|0)>>2]=12;c[1161476+(o*20|0)>>2]=162;c[1161480+(o*20|0)>>2]=134;c[744992+(o<<3)>>2]=24;c[744996+(o<<3)>>2]=162;o=o+1|0;}while((o|0)<(k|0));c[239321]=40;c[239322]=10;c[239323]=172;c[239324]=76;c[239326]=40;c[239327]=10;c[239328]=172;c[239329]=76;c[239331]=40;c[239332]=10;c[239333]=172;c[239334]=76;c[239336]=40;c[239337]=10;c[239338]=172;c[239339]=76;c[239340]=11097184;aIv(957364,0,16);c[239345]=11162720;aIv(957384,0,16);a[11630189]=0}a[11629666]=(a[11629666]&224|f&29)&255;return}}while(0);a[11629666]=(n&227|m&28)&255;return};case 15:{s=g;break};case 7:{ma(g);return};case 14:{s=f>>>1&255;break};case 55:{do{if((f&4|0)!=0){if((a[11629718]&4)!=0){break}c[2994359]=((c[2907544]|0)-(c[240563]|0)|0)*3|0;m=a[11630188]|16;a[11630188]=m;n=a[11629714]|0;if((n&16)==0){break}c[240596]=(d[670008+((m&n&255)>>>1)|0]|0)<<8}}while(0);a[11629718]=g;return};default:{if((e&240|0)==32){f=(((c[240563]|0)*3420|0)>>>0)/3184|0;n=c[291683]|0;if((n|0)==0&(c[291649]|0)>>>0<f>>>0){IE(f);t=c[291683]|0}else{t=n}n=3<<(e+16&30);if((t&n|0)!=0){c[291649]=f;c[291683]=0}f=~n;c[291648]=c[291648]&f;c[240562]=c[240562]&f}f=11629664+((e>>>1&255)<<1)|0;if((e&1|0)==0){a[f+1|0]=g;return}else{a[f]=g;return}}}g=(((c[240563]|0)*3420|0)>>>0)/3184|0;f=c[291683]|0;if((f|0)==0&(c[291649]|0)>>>0<g>>>0){IE(g);u=c[291683]|0}else{u=f}if((u&49152|0)!=0){c[291649]=g;c[291683]=0}c[291648]=c[291648]&-49153;c[240562]=c[240562]&-49153;a[11629678]=s;return}function mM(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if(f>>>0<16744448){my(f>>>1&8191,g&255);return}switch(f&510|0){case 48:{h=g&255;i=h*1536|0;c[2907546]=i;if((h|0)!=0){c[2907546]=(c[240563]|0)+i-(c[2907544]|0)}a[11629712]=g&255;return};case 0:{a[11629671]=g>>>8&255;if((g&1|0)!=0){return}aIv(11629668,0,508);b[5814836]=-1;b[5814837]=-1;b[5814859]=256;b[5814864]=15;aIv(11629730,-1|0,10);a[11629670]=1;aIv(11630176,0,13);aIv(1166584,0,12);aIv(962240,0,12);c[2994359]=0;c[2994360]=0;c[2994362]=0;c[2994363]=0;a[11977464]=(c[2994361]|0)!=0?9:0;c[2994365]=1024;b[5989539]=0;b[5989538]=0;a[11629668]=0;a[11958668]=-1;a[11958669]=0;a[11958678]=0;a[11958679]=0;a[11958688]=0;a[11958689]=0;a[11958690]=0;a[11958691]=-128;a[11958680]=0;a[11958681]=0;a[11958682]=0;a[11958683]=1;c[2989673]=0;c[2989674]=0;c[2989671]=0;c[2907548]=0;aIv(11979080,0,65676);c[2994803]=11979219;a[11979093]=-1;a[11979109]=-1;a[11979125]=-1;a[11979141]=-1;a[11979157]=-1;a[11979173]=-1;a[11979189]=-1;a[11979205]=-1;c[3011189]=0;i=c[3184684]|0;h=i|0;j=c[h+4>>2]|0;k=i+8|0;c[k>>2]=(c[h>>2]|0)>>>1|j<<31;c[k+4>>2]=j>>>1|0<<31;c[i+20>>2]=0;aIv(i+24|0,0,(c[i+16>>2]<<2)+72|0);i=c[3184678]|0;j=i|0;k=c[j+4>>2]|0;h=i+8|0;c[h>>2]=(c[j>>2]|0)>>>1|k<<31;c[h+4>>2]=k>>>1|0<<31;c[i+20>>2]=0;aIv(i+24|0,0,(c[i+16>>2]<<2)+72|0);return};case 12:{i=c[2907545]|0;k=(c[240563]|0)-i|0;c[2907545]=i-((k>>>0)%1536|0)+k;b[5814838]=0;return};case 14:{k=(((c[240563]|0)*3420|0)>>>0)/3184|0;i=c[291683]|0;if((i|0)==0&(c[291649]|0)>>>0<k>>>0){IE(k);l=c[291683]|0}else{l=i}if((l&49152|0)!=0){c[291649]=k;c[291683]=0}c[291648]=c[291648]&-49153;c[240562]=c[240562]&-49153;a[11629678]=g&255;return};case 102:{b[5814883]=g&65535;k=c[240563]|0;if((a[11629666]&4)!=0){return}c[2907551]=(g<<2&262136)+11359328;l=(d[11629752]|0)>>>1&3;if((l|0)==0){c[2907550]=524287;a[11630212]=15;a[11630213]=4;m=261632}else if((l|0)==1){c[2907550]=524287;a[11630212]=16;a[11630213]=3;m=262016}else if((l|0)==2){c[2907550]=8388607;a[11630212]=15;a[11630213]=8;m=131072}else if((l|0)==3){c[2907550]=8388607;a[11630212]=16;a[11630213]=7;m=229376}else{m=0}c[2907552]=(e[5814877]<<2&m)+11359328;b[5815107]=d[11629756]<<6&1984|57;c[2907554]=e[5814879]<<3&524224|a[11629760]&63;c[2907548]=k;c[2907549]=(e[5814881]|0)*20|0;a[11629753]=-128;return};case 50:{a[11629714]=g&255;a[11629665]=(a[11629665]&127|g<<5&128)&255;c[240596]=d[670008+((g&254&d[11630188])>>>1)|0]<<8;return};case 74:{b[5814869]=0;L15606:do{switch(a[11629731]&15|0){case 7:{a[11629721]=1;a[11977464]=1;n=1;break};case 8:{c[2994364]=30;a[11629721]=3;a[11977464]=3;n=3;break};case 1:{a[11977464]=(c[2994361]|0)!=0?9:0;a[11629719]=1;k=11629720;c[k>>2]=0;c[k+4>>2]=0;b[5814864]=15;return};case 2:{switch(d[11629732]|0){case 1:{k=c[2994362]|0;m=(c[2994363]|0)-(c[11977484+(k<<4)>>2]|0)|0;l=a[11977464]|0;b[5814860]=(l&255)<<8|1;b[5814861]=b[668464+(((m|0)/4500|0)<<1)>>1]|0;b[5814862]=b[668464+((((m|0)/75|0|0)%60|0)<<1)>>1]|0;b[5814863]=b[668464+(((m|0)%75|0)<<1)>>1]|0;a[11629729]=(k|0)!=0?0:4;n=l;break L15606;break};case 2:{l=a[11977464]|0;b[5814860]=(l&255)<<8|2;k=c[2994362]|0;if((k|0)<(c[2994368]|0)){o=b[668464+(k+1<<1)>>1]|0}else{o=2570}b[5814861]=o;b[5814862]=0;b[5814863]=0;a[11629729]=0;n=l;break L15606;break};case 3:{l=(c[2994367]|0)+150|0;k=a[11977464]|0;b[5814860]=(k&255)<<8|3;b[5814861]=b[668464+(((l|0)/4500|0)<<1)>>1]|0;b[5814862]=b[668464+((((l|0)/75|0|0)%60|0)<<1)>>1]|0;b[5814863]=b[668464+(((l|0)%75|0)<<1)>>1]|0;a[11629729]=0;n=k;break L15606;break};case 0:{k=(c[2994363]|0)+150|0;l=a[11977464]|0;b[5814860]=(l&255)<<8;b[5814861]=b[668464+(((k|0)/4500|0)<<1)>>1]|0;b[5814862]=b[668464+((((k|0)/75|0|0)%60|0)<<1)>>1]|0;b[5814863]=b[668464+(((k|0)%75|0)<<1)>>1]|0;a[11629729]=(c[2994362]|0)!=0?0:4;n=l;break L15606;break};case 4:{l=a[11977464]|0;b[5814860]=(l&255)<<8|4;b[5814861]=1;b[5814862]=b[668464+(c[2994368]<<1)>>1]|0;b[5814863]=0;a[11629729]=0;n=l;break L15606;break};case 5:{l=((d[11629735]|0)*10|0)+(d[11629734]|0)|0;k=(c[11977484+(l-1<<4)>>2]|0)+150|0;m=a[11977464]|0;b[5814860]=(m&255)<<8|5;b[5814861]=b[668464+(((k|0)/4500|0)<<1)>>1]|0;b[5814862]=b[668464+((((k|0)/75|0|0)%60|0)<<1)>>1]|0;i=b[668464+(((k|0)%75|0)<<1)>>1]|0;b[5814863]=i;a[11629729]=((l>>>0)%10|0)&255;if((l|0)!=1){n=m;break L15606}a[11629727]=(i&65535)>>>8&255|8;n=m;break L15606;break};default:{return}}break};case 4:{m=(d[11629736]|0)-150+((d[11629737]|0)*10|0)+((((d[11629735]|0)*10|0)+(d[11629734]|0)+((((d[11629733]|0)*10|0)+(d[11629732]|0)|0)*60|0)|0)*75|0)|0;i=c[2994363]|0;c[2994360]=(((m|0)>(i|0)?m-i|0:i-m|0)*120|0|0)/27e4|0;c[2994363]=m;i=0;while(1){if((c[11977488+(i<<4)>>2]|0)>(m|0)){break}if((i|0)<(c[2994368]|0)){i=i+1|0}else{break}}c[2994362]=i;l=c[11977484+(i<<4)>>2]|0;k=(m|0)<(l|0)?l:m;do{if((i|0)==0){l=c[2994369]|0;h=ab(e[5988733]|0,k)|0;ev(l|0,h|0,0)|0}else{h=c[11977476+(i<<4)>>2]|0;if((h|0)==0){break}l=(k*2352|0)-(c[11977480+(i<<4)>>2]|0)|0;ev(h|0,l|0,0)|0}}while(0);a[11629719]=1;a[11977464]=2;b[5814860]=527;b[5814861]=0;b[5814862]=0;b[5814863]=0;b[5814864]=14;return};case 0:{i=a[11977464]|0;a[11629721]=i;if((a[11629720]|0)!=15|i<<24>>24==2){n=i;break L15606}a[11629720]=2;k=c[2994362]|0;if((k|0)<(c[2994368]|0)){p=b[668464+(k+1<<1)>>1]|0}else{p=2570}b[5814861]=p;n=i;break};case 13:{a[11629719]=1;a[11977464]=5;b[5814860]=1280;b[5814861]=0;b[5814862]=0;b[5814863]=0;b[5814864]=10;return};case 6:{a[11629719]=1;a[11629721]=4;a[11977464]=4;n=4;break};case 3:{i=(d[11629736]|0)-150+((d[11629737]|0)*10|0)+((((d[11629735]|0)*10|0)+(d[11629734]|0)+((((d[11629733]|0)*10|0)+(d[11629732]|0)|0)*60|0)|0)*75|0)|0;k=c[2994360]|0;if((k|0)==0){c[2994360]=10;q=10}else{q=k}k=c[2994363]|0;c[2994360]=((((i|0)>(k|0)?i-k|0:k-i|0)*120|0|0)/27e4|0)+q;c[2994363]=i;k=0;while(1){if((c[11977488+(k<<4)>>2]|0)>(i|0)){break}if((k|0)<(c[2994368]|0)){k=k+1|0}else{break}}c[2994362]=k;m=c[11977484+(k<<4)>>2]|0;l=(i|0)<(m|0)?m:i;do{if((k|0)==0){m=c[2994369]|0;h=ab(e[5988733]|0,l)|0;ev(m|0,h|0,0)|0}else{h=c[11977476+(k<<4)>>2]|0;if((h|0)==0){break}m=(l*2352|0)-(c[11977480+(k<<4)>>2]|0)|0;ev(h|0,m|0,0)|0}}while(0);a[11629719]=1;a[11977464]=1;b[5814860]=258;if((c[2994362]|0)<(c[2994368]|0)){r=b[668464+(k+1<<1)>>1]|0}else{r=2570}b[5814861]=r;b[5814862]=0;b[5814863]=0;a[11629729]=0;n=1;break};case 9:{c[2994364]=-30;a[11629721]=3;a[11977464]=3;n=3;break};case 10:{a[11629719]=1;a[11629721]=4;a[11977464]=4;n=4;break};case 12:{a[11629719]=1;a[11977464]=(c[2994361]|0)!=0?9:0;l=11629720;c[l>>2]=0;c[l+4>>2]=0;b[5814864]=15;return};default:{l=a[11977464]|0;a[11629721]=l;n=l}}}while(0);a[11629728]=((((((((a[11629720]|0)+n&255)+(a[11629723]|0)&255)+(a[11629722]|0)&255)+(a[11629725]|0)&255)+(a[11629724]|0)&255)+(a[11629727]|0)&255)+(a[11629726]|0)&255)+(a[11629729]|0)&15^15;return};case 2:{n=(((c[240563]|0)*3420|0)>>>0)/3184|0;r=c[291683]|0;if((r|0)==0&(c[291649]|0)>>>0<n>>>0){IE(n);s=c[291683]|0}else{s=r}if((s&12|0)!=0){c[291649]=n;c[291683]=0}c[291648]=c[291648]&-13;c[240562]=c[240562]&-13;n=a[11629666]|0;s=n&255;do{if(((s^g)&5|0)==0){t=g;u=n}else{r=(s&4|0)!=0;if((g&4|0)==0){do{if(r){q=0;p=11359328;o=11097184;l=11228256;while(1){b[p>>1]=b[o>>1]|0;b[p+2>>1]=b[l>>1]|0;i=q+1|0;if((i|0)<65536){q=i;p=p+4|0;o=o+2|0;l=l+2|0}else{break}}l=d[10441816]|0;o=l+32|0;p=l+36|0;if(o>>>0<p>>>0){l=o;do{c[1161464+(l*20|0)>>2]=(l<<16&196608)+11359328;aIv(1161468+(l*20|0)|0,0,16);c[744992+(l<<3)>>2]=0;c[744996+(l<<3)>>2]=0;l=l+1|0;}while((l|0)<(p|0))}aIv(957284,0,16);aIv(957304,0,16);aIv(957324,0,16);aIv(957344,0,16);c[239341]=166;c[239342]=58;c[239343]=164;c[239344]=224;c[239346]=166;c[239347]=58;c[239348]=164;c[239349]=224;p=a[11630189]&1^1|g;if((p&1|0)!=0){v=p;break}a[11629666]=(p&29|a[11629666]&224|2)&255;return}else{v=g}}while(0);if((v&1|0)==0){t=v;u=a[11629666]|0;break}a[11630189]=0;a[11629666]=(a[11629666]&224|v&29)&255;return}if(!r){k=0;p=11359328;l=11097184;o=11228256;while(1){b[l>>1]=b[p>>1]|0;b[o>>1]=b[p+2>>1]|0;q=k+1|0;if((q|0)<65536){k=q;p=p+4|0;l=l+2|0;o=o+2|0}else{break}}}o=d[10441816]|0;l=o+32|0;p=o+34|0;k=l>>>0<p>>>0;if((g&1|0)==0){if(k){r=l;do{c[1161464+(r*20|0)>>2]=(r<<16&65536)+11097184;r=r+1|0;}while((r|0)<(p|0))}r=o+36|0;q=p;do{c[1161468+(q*20|0)>>2]=124;c[1161472+(q*20|0)>>2]=122;c[1161476+(q*20|0)>>2]=220;c[1161480+(q*20|0)>>2]=182;c[744992+(q<<3)>>2]=124;c[744996+(q<<3)>>2]=220;q=q+1|0;}while((q|0)<(r|0));c[239321]=78;c[239322]=14;c[239323]=314;c[239324]=150;c[239326]=78;c[239327]=14;c[239328]=314;c[239329]=150;c[239331]=78;c[239332]=14;c[239333]=314;c[239334]=150;c[239336]=78;c[239337]=14;c[239338]=314;c[239339]=150;c[239340]=11228256;aIv(957364,0,16);c[239345]=11293792;aIv(957384,0,16)}else{if(k){r=l;do{c[1161464+(r*20|0)>>2]=(r<<16&65536)+11228256;r=r+1|0;}while((r|0)<(p|0))}r=o+36|0;l=p;do{c[1161468+(l*20|0)>>2]=24;c[1161472+(l*20|0)>>2]=12;c[1161476+(l*20|0)>>2]=162;c[1161480+(l*20|0)>>2]=134;c[744992+(l<<3)>>2]=24;c[744996+(l<<3)>>2]=162;l=l+1|0;}while((l|0)<(r|0));c[239321]=40;c[239322]=10;c[239323]=172;c[239324]=76;c[239326]=40;c[239327]=10;c[239328]=172;c[239329]=76;c[239331]=40;c[239332]=10;c[239333]=172;c[239334]=76;c[239336]=40;c[239337]=10;c[239338]=172;c[239339]=76;c[239340]=11097184;aIv(957364,0,16);c[239345]=11162720;aIv(957384,0,16);a[11630189]=0}a[11629666]=(a[11629666]&224|g&29)&255;return}}while(0);a[11629666]=(u&227|t&28)&255;return};case 6:{ma(g&255);return};default:{if((f&240|0)==32){t=(((c[240563]|0)*3420|0)>>>0)/3184|0;u=c[291683]|0;if((u|0)==0&(c[291649]|0)>>>0<t>>>0){IE(t);w=c[291683]|0}else{w=u}u=3<<(f+16&30);if((w&u|0)!=0){c[291649]=t;c[291683]=0}t=~u;c[291648]=c[291648]&t;c[240562]=c[240562]&t}b[11629664+((f>>>1&255)<<1)>>1]=g&65535;return}}}function mN(a,b){a=a|0;b=b|0;if(!((a&255|0)==120&(b|0)==65535)){return}c[290366]=1987672;return}function mO(a,d){a=a|0;d=d|0;b[(c[3579470]|0)+(a&65534)>>1]=(d<<8|d)&65535;return}function mP(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a[14317872]|0;if((f<<24>>24|0)==0){return}else if((f<<24>>24|0)==2){g=(d|0)==2?0:d}else{g=d}do{if((g|0)==0|(g|0)==2){if((a[14317873]|0)!=1){break}b[1987672+(c[3579482]|0)>>1]=b[7158955]|0;b[1987672+(c[3579483]|0)>>1]=b[7158956]|0;b[1987672+(c[3579484]|0)>>1]=b[7158957]|0;b[1987672+(c[3579485]|0)>>1]=b[7158958]|0}else if((g|0)==1){if((a[14317873]|0)==1){break}d=b[7158942]|0;b[7158959]=d;f=b[7158946]|0;b[7158960]=f;h=b[7158949]|0;b[7158961]=h;i=b[7158952]|0;b[7158962]=i;j=(e[7158944]<<8&4128768|e[7158943])<<1;c[3579482]=j;k=(e[7158948]<<8&4128768|e[7158947])<<1;c[3579483]=k;l=(e[7158951]<<8&4128768|e[7158950])<<1;c[3579484]=l;m=(e[7158954]<<8&4128768|e[7158953])<<1;c[3579485]=m;n=1987672+j|0;b[7158955]=b[n>>1]|0;j=1987672+k|0;b[7158956]=b[j>>1]|0;k=1987672+l|0;b[7158957]=b[k>>1]|0;l=1987672+m|0;b[7158958]=b[l>>1]|0;b[n>>1]=d;b[j>>1]=f;b[k>>1]=h;b[l>>1]=i}else{return}}while(0);a[14317873]=g&255;return}function mQ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=c[2989674]|0;do{if((g|0)!=0){h=b[5979335]|0;if((h&65535)>=512){fi[g&255](256);b[5979335]=(b[5979335]|0)-512&65535;break}fi[g&255](((h&65535)+1|0)>>>1);b[5979335]=-4096;a[11958668]=a[11958668]&-75|10;do{if((a[11958669]&64)!=0){h=a[11630188]|32;a[11630188]=h;i=a[11629714]|0;if((i&32)==0){break}c[240596]=d[670008+((h&i&255)>>>1)|0]<<8}}while(0);a[11629669]=a[11629669]&7|-128;c[2989674]=0}}while(0);while(1){IE(f);g=(c[2907544]|0)+3184|0;i=c[240563]|0;do{if(i>>>0<g>>>0){ahk();if((c[240597]|0)!=0){c[240563]=g;j=g;break}c[240564]=g;h=c[240563]|0;if(h>>>0>=g>>>0){j=h;break}while(1){h=c[240581]|0;c[240581]=h+2;k=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;c[240587]=k;fG[c[11976+(k<<2)>>2]&16383]();k=(c[240563]|0)+(d[537288+(c[240587]|0)|0]|0)|0;c[240563]=k;if(k>>>0>=g>>>0){j=k;break}}}else{j=i}}while(0);if((c[291649]|0)>>>0<f>>>0){continue}l=(c[2907544]|0)+3184|0;if(j>>>0>=l>>>0){break}}c[2907544]=l;l=c[2994359]|0;j=l+9552|0;c[2994359]=j;do{if(j>>>0>1999999){c[2994359]=l-1990448;f=a[11977464]|0;L15763:do{if((f<<24>>24|0)==1){i=c[2994360]|0;if((i|0)!=0){c[2994360]=i-1;break}i=c[2994362]|0;if((i|0)==0){g=(c[2994363]|0)+150|0;k=l9(d[668360+((g>>>0)/4500|0)|0]|d[668360+((((g>>>0)/75|0)>>>0)%60|0)|0]<<8|d[668360+((g>>>0)%75|0)|0]<<16|16777216)|0;m=(c[2994363]|0)+k|0}else{if((i|0)>=(c[2994368]|0)){a[11977464]=12;break}if((c[2994363]|0)>=(c[11977484+(i<<4)>>2]|0)){a[11629719]=0}l9(0)|0;m=(c[2994363]|0)+1|0}c[2994363]=m;i=c[2994362]|0;if((m|0)<(c[11977488+(i<<4)>>2]|0)){break}k=i+1|0;c[2994362]=k;a[11629719]=1;i=c[11977476+(k<<4)>>2]|0;if((i|0)==0){break}g=((c[11977484+(k<<4)>>2]|0)*2352|0)-(c[11977480+(k<<4)>>2]|0)|0;ev(i|0,g|0,0)|0}else if((f<<24>>24|0)==2){g=c[2994360]|0;if((g|0)==0){a[11977464]=4;break}else{c[2994360]=g-1;break}}else if((f<<24>>24|0)==3){g=(c[2994363]|0)+(c[2994364]|0)|0;c[2994363]=g;i=c[2994362]|0;do{if((g|0)<(c[11977488+(i<<4)>>2]|0)){if((g|0)>=(c[11977484+(i<<4)>>2]|0)){n=i;o=g;break}k=i-1|0;c[2994362]=k;h=c[11977488+(k<<4)>>2]|0;c[2994363]=h;n=k;o=h}else{h=i+1|0;c[2994362]=h;k=c[11977484+(h<<4)>>2]|0;c[2994363]=k;n=h;o=k}}while(0);do{if((n|0)<0){c[2994362]=0;c[2994363]=0;p=0}else{i=c[2994368]|0;if((n|0)>=(i|0)){a[11629719]=1;c[2994362]=i;c[2994363]=c[2994367];a[11977464]=12;break L15763}if((n|0)==0){p=o;break}i=c[11977476+(n<<4)>>2]|0;if((i|0)==0){break L15763}g=(o*2352|0)-(c[11977480+(n<<4)>>2]|0)|0;ev(i|0,g|0,0)|0;break L15763}}while(0);a[11629719]=1;g=c[2994369]|0;ev(g|0,ab(e[5988733]|0,p)|0,0)|0}}while(0);if((d[11629738]|0)>15){break}a[11629738]=-16;f=a[11630188]|16;a[11630188]=f;g=a[11629714]|0;if((g&16)==0){break}c[240596]=d[670008+((f&g&255)>>>1)|0]<<8}}while(0);p=c[2907546]|0;do{if((p|0)!=0){n=p-3184|0;c[2907546]=n;if((n|0)>=1){break}c[2907546]=((d[11629712]|0)*1536|0)+n;n=a[11629714]|0;if((n&8)==0){break}o=a[11630188]|8;a[11630188]=o;c[240596]=d[670008+((o&n&255)>>>1)|0]<<8}}while(0);if((a[11629753]|0)>=0){return}p=c[2907548]|0;n=(c[2907544]|0)-p|0;if((n|0)<=0){return}o=c[2907549]|0;m=((n-1+o|0)>>>0)/(o>>>0)|0;n=d[11629764]|0;do{if(m>>>0<n>>>0){a[11629764]=n-m&255;c[2907548]=(ab(m,o)|0)+p;q=m}else{a[11629764]=0;a[11629753]=0;l=a[11629714]|0;if((l&2)==0){q=n;break}j=a[11630188]|2;a[11630188]=j;c[240596]=d[670008+((j&l&255)>>>1)|0]<<8;q=n}}while(0);if((q|0)==0){return}n=q;q=c[2907554]|0;do{n=n-1|0;m=b[5814881]|0;p=c[2907551]|0;o=p+2|0;c[2907551]=o;l=b[p>>1]|0;j=p+4|0;c[2907551]=j;g=b[o>>1]|0;o=p+6|0;c[2907551]=o;f=b[j>>1]|0;c[2907551]=p+8;p=b[o>>1]|0;if(m<<16>>16==0){r=q}else{o=(l&65535)<<8;l=(g&65535)<<8;g=q;j=m&65535;while(1){m=j-1|0;i=a[11629752]|0;k=c[2907550]|0;h=(i&1)==0?16777215:k;s=h&l;t=h&o;do{if(((t|s)&~k|0)==0){h=d[11630212]|0;u=b[(c[2907552]|0)+((s>>>(h>>>0)<<d[11630213]|t>>>(h>>>0))<<1)>>1]|0;h=(u&65535)<<8&524032;if((h|0)==0){v=0;break}w=(u&65535)>>>13&65535;u=d[(s>>>5&448|t>>>8&56|w)+11957900|0]|0;x=a[((d[(s>>>8&192|(i&255)<<2&8|t>>>10&48|w)+11958412|0]<<6|h|u)>>>1^1)+11359328|0]|0;if((u&1|0)==0){v=(x&255)>>>4;break}else{v=x&15;break}}else{v=0}}while(0);i=(g>>>1^1)+11359328|0;k=a[i]|0;if((g&1|0)==0){y=k&15|v<<4}else{y=k&-16|v}a[i]=a[(y&255)+(11695756+(((e[5814833]|0)>>>3&3)<<16)+((k&255)<<8))|0]|0;if((g&7|0)==7){z=(e[5815107]|0)+g|0}else{z=g+1|0}if((m|0)==0){break}else{o=t+f|0;l=s+p|0;g=z;j=m}}r=c[2907554]|0}q=r+8|0;c[2907554]=q;}while((n|0)!=0);return}function mR(d,e){d=d|0;e=e|0;var f=0;f=d>>>1&32767;if(f>>>0>12){return}b[14317884+(f<<1)>>1]=e&65535;if((b[7158945]|0)!=-1){return}if((a[14317873]|0)==1){mP(0);mP(1)}c[290366]=1987672;return}function mS(a,b){a=a|0;b=b|0;var d=0,e=0;d=a<<2&56;if((d|0)==0){return}a=b<<19;b=d|1;c[1161464+(d*20|0)>>2]=1987672+a;c[1161464+(b*20|0)>>2]=1987672+(a|65536);e=d|3;c[1161464+((b+1|0)*20|0)>>2]=1987672+(a|131072);c[1161464+(e*20|0)>>2]=1987672+(a|196608);c[1161464+((e+1|0)*20|0)>>2]=1987672+(a|262144);c[1161464+((e+2|0)*20|0)>>2]=1987672+(a|327680);c[1161464+((e+3|0)*20|0)>>2]=1987672+(a|393216);c[1161464+((d|7)*20|0)>>2]=1987672+(a|458752);return}function mT(a){a=a|0;return d[1987672+(((a&65280|0)==33024?a&32767:a)^1)|0]|0|0}function mU(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+8|0;f=e|0;g=c[3118359]|0;h=65536;while(1){if(g>>>0>h>>>0){h=h<<1}else{break}}if(h>>>0<10485760&g>>>0<h>>>0){aIv(1987672+g|0,-1|0,h-g|0)}g=(bx(962582,695056)|0)==0?h-1|0:4194303;c[3118360]=g;h=0;while(1){c[1161464+(h*20|0)>>2]=1987672+(h<<16&g);c[1161468+(h*20|0)>>2]=0;c[1161472+(h*20|0)>>2]=0;c[1161476+(h*20|0)>>2]=278;c[1161480+(h*20|0)>>2]=84;c[744992+(h<<3)>>2]=0;c[744996+(h<<3)>>2]=268;j=h+1|0;if((j|0)<64){h=j}else{k=64;break}}do{c[1161464+(k*20|0)>>2]=1987672+(k<<16);c[1161468+(k*20|0)>>2]=100;c[1161472+(k*20|0)>>2]=92;c[1161476+(k*20|0)>>2]=278;c[1161480+(k*20|0)>>2]=84;c[744992+(k<<3)>>2]=158;c[744996+(k<<3)>>2]=268;k=k+1|0;}while((k|0)<128);k=(bx(962636,724480)|0)!=0;if(k&(c[3118359]|0)==524288){k=0;while(1){h=1987672+(k<<16&196608)|0;c[1161464+((k+32|0)*20|0)>>2]=h;c[1161464+(k*20|0)>>2]=h;h=k+1|0;if((h|0)<16){k=h}else{l=16;break}}do{k=1987672+(l<<16&196608|262144)|0;c[1161464+((l+32|0)*20|0)>>2]=k;c[1161464+(l*20|0)>>2]=k;l=l+1|0;}while((l|0)<32)}nN();aIv(12473640,0,40);c[3118410]=16843009;c[3118413]=0;a[937482]=0;l=b[481326]|0;k=0;while(1){if((bx(962636,676200+(k*44|0)|0)|0)!=0){h=b[676216+(k*44|0)>>1]|0;if(h<<16>>16==0|h<<16>>16==l<<16>>16){m=11727;break}}h=k+1|0;if((h|0)<28){k=h}else{m=11729;break}}L15886:do{if((m|0)==11727){a[937482]=1;a[937481]=1;l=676220+(k*44|0)|0;c[3118414]=c[l>>2];c[12473660>>2]=c[l+4>>2];c[12473664>>2]=c[l+8>>2];c[12473668>>2]=c[l+12>>2];c[12473672>>2]=c[l+16>>2];c[12473676>>2]=c[l+20>>2];n=(c[3118417]|0)>>>16;o=(c[3118416]|0)>>>16;p=(c[3118418]|0)>>>16;m=11733}else if((m|0)==11729){do{if((a[937480]|0)==0){q=0}else{if((a[1988107]|0)!=-24){if(((c[234372]|0)-(c[234371]|0)|0)>>>0>=2){q=0;break}}a[937482]=1;c[3118414]=c[169154];c[12473660>>2]=c[676620>>2];c[12473664>>2]=c[676624>>2];c[12473668>>2]=c[676628>>2];c[12473672>>2]=c[676632>>2];c[12473676>>2]=c[676636>>2];n=32;o=32;p=32;m=11733;break L15886}}while(0);if((a[937481]|0)==0|q){break}l=c[234371]|0;if((c[3118359]|0)>>>0>l>>>0){break}h=l>>>16;c[1161464+(h*20|0)>>2]=c[234374];c[1161468+(h*20|0)>>2]=76;c[1161472+(h*20|0)>>2]=176;c[1161476+(h*20|0)>>2]=130;c[1161480+(h*20|0)>>2]=124;c[744992+(h<<3)>>2]=76;c[744996+(h<<3)>>2]=130}}while(0);if((m|0)==11733){c[1161468+(n*20|0)>>2]=22;c[1161472+(n*20|0)>>2]=208;c[1161468+(o*20|0)>>2]=22;c[1161472+(o*20|0)>>2]=208;c[1161476+(p*20|0)>>2]=78;c[1161480+(p*20|0)>>2]=94;c[744992+(n<<3)>>2]=22;c[744992+(o<<3)>>2]=22;c[744996+(p<<3)>>2]=78;}c[234362]=0;if((bx(962582,712280)|0)!=0){c[234362]=4084824;aIv(4084824,0,263424);c[290606]=4215896;c[290608]=0;c[290610]=194;c[290611]=4281432;c[290613]=0;c[290615]=194;c[290653]=130;c[290658]=46}a[12473444]=0;p=(bx(962636,706392)|0)!=0;o=b[481325]|0;do{if(p&(o<<16>>16==5771|o<<16>>16==5726|o<<16>>16==-12576|o<<16>>16==11329)){m=11744}else{if((bx(962636,702272)|0)!=0&o<<16>>16==-8391){m=11744;break}if((bx(962636,698904)|0)!=0&o<<16>>16==7854){m=11744;break}if((bx(962636,697272)|0)!=0&o<<16>>16==5796){m=11744;break}n=(bx(962636,695232)|0)!=0;if(n&(c[3118359]|0)>>>0<3670017){m=11745}}}while(0);if((m|0)==11744){if((c[3118359]|0)>>>0<3670017){m=11745}}if((m|0)==11745){a[12473444]=4;o=a[1692296]|0;if(o<<24>>24!=12){c[2782]=o&255;a[1692296]=1}c[290648]=214;c[290650]=144;c[290683]=214;c[290685]=144}nD();mP(0);a[14317872]=0;o=d[12474173]|0;do{if((o|0)==2){p=f|0;aIv(14317872,0,72);if((c[3118359]|0)>>>0>8454144){break}c[3579469]=10441816;c[3579470]=10572888;n=c9(14586992,697480)|0;if((n|0)==0){break}ev(n|0,0,2)|0;q=cf(n|0)|0;ev(n|0,0,0)|0;do{if((q|0)==32768){a[14317872]=2;c[290375]=310;r=0;m=11764}else if((q|0)==65536|(q|0)==131072){ec(p|0,4,1,n|0)|0;ev(n|0,0,0)|0;k=a[f+1|0]|0;if((k<<24>>24|0)==66){a[14317872]=18;c[290375]=310}else if((k<<24>>24|0)==96){a[14317872]=34;c[290450]=256}else{if((a[14317872]|0)==0){break}}h=k&255;c[1161464+(h*20|0)>>2]=c[3579470];c[1161468+(h*20|0)>>2]=0;c[1161472+(h*20|0)>>2]=0;c[1161476+(h*20|0)>>2]=272;c[1161480+(h*20|0)>>2]=0;if((q|0)>0){r=0;m=11764}}else{if((a[14317872]|0)!=0&(q|0)>0){r=0;m=11764}}}while(0);if((m|0)==11764){while(1){m=0;ec((c[3579469]|0)+r|0,4096,1,n|0)|0;p=r+4096|0;if((p|0)<(q|0)){r=p;m=11764}else{s=0;break}}do{p=c[3579469]|0;h=p+s|0;k=a[h]|0;l=s|1;a[h]=a[p+l|0]|0;a[(c[3579469]|0)+l|0]=k;s=s+2|0;}while((s|0)<(q|0))}aS(n|0)|0}else if((o|0)==1){aIv(1717144,0,120);if((c[3118359]|0)>>>0>8454144){break}c[429287]=10441816;q=c9(14583656,697480)|0;if((q|0)==0){break}ec(c[429287]|0,4096,1,q|0)|0;ec((c[429287]|0)+4096|0,4096,1,q|0)|0;ec((c[429287]|0)+8192|0,4096,1,q|0)|0;ec((c[429287]|0)+12288|0,4096,1,q|0)|0;ec((c[429287]|0)+16384|0,4096,1,q|0)|0;ec((c[429287]|0)+20480|0,4096,1,q|0)|0;ec((c[429287]|0)+24576|0,4096,1,q|0)|0;ec((c[429287]|0)+28672|0,4096,1,q|0)|0;aS(q|0)|0;q=0;k=c[429287]|0;do{l=k+q|0;p=a[l]|0;h=q|1;a[l]=a[k+h|0]|0;a[(c[429287]|0)+h|0]=p;q=q+2|0;k=c[429287]|0}while((q|0)<32768);q=k+32768|0;aIy(q|0,k|0,32768)|0;a[1717144]=1}else if((o|0)==3){if((c[3118359]|0)>>>0>6291456){break}q=c9(14582616,697480)|0;if((q|0)==0){break}else{t=0}do{ec(t+8279128|0,4096,1,q|0)|0;t=t+4096|0;}while((t|0)<2097152);aS(q|0)|0;k=c9(14582360,697480)|0;if((k|0)==0){break}else{u=0}do{ec(u+11424856|0,4096,1,k|0)|0;u=u+4096|0;}while((u|0)<262144);aS(k|0)|0;q=0;while(1){n=q+8279128|0;p=a[n]|0;h=q+8279129|0;a[n]=a[h]|0;a[h]=p;p=q+2|0;if((p|0)<2097152){q=p}else{v=0;break}}while(1){q=v+11424856|0;k=a[q]|0;p=v+11424857|0;a[q]=a[p]|0;a[p]=k;k=v+2|0;if((k|0)<262144){v=k}else{w=0;break}}do{c[1161464+(w*20|0)>>2]=(w<<16)+8279128;w=w+1|0;}while((w|0)<32);a[12473444]=a[12473444]|8}}while(0);aIv(12473448,0,56);w=b[481325]|0;v=b[481326]|0;u=0;while(1){if(w<<16>>16==(b[2680+(u<<6)>>1]|0)){if(v<<16>>16==(b[2682+(u<<6)>>1]|0)){m=11780;break}}t=u+1|0;if((t|0)<54){u=t}else{break}}L15962:do{if((m|0)==11780){w=a[2684+(u<<6)|0]|0;t=w&255;o=2688+(u<<6)|0;aIy(12473448,o|0,56)|0;o=a[2685+(u<<6)|0]|0;if((w&255)>(o&255)){break}w=c[3118374]|0;s=c[3118375]|0;r=(s|0)==0;f=o&255;if((w|0)==0){if(r){break}else{x=t}while(1){c[1161476+(x*20|0)>>2]=s;c[1161480+(x*20|0)>>2]=s;c[744996+(x<<3)>>2]=s;x=x+1|0;if((x|0)>(f|0)){break L15962}}}if(r){o=t;do{c[1161468+(o*20|0)>>2]=w;c[1161472+(o*20|0)>>2]=w;c[744992+(o<<3)>>2]=w;o=o+1|0;}while((o|0)<=(f|0))}else{o=t;do{c[1161468+(o*20|0)>>2]=w;c[1161472+(o*20|0)>>2]=w;c[744992+(o<<3)>>2]=w;c[1161476+(o*20|0)>>2]=s;c[1161480+(o*20|0)>>2]=s;c[744996+(o<<3)>>2]=s;o=o+1|0;}while((o|0)<=(f|0))}}}while(0);if((b[6236742]|0)!=0){aIy(11424856,2503768,8192)|0;aIy(11433048,2503768,8192)|0;aIy(11441240,2503768,8192)|0;aIy(11449432,2503768,8192)|0;aIy(11457624,2503768,8192)|0;aIy(11465816,2503768,8192)|0;aIy(11474008,2503768,8192)|0;aIy(11482200,2503768,8192)|0;x=0;do{c[1161464+(x*20|0)>>2]=11424856;x=x+1|0;}while((x|0)<64)}if((bx(962532,691008)|0)!=0){b[6236743]=1;c[3118373]=14;i=e;return}L15985:do{if((bx(962636,730248)|0)==0){do{if((bx(962632,702168)|0)!=0){if((bx(962636,698768)|0)!=0){c[290369]=260;c[290370]=260;c[186249]=260;c[3118373]=278;i=e;return}if((bx(962636,724568)|0)!=0){c[290369]=308;c[290370]=308;c[186249]=308;c[3118373]=278;i=e;return}if((bx(962636,697160)|0)==0){break}c[290369]=316;c[290370]=316;c[186249]=316;c[3118372]=120;c[3118373]=278;x=0;do{c[1161464+(x*20|0)>>2]=1987672+(x<<16&196608);x=x+1|0;}while((x|0)<32);x=c[234374]|0;u=32;while(1){c[1161464+(u*20|0)>>2]=x;c[1161468+(u*20|0)>>2]=100;c[1161472+(u*20|0)>>2]=92;c[1161476+(u*20|0)>>2]=278;c[1161480+(u*20|0)>>2]=84;c[744992+(u<<3)>>2]=100;c[744996+(u<<3)>>2]=268;m=u+1|0;if((m|0)<48){u=m}else{y=48;break}}while(1){c[1161468+(y*20|0)>>2]=100;c[1161472+(y*20|0)>>2]=92;c[1161476+(y*20|0)>>2]=278;c[1161480+(y*20|0)>>2]=84;c[744992+(y<<3)>>2]=100;c[744996+(y<<3)>>2]=268;y=y+1|0;if((y|0)>=64){break L15985}}}}while(0);do{if((b[993840]|0)==24576){if(!((b[993841]|0)==502&v<<16>>16==-1900)){break}c[290406]=1987672;c[290411]=2053208;c[290416]=2118744;c[290421]=2184280;c[290426]=2249816;c[290431]=2315352;c[290436]=2380888;c[290441]=2446424;u=16;while(1){c[1161468+(u*20|0)>>2]=100;c[1161472+(u*20|0)>>2]=92;c[1161476+(u*20|0)>>2]=278;c[1161480+(u*20|0)>>2]=84;c[744992+(u<<3)>>2]=100;c[744996+(u<<3)>>2]=268;x=u+1|0;if((x|0)<64){u=x}else{z=96;break}}while(1){c[1161464+(z*20|0)>>2]=2970712;u=(z&4)>>>0<4?0:70;c[1161468+(z*20|0)>>2]=u;c[1161472+(z*20|0)>>2]=u;c[1161476+(z*20|0)>>2]=12;c[1161480+(z*20|0)>>2]=12;c[744992+(z<<3)>>2]=u;c[744996+(z<<3)>>2]=12;z=z+1|0;if((z|0)>=112){break L15985}}}}while(0);if((c[3118359]|0)>>>0>4194304){A=64}else{break}do{c[1161464+(A*20|0)>>2]=1987672+(A<<16);c[1161468+(A*20|0)>>2]=0;c[1161472+(A*20|0)>>2]=0;c[744992+(A<<3)>>2]=0;A=A+1|0;}while((A|0)<160)}else{b[6236743]=1;c[290372]=106;c[186250]=106;c[3118373]=226;c[3118372]=142;aIv(937528,0,12);a[937530]=1;c[234385]=1;a[937482]=2;a[937481]=1}}while(0);if((c[3118373]|0)!=0){i=e;return}c[3118373]=138;i=e;return}function mV(a){a=a|0;return(c[290366]|0)-1987672>>18<<4|0}function mW(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=f&255;if((h|0)==3){f=g<<19&7864320;c[290566]=1987672+f;c[290571]=1987672+(f|65536);c[290576]=1987672+(f|131072);c[290581]=1987672+(f|196608);c[290586]=1987672+(f|262144);c[290591]=1987672+(f|327680);c[290596]=1987672+(f|393216);c[290601]=1987672+(f|458752);return}else if((h|0)==5){f=g<<19&7864320;c[290606]=1987672+f;c[290611]=1987672+(f|65536);c[290616]=1987672+(f|131072);c[290621]=1987672+(f|196608);c[290626]=1987672+(f|262144);c[290631]=1987672+(f|327680);c[290636]=1987672+(f|393216);c[290641]=1987672+(f|458752);return}else if((h|0)==7){f=g<<19&7864320;c[290646]=1987672+f;c[290651]=1987672+(f|65536);c[290656]=1987672+(f|131072);c[290661]=1987672+(f|196608);c[290666]=1987672+(f|262144);c[290671]=1987672+(f|327680);c[290676]=1987672+(f|393216);c[290681]=1987672+(f|458752);return}else if((h|0)==9){h=g&255;L16032:do{if((g&4|0)!=0){if((g&8|0)!=0){c[234384]=0;a[937530]=1;a[937532]=0;c[234385]=1;break}f=c[234385]|0;if((f|0)==2){if((g&2|0)==0|(a[937529]|0)!=0){break}i=e[468767]|g&1;j=i&65535;b[468767]=j;k=(c[234384]|0)+1|0;c[234384]=k;if((k|0)!=16){b[468767]=j<<1;break}c[234384]=0;if((a[937532]&1)==0){a[937533]=0;c[234385]=3;break}else{a[937533]=a[(c[234374]|0)+i|0]|0;c[234385]=4;break}}else if((f|0)==4){if((g&2|0)==0|(a[937529]|0)!=0){break}i=c[234384]|0;a[937530]=(d[937533]|0)>>>((7-i|0)>>>0)&1;j=i+1|0;c[234384]=j;if((j|0)!=8){break}c[234384]=0;if((a[937532]|0)!=3){break}j=(e[468767]|0)+1|0;b[468767]=j&65535;a[937533]=a[(c[234374]|0)+(j&65535)|0]|0;break}else if((f|0)==1){if((g&2|0)==0|(a[937529]|0)!=0){break}j=a[937532]|h&1;a[937532]=j;i=(c[234384]|0)+1|0;c[234384]=i;if((i|0)!=8){a[937532]=j<<1;break}c[234384]=0;switch(j&255|0){case 3:{b[468767]=0;c[234385]=2;break L16032;break};case 4:{a[937531]=a[937531]&-3;c[234385]=0;break L16032;break};case 6:{a[937531]=a[937531]|2;c[234385]=0;break L16032;break};case 2:{b[468767]=0;c[234385]=2;break L16032;break};case 5:{a[937533]=a[937531]|0;c[234385]=4;break L16032;break};case 1:{a[937533]=0;c[234385]=3;break L16032;break};default:{c[234385]=0;break L16032}}}else if((f|0)==3){if((g&2|0)==0|(a[937529]|0)!=0){break}f=a[937533]|0;j=f|h&1;a[937533]=j;i=(c[234384]|0)+1|0;c[234384]=i;if((i|0)!=8){a[937533]=j<<1;break}c[234384]=0;i=d[937531]|0;k=i&2;if((a[937532]&1)!=0){a[937531]=(k|f&12)&255;c[234385]=0;break}do{if((k|0)!=0){f=i>>>2&3;if((f|0)==3){break}else if((f|0)==1){l=b[468767]|0;if((l&65535)>=49152){break}a[(c[234374]|0)+(l&65535)|0]=j;break}else if((f|0)==2){f=b[468767]|0;if(f<<16>>16<=-1){break}a[(c[234374]|0)+(f&65535)|0]=j;break}else{a[(c[234374]|0)+(e[468767]|0)|0]=j;break}}}while(0);a[937533]=0;j=b[468767]|0;b[468767]=j+1&127|j&-128;break}else{break}}}while(0);a[937528]=(h&255)>>>3&1;a[937529]=(h&255)>>>1&1;return}else{return}}function mX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((a&3840|0)!=3584){return}L16087:do{if((b&64|0)==0){if((b&128|0)==0){a=0;while(1){c[1161464+(a*20|0)>>2]=1987672+(a<<16);c[1161468+(a*20|0)>>2]=0;c[1161472+(a*20|0)>>2]=0;d=(a|0)>0;e=d?278:260;c[1161476+(a*20|0)>>2]=e;c[1161480+(a*20|0)>>2]=d?84:260;c[744992+(a<<3)>>2]=0;c[744996+(a<<3)>>2]=e;a=a+1|0;if((a|0)>=64){break L16087}}}c[290366]=5657688;c[290367]=0;c[290368]=0;c[186248]=0;c[290371]=5723224;c[290372]=0;c[290373]=0;c[186250]=0;c[290376]=5788760;c[290377]=0;c[290378]=0;c[186252]=0;c[290381]=5854296;c[290382]=0;c[290383]=0;c[186254]=0;a=c[234371]|0;if(a>>>0>327679){e=a>>>16;a=4;do{c[1161464+(a*20|0)>>2]=1987672+(a<<16);c[1161468+(a*20|0)>>2]=0;c[1161472+(a*20|0)>>2]=0;c[744992+(a<<3)>>2]=0;a=a+1|0;}while(a>>>0<e>>>0);a=e>>>0>5?e:5;if(a>>>0<64){f=a}else{break}}else{f=4}a=c[234374]|0;d=f;do{c[1161464+(d*20|0)>>2]=a;c[1161468+(d*20|0)>>2]=76;c[1161472+(d*20|0)>>2]=176;c[1161476+(d*20|0)>>2]=130;c[1161480+(d*20|0)>>2]=124;c[744992+(d<<3)>>2]=76;c[744996+(d<<3)>>2]=130;d=d+1|0;}while((d|0)<64)}else{d=0;do{c[1161464+(d*20|0)>>2]=1987672+(d<<16);c[1161468+(d*20|0)>>2]=100;c[1161472+(d*20|0)>>2]=92;a=(d|0)>0;e=a?278:260;c[1161476+(d*20|0)>>2]=e;c[1161480+(d*20|0)>>2]=a?84:260;c[744992+(d<<3)>>2]=158;c[744996+(d<<3)>>2]=e;d=d+1|0;}while((d|0)<64)}}while(0);if((b&32|0)==0){return}c[290369]=278;c[290370]=84;c[186249]=278;return}function mY(a,b){a=a|0;b=b|0;if((b&128|0)==0){b=32;do{c[1161464+(b*20|0)>>2]=1987672+(b<<16);b=b+1|0;}while((b|0)<60);return}else{b=32;do{c[1161464+(b*20|0)>>2]=1987672+(b<<16&2031616);b=b+1|0;}while((b|0)<60);return}}function mZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=a>>>8&15;if((d|0)==13){if((b&128|0)==0){a=32;do{c[1161468+(a*20|0)>>2]=100;c[1161472+(a*20|0)>>2]=92;c[1161476+(a*20|0)>>2]=278;c[1161480+(a*20|0)>>2]=84;c[744992+(a<<3)>>2]=100;c[744996+(a<<3)>>2]=278;a=a+1|0;}while((a|0)<48);return}else{a=32;do{c[1161468+(a*20|0)>>2]=76;c[1161472+(a*20|0)>>2]=176;c[1161476+(a*20|0)>>2]=130;c[1161480+(a*20|0)>>2]=124;c[744992+(a<<3)>>2]=76;c[744996+(a<<3)>>2]=130;a=a+1|0;}while((a|0)<48);return}}else if((d|0)==15){a=b>>>4<<2;if((c[290366]|0)!=(c[290386]|0)){e=0;do{c[1161464+(e*20|0)>>2]=1987672+(e+a<<16&2031616);e=e+1|0;}while((e|0)<20);return}e=a&28;a=0;do{c[1161464+(a*20|0)>>2]=1987672+((a&3|e)<<16);a=a+1|0;}while((a|0)<32);return}else if((d|0)==14){L16137:do{if((b&32|0)==0){if((b&64|0)==0){d=0;while(1){c[1161464+(d*20|0)>>2]=(c[290366]|0)+(d<<16&196608);c[1161468+(d*20|0)>>2]=0;c[1161472+(d*20|0)>>2]=0;c[744992+(d<<3)>>2]=0;d=d+1|0;if((d|0)>=32){break L16137}}}d=(c[290366]|0)+(-1987672|0)|0;a=0;do{c[1161464+(a*20|0)>>2]=1987672+(d+(a<<16)&2031616);c[1161468+(a*20|0)>>2]=0;c[1161472+(a*20|0)>>2]=0;c[744992+(a<<3)>>2]=0;a=a+1|0;}while((a|0)<20);c[290467]=100;c[290468]=92;c[186288]=100;c[290472]=100;c[290473]=92;c[186290]=100;c[290477]=100;c[290478]=92;c[186292]=100;c[290482]=100;c[290483]=92;c[186294]=100;c[290487]=100;c[290488]=92;c[186296]=100;c[290492]=100;c[290493]=92;c[186298]=100;c[290497]=100;c[290498]=92;c[186300]=100;c[290502]=100;c[290503]=92;c[186302]=100;c[290507]=100;c[290508]=92;c[186304]=100;c[290512]=100;c[290513]=92;c[186306]=100;c[290517]=100;c[290518]=92;c[186308]=100;c[290522]=100;c[290523]=92;c[186310]=100}else{a=0;do{c[1161468+(a*20|0)>>2]=100;c[1161472+(a*20|0)>>2]=92;c[744992+(a<<3)>>2]=100;a=a+1|0;}while((a|0)<32)}}while(0);if((b&128|0)!=0){return}c[290369]=278;c[290370]=84;c[186249]=278;return}else{return}}function m_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=b>>>16&3;if((e|0)==2){f=11920}else if((e|0)!=3){g=0;return g|0}L16156:do{if((f|0)==11920){switch(b>>>1&7|0){case 2:{g=d[(c[234374]|0)+7|0]|0;return g|0};case 0:{g=d[(c[234374]|0)+6|0]|0;return g|0};case 3:{g=(d[(c[234374]|0)+7|0]|0)+1|0;return g|0};case 7:{g=(d[(c[234374]|0)+8|0]|0)+3|0;return g|0};case 4:{g=d[(c[234374]|0)+8|0]|0;return g|0};case 6:{g=(d[(c[234374]|0)+8|0]|0)+2|0;return g|0};case 5:{g=(d[(c[234374]|0)+8|0]|0)+1|0;return g|0};case 1:{g=(d[(c[234374]|0)+6|0]|0)+1|0;return g|0};default:{break L16156}}}}while(0);f=c[234374]|0;do{if((a[f+2|0]|0)<0){e=a[f+3|0]|0;if((a[f+5|0]&64)==0){h=~e;break}else{h=a[f+4|0]&e;break}}else{h=0}}while(0);do{if((b&2|0)==0){e=d[f+5|0]|0;if((e&128|0)==0){i=h;break}if((e&32|0)==0){a[f+6|0]=a[f+3|0]<<1^a[f+1|0]&-2;i=h;break}else{a[f+8|0]=a[f+4|0]<<2;i=h;break}}else{i=h&127}}while(0);g=i&255;return g|0}function m$(b,c){b=b|0;c=c|0;var e=0;e=b&14;if((e|0)==0){a[12473448]=0;return}else if((e|0)==2|(e|0)==12|(e|0)==14){return}else{if((c&1|0)==0){return}a[12473448]=(d[12473448]|0|1<<((b+4|0)>>>1&3))&255;return}}function m0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b>>>16&7;if((e|0)==7){if((b&2|0)!=0){return}a[(c[234374]|0)+5|0]=d&255;if((a[(c[234374]|0)+2|0]|0)>=0){return}f=1987672+(d<<14&458752|524288)|0;c[290886]=f;c[290846]=f;return}else if((e|0)==0){if((b&2|0)==0){a[c[234374]|0]=d&255;return}f=c[234374]|0;g=a[f]&7;if((g|0)==7){h=1987672+(d<<14&458752|524288)|0;c[290891]=h;c[290851]=h}else if((g|0)==1){a[f+7|0]=d&255&-2}else if((g|0)==0){g=f+6|0;a[g]=((a[f+1|0]^a[g])&255^d)&255&-2}a[(c[234374]|0)+1|0]=d&255;return}else if((e|0)==1){if((b&2|0)==0){return}a[(c[234374]|0)+2|0]=d&255;return}else if((e|0)==4){e=d&255;d=c[234374]|0;if((b&2|0)==0){a[d+3|0]=e;return}else{a[d+4|0]=e;return}}else{return}}function m1(b,d){b=b|0;d=d|0;var e=0,f=0;if(b>>>0<10563648){e=b;b=0;while(1){c[1161464+(b*20|0)>>2]=1987672+(e<<16&4128768);f=b+1|0;if((f|0)<64){e=e+1|0;b=f}else{break}}return}if((d&1|0)==0){b=c[3118360]|0;e=32;do{c[1161464+(e*20|0)>>2]=1987672+(e<<16&b);c[1161468+(e*20|0)>>2]=0;c[1161472+(e*20|0)>>2]=0;c[744992+(e<<3)>>2]=0;c[1161476+(e*20|0)>>2]=278;c[1161480+(e*20|0)>>2]=84;c[744996+(e<<3)>>2]=268;e=e+1|0;}while((e|0)<64);return}do{if((a[937481]|0)!=0){c[290526]=c[234374];c[290527]=76;c[290528]=176;c[186312]=76;if((d&2|0)==0){c[290529]=130;c[290530]=124;c[186313]=130;break}else{c[290529]=278;c[290530]=84;c[186313]=268;break}}}while(0);if(!((a[12473444]&8)!=0&(a[12474173]|0)==3)){return}c[290606]=11424856;c[290611]=11490392;c[290616]=11555928;c[290621]=11621464;c[290626]=11424856;c[290631]=11490392;c[290636]=11555928;c[290641]=11621464;c[290646]=11424856;c[290651]=11490392;c[290656]=11555928;c[290661]=11621464;c[290666]=11424856;c[290671]=11490392;c[290676]=11555928;c[290681]=11621464;return}function m2(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;if((b|0)==4202496){a[12473450]=e<<1&255;return}else if((b|0)==4194304){f=e&6;a[12473449]=f;g=a[12473450]|0;if(g<<24>>24==0){return}h=(d[12473448]|0)<<1|(f&255)<<3;f=g&255;g=0;do{c[1161464+(g*20|0)>>2]=1987672+(((g|0)%(f|0)|0)+h<<16);g=g+1|0;}while((g|0)<64);return}else if((b|0)==4210688){a[12473448]=e&7;return}else{return}}function m3(a){a=a|0;var b=0,d=0;b=a>>>1;a=0;while(1){c[1161464+(a*20|0)>>2]=1987672+(b<<16&4128768);d=a+1|0;if((d|0)<64){b=b+1|0;a=d}else{break}}return 65535}function m4(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=0;while(1){if((d|0)>=4){e=12022;break}if((c[12473452+(d<<2)>>2]&b|0)==(c[12473468+(d<<2)>>2]|0)){e=12021;break}else{d=d+1|0}}if((e|0)==12021){f=12473448+d|0;g=a[f]|0;h=g&255;return h|0}else if((e|0)==12022){e=c[291667]|0;f=(c[1161464+((e>>>16&255)*20|0)>>2]|0)+((e&65535|b&1)^1)|0;g=a[f]|0;h=g&255;return h|0}return 0}function m5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if(b>>>0>6291455){if((d|0)==0){e=2970712;f=2905176;g=2839640;h=2774104;i=2708568;j=2643032;k=2577496;l=2511960;m=2446424;n=2380888;o=2315352;p=2249816;q=2184280;r=2118744;s=2053208;t=1987672}else{u=1987672+(d<<16&983040)|0;e=u;f=u;g=u;h=u;i=u;j=u;k=u;l=u;m=u;n=u;o=u;p=u;q=u;r=u;s=u;t=u}c[290366]=t;c[290371]=s;c[290376]=r;c[290381]=q;c[290386]=p;c[290391]=o;c[290396]=n;c[290401]=m;c[290406]=l;c[290411]=k;c[290416]=j;c[290421]=i;c[290426]=h;c[290431]=g;c[290436]=f;c[290441]=e;return}else{v=0}while(1){if((v|0)>=4){w=12035;break}if((c[12473452+(v<<2)>>2]&b|0)==(c[12473468+(v<<2)>>2]|0)){break}else{v=v+1|0}}if((w|0)==12035){return}a[12473448+v|0]=d&255;return}function m6(a){a=a|0;var b=0;if((a&14|0)==2){b=(d[12473448]|0)-1|0;return b|0}else{a=c[291667]|0;b=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;return b|0}return 0}function m7(b,d){b=b|0;d=d|0;var e=0,f=0;e=0;while(1){if((e|0)>=4){f=12048;break}if((c[12473452+(e<<2)>>2]&b|0)==(c[12473468+(e<<2)>>2]|0)){break}else{e=e+1|0}}if((f|0)==12048){return}a[12473448+e|0]=d&255;return}function m8(a){a=a|0;var b=0,f=0,g=0;b=0;while(1){if((b|0)>=4){f=12054;break}if((c[12473452+(b<<2)>>2]&a|0)==(c[12473468+(b<<2)>>2]|0)){f=12053;break}else{b=b+1|0}}if((f|0)==12054){a=c[291667]|0;g=e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;return g|0}else if((f|0)==12053){g=(d[12473448+b|0]|0)<<8;return g|0}return 0}function m9(a){a=a|0;var b=0,e=0,f=0;b=0;while(1){if((b|0)>=4){e=12062;break}if((c[12473452+(b<<2)>>2]&a|0)==(c[12473468+(b<<2)>>2]|0)){e=12061;break}else{b=b+1|0}}if((e|0)==12061){f=(d[12473448+b|0]|0)>>>1;return f|0}else if((e|0)==12062){e=c[291667]|0;f=d[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+((e&65535|a&1)^1)|0]|0;return f|0}return 0}function na(a,b){a=a|0;b=b|0;if((a&255|0)!=241){return}if((b&1|0)==0){b=0;do{c[1161476+(b*20|0)>>2]=0;c[1161480+(b*20|0)>>2]=0;c[744996+(b<<3)>>2]=0;b=b+1|0;}while((b|0)<64);return}else{b=0;do{c[1161476+(b*20|0)>>2]=278;c[1161480+(b*20|0)>>2]=84;c[744996+(b<<3)>>2]=268;b=b+1|0;}while((b|0)<64);return}}function nb(d){d=d|0;var e=0,f=0,g=0,h=0;L16341:do{if(d>>>0<2105344){switch(d&255|0){case 73:{e=b[846136]|0;f=(e&4)==0?-1:-4;if((e&32)==0){g=f;break L16341}g=f&-2;break L16341;break};case 69:{f=b[846136]|0;e=(f&1)==0?-1:-9;if((f&2)==0){g=e;break L16341}g=e&-17;break L16341;break};case 67:{e=b[846136]|0;f=(e&64)==0?-1:127;h=(e&16)==0?f:f&-17;g=(e&128)==0?h:h&-33;break L16341;break};case 81:{g=-91;break L16341;break};case 71:{g=(b[846136]&8)==0?-1:-4;break L16341;break};default:{h=c[291667]|0;g=a[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+((h&65535|d&1)^1)|0]|0;break L16341}}}else{g=a[(c[234374]|0)+(d&65535^1)|0]|0}}while(0);return g&255|0}function nc(b,d){b=b|0;d=d|0;if(b>>>0<=2105343){return}a[(c[234374]|0)+(b&65535^1)|0]=d&255;return}function nd(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=0;while(1){f=e+1|0;g=a[b+e|0]|0;h=g&255;if(g<<24>>24==-1){c[1161464+(e*20|0)>>2]=c[234374];c[1161468+(e*20|0)>>2]=76;c[1161472+(e*20|0)>>2]=176;c[1161476+(e*20|0)>>2]=130;c[1161480+(e*20|0)>>2]=124;c[744992+(e<<3)>>2]=76;c[744996+(e<<3)>>2]=130}else{g=1161464+(e*20|0)|0;if((c[g>>2]|0)==(c[234374]|0)){c[1161468+(e*20|0)>>2]=0;c[1161472+(e*20|0)>>2]=0;c[1161476+(e*20|0)>>2]=278;c[1161480+(e*20|0)>>2]=84;c[744992+(e<<3)>>2]=0;c[744996+(e<<3)>>2]=268}c[g>>2]=1987672+(h<<16)}if((f|0)<64){e=f}else{break}}e=b+64|0;c[3118362]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=c[234362]|0;if((e|0)==0){i=68;return i|0}f=e|0;h=b+68|0;aIy(f|0,h|0,2048)|0;h=e+131072|0;f=b+2116|0;aIy(h|0,f|0,131072)|0;f=e+262144|0;e=b+133188|0;aIy(f|0,e|0,1280)|0;i=134468;return i|0}function ne(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(b>>>0>7340031){if((d|0)==0){c[290366]=1987672;c[290371]=2053208;c[290376]=2118744;c[290381]=2184280;c[290386]=2249816;c[290391]=2315352;c[290396]=2380888;c[290401]=2446424;c[290406]=2511960;c[290411]=2577496;c[290416]=2643032;c[290421]=2708568;c[290426]=2774104;c[290431]=2839640;c[290436]=2905176;c[290441]=2970712;return}e=d<<15;f=e&2064384;g=e&2031616;e=0;do{h=e<<16;i=h+6181976|0;c[1161464+(e*20|0)>>2]=i;j=1987672+(h|f)|0;aIy(i|0,j|0,32768)|0;j=h+6214744|0;i=1987672+(g|h|32768)|0;aIy(j|0,i|0,32768)|0;e=e+1|0;}while((e|0)<16);return}else{k=0}while(1){if((k|0)>=4){break}if((c[12473452+(k<<2)>>2]&b|0)==(c[12473468+(k<<2)>>2]|0)){l=12109;break}else{k=k+1|0}}if((l|0)==12109){a[12473448+k|0]=d&255}d=a[12473448]|0;k=a[12473449]&3;if((k|0)==0){a[12473450]=d<<1;return}else if((k|0)==2){a[12473450]=(d&255)>>>4|d<<4;return}else if((k|0)==1){a[12473450]=(d&255)>>>1;return}else{a[12473450]=d<<7|(d&255)>>>7|(d&255)>>>5&2|(d&255)>>>3&4|(d&255)>>>1&8|d<<1&16|d<<3&32|d<<5&64;return}}function nf(b){b=b|0;return a[(c[747336+(b>>>10<<2)>>2]|0)+(b&1023)|0]|0}function ng(b,d){b=b|0;d=d|0;a[(c[747064+(b>>>10<<2)>>2]|0)+(b&1023)|0]=d;return}function nh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[3118359]|0;if((b|0)==0){e=0}else{f=b;g=1987672;h=-1;while(1){i=f-1|0;j=d[g]|0;k=c[684280+(((j^h)&15)<<2)>>2]^h>>>4;l=k>>>4^c[684280+((k&15^j>>>4)<<2)>>2];if((i|0)==0){break}else{f=i;g=g+1|0;h=l}}e=~l}aIv(7296088,-1|0,2048);l=b>>>0>49152?16:0;a[12474460]=l;a[12473444]=0;h=a[12474148]|0;do{if((h&2)==0){m=h}else{if((a[937424]&32)!=0&(a[9808]|0)==0){a[12474148]=3;m=3;break}else{a[12474148]=2;m=2;break}}}while(0);h=a[12474166]|0;L16412:do{if((h<<24>>24|0)==0){g=0;while(1){if((c[672536+(g*12|0)>>2]|0)==(e|0)){break}f=g+1|0;if((f|0)<211){g=f}else{n=7;o=l;p=0;break L16412}}f=a[672543+(g*12|0)|0]|0;a[12474460]=f;i=a[672542+(g*12|0)|0]|0;j=a[672540+(g*12|0)|0]|0;a[12473444]=j;a[937424]=a[672544+(g*12|0)|0]|0;if((m&2)==0){n=i;o=f;p=j;break}a[12474148]=a[672541+(g*12|0)|0]|m;n=i;o=f;p=j}else if((h<<24>>24|0)==64){j=0;while(1){if((c[672536+(j*12|0)>>2]|0)==(e|0)){break}f=j+1|0;if((f|0)<211){j=f}else{n=7;o=l;p=0;break L16412}}g=a[672543+(j*12|0)|0]|0;a[12474460]=g;f=a[672542+(j*12|0)|0]|0;i=a[672540+(j*12|0)|0]|0;a[12473444]=i;if((a[672544+(j*12|0)|0]|0)==65){a[937424]=65}if((m&2)==0){n=f;o=g;p=i;break}a[12474148]=a[672541+(j*12|0)|0]|m;n=f;o=g;p=i}else{i=0;while(1){if((c[672536+(i*12|0)>>2]|0)==(e|0)){break}g=i+1|0;if((g|0)<211){i=g}else{n=7;o=l;p=0;break L16412}}j=a[672543+(i*12|0)|0]|0;a[12474460]=j;g=a[672542+(i*12|0)|0]|0;f=a[672540+(i*12|0)|0]|0;a[12473444]=f;if((m&2)==0){n=g;o=j;p=f;break}a[12474148]=a[672541+(i*12|0)|0]|m;n=g;o=j;p=f}}while(0);do{if((o&255)<16){a[12474461]=(b+1023|0)>>>10&255}else{if((o&32)==0){a[12474461]=(b+16383|0)>>>14&255;break}else{a[12474461]=(b+8191|0)>>>13&255;break}}}while(0);if((o<<24>>24|0)==18){aIv(12473680,0,12);a[12473683]=1;c[3118423]=1;a[937482]=3}else if((o<<24>>24|0)==1){a[12473444]=p|2}nN();a[937481]=1;if((c[2784]|0)==-1){c[2784]=d[1692304]|0}if((c[2782]|0)==-1){c[2782]=d[1692296]|0}a[1692304]=n;a[1692296]=7;c[423058]=20;c[423056]=0;if((e|0)==1606896938|(e|0)==1398371885){c[423058]=16}if((a[12474172]&1)==0){a[937440]=a[937440]&-97;a[13787389]=0;return}e=kO()|0;do{if((e|0)>49152){a[13787388]=16;n=e>>>14&255;a[13787389]=n;q=n}else{if((e|0)>-1){a[13787388]=0;n=e>>>10&255;a[13787389]=n;q=n;break}else{q=a[13787389]|0;break}}}while(0);if((a[12474172]&2)!=0|q<<24>>24==0){return}a[12474461]=0;return}function ni(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[937424]|0)==16){if((a[12474460]|0)==3){b=48;do{e=756920+(b<<10&7168)|0;c[747064+(b<<2)>>2]=e;c[747336+(b<<2)>>2]=e;b=b+1|0;}while((b|0)<64)}else{b=48;do{e=756920+(b<<10&1024)|0;c[747064+(b<<2)>>2]=e;c[747336+(b<<2)>>2]=e;b=b+1|0;}while((b|0)<64)}}else{b=48;do{e=756920+(b<<10&7168)|0;c[747064+(b<<2)>>2]=e;c[747336+(b<<2)>>2]=e;b=b+1|0;}while((b|0)<64)}b=a[943736]|0;if(b<<24>>24==0){e=0;do{c[747064+(e<<2)>>2]=7296088;c[747336+(e<<2)>>2]=7297112;e=e+1|0;}while((e|0)<48);c[186832]=146;c[186764]=186;return}e=a[943744]|0;f=c[235940]|0;do{if((e&255)<16){g=0;do{c[747336+(g<<2)>>2]=f+(g<<10);c[747064+(g<<2)>>2]=7296088;g=g+1|0;}while((g|0)<48);if((b&255)<33){g=32;do{h=756920+(g<<10&7168|8192)|0;c[747064+(g<<2)>>2]=h;c[747336+(g<<2)>>2]=h;g=g+1|0;}while((g|0)<48)}if(e<<24>>24!=2){i=e;break}c[186774]=765112;c[186842]=765112;c[186775]=766136;c[186843]=766136;c[186776]=767160;c[186844]=767160;c[186777]=768184;c[186845]=768184;c[186778]=769208;c[186846]=769208;c[186779]=770232;c[186847]=770232;c[186780]=771256;c[186848]=771256;c[186781]=772280;c[186849]=772280;i=2}else{g=0;do{c[747336+(g<<2)>>2]=f+(g<<10);c[747064+(g<<2)>>2]=7296088;g=g+1|0;}while((g|0)<48);g=c[235938]|0;h=a[g]|0;if((e&32)==0){nk(0,h&255);nk(1,d[g+1|0]|0);nk(2,d[g+2|0]|0);nk(3,d[g+3|0]|0);i=e;break}a[g]=h;j=(((h&255)%(b&255)|0)&255)<<13;c[186866]=f+j;c[186867]=f+(j|1024);c[186868]=f+(j|2048);c[186869]=f+(j|3072);c[186870]=f+(j|4096);c[186871]=f+(j|5120);c[186872]=f+(j|6144);c[186873]=f+(j|7168);j=(((d[g+1|0]|0)%(b&255)|0)&255)<<13;c[186874]=f+j;c[186875]=f+(j|1024);c[186876]=f+(j|2048);c[186877]=f+(j|3072);c[186878]=f+(j|4096);c[186879]=f+(j|5120);c[186880]=f+(j|6144);c[186881]=f+(j|7168);j=(((d[g+2|0]|0)%(b&255)|0)&255)<<13;c[186850]=f+j;c[186851]=f+(j|1024);c[186852]=f+(j|2048);c[186853]=f+(j|3072);c[186854]=f+(j|4096);c[186855]=f+(j|5120);c[186856]=f+(j|6144);c[186857]=f+(j|7168);j=(((d[g+3|0]|0)%(b&255)|0)&255)<<13;c[186858]=f+j;c[186859]=f+(j|1024);c[186860]=f+(j|2048);c[186861]=f+(j|3072);c[186862]=f+(j|4096);c[186863]=f+(j|5120);c[186864]=f+(j|6144);c[186865]=f+(j|7168);if(e<<24>>24!=34){i=e;break}c[186834]=f+122880;c[186835]=f+123904;c[186836]=f+124928;c[186837]=f+125952;c[186838]=f+126976;c[186839]=f+128e3;c[186840]=f+129024;c[186841]=f+130048;i=34}}while(0);switch(i&255|0){case 1:{c[186832]=116;c[186764]=152;return};case 18:{c[186832]=8;c[186764]=74;return};case 32:{c[186832]=160;c[186764]=208;return};case 20:{c[186832]=146;c[186764]=176;return};case 22:{c[186832]=146;c[186764]=52;return};case 0:case 2:case 3:{c[186832]=146;c[186764]=186;return};case 19:{c[186832]=146;c[186764]=110;return};case 21:{c[186832]=146;c[186764]=304;return};case 33:case 34:{c[186832]=146;c[186764]=320;return};default:{c[186832]=146;c[186764]=46;return}}}function nj(b){b=b|0;var d=0,e=0;a[943736]=0;d=b&255;L16523:do{if((d&64|0)==0){b=a[13787389]|0;do{if((d&8|0)!=0){if((b&255)>1){c[235940]=6181976;c[235938]=13787384;a[943744]=a[13787388]|0;a[943736]=b;break L16523}else{c[235940]=1987672;c[235938]=12474456;a[943744]=a[12474460]|0;a[943736]=a[12474461]|0;break}}}while(0);e=c[3118359]|0;if(!(b<<24>>24==0&e>>>0<1048577)){break}aIy(6181976,1987672,e)|0;c[3446846]=c[3118614];a[13787388]=a[12474460]|0;a[13787389]=a[12474461]|0;a[12474461]=0}else{e=a[12474461]|0;if(e<<24>>24==0){break}c[235940]=1987672;c[235938]=12474456;a[943744]=a[12474460]|0;a[943736]=e}}while(0);ni();if((a[13787389]|0)!=1){return}if((d&72|0)!=8){return}c[186834]=6181976;return}function nk(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=a[943736]|0;g=f&255;h=(e>>>0)%(g>>>0)|0;i=c[235938]|0;j=a[i]&3;k=a[943744]|0;l=k<<24>>24==16;if((j|0)!=0&l){m=((((4-j<<3)+h|0)>>>0)%(g>>>0)|0)&255}else{m=h&255}a[i+b|0]=e&255;if((b|0)==3){if((a[i]&8)!=0){return}h=(m&255)<<14;j=c[235940]|0;c[186866]=j+h;c[186867]=j+(h|1024);c[186868]=j+(h|2048);c[186869]=j+(h|3072);c[186870]=j+(h|4096);c[186871]=j+(h|5120);c[186872]=j+(h|6144);c[186873]=j+(h|7168);do{if(k<<24>>24==19){if((a[i+2|0]|0)>=0){break}return}}while(0);c[186874]=j+(h|8192);c[186875]=j+(h|9216);c[186876]=j+(h|10240);c[186877]=j+(h|11264);c[186878]=j+(h|12288);c[186879]=j+(h|13312);c[186880]=j+(h|14336);c[186881]=j+(h|15360);return}else if((b|0)==2){h=(m&255)<<14;j=c[235940]|0;c[186850]=j+h;c[186851]=j+(h|1024);c[186852]=j+(h|2048);c[186853]=j+(h|3072);c[186854]=j+(h|4096);c[186855]=j+(h|5120);c[186856]=j+(h|6144);c[186857]=j+(h|7168);c[186858]=j+(h|8192);c[186859]=j+(h|9216);c[186860]=j+(h|10240);c[186861]=j+(h|11264);c[186862]=j+(h|12288);c[186863]=j+(h|13312);c[186864]=j+(h|14336);c[186865]=j+(h|15360);if(k<<24>>24!=19){return}if((e&128|0)==0){h=(((d[i+3|0]|0)%(f&255)|0)&255)<<14;c[186874]=j+(h|8192);c[186806]=7296088;c[186875]=j+(h|9216);c[186807]=7296088;c[186876]=j+(h|10240);c[186808]=7296088;c[186877]=j+(h|11264);c[186809]=7296088;c[186878]=j+(h|12288);c[186810]=7296088;c[186879]=j+(h|13312);c[186811]=7296088;c[186880]=j+(h|14336);c[186812]=7296088;c[186881]=j+(h|15360);c[186813]=7296088;return}else{h=c[234374]|0;j=h+8192|0;c[186806]=j;c[186874]=j;j=h+9216|0;c[186807]=j;c[186875]=j;j=h+10240|0;c[186808]=j;c[186876]=j;j=h+11264|0;c[186809]=j;c[186877]=j;j=h+12288|0;c[186810]=j;c[186878]=j;j=h+13312|0;c[186811]=j;c[186879]=j;j=h+14336|0;c[186812]=j;c[186880]=j;j=h+15360|0;c[186813]=j;c[186881]=j;return}}else if((b|0)==0){if((e&8|0)==0){j=(d[i+3|0]|0)%(f&255)|0;f=e&3;if((f|0)!=0&l){n=((((j&255)+(4-f<<3)|0)>>>0)%(g>>>0)|0)&255}else{n=j}j=(n&255)<<14;n=c[235940]|0;g=32;do{c[747336+(g<<2)>>2]=n+(g<<10&15360|j);c[747064+(g<<2)>>2]=7296088;g=g+1|0;}while((g|0)<48)}else{g=e<<12&16384;j=c[234374]|0;n=32;do{f=j+(n<<10&15360|g)|0;c[747064+(n<<2)>>2]=f;c[747336+(n<<2)>>2]=f;n=n+1|0;}while((n|0)<48)}if((e&16|0)==0){e=48;do{n=756920+(e<<10&7168)|0;c[747064+(e<<2)>>2]=n;c[747336+(e<<2)>>2]=n;e=e+1|0;}while((e|0)<64);return}e=c[234374]|0;n=48;do{g=e+(n<<10&15360)|0;c[747064+(n<<2)>>2]=g;c[747336+(n<<2)>>2]=g;n=n+1|0;}while((n|0)<64);return}else if((b|0)==1){if((k-19&255)<2){k=(m&255)<<14;b=c[235940]|0;c[186834]=b+k;o=b;p=k}else{o=c[235940]|0;p=(m&255)<<14}c[186835]=o+(p|1024);c[186836]=o+(p|2048);c[186837]=o+(p|3072);c[186838]=o+(p|4096);c[186839]=o+(p|5120);c[186840]=o+(p|6144);c[186841]=o+(p|7168);c[186842]=o+(p|8192);c[186843]=o+(p|9216);c[186844]=o+(p|10240);c[186845]=o+(p|11264);c[186846]=o+(p|12288);c[186847]=o+(p|13312);c[186848]=o+(p|14336);c[186849]=o+(p|15360);return}else{return}}function nl(b){b=b|0;var d=0,e=0,f=0;d=a[(c[747336+(b>>>10<<2)>>2]|0)+(b&1023)|0]|0;e=b>>>14&255;do{if((e|0)==2){if((a[c[235938]|0]|0)<0){break}else{f=d}return f|0}else if((e|0)==1){if((a[(c[235938]|0)+2|0]|0)<0){break}else{f=d}return f|0}else{f=d;return f|0}}while(0);f=d<<7|(d&255)>>>7|(d&255)>>>5&2|(d&255)>>>3&4|(d&255)>>>1&8|d<<1&16|d<<3&32|d<<5&64;return f|0}function nm(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((b|0)==65535){f=(e&255)<<1;g=f&254;h=d[943736]|0;i=c[235938]|0;a[i]=f&255;f=((g>>>0)%(h>>>0)|0)<<13;j=c[235940]|0;c[186866]=j+f;c[186867]=j+(f|1024);c[186868]=j+(f|2048);c[186869]=j+(f|3072);c[186870]=j+(f|4096);c[186871]=j+(f|5120);c[186872]=j+(f|6144);c[186873]=j+(f|7168);f=g|1;a[i+1|0]=f&255;i=((f>>>0)%(h>>>0)|0)<<13;c[186874]=j+i;c[186875]=j+(i|1024);c[186876]=j+(i|2048);c[186877]=j+(i|3072);c[186878]=j+(i|4096);c[186879]=j+(i|5120);c[186880]=j+(i|6144);c[186881]=j+(i|7168)}else if((b|0)==16384){i=((e&255)%(d[943736]|0)|0)&255;a[(c[235938]|0)+2|0]=e;j=i<<13;i=c[235940]|0;c[186850]=i+j;c[186851]=i+(j|1024);c[186852]=i+(j|2048);c[186853]=i+(j|3072);c[186854]=i+(j|4096);c[186855]=i+(j|5120);c[186856]=i+(j|6144);c[186857]=i+(j|7168);return}else if((b|0)==32768){j=((e&255)%(d[943736]|0)|0)&255;a[c[235938]|0]=e;i=j<<13;j=c[235940]|0;c[186866]=j+i;c[186867]=j+(i|1024);c[186868]=j+(i|2048);c[186869]=j+(i|3072);c[186870]=j+(i|4096);c[186871]=j+(i|5120);c[186872]=j+(i|6144);c[186873]=j+(i|7168);return}else if((b|0)==40960){i=((e&255)%(d[943736]|0)|0)&255;a[(c[235938]|0)+1|0]=e;j=i<<13;i=c[235940]|0;c[186874]=i+j;c[186875]=i+(j|1024);c[186876]=i+(j|2048);c[186877]=i+(j|3072);c[186878]=i+(j|4096);c[186879]=i+(j|5120);c[186880]=i+(j|6144);c[186881]=i+(j|7168);return}else if((b|0)==65534){j=(e&255)<<1;i=j&254;h=d[943736]|0;f=c[235938]|0;a[f+2|0]=j&255;j=((i>>>0)%(h>>>0)|0)<<13;g=c[235940]|0;c[186850]=g+j;c[186851]=g+(j|1024);c[186852]=g+(j|2048);c[186853]=g+(j|3072);c[186854]=g+(j|4096);c[186855]=g+(j|5120);c[186856]=g+(j|6144);c[186857]=g+(j|7168);j=i|1;a[f+3|0]=j&255;f=((j>>>0)%(h>>>0)|0)<<13;c[186858]=g+f;c[186859]=g+(f|1024);c[186860]=g+(f|2048);c[186861]=g+(f|3072);c[186862]=g+(f|4096);c[186863]=g+(f|5120);c[186864]=g+(f|6144);c[186865]=g+(f|7168)}else if((b|0)==24576){f=((e&255)%(d[943736]|0)|0)&255;a[(c[235938]|0)+3|0]=e;g=f<<13;f=c[235940]|0;c[186858]=f+g;c[186859]=f+(g|1024);c[186860]=f+(g|2048);c[186861]=f+(g|3072);c[186862]=f+(g|4096);c[186863]=f+(g|5120);c[186864]=f+(g|6144);c[186865]=f+(g|7168);return}a[(c[747064+(b>>>10<<2)>>2]|0)+(b&1023)|0]=e;return}function nn(b,e){b=b|0;e=e|0;var f=0,g=0;if(b>>>0>=4){a[(c[747064+(b>>>10<<2)>>2]|0)+(b&1023)|0]=e;return}f=((e&255)%(d[943736]|0)|0)&255;a[(c[235938]|0)+b|0]=e;e=b&3;if((e|0)==3){b=f<<13;g=c[235940]|0;c[186858]=g+b;c[186859]=g+(b|1024);c[186860]=g+(b|2048);c[186861]=g+(b|3072);c[186862]=g+(b|4096);c[186863]=g+(b|5120);c[186864]=g+(b|6144);c[186865]=g+(b|7168);return}else if((e|0)==2){b=f<<13;g=c[235940]|0;c[186850]=g+b;c[186851]=g+(b|1024);c[186852]=g+(b|2048);c[186853]=g+(b|3072);c[186854]=g+(b|4096);c[186855]=g+(b|5120);c[186856]=g+(b|6144);c[186857]=g+(b|7168);return}else if((e|0)==1){b=f<<13;g=c[235940]|0;c[186874]=g+b;c[186875]=g+(b|1024);c[186876]=g+(b|2048);c[186877]=g+(b|3072);c[186878]=g+(b|4096);c[186879]=g+(b|5120);c[186880]=g+(b|6144);c[186881]=g+(b|7168);return}else if((e|0)==0){e=f<<13;f=c[235940]|0;c[186866]=f+e;c[186867]=f+(e|1024);c[186868]=f+(e|2048);c[186869]=f+(e|3072);c[186870]=f+(e|4096);c[186871]=f+(e|5120);c[186872]=f+(e|6144);c[186873]=f+(e|7168);return}else{return}}function no(b,d){b=b|0;d=d|0;if((b|0)==32768){nk(3,d&255);return}else if((b|0)==0){nk(1,d&255);return}else if((b|0)==16384){nk(2,d&255);return}else{a[(c[747064+(b>>>10<<2)>>2]|0)+(b&1023)|0]=d;return}}function np(b,d){b=b|0;d=d|0;if((b|0)==40960){nk(3,d&255);return}else{a[(c[747064+(b>>>10<<2)>>2]|0)+(b&1023)|0]=d;return}}function nq(b,d){b=b|0;d=d|0;if((b|0)==16384){nk(2,d&255);return}else if((b|0)==32768){nk(3,d&255);return}else{if(b>>>0>65531){nk(b&3,d&255)}a[(c[747064+(b>>>10<<2)>>2]|0)+(b&1023)|0]=d;return}}function nr(b){b=b|0;var d=0;if((b|0)!=32768|(a[12473680]|0)==0){d=a[(c[747336+(b>>>10<<2)>>2]|0)+(b&1023)|0]|0;return d|0}else{d=a[12473683]|a[12473681]<<2|2;return d|0}return 0}function ns(e){e=e|0;var f=0,g=0,h=0;if((e|0)==40960){f=b[1692240+((d[937416]|0)<<1)>>1]|0;a[1496]=0;g=f&255;return g|0}else if((e|0)==32768){f=(a[1496]&1)<<15|b[1692240+((d[937416]|0)<<1)>>1];h=(b[846136]&16)==0?f|256:f;a[1496]=0;g=(h&65535)>>>8&255;return g|0}else{g=a[(c[747336+(e>>>10<<2)>>2]|0)+(e&1023)|0]|0;return g|0}return 0}function nt(b,d){b=b|0;d=d|0;if((b|0)==24576){a[937416]=d&1^1;a[1496]=1;return}else{a[(c[747064+(b>>>10<<2)>>2]|0)+(b&1023)|0]=d;return}}function nu(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((c[3118417]|0)!=(e|0)){f=a[1987672+(e^1)|0]|0;g=f&255;return g|0}e=a[12473640]|0;L16682:do{switch(c[3118413]|0){case 3:case 2:case 4:case 5:case 6:{h=(a[12473644]|0)==9?0:e;break};case 7:{i=a[12473644]|0;if((i&255)>=9){h=e;break L16682}j=b[6236824]|0;k=(d[(c[234374]|0)+((j|b[6236823])&65535)|0]|0)>>>((8-(i&255)|0)>>>0)&1;if(i<<24>>24!=8){h=k;break L16682}b[6236824]=b[6236829]&(j+1&65535);h=k;break};default:{h=e}}}while(0);f=(h&255)<<d[12473677]&255;g=f&255;return g|0}function nv(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c[3118417]|0;if((g|0)==(f|0)){h=a[12473640]|0;L16692:do{switch(c[3118413]|0){case 7:{i=a[12473644]|0;if((i&255)>=9){j=h;break L16692}k=b[6236824]|0;l=(d[(c[234374]|0)+((k|b[6236823])&65535)|0]|0)>>>((8-(i&255)|0)>>>0)&1;if(i<<24>>24!=8){j=l;break L16692}b[6236824]=b[6236829]&(k+1&65535);j=l;break};case 3:case 2:case 4:case 5:case 6:{j=(a[12473644]|0)==9?0:h;break};default:{j=h}}}while(0);m=(j&255)<<d[12473677]<<8&65280;return m|0}if((g^1|0)!=(f|0)){m=e[1987672+f>>1]|0;return m|0}f=a[12473640]|0;L16704:do{switch(c[3118413]|0){case 3:case 2:case 4:case 5:case 6:{n=(a[12473644]|0)==9?0:f;break};case 7:{g=a[12473644]|0;if((g&255)>=9){n=f;break L16704}j=b[6236824]|0;h=(d[(c[234374]|0)+((j|b[6236823])&65535)|0]|0)>>>((8-(g&255)|0)>>>0)&1;if(g<<24>>24!=8){n=h;break L16704}b[6236824]=b[6236829]&(j+1&65535);n=h;break};default:{n=f}}}while(0);m=(n&255)<<d[12473677]&255;return m|0}function nw(b,d){b=b|0;d=d|0;if((b|0)==16382){nk(1,d&255);return}else if((b|0)==49151){nk(3,(a[(c[235938]|0)+1|0]&48)+(d&255)|0);return}else if((b|0)==32767){nk(2,d&255);return}else{a[(c[747064+(b>>>10<<2)>>2]|0)+(b&1023)|0]=d;return}}function nx(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((f|0)!=32768|(a[12473680]|0)==0){do{if((f|0)==65532){a[12473680]=g&8;if(g<<24>>24>=0){break}aIv(12473680,0,12);a[12473683]=1;c[3118423]=1;a[937482]=3}else{if(f>>>0<=65532){break}nk(f&3,g&255)}}while(0);a[(c[747064+(f>>>10<<2)>>2]|0)+(f&1023)|0]=g;return}f=g&255;do{if((f&4|0)==0){if((a[12473681]|0)==0){break}a[12473683]=1;c[3118423]=1}else{if((f&2|0)==0|(a[12473682]|0)!=0){break}h=c[3118423]|0;if((h|0)==1){if((f&1|0)==0){break}a[12473686]=0;a[12473684]=0;c[3118423]=2;break}else if((h|0)==2){i=a[12473684]|0;j=(f&1)<<7-(i&255)|d[12473686];a[12473686]=j&255;k=i+1&255;a[12473684]=k;if(k<<24>>24!=8){break}k=j&255;j=k>>>6;if((j|0)==3){if((a[12473685]|0)!=0){b[(c[234374]|0)+(k<<1&126)>>1]=-1}c[3118423]=0;break}else if((j|0)==1){b[6236844]=0;a[12473684]=0;c[3118423]=3;break}else if((j|0)==2){b[6236844]=b[(c[234374]|0)+(k<<1&126)>>1]|0;a[12473684]=0;c[3118423]=4;a[12473683]=0;break}else{j=k>>>4;k=j&3;if((k|0)==1){b[6236844]=0;a[12473684]=0;c[3118423]=3;break}else if((k|0)==2){if((a[12473685]|0)!=0){aIv(c[234374]|0,-1|0,128)}c[3118423]=0;break}else{a[12473685]=j&1;c[3118423]=0;break}}}else if((h|0)==4){j=a[12473684]|0;a[12473683]=(e[6236844]|0)>>>((15-(j&255)|0)>>>0)&1;k=j+1&255;a[12473684]=k;if(k<<24>>24!=16){break}k=(a[12473686]|0)+1&255;a[12473686]=k;a[12473684]=0;b[6236844]=b[(c[234374]|0)+((k&255)<<1&126)>>1]|0;break}else if((h|0)==3){h=a[12473684]|0;k=((f&1)<<15-(h&255)|e[6236844])&65535;b[6236844]=k;j=h+1&255;a[12473684]=j;if(j<<24>>24!=16){break}do{if((a[12473685]|0)!=0){j=d[12473686]|0;h=c[234374]|0;if((j&64|0)!=0){b[h+(j<<1&126)>>1]=k;break}b[h>>1]=k;h=1;do{b[(c[234374]|0)+(h<<1)>>1]=b[6236844]|0;h=h+1|0;}while((h|0)<64)}}while(0);c[3118423]=0;break}else{break}}}while(0);a[12473681]=(g&255)>>>2&1;a[12473682]=(g&255)>>>1&1;return}function ny(b,d){b=b|0;d=d|0;if(b>>>0>65531){nk(b&3,d&255)}a[(c[747064+(b>>>10<<2)>>2]|0)+(b&1023)|0]=d;return}function nz(b,e){b=b|0;e=e|0;var f=0;if((c[3118416]|0)==(b|0)){a[12473640]=e>>>((d[12473676]|0)>>>0)&1;f=1}else{f=0}do{if((c[3118418]|0)==(b|0)){a[12473641]=e>>>((d[12473678]|0)>>>0)&1}else{if((f|0)!=0){break}return}}while(0);nC();return}function nA(b,e){b=b|0;e=e|0;var f=0,g=0;f=c[3118416]|0;do{if((f|0)==(b|0)){a[12473640]=e>>>(((d[12473676]|0)+8|0)>>>0)&1;g=1}else{if((f^1|0)!=(b|0)){g=0;break}a[12473640]=e>>>((d[12473676]|0)>>>0)&1;g=1}}while(0);f=c[3118418]|0;do{if((f|0)==(b|0)){a[12473641]=e>>>(((d[12473678]|0)+8|0)>>>0)&1}else{if((f^1|0)==(b|0)){a[12473641]=e>>>((d[12473678]|0)>>>0)&1;break}if((g|0)!=0){break}return}}while(0);nC();return}function nB(a){a=a|0;return d[937530]|0|0}function nC(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;L16802:do{switch(c[3118413]|0){case 4:{f=(a[12473643]|0)==0;g=(a[12473641]|0)==0;do{if(!(f|g)){if((a[12473642]|0)==0|(a[12473640]|0)!=0){break}a[12473644]=0;b[6236823]=0;if((a[12473656]|0)==7){b[6236824]=0;c[3118413]=3;break}else{c[3118413]=2;break}}}while(0);if(f){break L16802}h=a[12473642]|0;if(!(g|h<<24>>24!=0|(a[12473640]|0)==0)){c[3118413]=0}if(!g){break L16802}i=a[12473644]|0;j=i&255;if((i&255)>=9){a[12473644]=1;c[3118413]=5;break L16802}do{if(((e[6236829]|0)+1|0)<(1<<17-j|0)){b[6236823]=(e[6236823]|0)>>>1}else{k=1<<16-j;if(h<<24>>24==0){b[6236824]=e[6236824]&(k^65535)&65535;break}else{b[6236824]=(e[6236824]|k)&65535;break}}}while(0);a[12473644]=i+1&255;break};case 0:{h=(a[12473643]|0)==0;j=(a[12473641]|0)==0;do{if(!(h|j)){if((a[12473642]|0)==0|(a[12473640]|0)!=0){break}a[12473644]=0;b[6236823]=0;if((a[12473656]|0)==7){b[6236824]=0;c[3118413]=3;break}else{c[3118413]=2;break}}}while(0);if(h){break L16802}if(j|(a[12473642]|0)!=0|(a[12473640]|0)==0){break L16802}c[3118413]=0;break};case 5:{i=(a[12473643]|0)==0;g=(a[12473641]|0)==0;do{if(!(i|g)){if((a[12473642]|0)==0|(a[12473640]|0)!=0){break}a[12473644]=0;b[6236823]=0;if((a[12473656]|0)==7){b[6236824]=0;c[3118413]=3;break}else{c[3118413]=2;break}}}while(0);if(i){break L16802}j=a[12473642]|0;if(!(g|j<<24>>24!=0|(a[12473640]|0)==0)){c[3118413]=0}if(!g){break L16802}h=a[12473644]|0;f=h&255;if((h&255)>=9){a[12473644]=1;b[6236824]=b[6236824]&b[6236829];c[3118413]=6;break L16802}do{if(((e[6236829]|0)+1|0)<(1<<9-f|0)){b[6236823]=(e[6236823]|0)>>>1}else{k=1<<8-f;if(j<<24>>24==0){b[6236824]=e[6236824]&(k^65535)&65535;break}else{b[6236824]=(e[6236824]|k)&65535;break}}}while(0);a[12473644]=h+1&255;break};case 3:{j=a[12473643]|0;f=j<<24>>24==0;g=a[12473641]|0;i=g<<24>>24==0;do{if(!(f|i)){if((a[12473642]|0)==0|(a[12473640]|0)!=0){break}a[12473644]=0;b[6236823]=0;if((a[12473656]|0)==7){b[6236824]=0;c[3118413]=3;break}else{c[3118413]=2;break}}}while(0);do{if(!f){if(i|(a[12473642]|0)!=0|(a[12473640]|0)==0){break}c[3118413]=0}}while(0);h=a[12473644]|0;if(h<<24>>24==0&((j<<24>>24!=0|i)^1)){a[12473644]=1;l=1}else{l=h}if(f|g<<24>>24!=0){break L16802}if(l<<24>>24==0){break L16802}do{if((l&255)<8){b[6236824]=(e[6236824]|d[12473642]<<7-(l&255))&65535;m=l+1&255}else{if(l<<24>>24==8){a[12473645]=a[12473642]|0;m=9;break}else{a[12473644]=0;b[6236824]=b[6236824]&b[6236829];c[3118413]=(a[12473645]|0)!=0?7:6;m=1;break}}}while(0);a[12473644]=m;break};case 1:{if((a[12473643]|0)==0){break L16802}if((a[12473641]|0)==0|(a[12473642]|0)!=0|(a[12473640]|0)==0){break L16802}c[3118413]=0;break};case 2:{g=a[12473643]|0;f=g<<24>>24==0;i=a[12473641]|0;j=i<<24>>24==0;do{if(!(f|j)){if((a[12473642]|0)==0|(a[12473640]|0)!=0){break}a[12473644]=0;b[6236823]=0;if((a[12473656]|0)==7){b[6236824]=0;c[3118413]=3;break}else{c[3118413]=2;break}}}while(0);do{if(!f){if(j|(a[12473642]|0)!=0|(a[12473640]|0)==0){break}c[3118413]=0}}while(0);h=a[12473644]|0;if(h<<24>>24==0&((g<<24>>24!=0|j)^1)){a[12473644]=1;n=1}else{n=h}if(f|i<<24>>24!=0){break L16802}h=n&255;if(n<<24>>24==0){break L16802}L16903:do{if((n-5&255)<3){do{if((a[12473656]|0)!=16){k=1<<15-h;if((e[6236829]|0)<(k|0)){break}if((a[12473642]|0)==0){b[6236824]=e[6236824]&(k^65535)&65535;o=n;break L16903}else{b[6236824]=(e[6236824]|k)&65535;o=n;break L16903}}}while(0);b[6236823]=(d[12473642]<<7-h|e[6236823])&65535;o=n}else{if(n<<24>>24==8){a[12473645]=a[12473642]|0;o=8;break}if((n&255)<=8){o=n;break}a[12473644]=0;k=(a[12473645]|0)!=0;if((a[12473656]|0)==16){c[3118413]=k?7:4;b[6236823]=0;o=0;break}else{c[3118413]=k?7:5;b[6236823]=b[6236823]<<8;o=0;break}}}while(0);a[12473644]=o+1&255;break};case 7:{h=(a[12473643]|0)==0;i=(a[12473641]|0)==0;do{if(!(h|i)){if((a[12473642]|0)==0|(a[12473640]|0)!=0){break}a[12473644]=0;b[6236823]=0;if((a[12473656]|0)==7){b[6236824]=0;c[3118413]=3;break}else{c[3118413]=2;break}}}while(0);if(h){break L16802}f=a[12473642]|0;if(!(i|f<<24>>24!=0|(a[12473640]|0)==0)){c[3118413]=0}if(!i){break L16802}j=a[12473644]|0;if((j&255)<9){a[12473644]=j+1&255;break L16802}a[12473644]=1;if(f<<24>>24==0){break L16802}c[3118413]=1;break};case 6:{f=(a[12473643]|0)==0;j=(a[12473641]|0)==0;do{if(!(f|j)){if((a[12473642]|0)==0|(a[12473640]|0)!=0){break}a[12473644]=0;b[6236823]=0;if((a[12473656]|0)==7){b[6236824]=0;c[3118413]=3;break}else{c[3118413]=2;break}}}while(0);if(f){break L16802}i=a[12473642]|0;if(!(j|i<<24>>24!=0|(a[12473640]|0)==0)){c[3118413]=0}if(!j){break L16802}h=a[12473644]|0;if((h&255)>=9){a[12473644]=1;break L16802}g=b[6236824]|b[6236823];k=1<<8-(h&255);if(i<<24>>24==0){i=(c[234374]|0)+(g&65535)|0;a[i]=d[i]&(k^255)&255}else{i=(c[234374]|0)+(g&65535)|0;a[i]=(d[i]|k)&255}k=a[12473644]|0;if(k<<24>>24==8){i=b[6236824]|0;g=b[6236830]|0;b[6236824]=i&~g|i+1&65535&g}a[12473644]=k+1&255;break};default:{}}}while(0);a[12473643]=a[12473641]|0;a[12473642]=a[12473640]|0;return}function nD(){var d=0;if((a[1717144]|0)==0){return}d=e[858576]|0;if((d&32|0)!=0){b[1987672+(c[429315]|0)>>1]=b[858613]|0}if((d&16|0)!=0){b[1987672+(c[429314]|0)>>1]=b[858612]|0}if((d&8|0)!=0){b[1987672+(c[429313]|0)>>1]=b[858611]|0}if((d&4|0)!=0){b[1987672+(c[429312]|0)>>1]=b[858610]|0}if((d&2|0)!=0){b[1987672+(c[429311]|0)>>1]=b[858609]|0}if((d&1|0)!=0){b[1987672+(c[429310]|0)>>1]=b[858608]|0}a[1717144]=0;return}function nE(a,b){a=a|0;b=b|0;var c=0,d=0,f=0;c=a>>>1&31;d=e[1717152+(c<<1)>>1]|0;if((a&1|0)==0){f=d&255|b<<8&65280;nG(c,f);return}else{f=d&65280|b&255;nG(c,f);return}}function nF(a,b){a=a|0;b=b|0;nG(a>>>1&31,b);return}function nG(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b[1717152+(a<<1)>>1]=d&65535;if((a|0)==0){do{if((d&1024|0)==0){c[290366]=c[429287];c[290367]=0;c[290368]=0;if((d&512|0)==0){break}c[290367]=72;c[290368]=178}else{c[290366]=1987672;c[290367]=0;c[290368]=0}}while(0);if((d&256|0)==0){c[290369]=298;c[290370]=114;return}d=(e[858578]|0)<<16&4128768|(e[858579]|0);c[429310]=d;f=(e[858581]|0)<<16&4128768|(e[858582]|0);c[429311]=f;g=(e[858584]|0)<<16&4128768|(e[858585]|0);c[429312]=g;h=(e[858587]|0)<<16&4128768|(e[858588]|0);c[429313]=h;i=(e[858590]|0)<<16&4128768|(e[858591]|0);c[429314]=i;j=(e[858593]|0)<<16&4128768|(e[858594]|0);c[429315]=j;k=b[858580]|0;b[858614]=k;l=b[858583]|0;b[858615]=l;m=b[858586]|0;b[858616]=m;n=b[858589]|0;b[858617]=n;o=b[858592]|0;b[858618]=o;p=b[858595]|0;b[858619]=p;c[290369]=278;c[290370]=84;q=e[858576]|0;if((q&1|0)!=0){r=1987672+d|0;b[858608]=b[r>>1]|0;b[r>>1]=k}if((q&2|0)!=0){k=1987672+f|0;b[858609]=b[k>>1]|0;b[k>>1]=l}if((q&4|0)!=0){l=1987672+g|0;b[858610]=b[l>>1]|0;b[l>>1]=m}if((q&8|0)!=0){m=1987672+h|0;b[858611]=b[m>>1]|0;b[m>>1]=n}if((q&16|0)!=0){n=1987672+i|0;b[858612]=b[n>>1]|0;b[n>>1]=o}if((q&32|0)==0){return}q=1987672+j|0;b[858613]=b[q>>1]|0;b[q>>1]=p;return}else if((a|0)==1){b[858577]=b[858577]|1;return}else{return}}function nH(a){a=a|0;var b=0;b=e[1717152+((a>>>1&31)<<1)>>1]|0;return((a&1|0)!=0?b:b>>>8)&255|0}function nI(a){a=a|0;return e[1717152+((a>>>1&31)<<1)>>1]|0|0}function nJ(a){a=a|0;return d[(c[234374]|0)+(a&65535)|0]|0|0}function nK(a){a=a|0;var b=0;b=a&65534;a=c[234374]|0;return(d[a+b|0]|0)<<8|(d[a+(b|1)|0]|0)|0}function nL(b,d){b=b|0;d=d|0;a[(c[234374]|0)+(b&65535)|0]=d&255;return}function nM(b,d){b=b|0;d=d|0;var e=0;e=b&65534;a[(c[234374]|0)+e|0]=d>>>8&255;a[(c[234374]|0)+(e|1)|0]=d&255;return}function nN(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;aIv(937480,0,20);e=c[3118359]|0;if(e>>>0>8388608){return}c[234374]=10376280;aIv(10376280,-1|0,65536);f=65535;g=10376280;h=-1;i=255;while(1){j=g+1|0;k=c[684280+(((i^h)&15)<<2)>>2]^h>>>4;l=k>>>4^c[684280+((k&15^i>>>4)<<2)>>2];if((f|0)==0){break}f=f-1|0;g=j;h=l;i=d[j]|0}c[234373]=~l;if((a[1988105]|0)==82&(a[1988104]|0)==65){a[937480]=1;a[937481]=1;l=d[1988108]<<16|d[1988109]<<24|d[1988111]<<8|d[1988110];c[234371]=l;i=d[1988112]<<16|d[1988113]<<24|d[1988115]<<8|d[1988114];c[234372]=i;if((bx(962636,704080)|0)!=0){c[234371]=2097153;c[234372]=2113535;return}if((l|0)==16711680){a[937481]=0;return}if(!(l>>>0>i>>>0|(i-l|0)>>>0>65535)){return}c[234372]=l+65535;return}if((bx(962636,724112)|0)!=0){a[937481]=1;c[234371]=2097153;c[234372]=2113535;return}if((bx(962636,711808)|0)!=0){a[937481]=1;c[234371]=2097153;c[234372]=2101247;return}if((bx(962636,706272)|0)!=0){a[937481]=1;c[234371]=2097153;c[234372]=2113535;return}l=b[481326]|0;do{if((l<<16>>16|0)==(-20822|0)|(l<<16>>16|0)==(-29254|0)){if((b[481325]|0)!=-32508){break}a[937481]=1;c[234371]=4194305;c[234372]=4259839;return}}while(0);do{if((bx(962632,702168)|0)!=0){if((bx(962636,698768)|0)==0){if((bx(962636,697160)|0)==0){break}a[937481]=1;c[234371]=2097153;c[234372]=2113535;return}a[937481]=1;if((b[481325]|0)==15880){c[234371]=3932161;c[234372]=3997695;return}else{c[234371]=4194305;c[234372]=4259839;return}}}while(0);if((bx(962582,695056)|0)!=0){if((e|0)!=4194304){return}a[937481]=1;c[234371]=2097153;c[234372]=2113535;return}if((bx(962636,692928)|0)!=0){a[937481]=0;return}if((bx(962582,690912)|0)!=0){a[937481]=0;return}if(e>>>0>=2097153){return}c[234371]=2097152;c[234372]=2162687;a[937481]=1;return}function nO(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0;f=c[234368]|0;g=(c[234362]|0)+(e[f+1050>>1]<<1)|0;c[3645718]=g;c[494722]=800;h=f;f=799;i=g;while(1){g=i+2|0;c[3645718]=g;j=b[i>>1]|0;k=j&65535;L17107:do{switch(k>>>9|0){case 75:{l=h+1030|0;m=h+1034|0;n=ab(b[l>>1]<<1,b[m>>1]|0)|0;c[h+1052>>2]=n;o=h+1036|0;p=(c[o>>2]|0)+n|0;c[o>>2]=p;o=h+1042|0;n=b[o>>1]&24575;b[o>>1]=n;if((p|0)==0){q=n|8192}else{q=(n&65535|p>>>16&32768)&65535}b[o>>1]=q;b[l>>1]=(nR(k&3,0,k<<1&24)|0)&65535;b[m>>1]=(nR(k>>>4&3,4,k>>>3&24)|0)&65535;break};case 12:case 13:case 14:case 15:{a[(k>>>8&7)+(h+1088)|0]=j&255;break};case 101:{m=h+1036|0;l=(nT(k)|0)<<16|c[m>>2];c[m>>2]=l;m=h+1042|0;o=b[m>>1]&24575;b[m>>1]=o;if((l|0)==0){b[m>>1]=o|8192;break L17107}else{b[m>>1]=(o&65535|l>>>16&32768)&65535;break L17107}break};case 117:{l=(nT(k)|0)<<16;o=h+1036|0;m=c[o>>2]|0;p=m^l;c[o>>2]=p;o=h+1042|0;n=b[o>>1]&24575;b[o>>1]=n;if((m|0)==(l|0)){b[o>>1]=n|8192;break L17107}else{b[o>>1]=(n&65535|p>>>16&32768)&65535;break L17107}break};case 36:{p=k&240;if((p|0)==0){n=i+4|0;c[3645718]=n;r=n}else if((p|0)==80){s=(e[h+1042>>1]^k<<5)>>>13;t=12732}else if((p|0)==112){s=(e[h+1042>>1]^k<<7)>>>15;t=12732}else{c[3645718]=i+4;break L17107}if((t|0)==12732){t=0;p=i+4|0;c[3645718]=p;if((s&1|0)==0){r=p}else{break L17107}}p=e[g>>1]|0;n=c[234362]|0;o=h+1046|0;l=b[o>>1]|0;if((l&65535)>5){b[o>>1]=0;u=0}else{u=l}b[o>>1]=u+1&65535;b[h+1096+((u&65535)<<1)>>1]=(r-n|0)>>>1&65535;c[3645718]=n+(p<<1);c[494722]=f;break};case 112:{p=k&15;if((p|0)==7){n=ab(b[h+1030>>1]<<1,b[h+1034>>1]|0)|0;c[h+1052>>2]=n;o=h+1036|0;l=c[o>>2]|0;m=l^n;c[o>>2]=m;o=h+1042|0;v=b[o>>1]&24575;b[o>>1]=v;if((l|0)==(n|0)){b[o>>1]=v|8192;break L17107}else{b[o>>1]=(v&65535|m>>>16&32768)&65535;break L17107}}else if((p|0)==3){c[h+1036>>2]=0;m=h+1042|0;v=b[m>>1]&24575;b[m>>1]=v;b[m>>1]=v|8192;break L17107}else{if(p>>>0<5){w=e[h+1024+(p<<2)+2>>1]|0;x=h}else{v=fD[c[9816+(p<<2)>>2]&127]()|0;w=v;x=c[234368]|0}v=w<<16;p=x+1036|0;m=c[p>>2]|0;o=m^v;c[p>>2]=o;p=x+1042|0;n=b[p>>1]&24575;b[p>>1]=n;if((m|0)==(v|0)){b[p>>1]=n|8192;break L17107}else{b[p>>1]=(n&65535|o>>>16&32768)&65535;break L17107}}break};case 9:{o=a[(k>>>6&4|k&3)+(h+1088)|0]|0;n=k>>>4&15;if(n>>>0>3){fi[c[8+(n<<2)>>2]&255](o&255);break L17107}if((n|0)==0){break L17107}b[h+1024+(n<<2)+2>>1]=o&255;break};case 10:{o=k>>>4&15;if(o>>>0<5){y=b[h+1024+(o<<2)+2>>1]&255;z=h}else{n=(fD[c[9816+(o<<2)>>2]&127]()|0)&255;y=n;z=c[234368]|0}a[(k>>>6&4|k&3)+(z+1088)|0]=y;break};case 83:{n=h+1036|0;o=e[h+((k&511)<<1)>>1]<<16&c[n>>2];c[n>>2]=o;n=h+1042|0;p=b[n>>1]&24575;b[n>>1]=p;if((o|0)==0){b[n>>1]=p|8192;break L17107}else{b[n>>1]=(p&65535|o>>>16&32768)&65535;break L17107}break};case 21:{o=(nT(k)|0)<<16;p=h+1036|0;n=c[p>>2]|0;v=n-o|0;c[p>>2]=v;p=h+1042|0;m=b[p>>1]&4095;b[p>>1]=m;if((n|0)==(o|0)){b[p>>1]=m|8192;break L17107}else{b[p>>1]=(m&65535|v>>>16&32768)&65535;break L17107}break};case 53:{v=nT(k)|0;m=c[h+1036>>2]|0;p=v<<16;v=h+1042|0;o=b[v>>1]&4095;b[v>>1]=o;if((m|0)==(p|0)){b[v>>1]=o|8192;break L17107}else{b[v>>1]=(o&65535|(m-p|0)>>>16&32768)&65535;break L17107}break};case 25:{p=d[(k>>>6&4|k&3)+(h+1088)|0]<<16;m=h+1036|0;o=c[m>>2]|0;v=o-p|0;c[m>>2]=v;m=h+1042|0;n=b[m>>1]&4095;b[m>>1]=n;if((o|0)==(p|0)){b[m>>1]=n|8192;break L17107}else{b[m>>1]=(n&65535|v>>>16&32768)&65535;break L17107}break};case 97:{v=h+1036|0;n=(nR(k&3,k>>>6&4,k<<1&24)|0)<<16|c[v>>2];c[v>>2]=n;v=h+1042|0;m=b[v>>1]&24575;b[v>>1]=m;if((n|0)==0){b[v>>1]=m|8192;break L17107}else{b[v>>1]=(m&65535|n>>>16&32768)&65535;break L17107}break};case 6:{c[3645718]=i+4;nS(k,e[g>>1]|0);break};case 121:{n=d[(k>>>6&4|k&3)+(h+1088)|0]<<16;m=h+1036|0;v=c[m>>2]|0;p=n^v;c[m>>2]=p;m=h+1042|0;o=b[m>>1]&24575;b[m>>1]=o;if((n|0)==(v|0)){b[m>>1]=o|8192;break L17107}else{b[m>>1]=(o&65535|p>>>16&32768)&65535;break L17107}break};case 28:{p=k<<16&16711680;o=h+1036|0;m=c[o>>2]|0;v=m-p|0;c[o>>2]=v;o=h+1042|0;n=b[o>>1]&4095;b[o>>1]=n;if((m|0)==(p|0)){b[o>>1]=n|8192;break L17107}else{b[o>>1]=(n&65535|v>>>16&32768)&65535;break L17107}break};case 96:{v=k&15;if((v|0)==7){n=ab(b[h+1030>>1]<<1,b[h+1034>>1]|0)|0;c[h+1052>>2]=n;o=h+1036|0;p=c[o>>2]|n;c[o>>2]=p;o=h+1042|0;n=b[o>>1]&24575;b[o>>1]=n;if((p|0)==0){b[o>>1]=n|8192;break L17107}else{b[o>>1]=(n&65535|p>>>16&32768)&65535;break L17107}}else if((v|0)==3){p=h+1042|0;n=b[p>>1]&24575;b[p>>1]=n;o=c[h+1036>>2]|0;if((o|0)==0){b[p>>1]=n|8192;break L17107}else{b[p>>1]=(n&65535|o>>>16&32768)&65535;break L17107}}else{if(v>>>0<5){A=e[h+1024+(v<<2)+2>>1]|0;B=h}else{o=fD[c[9816+(v<<2)>>2]&127]()|0;A=o;B=c[234368]|0}o=B+1036|0;v=c[o>>2]|A<<16;c[o>>2]=v;o=B+1042|0;n=b[o>>1]&24575;b[o>>1]=n;if((v|0)==0){b[o>>1]=n|8192;break L17107}else{b[o>>1]=(n&65535|v>>>16&32768)&65535;break L17107}}break};case 1:{v=nR(k&3,k>>>6&4,k<<1&24)|0;n=k>>>4&15;if(n>>>0>3){fi[c[8+(n<<2)>>2]&255](v);break L17107}if((n|0)==0){break L17107}b[h+1024+(n<<2)+2>>1]=v&65535;break};case 3:{b[h+1038>>1]=b[h+((k&511)<<1)>>1]|0;break};case 19:{v=e[h+((k&511)<<1)>>1]<<16;n=h+1036|0;o=c[n>>2]|0;p=o-v|0;c[n>>2]=p;n=h+1042|0;m=b[n>>1]&4095;b[n>>1]=m;if((o|0)==(v|0)){b[n>>1]=m|8192;break L17107}else{b[n>>1]=(m&65535|p>>>16&32768)&65535;break L17107}break};case 38:{p=k&240;if((p|0)==112){C=(e[h+1042>>1]^k<<7)>>>15;t=12745}else if((p|0)==0){c[3645718]=i+4}else if((p|0)==80){C=(e[h+1042>>1]^k<<5)>>>13;t=12745}else{c[3645718]=i+4;break L17107}if((t|0)==12745){t=0;c[3645718]=i+4;if((C&1|0)!=0){break L17107}}c[3645718]=(c[234362]|0)+(e[g>>1]<<1);c[494722]=f;break};case 116:{c[3645718]=i+4;p=e[g>>1]<<16;m=h+1036|0;n=c[m>>2]|0;v=p^n;c[m>>2]=v;m=h+1042|0;o=b[m>>1]&24575;b[m>>1]=o;if((p|0)==(n|0)){b[m>>1]=o|8192;break L17107}else{b[m>>1]=(o&65535|v>>>16&32768)&65535;break L17107}break};case 72:{v=k&240;if((v|0)==80){D=(e[h+1042>>1]^k<<5)>>>13;t=12750}else if((v|0)==112){D=(e[h+1042>>1]^k<<7)>>>15;t=12750}else if((v|0)!=0){break L17107}if((t|0)==12750){t=0;if((D&1|0)!=0){break L17107}}v=k&7;do{if((v|0)==3){o=h+1036|0;m=c[o>>2]<<1;c[o>>2]=m;E=m}else if((v|0)==6){m=h+1036|0;o=-(c[m>>2]|0)|0;c[m>>2]=o;E=o}else if((v|0)==7){o=h+1036|0;m=c[o>>2]|0;if((m|0)>=0){E=m;break}n=-m|0;c[o>>2]=n;E=n}else if((v|0)==2){n=h+1036|0;o=c[n>>2]>>1;c[n>>2]=o;E=o}else{E=c[h+1036>>2]|0}}while(0);v=h+1042|0;o=b[v>>1]&24575;b[v>>1]=o;if((E|0)==0){b[v>>1]=o|8192;break L17107}else{b[v>>1]=(o&65535|E>>>16&32768)&65535;break L17107}break};case 89:{o=h+1036|0;v=d[(k>>>6&4|k&3)+(h+1088)|0]<<16&c[o>>2];c[o>>2]=v;o=h+1042|0;n=b[o>>1]&24575;b[o>>1]=n;if((v|0)==0){b[o>>1]=n|8192;break L17107}else{b[o>>1]=n;break L17107}break};case 105:{n=h+1036|0;o=c[n>>2]|0;v=d[(k>>>6&4|k&3)+(h+1088)|0]<<16|o;c[n>>2]=v;n=h+1042|0;m=b[n>>1]&24575;b[n>>1]=m;if((v|0)==0){b[n>>1]=m|8192;break L17107}else{b[n>>1]=(m&65535|o>>>16&32768)&65535;break L17107}break};case 64:{o=k&15;if((o|0)==7){m=ab(b[h+1030>>1]<<1,b[h+1034>>1]|0)|0;c[h+1052>>2]=m;n=h+1036|0;v=(c[n>>2]|0)+m|0;c[n>>2]=v;n=h+1042|0;m=b[n>>1]&4095;b[n>>1]=m;if((v|0)==0){b[n>>1]=m|8192;break L17107}else{b[n>>1]=(m&65535|v>>>16&32768)&65535;break L17107}}else if((o|0)==3){v=h+1036|0;m=c[v>>2]|0;n=m<<1;c[v>>2]=n;v=h+1042|0;p=b[v>>1]&4095;b[v>>1]=p;if((n|0)==0){b[v>>1]=p|8192;break L17107}else{b[v>>1]=(p&65535|m>>>15&32768)&65535;break L17107}}else{if(o>>>0<5){F=e[h+1024+(o<<2)+2>>1]|0;G=h}else{m=fD[c[9816+(o<<2)>>2]&127]()|0;F=m;G=c[234368]|0}m=G+1036|0;o=(c[m>>2]|0)+(F<<16)|0;c[m>>2]=o;m=G+1042|0;p=b[m>>1]&4095;b[m>>1]=p;if((o|0)==0){b[m>>1]=p|8192;break L17107}else{b[m>>1]=(p&65535|o>>>16&32768)&65535;break L17107}}break};case 60:{o=c[h+1036>>2]|0;p=k<<16&16711680;m=h+1042|0;v=b[m>>1]&4095;b[m>>1]=v;if((o|0)==(p|0)){b[m>>1]=v|8192;break L17107}else{b[m>>1]=(v&65535|(o-p|0)>>>16&32768)&65535;break L17107}break};case 76:{p=h+1036|0;o=(c[p>>2]|0)+(k<<16&16711680)|0;c[p>>2]=o;p=h+1042|0;v=b[p>>1]&4095;b[p>>1]=v;if((o|0)==0){b[p>>1]=v|8192;break L17107}else{b[p>>1]=(v&65535|o>>>16&32768)&65535;break L17107}break};case 92:{o=h+1036|0;v=k<<16&16711680&c[o>>2];c[o>>2]=v;o=h+1042|0;p=b[o>>1]&24575;b[o>>1]=p;if((v|0)==0){b[o>>1]=p|8192;break L17107}else{b[o>>1]=p;break L17107}break};case 108:{p=h+1036|0;o=c[p>>2]|0;v=o|k<<16&16711680;c[p>>2]=v;p=h+1042|0;m=b[p>>1]&24575;b[p>>1]=m;if((v|0)==0){b[p>>1]=m|8192;break L17107}else{b[p>>1]=(m&65535|o>>>16&32768)&65535;break L17107}break};case 113:{o=(nR(k&3,k>>>6&4,k<<1&24)|0)<<16;m=h+1036|0;p=c[m>>2]|0;v=p^o;c[m>>2]=v;m=h+1042|0;n=b[m>>1]&24575;b[m>>1]=n;if((p|0)==(o|0)){b[m>>1]=n|8192;break L17107}else{b[m>>1]=(n&65535|v>>>16&32768)&65535;break L17107}break};case 0:{if((j<<16>>16|0)==55){v=ab(b[h+1030>>1]<<1,b[h+1034>>1]|0)|0;c[h+1052>>2]=v;c[h+1036>>2]=v;break L17107}else if((j<<16>>16|0)==0){break L17107}v=k&15;if(v>>>0<5){H=e[h+1024+(v<<2)+2>>1]|0}else{H=fD[c[9816+(v<<2)>>2]&127]()|0}v=k>>>4&15;if(v>>>0>3){fi[c[8+(v<<2)>>2]&255](H);break L17107}if((v|0)==0){break L17107}b[(c[234368]|0)+1024+(v<<2)+2>>1]=H&65535;break};case 52:{c[3645718]=i+4;v=c[h+1036>>2]|0;n=e[g>>1]<<16;m=h+1042|0;o=b[m>>1]&4095;b[m>>1]=o;if((v|0)==(n|0)){b[m>>1]=o|8192;break L17107}else{b[m>>1]=(o&65535|(v-n|0)>>>16&32768)&65535;break L17107}break};case 68:{c[3645718]=i+4;n=h+1036|0;v=(e[g>>1]<<16)+(c[n>>2]|0)|0;c[n>>2]=v;n=h+1042|0;o=b[n>>1]&4095;b[n>>1]=o;if((v|0)==0){b[n>>1]=o|8192;break L17107}else{b[n>>1]=(o&65535|v>>>16&32768)&65535;break L17107}break};case 124:{v=k<<16&16711680;o=h+1036|0;n=c[o>>2]|0;m=n^v;c[o>>2]=m;o=h+1042|0;p=b[o>>1]&24575;b[o>>1]=p;if((n|0)==(v|0)){b[o>>1]=p|8192;break L17107}else{b[o>>1]=(p&65535|m>>>16&32768)&65535;break L17107}break};case 27:{m=h+1030|0;p=h+1034|0;o=ab(b[m>>1]<<1,b[p>>1]|0)|0;c[h+1052>>2]=o;v=h+1036|0;n=c[v>>2]|0;l=n-o|0;c[v>>2]=l;v=h+1042|0;I=b[v>>1]&24575;b[v>>1]=I;if((n|0)==(o|0)){J=I|8192}else{J=(I&65535|l>>>16&32768)&65535}b[v>>1]=J;b[m>>1]=(nR(k&3,0,k<<1&24)|0)&65535;b[p>>1]=(nR(k>>>4&3,4,k>>>3&24)|0)&65535;break};case 48:{p=k&15;if((p|0)==7){m=ab(b[h+1030>>1]<<1,b[h+1034>>1]|0)|0;c[h+1052>>2]=m;v=c[h+1036>>2]|0;l=h+1042|0;I=b[l>>1]&4095;b[l>>1]=I;if((v|0)==(m|0)){b[l>>1]=I|8192;break L17107}else{b[l>>1]=(I&65535|(v-m|0)>>>16&32768)&65535;break L17107}}else if((p|0)==3){m=h+1042|0;b[m>>1]=b[m>>1]&4095|8192;break L17107}else{if(p>>>0<5){K=e[h+1024+(p<<2)+2>>1]|0;L=h}else{m=fD[c[9816+(p<<2)>>2]&127]()|0;K=m;L=c[234368]|0}m=c[L+1036>>2]|0;p=K<<16;v=L+1042|0;I=b[v>>1]&4095;b[v>>1]=I;if((m|0)==(p|0)){b[v>>1]=I|8192;break L17107}else{b[v>>1]=(I&65535|(m-p|0)>>>16&32768)&65535;break L17107}}break};case 37:{p=b[(c[234362]|0)+(e[h+1038>>1]<<1)>>1]|0;m=k>>>4&15;if(m>>>0>3){fi[c[8+(m<<2)>>2]&255](p&65535);break L17107}if((m|0)==0){break L17107}b[h+1024+(m<<2)+2>>1]=p;break};case 2:{p=k>>>4&15;if(p>>>0<5){M=e[h+1024+(p<<2)+2>>1]|0}else{M=fD[c[9816+(p<<2)>>2]&127]()|0}nS(k,M);break};case 65:{p=h+1036|0;m=((nR(k&3,k>>>6&4,k<<1&24)|0)<<16)+(c[p>>2]|0)|0;c[p>>2]=m;p=h+1042|0;I=b[p>>1]&4095;b[p>>1]=I;if((m|0)==0){b[p>>1]=I|8192;break L17107}else{b[p>>1]=(I&65535|m>>>16&32768)&65535;break L17107}break};case 81:{m=h+1036|0;I=(nR(k&3,k>>>6&4,k<<1&24)|0)<<16&c[m>>2];c[m>>2]=I;m=h+1042|0;p=b[m>>1]&24575;b[m>>1]=p;if((I|0)==0){b[m>>1]=p|8192;break L17107}else{b[m>>1]=(p&65535|I>>>16&32768)&65535;break L17107}break};case 84:{c[3645718]=i+4;I=h+1036|0;p=e[g>>1]<<16&c[I>>2];c[I>>2]=p;I=h+1042|0;m=b[I>>1]&24575;b[I>>1]=m;if((p|0)==0){b[I>>1]=m|8192;break L17107}else{b[I>>1]=(m&65535|p>>>16&32768)&65535;break L17107}break};case 100:{c[3645718]=i+4;p=h+1036|0;m=e[g>>1]<<16|c[p>>2];c[p>>2]=m;p=h+1042|0;I=b[p>>1]&24575;b[p>>1]=I;if((m|0)==0){b[p>>1]=I|8192;break L17107}else{b[p>>1]=(I&65535|m>>>16&32768)&65535;break L17107}break};case 91:{c[h+1036>>2]=0;m=h+1042|0;b[m>>1]=b[m>>1]&4095;b[h+1030>>1]=(nR(k&3,0,k<<1&24)|0)&65535;b[h+1034>>1]=(nR(k>>>4&3,4,k>>>3&24)|0)&65535;break};case 16:{m=k&15;if((m|0)==7){I=ab(b[h+1030>>1]<<1,b[h+1034>>1]|0)|0;c[h+1052>>2]=I;p=h+1036|0;v=c[p>>2]|0;l=v-I|0;c[p>>2]=l;p=h+1042|0;o=b[p>>1]&4095;b[p>>1]=o;if((v|0)==(I|0)){b[p>>1]=o|8192;break L17107}else{b[p>>1]=(o&65535|l>>>16&32768)&65535;break L17107}}else if((m|0)==3){c[h+1036>>2]=0;l=h+1042|0;o=b[l>>1]&4095;b[l>>1]=o;b[l>>1]=o|8192;break L17107}else{if(m>>>0<5){N=e[h+1024+(m<<2)+2>>1]|0;O=h}else{o=fD[c[9816+(m<<2)>>2]&127]()|0;N=o;O=c[234368]|0}o=N<<16;m=O+1036|0;l=c[m>>2]|0;p=l-o|0;c[m>>2]=p;m=O+1042|0;I=b[m>>1]&4095;b[m>>1]=I;if((l|0)==(o|0)){b[m>>1]=I|8192;break L17107}else{b[m>>1]=(I&65535|p>>>16&32768)&65535;break L17107}}break};case 99:{p=h+1036|0;I=e[h+((k&511)<<1)>>1]<<16|c[p>>2];c[p>>2]=I;p=h+1042|0;m=b[p>>1]&24575;b[p>>1]=m;if((I|0)==0){b[p>>1]=m|8192;break L17107}else{b[p>>1]=(m&65535|I>>>16&32768)&65535;break L17107}break};case 115:{I=e[h+((k&511)<<1)>>1]<<16;m=h+1036|0;p=c[m>>2]|0;o=I^p;c[m>>2]=o;m=h+1042|0;l=b[m>>1]&24575;b[m>>1]=l;if((I|0)==(p|0)){b[m>>1]=l|8192;break L17107}else{b[m>>1]=(l&65535|o>>>16&32768)&65535;break L17107}break};case 17:{o=(nR(k&3,k>>>6&4,k<<1&24)|0)<<16;l=h+1036|0;m=c[l>>2]|0;p=m-o|0;c[l>>2]=p;l=h+1042|0;I=b[l>>1]&4095;b[l>>1]=I;if((m|0)==(o|0)){b[l>>1]=I|8192;break L17107}else{b[l>>1]=(I&65535|p>>>16&32768)&65535;break L17107}break};case 49:{p=nR(k&3,k>>>6&4,k<<1&24)|0;I=c[h+1036>>2]|0;l=p<<16;p=h+1042|0;o=b[p>>1]&4095;b[p>>1]=o;if((I|0)==(l|0)){b[p>>1]=o|8192;break L17107}else{b[p>>1]=(o&65535|(I-l|0)>>>16&32768)&65535;break L17107}break};case 80:{l=k&15;if((l|0)==3){I=h+1042|0;o=b[I>>1]&24575;b[I>>1]=o;p=c[h+1036>>2]|0;if((p|0)==0){b[I>>1]=o|8192;break L17107}else{b[I>>1]=(o&65535|p>>>16&32768)&65535;break L17107}}else if((l|0)==7){p=ab(b[h+1030>>1]<<1,b[h+1034>>1]|0)|0;c[h+1052>>2]=p;o=h+1036|0;I=c[o>>2]&p;c[o>>2]=I;o=h+1042|0;p=b[o>>1]&24575;b[o>>1]=p;if((I|0)==0){b[o>>1]=p|8192;break L17107}else{b[o>>1]=(p&65535|I>>>16&32768)&65535;break L17107}}else{if(l>>>0<5){P=e[h+1024+(l<<2)+2>>1]|0;Q=h}else{I=fD[c[9816+(l<<2)>>2]&127]()|0;P=I;Q=c[234368]|0}I=Q+1036|0;l=c[I>>2]&P<<16;c[I>>2]=l;I=Q+1042|0;p=b[I>>1]&24575;b[I>>1]=p;if((l|0)==0){b[I>>1]=p|8192;break L17107}else{b[I>>1]=(p&65535|l>>>16&32768)&65535;break L17107}}break};case 51:{l=c[h+1036>>2]|0;p=e[h+((k&511)<<1)>>1]<<16;I=h+1042|0;o=b[I>>1]&4095;b[I>>1]=o;if((l|0)==(p|0)){b[I>>1]=o|8192;break L17107}else{b[I>>1]=(o&65535|(l-p|0)>>>16&32768)&65535;break L17107}break};case 67:{p=h+1036|0;l=(e[h+((k&511)<<1)>>1]<<16)+(c[p>>2]|0)|0;c[p>>2]=l;p=h+1042|0;o=b[p>>1]&4095;b[p>>1]=o;if((l|0)==0){b[p>>1]=o|8192;break L17107}else{b[p>>1]=(o&65535|l>>>16&32768)&65535;break L17107}break};case 57:{l=c[h+1036>>2]|0;o=d[(k>>>6&4|k&3)+(h+1088)|0]<<16;p=h+1042|0;I=b[p>>1]&4095;b[p>>1]=I;if((l|0)==(o|0)){b[p>>1]=I|8192;break L17107}else{b[p>>1]=(I&65535|(l-o|0)>>>16&32768)&65535;break L17107}break};case 73:{o=h+1036|0;l=(d[(k>>>6&4|k&3)+(h+1088)|0]<<16)+(c[o>>2]|0)|0;c[o>>2]=l;o=h+1042|0;I=b[o>>1]&4095;b[o>>1]=I;if((l|0)==0){b[o>>1]=I|8192;break L17107}else{b[o>>1]=(I&65535|l>>>16&32768)&65535;break L17107}break};case 7:{b[h+((k&511)<<1)>>1]=b[h+1038>>1]|0;break};case 69:{l=h+1036|0;I=((nT(k)|0)<<16)+(c[l>>2]|0)|0;c[l>>2]=I;l=h+1042|0;o=b[l>>1]&4095;b[l>>1]=o;if((I|0)==0){b[l>>1]=o|8192;break L17107}else{b[l>>1]=(o&65535|I>>>16&32768)&65535;break L17107}break};case 85:{I=h+1036|0;o=(nT(k)|0)<<16&c[I>>2];c[I>>2]=o;I=h+1042|0;l=b[I>>1]&24575;b[I>>1]=l;if((o|0)==0){b[I>>1]=l|8192;break L17107}else{b[I>>1]=(l&65535|o>>>16&32768)&65535;break L17107}break};case 5:{o=nT(k)|0;l=k>>>4&15;if(l>>>0>3){fi[c[8+(l<<2)>>2]&255](o);break L17107}if((l|0)==0){break L17107}b[h+1024+(l<<2)+2>>1]=o&65535;break};case 4:{c[3645718]=i+4;o=b[g>>1]|0;l=k>>>4&15;if(l>>>0>3){fi[c[8+(l<<2)>>2]&255](o&65535);break L17107}if((l|0)==0){break L17107}b[h+1024+(l<<2)+2>>1]=o;break};case 20:{c[3645718]=i+4;o=e[g>>1]<<16;l=h+1036|0;I=c[l>>2]|0;p=I-o|0;c[l>>2]=p;l=h+1042|0;m=b[l>>1]&4095;b[l>>1]=m;if((I|0)==(o|0)){b[l>>1]=m|8192;break L17107}else{b[l>>1]=(m&65535|p>>>16&32768)&65535;break L17107}break};default:{}}}while(0);g=c[494722]|0;k=g-1|0;c[494722]=k;j=c[234368]|0;if((k|0)<=0){R=j;t=12955;break}if((c[j+1156>>2]&61440|0)!=0){R=j;t=12956;break}h=j;f=g-2|0;i=c[3645718]|0}if((t|0)==12955){S=R+1028|0;T=S;U=T+2|0;V=b[U>>1]|0;W=V<<16>>16;X=R+1032|0;Y=X;Z=Y+2|0;_=b[Z>>1]|0;$=_<<16>>16;aa=W<<1;ac=ab(aa,$)|0;ad=R+1052|0;c[ad>>2]=ac;ae=c[3645718]|0;af=c[234362]|0;ag=ae;ah=af;ai=ag-ah|0;aj=ai>>>1;ak=aj&65535;al=R+1048|0;am=al;an=am+2|0;b[an>>1]=ak;return}else if((t|0)==12956){S=R+1028|0;T=S;U=T+2|0;V=b[U>>1]|0;W=V<<16>>16;X=R+1032|0;Y=X;Z=Y+2|0;_=b[Z>>1]|0;$=_<<16>>16;aa=W<<1;ac=ab(aa,$)|0;ad=R+1052|0;c[ad>>2]=ac;ae=c[3645718]|0;af=c[234362]|0;ag=ae;ah=af;ai=ag-ah|0;aj=ai>>>1;ak=aj&65535;al=R+1048|0;am=al;an=am+2|0;b[an>>1]=ak;return}}function nP(a){a=a|0;return}function nQ(){var a=0,d=0;a=c[234368]|0;d=ab(b[a+1030>>1]<<1,b[a+1034>>1]|0)|0;c[a+1052>>2]=d;return d>>>16|0}function nR(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=g|f|h;L17461:do{switch(i|0){case 31:{j=e[(c[234368]|0)+518>>1]|0;return j|0};case 16:case 17:case 18:{h=c[234368]|0;f=h+1088+(i&3)|0;g=a[f]|0;k=e[h+((g&255)<<1)>>1]|0;l=b[h+1042>>1]|0;if((l&7)!=0){m=f;n=k;o=-1;p=l;q=g;break L17461}a[f]=g-1&255;j=k;return j|0};case 12:case 13:case 14:{k=c[234368]|0;g=(i&3|4)+(k+1088)|0;f=a[g]|0;a[g]=f+1&255;j=e[k+((f&255|256)<<1)>>1]|0;return j|0};case 27:{j=e[(c[234368]|0)+6>>1]|0;return j|0};case 0:case 1:case 2:{f=c[234368]|0;j=e[f+((d[f+1088+(i&3)|0]|0)<<1)>>1]|0;return j|0};case 20:case 21:case 22:{f=c[234368]|0;k=(i&3|4)+(f+1088)|0;g=a[k]|0;l=e[f+((g&255|256)<<1)>>1]|0;h=b[f+1042>>1]|0;if((h&7)!=0){m=k;n=l;o=-1;p=h;q=g;break L17461}a[k]=g-1&255;j=l;return j|0};case 24:case 25:case 26:{l=c[234368]|0;g=l+1088+(i&3)|0;k=a[g]|0;h=e[l+((k&255)<<1)>>1]|0;f=b[l+1042>>1]|0;if((f&7)!=0){m=g;n=h;o=1;p=f;q=k;break L17461}a[g]=k+1&255;j=h;return j|0};case 3:{j=e[c[234368]>>1]|0;return j|0};case 4:case 5:case 6:{h=c[234368]|0;j=e[h+((d[(i&3|4)+(h+1088)|0]|0|256)<<1)>>1]|0;return j|0};case 11:{j=e[(c[234368]|0)+2>>1]|0;return j|0};case 23:{j=e[(c[234368]|0)+516>>1]|0;return j|0};case 15:{j=e[(c[234368]|0)+514>>1]|0;return j|0};case 8:case 9:case 10:{h=c[234368]|0;k=h+1088+(i&3)|0;g=a[k]|0;a[k]=g+1&255;j=e[h+((g&255)<<1)>>1]|0;return j|0};case 7:{j=e[(c[234368]|0)+512>>1]|0;return j|0};case 28:case 29:case 30:{g=c[234368]|0;h=(i&3|4)+(g+1088)|0;k=a[h]|0;f=e[g+((k&255|256)<<1)>>1]|0;l=b[g+1042>>1]|0;if((l&7)!=0){m=h;n=f;o=1;p=l;q=k;break L17461}a[h]=k+1&255;j=f;return j|0};case 19:{j=e[(c[234368]|0)+4>>1]|0;return j|0};default:{j=0;return j|0}}}while(0);i=1<<(p&7);p=q&255;a[m]=(i+255&o+p|p&-i)&255;j=n;return j|0}function nS(e,f){e=e|0;f=f|0;var g=0,h=0,i=0;g=e&3;switch(e>>>6&4|g|e<<1&24|0){case 16:case 17:case 18:{e=c[234368]|0;h=e+1088+g|0;i=a[h]|0;a[h]=i-1&255;b[e+((i&255)<<1)>>1]=f&65535;return};case 20:case 21:case 22:{i=c[234368]|0;e=(g|4)+(i+1088)|0;h=a[e]|0;a[e]=h-1&255;b[i+((h&255|256)<<1)>>1]=f&65535;return};case 0:case 1:case 2:{h=c[234368]|0;b[h+((d[h+1088+g|0]|0)<<1)>>1]=f&65535;return};case 11:{b[(c[234368]|0)+2>>1]=f&65535;return};case 4:case 5:case 6:{h=c[234368]|0;b[h+((d[(g|4)+(h+1088)|0]|0|256)<<1)>>1]=f&65535;return};case 3:{b[c[234368]>>1]=f&65535;return};case 8:case 24:case 9:case 25:case 10:case 26:{h=c[234368]|0;i=h+1088+g|0;e=a[i]|0;a[i]=e+1&255;b[h+((e&255)<<1)>>1]=f&65535;return};case 23:{b[(c[234368]|0)+516>>1]=f&65535;return};case 7:{b[(c[234368]|0)+512>>1]=f&65535;return};case 19:{b[(c[234368]|0)+4>>1]=f&65535;return};case 15:{b[(c[234368]|0)+514>>1]=f&65535;return};case 27:{b[(c[234368]|0)+6>>1]=f&65535;return};case 31:{b[(c[234368]|0)+518>>1]=f&65535;return};case 12:case 28:case 13:case 29:case 14:case 30:{e=c[234368]|0;h=(g|4)+(e+1088)|0;g=a[h]|0;a[h]=g+1&255;b[e+((g&255|256)<<1)>>1]=f&65535;return};default:{return}}}function nT(a){a=a|0;var f=0,g=0,h=0,i=0;f=a&3;switch(a>>>6&4|f|a<<1&24|0){case 15:{a=(c[234368]|0)+514|0;g=b[a>>1]|0;b[a>>1]=g+1&65535;h=g;break};case 7:{g=(c[234368]|0)+512|0;a=b[g>>1]|0;b[g>>1]=a+1&65535;h=a;break};case 27:{a=(c[234368]|0)+6|0;g=b[a>>1]|0;b[a>>1]=g+1&65535;h=g;break};case 31:{g=(c[234368]|0)+518|0;a=b[g>>1]|0;b[g>>1]=a+1&65535;h=a;break};case 4:case 5:case 6:{a=c[234368]|0;g=a+((d[(f|4)+(a+1088)|0]|0|256)<<1)|0;a=b[g>>1]|0;b[g>>1]=a+1&65535;h=a;break};case 11:{a=(c[234368]|0)+2|0;g=b[a>>1]|0;b[a>>1]=g+1&65535;h=g;break};case 19:{g=(c[234368]|0)+4|0;a=b[g>>1]|0;b[g>>1]=a+1&65535;h=a;break};case 3:{a=c[234368]|0;g=b[a>>1]|0;b[a>>1]=g+1&65535;h=g;break};case 0:case 1:case 2:{g=c[234368]|0;a=g+((d[g+1088+f|0]|0)<<1)|0;f=b[a>>1]|0;b[a>>1]=f+1&65535;h=f;break};case 23:{f=(c[234368]|0)+516|0;a=b[f>>1]|0;b[f>>1]=a+1&65535;h=a;break};default:{i=0;return i|0}}i=e[(c[234362]|0)+((h&65535)<<1)>>1]|0;return i|0}function nU(a){a=a|0;var d=0,e=0,f=0,g=0;d=c[234368]|0;e=d+1046|0;f=b[e>>1]|0;if((f&65535)>5){b[e>>1]=0;g=0}else{g=f}b[e>>1]=g+1&65535;b[d+1096+((g&65535)<<1)>>1]=a&65535;return}function nV(a){a=a|0;c[3645718]=(c[234362]|0)+(a<<1);c[494722]=(c[494722]|0)-1;return}function nW(a){a=a|0;b[(c[234368]|0)+1042>>1]=a&65535;return}function nX(a){a=a|0;var d=0,e=0,f=0;d=c[234368]|0;e=d+1156|0;f=c[e>>2]|0;if((f&1|0)==0){c[e>>2]=f|1;b[d+1080>>1]=a&65535;return}else{c[e>>2]=f&-4|2;b[d+1082>>1]=a&65535;return}}function nY(a){a=a|0;b[(c[234368]|0)+1036>>1]=a&65535;return}function nZ(a){a=a|0;if((n4(0,1,a)|0)!=-1){return}b[(c[234368]|0)+1058>>1]=a&65535;return}function n_(a){a=a|0;if((n4(1,1,a)|0)!=-1){return}b[(c[234368]|0)+1062>>1]=a&65535;return}function n$(a){a=a|0;if((n4(2,1,a)|0)!=-1){return}b[(c[234368]|0)+1066>>1]=a&65535;return}function n0(a){a=a|0;var d=0,e=0;if((n4(3,1,a)|0)!=-1){return}d=c[234368]|0;e=d+1058|0;b[e>>1]=b[e>>1]|1;b[d+1070>>1]=a&65535;return}function n1(a){a=a|0;if((n4(4,1,a)|0)!=-1){return}b[(c[234368]|0)+1074>>1]=a&65535;return}function n2(){return 0}function n3(){return(c[3645718]|0)-(c[234362]|0)>>1|0}function n4(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=c[234368]|0;h=g+1156|0;i=c[h>>2]|0;if((i&2|0)!=0){j=e[(c[3645718]|0)-2>>1]|0;if((j&65295|0)==0|(j&65520|0)==0){c[g+1108+(d*24|0)+(a<<2)>>2]=c[g+1080>>2];c[h>>2]=c[h>>2]&-3;k=0;return k|0}else{c[h>>2]=i&-3;k=0;return k|0}}if((i&1|0)!=0){c[h>>2]=i&-2}do{if((a|0)!=4){if((b[g+1042>>1]&96)==0){k=-1}else{break}return k|0}}while(0);i=c[234362]|0;h=i+131072|0;do{if((d|0)==0){j=g+1108+(a<<2)|0;l=c[j>>2]|0;m=l&65535;n=l>>>16;if((n&65520|0)==2048){c[j>>2]=l+1;o=e[1987672+((n<<16&983040|m)<<1)>>1]|0;break}if((n&18431|0)!=24){o=0;break}p=l>>>27&7;if((p|0)==0){q=0}else if((p|0)==7){r=7;s=13133}else{r=p-1|0;s=13133}do{if((s|0)==13133){p=1<<r;if((n&32768|0)==0){q=p;break}q=-p|0}}while(0);n=e[h+(m<<1)>>1]|0;c[j>>2]=q+l;o=n}else{n=g+1132+(a<<2)|0;p=c[n>>2]|0;t=p&65535;u=p>>>16;if((u&17407|0)==24){v=p>>>27&7;if((v|0)==0){w=0}else if((v|0)==7){x=7;s=13097}else{x=v-1|0;s=13097}do{if((s|0)==13097){v=1<<x;if((u&32768|0)==0){w=v;break}w=-v|0}}while(0);do{if((u&1024|0)==0){b[h+(t<<1)>>1]=f&65535}else{l=f&61440;if((l|0)!=0){j=h+(t<<1)|0;b[j>>1]=(b[j>>1]&4095|l)&65535}l=f&3840;if((l|0)!=0){j=h+(t<<1)|0;b[j>>1]=(b[j>>1]&-3841&65535|l)&65535}l=f&240;if((l|0)!=0){j=h+(t<<1)|0;b[j>>1]=(b[j>>1]&-241&65535|l)&65535}l=f&15;if((l|0)==0){break}j=h+(t<<1)|0;b[j>>1]=(b[j>>1]&-16&65535|l)&65535}}while(0);c[n>>2]=(c[n>>2]|0)+w;o=f;break}if((u&64511|0)!=16408){if((u&18431|0)!=28){o=f;break}l=p>>>27&7;if((l|0)==0){y=0}else if((l|0)==7){z=7;s=13125}else{z=l-1|0;s=13125}do{if((s|0)==13125){l=1<<z;if((u&32768|0)==0){y=l;break}y=-l|0}}while(0);b[i+((p&1023)<<1)>>1]=f&65535;c[n>>2]=(c[n>>2]|0)+y;o=f;break}do{if((u&1024|0)==0){b[h+(t<<1)>>1]=f&65535}else{l=f&61440;if((l|0)!=0){j=h+(t<<1)|0;b[j>>1]=(b[j>>1]&4095|l)&65535}l=f&3840;if((l|0)!=0){j=h+(t<<1)|0;b[j>>1]=(b[j>>1]&-3841&65535|l)&65535}l=f&240;if((l|0)!=0){j=h+(t<<1)|0;b[j>>1]=(b[j>>1]&-241&65535|l)&65535}l=f&15;if((l|0)==0){break}j=h+(t<<1)|0;b[j>>1]=(b[j>>1]&-16&65535|l)&65535}}while(0);c[n>>2]=(c[n>>2]|0)+((p&1|0)!=0?31:1);o=f}}while(0);c[g+1080>>2]=c[g+1108+(d*24|0)+(a<<2)>>2];k=o;return k|0}function n5(){var a=0,d=0,f=0,g=0;a=c[234368]|0;d=a+1046|0;f=(b[d>>1]|0)-1&65535;g=f<<16>>16<0?5:f;b[d>>1]=g;return e[a+1096+((g&65535)<<1)>>1]|0|0}function n6(){var a=0,b=0,d=0,f=0;a=c[234368]|0;b=a+1156|0;d=c[b>>2]|0;if((d&1|0)==0){c[b>>2]=d|1;f=e[a+1080>>1]|0;return f|0}else{c[b>>2]=d&-4|2;d=e[a+1080>>1]|0;f=d<<4&65520|d>>>4&15;return f|0}return 0}function n7(){var a=0,d=0;a=c[234368]|0;if((b[(c[3645718]|0)-2>>1]|0)==15){d=a+1156|0;c[d>>2]=c[d>>2]&-4}return e[a+1036>>1]|0}function n8(a,d){a=a|0;d=d|0;var e=0;b[(a&131070)+((c[234362]|0)+131072)>>1]=d&65535;e=(d|0)==0;if(!((a|0)!=3210758|e)){c[1087031]=c[1087031]&-16385}if((a|0)!=3210760|e){return}c[1087031]=c[1087031]&-32769;return}function n9(a){a=a|0;var b=0;b=a>>>1;return e[(a>>>6&126|b&28672|b<<6&3968)+((c[234362]|0)+131072)>>1]|0|0}function oa(a){a=a|0;var b=0;b=a>>>1;return e[(a>>>5&126|b&30720|b<<6&1920)+((c[234362]|0)+131072)>>1]|0|0}function ob(){var a=0,d=0,e=0,f=0,g=0,h=0;a=n4(0,0,0)|0;if((a|0)!=-1){d=a;return d|0}a=c[234368]|0;e=a+1058|0;f=b[e>>1]|0;g=f&65535;do{if((g&2|0)==0){h=(c[3645718]|0)-(c[234362]|0)|0;if(!((h|0)==2050|(h|0)==99616)){break}h=a+1156|0;c[h>>2]=c[h>>2]|8192}}while(0);b[e>>1]=f&-3;d=g;return d|0}function oc(){var a=0,b=0;a=n4(1,0,0)|0;if((a|0)!=-1){b=a;return b|0}b=e[(c[234368]|0)+1062>>1]|0;return b|0}function od(){var a=0,b=0;a=n4(2,0,0)|0;if((a|0)!=-1){b=a;return b|0}b=e[(c[234368]|0)+1066>>1]|0;return b|0}function oe(){var a=0,b=0;a=n4(3,0,0)|0;if((a|0)!=-1){b=a;return b|0}b=e[(c[234368]|0)+1070>>1]|0;return b|0}function of(){var a=0,b=0,d=0,f=0;a=n4(4,0,0)|0;if((a|0)==0){b=(c[3645718]|0)-(c[234362]|0)|0;if((b|0)==20244){d=(c[234368]|0)+1156|0;c[d>>2]=c[d>>2]|16384;f=0;return f|0}else if((b|0)==2134){b=(c[234368]|0)+1156|0;c[b>>2]=c[b>>2]|32768;f=0;return f|0}else{f=0;return f|0}}else if((a|0)==(-1|0)){f=e[(c[234368]|0)+1074>>1]|0;return f|0}else{f=a;return f|0}return 0}function og(b,d){b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0.0,m=0,n=0.0,o=0,p=0.0,q=0.0,r=0.0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0.0,N=0,O=0.0,P=0,Q=0.0,R=0,V=0.0,W=0,X=0.0,Y=0.0,Z=0.0,$=0,aa=0,ac=0.0,ad=0.0,ae=0.0,af=0.0,ag=0.0,ah=0.0;e=i;i=i+336|0;f=e|0;j=(d|0)==0?1161360:d;d=f+60|0;g[d>>2]=+h[j+24>>3]*128.0+512.5;k=f+56|0;g[k>>2]=+h[j+16>>3]*128.0+256.0;l=+h[j+56>>3];m=f+64|0;if(l>0.0){n=l*.6000000238418579}else{n=l}g[m>>2]=n*.4000000059604645+.4000000059604645;n=+h[j+64>>3];o=f+68|0;if(n>0.0){p=n*.30000001192092896}else{p=n}g[o>>2]=p*.30000001192092896+.30000001192092896;p=+h[j+32>>3]*.03200000151991844+1.0;n=+S(+p,32.0);l=+h[j+48>>3]+1.0;q=(l*l+1.0)*.01937970146536827;g[f+268>>2]=32.0;l=n*p;r=p*p;if(n>1.055999994277954|n<.9810000061988831){s=0;while(1){t=q*+(s-16|0);u=p*+T(+t);v=1.0-u;w=v-n*+T(+(t*32.0));g[f+72+(s+33<<2)>>2]=(w+l*+T(+(t*31.0)))/(r+(v-u))+-.5;x=s+1|0;if((x|0)<33){s=x}else{y=0;z=0.0;break}}}else{s=0;while(1){x=s-16|0;u=q*+(x|0);if((x|0)!=0){v=p*+T(+u);t=1.0-v;w=t-n*+T(+(u*32.0));g[f+72+(s+33<<2)>>2]=(w+l*+T(+(u*31.0)))/(r+(t-v))+-.5}x=s+1|0;if((x|0)<33){s=x}else{y=0;z=0.0;break}}}do{r=+(y|0)*.19634954631328583;l=.41999998688697815- +T(+r)*.5;n=l+ +T(+(r*2.0))*.07999999821186066;s=f+72+(y+33<<2)|0;r=+g[s>>2]*n;g[s>>2]=r;z=z+r;y=y+1|0;}while((y|0)<33);r=1.0/z;y=0;do{s=f+72+(y+33<<2)|0;g[s>>2]=r*+g[s>>2];y=y+1|0;}while((y|0)<33);r=+h[j+72>>3];if(r<0.0){z=r*r;n=z*z;A=n*n*-46.153846740722656}else{A=r}r=-.03125-A*-.02031249925494194;y=-16;do{g[f+72+(y+16<<2)>>2]=+_(+(r*+(ab(y,y)|0)));y=y+1|0;}while((y|0)<17);y=f+72|0;r=+g[y>>2];s=f+80|0;A=+g[s>>2];x=f+88|0;n=+g[x>>2];B=f+96|0;z=+g[B>>2];C=f+104|0;l=+g[C>>2];D=f+112|0;p=+g[D>>2];E=f+120|0;q=+g[E>>2];F=f+128|0;v=+g[F>>2];G=f+136|0;t=+g[G>>2];H=f+144|0;u=+g[H>>2];I=f+152|0;w=+g[I>>2];J=f+160|0;K=+g[J>>2];L=f+168|0;M=+g[L>>2];N=f+176|0;O=+g[N>>2];P=f+184|0;Q=+g[P>>2];R=f+192|0;V=+g[R>>2];W=f+200|0;X=+g[W>>2];Y=1.0/(r+0.0+A+n+z+l+p+q+v+t+u+w+K+M+O+Q+V+X);g[y>>2]=r*Y;g[s>>2]=A*Y;g[x>>2]=n*Y;g[B>>2]=z*Y;g[C>>2]=l*Y;g[D>>2]=p*Y;g[E>>2]=q*Y;g[F>>2]=v*Y;g[G>>2]=t*Y;g[H>>2]=u*Y;g[I>>2]=w*Y;g[J>>2]=K*Y;g[L>>2]=M*Y;g[N>>2]=O*Y;g[P>>2]=Q*Y;g[R>>2]=V*Y;g[W>>2]=X*Y;W=f+76|0;Y=+g[W>>2];R=f+84|0;X=+g[R>>2];P=f+92|0;V=+g[P>>2];N=f+100|0;Q=+g[N>>2];L=f+108|0;O=+g[L>>2];J=f+116|0;M=+g[J>>2];I=f+124|0;K=+g[I>>2];H=f+132|0;w=+g[H>>2];G=f+140|0;u=+g[G>>2];F=f+148|0;t=+g[F>>2];E=f+156|0;v=+g[E>>2];D=f+164|0;q=+g[D>>2];C=f+172|0;p=+g[C>>2];B=f+180|0;l=+g[B>>2];x=f+188|0;z=+g[x>>2];s=f+196|0;n=+g[s>>2];A=1.0/(Y+0.0+X+V+Q+O+M+K+w+u+t+v+q+p+l+z+n);g[W>>2]=Y*A;g[R>>2]=X*A;g[P>>2]=V*A;g[N>>2]=Q*A;g[L>>2]=O*A;g[J>>2]=M*A;g[I>>2]=K*A;g[H>>2]=w*A;g[G>>2]=u*A;g[F>>2]=t*A;g[E>>2]=v*A;g[D>>2]=q*A;g[C>>2]=p*A;g[B>>2]=l*A;g[x>>2]=z*A;g[s>>2]=n*A;A=1.1332999467849731- +h[j+40>>3]*.5;n=+S(0.0,+A);z=+g[k>>2];l=+g[d>>2];g[f+24>>2]=n*z+l;g[f+28>>2]=l+z*+S(.1428571492433548,+A);g[f+32>>2]=l+z*+S(.2857142984867096,+A);g[f+36>>2]=l+z*+S(.4285714626312256,+A);g[f+40>>2]=l+z*+S(.5714285969734192,+A);g[f+44>>2]=l+z*+S(.7142857313156128,+A);g[f+48>>2]=l+z*+S(.8571429252624512,+A);g[f+52>>2]=z+l;l=+h[j>>3]*3.1415927410125732+.2617993950843811;z=+h[j+8>>3]+1.0;d=c[j+80>>2]|0;if((d|0)==0){Z=l+-.2617993950843811;$=676176}else{Z=l;$=d}l=Z;Z=z*+U(+l);A=z*+T(+l);d=f|0;l=+g[$>>2];z=+g[$+4>>2];n=l*A-Z*z;k=f+4|0;g[d>>2]=n;p=Z*l+A*z;s=f+8|0;g[k>>2]=p;z=+g[$+8>>2];l=+g[$+12>>2];q=A*z-Z*l;x=f+12|0;g[s>>2]=q;v=Z*z+A*l;B=f+16|0;g[x>>2]=v;l=+g[$+16>>2];z=+g[$+20>>2];t=A*l-Z*z;$=f+20|0;g[B>>2]=t;u=Z*l+A*z;g[$>>2]=u;C=j+84|0;if((b|0)==0){j=0;z=n;A=p;l=q;Z=v;w=t;K=u;while(1){M=+g[f+24+((j>>>6&7)<<2)>>2];O=+g[f+24+((j>>>3&7)<<2)>>2];Q=+g[f+24+((j&7)<<2)>>2];V=M*.11400000005960464+(O*.5870000123977661+Q*.29899999499320984);X=Q*.5960000157356262-O*.2750000059604645-M*.32100000977516174;Y=M*.3109999895095825+(Q*.21199999749660492-O*.5230000019073486);D=~~(A*Y+(V+z*X))<<21|~~(Z*Y+(V+l*X))<<11|~~(K*Y+(V+w*X))<<1;E=c[C>>2]|0;if((E|0)!=0){F=j*3|0;G=D>>>9&3148803;H=539494914-G|0;I=(H|D)&H-G;a[E+F|0]=I>>>21&255;a[E+(F+1)|0]=I>>>11&255;a[E+(F+2)|0]=I>>>1&255}I=j+1|0;if((I|0)>=512){break}j=I;z=+g[d>>2];A=+g[k>>2];l=+g[s>>2];Z=+g[x>>2];w=+g[B>>2];K=+g[$>>2]}i=e;return}else{aa=0;ac=n;ad=p;ae=q;af=v;ag=t;ah=u}while(1){u=+g[f+24+((aa>>>6&7)<<2)>>2];t=+g[f+24+((aa>>>3&7)<<2)>>2];v=+g[f+24+((aa&7)<<2)>>2];q=u*.11400000005960464+(t*.5870000123977661+v*.29899999499320984);p=v*.5960000157356262-t*.2750000059604645-u*.32100000977516174;n=u*.3109999895095825+(v*.21199999749660492-t*.5230000019073486);j=~~(ad*n+(q+ac*p))<<21|~~(af*n+(q+ae*p))<<11|~~(ah*n+(q+ag*p))<<1;I=c[C>>2]|0;if((I|0)!=0){F=aa*3|0;E=j>>>9&3148803;G=539494914-E|0;H=(G|j)&G-E;a[I+F|0]=H>>>21&255;a[I+(F+1)|0]=H>>>11&255;a[I+(F+2)|0]=H>>>1&255}H=b+(aa<<7)|0;t=q-512.5;F=H;I=11368;E=2;while(1){q=+g[I+4>>2];v=t*+g[o>>2]*q;u=+g[I+8>>2];K=u*(p+v);w=+g[I+12>>2];Z=(n+v)*w;l=+g[I+16>>2];A=(p-v)*l;z=+g[I+20>>2];X=(n-v)*z;v=q*+g[m>>2];q=p*v;V=u*(t+q);u=l*(t-q);q=n*v;v=w*(t+q);w=z*(t-q);G=15;D=f+72+(c[I>>2]<<2)|0;J=F;while(1){q=K*+g[D>>2]+A*+g[D+8>>2];z=Z*+g[D+4>>2]+X*+g[D+12>>2];l=V*+g[D+132>>2]+v*+g[D+136>>2]+u*+g[D+140>>2]+w*+g[D+144>>2]+512.5;c[J>>2]=(~~(l+q*+g[s>>2]+z*+g[x>>2])<<11|~~(z*+g[k>>2]+(q*+g[d>>2]+l))<<21|~~(l+q*+g[B>>2]+z*+g[$>>2])<<1)-1074791424;if((G|0)==0){break}G=G-1|0;D=D-4|0;J=J+4|0}J=E-1|0;if((J|0)==0){break}else{F=F+64|0;I=I+24|0;E=J}}c[b+(aa<<7)+88>>2]=j-(c[H>>2]|0)-(c[b+(aa<<7)+72>>2]|0)-(c[b+(aa<<7)+16>>2]|0)-(c[b+(aa<<7)+32>>2]|0)-(c[b+(aa<<7)+104>>2]|0)-(c[b+(aa<<7)+48>>2]|0)-(c[b+(aa<<7)+120>>2]|0);c[b+(aa<<7)+92>>2]=j-(c[b+(aa<<7)+4>>2]|0)-(c[b+(aa<<7)+76>>2]|0)-(c[b+(aa<<7)+20>>2]|0)-(c[b+(aa<<7)+36>>2]|0)-(c[b+(aa<<7)+108>>2]|0)-(c[b+(aa<<7)+52>>2]|0)-(c[b+(aa<<7)+124>>2]|0);c[b+(aa<<7)+96>>2]=j-(c[b+(aa<<7)+8>>2]|0)-(c[b+(aa<<7)+80>>2]|0)-(c[b+(aa<<7)+24>>2]|0)-(c[b+(aa<<7)+40>>2]|0)-(c[b+(aa<<7)+112>>2]|0)-(c[b+(aa<<7)+56>>2]|0)-(c[b+(aa<<7)+64>>2]|0);c[b+(aa<<7)+100>>2]=j-(c[b+(aa<<7)+12>>2]|0)-(c[b+(aa<<7)+84>>2]|0)-(c[b+(aa<<7)+28>>2]|0)-(c[b+(aa<<7)+44>>2]|0)-(c[b+(aa<<7)+116>>2]|0)-(c[b+(aa<<7)+60>>2]|0)-(c[b+(aa<<7)+68>>2]|0);E=aa+1|0;if((E|0)>=512){break}aa=E;ac=+g[d>>2];ad=+g[k>>2];ae=+g[s>>2];af=+g[x>>2];ag=+g[B>>2];ah=+g[$>>2]}i=e;return}function oh(b,d){b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0.0,n=0,o=0.0,p=0,q=0.0,r=0.0,s=0.0,t=0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0,A=0.0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0.0,O=0,P=0.0,Q=0,R=0.0,V=0,W=0.0,X=0,Y=0.0,Z=0.0,$=0.0,aa=0.0,ac=0.0,ad=0,ae=0,af=0.0,ag=0.0,ah=0.0,ai=0.0,aj=0.0,ak=0.0,al=0;e=i;i=i+2216|0;f=e|0;j=e+264|0;k=(d|0)==0?2288:d;d=j+92|0;g[d>>2]=+h[k+24>>3]*128.0+512.5;l=j+88|0;g[l>>2]=+h[k+16>>3]*128.0+256.0;m=+h[k+56>>3];n=j+96|0;if(m>0.0){o=m*.8000000715255737}else{o=m}g[n>>2]=o*.4000000059604645+.4000000059604645;o=+h[k+64>>3];p=j+100|0;if(o>0.0){q=o*.800000011920929}else{q=o}g[p>>2]=q*.800000011920929+.800000011920929;q=+h[k+32>>3]*.03200000151991844+1.0;o=+S(+q,32.0);m=+h[k+48>>3]+1.0;r=(m*m+1.0)*.019634954631328583;g[f+196>>2]=32.0;m=o*q;s=q*q;if(o>1.055999994277954|o<.9810000061988831){t=0;while(1){u=r*+(t-16|0);v=q*+T(+u);w=1.0-v;x=w-o*+T(+(u*32.0));g[f+(t+33<<2)>>2]=(x+m*+T(+(u*31.0)))/(s+(w-v))+-.5;y=t+1|0;if((y|0)<33){t=y}else{z=0;A=0.0;break}}}else{t=0;while(1){y=t-16|0;v=r*+(y|0);if((y|0)!=0){w=q*+T(+v);u=1.0-w;x=u-o*+T(+(v*32.0));g[f+(t+33<<2)>>2]=(x+m*+T(+(v*31.0)))/(s+(u-w))+-.5}y=t+1|0;if((y|0)<33){t=y}else{z=0;A=0.0;break}}}do{s=+(z|0)*.19634954631328583;m=.41999998688697815- +T(+s)*.5;o=m+ +T(+(s*2.0))*.07999999821186066;t=f+(z+33<<2)|0;s=+g[t>>2]*o;g[t>>2]=s;A=A+s;z=z+1|0;}while((z|0)<33);s=1.0/A;z=0;do{t=f+(z+33<<2)|0;g[t>>2]=s*+g[t>>2];z=z+1|0;}while((z|0)<33);s=+h[k+72>>3];if(s<0.0){A=s*s;o=A*A;B=o*o*-46.153846740722656}else{B=s}s=-.03125-B*-.02031249925494194;z=-16;do{g[f+(z+16<<2)>>2]=+_(+(s*+(ab(z,z)|0)));z=z+1|0;}while((z|0)<17);z=f|0;s=+g[z>>2];t=f+8|0;B=+g[t>>2];y=f+16|0;o=+g[y>>2];C=f+24|0;A=+g[C>>2];D=f+32|0;m=+g[D>>2];E=f+40|0;q=+g[E>>2];F=f+48|0;r=+g[F>>2];G=f+56|0;w=+g[G>>2];H=f+64|0;u=+g[H>>2];I=f+72|0;v=+g[I>>2];J=f+80|0;x=+g[J>>2];K=f+88|0;L=+g[K>>2];M=f+96|0;N=+g[M>>2];O=f+104|0;P=+g[O>>2];Q=f+112|0;R=+g[Q>>2];V=f+120|0;W=+g[V>>2];X=f+128|0;Y=+g[X>>2];Z=1.0/(s+0.0+B+o+A+m+q+r+w+u+v+x+L+N+P+R+W+Y);$=s*Z;g[z>>2]=$;s=B*Z;g[t>>2]=s;g[y>>2]=o*Z;g[C>>2]=A*Z;g[D>>2]=m*Z;g[E>>2]=q*Z;g[F>>2]=r*Z;g[G>>2]=w*Z;g[H>>2]=u*Z;g[I>>2]=v*Z;g[J>>2]=x*Z;g[K>>2]=L*Z;g[M>>2]=N*Z;g[O>>2]=P*Z;g[Q>>2]=R*Z;g[V>>2]=W*Z;g[X>>2]=Y*Z;X=f+4|0;Z=+g[X>>2];V=f+12|0;Y=+g[V>>2];Q=f+20|0;W=+g[Q>>2];O=f+28|0;R=+g[O>>2];M=f+36|0;P=+g[M>>2];K=f+44|0;N=+g[K>>2];J=f+52|0;L=+g[J>>2];I=f+60|0;x=+g[I>>2];H=f+68|0;v=+g[H>>2];G=f+76|0;u=+g[G>>2];F=f+84|0;w=+g[F>>2];E=f+92|0;r=+g[E>>2];D=f+100|0;q=+g[D>>2];C=f+108|0;m=+g[C>>2];y=f+116|0;A=+g[y>>2];t=f+124|0;o=+g[t>>2];B=1.0/(Z+0.0+Y+W+R+P+N+L+x+v+u+w+r+q+m+A+o);aa=Z*B;g[X>>2]=aa;g[V>>2]=Y*B;g[Q>>2]=W*B;g[O>>2]=R*B;g[M>>2]=P*B;g[K>>2]=N*B;g[J>>2]=L*B;g[I>>2]=x*B;g[H>>2]=v*B;g[G>>2]=u*B;g[F>>2]=w*B;g[E>>2]=r*B;g[D>>2]=q*B;g[C>>2]=m*B;g[y>>2]=A*B;g[t>>2]=o*B;B=$*.875;g[j+104>>2]=B+0.0;t=j+108|0;o=aa*.875;g[t>>2]=o+($-B);B=aa;y=3;C=t;aa=o;o=s;while(1){t=C+4|0;s=o*.875;g[t>>2]=s+(B-aa);if((y|0)>=66){break}$=+g[f+(y<<2)>>2];B=o;y=y+1|0;C=t;aa=s;o=$}C=j+368|0;o=0.0;y=0;while(1){aa=+g[f+(y<<2)>>2];B=aa*.75;g[C>>2]=o+B;t=y+1|0;if((t|0)<66){C=C+4|0;o=aa-B;y=t}else{break}}y=j+632|0;o=0.0;C=0;while(1){B=+g[f+(C<<2)>>2];aa=B*.625;g[y>>2]=o+aa;t=C+1|0;if((t|0)<66){y=y+4|0;o=B-aa;C=t}else{break}}C=j+896|0;o=0.0;y=0;while(1){aa=+g[f+(y<<2)>>2];B=aa*.5;g[C>>2]=o+B;t=y+1|0;if((t|0)<66){C=C+4|0;o=aa-B;y=t}else{break}}y=j+1160|0;o=0.0;C=0;while(1){B=+g[f+(C<<2)>>2];aa=B*.375;g[y>>2]=o+aa;t=C+1|0;if((t|0)<66){y=y+4|0;o=B-aa;C=t}else{break}}C=j+1424|0;o=0.0;y=0;while(1){aa=+g[f+(y<<2)>>2];B=aa*.25;g[C>>2]=o+B;t=y+1|0;if((t|0)<66){C=C+4|0;o=aa-B;y=t}else{break}}y=j+1688|0;C=y;o=0.0;t=0;while(1){B=+g[f+(t<<2)>>2];aa=B*.125;g[C>>2]=o+aa;D=t+1|0;if((D|0)<66){C=C+4|0;o=B-aa;t=D}else{break}}o=1.1332999467849731- +h[k+40>>3]*.5;t=0;do{aa=+S(+(+(t|0)*.06666667014360428),+o);g[j+24+(t<<2)>>2]=aa*+g[l>>2]+ +g[d>>2];t=t+1|0;}while((t|0)<16);o=+h[k>>3]*3.1415927410125732+.2617993950843811;aa=+h[k+8>>3]+1.0;t=c[k+80>>2]|0;if((t|0)==0){ac=o+-.2617993950843811;ad=676176}else{ac=o;ad=t}o=ac;ac=aa*+U(+o);B=aa*+T(+o);t=j|0;o=+g[ad>>2];aa=+g[ad+4>>2];$=o*B-ac*aa;d=j+4|0;g[t>>2]=$;s=ac*o+B*aa;l=j+8|0;g[d>>2]=s;aa=+g[ad+8>>2];o=+g[ad+12>>2];A=B*aa-ac*o;C=j+12|0;g[l>>2]=A;m=ac*aa+B*o;f=j+16|0;g[C>>2]=m;o=+g[ad+16>>2];aa=+g[ad+20>>2];q=B*o-ac*aa;ad=j+20|0;g[f>>2]=q;r=ac*o+B*aa;g[ad>>2]=r;D=k+84|0;if((b|0)==0){k=0;aa=$;B=s;o=A;ac=m;w=q;u=r;while(1){v=+g[j+24+((k>>>8&15)<<2)>>2];x=+g[j+24+((k>>>4&15)<<2)>>2];L=+g[j+24+((k&15)<<2)>>2];N=v*.11400000005960464+(x*.5870000123977661+L*.29899999499320984);P=L*.5960000157356262-x*.2750000059604645-v*.32100000977516174;R=v*.3109999895095825+(L*.21199999749660492-x*.5230000019073486);E=~~(B*R+(N+aa*P))<<21|~~(ac*R+(N+o*P))<<11|~~(u*R+(N+w*P))<<1;F=c[D>>2]|0;if((F|0)!=0){G=k*3|0;H=E>>>9&3148803;I=539494914-H|0;J=(I|E)&I-H;a[F+G|0]=J>>>21&255;a[F+(G+1)|0]=J>>>11&255;a[F+(G+2)|0]=J>>>1&255}J=k+1|0;if((J|0)>=4096){break}k=J;aa=+g[t>>2];B=+g[d>>2];o=+g[l>>2];ac=+g[C>>2];w=+g[f>>2];u=+g[ad>>2]}i=e;return}else{ae=0;af=$;ag=s;ah=A;ai=m;aj=q;ak=r}while(1){r=+g[j+24+((ae>>>8&15)<<2)>>2];q=+g[j+24+((ae>>>4&15)<<2)>>2];m=+g[j+24+((ae&15)<<2)>>2];A=r*.11400000005960464+(q*.5870000123977661+m*.29899999499320984);s=m*.5960000157356262-q*.2750000059604645-r*.32100000977516174;$=r*.3109999895095825+(m*.21199999749660492-q*.5230000019073486);k=~~(ag*$+(A+af*s))<<21|~~(ai*$+(A+ah*s))<<11|~~(ak*$+(A+aj*s))<<1;J=c[D>>2]|0;if((J|0)!=0){G=ae*3|0;F=k>>>9&3148803;H=539494914-F|0;I=(H|k)&H-F;a[J+G|0]=I>>>21&255;a[J+(G+1)|0]=I>>>11&255;a[J+(G+2)|0]=I>>>1&255}q=A-512.5;I=b+(ae*168|0)|0;G=2128;J=3;while(1){A=+g[G+4>>2];m=q*+g[p>>2]*A;r=+g[G+8>>2];u=r*(s+m);w=+g[G+12>>2];ac=($+m)*w;o=+g[G+16>>2];B=(s-m)*o;aa=+g[G+20>>2];P=($-m)*aa;m=A*+g[n>>2];A=s*m;N=r*(q+A);r=o*(q-A);A=$*m;m=w*(q+A);w=aa*(q-A);F=13;H=j+104+(c[G>>2]<<2)|0;E=I;while(1){A=u*+g[H>>2]+B*+g[H+8>>2];aa=ac*+g[H+4>>2]+P*+g[H+12>>2];o=N*+g[H+132>>2]+m*+g[H+136>>2]+r*+g[H+140>>2]+w*+g[H+144>>2]+512.5;c[E>>2]=(~~(o+A*+g[l>>2]+aa*+g[C>>2])<<11|~~(aa*+g[d>>2]+(A*+g[t>>2]+o))<<21|~~(o+A*+g[f>>2]+aa*+g[ad>>2])<<1)-1074791424;if((F|0)==0){break}F=F-1|0;H=H>>>0<y>>>0?H+260|0:H-1592|0;E=E+4|0}E=J-1|0;if((E|0)==0){al=0;break}else{I=I+56|0;G=G+24|0;J=E}}do{c[b+(ae*168|0)+(al+31<<2)>>2]=k-(c[b+(ae*168|0)+(al<<2)>>2]|0)-(c[b+(ae*168|0)+((((al+12|0)>>>0)%14|0)+14<<2)>>2]|0)-(c[b+(ae*168|0)+((((al+10|0)>>>0)%14|0)+28<<2)>>2]|0)-(c[b+(ae*168|0)+(al+7<<2)>>2]|0)-(c[b+(ae*168|0)+(al+19<<2)>>2]|0);al=al+1|0;}while(al>>>0<7);k=ae+1|0;if((k|0)>=4096){break}ae=k;af=+g[t>>2];ag=+g[d>>2];ah=+g[l>>2];ai=+g[C>>2];aj=+g[f>>2];ak=+g[ad>>2]}i=e;return}function oi(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[187441]|0;do{if(((e^b)&192|0)!=0){c[187087]=-1;if((b&192|0)==128|(a[750848]|0)==0){break}do{if((a[748382]|0)==0&(d[748352]|0)>1){a[748352]=1;f=d[748380]|0;if((f&8|0)==0){break}g=c[187090]|0;if((d[748381]|0)==(f&4|0)){h=g}else{f=512-g|0;c[187090]=f;h=f}if((h|0)>511){c[187090]=1023;a[748352]=0;i=1023}else{i=h}c[187092]=(c[187089]|0)+i}}while(0);do{if((a[748534]|0)==0&(d[748504]|0)>1){a[748504]=1;f=d[748532]|0;if((f&8|0)==0){break}g=c[187128]|0;if((d[748533]|0)==(f&4|0)){j=g}else{f=512-g|0;c[187128]=f;j=f}if((j|0)>511){c[187128]=1023;a[748504]=0;k=1023}else{k=j}c[187130]=(c[187127]|0)+k}}while(0);do{if((a[748458]|0)==0&(d[748428]|0)>1){a[748428]=1;f=d[748456]|0;if((f&8|0)==0){break}g=c[187109]|0;if((d[748457]|0)==(f&4|0)){l=g}else{f=512-g|0;c[187109]=f;l=f}if((l|0)>511){c[187109]=1023;a[748428]=0;m=1023}else{m=l}c[187111]=(c[187108]|0)+m}}while(0);do{if((a[748610]|0)==0&(d[748580]|0)>1){a[748580]=1;f=d[748608]|0;if((f&8|0)==0){break}g=c[187147]|0;if((d[748609]|0)==(f&4|0)){n=g}else{f=512-g|0;c[187147]=f;n=f}if((n|0)>511){c[187147]=1023;a[748580]=0;o=1023}else{o=n}c[187149]=(c[187146]|0)+o}}while(0);a[750848]=0}}while(0);do{if((b&1|0)!=0){if((e&1|0)!=0){break}c[187445]=c[187444]}}while(0);if((b&2|0)==0){p=b>>>4;q=p^255;r=a[749762]|0;s=r&255;t=s&q;u=t&255;a[749762]=u;c[187441]=b;return}if((e&2|0)!=0){p=b>>>4;q=p^255;r=a[749762]|0;s=r&255;t=s&q;u=t&255;a[749762]=u;c[187441]=b;return}c[187448]=c[187447];p=b>>>4;q=p^255;r=a[749762]|0;s=r&255;t=s&q;u=t&255;a[749762]=u;c[187441]=b;return}function oj(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b&3;if(f<<24>>24==3){return}g=((b|0)>255?f+3&255:f)&255;f=b>>>2&3;switch(b&240|0){case 144:{h=e&15;a[747592+(g*360|0)+(f*76|0)+68|0]=h;if((d[747592+(g*360|0)+(f*76|0)+40|0]|0)<=1){return}i=h&255;do{if((i&8|0)!=0){if((d[747592+(g*360|0)+(f*76|0)+69|0]|0)==(i&4|0)){break}c[747592+(g*360|0)+(f*76|0)+56>>2]=(512-(c[747592+(g*360|0)+(f*76|0)+48>>2]|0)&1023)+(c[747592+(g*360|0)+(f*76|0)+44>>2]|0);return}}while(0);c[747592+(g*360|0)+(f*76|0)+56>>2]=(c[747592+(g*360|0)+(f*76|0)+44>>2]|0)+(c[747592+(g*360|0)+(f*76|0)+48>>2]|0);return};case 112:{i=e&31;if((i|0)==0){j=0}else{j=(i<<1)+32|0}c[747592+(g*360|0)+(f*76|0)+16>>2]=j;i=(d[747592+(g*360|0)+(f*76|0)+24|0]|0)+j|0;a[747592+(g*360|0)+(f*76|0)+64|0]=a[675352+i|0]|0;a[747592+(g*360|0)+(f*76|0)+65|0]=a[675576+i|0]|0;return};case 176:{if((f|0)==1){c[747932+(g*360|0)>>2]=e<<5&224;a[747936+(g*360|0)|0]=a[669272+(e>>>4&3)|0]|0;i=c[3184688]|0;j=g<<1;c[750852+(j<<2)>>2]=(e&128|0)!=0?i:0;c[750852+((j|1)<<2)>>2]=(e&64|0)!=0?i:0;return}else if((f|0)==0){i=e&7;a[747896+(g*360|0)|0]=i;a[747897+(g*360|0)|0]=e>>>3&7;j=968040+(g<<2)|0;h=747908+(g*360|0)|0;k=747912+(g*360|0)|0;l=747916+(g*360|0)|0;m=747924+(g*360|0)|0;switch(i&255|0){case 5:{c[h>>2]=0;c[l>>2]=j;c[k>>2]=j;c[m>>2]=1166832;break};case 6:{c[h>>2]=12474480;c[l>>2]=j;c[k>>2]=j;c[m>>2]=1161352;break};case 3:{c[h>>2]=12474480;c[l>>2]=1161352;c[k>>2]=12474472;c[m>>2]=12474472;break};case 4:{c[h>>2]=12474480;c[l>>2]=j;c[k>>2]=12474472;c[m>>2]=1161352;break};case 1:{c[h>>2]=1161352;c[l>>2]=1161352;c[k>>2]=12474472;c[m>>2]=1166832;break};case 2:{c[h>>2]=12474472;c[l>>2]=1161352;c[k>>2]=12474472;c[m>>2]=1166832;break};case 0:{c[h>>2]=12474480;c[l>>2]=1161352;c[k>>2]=12474472;c[m>>2]=1166832;break};case 7:{c[h>>2]=j;c[l>>2]=j;c[k>>2]=j;c[m>>2]=1161352;break};default:{}}c[747920+(g*360|0)>>2]=j;return}else{return}break};case 64:{j=e<<3&1016;c[747592+(g*360|0)+(f*76|0)+44>>2]=j;m=d[747592+(g*360|0)+(f*76|0)+68|0]|0;do{if((m&8|0)!=0){if((d[747592+(g*360|0)+(f*76|0)+69|0]|0)==(m&4|0)){break}if((d[747592+(g*360|0)+(f*76|0)+40|0]|0)<=1){break}c[747592+(g*360|0)+(f*76|0)+56>>2]=(512-(c[747592+(g*360|0)+(f*76|0)+48>>2]|0)&1023)+j;return}}while(0);c[747592+(g*360|0)+(f*76|0)+56>>2]=(c[747592+(g*360|0)+(f*76|0)+48>>2]|0)+j;return};case 48:{j=e&15;c[747592+(g*360|0)+(f*76|0)+28>>2]=(j|0)==0?1:j<<1;c[747592+(g*360|0)+(f*76|0)>>2]=749796+((e>>>4&7)<<7);c[747628+(g*360|0)>>2]=-1;return};case 80:{j=747592+(g*360|0)+(f*76|0)+4|0;m=a[j]|0;k=e&31;if((k|0)==0){n=0}else{n=(k<<1)+32|0}k=747592+(g*360|0)+(f*76|0)+8|0;c[k>>2]=n;l=3-(e>>>6)&255;a[j]=l;if(m<<24>>24==l<<24>>24){o=n}else{c[747628+(g*360|0)>>2]=-1;o=c[k>>2]|0}k=(d[747592+(g*360|0)+(f*76|0)+24|0]|0)+o|0;if(k>>>0<94){a[747592+(g*360|0)+(f*76|0)+60|0]=a[675352+k|0]|0;a[747592+(g*360|0)+(f*76|0)+61|0]=a[675576+k|0]|0;return}else{a[747592+(g*360|0)+(f*76|0)+60|0]=0;a[747592+(g*360|0)+(f*76|0)+61|0]=-112;return}break};case 160:{if((f|0)==0){k=a[749768]|0;o=((k&255)<<8&1792)+e|0;n=(k&255)>>>3;k=n&255;a[747944+(g*360|0)|0]=n<<2|a[11112+(o>>>7)|0];c[747940+(g*360|0)>>2]=o<<6>>>((7-k|0)>>>0);c[747948+(g*360|0)>>2]=o|k<<11;c[747628+(g*360|0)>>2]=-1;return}else if((f|0)==2){if((b|0)>=256){return}k=a[750832]|0;o=((k&255)<<8&1792)+e|0;n=(k&255)>>>3;k=n&255;a[750833+g|0]=n<<2|a[11112+(o>>>7)|0];c[750820+(g<<2)>>2]=o<<6>>>((7-k|0)>>>0);c[750836+(g<<2)>>2]=o|k<<11;c[187087]=-1;return}else if((f|0)==1){a[749768]=e&63;return}else if((f|0)==3){if((b|0)>=256){return}a[750832]=e&63;return}else{return}break};case 96:{b=e&31;if((b|0)==0){p=0}else{p=(b<<1)+32|0}c[747592+(g*360|0)+(f*76|0)+12>>2]=p;b=(d[747592+(g*360|0)+(f*76|0)+24|0]|0)+p|0;a[747592+(g*360|0)+(f*76|0)+62|0]=a[675352+b|0]|0;a[747592+(g*360|0)+(f*76|0)+63|0]=a[675576+b|0]|0;c[747592+(g*360|0)+(f*76|0)+72>>2]=e<<24>>31;return};case 128:{b=c[2376+(e>>4<<2)>>2]|0;c[747592+(g*360|0)+(f*76|0)+52>>2]=b;p=747592+(g*360|0)+(f*76|0)+40|0;do{if((a[p]|0)==3){if((c[747592+(g*360|0)+(f*76|0)+48>>2]|0)<(b|0)){break}a[p]=2}}while(0);p=(e<<2&60)+34|0;c[747592+(g*360|0)+(f*76|0)+20>>2]=p;e=(d[747592+(g*360|0)+(f*76|0)+24|0]|0)+p|0;a[747592+(g*360|0)+(f*76|0)+66|0]=a[675352+e|0]|0;a[747592+(g*360|0)+(f*76|0)+67|0]=a[675576+e|0]|0;return};default:{return}}}function ok(){var b=0;c[187726]=0;c[187725]=0;c[187729]=0;c[187728]=0;a[750908]=0;c[187730]=126;c[187731]=0;c[187445]=0;c[187448]=0;a[750848]=0;a[749752]=0;c[187439]=0;oi(48);c[187446]=0;c[187447]=4096;c[187443]=0;c[187444]=1024;b=0;do{c[747928+(b*360|0)>>2]=0;c[747900+(b*360|0)>>2]=0;c[747904+(b*360|0)>>2]=0;c[747628+(b*360|0)>>2]=-1;a[747662+(b*360|0)|0]=0;c[747624+(b*360|0)>>2]=0;a[747661+(b*360|0)|0]=0;a[747632+(b*360|0)|0]=0;c[747640+(b*360|0)>>2]=1023;c[747648+(b*360|0)>>2]=1023;c[747704+(b*360|0)>>2]=-1;a[747738+(b*360|0)|0]=0;c[747700+(b*360|0)>>2]=0;a[747737+(b*360|0)|0]=0;a[747708+(b*360|0)|0]=0;c[747716+(b*360|0)>>2]=1023;c[747724+(b*360|0)>>2]=1023;c[747780+(b*360|0)>>2]=-1;a[747814+(b*360|0)|0]=0;c[747776+(b*360|0)>>2]=0;a[747813+(b*360|0)|0]=0;a[747784+(b*360|0)|0]=0;c[747792+(b*360|0)>>2]=1023;c[747800+(b*360|0)>>2]=1023;c[747856+(b*360|0)>>2]=-1;a[747890+(b*360|0)|0]=0;c[747852+(b*360|0)>>2]=0;a[747889+(b*360|0)|0]=0;a[747860+(b*360|0)|0]=0;c[747868+(b*360|0)>>2]=1023;c[747876+(b*360|0)>>2]=1023;b=b+1|0;}while((b|0)<6);c[187163]=0;a[748656]=8;b=c[3184688]|0;c[187717]=b;c[187718]=b;c[187433]=0;a[749736]=8;c[187723]=b;c[187724]=b;c[187073]=0;a[748296]=8;c[187715]=b;c[187716]=b;c[187343]=0;a[749376]=8;c[187721]=b;c[187722]=b;c[186983]=0;a[747936]=8;c[187713]=b;c[187714]=b;c[187253]=0;a[749016]=8;c[187719]=b;c[187720]=b;b=178;do{oj(b,0);oj(b|256,0);b=b-1|0;}while((b|0)>47);return}function ol(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=g&255;if((f|0)==0){b[374880]=h&65535;return}else if((f|0)==2){b[374880]=(h|256)&65535;return}else{f=e[374880]|0;if((f&496|0)!=32){oj(f,h);return}switch(f|0){case 34:{if((g&8|0)==0){c[187729]=0;c[187728]=0;a[750908]=0;c[187731]=0;c[187730]=126;return}else{c[187729]=c[668728+((g&7)<<2)>>2];return}break};case 38:{c[187446]=h;c[187447]=256-h<<4;return};case 37:{f=c[187443]&1020|g&3;c[187443]=f;c[187444]=1024-f;return};case 39:{oi(h);return};case 40:{f=g&3;if(f<<24>>24==3){return}i=((g&4|0)==0?f:f+3&255)&255;f=747662+(i*360|0)|0;j=a[f]|0;do{if((g&16|0)==0){if(j<<24>>24==0|(a[750848]|0)!=0){k=0;break}l=747632+(i*360|0)|0;if((d[l]|0)<=1){k=0;break}a[l]=1;m=d[747660+(i*360|0)|0]|0;if((m&8|0)==0){k=0;break}n=747640+(i*360|0)|0;o=c[n>>2]|0;if((d[747661+(i*360|0)|0]|0)==(m&4|0)){p=o}else{m=512-o|0;c[n>>2]=m;p=m}if((p|0)>511){c[n>>2]=1023;a[l]=0;q=1023}else{q=p}c[747648+(i*360|0)>>2]=(c[747636+(i*360|0)>>2]|0)+q;k=0}else{if((a[750848]|j)<<24>>24!=0){k=1;break}c[747624+(i*360|0)>>2]=0;a[747661+(i*360|0)|0]=0;l=747640+(i*360|0)|0;if(((d[747616+(i*360|0)|0]|0)+(c[747600+(i*360|0)>>2]|0)|0)>>>0<94){n=c[l>>2]|0;if((n|0)<1){r=(c[747644+(i*360|0)>>2]|0)==0?2:3}else{r=4}a[747632+(i*360|0)|0]=r;s=n}else{c[l>>2]=0;a[747632+(i*360|0)|0]=(c[747644+(i*360|0)>>2]|0)==0?2:3;s=0}if((a[747660+(i*360|0)|0]&12)==12){c[747648+(i*360|0)>>2]=(c[747636+(i*360|0)>>2]|0)+(512-s&1023);k=1;break}else{c[747648+(i*360|0)>>2]=(c[747636+(i*360|0)>>2]|0)+s;k=1;break}}}while(0);a[f]=k;k=747814+(i*360|0)|0;f=a[k]|0;do{if((g&32|0)==0){if(f<<24>>24==0|(a[750848]|0)!=0){t=0;break}s=747784+(i*360|0)|0;if((d[s]|0)<=1){t=0;break}a[s]=1;r=d[747812+(i*360|0)|0]|0;if((r&8|0)==0){t=0;break}j=747792+(i*360|0)|0;q=c[j>>2]|0;if((d[747813+(i*360|0)|0]|0)==(r&4|0)){u=q}else{r=512-q|0;c[j>>2]=r;u=r}if((u|0)>511){c[j>>2]=1023;a[s]=0;v=1023}else{v=u}c[747800+(i*360|0)>>2]=(c[747788+(i*360|0)>>2]|0)+v;t=0}else{if((a[750848]|f)<<24>>24!=0){t=1;break}c[747776+(i*360|0)>>2]=0;a[747813+(i*360|0)|0]=0;s=747792+(i*360|0)|0;if(((d[747768+(i*360|0)|0]|0)+(c[747752+(i*360|0)>>2]|0)|0)>>>0<94){j=c[s>>2]|0;if((j|0)<1){w=(c[747796+(i*360|0)>>2]|0)==0?2:3}else{w=4}a[747784+(i*360|0)|0]=w;x=j}else{c[s>>2]=0;a[747784+(i*360|0)|0]=(c[747796+(i*360|0)>>2]|0)==0?2:3;x=0}if((a[747812+(i*360|0)|0]&12)==12){c[747800+(i*360|0)>>2]=(c[747788+(i*360|0)>>2]|0)+(512-x&1023);t=1;break}else{c[747800+(i*360|0)>>2]=(c[747788+(i*360|0)>>2]|0)+x;t=1;break}}}while(0);a[k]=t;t=747738+(i*360|0)|0;k=a[t]|0;do{if((g&64|0)==0){x=a[750848]|0;if(k<<24>>24==0|x<<24>>24!=0){y=0;z=x;break}x=747708+(i*360|0)|0;if((d[x]|0)<=1){y=0;z=0;break}a[x]=1;w=d[747736+(i*360|0)|0]|0;if((w&8|0)==0){y=0;z=0;break}f=747716+(i*360|0)|0;v=c[f>>2]|0;if((d[747737+(i*360|0)|0]|0)==(w&4|0)){A=v}else{w=512-v|0;c[f>>2]=w;A=w}if((A|0)>511){c[f>>2]=1023;a[x]=0;B=1023}else{B=A}c[747724+(i*360|0)>>2]=(c[747712+(i*360|0)>>2]|0)+B;y=0;z=0}else{x=a[750848]|0;if((x|k)<<24>>24!=0){y=1;z=x;break}c[747700+(i*360|0)>>2]=0;a[747737+(i*360|0)|0]=0;f=747716+(i*360|0)|0;if(((d[747692+(i*360|0)|0]|0)+(c[747676+(i*360|0)>>2]|0)|0)>>>0<94){w=c[f>>2]|0;if((w|0)<1){C=(c[747720+(i*360|0)>>2]|0)==0?2:3}else{C=4}a[747708+(i*360|0)|0]=C;D=w}else{c[f>>2]=0;a[747708+(i*360|0)|0]=(c[747720+(i*360|0)>>2]|0)==0?2:3;D=0}if((a[747736+(i*360|0)|0]&12)==12){c[747724+(i*360|0)>>2]=(c[747712+(i*360|0)>>2]|0)+(512-D&1023);y=1;z=x;break}else{c[747724+(i*360|0)>>2]=(c[747712+(i*360|0)>>2]|0)+D;y=1;z=x;break}}}while(0);a[t]=y;y=747890+(i*360|0)|0;t=a[y]|0;if((g&128|0)==0){do{if(!(t<<24>>24==0|z<<24>>24!=0)){D=747860+(i*360|0)|0;if((d[D]|0)<=1){break}a[D]=1;C=d[747888+(i*360|0)|0]|0;if((C&8|0)==0){break}k=747868+(i*360|0)|0;B=c[k>>2]|0;if((d[747889+(i*360|0)|0]|0)==(C&4|0)){E=B}else{C=512-B|0;c[k>>2]=C;E=C}if((E|0)>511){c[k>>2]=1023;a[D]=0;F=1023}else{F=E}c[747876+(i*360|0)>>2]=(c[747864+(i*360|0)>>2]|0)+F}}while(0);a[y]=0;return}do{if((t|z)<<24>>24==0){c[747852+(i*360|0)>>2]=0;a[747889+(i*360|0)|0]=0;F=747868+(i*360|0)|0;if(((d[747844+(i*360|0)|0]|0)+(c[747828+(i*360|0)>>2]|0)|0)>>>0<94){E=c[F>>2]|0;if((E|0)<1){G=(c[747872+(i*360|0)>>2]|0)==0?2:3}else{G=4}a[747860+(i*360|0)|0]=G;H=E}else{c[F>>2]=0;a[747860+(i*360|0)|0]=(c[747872+(i*360|0)>>2]|0)==0?2:3;H=0}if((a[747888+(i*360|0)|0]&12)==12){c[747876+(i*360|0)>>2]=(c[747864+(i*360|0)>>2]|0)+(512-H&1023);break}else{c[747876+(i*360|0)>>2]=(c[747864+(i*360|0)>>2]|0)+H;break}}}while(0);a[y]=1;return};case 42:{c[187439]=(h<<6)-8192;return};case 36:{y=c[187443]&3|h<<2;c[187443]=y;c[187444]=1024-y;return};case 43:{a[749752]=g&255&-128;return};default:{return}}}}function om(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0;do{if((c[186907]|0)==-1){f=c[186985]|0;g=d[747944]|0;c[186907]=(ab((c[(c[186898]|0)+(g<<2)>>2]|0)+f&131071,c[186905]|0)|0)>>>1;h=g>>>((d[747596]|0)>>>0);if((d[747616]|0)!=(h|0)){a[747616]=h&255;i=(c[186900]|0)+h|0;if(i>>>0<94){a[747652]=a[675352+i|0]|0;j=a[675576+i|0]|0}else{a[747652]=0;j=-112}a[747653]=j;i=(c[186901]|0)+h|0;a[747654]=a[675352+i|0]|0;a[747655]=a[675576+i|0]|0;i=(c[186902]|0)+h|0;a[747656]=a[675352+i|0]|0;a[747657]=a[675576+i|0]|0;i=(c[186903]|0)+h|0;a[747658]=a[675352+i|0]|0;a[747659]=a[675576+i|0]|0}c[186945]=(ab((c[(c[186936]|0)+(g<<2)>>2]|0)+f&131071,c[186943]|0)|0)>>>1;i=g>>>((d[747748]|0)>>>0);if((d[747768]|0)!=(i|0)){a[747768]=i&255;h=(c[186938]|0)+i|0;if(h>>>0<94){a[747804]=a[675352+h|0]|0;k=a[675576+h|0]|0}else{a[747804]=0;k=-112}a[747805]=k;h=(c[186939]|0)+i|0;a[747806]=a[675352+h|0]|0;a[747807]=a[675576+h|0]|0;h=(c[186940]|0)+i|0;a[747808]=a[675352+h|0]|0;a[747809]=a[675576+h|0]|0;h=(c[186941]|0)+i|0;a[747810]=a[675352+h|0]|0;a[747811]=a[675576+h|0]|0}c[186926]=(ab((c[(c[186917]|0)+(g<<2)>>2]|0)+f&131071,c[186924]|0)|0)>>>1;h=g>>>((d[747672]|0)>>>0);if((d[747692]|0)!=(h|0)){a[747692]=h&255;i=(c[186919]|0)+h|0;if(i>>>0<94){a[747728]=a[675352+i|0]|0;l=a[675576+i|0]|0}else{a[747728]=0;l=-112}a[747729]=l;i=(c[186920]|0)+h|0;a[747730]=a[675352+i|0]|0;a[747731]=a[675576+i|0]|0;i=(c[186921]|0)+h|0;a[747732]=a[675352+i|0]|0;a[747733]=a[675576+i|0]|0;i=(c[186922]|0)+h|0;a[747734]=a[675352+i|0]|0;a[747735]=a[675576+i|0]|0}c[186964]=(ab((c[(c[186955]|0)+(g<<2)>>2]|0)+f&131071,c[186962]|0)|0)>>>1;f=g>>>((d[747824]|0)>>>0);if((d[747844]|0)==(f|0)){break}a[747844]=f&255;g=(c[186957]|0)+f|0;if(g>>>0<94){a[747880]=a[675352+g|0]|0;m=a[675576+g|0]|0}else{a[747880]=0;m=-112}a[747881]=m;g=(c[186958]|0)+f|0;a[747882]=a[675352+g|0]|0;a[747883]=a[675576+g|0]|0;g=(c[186959]|0)+f|0;a[747884]=a[675352+g|0]|0;a[747885]=a[675576+g|0]|0;g=(c[186960]|0)+f|0;a[747886]=a[675352+g|0]|0;a[747887]=a[675576+g|0]|0}}while(0);do{if((c[186997]|0)==-1){m=c[187075]|0;l=d[748304]|0;c[186997]=(ab((c[(c[186988]|0)+(l<<2)>>2]|0)+m&131071,c[186995]|0)|0)>>>1;k=l>>>((d[747956]|0)>>>0);if((d[747976]|0)!=(k|0)){a[747976]=k&255;j=(c[186990]|0)+k|0;if(j>>>0<94){a[748012]=a[675352+j|0]|0;n=a[675576+j|0]|0}else{a[748012]=0;n=-112}a[748013]=n;j=(c[186991]|0)+k|0;a[748014]=a[675352+j|0]|0;a[748015]=a[675576+j|0]|0;j=(c[186992]|0)+k|0;a[748016]=a[675352+j|0]|0;a[748017]=a[675576+j|0]|0;j=(c[186993]|0)+k|0;a[748018]=a[675352+j|0]|0;a[748019]=a[675576+j|0]|0}c[187035]=(ab((c[(c[187026]|0)+(l<<2)>>2]|0)+m&131071,c[187033]|0)|0)>>>1;j=l>>>((d[748108]|0)>>>0);if((d[748128]|0)!=(j|0)){a[748128]=j&255;k=(c[187028]|0)+j|0;if(k>>>0<94){a[748164]=a[675352+k|0]|0;o=a[675576+k|0]|0}else{a[748164]=0;o=-112}a[748165]=o;k=(c[187029]|0)+j|0;a[748166]=a[675352+k|0]|0;a[748167]=a[675576+k|0]|0;k=(c[187030]|0)+j|0;a[748168]=a[675352+k|0]|0;a[748169]=a[675576+k|0]|0;k=(c[187031]|0)+j|0;a[748170]=a[675352+k|0]|0;a[748171]=a[675576+k|0]|0}c[187016]=(ab((c[(c[187007]|0)+(l<<2)>>2]|0)+m&131071,c[187014]|0)|0)>>>1;k=l>>>((d[748032]|0)>>>0);if((d[748052]|0)!=(k|0)){a[748052]=k&255;j=(c[187009]|0)+k|0;if(j>>>0<94){a[748088]=a[675352+j|0]|0;p=a[675576+j|0]|0}else{a[748088]=0;p=-112}a[748089]=p;j=(c[187010]|0)+k|0;a[748090]=a[675352+j|0]|0;a[748091]=a[675576+j|0]|0;j=(c[187011]|0)+k|0;a[748092]=a[675352+j|0]|0;a[748093]=a[675576+j|0]|0;j=(c[187012]|0)+k|0;a[748094]=a[675352+j|0]|0;a[748095]=a[675576+j|0]|0}c[187054]=(ab((c[(c[187045]|0)+(l<<2)>>2]|0)+m&131071,c[187052]|0)|0)>>>1;m=l>>>((d[748184]|0)>>>0);if((d[748204]|0)==(m|0)){break}a[748204]=m&255;l=(c[187047]|0)+m|0;if(l>>>0<94){a[748240]=a[675352+l|0]|0;q=a[675576+l|0]|0}else{a[748240]=0;q=-112}a[748241]=q;l=(c[187048]|0)+m|0;a[748242]=a[675352+l|0]|0;a[748243]=a[675576+l|0]|0;l=(c[187049]|0)+m|0;a[748244]=a[675352+l|0]|0;a[748245]=a[675576+l|0]|0;l=(c[187050]|0)+m|0;a[748246]=a[675352+l|0]|0;a[748247]=a[675576+l|0]|0}}while(0);q=c[187441]|0;p=(c[187087]|0)==-1;do{if((q&192|0)==0){if(!p){break}o=c[187165]|0;n=d[748664]|0;c[187087]=(ab((c[(c[187078]|0)+(n<<2)>>2]|0)+o&131071,c[187085]|0)|0)>>>1;l=n>>>((d[748316]|0)>>>0);if((d[748336]|0)!=(l|0)){a[748336]=l&255;m=(c[187080]|0)+l|0;if(m>>>0<94){a[748372]=a[675352+m|0]|0;r=a[675576+m|0]|0}else{a[748372]=0;r=-112}a[748373]=r;m=(c[187081]|0)+l|0;a[748374]=a[675352+m|0]|0;a[748375]=a[675576+m|0]|0;m=(c[187082]|0)+l|0;a[748376]=a[675352+m|0]|0;a[748377]=a[675576+m|0]|0;m=(c[187083]|0)+l|0;a[748378]=a[675352+m|0]|0;a[748379]=a[675576+m|0]|0}c[187125]=(ab((c[(c[187116]|0)+(n<<2)>>2]|0)+o&131071,c[187123]|0)|0)>>>1;m=n>>>((d[748468]|0)>>>0);if((d[748488]|0)!=(m|0)){a[748488]=m&255;l=(c[187118]|0)+m|0;if(l>>>0<94){a[748524]=a[675352+l|0]|0;s=a[675576+l|0]|0}else{a[748524]=0;s=-112}a[748525]=s;l=(c[187119]|0)+m|0;a[748526]=a[675352+l|0]|0;a[748527]=a[675576+l|0]|0;l=(c[187120]|0)+m|0;a[748528]=a[675352+l|0]|0;a[748529]=a[675576+l|0]|0;l=(c[187121]|0)+m|0;a[748530]=a[675352+l|0]|0;a[748531]=a[675576+l|0]|0}c[187106]=(ab((c[(c[187097]|0)+(n<<2)>>2]|0)+o&131071,c[187104]|0)|0)>>>1;l=n>>>((d[748392]|0)>>>0);if((d[748412]|0)!=(l|0)){a[748412]=l&255;m=(c[187099]|0)+l|0;if(m>>>0<94){a[748448]=a[675352+m|0]|0;t=a[675576+m|0]|0}else{a[748448]=0;t=-112}a[748449]=t;m=(c[187100]|0)+l|0;a[748450]=a[675352+m|0]|0;a[748451]=a[675576+m|0]|0;m=(c[187101]|0)+l|0;a[748452]=a[675352+m|0]|0;a[748453]=a[675576+m|0]|0;m=(c[187102]|0)+l|0;a[748454]=a[675352+m|0]|0;a[748455]=a[675576+m|0]|0}c[187144]=(ab((c[(c[187135]|0)+(n<<2)>>2]|0)+o&131071,c[187142]|0)|0)>>>1;o=n>>>((d[748544]|0)>>>0);if((d[748564]|0)==(o|0)){break}a[748564]=o&255;n=(c[187137]|0)+o|0;if(n>>>0<94){a[748600]=a[675352+n|0]|0;u=a[675576+n|0]|0}else{a[748600]=0;u=-112}a[748601]=u;n=(c[187138]|0)+o|0;a[748602]=a[675352+n|0]|0;a[748603]=a[675576+n|0]|0;n=(c[187139]|0)+o|0;a[748604]=a[675352+n|0]|0;a[748605]=a[675576+n|0]|0;n=(c[187140]|0)+o|0;a[748606]=a[675352+n|0]|0;a[748607]=a[675576+n|0]|0}else{if(!p){break}n=d[750834]|0;c[187087]=(ab((c[(c[187078]|0)+(n<<2)>>2]|0)+(c[187706]|0)&131071,c[187085]|0)|0)>>>1;o=n>>>((d[748316]|0)>>>0);if((d[748336]|0)!=(o|0)){a[748336]=o&255;n=(c[187080]|0)+o|0;if(n>>>0<94){a[748372]=a[675352+n|0]|0;v=a[675576+n|0]|0}else{a[748372]=0;v=-112}a[748373]=v;n=(c[187081]|0)+o|0;a[748374]=a[675352+n|0]|0;a[748375]=a[675576+n|0]|0;n=(c[187082]|0)+o|0;a[748376]=a[675352+n|0]|0;a[748377]=a[675576+n|0]|0;n=(c[187083]|0)+o|0;a[748378]=a[675352+n|0]|0;a[748379]=a[675576+n|0]|0}n=d[750835]|0;c[187125]=(ab((c[(c[187116]|0)+(n<<2)>>2]|0)+(c[187707]|0)&131071,c[187123]|0)|0)>>>1;o=n>>>((d[748468]|0)>>>0);if((d[748488]|0)!=(o|0)){a[748488]=o&255;n=(c[187118]|0)+o|0;if(n>>>0<94){a[748524]=a[675352+n|0]|0;w=a[675576+n|0]|0}else{a[748524]=0;w=-112}a[748525]=w;n=(c[187119]|0)+o|0;a[748526]=a[675352+n|0]|0;a[748527]=a[675576+n|0]|0;n=(c[187120]|0)+o|0;a[748528]=a[675352+n|0]|0;a[748529]=a[675576+n|0]|0;n=(c[187121]|0)+o|0;a[748530]=a[675352+n|0]|0;a[748531]=a[675576+n|0]|0}n=d[750833]|0;c[187106]=(ab((c[(c[187097]|0)+(n<<2)>>2]|0)+(c[187705]|0)&131071,c[187104]|0)|0)>>>1;o=n>>>((d[748392]|0)>>>0);if((d[748412]|0)!=(o|0)){a[748412]=o&255;n=(c[187099]|0)+o|0;if(n>>>0<94){a[748448]=a[675352+n|0]|0;x=a[675576+n|0]|0}else{a[748448]=0;x=-112}a[748449]=x;n=(c[187100]|0)+o|0;a[748450]=a[675352+n|0]|0;a[748451]=a[675576+n|0]|0;n=(c[187101]|0)+o|0;a[748452]=a[675352+n|0]|0;a[748453]=a[675576+n|0]|0;n=(c[187102]|0)+o|0;a[748454]=a[675352+n|0]|0;a[748455]=a[675576+n|0]|0}n=d[748664]|0;c[187144]=(ab((c[(c[187135]|0)+(n<<2)>>2]|0)+(c[187165]|0)&131071,c[187142]|0)|0)>>>1;o=n>>>((d[748544]|0)>>>0);if((d[748564]|0)==(o|0)){break}a[748564]=o&255;n=(c[187137]|0)+o|0;if(n>>>0<94){a[748600]=a[675352+n|0]|0;y=a[675576+n|0]|0}else{a[748600]=0;y=-112}a[748601]=y;n=(c[187138]|0)+o|0;a[748602]=a[675352+n|0]|0;a[748603]=a[675576+n|0]|0;n=(c[187139]|0)+o|0;a[748604]=a[675352+n|0]|0;a[748605]=a[675576+n|0]|0;n=(c[187140]|0)+o|0;a[748606]=a[675352+n|0]|0;a[748607]=a[675576+n|0]|0}}while(0);do{if((c[187177]|0)==-1){y=c[187255]|0;x=d[749024]|0;c[187177]=(ab((c[(c[187168]|0)+(x<<2)>>2]|0)+y&131071,c[187175]|0)|0)>>>1;w=x>>>((d[748676]|0)>>>0);if((d[748696]|0)!=(w|0)){a[748696]=w&255;v=(c[187170]|0)+w|0;if(v>>>0<94){a[748732]=a[675352+v|0]|0;z=a[675576+v|0]|0}else{a[748732]=0;z=-112}a[748733]=z;v=(c[187171]|0)+w|0;a[748734]=a[675352+v|0]|0;a[748735]=a[675576+v|0]|0;v=(c[187172]|0)+w|0;a[748736]=a[675352+v|0]|0;a[748737]=a[675576+v|0]|0;v=(c[187173]|0)+w|0;a[748738]=a[675352+v|0]|0;a[748739]=a[675576+v|0]|0}c[187215]=(ab((c[(c[187206]|0)+(x<<2)>>2]|0)+y&131071,c[187213]|0)|0)>>>1;v=x>>>((d[748828]|0)>>>0);if((d[748848]|0)!=(v|0)){a[748848]=v&255;w=(c[187208]|0)+v|0;if(w>>>0<94){a[748884]=a[675352+w|0]|0;A=a[675576+w|0]|0}else{a[748884]=0;A=-112}a[748885]=A;w=(c[187209]|0)+v|0;a[748886]=a[675352+w|0]|0;a[748887]=a[675576+w|0]|0;w=(c[187210]|0)+v|0;a[748888]=a[675352+w|0]|0;a[748889]=a[675576+w|0]|0;w=(c[187211]|0)+v|0;a[748890]=a[675352+w|0]|0;a[748891]=a[675576+w|0]|0}c[187196]=(ab((c[(c[187187]|0)+(x<<2)>>2]|0)+y&131071,c[187194]|0)|0)>>>1;w=x>>>((d[748752]|0)>>>0);if((d[748772]|0)!=(w|0)){a[748772]=w&255;v=(c[187189]|0)+w|0;if(v>>>0<94){a[748808]=a[675352+v|0]|0;B=a[675576+v|0]|0}else{a[748808]=0;B=-112}a[748809]=B;v=(c[187190]|0)+w|0;a[748810]=a[675352+v|0]|0;a[748811]=a[675576+v|0]|0;v=(c[187191]|0)+w|0;a[748812]=a[675352+v|0]|0;a[748813]=a[675576+v|0]|0;v=(c[187192]|0)+w|0;a[748814]=a[675352+v|0]|0;a[748815]=a[675576+v|0]|0}c[187234]=(ab((c[(c[187225]|0)+(x<<2)>>2]|0)+y&131071,c[187232]|0)|0)>>>1;y=x>>>((d[748904]|0)>>>0);if((d[748924]|0)==(y|0)){break}a[748924]=y&255;x=(c[187227]|0)+y|0;if(x>>>0<94){a[748960]=a[675352+x|0]|0;C=a[675576+x|0]|0}else{a[748960]=0;C=-112}a[748961]=C;x=(c[187228]|0)+y|0;a[748962]=a[675352+x|0]|0;a[748963]=a[675576+x|0]|0;x=(c[187229]|0)+y|0;a[748964]=a[675352+x|0]|0;a[748965]=a[675576+x|0]|0;x=(c[187230]|0)+y|0;a[748966]=a[675352+x|0]|0;a[748967]=a[675576+x|0]|0}}while(0);do{if((c[187267]|0)==-1){C=c[187345]|0;B=d[749384]|0;c[187267]=(ab((c[(c[187258]|0)+(B<<2)>>2]|0)+C&131071,c[187265]|0)|0)>>>1;A=B>>>((d[749036]|0)>>>0);if((d[749056]|0)!=(A|0)){a[749056]=A&255;z=(c[187260]|0)+A|0;if(z>>>0<94){a[749092]=a[675352+z|0]|0;D=a[675576+z|0]|0}else{a[749092]=0;D=-112}a[749093]=D;z=(c[187261]|0)+A|0;a[749094]=a[675352+z|0]|0;a[749095]=a[675576+z|0]|0;z=(c[187262]|0)+A|0;a[749096]=a[675352+z|0]|0;a[749097]=a[675576+z|0]|0;z=(c[187263]|0)+A|0;a[749098]=a[675352+z|0]|0;a[749099]=a[675576+z|0]|0}c[187305]=(ab((c[(c[187296]|0)+(B<<2)>>2]|0)+C&131071,c[187303]|0)|0)>>>1;z=B>>>((d[749188]|0)>>>0);if((d[749208]|0)!=(z|0)){a[749208]=z&255;A=(c[187298]|0)+z|0;if(A>>>0<94){a[749244]=a[675352+A|0]|0;E=a[675576+A|0]|0}else{a[749244]=0;E=-112}a[749245]=E;A=(c[187299]|0)+z|0;a[749246]=a[675352+A|0]|0;a[749247]=a[675576+A|0]|0;A=(c[187300]|0)+z|0;a[749248]=a[675352+A|0]|0;a[749249]=a[675576+A|0]|0;A=(c[187301]|0)+z|0;a[749250]=a[675352+A|0]|0;a[749251]=a[675576+A|0]|0}c[187286]=(ab((c[(c[187277]|0)+(B<<2)>>2]|0)+C&131071,c[187284]|0)|0)>>>1;A=B>>>((d[749112]|0)>>>0);if((d[749132]|0)!=(A|0)){a[749132]=A&255;z=(c[187279]|0)+A|0;if(z>>>0<94){a[749168]=a[675352+z|0]|0;F=a[675576+z|0]|0}else{a[749168]=0;F=-112}a[749169]=F;z=(c[187280]|0)+A|0;a[749170]=a[675352+z|0]|0;a[749171]=a[675576+z|0]|0;z=(c[187281]|0)+A|0;a[749172]=a[675352+z|0]|0;a[749173]=a[675576+z|0]|0;z=(c[187282]|0)+A|0;a[749174]=a[675352+z|0]|0;a[749175]=a[675576+z|0]|0}c[187324]=(ab((c[(c[187315]|0)+(B<<2)>>2]|0)+C&131071,c[187322]|0)|0)>>>1;C=B>>>((d[749264]|0)>>>0);if((d[749284]|0)==(C|0)){break}a[749284]=C&255;B=(c[187317]|0)+C|0;if(B>>>0<94){a[749320]=a[675352+B|0]|0;G=a[675576+B|0]|0}else{a[749320]=0;G=-112}a[749321]=G;B=(c[187318]|0)+C|0;a[749322]=a[675352+B|0]|0;a[749323]=a[675576+B|0]|0;B=(c[187319]|0)+C|0;a[749324]=a[675352+B|0]|0;a[749325]=a[675576+B|0]|0;B=(c[187320]|0)+C|0;a[749326]=a[675352+B|0]|0;a[749327]=a[675576+B|0]|0}}while(0);do{if((c[187357]|0)==-1){G=c[187435]|0;F=d[749744]|0;c[187357]=(ab((c[(c[187348]|0)+(F<<2)>>2]|0)+G&131071,c[187355]|0)|0)>>>1;E=F>>>((d[749396]|0)>>>0);if((d[749416]|0)!=(E|0)){a[749416]=E&255;D=(c[187350]|0)+E|0;if(D>>>0<94){a[749452]=a[675352+D|0]|0;H=a[675576+D|0]|0}else{a[749452]=0;H=-112}a[749453]=H;D=(c[187351]|0)+E|0;a[749454]=a[675352+D|0]|0;a[749455]=a[675576+D|0]|0;D=(c[187352]|0)+E|0;a[749456]=a[675352+D|0]|0;a[749457]=a[675576+D|0]|0;D=(c[187353]|0)+E|0;a[749458]=a[675352+D|0]|0;a[749459]=a[675576+D|0]|0}c[187395]=(ab((c[(c[187386]|0)+(F<<2)>>2]|0)+G&131071,c[187393]|0)|0)>>>1;D=F>>>((d[749548]|0)>>>0);if((d[749568]|0)!=(D|0)){a[749568]=D&255;E=(c[187388]|0)+D|0;if(E>>>0<94){a[749604]=a[675352+E|0]|0;I=a[675576+E|0]|0}else{a[749604]=0;I=-112}a[749605]=I;E=(c[187389]|0)+D|0;a[749606]=a[675352+E|0]|0;a[749607]=a[675576+E|0]|0;E=(c[187390]|0)+D|0;a[749608]=a[675352+E|0]|0;a[749609]=a[675576+E|0]|0;E=(c[187391]|0)+D|0;a[749610]=a[675352+E|0]|0;a[749611]=a[675576+E|0]|0}c[187376]=(ab((c[(c[187367]|0)+(F<<2)>>2]|0)+G&131071,c[187374]|0)|0)>>>1;E=F>>>((d[749472]|0)>>>0);if((d[749492]|0)!=(E|0)){a[749492]=E&255;D=(c[187369]|0)+E|0;if(D>>>0<94){a[749528]=a[675352+D|0]|0;J=a[675576+D|0]|0}else{a[749528]=0;J=-112}a[749529]=J;D=(c[187370]|0)+E|0;a[749530]=a[675352+D|0]|0;a[749531]=a[675576+D|0]|0;D=(c[187371]|0)+E|0;a[749532]=a[675352+D|0]|0;a[749533]=a[675576+D|0]|0;D=(c[187372]|0)+E|0;a[749534]=a[675352+D|0]|0;a[749535]=a[675576+D|0]|0}c[187414]=(ab((c[(c[187405]|0)+(F<<2)>>2]|0)+G&131071,c[187412]|0)|0)>>>1;G=F>>>((d[749624]|0)>>>0);if((d[749644]|0)==(G|0)){break}a[749644]=G&255;F=(c[187407]|0)+G|0;if(F>>>0<94){a[749680]=a[675352+F|0]|0;K=a[675576+F|0]|0}else{a[749680]=0;K=-112}a[749681]=K;F=(c[187408]|0)+G|0;a[749682]=a[675352+F|0]|0;a[749683]=a[675576+F|0]|0;F=(c[187409]|0)+G|0;a[749684]=a[675352+F|0]|0;a[749685]=a[675576+F|0]|0;F=(c[187410]|0)+G|0;a[749686]=a[675352+F|0]|0;a[749687]=a[675576+F|0]|0}}while(0);if((e|0)>0){K=0;J=b;while(1){aIv(968040,0,24);b=6;I=747592;while(1){H=I|0;F=4;while(1){G=d[H+68|0]|0;do{if((G&8|0)!=0){D=H+48|0;E=c[D>>2]|0;if((E|0)<=511){break}B=H+40|0;C=a[B]|0;if((C&255)<=1){break}z=(G&2|0)!=0;do{if((G&1|0)==0){if(z){A=H+69|0;a[A]=a[A]^4}else{c[H+32>>2]=0}if(C<<24>>24==4){L=E;break}if(((d[H+24|0]|0)+(c[H+8>>2]|0)|0)>>>0>=94){c[D>>2]=0;a[B]=(c[H+52>>2]|0)==0?2:3;L=0;break}if((E|0)<1){M=(c[H+52>>2]|0)==0?2:3}else{M=4}a[B]=M;L=E}else{if(z){a[H+69|0]=4}if(C<<24>>24==4){L=E;break}if((d[H+69|0]|0)!=(G&4|0)){L=E;break}c[D>>2]=1023;L=1023}}while(0);if((d[H+69|0]|0)==(G&4|0)){c[H+56>>2]=(c[H+44>>2]|0)+L;break}else{c[H+56>>2]=(c[H+44>>2]|0)+(512-L&1023);break}}}while(0);G=F-1|0;if((G|0)==0){break}else{H=H+76|0;F=G}}F=b-1|0;if((F|0)==0){break}else{b=F;I=I+360|0}}if((a[749752]|0)==0){oo(6)}else{c[242015]=c[187439];oo(5)}I=c[187729]|0;do{if((I|0)!=0){b=(c[187728]|0)+1|0;c[187728]=b;if(b>>>0<I>>>0){break}c[187728]=0;b=(a[750908]|0)+1&127;a[750908]=b;F=b&255;H=F<<1;c[187730]=(b&255)<64?H^126:H&126;c[187731]=F>>>2}}while(0);I=(c[187726]|0)+1|0;c[187726]=I;if(I>>>0>2){c[187726]=0;I=(c[187725]|0)+1|0;c[187725]=I;F=6;H=747592;while(1){b=H|0;G=4;while(1){D=b+40|0;E=d[D]|0;L18395:do{if((E|0)==1){C=d[b+66|0]|0;if(((1<<C)-1&I|0)!=0){break}do{if((a[b+68|0]&8)==0){z=b+48|0;B=(c[z>>2]|0)+(d[675824+((d[b+67|0]|0)+(I>>>(C>>>0)&7))|0]|0)|0;c[z>>2]=B;if((B|0)<=1022){N=B;break}c[z>>2]=1023;a[D]=0;N=1023}else{z=b+48|0;B=c[z>>2]|0;if((B|0)<512){A=(d[675824+((d[b+67|0]|0)+(I>>>(C>>>0)&7))|0]<<2)+B|0;c[z>>2]=A;if((A|0)<=511){N=A;break}}c[z>>2]=1023;a[D]=0;N=1023}}while(0);c[b+56>>2]=(c[b+44>>2]|0)+N}else if((E|0)==3){C=d[b+62|0]|0;if(((1<<C)-1&I|0)!=0){break}z=a[b+68|0]|0;do{if((z&8)==0){A=b+48|0;B=(c[A>>2]|0)+(d[675824+((d[b+63|0]|0)+(I>>>(C>>>0)&7))|0]|0)|0;c[A>>2]=B;c[b+56>>2]=B+(c[b+44>>2]|0);O=B}else{B=b+48|0;A=c[B>>2]|0;if((A|0)>=512){O=A;break}x=(d[675824+((d[b+63|0]|0)+(I>>>(C>>>0)&7))|0]<<2)+A|0;c[B>>2]=x;if((d[b+69|0]|0)==(z&4|0)){c[b+56>>2]=(c[b+44>>2]|0)+x;O=x;break}else{c[b+56>>2]=(c[b+44>>2]|0)+(512-x&1023);O=x;break}}}while(0);if((O|0)<(c[b+52>>2]|0)){break}a[D]=2}else if((E|0)==2){z=d[b+64|0]|0;if(((1<<z)-1&I|0)!=0){break}C=a[b+68|0]|0;if((C&8)==0){x=b+48|0;B=(c[x>>2]|0)+(d[675824+((d[b+65|0]|0)+(I>>>(z>>>0)&7))|0]|0)|0;A=(B|0)<1023?B:1023;c[x>>2]=A;c[b+56>>2]=A+(c[b+44>>2]|0);break}A=b+48|0;x=c[A>>2]|0;if((x|0)>=512){break}B=(d[675824+((d[b+65|0]|0)+(I>>>(z>>>0)&7))|0]<<2)+x|0;c[A>>2]=B;if((d[b+69|0]|0)==(C&4|0)){c[b+56>>2]=(c[b+44>>2]|0)+B;break}else{c[b+56>>2]=(c[b+44>>2]|0)+(512-B&1023);break}}else if((E|0)==4){B=d[b+60|0]|0;if(((1<<B)-1&I|0)!=0){break}C=b+48|0;A=c[C>>2]|0;x=((ab(d[675824+((d[b+61|0]|0)+(I>>>(B>>>0)&7))|0]|0,~A)|0)>>4)+A|0;c[C>>2]=x;if((x|0)<1){c[C>>2]=0;a[D]=(c[b+52>>2]|0)==0?2:3;P=0}else{P=x}x=d[b+68|0]|0;do{if((x&8|0)!=0){if((d[b+69|0]|0)==(x&4|0)){break}c[b+56>>2]=(c[b+44>>2]|0)+(512-P&1023);break L18395}}while(0);c[b+56>>2]=(c[b+44>>2]|0)+P}}while(0);D=G-1|0;if((D|0)==0){break}else{b=b+76|0;G=D}}G=F-1|0;if((G|0)==0){break}else{F=G;H=H+360|0}}}H=c[242010]|0;do{if((H|0)>8192){c[242010]=8192;Q=8192}else{if((H|0)>=-8192){Q=H;break}c[242010]=-8192;Q=-8192}}while(0);H=c[242011]|0;do{if((H|0)>8192){c[242011]=8192;R=8192}else{if((H|0)>=-8192){R=H;break}c[242011]=-8192;R=-8192}}while(0);H=c[242012]|0;do{if((H|0)>8192){c[242012]=8192;S=8192}else{if((H|0)>=-8192){S=H;break}c[242012]=-8192;S=-8192}}while(0);H=c[242013]|0;do{if((H|0)>8192){c[242013]=8192;T=8192}else{if((H|0)>=-8192){T=H;break}c[242013]=-8192;T=-8192}}while(0);H=c[242014]|0;do{if((H|0)>8192){c[242014]=8192;U=8192}else{if((H|0)>=-8192){U=H;break}c[242014]=-8192;U=-8192}}while(0);H=c[242015]|0;do{if((H|0)>8192){c[242015]=8192;V=8192}else{if((H|0)>=-8192){V=H;break}c[242015]=-8192;V=-8192}}while(0);H=(c[187716]&R)+(c[187714]&Q)+(c[187718]&S)+(c[187720]&T)+(c[187722]&U)+(c[187724]&V)|0;c[J>>2]=(c[187715]&R)+(c[187713]&Q)+(c[187717]&S)+(c[187719]&T)+(c[187721]&U)+(c[187723]&V);F=J+8|0;c[J+4>>2]=H;H=a[750848]<<1;a[750848]=H;I=c[187441]|0;do{if((I&1|0)==0){W=13787}else{G=(c[187445]|0)-1|0;c[187445]=G;if((G|0)>=1){W=13787;break}if((I&4|0)!=0){a[749762]=a[749762]|1}c[187445]=c[187444];if((I&192|0)!=128){W=13787;break}do{if((a[748382]|H)<<24>>24==0){c[187086]=0;a[748381]=0;do{if(((d[748336]|0)+(c[187080]|0)|0)>>>0<94){G=c[187090]|0;if((G|0)>=1){X=G;Y=4;break}X=G;Y=(c[187091]|0)==0?2:3}else{c[187090]=0;X=0;Y=(c[187091]|0)==0?2:3}}while(0);a[748352]=Y;if((a[748380]&12)==12){c[187092]=(c[187089]|0)+(512-X&1023);break}else{c[187092]=(c[187089]|0)+X;break}}}while(0);do{if((a[748534]|H)<<24>>24==0){c[187124]=0;a[748533]=0;do{if(((d[748488]|0)+(c[187118]|0)|0)>>>0<94){G=c[187128]|0;if((G|0)>=1){Z=G;_=4;break}Z=G;_=(c[187129]|0)==0?2:3}else{c[187128]=0;Z=0;_=(c[187129]|0)==0?2:3}}while(0);a[748504]=_;if((a[748532]&12)==12){c[187130]=(c[187127]|0)+(512-Z&1023);break}else{c[187130]=(c[187127]|0)+Z;break}}}while(0);do{if((a[748458]|H)<<24>>24==0){c[187105]=0;a[748457]=0;do{if(((d[748412]|0)+(c[187099]|0)|0)>>>0<94){G=c[187109]|0;if((G|0)>=1){$=G;aa=4;break}$=G;aa=(c[187110]|0)==0?2:3}else{c[187109]=0;$=0;aa=(c[187110]|0)==0?2:3}}while(0);a[748428]=aa;if((a[748456]&12)==12){c[187111]=(c[187108]|0)+(512-$&1023);break}else{c[187111]=(c[187108]|0)+$;break}}}while(0);do{if((a[748610]|H)<<24>>24==0){c[187143]=0;a[748609]=0;do{if(((d[748564]|0)+(c[187137]|0)|0)>>>0<94){G=c[187147]|0;if((G|0)>=1){ac=G;ad=4;break}ac=G;ad=(c[187148]|0)==0?2:3}else{c[187147]=0;ac=0;ad=(c[187148]|0)==0?2:3}}while(0);a[748580]=ad;if((a[748608]&12)==12){c[187149]=(c[187146]|0)+(512-ac&1023);break}else{c[187149]=(c[187146]|0)+ac;break}}}while(0);a[750848]=1}}while(0);do{if((W|0)==13787){W=0;if((H&2)==0){break}do{if((a[748382]|0)==0&(d[748352]|0)>1){a[748352]=1;G=d[748380]|0;if((G&8|0)==0){break}b=c[187090]|0;if((d[748381]|0)==(G&4|0)){ae=b}else{G=512-b|0;c[187090]=G;ae=G}if((ae|0)>511){c[187090]=1023;a[748352]=0;af=1023}else{af=ae}c[187092]=(c[187089]|0)+af}}while(0);do{if((a[748534]|0)==0&(d[748504]|0)>1){a[748504]=1;G=d[748532]|0;if((G&8|0)==0){break}b=c[187128]|0;if((d[748533]|0)==(G&4|0)){ag=b}else{G=512-b|0;c[187128]=G;ag=G}if((ag|0)>511){c[187128]=1023;a[748504]=0;ah=1023}else{ah=ag}c[187130]=(c[187127]|0)+ah}}while(0);do{if((a[748458]|0)==0&(d[748428]|0)>1){a[748428]=1;G=d[748456]|0;if((G&8|0)==0){break}b=c[187109]|0;if((d[748457]|0)==(G&4|0)){ai=b}else{G=512-b|0;c[187109]=G;ai=G}if((ai|0)>511){c[187109]=1023;a[748428]=0;aj=1023}else{aj=ai}c[187111]=(c[187108]|0)+aj}}while(0);do{if((a[748610]|0)==0&(d[748580]|0)>1){a[748580]=1;G=d[748608]|0;if((G&8|0)==0){break}b=c[187147]|0;if((d[748609]|0)==(G&4|0)){ak=b}else{G=512-b|0;c[187147]=G;ak=G}if((ak|0)>511){c[187147]=1023;a[748580]=0;al=1023}else{al=ak}c[187149]=(c[187146]|0)+al}}while(0);a[750848]=0}}while(0);H=K+1|0;if((H|0)<(e|0)){K=H;J=F}else{am=I;break}}}else{am=q}if((am&2|0)==0){return}q=(c[187448]|0)-e|0;c[187448]=q;if((q|0)>=1){return}if((am&8|0)!=0){a[749762]=a[749762]|2}am=c[187447]|0;if((am|0)==0){c[187448]=0;return}else{c[187448]=am+q;return}}function on(a){a=a|0;var b=0;b=-1<<14-(a&255);c[3184688]=b;if((c[187713]|0)!=0){c[187713]=b}if((c[187714]|0)!=0){c[187714]=b}if((c[187715]|0)!=0){c[187715]=b}if((c[187716]|0)!=0){c[187716]=b}if((c[187717]|0)!=0){c[187717]=b}if((c[187718]|0)!=0){c[187718]=b}if((c[187719]|0)!=0){c[187719]=b}if((c[187720]|0)!=0){c[187720]=b}if((c[187721]|0)!=0){c[187721]=b}if((c[187722]|0)!=0){c[187722]=b}if((c[187723]|0)!=0){c[187723]=b}if((c[187724]|0)==0){return}c[187724]=b;return}function oo(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=747592;f=b;while(1){b=(c[187730]|0)>>>((d[e+344|0]|0)>>>0);g=(b&c[e+72>>2])+(c[e+56>>2]|0)|0;c[290338]=0;c[3118618]=0;c[3118620]=0;c[291708]=0;h=e+336|0;c[c[e+332>>2]>>2]=c[h>>2];i=e+308|0;j=e+312|0;k=c[j>>2]|0;l=k+(c[i>>2]|0)|0;c[i>>2]=k;i=c[e+316>>2]|0;if((i|0)==0){c[3118618]=k;c[3118620]=k;c[290338]=k}else{c[i>>2]=(c[i>>2]|0)+k}c[j>>2]=0;if(g>>>0<832){k=a[e+305|0]|0;i=(c[951960+(((((k<<24>>24==0?0:l)<<(k&255))+(c[e+32>>2]|0)|0)>>>10&1023)<<2)>>2]|0)+(g<<3)|0;if(i>>>0>6655){m=0}else{m=c[910760+(i<<2)>>2]|0}c[j>>2]=m}j=(c[e+148>>2]&b)+(c[e+132>>2]|0)|0;if(j>>>0<832){i=(c[951960+((((c[291708]|0)>>>1)+((c[e+108>>2]|0)>>>10)&1023)<<2)>>2]|0)+(j<<3)|0;if(i>>>0>6655){n=0}else{n=c[910760+(i<<2)>>2]|0}i=c[e+320>>2]|0;c[i>>2]=(c[i>>2]|0)+n}i=(c[e+224>>2]&b)+(c[e+208>>2]|0)|0;if(i>>>0<832){j=(c[951960+((((c[3118620]|0)>>>1)+((c[e+184>>2]|0)>>>10)&1023)<<2)>>2]|0)+(i<<3)|0;if(j>>>0>6655){o=0}else{o=c[910760+(j<<2)>>2]|0}j=c[e+324>>2]|0;c[j>>2]=(c[j>>2]|0)+o}j=(c[e+300>>2]&b)+(c[e+284>>2]|0)|0;if(j>>>0<832){b=(c[951960+((((c[3118618]|0)>>>1)+((c[e+260>>2]|0)>>>10)&1023)<<2)>>2]|0)+(j<<3)|0;if(b>>>0>6655){p=0}else{p=c[910760+(b<<2)>>2]|0}b=c[e+328>>2]|0;c[b>>2]=(c[b>>2]|0)+p}c[h>>2]=c[290338];h=e+340|0;b=c[h>>2]|0;do{if((b|0)==0){j=e+32|0;c[j>>2]=(c[j>>2]|0)+(c[e+36>>2]|0);j=e+184|0;c[j>>2]=(c[j>>2]|0)+(c[e+188>>2]|0);j=e+108|0;c[j>>2]=(c[j>>2]|0)+(c[e+112>>2]|0);j=e+260|0;c[j>>2]=(c[j>>2]|0)+(c[e+264>>2]|0)}else{if(!((c[187441]&192|0)!=0&(e|0)==748312)){j=c[e+356>>2]|0;i=c[1561112+((c[187731]|0)+b+(j>>>4<<8&32512)<<2)>>2]|0;if((i|0)==0){g=e+32|0;c[g>>2]=(c[g>>2]|0)+(c[e+36>>2]|0);g=e+184|0;c[g>>2]=(c[g>>2]|0)+(c[e+188>>2]|0);g=e+108|0;c[g>>2]=(c[g>>2]|0)+(c[e+112>>2]|0);g=e+260|0;c[g>>2]=(c[g>>2]|0)+(c[e+264>>2]|0);break}else{g=i+(j<<1)|0;j=g&4095;i=g>>>12&7;g=d[11112+(j>>>8)|0]|0|i<<2;k=j<<5>>>((i^7)>>>0);i=(ab((c[(c[e>>2]|0)+(g<<2)>>2]|0)+k&131071,c[e+28>>2]|0)|0)>>>1;j=e+32|0;c[j>>2]=i+(c[j>>2]|0);j=(ab((c[(c[e+152>>2]|0)+(g<<2)>>2]|0)+k&131071,c[e+180>>2]|0)|0)>>>1;i=e+184|0;c[i>>2]=j+(c[i>>2]|0);i=(ab((c[(c[e+76>>2]|0)+(g<<2)>>2]|0)+k&131071,c[e+104>>2]|0)|0)>>>1;j=e+108|0;c[j>>2]=i+(c[j>>2]|0);j=(ab((c[(c[e+228>>2]|0)+(g<<2)>>2]|0)+k&131071,c[e+256>>2]|0)|0)>>>1;k=e+260|0;c[k>>2]=j+(c[k>>2]|0);break}}k=c[187710]|0;j=c[187731]|0;g=c[1561112+(j+b+(k>>>4<<8&32512)<<2)>>2]|0;if((g|0)==0){q=(c[187086]|0)+(c[187087]|0)|0}else{i=g+(k<<1)|0;k=i&4095;g=i>>>12&7;i=(ab((c[(c[187078]|0)+((d[11112+(k>>>8)|0]|0|g<<2)<<2)>>2]|0)+(k<<5>>>((g^7)>>>0))&131071,c[187085]|0)|0)>>>1;q=i+(c[187086]|0)|0}c[187086]=q;i=c[187711]|0;g=c[1561112+((c[h>>2]|0)+j+(i>>>4<<8&32512)<<2)>>2]|0;if((g|0)==0){r=(c[187124]|0)+(c[187125]|0)|0}else{k=g+(i<<1)|0;i=k&4095;g=k>>>12&7;k=(ab((c[(c[187116]|0)+((d[11112+(i>>>8)|0]|0|g<<2)<<2)>>2]|0)+(i<<5>>>((g^7)>>>0))&131071,c[187123]|0)|0)>>>1;r=k+(c[187124]|0)|0}c[187124]=r;k=c[187709]|0;g=c[1561112+((c[h>>2]|0)+j+(k>>>4<<8&32512)<<2)>>2]|0;if((g|0)==0){s=(c[187105]|0)+(c[187106]|0)|0}else{i=g+(k<<1)|0;k=i&4095;g=i>>>12&7;i=(ab((c[(c[187097]|0)+((d[11112+(k>>>8)|0]|0|g<<2)<<2)>>2]|0)+(k<<5>>>((g^7)>>>0))&131071,c[187104]|0)|0)>>>1;s=i+(c[187105]|0)|0}c[187105]=s;i=c[187167]|0;g=c[1561112+((c[h>>2]|0)+j+(i>>>4<<8&32512)<<2)>>2]|0;if((g|0)==0){c[187143]=(c[187143]|0)+(c[187144]|0);break}else{j=g+(i<<1)|0;i=j&4095;g=j>>>12&7;j=(ab((c[(c[187135]|0)+((d[11112+(i>>>8)|0]|0|g<<2)<<2)>>2]|0)+(i<<5>>>((g^7)>>>0))&131071,c[187142]|0)|0)>>>1;c[187143]=j+(c[187143]|0);break}}}while(0);h=f-1|0;if((h|0)==0){break}else{e=e+360|0;f=h}}return}function op(){var b=0;c[188150]=0;c[188149]=0;c[188158]=1;b=752644;c[b>>2]=306990153;c[b+4>>2]=0;b=752652;c[b>>2]=387866977;c[b+4>>2]=385906928;b=752660;c[b>>2]=220086547;c[b+4>>2]=320075735;b=752668;c[b>>2]=77136147;c[b+4>>2]=588379378;b=752676;c[b>>2]=119234849;c[b+4>>2]=658531503;b=752684;c[b>>2]=102637858;c[b+4>>2]=403207664;b=752692;c[b>>2]=85336625;c[b+4>>2]=318796176;b=752700;c[b>>2]=119365921;c[b+4>>2]=386957442;b=752708;c[b>>2]=372056355;c[b+4>>2]=117928128;b=752716;c[b>>2]=102457697;c[b+4>>2]=386950500;b=752724;c[b>>2]=403464545;c[b+4>>2]=124842117;b=752732;c[b>>2]=285671715;c[b+4>>2]=570467568;b=752740;c[b>>2]=119849367;c[b+4>>2]=304281855;b=752748;c[b>>2]=84676705;c[b+4>>2]=1145107698;b=752756;c[b>>2]=55902465;c[b+4>>2]=-202140941;b=752764;c[b>>2]=59326817;c[b+4>>2]=334558449;b=752772;c[b>>2]=1442049;c[b+4>>2]=1831860477;b=752780;c[b>>2]=257;c[b+4>>2]=-117843752;b=752788;c[b>>2]=261;c[b+4>>2]=1430895352;b=63;do{oq(b,0);b=b-1|0;}while((b|0)>15);c[187752]=0;a[750965]=0;c[187744]=255;c[187773]=0;a[751049]=0;c[187765]=255;c[187798]=0;a[751149]=0;c[187790]=255;c[187819]=0;a[751233]=0;c[187811]=255;c[187844]=0;a[751333]=0;c[187836]=255;c[187865]=0;a[751417]=0;c[187857]=255;c[187890]=0;a[751517]=0;c[187882]=255;c[187911]=0;a[751601]=0;c[187903]=255;c[187936]=0;a[751701]=0;c[187928]=255;c[187957]=0;a[751785]=0;c[187949]=255;c[187982]=0;a[751885]=0;c[187974]=255;c[188003]=0;a[751969]=0;c[187995]=255;c[188028]=0;a[752069]=0;c[188020]=255;c[188049]=0;a[752153]=0;c[188041]=255;c[188074]=0;a[752253]=0;c[188066]=255;c[188095]=0;a[752337]=0;c[188087]=255;c[188120]=0;a[752437]=0;c[188112]=255;c[188141]=0;a[752521]=0;c[188133]=255;return}function oq(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=e&255;g=b&240;if((g|0)==0){switch(b&15|0){case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{a[752644+(b&255)|0]=e&255;h=(a[752612]&32)==0?9:6;switch(b&7|0){case 2:{i=0;do{if((d[752584+i|0]|0)<16){j=d[752646]|0;k=j>>>6;if((k|0)==0){l=31}else{l=(k^3)&255}a[750941+(i*184|0)|0]=l;k=j<<1&126;c[750968+(i*184|0)>>2]=k;c[750972+(i*184|0)>>2]=((c[751104+(i*184|0)>>2]|0)>>>((l&255)>>>0))+k}i=i+1|0;}while(i>>>0<h>>>0);return};case 1:{i=0;do{if((d[752584+i|0]|0)<16){l=a[752645]|0;k=l&255;j=(i<<1|1|0)/2|0;m=a[11144+(k&15)|0]|0;a[751027+(j*184|0)|0]=m;n=(l&255)>>>3&2^2;a[751024+(j*184|0)|0]=n;a[751048+(j*184|0)|0]=l&32;a[751088+(j*184|0)|0]=l&64;c[751084+(j*184|0)>>2]=k<<24>>31;c[751032+(j*184|0)>>2]=ab(m&255,c[751100+(j*184|0)>>2]|0)|0;m=(d[751108+(j*184|0)|0]|0)>>>((n&255)>>>0);n=751026+(j*184|0)|0;k=a[n]|0;if((k&255|0)==(m|0)){o=k}else{k=m&255;a[n]=k;n=m&255;m=(c[751012+(j*184|0)>>2]|0)+n|0;if(m>>>0<78){a[751070+(j*184|0)|0]=a[675256+m|0]|0;a[751071+(j*184|0)|0]=a[675480+m|0]|0}else{a[751070+(j*184|0)|0]=0;a[751071+(j*184|0)|0]=104}m=(c[751016+(j*184|0)>>2]|0)+n|0;a[751072+(j*184|0)|0]=a[675256+m|0]|0;a[751073+(j*184|0)|0]=a[675480+m|0]|0;m=(c[751020+(j*184|0)>>2]|0)+n|0;a[751074+(j*184|0)|0]=a[675256+m|0]|0;a[751075+(j*184|0)|0]=a[675480+m|0]|0;o=k}k=o&255;m=((a[751109+(j*184|0)|0]|0)==0?44:36)+k|0;a[751076+(j*184|0)|0]=a[675256+m|0]|0;a[751077+(j*184|0)|0]=a[675480+m|0]|0;m=k+68|0;a[751068+(j*184|0)|0]=a[675256+m|0]|0;a[751069+(j*184|0)|0]=a[675480+m|0]|0}i=i+1|0;}while(i>>>0<h>>>0);return};case 0:{i=0;do{if((d[752584+i|0]|0)<16){o=a[752644]|0;m=o&255;j=(i<<1|0)/2|0;k=a[11144+(m&15)|0]|0;a[750943+(j*184|0)|0]=k;n=(o&255)>>>3&2^2;a[750940+(j*184|0)|0]=n;a[750964+(j*184|0)|0]=o&32;a[751004+(j*184|0)|0]=o&64;c[751e3+(j*184|0)>>2]=m<<24>>31;c[750948+(j*184|0)>>2]=ab(k&255,c[751100+(j*184|0)>>2]|0)|0;k=(d[751108+(j*184|0)|0]|0)>>>((n&255)>>>0);n=750942+(j*184|0)|0;m=a[n]|0;if((m&255|0)==(k|0)){p=m}else{m=k&255;a[n]=m;n=k&255;k=(c[750928+(j*184|0)>>2]|0)+n|0;if(k>>>0<78){a[750986+(j*184|0)|0]=a[675256+k|0]|0;a[750987+(j*184|0)|0]=a[675480+k|0]|0}else{a[750986+(j*184|0)|0]=0;a[750987+(j*184|0)|0]=104}k=(c[750932+(j*184|0)>>2]|0)+n|0;a[750988+(j*184|0)|0]=a[675256+k|0]|0;a[750989+(j*184|0)|0]=a[675480+k|0]|0;k=(c[750936+(j*184|0)>>2]|0)+n|0;a[750990+(j*184|0)|0]=a[675256+k|0]|0;a[750991+(j*184|0)|0]=a[675480+k|0]|0;p=m}m=p&255;k=((a[751109+(j*184|0)|0]|0)==0?44:36)+m|0;a[750992+(j*184|0)|0]=a[675256+k|0]|0;a[750993+(j*184|0)|0]=a[675480+k|0]|0;k=m+68|0;a[750984+(j*184|0)|0]=a[675256+k|0]|0;a[750985+(j*184|0)|0]=a[675480+k|0]|0}i=i+1|0;}while(i>>>0<h>>>0);return};case 3:{i=0;do{if((d[752584+i|0]|0)<16){p=d[752647]|0;c[751008+(i*184|0)>>2]=p>>>3<<10&1024;k=p&7;if((k|0)==0){q=0}else{q=(k|8)&255}a[750952+(i*184|0)|0]=q;c[751092+(i*184|0)>>2]=p>>>4<<10&1024;k=p>>>6;if((k|0)==0){r=31}else{r=(k^3)&255}a[751025+(i*184|0)|0]=r;c[751056+(i*184|0)>>2]=((c[751104+(i*184|0)>>2]|0)>>>((r&255)>>>0))+(c[751052+(i*184|0)>>2]|0)}i=i+1|0;}while(i>>>0<h>>>0);return};case 4:{i=0;do{if((d[752584+i|0]|0)<16){r=d[752648]|0;q=(i<<1|0)/2|0;k=r>>>4;if((k|0)==0){s=0}else{s=(k<<2)+16|0}c[750928+(q*184|0)>>2]=s;k=d[750942+(q*184|0)|0]|0;p=k+s|0;if(p>>>0<78){a[750986+(q*184|0)|0]=a[675256+p|0]|0;a[750987+(q*184|0)|0]=a[675480+p|0]|0}else{a[750986+(q*184|0)|0]=0;a[750987+(q*184|0)|0]=104}p=r&15;if((p|0)==0){t=0}else{t=(p<<2)+16|0}c[750932+(q*184|0)>>2]=t;p=t+k|0;a[750988+(q*184|0)|0]=a[675256+p|0]|0;a[750989+(q*184|0)|0]=a[675480+p|0]|0}i=i+1|0;}while(i>>>0<h>>>0);return};case 5:{i=0;do{if((d[752584+i|0]|0)<16){t=d[752649]|0;s=(i<<1|1|0)/2|0;p=t>>>4;if((p|0)==0){u=0}else{u=(p<<2)+16|0}c[751012+(s*184|0)>>2]=u;p=d[751026+(s*184|0)|0]|0;q=p+u|0;if(q>>>0<78){a[751070+(s*184|0)|0]=a[675256+q|0]|0;a[751071+(s*184|0)|0]=a[675480+q|0]|0}else{a[751070+(s*184|0)|0]=0;a[751071+(s*184|0)|0]=104}q=t&15;if((q|0)==0){v=0}else{v=(q<<2)+16|0}c[751016+(s*184|0)>>2]=v;q=v+p|0;a[751072+(s*184|0)|0]=a[675256+q|0]|0;a[751073+(s*184|0)|0]=a[675480+q|0]|0}i=i+1|0;}while(i>>>0<h>>>0);return};case 6:{i=0;do{if((d[752584+i|0]|0)<16){v=d[752650]|0;u=(i<<1|0)/2|0;c[750980+(u*184|0)>>2]=c[2440+(v>>>4<<2)>>2];q=v&15;if((q|0)==0){w=0}else{w=(q<<2)+16|0}c[750936+(u*184|0)>>2]=w;q=(d[750942+(u*184|0)|0]|0)+w|0;a[750990+(u*184|0)|0]=a[675256+q|0]|0;a[750991+(u*184|0)|0]=a[675480+q|0]|0}i=i+1|0;}while(i>>>0<h>>>0);return};case 7:{i=0;do{if((d[752584+i|0]|0)<16){w=d[752651]|0;q=(i<<1|1|0)/2|0;c[751064+(q*184|0)>>2]=c[2440+(w>>>4<<2)>>2];u=w&15;if((u|0)==0){x=0}else{x=(u<<2)+16|0}c[751020+(q*184|0)>>2]=x;u=(d[751026+(q*184|0)|0]|0)+x|0;a[751074+(q*184|0)|0]=a[675256+u|0]|0;a[751075+(q*184|0)|0]=a[675480+u|0]|0}i=i+1|0;}while(i>>>0<h>>>0);return};default:{return}}break};case 14:{h=(a[752612]&32)==0;do{if((e&32|0)==0){if(!h){ot(6,12,752644+((d[752590]|0)>>>4<<3)|0);ot(7,14,752644+((d[752591]|0)>>>4<<3)|0);ot(8,16,752644+((d[752592]|0)>>>4<<3)|0)}i=c[188025]|0;do{if((i|0)!=0){x=i&-3;c[188025]=x;if(!((x|0)==0&(d[752069]|0)>1)){break}a[752069]=1}}while(0);i=c[188046]|0;do{if((i|0)!=0){x=i&-3;c[188046]=x;if(!((x|0)==0&(d[752153]|0)>1)){break}a[752153]=1}}while(0);i=c[188071]|0;do{if((i|0)!=0){x=i&-3;c[188071]=x;if(!((x|0)==0&(d[752253]|0)>1)){break}a[752253]=1}}while(0);i=c[188092]|0;do{if((i|0)!=0){x=i&-3;c[188092]=x;if(!((x|0)==0&(d[752337]|0)>1)){break}a[752337]=1}}while(0);i=c[188117]|0;do{if((i|0)!=0){x=i&-3;c[188117]=x;if(!((x|0)==0&(d[752437]|0)>1)){break}a[752437]=1}}while(0);i=c[188138]|0;if((i|0)==0){break}x=i&-3;c[188138]=x;if(!((x|0)==0&(d[752521]|0)>1)){break}a[752521]=1}else{if(h){ot(6,12,752772);ot(7,14,752780);x=(d[752591]|0)>>>4<<3;c[188064]=x;c[188065]=((c[188098]|0)>>>((d[752229]|0)>>>0))+x;ot(8,16,752788);x=(d[752592]|0)>>>4<<3;c[188110]=x;c[188111]=((c[188144]|0)>>>((d[752413]|0)>>>0))+x}x=c[188025]|0;i=(x|0)==0;do{if((e&16|0)==0){do{if(!i){u=x&-3;c[188025]=u;if(!((u|0)==0&(d[752069]|0)>1)){break}a[752069]=1}}while(0);u=c[188046]|0;if((u|0)==0){break}q=u&-3;c[188046]=q;if(!((q|0)==0&(d[752153]|0)>1)){break}a[752153]=1}else{if(i){a[752069]=5}c[188025]=x|2;q=c[188046]|0;if((q|0)==0){a[752153]=5}c[188046]=q|2}}while(0);x=c[188071]|0;i=(x|0)==0;do{if((e&1|0)==0){if(i){break}q=x&-3;c[188071]=q;if(!((q|0)==0&(d[752253]|0)>1)){break}a[752253]=1}else{if(i){a[752253]=5}c[188071]=x|2}}while(0);x=c[188092]|0;i=(x|0)==0;do{if((e&8|0)==0){if(i){break}q=x&-3;c[188092]=q;if(!((q|0)==0&(d[752337]|0)>1)){break}a[752337]=1}else{if(i){a[752337]=5}c[188092]=x|2}}while(0);x=c[188117]|0;i=(x|0)==0;do{if((e&4|0)==0){if(i){break}q=x&-3;c[188117]=q;if(!((q|0)==0&(d[752437]|0)>1)){break}a[752437]=1}else{if(i){a[752437]=5}c[188117]=x|2}}while(0);x=c[188138]|0;i=(x|0)==0;if((e&2|0)==0){if(i){break}q=x&-3;c[188138]=q;if(!((q|0)==0&(d[752521]|0)>1)){break}a[752521]=1;break}else{if(i){a[752521]=5}c[188138]=x|2;break}}}while(0);a[752612]=e&63;return};default:{return}}}else if((g|0)==16|(g|0)==32){h=b&15;x=h>>>0>8?h-9|0:h;if((b&16|0)==0){h=c[751096+(x*184|0)>>2]|0;i=h&255|e<<8&3840;q=750996+(x*184|0)|0;u=c[q>>2]|0;w=(u|0)==0;do{if((e&16|0)==0){do{if(!w){v=u&-2;c[q>>2]=v;if((v|0)!=0){break}v=750965+(x*184|0)|0;if((d[v]|0)<=1){break}a[v]=1}}while(0);v=751080+(x*184|0)|0;s=c[v>>2]|0;if((s|0)==0){break}p=s&-2;c[v>>2]=p;if((p|0)!=0){break}p=751049+(x*184|0)|0;if((d[p]|0)<=1){break}a[p]=1}else{if(w){a[750965+(x*184|0)|0]=5}c[q>>2]=u|1;p=751080+(x*184|0)|0;v=c[p>>2]|0;if((v|0)==0){a[751049+(x*184|0)|0]=5}c[p>>2]=v|1}}while(0);a[751109+(x*184|0)|0]=e&32;y=i;z=h}else{h=c[751096+(x*184|0)>>2]|0;y=h&3840|f;z=h}if((z|0)==(y|0)){return}c[751096+(x*184|0)>>2]=y;z=y>>>8&15;a[751108+(x*184|0)|0]=z;h=c[669496+(y>>5<<2)>>2]|0;c[751104+(x*184|0)>>2]=h;i=(c[752796+((y<<1&1022)<<2)>>2]|0)>>>((y>>>9&7^7)>>>0);c[751100+(x*184|0)>>2]=i;c[750972+(x*184|0)>>2]=(h>>>((d[750941+(x*184|0)|0]|0)>>>0))+(c[750968+(x*184|0)>>2]|0);c[751056+(x*184|0)>>2]=(h>>>((d[751025+(x*184|0)|0]|0)>>>0))+(c[751052+(x*184|0)>>2]|0);c[750948+(x*184|0)>>2]=ab(d[750943+(x*184|0)|0]|0,i)|0;h=z&255;z=h>>>((d[750940+(x*184|0)|0]|0)>>>0);y=750942+(x*184|0)|0;u=a[y]|0;if((u&255|0)==(z|0)){A=u}else{u=z&255;a[y]=u;y=z&255;z=(c[750928+(x*184|0)>>2]|0)+y|0;if(z>>>0<78){a[750986+(x*184|0)|0]=a[675256+z|0]|0;a[750987+(x*184|0)|0]=a[675480+z|0]|0}else{a[750986+(x*184|0)|0]=0;a[750987+(x*184|0)|0]=104}z=(c[750932+(x*184|0)>>2]|0)+y|0;a[750988+(x*184|0)|0]=a[675256+z|0]|0;a[750989+(x*184|0)|0]=a[675480+z|0]|0;z=(c[750936+(x*184|0)>>2]|0)+y|0;a[750990+(x*184|0)|0]=a[675256+z|0]|0;a[750991+(x*184|0)|0]=a[675480+z|0]|0;A=u}u=(a[751109+(x*184|0)|0]|0)==0?44:36;z=A&255;A=u+z|0;a[750992+(x*184|0)|0]=a[675256+A|0]|0;a[750993+(x*184|0)|0]=a[675480+A|0]|0;A=z+68|0;a[750984+(x*184|0)|0]=a[675256+A|0]|0;a[750985+(x*184|0)|0]=a[675480+A|0]|0;c[751032+(x*184|0)>>2]=ab(d[751027+(x*184|0)|0]|0,i)|0;i=h>>>((d[751024+(x*184|0)|0]|0)>>>0);h=751026+(x*184|0)|0;A=a[h]|0;if((A&255|0)==(i|0)){B=A}else{A=i&255;a[h]=A;h=i&255;i=(c[751012+(x*184|0)>>2]|0)+h|0;if(i>>>0<78){a[751070+(x*184|0)|0]=a[675256+i|0]|0;a[751071+(x*184|0)|0]=a[675480+i|0]|0}else{a[751070+(x*184|0)|0]=0;a[751071+(x*184|0)|0]=104}i=(c[751016+(x*184|0)>>2]|0)+h|0;a[751072+(x*184|0)|0]=a[675256+i|0]|0;a[751073+(x*184|0)|0]=a[675480+i|0]|0;i=(c[751020+(x*184|0)>>2]|0)+h|0;a[751074+(x*184|0)|0]=a[675256+i|0]|0;a[751075+(x*184|0)|0]=a[675480+i|0]|0;B=A}A=B&255;B=u+A|0;a[751076+(x*184|0)|0]=a[675256+B|0]|0;a[751077+(x*184|0)|0]=a[675480+B|0]|0;B=A+68|0;a[751068+(x*184|0)|0]=a[675256+B|0]|0;a[751069+(x*184|0)|0]=a[675480+B|0]|0;return}else if((g|0)==48){g=b&15;b=g>>>0>8?g-9|0:g;g=e<<3&120;c[751052+(b*184|0)>>2]=g;B=c[751104+(b*184|0)>>2]|0;c[751056+(b*184|0)>>2]=(B>>>((d[751025+(b*184|0)|0]|0)>>>0))+g;do{if((b|0)>5){if((a[752612]&32)==0){break}if((b|0)<=6){return}g=f>>>4<<3;c[750968+(b*184|0)>>2]=g;c[750972+(b*184|0)>>2]=(B>>>((d[750941+(b*184|0)|0]|0)>>>0))+g;return}}while(0);B=752584+b|0;if(((d[B]^e)&240|0)==0){return}a[B]=e&255;ot(b,b<<1,752644+(f>>>4<<3)|0);return}else{return}}function or(b,c){b=b|0;c=c|0;if((b&2|0)!=0){a[756893]=c&1;return}if((b&1|0)==0){a[756892]=c&255;return}else{oq(d[756892]|0,c);return}}function os(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0;if((e|0)>0){f=0;g=b}else{return}while(1){b=(c[188154]|0)+(c[188155]|0)|0;h=b>>>0>3523215359?b+771751936|0:b;c[188154]=h;b=(d[669280+(h>>>24)|0]|0)>>>1;h=(c[188156]|0)+(c[188157]|0)|0;c[188156]=h;i=h>>>24&7;h=(c[187744]|0)+(c[187743]|0)+(c[187750]&b)|0;j=c[187739]|0;k=c[187740]|0;c[187739]=k;c[187740]=0;if(h>>>0<176){l=a[750952]|0;m=(c[943768+(((((l<<24>>24==0?0:k+j|0)<<(l&255))+(c[187736]&67043328)|0)>>>16&1023)+(c[187752]|0)<<2)>>2]|0)+(h<<5)|0;if(m>>>0>5631){n=0}else{n=c[888232+(m<<2)>>2]|0}c[187740]=n}m=(c[187765]|0)+(c[187764]|0)+(c[187771]&b)|0;do{if(m>>>0<176){h=(c[943768+((((c[187757]&67043328)+(k<<17)|0)>>>16&1023)+(c[187773]|0)<<2)>>2]|0)+(m<<5)|0;if(h>>>0>5631){o=0;break}o=c[888232+(h<<2)>>2]|0}else{o=0}}while(0);m=(c[187790]|0)+(c[187789]|0)+(c[187796]&b)|0;k=c[187785]|0;h=c[187786]|0;c[187785]=h;c[187786]=0;if(m>>>0<176){l=a[751136]|0;j=(c[943768+(((((l<<24>>24==0?0:h+k|0)<<(l&255))+(c[187782]&67043328)|0)>>>16&1023)+(c[187798]|0)<<2)>>2]|0)+(m<<5)|0;if(j>>>0>5631){p=0}else{p=c[888232+(j<<2)>>2]|0}c[187786]=p}j=(c[187811]|0)+(c[187810]|0)+(c[187817]&b)|0;if(j>>>0<176){m=(c[943768+((((c[187803]&67043328)+(h<<17)|0)>>>16&1023)+(c[187819]|0)<<2)>>2]|0)+(j<<5)|0;if(m>>>0>5631){q=0}else{q=c[888232+(m<<2)>>2]|0}r=q+o|0}else{r=o}m=(c[187836]|0)+(c[187835]|0)+(c[187842]&b)|0;j=c[187831]|0;h=c[187832]|0;c[187831]=h;c[187832]=0;if(m>>>0<176){l=a[751320]|0;k=(c[943768+(((((l<<24>>24==0?0:h+j|0)<<(l&255))+(c[187828]&67043328)|0)>>>16&1023)+(c[187844]|0)<<2)>>2]|0)+(m<<5)|0;if(k>>>0>5631){s=0}else{s=c[888232+(k<<2)>>2]|0}c[187832]=s}k=(c[187857]|0)+(c[187856]|0)+(c[187863]&b)|0;if(k>>>0<176){m=(c[943768+((((c[187849]&67043328)+(h<<17)|0)>>>16&1023)+(c[187865]|0)<<2)>>2]|0)+(k<<5)|0;if(m>>>0>5631){t=0}else{t=c[888232+(m<<2)>>2]|0}u=t+r|0}else{u=r}m=(c[187882]|0)+(c[187881]|0)+(c[187888]&b)|0;k=c[187877]|0;h=c[187878]|0;c[187877]=h;c[187878]=0;if(m>>>0<176){l=a[751504]|0;j=(c[943768+(((((l<<24>>24==0?0:h+k|0)<<(l&255))+(c[187874]&67043328)|0)>>>16&1023)+(c[187890]|0)<<2)>>2]|0)+(m<<5)|0;if(j>>>0>5631){v=0}else{v=c[888232+(j<<2)>>2]|0}c[187878]=v}j=(c[187903]|0)+(c[187902]|0)+(c[187909]&b)|0;if(j>>>0<176){m=(c[943768+((((c[187895]&67043328)+(h<<17)|0)>>>16&1023)+(c[187911]|0)<<2)>>2]|0)+(j<<5)|0;if(m>>>0>5631){w=0}else{w=c[888232+(m<<2)>>2]|0}x=w+u|0}else{x=u}m=(c[187928]|0)+(c[187927]|0)+(c[187934]&b)|0;j=c[187923]|0;h=c[187924]|0;c[187923]=h;c[187924]=0;if(m>>>0<176){l=a[751688]|0;k=(c[943768+(((((l<<24>>24==0?0:h+j|0)<<(l&255))+(c[187920]&67043328)|0)>>>16&1023)+(c[187936]|0)<<2)>>2]|0)+(m<<5)|0;if(k>>>0>5631){y=0}else{y=c[888232+(k<<2)>>2]|0}c[187924]=y}k=(c[187949]|0)+(c[187948]|0)+(c[187955]&b)|0;if(k>>>0<176){m=(c[943768+((((c[187941]&67043328)+(h<<17)|0)>>>16&1023)+(c[187957]|0)<<2)>>2]|0)+(k<<5)|0;if(m>>>0>5631){z=0}else{z=c[888232+(m<<2)>>2]|0}A=z+x|0}else{A=x}m=(c[187974]|0)+(c[187973]|0)+(c[187980]&b)|0;k=c[187969]|0;h=c[187970]|0;c[187969]=h;c[187970]=0;if(m>>>0<176){l=a[751872]|0;j=(c[943768+(((((l<<24>>24==0?0:h+k|0)<<(l&255))+(c[187966]&67043328)|0)>>>16&1023)+(c[187982]|0)<<2)>>2]|0)+(m<<5)|0;if(j>>>0>5631){B=0}else{B=c[888232+(j<<2)>>2]|0}c[187970]=B}j=(c[187995]|0)+(c[187994]|0)+(c[188001]&b)|0;if(j>>>0<176){m=(c[943768+((((c[187987]&67043328)+(h<<17)|0)>>>16&1023)+(c[188003]|0)<<2)>>2]|0)+(j<<5)|0;if(m>>>0>5631){C=0}else{C=c[888232+(m<<2)>>2]|0}D=C+A|0}else{D=A}do{if((a[752612]&32)==0){m=(c[188020]|0)+(c[188019]|0)+(c[188026]&b)|0;j=c[188015]|0;h=c[188016]|0;c[188015]=h;c[188016]=0;if(m>>>0<176){l=a[752056]|0;k=(c[943768+(((((l<<24>>24==0?0:h+j|0)<<(l&255))+(c[188012]&67043328)|0)>>>16&1023)+(c[188028]|0)<<2)>>2]|0)+(m<<5)|0;if(k>>>0>5631){E=0}else{E=c[888232+(k<<2)>>2]|0}c[188016]=E}k=(c[188041]|0)+(c[188040]|0)+(c[188047]&b)|0;if(k>>>0<176){m=(c[943768+((((c[188033]&67043328)+(h<<17)|0)>>>16&1023)+(c[188049]|0)<<2)>>2]|0)+(k<<5)|0;if(m>>>0>5631){F=0}else{F=c[888232+(m<<2)>>2]|0}G=F+D|0}else{G=D}m=(c[188066]|0)+(c[188065]|0)+(c[188072]&b)|0;k=c[188061]|0;h=c[188062]|0;c[188061]=h;c[188062]=0;if(m>>>0<176){l=a[752240]|0;j=(c[943768+(((((l<<24>>24==0?0:h+k|0)<<(l&255))+(c[188058]&67043328)|0)>>>16&1023)+(c[188074]|0)<<2)>>2]|0)+(m<<5)|0;if(j>>>0>5631){H=0}else{H=c[888232+(j<<2)>>2]|0}c[188062]=H}j=(c[188087]|0)+(c[188086]|0)+(c[188093]&b)|0;if(j>>>0<176){m=(c[943768+((((c[188079]&67043328)+(h<<17)|0)>>>16&1023)+(c[188095]|0)<<2)>>2]|0)+(j<<5)|0;if(m>>>0>5631){I=0}else{I=c[888232+(m<<2)>>2]|0}J=I+G|0}else{J=G}m=(c[188112]|0)+(c[188111]|0)+(c[188118]&b)|0;j=c[188107]|0;h=c[188108]|0;c[188107]=h;c[188108]=0;if(m>>>0<176){l=a[752424]|0;k=(c[943768+(((((l<<24>>24==0?0:h+j|0)<<(l&255))+(c[188104]&67043328)|0)>>>16&1023)+(c[188120]|0)<<2)>>2]|0)+(m<<5)|0;if(k>>>0>5631){K=0}else{K=c[888232+(k<<2)>>2]|0}c[188108]=K}k=(c[188133]|0)+(c[188132]|0)+(c[188139]&b)|0;if(k>>>0>=176){L=J;M=0;break}m=(c[943768+((((c[188125]&67043328)+(h<<17)|0)>>>16&1023)+(c[188141]|0)<<2)>>2]|0)+(k<<5)|0;if(m>>>0>5631){N=0}else{N=c[888232+(m<<2)>>2]|0}L=N+J|0;M=0}else{m=c[188158]&1;k=(c[188020]|0)+(c[188019]|0)+(c[188026]&b)|0;h=c[188015]|0;l=c[188016]|0;c[188015]=l;c[188016]=0;if(k>>>0<176){j=a[752056]|0;O=(c[943768+(((((j<<24>>24==0?0:l+h|0)<<(j&255))+(c[188012]&67043328)|0)>>>16&1023)+(c[188028]|0)<<2)>>2]|0)+(k<<5)|0;if(O>>>0>5631){P=0}else{P=c[888232+(O<<2)>>2]|0}c[188016]=P}O=(c[188041]|0)+(c[188040]|0)+(c[188047]&b)|0;do{if(O>>>0<176){k=(c[943768+((((c[188033]&67043328)+(l<<17)|0)>>>16&1023)+(c[188049]|0)<<2)>>2]|0)+(O<<5)|0;if(k>>>0>5631){Q=0;break}Q=c[888232+(k<<2)>>2]|0}else{Q=0}}while(0);O=(c[188066]|0)+(c[188065]|0)+(c[188072]&b)|0;if(O>>>0<176){l=c[188058]|0;k=c[188125]|0;j=((k>>>19|k>>>21)&1|0)==0?((l>>>18^l>>>23|l>>>19)&1|0)!=0?564:208:564;l=(m|0)!=0;if((j&512|0)==0){R=l?52:j}else{R=l?720:j}j=(c[943768+((R&1023)+(c[188074]|0)<<2)>>2]|0)+(O<<5)|0;if(j>>>0>5631){S=0}else{S=c[888232+(j<<2)>>2]|0}T=S+Q|0}else{T=Q}j=(c[188087]|0)+(c[188086]|0)+(c[188093]&b)|0;if(j>>>0<176){O=((c[188058]|0)>>>16&256)+256|0;l=(c[943768+((((m|0)==0?O:O^256)&768)+(c[188095]|0)<<2)>>2]|0)+(j<<5)|0;if(l>>>0>5631){U=0}else{U=c[888232+(l<<2)>>2]|0}V=U+T|0}else{V=T}l=(c[188112]|0)+(c[188111]|0)+(c[188118]&b)|0;if(l>>>0<176){j=(c[943768+(((c[188104]|0)>>>16&1023)+(c[188120]|0)<<2)>>2]|0)+(l<<5)|0;if(j>>>0>5631){W=0}else{W=c[888232+(j<<2)>>2]|0}X=W+V|0}else{X=V}j=(c[188133]|0)+(c[188132]|0)+(c[188139]&b)|0;if(j>>>0>=176){L=D;M=X;break}l=c[188058]|0;O=c[188125]|0;k=(c[943768+((((O>>>19|O>>>21)&1|0)==0?(l>>>18^l>>>23|l>>>19)<<9&512|256:768)+(c[188141]|0)<<2)>>2]|0)+(j<<5)|0;if(k>>>0>5631){Y=0}else{Y=c[888232+(k<<2)>>2]|0}L=D;M=Y+X|0}}while(0);b=ab((M<<1)+L<<1,d[756893]|0)|0;c[g>>2]=b;k=g+8|0;c[g+4>>2]=b;b=(c[188150]|0)+(c[188151]|0)|0;c[188150]=b;j=c[188152]|0;if(b>>>0<j>>>0){Z=0}else{l=b;b=j;while(1){c[188150]=l-b;c[188149]=(c[188149]|0)+1;j=0;do{O=j>>>1;h=j&1;_=750928+(O*184|0)+(h*84|0)+37|0;L19086:do{switch(d[_]|0){case 5:{$=c[188149]|0;aa=d[750928+(O*184|0)+(h*84|0)+56|0]|0;if(((1<<aa)-1&$|0)!=0){break L19086}ac=750928+(O*184|0)+(h*84|0)+48|0;ad=(c[ac>>2]|0)+(d[675704+((d[750928+(O*184|0)+(h*84|0)+57|0]|0)+($>>>(aa>>>0)&7))|0]|0)|0;c[ac>>2]=ad;if((ad|0)<=254){break L19086}c[ac>>2]=255;a[_]=4;c[750928+(O*184|0)+(h*84|0)+16>>2]=0;break};case 1:{if((h|0)==0){if(!((a[752612]&32)!=0&j>>>0>11)){break L19086}}if((a[750928+(O*184|0)+(h*84|0)+36|0]|0)==0){ac=c[188149]|0;ad=d[750928+(O*184|0)+(h*84|0)+64|0]|0;if(((1<<ad)-1&ac|0)!=0){break L19086}aa=750928+(O*184|0)+(h*84|0)+48|0;$=(c[aa>>2]|0)+(d[675704+((d[750928+(O*184|0)+(h*84|0)+65|0]|0)+(ac>>>(ad>>>0)&7))|0]|0)|0;c[aa>>2]=$;if(($|0)<=254){break L19086}c[aa>>2]=255;a[_]=0;break L19086}aa=c[188149]|0;if((a[751109+(O*184|0)|0]|0)==0){$=d[750928+(O*184|0)+(h*84|0)+62|0]|0;if(((1<<$)-1&aa|0)!=0){break L19086}ad=750928+(O*184|0)+(h*84|0)+48|0;ac=(c[ad>>2]|0)+(d[675704+((d[750928+(O*184|0)+(h*84|0)+63|0]|0)+(aa>>>($>>>0)&7))|0]|0)|0;c[ad>>2]=ac;if((ac|0)<=254){break L19086}c[ad>>2]=255;a[_]=0;break L19086}else{ad=d[750928+(O*184|0)+(h*84|0)+64|0]|0;if(((1<<ad)-1&aa|0)!=0){break L19086}ac=750928+(O*184|0)+(h*84|0)+48|0;$=(c[ac>>2]|0)+(d[675704+((d[750928+(O*184|0)+(h*84|0)+65|0]|0)+(aa>>>(ad>>>0)&7))|0]|0)|0;c[ac>>2]=$;if(($|0)<=254){break L19086}c[ac>>2]=255;a[_]=0;break L19086}break};case 3:{ac=c[188149]|0;$=d[750928+(O*184|0)+(h*84|0)+60|0]|0;if(((1<<$)-1&ac|0)!=0){break L19086}ad=750928+(O*184|0)+(h*84|0)+48|0;aa=(c[ad>>2]|0)+(d[675704+((d[750928+(O*184|0)+(h*84|0)+61|0]|0)+(ac>>>($>>>0)&7))|0]|0)|0;c[ad>>2]=aa;if(aa>>>0<(c[750928+(O*184|0)+(h*84|0)+52>>2]|0)>>>0){break L19086}a[_]=2;break};case 2:{if((a[750928+(O*184|0)+(h*84|0)+36|0]|0)!=0){break L19086}aa=c[188149]|0;ad=d[750928+(O*184|0)+(h*84|0)+62|0]|0;if(((1<<ad)-1&aa|0)!=0){break L19086}$=750928+(O*184|0)+(h*84|0)+48|0;ac=(c[$>>2]|0)+(d[675704+((d[750928+(O*184|0)+(h*84|0)+63|0]|0)+(aa>>>(ad>>>0)&7))|0]|0)|0;c[$>>2]=ac;if((ac|0)<=254){break L19086}c[$>>2]=255;break};case 4:{$=c[188149]|0;ac=d[750928+(O*184|0)+(h*84|0)+58|0]|0;if(((1<<ac)-1&$|0)!=0){break L19086}ad=750928+(O*184|0)+(h*84|0)+48|0;aa=c[ad>>2]|0;ae=((ab(d[675704+((d[750928+(O*184|0)+(h*84|0)+59|0]|0)+($>>>(ac>>>0)&7))|0]|0,~aa)|0)>>2)+aa|0;c[ad>>2]=ae;if((ae|0)>=1){break L19086}c[ad>>2]=0;a[_]=3;break};default:{}}}while(0);j=j+1|0;}while(j>>>0<18);j=c[188150]|0;m=c[188152]|0;if(j>>>0<m>>>0){Z=0;break}else{l=j;b=m}}}do{b=Z>>>1;l=Z&1;do{if((a[750928+(b*184|0)+(l*84|0)+76|0]|0)==0){m=750928+(b*184|0)+(l*84|0)+16|0;c[m>>2]=(c[m>>2]|0)+(c[750928+(b*184|0)+(l*84|0)+20>>2]|0)}else{m=c[751096+(b*184|0)>>2]|0;j=a[668760+(m>>>6<<3&56|i)|0]|0;if(j<<24>>24==0){_=750928+(b*184|0)+(l*84|0)+16|0;c[_>>2]=(c[_>>2]|0)+(c[750928+(b*184|0)+(l*84|0)+20>>2]|0);break}else{_=(j<<24>>24)+(m<<1)|0;m=ab(d[750928+(b*184|0)+(l*84|0)+15|0]|0,(c[752796+((_&1023)<<2)>>2]|0)>>>((_>>>10&7^7)>>>0))|0;_=750928+(b*184|0)+(l*84|0)+16|0;c[_>>2]=m+(c[_>>2]|0);break}}}while(0);Z=Z+1|0;}while(Z>>>0<18);l=(c[188159]|0)+(c[188160]|0)|0;b=l>>>16;c[188159]=l&65535;if((b|0)!=0){l=b;b=c[188158]|0;do{b=((b&1|0)==0?b:b^8389378)>>>1;l=l-1|0;}while((l|0)!=0);c[188158]=b}l=f+1|0;if((l|0)<(e|0)){f=l;g=k}else{break}}c[3645912]=i;return}function ot(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a[f]|0;h=g&255;i=(e|0)/2|0;j=e&1;k=a[11144+(h&15)|0]|0;a[750928+(i*184|0)+(j*84|0)+15|0]=k;l=(g&255)>>>3&2^2;a[750928+(i*184|0)+(j*84|0)+12|0]=l;a[750928+(i*184|0)+(j*84|0)+36|0]=g&32;a[750928+(i*184|0)+(j*84|0)+76|0]=g&64;c[750928+(i*184|0)+(j*84|0)+72>>2]=h<<24>>31;c[750928+(i*184|0)+(j*84|0)+20>>2]=ab(k&255,c[751100+(i*184|0)>>2]|0)|0;k=(d[751108+(i*184|0)|0]|0)>>>((l&255)>>>0);l=750928+(i*184|0)+(j*84|0)+14|0;h=a[l]|0;if((h&255|0)==(k|0)){m=h}else{h=k&255;a[l]=h;g=k&255;k=(c[750928+(i*184|0)+(j*84|0)>>2]|0)+g|0;if(k>>>0<78){a[750928+(i*184|0)+(j*84|0)+58|0]=a[675256+k|0]|0;a[750928+(i*184|0)+(j*84|0)+59|0]=a[675480+k|0]|0}else{a[750928+(i*184|0)+(j*84|0)+58|0]=0;a[750928+(i*184|0)+(j*84|0)+59|0]=104}k=(c[750928+(i*184|0)+(j*84|0)+4>>2]|0)+g|0;a[750928+(i*184|0)+(j*84|0)+60|0]=a[675256+k|0]|0;a[750928+(i*184|0)+(j*84|0)+61|0]=a[675480+k|0]|0;k=(c[750928+(i*184|0)+(j*84|0)+8>>2]|0)+g|0;a[750928+(i*184|0)+(j*84|0)+62|0]=a[675256+k|0]|0;a[750928+(i*184|0)+(j*84|0)+63|0]=a[675480+k|0]|0;m=h}h=m&255;m=((a[751109+(i*184|0)|0]|0)==0?44:36)+h|0;a[750928+(i*184|0)+(j*84|0)+64|0]=a[675256+m|0]|0;a[750928+(i*184|0)+(j*84|0)+65|0]=a[675480+m|0]|0;m=h+68|0;a[750928+(i*184|0)+(j*84|0)+56|0]=a[675256+m|0]|0;a[750928+(i*184|0)+(j*84|0)+57|0]=a[675480+m|0]|0;m=e+1|0;e=a[f+1|0]|0;h=e&255;k=(m|0)/2|0;g=m&1;m=a[11144+(h&15)|0]|0;a[750928+(k*184|0)+(g*84|0)+15|0]=m;n=(e&255)>>>3&2^2;a[750928+(k*184|0)+(g*84|0)+12|0]=n;a[750928+(k*184|0)+(g*84|0)+36|0]=e&32;a[750928+(k*184|0)+(g*84|0)+76|0]=e&64;c[750928+(k*184|0)+(g*84|0)+72>>2]=h<<24>>31;c[750928+(k*184|0)+(g*84|0)+20>>2]=ab(m&255,c[751100+(k*184|0)>>2]|0)|0;m=(d[751108+(k*184|0)|0]|0)>>>((n&255)>>>0);n=750928+(k*184|0)+(g*84|0)+14|0;h=a[n]|0;if((h&255|0)==(m|0)){o=h}else{h=m&255;a[n]=h;e=m&255;m=(c[750928+(k*184|0)+(g*84|0)>>2]|0)+e|0;if(m>>>0<78){a[750928+(k*184|0)+(g*84|0)+58|0]=a[675256+m|0]|0;a[750928+(k*184|0)+(g*84|0)+59|0]=a[675480+m|0]|0}else{a[750928+(k*184|0)+(g*84|0)+58|0]=0;a[750928+(k*184|0)+(g*84|0)+59|0]=104}m=(c[750928+(k*184|0)+(g*84|0)+4>>2]|0)+e|0;a[750928+(k*184|0)+(g*84|0)+60|0]=a[675256+m|0]|0;a[750928+(k*184|0)+(g*84|0)+61|0]=a[675480+m|0]|0;m=(c[750928+(k*184|0)+(g*84|0)+8>>2]|0)+e|0;a[750928+(k*184|0)+(g*84|0)+62|0]=a[675256+m|0]|0;a[750928+(k*184|0)+(g*84|0)+63|0]=a[675480+m|0]|0;o=h}h=o&255;o=((a[751109+(k*184|0)|0]|0)==0?44:36)+h|0;a[750928+(k*184|0)+(g*84|0)+64|0]=a[675256+o|0]|0;a[750928+(k*184|0)+(g*84|0)+65|0]=a[675480+o|0]|0;o=h+68|0;a[750928+(k*184|0)+(g*84|0)+56|0]=a[675256+o|0]|0;a[750928+(k*184|0)+(g*84|0)+57|0]=a[675480+o|0]|0;o=d[f+2|0]|0;h=o>>>6;if((h|0)==0){p=31}else{p=(h^3)&255}a[750941+(b*184|0)|0]=p;h=o<<1&126;c[750968+(b*184|0)>>2]=h;o=c[751104+(b*184|0)>>2]|0;c[750972+(b*184|0)>>2]=(o>>>((p&255)>>>0))+h;h=d[f+3|0]|0;c[751008+(b*184|0)>>2]=h>>>3<<10&1024;p=h&7;if((p|0)==0){q=0}else{q=(p|8)&255}a[750952+(b*184|0)|0]=q;c[751092+(b*184|0)>>2]=h>>>4<<10&1024;q=h>>>6;if((q|0)==0){r=31}else{r=(q^3)&255}a[751025+(b*184|0)|0]=r;c[751056+(b*184|0)>>2]=(o>>>((r&255)>>>0))+(c[751052+(b*184|0)>>2]|0);b=d[f+4|0]|0;r=b>>>4;if((r|0)==0){s=0}else{s=(r<<2)+16|0}c[750928+(i*184|0)+(j*84|0)>>2]=s;r=d[l]|0;o=r+s|0;if(o>>>0<78){a[750928+(i*184|0)+(j*84|0)+58|0]=a[675256+o|0]|0;a[750928+(i*184|0)+(j*84|0)+59|0]=a[675480+o|0]|0}else{a[750928+(i*184|0)+(j*84|0)+58|0]=0;a[750928+(i*184|0)+(j*84|0)+59|0]=104}o=b&15;if((o|0)==0){t=0}else{t=(o<<2)+16|0}c[750928+(i*184|0)+(j*84|0)+4>>2]=t;o=t+r|0;a[750928+(i*184|0)+(j*84|0)+60|0]=a[675256+o|0]|0;a[750928+(i*184|0)+(j*84|0)+61|0]=a[675480+o|0]|0;o=d[f+5|0]|0;r=o>>>4;if((r|0)==0){u=0}else{u=(r<<2)+16|0}c[750928+(k*184|0)+(g*84|0)>>2]=u;r=d[n]|0;t=r+u|0;if(t>>>0<78){a[750928+(k*184|0)+(g*84|0)+58|0]=a[675256+t|0]|0;a[750928+(k*184|0)+(g*84|0)+59|0]=a[675480+t|0]|0}else{a[750928+(k*184|0)+(g*84|0)+58|0]=0;a[750928+(k*184|0)+(g*84|0)+59|0]=104}t=o&15;if((t|0)==0){v=0}else{v=(t<<2)+16|0}c[750928+(k*184|0)+(g*84|0)+4>>2]=v;t=v+r|0;a[750928+(k*184|0)+(g*84|0)+60|0]=a[675256+t|0]|0;a[750928+(k*184|0)+(g*84|0)+61|0]=a[675480+t|0]|0;t=d[f+6|0]|0;c[750928+(i*184|0)+(j*84|0)+52>>2]=c[2440+(t>>>4<<2)>>2];r=t&15;if((r|0)==0){w=0}else{w=(r<<2)+16|0}c[750928+(i*184|0)+(j*84|0)+8>>2]=w;r=(d[l]|0)+w|0;a[750928+(i*184|0)+(j*84|0)+62|0]=a[675256+r|0]|0;a[750928+(i*184|0)+(j*84|0)+63|0]=a[675480+r|0]|0;r=d[f+7|0]|0;c[750928+(k*184|0)+(g*84|0)+52>>2]=c[2440+(r>>>4<<2)>>2];f=r&15;if((f|0)==0){x=0;y=750928+(k*184|0)+(g*84|0)+8|0;c[y>>2]=x;z=a[n]|0;A=z&255;B=A+x|0;C=675256+B|0;D=a[C]|0;E=750928+(k*184|0)+(g*84|0)+62|0;a[E]=D;F=675480+B|0;G=a[F]|0;H=750928+(k*184|0)+(g*84|0)+63|0;a[H]=G;return}x=(f<<2)+16|0;y=750928+(k*184|0)+(g*84|0)+8|0;c[y>>2]=x;z=a[n]|0;A=z&255;B=A+x|0;C=675256+B|0;D=a[C]|0;E=750928+(k*184|0)+(g*84|0)+62|0;a[E]=D;F=675480+B|0;G=a[F]|0;H=750928+(k*184|0)+(g*84|0)+63|0;a[H]=G;return}function ou(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((c[3645589]|0)>>>0<a>>>0){ov(a);g=c[3645589]|0;h=a-g+239|0;c[3645589]=g-((h>>>0)%240|0)+h;i=0}else{i=0}do{h=-(f>>>((i+4|0)>>>0)&1)&b;g=14582176+(i<<3)|0;c[g>>2]=h;a=-(f>>>(i>>>0)&1)&b;j=14582180+(i<<3)|0;c[j>>2]=a;if((i|0)==3){c[3645550]=c[3645550]<<d;c[3645551]=c[3645551]<<d;k=c[g>>2]|0;l=c[j>>2]|0}else{k=h;l=a}a=e[736760+(c[14582216+((i<<1|1)<<2)>>2]<<1)>>1]|0;c[14582292+(i<<3)>>2]=(ab(a,k)|0)/100|0;c[14582296+(i<<3)>>2]=(ab(a,l)|0)/100|0;i=i+1|0;}while((i|0)<4);return}function ov(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[3645564]|0;if((b|0)==128){d=c[3645558]|0;c[3645568]=c[3645567];e=d}else{e=b}b=c[3645589]|0;d=c[3645563]|0;f=c[3645579]&-(d&1);g=c[3645587]|0;if((f|0)==(g|0)){h=d}else{d=f-g|0;c[3645587]=f;f=c[3184682]|0;g=f|0;i=aIP(c[g>>2]|0,c[g+4>>2]|0,b,0)|0;g=F;j=f+8|0;k=c[j>>2]|0;l=c[j+4>>2]|0;aIF(i,g,k,l)|0;l=F;k=f+24|0;f=l>>>20|0<<12;g=ab((l>>>5|0<<27)&32767,d)|0;l=k+(f+7<<2)|0;c[l>>2]=(c[l>>2]|0)+(d<<15)-g;d=k+(f+8<<2)|0;c[d>>2]=g+(c[d>>2]|0);h=c[3645563]|0}d=c[3645580]&-(h&1);h=c[3645588]|0;if((d|0)!=(h|0)){g=d-h|0;c[3645588]=d;d=c[3184676]|0;h=d|0;f=aIP(c[h>>2]|0,c[h+4>>2]|0,b,0)|0;b=F;h=d+8|0;k=c[h>>2]|0;l=c[h+4>>2]|0;aIF(f,b,k,l)|0;l=F;k=d+24|0;d=l>>>20|0<<12;b=ab((l>>>5|0<<27)&32767,g)|0;l=k+(d+7<<2)|0;c[l>>2]=(c[l>>2]|0)+(g<<15)-b;g=k+(d+8<<2)|0;c[g>>2]=b+(c[g>>2]|0)}g=c[3645568]|0;if((g|0)<(a|0)){b=e*240|0;e=c[3184676]|0;d=e|0;k=e+8|0;l=e+24|0;f=c[3184682]|0;h=f|0;i=f+8|0;j=f+24|0;m=g;while(1){n=-(c[3645572]|0)|0;c[3645572]=n;do{if((n|0)==1){o=c[3645563]|0;do{if((c[3645560]&4|0)==0){p=o&1}else{q=c[3645552]|0;r=q&o;if((r|0)==0){p=0;break}p=(r|0)!=(q|0)|0}}while(0);q=p<<(c[3645553]|0)-1|o>>1;c[3645563]=q;r=c[3645579]&-(q&1);s=c[3645587]|0;if((r|0)==(s|0)){t=q}else{q=r-s|0;c[3645587]=r;r=aIP(c[h>>2]|0,c[h+4>>2]|0,m,0)|0;s=F;u=c[i>>2]|0;v=c[i+4>>2]|0;aIF(r,s,u,v)|0;v=F;u=v>>>20|0<<12;s=ab((v>>>5|0<<27)&32767,q)|0;v=j+(u+7<<2)|0;c[v>>2]=(c[v>>2]|0)+(q<<15)-s;q=j+(u+8<<2)|0;c[q>>2]=s+(c[q>>2]|0);t=c[3645563]|0}q=c[3645580]&-(t&1);s=c[3645588]|0;if((q|0)==(s|0)){break}u=q-s|0;c[3645588]=q;q=aIP(c[d>>2]|0,c[d+4>>2]|0,m,0)|0;s=F;v=c[k>>2]|0;r=c[k+4>>2]|0;aIF(q,s,v,r)|0;r=F;v=r>>>20|0<<12;s=ab((r>>>5|0<<27)&32767,u)|0;r=l+(v+7<<2)|0;c[r>>2]=(c[r>>2]|0)+(u<<15)-s;u=l+(v+8<<2)|0;c[u>>2]=s+(c[u>>2]|0)}}while(0);n=m+b|0;if((n|0)<(a|0)){m=n}else{w=n;x=e;y=f;break}}}else{w=g;x=c[3184676]|0;y=c[3184682]|0}c[3645568]=w;w=x|0;g=x+8|0;f=x+24|0;x=y|0;e=y+8|0;m=y+24|0;y=0;do{b=c[3645589]|0;l=14582292+(y<<3)|0;k=14582276+(y<<2)|0;d=c[k>>2]|0;t=ab(d,c[l>>2]|0)|0;j=14582324+(y<<3)|0;i=c[j>>2]|0;if((t|0)==(i|0)){z=d}else{d=t-i|0;c[j>>2]=t;t=aIP(c[x>>2]|0,c[x+4>>2]|0,b,0)|0;i=F;h=c[e>>2]|0;p=c[e+4>>2]|0;aIF(t,i,h,p)|0;p=F;h=p>>>20|0<<12;i=ab((p>>>5|0<<27)&32767,d)|0;p=m+(h+7<<2)|0;c[p>>2]=(c[p>>2]|0)+(d<<15)-i;d=m+(h+8<<2)|0;c[d>>2]=i+(c[d>>2]|0);z=c[k>>2]|0}d=14582296+(y<<3)|0;i=ab(c[d>>2]|0,z)|0;h=14582328+(y<<3)|0;p=c[h>>2]|0;if((i|0)!=(p|0)){t=i-p|0;c[h>>2]=i;i=aIP(c[w>>2]|0,c[w+4>>2]|0,b,0)|0;b=F;p=c[g>>2]|0;n=c[g+4>>2]|0;aIF(i,b,p,n)|0;n=F;p=n>>>20|0<<12;b=ab((n>>>5|0<<27)&32767,t)|0;n=f+(p+7<<2)|0;c[n>>2]=(c[n>>2]|0)+(t<<15)-b;t=f+(p+8<<2)|0;c[t>>2]=b+(c[t>>2]|0)}t=14582260+(y<<2)|0;b=c[t>>2]|0;if((b|0)<(a|0)){p=14582216+(y<<1<<2)|0;n=b;i=c[p>>2]|0;while(1){if((i|0)>1){A=-(c[k>>2]|0)|0}else{A=1}c[k>>2]=A;u=ab(c[l>>2]|0,A)|0;s=c[j>>2]|0;if((u|0)==(s|0)){B=A}else{v=u-s|0;c[j>>2]=u;u=aIP(c[x>>2]|0,c[x+4>>2]|0,n,0)|0;s=F;r=c[e>>2]|0;q=c[e+4>>2]|0;aIF(u,s,r,q)|0;q=F;r=q>>>20|0<<12;s=ab((q>>>5|0<<27)&32767,v)|0;q=m+(r+7<<2)|0;c[q>>2]=(c[q>>2]|0)+(v<<15)-s;v=m+(r+8<<2)|0;c[v>>2]=s+(c[v>>2]|0);B=c[k>>2]|0}v=ab(c[d>>2]|0,B)|0;s=c[h>>2]|0;if((v|0)!=(s|0)){r=v-s|0;c[h>>2]=v;v=aIP(c[w>>2]|0,c[w+4>>2]|0,n,0)|0;s=F;q=c[g>>2]|0;u=c[g+4>>2]|0;aIF(v,s,q,u)|0;u=F;q=u>>>20|0<<12;s=ab((u>>>5|0<<27)&32767,r)|0;u=f+(q+7<<2)|0;c[u>>2]=(c[u>>2]|0)+(r<<15)-s;r=f+(q+8<<2)|0;c[r>>2]=s+(c[r>>2]|0)}r=c[p>>2]|0;s=(r*240|0)+n|0;if((s|0)<(a|0)){n=s;i=r}else{C=s;break}}}else{C=b}c[t>>2]=C;y=y+1|0;}while((y|0)<3);return}function ow(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=a|0;g=aIP(c[f>>2]|0,c[f+4>>2]|0,d,0)|0;d=a+8|0;aIF(g,F,c[d>>2]|0,c[d+4>>2]|0)|0;d=F;g=a+24|0;a=d>>>20|0<<12;f=g+(a<<2)|0;h=(d>>>15|0<<17)&31;i=32-h|0;j=(ab(d&32767,e)|0)>>15;d=e-j|0;e=ab(d,b[687104+(h<<4)>>1]|0)|0;k=ab(j,b[687120+(h<<4)>>1]|0)|0;c[f>>2]=k+(c[f>>2]|0)+e;e=ab(d,b[687106+(h<<4)>>1]|0)|0;f=ab(b[687122+(h<<4)>>1]|0,j)|0;k=g+(a+1<<2)|0;c[k>>2]=f+(c[k>>2]|0)+e;e=ab(b[687108+(h<<4)>>1]|0,d)|0;k=ab(b[687124+(h<<4)>>1]|0,j)|0;f=g+(a+2<<2)|0;c[f>>2]=(c[f>>2]|0)+e+k;k=ab(b[687110+(h<<4)>>1]|0,d)|0;e=ab(b[687126+(h<<4)>>1]|0,j)|0;f=g+(a+3<<2)|0;c[f>>2]=(c[f>>2]|0)+k+e;e=ab(b[687112+(h<<4)>>1]|0,d)|0;k=ab(b[687128+(h<<4)>>1]|0,j)|0;f=g+(a+4<<2)|0;c[f>>2]=(c[f>>2]|0)+e+k;k=ab(b[687114+(h<<4)>>1]|0,d)|0;e=ab(b[687130+(h<<4)>>1]|0,j)|0;f=g+(a+5<<2)|0;c[f>>2]=(c[f>>2]|0)+k+e;e=ab(b[687116+(h<<4)>>1]|0,d)|0;k=ab(b[687132+(h<<4)>>1]|0,j)|0;f=g+(a+6<<2)|0;c[f>>2]=(c[f>>2]|0)+e+k;k=ab(b[687118+(h<<4)>>1]|0,d)|0;e=ab(b[687134+(h<<4)>>1]|0,j)|0;h=g+(a+7<<2)|0;c[h>>2]=(c[h>>2]|0)+k+e;e=ab(b[687118+(i<<4)>>1]|0,d)|0;k=ab(b[687104+(i<<4)-2>>1]|0,j)|0;h=g+(a+8<<2)|0;c[h>>2]=(c[h>>2]|0)+e+k;k=ab(b[687116+(i<<4)>>1]|0,d)|0;e=ab(b[687104+(i<<4)-4>>1]|0,j)|0;h=g+(a+9<<2)|0;c[h>>2]=(c[h>>2]|0)+k+e;e=ab(b[687114+(i<<4)>>1]|0,d)|0;k=ab(b[687104+(i<<4)-6>>1]|0,j)|0;h=g+(a+10<<2)|0;c[h>>2]=(c[h>>2]|0)+e+k;k=ab(b[687112+(i<<4)>>1]|0,d)|0;e=ab(b[687104+(i<<4)-8>>1]|0,j)|0;h=g+(a+11<<2)|0;c[h>>2]=(c[h>>2]|0)+k+e;e=ab(b[687110+(i<<4)>>1]|0,d)|0;k=ab(b[687104+(i<<4)-10>>1]|0,j)|0;h=g+(a+12<<2)|0;c[h>>2]=(c[h>>2]|0)+e+k;k=ab(b[687108+(i<<4)>>1]|0,d)|0;e=ab(b[687104+(i<<4)-12>>1]|0,j)|0;h=g+(a+13<<2)|0;c[h>>2]=(c[h>>2]|0)+k+e;e=ab(b[687106+(i<<4)>>1]|0,d)|0;k=ab(b[687104+(i<<4)-14>>1]|0,j)|0;h=g+(a+14<<2)|0;c[h>>2]=(c[h>>2]|0)+e+k;k=ab(b[687104+(i<<4)>>1]|0,d)|0;d=ab(b[687104+(i<<4)-16>>1]|0,j)|0;j=g+(a+15<<2)|0;c[j>>2]=(c[j>>2]|0)+k+d;return}function ox(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;if((c[3645589]|0)>>>0<a>>>0){ov(a);d=c[3645589]|0;f=a-d+239|0;c[3645589]=d-((f>>>0)%240|0)+f}f=(b&128|0)!=0;if(f){d=b>>>4&7;c[3645562]=d;g=d}else{g=c[3645562]|0}switch(g|0){case 6:{c[3645560]=b&15;c[3645563]=32768;c[3645564]=16<<(b&3);return};case 7:{d=b&15;c[3645561]=d;a=e[736760+(d<<1)>>1]|0;c[3645579]=((ab(a,c[3645550]|0)|0)>>>0)/100|0;c[3645580]=((ab(c[3645551]|0,a)|0)>>>0)/100|0;return};case 1:case 3:case 5:{a=b&15;c[14582216+(g<<2)>>2]=a;d=e[736760+(a<<1)>>1]|0;a=g>>>1;c[14582292+(a<<3)>>2]=((ab(d,c[14582176+(a<<3)>>2]|0)|0)>>>0)/100|0;c[14582296+(a<<3)>>2]=((ab(c[14582180+(a<<3)>>2]|0,d)|0)>>>0)/100|0;return};case 0:case 2:case 4:{d=14582216+(g<<2)|0;g=c[d>>2]|0;if(f){h=g&1008|b&15}else{h=g&15|b<<4&1008}c[d>>2]=h;if((h|0)!=0){return}c[d>>2]=1;return};default:{return}}}
function hw(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;if(e>>>0<19){j=2;return j|0}k=c[i>>2]|0;l=a[b]|0;m=l&255;n=c[684280+((m&15^15)<<2)>>2]^268435455;o=n>>>4^c[684280+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=66){j=3;return j|0}l=a[b+1|0]|0;m=l&255;n=c[684280+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[684280+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=80){j=3;return j|0}l=a[b+2|0]|0;m=l&255;n=c[684280+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[684280+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=83){j=3;return j|0}l=a[b+3|0]|0;m=l&255;n=c[684280+(((m^o)&15)<<2)>>2]^o>>>4;if(l<<24>>24!=49){j=3;return j|0}l=0;o=0;p=0;q=1;r=n>>>4^c[684280+((n&15^m>>>4)<<2)>>2];m=4;n=7;while(1){s=d[b+m|0]|0;t=c[684280+(((s^r)&15)<<2)>>2]^r>>>4;u=t>>>4^c[684280+((t&15^s>>>4)<<2)>>2];t=m+1|0;v=aIP(s&127,0,q,p)|0;w=aIF(v,F,o,l)|0;if((s&128|0)!=0){x=0;y=0;z=0;A=1;B=u;C=t;D=n;break}s=q<<7|0>>>25;v=p<<7|q>>>25;E=aIF(w,F,s,v)|0;l=F;o=E;p=v;q=s;r=u;m=t;n=n+1|0}while(1){n=d[b+C|0]|0;m=c[684280+(((n^B)&15)<<2)>>2]^B>>>4;r=m>>>4^c[684280+((m&15^n>>>4)<<2)>>2];m=C+1|0;q=aIP(n&127,0,A,z)|0;G=aIF(q,F,y,x)|0;if((n&128|0)!=0){H=0;I=0;J=0;K=1;L=r;M=m;N=D;break}n=A<<7|0>>>25;q=z<<7|A>>>25;p=aIF(G,F,n,q)|0;x=F;y=p;z=q;A=n;B=r;C=m;D=D+1|0}while(1){O=a[b+M|0]|0;D=O&255;C=c[684280+(((D^L)&15)<<2)>>2]^L>>>4;P=C>>>4^c[684280+((C&15^D>>>4)<<2)>>2];Q=M+1|0;C=aIP(D&127,0,K,J)|0;R=aIF(C,F,I,H)|0;if((D&128|0)!=0){break}D=K<<7|0>>>25;C=J<<7|K>>>25;B=aIF(R,F,D,C)|0;H=F;I=B;J=C;K=D;L=P;M=Q;N=N+1|0}M=w;w=G;G=R;if((G|0)==0){S=P;T=Q}else{R=aIP(O&127,0,K,J)|0;J=aIF(R,F,I,H)|0;H=P;P=Q;Q=0;while(1){I=d[b+P|0]|0;R=c[684280+(((I^H)&15)<<2)>>2]^H>>>4;U=R>>>4^c[684280+((R&15^I>>>4)<<2)>>2];I=Q+1|0;if(I>>>0<G>>>0){H=U;P=P+1|0;Q=I}else{break}}S=U;T=J+N|0}if(M>>>0>g>>>0){j=5;return j|0}if(w>>>0>k>>>0){j=6;return j|0}k=e-12|0;e=T;T=0;M=0;N=S;S=-1;J=0;L4376:while(1){U=e;Q=T;P=N;H=S;G=J;while(1){I=U;R=P;V=H;W=G;L4380:while(1){X=I;Y=R;while(1){if(X>>>0<k>>>0){Z=0;_=0;$=0;aa=1;ab=Y;ac=X}else{break L4376}while(1){K=d[b+ac|0]|0;O=c[684280+(((K^ab)&15)<<2)>>2]^ab>>>4;ad=O>>>4^c[684280+((O&15^K>>>4)<<2)>>2];ae=ac+1|0;O=aIP(K&127,0,aa,$)|0;af=aIF(O,F,_,Z)|0;if((K&128|0)!=0){break}K=aa<<7|0>>>25;O=$<<7|aa>>>25;L=aIF(af,F,K,O)|0;Z=F;_=L;$=O;aa=K;ab=ad;ac=ae}ag=af;ah=ag&3;if((ah|0)==0){ai=3124;break}else if((ah|0)==1){ai=3126;break}else if((ah|0)==2|(ah|0)==3){break L4380}else{X=ae;Y=ad}}if((ai|0)==3124){ai=0;K=(ag>>>2)+1|0;O=W;L=V;D=K;while(1){C=a[f+O|0]|0;a[h+O|0]=C;B=C&255;C=c[684280+(((B^L)&15)<<2)>>2]^L>>>4;A=C>>>4^c[684280+((C&15^B>>>4)<<2)>>2];B=D-1|0;if((B|0)==0){aj=ae;ak=ad;al=A;am=K;break}else{O=O+1|0;L=A;D=B}}}else if((ai|0)==3126){ai=0;D=(ag>>>2)+1|0;L=W;O=V;K=ad;B=ae;A=D;while(1){C=A-1|0;z=a[b+B|0]|0;y=z&255;x=c[684280+(((y^K)&15)<<2)>>2]^K>>>4;m=y>>>4;an=x>>>4^c[684280+((x&15^m)<<2)>>2];a[h+L|0]=z;z=c[684280+(((y^O)&15)<<2)>>2]^O>>>4;ao=z>>>4^c[684280+((z&15^m)<<2)>>2];if((C|0)==0){break}else{L=L+1|0;O=ao;K=an;B=B+1|0;A=C}}aj=D+ae|0;ak=an;al=ao;am=D}I=aj;R=ak;V=al;W=am+W|0}ap=(ag>>>2)+1|0;R=0;I=0;A=0;B=1;K=ad;O=ae;while(1){L=d[b+O|0]|0;C=c[684280+(((L^K)&15)<<2)>>2]^K>>>4;aq=C>>>4^c[684280+((C&15^L>>>4)<<2)>>2];ar=O+1|0;C=aIP(L&127,0,B,A)|0;as=aIF(C,F,I,R)|0;if((L&128|0)!=0){break}L=B<<7|0>>>25;C=A<<7|B>>>25;m=aIF(as,F,L,C)|0;R=F;I=m;A=C;B=L;K=aq;O=ar}O=as;K=O>>1;at=(O&1|0)==0?K:-K|0;if((ah|0)!=2){break}K=W;O=V;B=at+Q|0;A=ap;while(1){I=A-1|0;R=a[f+B|0]|0;a[h+K|0]=R;L=R&255;R=c[684280+(((L^O)&15)<<2)>>2]^O>>>4;au=R>>>4^c[684280+((R&15^L>>>4)<<2)>>2];if((I|0)==0){break}else{K=K+1|0;O=au;B=B+1|0;A=I}}U=ar;Q=ap+Q+at|0;P=aq;H=au;G=ap+W|0}G=W;H=V;P=at+M|0;U=ap;while(1){A=U-1|0;B=a[h+P|0]|0;a[h+G|0]=B;O=B&255;B=c[684280+(((O^H)&15)<<2)>>2]^H>>>4;av=B>>>4^c[684280+((B&15^O>>>4)<<2)>>2];if((A|0)==0){break}else{G=G+1|0;H=av;P=P+1|0;U=A}}e=ar;T=Q;M=ap+M+at|0;N=aq;S=av;J=ap+W|0}W=d[b+X|0]|0;ap=c[684280+(((W^Y)&15)<<2)>>2]^Y>>>4;Y=ap>>>4^c[684280+((ap&15^W>>>4)<<2)>>2];ap=d[b+(X+1)|0]|0;J=c[684280+(((ap^Y)&15)<<2)>>2]^Y>>>4;Y=J>>>4^c[684280+((J&15^ap>>>4)<<2)>>2];J=d[b+(X+2)|0]|0;av=c[684280+(((J^Y)&15)<<2)>>2]^Y>>>4;Y=av>>>4^c[684280+((av&15^J>>>4)<<2)>>2];av=d[b+(X+3)|0]|0;S=c[684280+(((av^Y)&15)<<2)>>2]^Y>>>4;Y=S>>>4^c[684280+((S&15^av>>>4)<<2)>>2];S=d[b+(X+4)|0]|0;aq=c[684280+(((S^Y)&15)<<2)>>2]^Y>>>4;Y=aq>>>4^c[684280+((aq&15^S>>>4)<<2)>>2];aq=ap<<8|W|J<<16|av<<24;av=d[b+(X+5)|0]|0;J=c[684280+(((av^Y)&15)<<2)>>2]^Y>>>4;Y=J>>>4^c[684280+((J&15^av>>>4)<<2)>>2];J=d[b+(X+6)|0]|0;W=c[684280+(((J^Y)&15)<<2)>>2]^Y>>>4;Y=W>>>4^c[684280+((W&15^J>>>4)<<2)>>2];W=d[b+(X+7)|0]|0;ap=c[684280+(((W^Y)&15)<<2)>>2]^Y>>>4;Y=~(ap>>>4^c[684280+((ap&15^W>>>4)<<2)>>2]);ap=(d[b+(X+9)|0]|0)<<8|(d[b+(X+8)|0]|0)|(d[b+(X+10)|0]|0)<<16|(d[b+(X+11)|0]|0)<<24;if((f|0)==0|(g|0)==0){aw=0}else{X=g;g=f;f=-1;while(1){b=X-1|0;N=d[g]|0;at=c[684280+(((N^f)&15)<<2)>>2]^f>>>4;ax=at>>>4^c[684280+((at&15^N>>>4)<<2)>>2];if((b|0)==0){break}else{X=b;g=g+1|0;f=ax}}aw=~ax}if((aw|0)!=(aq|0)){j=9;return j|0}if((av<<8|S|J<<16|W<<24|0)!=(~V|0)){j=10;return j|0}if((ap|0)!=(Y|0)){j=11;return j|0}c[i>>2]=w;j=1;return j|0}function hx(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;j=c[i>>2]|0;if(e>>>0<=17){k=4;return k|0}l=a[b]|0;m=l&255;n=c[684280+((m&15^15)<<2)>>2]^268435455;o=n>>>4^c[684280+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=85){k=4;return k|0}l=a[b+1|0]|0;m=l&255;n=c[684280+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[684280+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=80){k=4;return k|0}l=a[b+2|0]|0;m=l&255;n=c[684280+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[684280+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=83){k=4;return k|0}l=a[b+3|0]|0;m=l&255;n=c[684280+(((m^o)&15)<<2)>>2]^o>>>4;if(l<<24>>24!=49){k=4;return k|0}l=0;o=0;p=0;q=1;r=4;s=n>>>4^c[684280+((n&15^m>>>4)<<2)>>2];while(1){if(r>>>0<e>>>0){m=d[b+r|0]|0;n=c[684280+(((m^s)&15)<<2)>>2]^s>>>4;t=n>>>4^c[684280+((n&15^m>>>4)<<2)>>2];n=r+1|0;u=aIP(m&127,0,q,p)|0;v=aIF(u,F,o,l)|0;if((m&128|0)==0){w=F;x=v;y=n;z=t}else{A=0;B=0;C=0;D=1;E=n;G=t;break}}else{w=l;x=o;y=r;z=s}t=q<<7|0>>>25;n=p<<7|q>>>25;m=aIF(x,w,t,n)|0;l=F;o=m;p=n;q=t;r=y;s=z}while(1){if(E>>>0<e>>>0){z=d[b+E|0]|0;s=c[684280+(((z^G)&15)<<2)>>2]^G>>>4;H=s>>>4^c[684280+((s&15^z>>>4)<<2)>>2];I=E+1|0;s=aIP(z&127,0,D,C)|0;J=aIF(s,F,B,A)|0;if((z&128|0)==0){K=F;L=J;M=I;N=H}else{break}}else{K=A;L=B;M=E;N=G}z=D<<7|0>>>25;s=C<<7|D>>>25;y=aIF(L,K,z,s)|0;A=F;B=y;C=s;D=z;E=M;G=N}N=v;v=J;J=(N|0)==(g|0);G=(v|0)==(g|0);if(!(J|G)){k=7;return k|0}M=J?v:N;c[i>>2]=M;if(j>>>0<M>>>0){k=6;return k|0}j=e-12|0;if(I>>>0<j>>>0){i=-1;E=-1;D=H;C=0;B=0;A=I;while(1){K=0;L=0;z=0;s=1;y=A;r=D;while(1){if(y>>>0<e>>>0){q=d[b+y|0]|0;p=c[684280+(((q^r)&15)<<2)>>2]^r>>>4;O=p>>>4^c[684280+((p&15^q>>>4)<<2)>>2];P=y+1|0;p=aIP(q&127,0,s,z)|0;Q=aIF(p,F,L,K)|0;if((q&128|0)==0){R=F;S=Q;T=P;U=O}else{break}}else{R=K;S=L;T=y;U=r}q=s<<7|0>>>25;p=z<<7|s>>>25;o=aIF(S,R,q,p)|0;K=F;L=o;z=p;s=q;y=T;r=U}r=Q;if((r|0)==0){V=P;W=B;X=C;Y=O;Z=E;_=i}else{y=i;s=E;z=C;L=B;K=r;while(1){q=K-1|0;if(L>>>0<g>>>0){p=a[f+L|0]|0;o=p&255;l=c[684280+(((o^s)&15)<<2)>>2]^s>>>4;$=p;aa=L+1|0;ab=l>>>4^c[684280+((l&15^o>>>4)<<2)>>2]}else{$=0;aa=L;ab=s}if(z>>>0<M>>>0){a[h+z|0]=$;o=$&255;l=c[684280+(((o^y)&15)<<2)>>2]^y>>>4;ac=l>>>4^c[684280+((l&15^o>>>4)<<2)>>2]}else{ac=y}if((q|0)==0){break}else{y=ac;s=ab;z=z+1|0;L=aa;K=q}}V=P;W=aa;X=r+C|0;Y=O;Z=ab;_=ac}while(1){if(V>>>0<e>>>0){K=a[b+V|0]|0;L=K&255;z=c[684280+(((L^Y)&15)<<2)>>2]^Y>>>4;ad=K;ae=V+1|0;af=z>>>4^c[684280+((z&15^L>>>4)<<2)>>2]}else{ad=0;ae=V;af=Y}if(W>>>0<g>>>0){L=a[f+W|0]|0;z=L&255;K=c[684280+(((z^Z)&15)<<2)>>2]^Z>>>4;ag=L;ah=W+1|0;ai=K>>>4^c[684280+((K&15^z>>>4)<<2)>>2]}else{ag=0;ah=W;ai=Z}z=ag^ad;if(X>>>0<M>>>0){a[h+X|0]=z;K=z&255;z=c[684280+(((K^_)&15)<<2)>>2]^_>>>4;aj=z>>>4^c[684280+((z&15^K>>>4)<<2)>>2]}else{aj=_}ak=X+1|0;if(ad<<24>>24==0){break}else{V=ae;W=ah;X=ak;Y=af;Z=ai;_=aj}}if(ae>>>0<j>>>0){i=aj;E=ai;D=af;C=ak;B=ah;A=ae}else{al=aj;am=ai;an=af;ao=ak;ap=ah;aq=ae;break}}}else{al=-1;am=-1;an=H;ao=0;ap=0;aq=I}if(ap>>>0<g>>>0){I=al;H=am;ae=ao;ah=ap;while(1){ak=a[f+ah|0]|0;af=ak&255;ai=c[684280+(((af^H)&15)<<2)>>2]^H>>>4;aj=af>>>4;ar=ai>>>4^c[684280+((ai&15^aj)<<2)>>2];ai=ah+1|0;if(ae>>>0<M>>>0){a[h+ae|0]=ak;ak=c[684280+(((af^I)&15)<<2)>>2]^I>>>4;as=ak>>>4^c[684280+((ak&15^aj)<<2)>>2]}else{as=I}if(ai>>>0<g>>>0){I=as;H=ar;ae=ae+1|0;ah=ai}else{break}}at=as;au=ar;av=g-ap+ao|0;aw=g}else{at=al;au=am;av=ao;aw=ap}if(av>>>0<M>>>0){ap=at;ao=au;am=av;av=aw;while(1){if(av>>>0<g>>>0){aw=a[f+av|0]|0;al=aw&255;ar=c[684280+(((al^ao)&15)<<2)>>2]^ao>>>4;ax=aw;ay=av+1|0;az=ar>>>4^c[684280+((ar&15^al>>>4)<<2)>>2]}else{ax=0;ay=av;az=ao}a[h+am|0]=ax;al=ax&255;ar=c[684280+(((al^ap)&15)<<2)>>2]^ap>>>4;aw=ar>>>4^c[684280+((ar&15^al>>>4)<<2)>>2];al=am+1|0;if(al>>>0<M>>>0){ap=aw;ao=az;am=al;av=ay}else{aA=aw;aB=az;break}}}else{aA=at;aB=au}if(aq>>>0<e>>>0){au=d[b+aq|0]|0;at=c[684280+(((au^an)&15)<<2)>>2]^an>>>4;aC=au;aD=aq+1|0;aE=at>>>4^c[684280+((at&15^au>>>4)<<2)>>2]}else{aC=0;aD=aq;aE=an}if(aD>>>0<e>>>0){an=d[b+aD|0]|0;aq=c[684280+(((an^aE)&15)<<2)>>2]^aE>>>4;aF=an<<8;aG=aD+1|0;aH=aq>>>4^c[684280+((aq&15^an>>>4)<<2)>>2]}else{aF=0;aG=aD;aH=aE}if(aG>>>0<e>>>0){aE=d[b+aG|0]|0;aD=c[684280+(((aE^aH)&15)<<2)>>2]^aH>>>4;aI=aE<<16;aJ=aG+1|0;aK=aD>>>4^c[684280+((aD&15^aE>>>4)<<2)>>2]}else{aI=0;aJ=aG;aK=aH}if(aJ>>>0<e>>>0){aH=d[b+aJ|0]|0;aG=c[684280+(((aH^aK)&15)<<2)>>2]^aK>>>4;aL=aH<<24;aM=aJ+1|0;aN=aG>>>4^c[684280+((aG&15^aH>>>4)<<2)>>2]}else{aL=0;aM=aJ;aN=aK}aK=aF|aC|aI|aL;if(aM>>>0<e>>>0){aL=d[b+aM|0]|0;aI=c[684280+(((aL^aN)&15)<<2)>>2]^aN>>>4;aO=aL;aP=aM+1|0;aQ=aI>>>4^c[684280+((aI&15^aL>>>4)<<2)>>2]}else{aO=0;aP=aM;aQ=aN}if(aP>>>0<e>>>0){aN=d[b+aP|0]|0;aM=c[684280+(((aN^aQ)&15)<<2)>>2]^aQ>>>4;aR=aN<<8;aS=aP+1|0;aT=aM>>>4^c[684280+((aM&15^aN>>>4)<<2)>>2]}else{aR=0;aS=aP;aT=aQ}if(aS>>>0<e>>>0){aQ=d[b+aS|0]|0;aP=c[684280+(((aQ^aT)&15)<<2)>>2]^aT>>>4;aU=aQ<<16;aV=aS+1|0;aW=aP>>>4^c[684280+((aP&15^aQ>>>4)<<2)>>2]}else{aU=0;aV=aS;aW=aT}if(aV>>>0<e>>>0){aT=d[b+aV|0]|0;aS=c[684280+(((aT^aW)&15)<<2)>>2]^aW>>>4;aX=aT<<24;aY=aV+1|0;aZ=aS>>>4^c[684280+((aS&15^aT>>>4)<<2)>>2]}else{aX=0;aY=aV;aZ=aW}aW=aR|aO|aU|aX;aX=~aB;if(aY>>>0<e>>>0){a_=d[b+aY|0]|0;a$=aY+1|0}else{a_=0;a$=aY}if(a$>>>0<e>>>0){a0=(d[b+a$|0]|0)<<8;a1=a$+1|0}else{a0=0;a1=a$}if(a1>>>0<e>>>0){a2=(d[b+a1|0]|0)<<16;a3=a1+1|0}else{a2=0;a3=a1}if(a3>>>0<e>>>0){a4=(d[b+a3|0]|0)<<24}else{a4=0}a3=~aA;if((a0|a_|a2|a4|0)!=(~aZ|0)){k=4;return k|0}if(!((aK|0)!=(aX|0)|J^1)){return((aW|0)==(a3|0)&(M|0)==(v|0)?1:8)|0}if((aW|0)!=(aX|0)|G^1){k=7;return k|0}k=(aK|0)==(a3|0)&(M|0)==(N|0)?1:8;return k|0}function hy(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if(e>>>0<8){j=4;return j|0}if((a[b]|0)!=80){j=4;return j|0}if((a[b+1|0]|0)!=65){j=4;return j|0}if((a[b+2|0]|0)!=84){j=4;return j|0}if((a[b+3|0]|0)!=67){j=4;return j|0}if((a[b+4|0]|0)!=72){j=4;return j|0}aIy(h|0,f|0,g)|0;c[i>>2]=g;g=e-3|0;if(g>>>0<5){j=4;return j|0}f=e-2|0;k=5;while(1){l=k+3|0;m=d[b+(k+1)|0]<<8|d[b+k|0]<<16|d[b+(k+2)|0];if((m|0)==4542278){if((l|0)==(e|0)){j=1;n=3262;break}if((l|0)==(g|0)){n=3245;break}}if(l>>>0>f>>>0){j=4;n=3268;break}o=k+5|0;p=d[b+l|0]<<8|d[b+(k+4)|0];if((p|0)==0){if(o>>>0>g>>>0){j=4;n=3273;break}l=d[b+o|0]<<8|d[b+(k+6)|0];if((l|0)==0){j=4;n=3271;break}q=b+(k+7)|0;r=m;s=l;while(1){t=s-1|0;a[h+r|0]=a[q]|0;if((t|0)==0){break}else{r=r+1|0;s=t}}u=l;v=k+8|0}else{if(o>>>0>(e-p|0)>>>0){j=4;n=3272;break}else{w=o;x=m;y=p}while(1){s=y-1|0;a[h+x|0]=a[b+w|0]|0;if((s|0)==0){break}else{w=w+1|0;x=x+1|0;y=s}}u=p;v=p+o|0}l=u+m|0;if(l>>>0>(c[i>>2]|0)>>>0){c[i>>2]=l}if(v>>>0>g>>>0){j=4;n=3270;break}else{k=v}}if((n|0)==3273){return j|0}else if((n|0)==3245){c[i>>2]=d[b+(k+4)|0]<<8|d[b+g|0]<<16|d[b+(k+5)|0];j=1;return j|0}else if((n|0)==3272){return j|0}else if((n|0)==3271){return j|0}else if((n|0)==3262){return j|0}else if((n|0)==3268){return j|0}else if((n|0)==3270){return j|0}return 0}function hz(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=c[494446]|0;a5(729328,85,1,((f|0)!=0?f:c[p>>2]|0)|0)|0;f=c[494446]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;c[e>>2]=0;f=c9(b|0,720728)|0;if((f|0)==0){g=0;i=d;return g|0}b=aIp(4)|0;if((b|0)==0){aS(f|0)|0;g=0;i=d;return g|0}if((c[b-4>>2]&3|0)!=0){h=b;x=0;a[h]=x&255;x=x>>8;a[h+1|0]=x&255;x=x>>8;a[h+2|0]=x&255;x=x>>8;a[h+3|0]=x&255}h=b;ev(f|0,0,2)|0;j=cf(f|0)|0;eD(f|0);k=aIp(j+1|0)|0;do{if((k|0)==0){l=0;m=3288}else{a[k+j|0]=0;if((ec(k|0,1,j|0,f|0)|0)!=(j|0)){l=k;m=3288;break}aS(f|0)|0;c[e>>2]=k;do{if((aID(k|0,728752,5)|0)==0){n=bx(k|0,726552)|0;if((n|0)==0){o=k;break}q=n+3|0;c[e>>2]=q;r=q;m=3283}else{r=k;m=3283}}while(0);do{if((m|0)==3283){q=aIu(r|0)|0;n=aIp(q+1|0)|0;if((n|0)==0){o=k;break}a[n+q|0]=0;q=bx(r|0,691736)|0;s=bx(r|0,731040)|0;if((q|0)==0|(s|0)==0){t=r;u=n}else{v=r;w=n;y=q;q=s;while(1){s=y-v|0;aIy(w|0,v|0,s)|0;z=w+s|0;s=q+3|0;A=bx(s|0,691736)|0;B=bx(s|0,731040)|0;if((A|0)==0|(B|0)==0){t=s;u=z;break}else{v=s;w=z;y=A;q=B}}}q=aIu(t|0)|0;aIy(u|0,t|0,q)|0;a[u+q|0]=0;aIq(k);c[e>>2]=n;q=hA(e)|0;c[b>>2]=q;if((q|0)==0){o=n;break}aIq(n);g=h;i=d;return g|0}}while(0);aIq(o)}}while(0);if((m|0)==3288){aIq(l);aS(f|0)|0}f=c[b>>2]|0;if((f|0)!=0){hB(f)}aIq(b);g=0;i=d;return g|0}function hA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=aIp(24)|0;if((g|0)==0){h=0;i=d;return h|0}if((c[g-4>>2]&3|0)!=0){aIv(g|0,0,24)}j=g;k=c[b>>2]|0;while(1){l=k+1|0;if((bf(a[k]|0)|0)==0){break}else{k=l}}c[b>>2]=k;L4649:do{if((a[k]|0)==60){m=b4(k|0,62)|0;if((m|0)==0){n=0;break}o=m-l|0;p=aIp(o+1|0)|0;if((p|0)==0){n=0;break}aIy(p|0,l|0,o)|0;a[p+o|0]=0;o=p;while(1){if((bf(a[o]|0)|0)==0){q=o;break}else{o=o+1|0}}while(1){r=a[q]|0;if(r<<24>>24==0){s=0;break}if((bf(r<<24>>24|0)|0)==0){q=q+1|0}else{t=3311;break}}if((t|0)==3311){s=a[q]|0}r=(bf(s|0)|0)!=0?q:0;if((r|0)==0){u=dv(o|0)|0;c[g>>2]=u;if((u|0)==0){n=p;break}if((a[u]|0)==0){n=p;break}}else{u=r-o|0;v=aIp(u+1|0)|0;if((v|0)==0){c[g>>2]=0;n=p;break}aIy(v|0,o|0,u)|0;a[v+u|0]=0;c[g>>2]=v;if((a[v]|0)==0){n=p;break}v=dv(r|0)|0;if((v|0)==0){w=0}else{r=v+((aIu(v|0)|0)-1)|0;if((a[r]|0)==47){a[r]=0}r=ee(v|0,696024,e|0)|0;L4674:do{if((r|0)==0){x=0}else{u=r;y=0;z=0;while(1){A=bx(u|0,694016)|0;if((A|0)==0){x=z;break L4674}B=A+2|0;C=ck(B|0,34)|0;if((C|0)==0){x=z;break L4674}if((C|0)!=(u+((aIu(u|0)|0)-1)|0)){x=z;break L4674}D=A-u|0;A=aIp(D+1|0)|0;if((A|0)==0){E=0}else{aIy(A|0,u|0,D)|0;a[A+D|0]=0;E=A}A=C-B|0;C=aIp(A+1|0)|0;if((C|0)==0){x=z;break L4674}aIy(C|0,B|0,A)|0;a[C+A|0]=0;if((E|0)==0){x=z;break L4674}A=aIp(12)|0;if((A|0)==0){x=z;break L4674}if((c[A-4>>2]&3|0)!=0){aIv(A|0,0,12)}B=A;c[A>>2]=E;c[A+4>>2]=C;if((y|0)==0){F=B}else{c[y+8>>2]=B;F=z}C=ee(0,696024,e|0)|0;if((C|0)==0){x=F;break}else{u=C;y=B;z=F}}}}while(0);aIq(v);w=x}c[g+8>>2]=w}if(((bx(k|0,716184)|0)+1|0)==(m|0)){c[b>>2]=m+1}else{r=c[g>>2]|0;o=(aIu(r|0)|0)+4|0;z=aIp(o)|0;if((z|0)==0){n=p;break}bQ(z|0,o|0,707952,(o=i,i=i+8|0,c[o>>2]=r,o)|0)|0;i=o;o=m+1|0;r=bx(o|0,703664)|0;y=b4(o|0,60)|0;u=bx(o|0,z|0)|0;if((u|0)==0){aIq(z);n=p;break}L4702:do{if((r|0)==0){t=3349}else{B=o;while(1){if(B>>>0>=r>>>0){break}if((bf(a[B]|0)|0)==0){t=3349;break L4702}else{B=B+1|0}}B=bx(r|0,700336)|0;if((B|0)==0){aIq(z);n=p;break L4649}C=r+9|0;A=B-C|0;B=aIp(A+1|0)|0;if((B|0)==0){G=0}else{aIy(B|0,C|0,A)|0;a[B+A|0]=0;G=B}c[g+4>>2]=G;H=u}}while(0);do{if((t|0)==3349){if((u|0)==(y|0)){r=y-o|0;m=aIp(r+1|0)|0;if((m|0)==0){I=0}else{aIy(m|0,o|0,r)|0;a[m+r|0]=0;I=m}c[g+4>>2]=I;H=y;break}c[f>>2]=y;m=b4(y|0,60)|0;r=bx(y|0,697952)|0;L4721:do{if((r|0)!=0&(m|0)!=0&m>>>0<r>>>0){v=0;B=0;while(1){A=hA(f)|0;if((A|0)==0){break}if((B|0)==0){J=A}else{c[B+16>>2]=A;J=v}C=c[f>>2]|0;D=b4(C|0,60)|0;K=bx(C|0,697952)|0;if((K|0)!=0&(D|0)!=0&D>>>0<K>>>0){v=J;B=A}else{L=J;M=C;break L4721}}aIq(z);n=p;break L4649}else{L=0;M=y}}while(0);c[g+12>>2]=L;r=bx(M|0,z|0)|0;if((r|0)!=0){H=r;break}aIq(z);n=p;break L4649}}while(0);c[b>>2]=H+(aIu(z|0)|0);aIq(z)}aIq(p);h=j;i=d;return h|0}else{n=0}}while(0);aIq(n);hB(j);h=0;i=d;return h|0}function hB(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((b|0)!=0){d=b;while(1){b=c[d+16>>2]|0;hB(d);if((b|0)==0){break}else{d=b}}}d=c[a+8>>2]|0;if((d|0)!=0){b=d;while(1){d=c[b+8>>2]|0;aIq(c[b>>2]|0);aIq(c[b+4>>2]|0);aIq(b);if((d|0)==0){break}else{b=d}}}aIq(c[a>>2]|0);aIq(c[a+4>>2]|0);aIq(a);return}function hC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b;g=f-a|0;h=g>>2;do{if((h|0)==0){j=0}else{if(h>>>0<=65535){j=g;break}j=((g>>>0)/(h>>>0)|0|0)==4?g:-1}}while(0);k=aIp(j)|0;if((k|0)==0){l=c[494446]|0;m=(l|0)!=0?l:c[p>>2]|0;ei(m|0,712776,(m=i,i=i+16|0,c[m>>2]=728824,c[m+8>>2]=150,m)|0)|0;i=m;m=c[494446]|0;l=(m|0)!=0?m:c[p>>2]|0;a_(l|0)|0;ch(2)}if((c[k-4>>2]&3|0)!=0){aIv(k|0,0,j|0)}j=a;aIy(k|0,j|0,g)|0;aIC(j|0,b|0,d-f|0);f=d+(-h<<2)|0;aIy(f|0,k|0,g)|0;aIq(k);i=e;return}function hD(a){a=a|0;return 1}function hE(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=i;i=i+8256|0;k=j|0;l=j+8|0;m=j+64|0;n=j+4160|0;o=n|0;eM(k|0)|0;cX(o|0,4096,691032,bg(k|0)|0)|0;k=aIu(o|0)|0;q=k>>>0>4096?0:4096-k|0;L4758:do{if((q|0)==0){r=729096;s=3387}else{t=n+k|0;do{if((q|0)==1){u=729096;v=t}else{w=n+(k+1)|0;a[t]=98;if((q|0)==2){u=729097;v=w;break}y=n+(k+2)|0;a[w]=109;if((q|0)==3){u=729098;v=y;break}w=n+(k+3)|0;a[y]=112;if((q|0)==4){u=729099;v=w;break}a[w]=0;break L4758}}while(0);a[v]=0;r=u;s=3387}}while(0);do{if((s|0)==3387){if((a[r]|0)==0){break}else{z=r}do{z=z+1|0;}while((a[z]|0)!=0)}}while(0);z=m|0;gz(z,1807364,o);o=c9(z|0,707632)|0;if((o|0)==0){m=c[494446]|0;r=(m|0)!=0?m:c[p>>2]|0;ei(r|0,716024,(r=i,i=i+8|0,c[r>>2]=z,r)|0)|0;i=r;r=c[494446]|0;z=(r|0)!=0?r:c[p>>2]|0;a_(z|0)|0;A=0;i=j;return A|0}z=l|0;r=e*3|0;m=r+3&-4;u=ab(m,f)|0;v=u+54|0;a[z]=66;a[l+1|0]=77;a[l+2|0]=v&255;a[l+3|0]=v>>>8&255;a[l+4|0]=v>>>16&255;a[l+5|0]=v>>>24&255;v=l+6|0;x=0;a[v]=x&255;x=x>>8;a[v+1|0]=x&255;x=x>>8;a[v+2|0]=x&255;x=x>>8;a[v+3|0]=x&255;a[l+10|0]=54;a[l+11|0]=0;a[l+12|0]=0;a[l+13|0]=0;a[l+14|0]=40;a[l+15|0]=0;a[l+16|0]=0;a[l+17|0]=0;a[l+18|0]=e&255;a[l+19|0]=e>>>8&255;a[l+20|0]=e>>>16&255;a[l+21|0]=e>>>24&255;a[l+22|0]=f&255;a[l+23|0]=f>>>8&255;a[l+24|0]=f>>>16&255;a[l+25|0]=f>>>24&255;a[l+26|0]=1;a[l+27|0]=0;a[l+28|0]=24;aIv(l+29|0,0,5);a[l+34|0]=u&255;a[l+35|0]=u>>>8&255;a[l+36|0]=u>>>16&255;a[l+37|0]=u>>>24&255;a[l+38|0]=19;a[l+39|0]=11;a[l+40|0]=0;a[l+41|0]=0;a[l+42|0]=19;a[l+43|0]=11;aIv(l+44|0,0,10);l=(a5(z|0,1,54,o|0)|0)==54;do{if(l){z=(f|0)==0;do{if(z){B=0}else{u=f<<2;if(f>>>0<=65535){B=u;break}B=((u>>>0)/(f>>>0)|0|0)==4?u:-1}}while(0);u=aIp(B)|0;if((u|0)==0){break}if((c[u-4>>2]&3|0)!=0){aIv(u|0,0,B|0)}v=u;q=0;while(1){if((q|0)>=(f|0)){s=3405;break}k=aIp(m)|0;if((k|0)==0){s=3404;break}if((c[k-4>>2]&3|0)!=0){aIv(k|0,0,m|0)}c[v+(q<<2)>>2]=k;q=q+1|0}do{if((s|0)==3405){do{if(h){if((f|0)>0){C=d;D=0}else{s=3419;break}while(1){k=c[v+(D<<2)>>2]|0;aIy(k|0,C|0,r)|0;k=D+1|0;if((k|0)<(f|0)){C=C+g|0;D=k}else{s=3419;break}}}else{k=(f|0)>0;if((c[478774]|0)==1){if(!k){s=3419;break}if((e|0)==0){E=0;break}else{F=d;G=0}while(1){n=F;t=0;w=c[v+(G<<2)>>2]|0;while(1){y=c[n>>2]|0;a[w]=y&255;a[w+1|0]=y>>>8&255;a[w+2|0]=y>>>16&255;y=t+1|0;if(y>>>0<e>>>0){n=n+4|0;t=y;w=w+3|0}else{break}}w=G+1|0;if((w|0)<(f|0)){F=F+g|0;G=w}else{s=3419;break}}}else{if(!k){s=3419;break}if((e|0)==0){E=0;break}else{H=d;I=0}while(1){w=0;t=H;n=c[v+(I<<2)>>2]|0;while(1){y=b[t>>1]|0;J=y&255;a[n]=(J&255)>>>2&7|J<<3;a[n+1|0]=(y&65535)>>>5<<2&255|(y&65535)>>>9&3;J=(y&65535)>>>11&65535;a[n+2|0]=(J<<3|J>>>2)&255;J=w+1|0;if(J>>>0<e>>>0){w=J;t=t+2|0;n=n+3|0}else{break}}n=I+1|0;if((n|0)<(f|0)){H=H+g|0;I=n}else{s=3419;break}}}}}while(0);if((s|0)==3419){if(z){break}else{E=0}}while(1){a5(c[v+(E<<2)>>2]|0,1,m|0,o|0)|0;k=E+1|0;if(k>>>0<f>>>0){E=k}else{s=3421;break}}}else if((s|0)==3404){c[v+(q<<2)>>2]=0;s=3421}}while(0);do{if((s|0)==3421){if((f|0)>0){K=0}else{break}do{aIq(c[v+(K<<2)>>2]|0);K=K+1|0;}while((K|0)<(f|0))}}while(0);aIq(u)}else{v=c[494446]|0;a5(707896,51,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;v=c[494446]|0;a_(((v|0)!=0?v:c[p>>2]|0)|0)|0}}while(0);aS(o|0)|0;A=l;i=j;return A|0}function hF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+544|0;e=d|0;if((b|0)==0){i=d;return}f=b|0;if((c[f>>2]|0)!=0){g=e|0;h=d+512|0;do{if((a[1803268]|0)!=0){j=gP(1803268,0)|0;if((j|0)==0){k=aIp(20)|0;if((k|0)==0){l=c[494446]|0;m=(l|0)!=0?l:c[p>>2]|0;a5(730984,53,1,m|0)|0;m=c[494446]|0;l=(m|0)!=0?m:c[p>>2]|0;a_(l|0)|0;break}if((c[k-4>>2]&3|0)!=0){aIv(k|0,0,20)}n=k}else{n=j}aIv(g|0,0,512);aIv(h|0,0,32);j=b+8|0;k=c[j>>2]|0;do{if((k|0)!=0){l=0;m=k;while(1){if((a[(c[f>>2]|0)+(l*12|0)+4|0]&1)==0){o=m}else{bQ(h|0,32,728744,(q=i,i=i+8|0,c[q>>2]=l,q)|0)|0;i=q;r=aIu(g|0)|0;s=r>>>0>512?0:512-r|0;L4849:do{if((s|0)==0){t=h;u=3448}else{v=s;w=e+r|0;x=h;while(1){y=v-1|0;if((y|0)==0){break}z=a[x]|0;a[w]=z;if(z<<24>>24==0){break L4849}else{v=y;w=w+1|0;x=x+1|0}}a[w]=0;t=x;u=3448}}while(0);do{if((u|0)==3448){u=0;if((a[t]|0)==0){break}else{A=t}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);o=c[j>>2]|0}x=l+1|0;if(x>>>0<o>>>0){l=x;m=o}else{break}}if((a[g]|0)==0){break}a[e+((aIu(g|0)|0)-1)|0]=0}}while(0);gS(n,1977620,g);if(!(gT(n,1803268)|0)){j=c[494446]|0;k=(j|0)!=0?j:c[p>>2]|0;ei(k|0,726464,(q=i,i=i+8|0,c[q>>2]=1803268,q)|0)|0;i=q;k=c[494446]|0;j=(k|0)!=0?k:c[p>>2]|0;a_(j|0)|0}gN(n)}}while(0);n=b+8|0;q=c[f>>2]|0;if((c[n>>2]|0)==0){B=q}else{g=0;e=q;while(1){aIq(c[e+(g*12|0)+8>>2]|0);q=g+1|0;o=c[f>>2]|0;if(q>>>0<(c[n>>2]|0)>>>0){g=q;e=o}else{B=o;break}}}aIq(B)}aIq(b);i=d;return}function hG(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=i;i=i+256|0;e=d|0;f=c[492315]|0;g=f+4|0;h=c[g>>2]|0;if(h>>>0>1){j=f|0;k=1;l=h;while(1){h=c[(c[j>>2]|0)+(k<<2)>>2]|0;if((h|0)==0){m=l}else{aIq(c[h+8>>2]|0);aIq(c[(c[j>>2]|0)+(k<<2)>>2]|0);c[(c[j>>2]|0)+(k<<2)>>2]=0;m=c[g>>2]|0}h=k+1|0;if(h>>>0<m>>>0){k=h;l=m}else{break}}}c[g>>2]=1;g=f+12|0;aIq(c[g>>2]|0);c[g>>2]=0;g=e|0;e=c[b+4>>2]|0;f=c[b>>2]|0;b=(a[f+(e*12|0)+4|0]&1)!=0?708336:707768;m=c[f+(e*12|0)>>2]|0;bQ(g|0,256,697928,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=b,c[f+16>>2]=m,f)|0)|0;i=f;m=c[492315]|0;b=m+4|0;L4883:do{if((c[b>>2]|0)>>>0<(c[m+8>>2]|0)>>>0){e=aIp(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}aIv(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=180;l=dv(g|0)|0;k=c[b>>2]|0;c[e+8>>2]=l;l=m|0;c[(c[l>>2]|0)+(k<<2)>>2]=e;k=c[b>>2]|0;c[b>>2]=k+1;if(k>>>0>1){n=k}else{break}while(1){k=n>>>1;j=c[l>>2]|0;h=j+(k<<2)|0;o=c[h>>2]|0;q=c[j+(n<<2)>>2]|0;if((c[q+4>>2]|0)>>>0<=(c[o+4>>2]|0)>>>0){break L4883}c[h>>2]=q;c[(c[l>>2]|0)+(n<<2)>>2]=o;if(n>>>0>3){n=k}else{break}}}}while(0);if((a[1820736]&1)==0){i=d;return}n=c[494446]|0;ei(((n|0)!=0?n:c[p>>2]|0)|0,727024,(f=i,i=i+8|0,c[f>>2]=g,f)|0)|0;i=f;f=c[494446]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;i=d;return}function hH(a,b,d){a=a|0;b=b|0;d=d|0;b=aT(d|0)|0;if((b|0)==0){return b|0}c[433472]=c$()|0;return b|0}function hI(a,b,c){a=a|0;b=b|0;c=c|0;return bH(b|0,c|0)|0}function hJ(a){a=a|0;return aN()|0}function hK(a){a=a|0;return e1()|0}function hL(a,b){a=a|0;b=b|0;d3(b|0);return}function hM(a){a=a|0;dZ();return}function hN(a){a=a|0;return cR()|0}function hO(a){a=a|0;return bm()|0}function hP(b,d){b=b|0;d=+d;var e=0,f=0,h=0,i=0,j=0.0;e=b+24|0;if((c[e>>2]|0)!=0){f=b+12|0;h=0;do{i=c[f>>2]|0;if((a[i+(h*136|0)+20|0]&1)==0){g[i+(h*136|0)+56>>2]=d;g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2]*d;g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]*d;j=+g[i+(h*136|0)+60>>2];g[i+(h*136|0)+24>>2]=j+(+g[i+(h*136|0)+40>>2]-j)*d;j=+g[i+(h*136|0)+64>>2];g[i+(h*136|0)+28>>2]=j+(+g[i+(h*136|0)+44>>2]-j)*d}else{g[i+(h*136|0)+24>>2]=+g[i+(h*136|0)+40>>2];g[i+(h*136|0)+28>>2]=+g[i+(h*136|0)+44>>2];g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2];g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]}h=h+1|0;}while(h>>>0<(c[e>>2]|0)>>>0)}e=c[b+16>>2]|0;fn[c[(c[b+4>>2]|0)+12>>2]&7](c[b>>2]|0,+g[e+24>>2],+g[e+28>>2],+g[e+32>>2],+g[e+36>>2]);return}function hQ(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aY=0.0,aZ=0.0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0;b=i;i=i+9240|0;d=b|0;e=b+64|0;f=b+320|0;h=b+328|0;j=b+392|0;k=b+456|0;l=b+520|0;m=b+584|0;n=b+4680|0;o=b+8776|0;q=b+8792|0;r=b+8856|0;s=b+9112|0;t=b+9176|0;u=aIp(32)|0;if((u|0)==0){v=0;i=b;return v|0}if((c[u-4>>2]&3|0)!=0){aIv(u|0,0,32)}w=u;x=c[(c[3118437]|0)+52>>2]|0;do{if((x|0)==0){y=c[494446]|0;z=(y|0)!=0?y:c[p>>2]|0;a5(727528,71,1,z|0)|0;z=c[494446]|0;y=(z|0)!=0?z:c[p>>2]|0;a_(y|0)|0}else{y=u+4|0;fj[x&511](c[3118440]|0,y);z=u;c[z>>2]=c[3118440];if((c[y>>2]|0)==0){break}A=gP(1778680,0)|0;if((A|0)==0){B=c[494446]|0;C=(B|0)!=0?B:c[p>>2]|0;ei(C|0,728600,(D=i,i=i+8|0,c[D>>2]=1778680,D)|0)|0;i=D;C=c[494446]|0;B=(C|0)!=0?C:c[p>>2]|0;a_(B|0)|0;break}B=A+4|0;C=B;while(1){E=c[C>>2]|0;if((E|0)==0){G=3512;break}if((cP(715848,c[E+4>>2]|0)|0)==0){G=3511;break}else{C=E+12|0}}L4936:do{if((G|0)==3511){c[(dX()|0)>>2]=0;C=aX(c[E+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){G=3512;break}if((C|0)==0){break}H=C*136|0;if(C>>>0>65535){I=((H>>>0)/(C>>>0)|0|0)==136?H:-1}else{I=H}H=aIp(I)|0;if((H|0)==0){c[u+12>>2]=0;break}if((c[H-4>>2]&3|0)!=0){aIv(H|0,0,I|0)}J=H;H=u+12|0;c[H>>2]=J;K=u+24|0;c[K>>2]=C;C=k|0;L=l|0;M=m|0;N=n|0;O=o;P=q|0;Q=r|0;R=s|0;S=t|0;T=o+8|0;U=o|0;V=o+4|0;W=d|0;X=e|0;Y=h|0;Z=j|0;bQ(C|0,64,695976,(D=i,i=i+8|0,c[D>>2]=0,D)|0)|0;i=D;L4949:do{if(gQ(A,C,M)|0){_=J;$=0;L4950:while(1){bQ(L|0,64,691712,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;aa=_+($*136|0)+69|0;ab=B;while(1){ac=c[ab>>2]|0;if((ac|0)==0){break}if((cP(L|0,c[ac+4>>2]|0)|0)==0){G=3526;break}else{ab=ac+12|0}}L4955:do{if((G|0)==3526){G=0;ab=64;ad=aa;ae=c[ac+8>>2]|0;while(1){af=ab-1|0;if((af|0)==0){break}ag=a[ae]|0;a[ad]=ag;if(ag<<24>>24==0){break L4955}else{ab=af;ad=ad+1|0;ae=ae+1|0}}a[ad]=0;if((a[ae]|0)==0){break}else{ah=ae}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);gJ(N,1778680,M);aIv(O|0,0,12);if((a[12473924]&1)==0){if(!(ih(N,o,16,0)|0)){G=3534;break}}else{if(!(ih(N,o,0,16)|0)){G=3534;break}}c[_+($*136|0)+8>>2]=c[T>>2];c[_+($*136|0)+12>>2]=c[U>>2];c[_+($*136|0)+16>>2]=c[V>>2];aa=_+($*136|0)+44|0;g[aa>>2]=0.0;ae=_+($*136|0)+40|0;g[ae>>2]=0.0;ad=_+($*136|0)+52|0;g[ad>>2]=1.0;ab=_+($*136|0)+48|0;g[ab>>2]=1.0;bQ(P|0,64,728688,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;af=B;while(1){ai=c[af>>2]|0;if((ai|0)==0){break}if((cP(P|0,c[ai+4>>2]|0)|0)==0){G=3538;break}else{af=ai+12|0}}do{if((G|0)==3538){G=0;af=256;ag=0;aj=Q;ak=c[ai+8>>2]|0;while(1){al=af-1|0;if((al|0)==0){G=3541;break}am=a[ak]|0;a[aj]=am;if(am<<24>>24==0){an=ag;break}else{af=al;ag=ag+1|0;aj=aj+1|0;ak=ak+1|0}}do{if((G|0)==3541){G=0;a[aj]=0;if((a[ak]|0)==0){an=ag;break}else{ao=ak;ap=ag}while(1){af=ao+1|0;al=ap+1|0;if((a[af]|0)==0){an=al;break}else{ao=af;ap=al}}}}while(0);if(an>>>0>=256){break}ag=gx(Q,726400)|0;ak=ag+4|0;if((c[ak>>2]|0)>>>0<4){G=3545;break L4950}aj=ag|0;g[ae>>2]=+aIt(c[c[aj>>2]>>2]|0);g[aa>>2]=+aIt(c[(c[aj>>2]|0)+8>>2]|0);g[ab>>2]=+aIt(c[(c[aj>>2]|0)+16>>2]|0);g[ad>>2]=+aIt(c[(c[aj>>2]|0)+24>>2]|0);if((ag|0)==0){break}al=c[aj>>2]|0;if((c[ak>>2]|0)==0){aq=al}else{af=0;am=al;while(1){aIq(c[am+(af<<3)>>2]|0);al=af+1|0;ar=c[aj>>2]|0;if(al>>>0<(c[ak>>2]|0)>>>0){af=al;am=ar}else{aq=ar;break}}}aIq(aq);aIq(ag)}}while(0);bQ(R|0,64,723968,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;am=_+($*136|0)+68|0;a[am]=0;gR(A,R,am)|0;bQ(S|0,64,722544,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;am=B;while(1){as=c[am>>2]|0;if((as|0)==0){G=3554;break L4950}if((cP(S|0,c[as+4>>2]|0)|0)==0){break}else{am=as+12|0}}c[(dX()|0)>>2]=0;am=aX(c[as+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){G=3554;break}af=(am|0)==0;do{if(af){at=0}else{ak=am*104|0;if(am>>>0<=65535){at=ak;break}at=((ak>>>0)/(am>>>0)|0|0)==104?ak:-1}}while(0);ak=aIp(at)|0;if((ak|0)==0){G=3561;break}if((c[ak-4>>2]&3|0)!=0){aIv(ak|0,0,at|0)}aj=ak;ak=_+($*136|0)|0;c[ak>>2]=aj;ar=_+($*136|0)+4|0;c[ar>>2]=am;L5002:do{if(!af){al=c[U>>2]|0;au=c[V>>2]|0;bQ(W|0,64,718104,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=0,D)|0)|0;i=D;av=B;while(1){aw=c[av>>2]|0;if((aw|0)==0){ax=0;G=3572;break L4950}if((cP(W|0,c[aw+4>>2]|0)|0)==0){break}else{av=aw+12|0}}av=256;ag=0;ay=X;az=c[aw+8>>2]|0;while(1){aA=av-1|0;if((aA|0)==0){G=3569;break}aB=a[az]|0;a[ay]=aB;if(aB<<24>>24==0){aC=ag;break}else{av=aA;ag=ag+1|0;ay=ay+1|0;az=az+1|0}}do{if((G|0)==3569){G=0;a[ay]=0;if((a[az]|0)==0){aC=ag;break}else{aD=az;aE=ag}while(1){av=aD+1|0;aA=aE+1|0;if((a[av]|0)==0){aC=aA;break}else{aD=av;aE=aA}}}}while(0);if(aC>>>0<256){aF=aj;aG=0;aH=al;aI=au}else{ax=0;G=3572;break L4950}while(1){aJ=gx(X,726400)|0;if((aJ|0)==0){G=3574;break L4950}aK=aJ+4|0;aL=c[aK>>2]|0;if(aL>>>0<6){G=3576;break L4950}aM=aJ|0;ag=c[aM>>2]|0;az=c[ag+8>>2]|0;ay=c[ag+16>>2]|0;aN=c[ag+24>>2]|0;aA=c[ag>>2]|0;ag=aF+(aG*104|0)+24|0;c[ag>>2]=0;c[ag+4>>2]=0;L5020:do{if((cP(aA|0,712888)|0)==0){c[aF+(aG*104|0)+20>>2]=1}else{av=aF+(aG*104|0)+20|0;if((cP(aA|0,711744)|0)==0){c[av>>2]=2;break}c[av>>2]=0;av=ee(aA|0,726824,f|0)|0;if((av|0)!=0){aB=av;do{av=0;while(1){if(av>>>0>=56){aO=0;aP=56;break}if((cP(c[1504+(av<<3)>>2]|0,aB|0)|0)==0){G=3587;break}else{av=av+1|0}}if((G|0)==3587){G=0;aO=0;aP=c[1508+(av<<3)>>2]|0}aQ=aIH(1,0,aP|0)|0;aR=F;aS=c[ag+4>>2]|aR;c[ag>>2]=c[ag>>2]|aQ;c[ag+4>>2]=aS;aB=ee(0,726824,f|0)|0;}while((aB|0)!=0)}if((c[ag>>2]&0|0)==0&(c[ag+4>>2]&524288|0)==0){break}bQ(Y|0,64,710248,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aG,D)|0)|0;i=D;aB=aF+(aG*104|0)+40|0;aS=B;while(1){aT=c[aS>>2]|0;if((aT|0)==0){break L5020}if((cP(Y|0,c[aT+4>>2]|0)|0)==0){break}else{aS=aT+12|0}}aS=64;aQ=aB;aR=c[aT+8>>2]|0;while(1){aU=aS-1|0;if((aU|0)==0){break}aV=a[aR]|0;a[aQ]=aV;if(aV<<24>>24==0){break L5020}else{aS=aU;aQ=aQ+1|0;aR=aR+1|0}}a[aQ]=0;if((a[aR]|0)==0){break}else{aW=aR}do{aW=aW+1|0;}while((a[aW]|0)!=0)}}while(0);aY=+(aH>>>0>>>0);g[aF+(aG*104|0)>>2]=+aIt(az)/aY;aZ=+(aI>>>0>>>0);g[aF+(aG*104|0)+4>>2]=+aIt(ay)/aZ;if((cP(aN|0,709608)|0)==0){c[aF+(aG*104|0)+8>>2]=0;a$=0}else{if((cP(aN|0,709224)|0)!=0){G=3602;break L4950}c[aF+(aG*104|0)+8>>2]=1;a$=1}do{if((c[aF+(aG*104|0)+20>>2]|0)!=0){if((a$|0)!=0){G=3607;break L4950}bQ(Z|0,64,707856,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aG,D)|0)|0;i=D;ag=aF+(aG*104|0)+32|0;aA=B;while(1){a0=c[aA>>2]|0;if((a0|0)==0){G=3614;break}if((cP(Z|0,c[a0+4>>2]|0)|0)==0){G=3613;break}else{aA=a0+12|0}}if((G|0)==3613){G=0;g[ag>>2]=+aIt(c[a0+8>>2]|0);break}else if((G|0)==3614){G=0;g[ag>>2]=1.0;break}}}while(0);g[aF+(aG*104|0)+12>>2]=+aIt(c[(c[aM>>2]|0)+32>>2]|0)/aY;g[aF+(aG*104|0)+16>>2]=+aIt(c[(c[aM>>2]|0)+40>>2]|0)/aZ;ay=c[aM>>2]|0;if((c[aK>>2]|0)==0){a1=ay}else{az=0;aA=ay;while(1){aIq(c[aA+(az<<3)>>2]|0);ay=az+1|0;aR=c[aM>>2]|0;if(ay>>>0<(c[aK>>2]|0)>>>0){az=ay;aA=aR}else{a1=aR;break}}}aIq(a1);aIq(aJ);aA=aG+1|0;if(aA>>>0>=(c[ar>>2]|0)>>>0){break L5002}az=c[ak>>2]|0;aR=c[U>>2]|0;ay=c[V>>2]|0;bQ(W|0,64,718104,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aA,D)|0)|0;i=D;aQ=B;while(1){a2=c[aQ>>2]|0;if((a2|0)==0){ax=aA;G=3572;break L4950}if((cP(W|0,c[a2+4>>2]|0)|0)==0){break}else{aQ=a2+12|0}}aQ=256;aS=0;aB=X;aU=c[a2+8>>2]|0;while(1){aV=aQ-1|0;if((aV|0)==0){G=3624;break}a3=a[aU]|0;a[aB]=a3;if(a3<<24>>24==0){a4=aS;break}else{aQ=aV;aS=aS+1|0;aB=aB+1|0;aU=aU+1|0}}do{if((G|0)==3624){G=0;a[aB]=0;if((a[aU]|0)==0){a4=aS;break}else{a6=aU;a7=aS}while(1){aQ=a6+1|0;aV=a7+1|0;if((a[aQ]|0)==0){a4=aV;break}else{a6=aQ;a7=aV}}}}while(0);if(a4>>>0<256){aF=az;aG=aA;aH=aR;aI=ay}else{ax=aA;G=3572;break L4950}}}}while(0);a[_+($*136|0)+20|0]=0;g[_+($*136|0)+60>>2]=+g[ae>>2]+ +g[ab>>2]*.5;g[_+($*136|0)+64>>2]=+g[aa>>2]+ +g[ad>>2]*.5;ak=$+1|0;a8=c[K>>2]|0;if(ak>>>0>=a8>>>0){G=3521;break}ar=c[H>>2]|0;bQ(C|0,64,695976,(D=i,i=i+8|0,c[D>>2]=ak,D)|0)|0;i=D;if(gQ(A,C,M)|0){_=ar;$=ak}else{a9=ak;G=3522;break L4949}}if((G|0)==3602){ak=c[494446]|0;ar=(ak|0)!=0?ak:c[p>>2]|0;ei(ar|0,708752,(D=i,i=i+8|0,c[D>>2]=aN,D)|0)|0;i=D;ar=c[494446]|0;ak=(ar|0)!=0?ar:c[p>>2]|0;a_(ak|0)|0;ak=c[aM>>2]|0;if((c[aK>>2]|0)==0){ba=ak}else{ar=0;aj=ak;while(1){aIq(c[aj+(ar<<3)>>2]|0);ak=ar+1|0;af=c[aM>>2]|0;if(ak>>>0<(c[aK>>2]|0)>>>0){ar=ak;aj=af}else{ba=af;break}}}aIq(ba);aIq(aJ);bb=aG}else if((G|0)==3574){aj=c[494446]|0;a5(715944,62,1,((aj|0)!=0?aj:c[p>>2]|0)|0)|0;aj=c[494446]|0;a_(((aj|0)!=0?aj:c[p>>2]|0)|0)|0;bb=aG}else if((G|0)==3576){aj=aJ|0;ar=c[aj>>2]|0;if((aL|0)==0){bc=ar}else{af=0;ak=ar;while(1){aIq(c[ak+(af<<3)>>2]|0);ar=af+1|0;am=c[aj>>2]|0;if(ar>>>0<(c[aK>>2]|0)>>>0){af=ar;ak=am}else{bc=am;break}}}aIq(bc);aIq(aJ);ak=c[494446]|0;a5(714168,85,1,((ak|0)!=0?ak:c[p>>2]|0)|0)|0;ak=c[494446]|0;a_(((ak|0)!=0?ak:c[p>>2]|0)|0)|0;bb=aG}else if((G|0)==3607){ak=c[494446]|0;a5(708360,69,1,((ak|0)!=0?ak:c[p>>2]|0)|0)|0;ak=c[494446]|0;a_(((ak|0)!=0?ak:c[p>>2]|0)|0)|0;ak=c[aM>>2]|0;if((c[aK>>2]|0)==0){bd=ak}else{af=0;aj=ak;while(1){aIq(c[aj+(af<<3)>>2]|0);ak=af+1|0;am=c[aM>>2]|0;if(ak>>>0<(c[aK>>2]|0)>>>0){af=ak;aj=am}else{bd=am;break}}}aIq(bd);aIq(aJ);bb=aG}else if((G|0)==3561){c[_+($*136|0)>>2]=0;aj=c[494446]|0;a5(720104,58,1,((aj|0)!=0?aj:c[p>>2]|0)|0)|0;aj=c[494446]|0;a_(((aj|0)!=0?aj:c[p>>2]|0)|0)|0;be=$;break}else if((G|0)==3521){L5101:do{if((a8|0)!=0){aj=0;af=a8;L5102:while(1){am=c[H>>2]|0;ak=am+(aj*136|0)+4|0;if((c[ak>>2]|0)==0){bf=af;bg=aj+1|0}else{ar=am+(aj*136|0)|0;au=aj+1|0;al=0;do{aS=c[ar>>2]|0;bh=aS+(al*104|0)+40|0;if((a[bh]|0)==0){c[aS+(al*104|0)+36>>2]=(au>>>0)%(af>>>0)|0}else{aU=0;while(1){if(aU>>>0>=af>>>0){break L5102}if((cP(am+(aU*136|0)+69|0,bh|0)|0)==0){break}else{aU=aU+1|0}}if((aU|0)<0){break L5102}c[aS+(al*104|0)+36>>2]=aU}al=al+1|0;}while(al>>>0<(c[ak>>2]|0)>>>0);bf=c[K>>2]|0;bg=au}if(bg>>>0<bf>>>0){aj=bg;af=bf}else{break L5101}}af=c[494446]|0;ei(((af|0)!=0?af:c[p>>2]|0)|0,697816,(D=i,i=i+8|0,c[D>>2]=bh,D)|0)|0;i=D;af=c[494446]|0;a_(((af|0)!=0?af:c[p>>2]|0)|0)|0;af=c[494446]|0;a5(700168,64,1,((af|0)!=0?af:c[p>>2]|0)|0)|0;af=c[494446]|0;a_(((af|0)!=0?af:c[p>>2]|0)|0)|0;break L4936}}while(0);gN(A);_=c[H>>2]|0;af=u+16|0;c[af>>2]=_;fE[c[(c[y>>2]|0)+4>>2]&15](c[z>>2]|0,c[_+8>>2]|0,c[_+12>>2]|0,c[_+16>>2]|0)|0;_=c[af>>2]|0;fn[c[(c[y>>2]|0)+12>>2]&7](c[z>>2]|0,+g[_+24>>2],+g[_+28>>2],+g[_+32>>2],+g[_+36>>2]);fj[c[(c[y>>2]|0)+16>>2]&511](c[z>>2]|0,(a[(c[af>>2]|0)+68|0]&1)!=0);fj[c[c[y>>2]>>2]&511](c[z>>2]|0,1);a[u+8|0]=1;fg[c[(c[y>>2]|0)+20>>2]&7](c[z>>2]|0,+g[445694]);hP(w,1.0);c[u+28>>2]=(((c[u+20>>2]|0)+1|0)>>>0)%((c[K>>2]|0)>>>0)|0;v=w;i=b;return v|0}else if((G|0)==3554){af=c[494446]|0;ei(((af|0)!=0?af:c[p>>2]|0)|0,721176,(D=i,i=i+8|0,c[D>>2]=S,D)|0)|0;i=D;af=c[494446]|0;a_(((af|0)!=0?af:c[p>>2]|0)|0)|0;be=$;break}else if((G|0)==3534){af=c[494446]|0;ei(((af|0)!=0?af:c[p>>2]|0)|0,730928,(D=i,i=i+8|0,c[D>>2]=M,D)|0)|0;i=D;af=c[494446]|0;a_(((af|0)!=0?af:c[p>>2]|0)|0)|0;be=$;break}else if((G|0)==3545){af=c[494446]|0;ei(((af|0)!=0?af:c[p>>2]|0)|0,724904,(D=i,i=i+8|0,c[D>>2]=Q,D)|0)|0;i=D;af=c[494446]|0;a_(((af|0)!=0?af:c[p>>2]|0)|0)|0;be=$;break}else if((G|0)==3572){af=c[494446]|0;ei(((af|0)!=0?af:c[p>>2]|0)|0,717208,(D=i,i=i+8|0,c[D>>2]=W,D)|0)|0;i=D;af=c[494446]|0;a_(((af|0)!=0?af:c[p>>2]|0)|0)|0;bb=ax}af=c[494446]|0;ei(((af|0)!=0?af:c[p>>2]|0)|0,719152,(D=i,i=i+8|0,c[D>>2]=bb,D)|0)|0;i=D;af=c[494446]|0;a_(((af|0)!=0?af:c[p>>2]|0)|0)|0;be=$}else{a9=0;G=3522}}while(0);if((G|0)==3522){W=c[494446]|0;Q=(W|0)!=0?W:c[p>>2]|0;ei(Q|0,693872,(D=i,i=i+8|0,c[D>>2]=C,D)|0)|0;i=D;Q=c[494446]|0;W=(Q|0)!=0?Q:c[p>>2]|0;a_(W|0)|0;be=a9}W=c[494446]|0;Q=(W|0)!=0?W:c[p>>2]|0;ei(Q|0,703528,(D=i,i=i+8|0,c[D>>2]=be,D)|0)|0;i=D;Q=c[494446]|0;W=(Q|0)!=0?Q:c[p>>2]|0;a_(W|0)|0}}while(0);if((G|0)==3512){z=c[494446]|0;y=(z|0)!=0?z:c[p>>2]|0;a5(707776,62,1,y|0)|0;y=c[494446]|0;z=(y|0)!=0?y:c[p>>2]|0;a_(z|0)|0}gN(A)}}while(0);G=u+24|0;D=u+12|0;be=c[D>>2]|0;if((c[G>>2]|0)==0){bi=be}else{a9=0;bb=be;while(1){aIq(c[bb+(a9*136|0)>>2]|0);aIq(c[bb+(a9*136|0)+8>>2]|0);be=a9+1|0;ax=c[D>>2]|0;if(be>>>0<(c[G>>2]|0)>>>0){a9=be;bb=ax}else{bi=ax;break}}}aIq(bi);bi=c[u+4>>2]|0;if((bi|0)!=0){fj[c[bi>>2]&511](c[u>>2]|0,0)}aIq(u);v=0;i=b;return v|0}function hR(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,R=0.0,S=0.0,T=0,V=0,W=0,X=0,Y=0.0,Z=0.0,_=0.0,$=0.0,aa=0.0,ac=0.0,ad=0,ae=0,af=0.0,ag=0.0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;e=i;f=d+64|0;aIq(c[f>>2]|0);g=d+76|0;aIq(c[g>>2]|0);h=d+80|0;aIq(c[h>>2]|0);j=d+92|0;aIq(c[j>>2]|0);k=d+104|0;aIq(c[k>>2]|0);l=d+96|0;aIq(c[l>>2]|0);m=d+120|0;aIq(c[m>>2]|0);aIv(f|0,0,64);n=d|0;o=c[n>>2]|0;q=d+12|0;r=c[q>>2]|0;s=d+4|0;t=c[s>>2]|0;do{if((o|0)==(r|0)){if((t|0)!=(c[d+16>>2]|0)){u=3658;break}a[d+60|0]=1;v=1}else{u=3658}}while(0);if((u|0)==3658){c[d+36>>2]=46;c[d+40>>2]=80;a[d+60|0]=0;v=0}w=d+44|0;c[w>>2]=0;x=(r<<3)+56&-64;c[d+116>>2]=x;c[d+108>>2]=r;c[d+112>>2]=t;y=ab(x,t)|0;x=y>>3;if(x>>>0>65535){z=(y>>>3|0)==(x|0)?y:-1}else{z=y}y=aIp(z)|0;if((y|0)==0){c[k>>2]=0;A=0;i=e;return A|0}if((c[y-4>>2]&3|0)!=0){aIv(y|0,0,z|0)}c[k>>2]=y;y=c[d+24>>2]|0;if((y|0)!=0){k=(o<<2)+28&-32;c[d+100>>2]=k;o=ab(k,t)|0;t=o>>2;if(t>>>0>65535){B=(o>>>2|0)==(t|0)?o:-1}else{B=o}o=aIp(B)|0;if((o|0)==0){c[l>>2]=0;A=0;i=e;return A|0}if((c[o-4>>2]&3|0)!=0){aIv(o|0,0,B|0)}c[l>>2]=o}o=c[d+28>>2]|0;l=(o|0)==0;if(!l){B=(r<<2)+28&-32;c[d+124>>2]=B;r=ab(c[d+16>>2]|0,B)|0;B=r>>2;if(B>>>0>65535){C=(r>>>2|0)==(B|0)?r:-1}else{C=r}r=aIp(C)|0;if((r|0)==0){c[m>>2]=0;A=0;i=e;return A|0}if((c[r-4>>2]&3|0)!=0){aIv(r|0,0,C|0)}c[m>>2]=r}r=v<<24>>24==0;L5185:do{if(r){if((y|0)==2){c[d+48>>2]=6}else if((y|0)==3){c[d+48>>2]=8}else if((y|0)==4){c[d+48>>2]=14}else if((y|0)!=0){A=0;i=e;return A|0}if((o|0)==2){c[d+52>>2]=24;break}else if((o|0)==4){c[d+52>>2]=16;break}else if((o|0)==0){break}else{A=0;i=e;return A|0}}else{if((y|0)==(o|0)){c[d+56>>2]=10;A=1;i=e;return A|0}v=(y|0)==2;if(v&l){c[d+56>>2]=6;A=1;i=e;return A|0}if(!((y|0)!=3|l^1)){c[d+56>>2]=8;break}m=(y|0)==3;C=(o|0)==4;if(m&C){c[d+56>>2]=20;break}if(v&(o|0)==3){c[d+56>>2]=2;break}do{if(m){if((o|0)!=2){D=0;break}c[d+56>>2]=12;break L5185}else{if((y|0)==4){if(!l){D=0;break}c[d+56>>2]=14;break L5185}else if((y|0)!=0){D=0;break}if((o|0)==2){c[d+56>>2]=24;break L5185}else if((o|0)==4){c[d+56>>2]=16;break L5185}else{D=1;break}}}while(0);if(v&C){c[d+56>>2]=4;break}if(D&(o|0)==1){c[d+56>>2]=22;break}else{A=0;i=e;return A|0}}}while(0);if(!r){A=1;i=e;return A|0}r=c[d+32>>2]|0;L5237:do{if((r|0)==1){c[d+68>>2]=1;c[d+72>>2]=1;c[d+84>>2]=1;o=d+88|0;c[o>>2]=1;D=c[q>>2]|0;y=D<<1;if(D>>>0>65535){E=(D&2147483647|0)==(D|0)?y:-1}else{E=y}y=aIp(E)|0;do{if((y|0)!=0){if((c[y-4>>2]&3|0)==0){break}aIv(y|0,0,E|0)}}while(0);C=d+64|0;c[C>>2]=y;v=c[q>>2]|0;D=v<<2;if(v>>>0>65535){F=(v&1073741823|0)==(v|0)?D:-1}else{F=D}D=aIp(F)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}aIv(D|0,0,F|0)}}while(0);c[g>>2]=D;y=d+16|0;v=ab(c[y>>2]|0,c[o>>2]|0)|0;l=v<<1;if(v>>>0>65535){G=(v&2147483647|0)==(v|0)?l:-1}else{G=l}l=aIp(G)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}aIv(l|0,0,G|0)}}while(0);c[h>>2]=l;o=c[y>>2]|0;D=o<<2;if(o>>>0>65535){H=(o&1073741823|0)==(o|0)?D:-1}else{H=D}D=aIp(H)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}aIv(D|0,0,H|0)}}while(0);c[j>>2]=D;if((c[C>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}l=c[n>>2]|0;o=c[q>>2]|0;v=(l<<16|0)/(o|0)|0;m=c[s>>2]|0;B=c[y>>2]|0;t=((m<<15|0)/(B|0)|0)-32768|0;k=(m<<16|0)/(B|0)|0;if((o|0)>0){m=((l<<15|0)/(o|0)|0)-32768|0;l=0;while(1){c[(c[g>>2]|0)+(l<<2)>>2]=m>>16;b[(c[C>>2]|0)+(l<<1)>>1]=16384;z=l+1|0;if((z|0)<(o|0)){m=m+v|0;l=z}else{break}}I=c[y>>2]|0}else{I=B}L5279:do{if((I|0)>0){l=t;v=0;while(1){c[(c[j>>2]|0)+(v<<2)>>2]=l>>16;b[(c[h>>2]|0)+(v<<1)>>1]=16384;m=v+1|0;if((m|0)>=(I|0)){break L5279}l=l+k|0;v=m}}}while(0);c[w>>2]=6}else if((r|0)==3){k=c[n>>2]|0;t=c[q>>2]|0;if((k|0)>(t|0)){B=((k|0)/(t|0)|0)-1|0;k=B>>>1|B;B=k>>>2|k;k=B>>>4|B;B=k>>>8|k;J=((B>>>16|B)<<3)+8|0}else{J=8}B=d+68|0;c[B>>2]=J;c[d+72>>2]=J;k=d+84|0;c[k>>2]=J;y=d+88|0;c[y>>2]=J;v=ab(J,t)|0;t=v<<1;if(v>>>0>65535){K=(v&2147483647|0)==(v|0)?t:-1}else{K=t}t=aIp(K)|0;do{if((t|0)!=0){if((c[t-4>>2]&3|0)==0){break}aIv(t|0,0,K|0)}}while(0);v=d+64|0;c[v>>2]=t;l=c[q>>2]|0;m=l<<2;if(l>>>0>65535){L=(l&1073741823|0)==(l|0)?m:-1}else{L=m}m=aIp(L)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}aIv(m|0,0,L|0)}}while(0);c[g>>2]=m;t=d+16|0;l=ab(c[t>>2]|0,c[y>>2]|0)|0;o=l<<1;if(l>>>0>65535){M=(l&2147483647|0)==(l|0)?o:-1}else{M=o}o=aIp(M)|0;do{if((o|0)!=0){if((c[o-4>>2]&3|0)==0){break}aIv(o|0,0,M|0)}}while(0);c[h>>2]=o;y=c[t>>2]|0;m=y<<2;if(y>>>0>65535){N=(y&1073741823|0)==(y|0)?m:-1}else{N=m}m=aIp(N)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}aIv(m|0,0,N|0)}}while(0);c[j>>2]=m;if((c[v>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}o=c[n>>2]|0;y=c[q>>2]|0;l=-32768-(J<<15)|0;C=((o<<15|0)/(y|0)|0)+l|0;D=(o<<16|0)/(y|0)|0;z=c[s>>2]|0;x=c[t>>2]|0;O=((z<<15|0)/(x|0)|0)+l|0;l=(z<<16|0)/(x|0)|0;if((o|0)>(y|0)){P=+(y|0)/+(o|0)}else{P=1.0}if((z|0)>(x|0)){R=+(x|0)/+(z|0)}else{R=1.0}z=c[B>>2]|0;L5329:do{if((y|0)>0){x=z<<15;S=+(z>>1|0);if((z|0)>0){T=0;V=C}else{o=0;W=C;while(1){c[(c[g>>2]|0)+(o<<2)>>2]=W>>16;X=o+1|0;if((X|0)<(y|0)){o=X;W=W+D|0}else{break L5329}}}while(1){c[(c[g>>2]|0)+(T<<2)>>2]=V>>16;Y=+((V&65535)+x|0)*152587890625.0e-16;W=ab(T,z)|0;o=0;do{Z=(Y- +(o|0))*3.141592653589793;_=Z/S;$=P*Z;if(+Q(+$)<1.0e-4){aa=16384.0}else{aa=+U(+$)/$*16384.0}if(+Q(+_)<1.0e-4){ac=1.0}else{ac=+U(+_)/_}b[(c[v>>2]|0)+(o+W<<1)>>1]=~~(P*aa*ac);o=o+1|0;}while((o|0)<(z|0));o=T+1|0;if((o|0)<(y|0)){T=o;V=V+D|0}else{break}}}}while(0);D=c[t>>2]|0;y=c[k>>2]|0;if((D|0)<=0){break}z=y<<15;S=+(y>>1|0);if((y|0)>0){ad=0;ae=O}else{v=0;C=O;while(1){c[(c[j>>2]|0)+(v<<2)>>2]=C>>16;B=v+1|0;if((B|0)>=(D|0)){break L5237}v=B;C=C+l|0}}while(1){c[(c[j>>2]|0)+(ad<<2)>>2]=ae>>16;Y=+((ae&65535)+z|0)*152587890625.0e-16;C=ab(ad,y)|0;v=0;do{_=(Y- +(v|0))*3.141592653589793;$=_/S;Z=R*_;if(+Q(+Z)<1.0e-4){af=16384.0}else{af=+U(+Z)/Z*16384.0}if(+Q(+$)<1.0e-4){ag=1.0}else{ag=+U(+$)/$}b[(c[h>>2]|0)+(v+C<<1)>>1]=~~(R*af*ag);v=v+1|0;}while((v|0)<(y|0));v=ad+1|0;if((v|0)>=(D|0)){break L5237}ad=v;ae=ae+l|0}}else if((r|0)==2){c[d+68>>2]=2;c[d+72>>2]=2;c[d+84>>2]=2;l=d+88|0;c[l>>2]=2;D=c[q>>2]|0;y=D<<1;z=D<<2;if(y>>>0>65535){ah=(y&2147483646|0)==(y|0)?z:-1}else{ah=z}z=aIp(ah)|0;do{if((z|0)!=0){if((c[z-4>>2]&3|0)==0){break}aIv(z|0,0,ah|0)}}while(0);y=d+64|0;c[y>>2]=z;D=c[q>>2]|0;v=D<<2;if(D>>>0>65535){ai=(D&1073741823|0)==(D|0)?v:-1}else{ai=v}v=aIp(ai)|0;do{if((v|0)!=0){if((c[v-4>>2]&3|0)==0){break}aIv(v|0,0,ai|0)}}while(0);c[g>>2]=v;z=d+16|0;D=ab(c[z>>2]|0,c[l>>2]|0)|0;C=D<<1;if(D>>>0>65535){aj=(D&2147483647|0)==(D|0)?C:-1}else{aj=C}C=aIp(aj)|0;do{if((C|0)!=0){if((c[C-4>>2]&3|0)==0){break}aIv(C|0,0,aj|0)}}while(0);c[h>>2]=C;l=c[z>>2]|0;v=l<<2;if(l>>>0>65535){ak=(l&1073741823|0)==(l|0)?v:-1}else{ak=v}v=aIp(ak)|0;do{if((v|0)!=0){if((c[v-4>>2]&3|0)==0){break}aIv(v|0,0,ak|0)}}while(0);c[j>>2]=v;if((c[y>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}C=c[n>>2]|0;l=c[q>>2]|0;D=(C<<16|0)/(l|0)|0;O=c[s>>2]|0;k=c[z>>2]|0;t=((O<<15|0)/(k|0)|0)-32768|0;B=(O<<16|0)/(k|0)|0;if((l|0)>0){O=((C<<15|0)/(l|0)|0)-32768|0;C=0;while(1){c[(c[g>>2]|0)+(C<<2)>>2]=O>>16;m=C<<1;x=m|1;b[(c[y>>2]|0)+(x<<1)>>1]=O>>>2&16383;o=c[y>>2]|0;b[o+(m<<1)>>1]=16384-(b[o+(x<<1)>>1]|0)&65535;x=C+1|0;if((x|0)<(l|0)){O=O+D|0;C=x}else{break}}al=c[z>>2]|0}else{al=k}if((al|0)>0){am=t;an=0}else{break}while(1){c[(c[j>>2]|0)+(an<<2)>>2]=am>>16;C=an<<1;D=C|1;b[(c[h>>2]|0)+(D<<1)>>1]=am>>>2&16383;O=c[h>>2]|0;b[O+(C<<1)>>1]=16384-(b[O+(D<<1)>>1]|0)&65535;D=an+1|0;if((D|0)>=(al|0)){break L5237}am=am+B|0;an=D}}else{A=0;i=e;return A|0}}while(0);h5(f,c[q>>2]|0,c[n>>2]|0);f=d+16|0;h5(d+80|0,c[f>>2]|0,c[s>>2]|0);an=(c[n>>2]|0)-(c[d+68>>2]|0)|0;n=c[q>>2]|0;q=0;while(1){if((q|0)>=(n|0)){break}ao=c[(c[g>>2]|0)+(q<<2)>>2]|0;if((ao|0)>(an|0)|(ao|0)<0){u=3826;break}else{q=q+1|0}}if((u|0)==3826){an=c[p>>2]|0;ei(an|0,725240,(ap=i,i=i+16|0,c[ap>>2]=q,c[ap+8>>2]=ao,ap)|0)|0;i=ap;A=0;i=e;return A|0}ao=(c[s>>2]|0)-(c[d+84>>2]|0)|0;d=c[f>>2]|0;f=0;while(1){if((f|0)>=(d|0)){A=1;u=3835;break}aq=c[(c[j>>2]|0)+(f<<2)>>2]|0;if((aq|0)>(ao|0)|(aq|0)<0){break}else{f=f+1|0}}if((u|0)==3835){i=e;return A|0}ei(c[p>>2]|0,728032,(ap=i,i=i+16|0,c[ap>>2]=f,c[ap+8>>2]=aq,ap)|0)|0;i=ap;A=0;i=e;return A|0}function hS(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=0;i=a;a=c;while(1){c=0;do{j=b[a+(c<<1)>>1]|0;b[i+(c<<1)>>1]=(j&65535)>>>1&32736|j&31;c=c+1|0;}while((c|0)<(d|0));c=g+1|0;if((c|0)<(e|0)){g=c;i=i+(h<<1)|0;a=a+(f<<1)|0}else{break}}return}function hT(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=0;i=a;a=c;while(1){c=0;do{j=b[a+(c<<1)>>1]|0;b[i+(c<<1)>>1]=j<<1&-64|j&31|(j&65535)>>>4&32;c=c+1|0;}while((c|0)<(d|0));c=g+1|0;if((c|0)<(e|0)){g=c;i=i+(h<<1)|0;a=a+(f<<1)|0}else{break}}return}function hU(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=0;j=a;a=b;while(1){b=0;do{k=e[a+(b<<1)>>1]|0;l=k>>>10&31;m=k>>>5&31;n=k&31;c[j+(b<<2)>>2]=n<<3|n>>>2|(m<<3|m>>>2)<<8|(l<<3|l>>>2)<<16|-16777216;b=b+1|0;}while((b|0)<(d|0));b=h+1|0;if((b|0)<(f|0)){h=b;j=j+(i<<2)|0;a=a+(g<<1)|0}else{break}}return}function hV(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=0;j=a;a=b;while(1){b=0;do{k=e[a+(b<<1)>>1]|0;l=k>>>5&63;m=k&31;c[j+(b<<2)>>2]=m<<3|m>>>2|(k>>>11<<3|k>>>13)<<16|(l<<2|l>>>4)<<8|-16777216;b=b+1|0;}while((b|0)<(d|0));b=h+1|0;if((b|0)<(f|0)){h=b;j=j+(i<<2)|0;a=a+(g<<1)|0}else{break}}return}function hW(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<3|m>>>7&7)&255;a[l+2|0]=(m>>>10<<3|m>>>12&7)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function hX(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<2|m>>>9&3)&255;a[l+2|0]=(m>>>11<<3|m>>>13)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function hY(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>2;g=0;k=a;a=b;while(1){if(i){b=a;l=0;while(1){c[k+(l<<2)>>2]=d[b]|0|(d[b+1|0]|0)<<8|(d[b+2|0]|0)<<16|-16777216;m=l+1|0;if((m|0)<(e|0)){b=b+3|0;l=m}else{break}}}l=g+1|0;if((l|0)<(f|0)){g=l;k=k+(j<<2)|0;a=a+h|0}else{break}}return}function hZ(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>1;g=h>>2;h=0;k=a;a=d;while(1){if(i){d=0;do{l=c[a+(d<<2)>>2]|0;b[k+(d<<1)>>1]=(l>>>11<<5&992|l>>>3&31|l>>>19<<10&31744)&65535;d=d+1|0;}while((d|0)<(e|0))}d=h+1|0;if((d|0)<(f|0)){h=d;k=k+(j<<1)|0;a=a+(g<<2)|0}else{break}}return}function h_(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=h>>2;h=b;b=0;k=d;while(1){if(i){d=h;l=0;while(1){m=c[k+(l<<2)>>2]|0;a[d]=m&255;a[d+1|0]=m>>>8&255;a[d+2|0]=m>>>16&255;m=l+1|0;if((m|0)<(e|0)){d=d+3|0;l=m}else{break}}}l=b+1|0;if((l|0)<(f|0)){h=h+g|0;b=l;k=k+(j<<2)|0}else{break}}return}function h$(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)<=0){return}h=(d|0)>0;i=f>>2;f=g>>2;g=a;a=0;j=b;while(1){if(h){b=0;do{k=c[j+(b<<2)>>2]|0;c[g+(b<<2)>>2]=k>>>16&255|k&-16711936|k<<16&16711680;b=b+1|0;}while((b|0)<(d|0))}b=a+1|0;if((b|0)<(e|0)){g=g+(i<<2)|0;a=b;j=j+(f<<2)|0}else{break}}return}function h0(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[a+104>>2]|0;g=a+16|0;h=c[g>>2]|0;if((h|0)<=0){return}i=a+92|0;j=a+116|0;k=a+12|0;l=a+88|0;m=e>>2;e=a+84|0;n=0;o=c[a+80>>2]|0;a=d;d=c[k>>2]|0;p=h;while(1){h=ab(c[j>>2]>>3,c[(c[i>>2]|0)+(n<<2)>>2]|0)|0;if((d|0)>0){q=0;do{r=c[e>>2]|0;if((r|0)==0){s=0;t=0;u=0;v=0}else{w=c[j>>2]>>3;x=0;y=0;z=f+(q+h<<3)|0;A=0;B=0;C=0;while(1){D=c[z>>2]|0;E=c[z+4>>2]|0;F=b[o+(A<<1)>>1]|0;G=ab(((E>>>16|0<<16)&65535)<<16>>16,F)|0;H=ab((E&65535)<<16>>16,F)|0;I=ab(((D>>>16|E<<16)&65535)<<16>>16,F)|0;E=A+1|0;J=G+(C<<16)>>16;K=H+(B<<16)>>16;L=I+(x<<16)>>16;M=(ab((D&65535)<<16>>16,F)|0)+(y<<16)>>16;if(E>>>0<r>>>0){x=L;y=M;z=z+(w<<3)|0;A=E;B=K;C=J}else{break}}s=L>>>3;t=M>>>3;u=K>>>3;v=J>>>3}C=v&65535;B=u&65535;A=s&65535;w=t&65535;if(C<<16>>16>255){N=-16777216}else{N=C<<16>>16<0?0:v<<24}if(B<<16>>16>255){O=16711680}else{O=B<<16>>16<0?0:u<<16&16711680}if(A<<16>>16>255){P=65280}else{P=A<<16>>16<0?0:s<<8&65280}if(w<<16>>16>255){Q=255}else{Q=w<<16>>16<0?0:t&255}c[a+(q<<2)>>2]=O|N|P|Q;q=q+1|0;R=c[k>>2]|0;}while((q|0)<(R|0));S=R;T=c[g>>2]|0}else{S=d;T=p}q=n+1|0;if((q|0)>=(T|0)){break}n=q;o=o+(c[l>>2]<<1)|0;a=a+(m<<2)|0;d=S;p=T}return}function h1(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[b+60|0]&1)!=0){fB[c[b+56>>2]&31](d,e,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[b+8>>2]|0);return}f=b+44|0;if((c[f>>2]|0)==0){if((c[b+24>>2]|0)==0){fF[c[b+36>>2]&127](b,e,c[b+8>>2]|0)}else{g=b+96|0;h=b+100|0;fB[c[b+48>>2]&31](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,c[b+8>>2]|0);fF[c[b+36>>2]&127](b,c[g>>2]|0,c[h>>2]|0)}h=c[b+40>>2]|0;if((c[b+28>>2]|0)==0){fF[h&127](b,d,c[b+20>>2]|0);return}else{g=b+120|0;i=b+124|0;fF[h&127](b,c[g>>2]|0,c[i>>2]|0);fB[c[b+52>>2]&31](d,c[g>>2]|0,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[i>>2]|0);return}}else{i=c[b+8>>2]|0;if((c[b+24>>2]|0)==0){j=e;k=i}else{g=b+96|0;h=b+100|0;fB[c[b+48>>2]&31](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,i);j=c[g>>2]|0;k=c[h>>2]|0}h=(c[b+28>>2]|0)!=0;g=b+20|0;if(h){l=b+124|0;m=c[b+120>>2]|0}else{l=g;m=d}i=b+12|0;e=b+16|0;fz[c[f>>2]&15](b,m,j,c[i>>2]|0,c[e>>2]|0,c[b>>2]|0,c[b+4>>2]|0,c[l>>2]|0,k);if(!h){return}fB[c[b+52>>2]&31](d,c[b+120>>2]|0,c[i>>2]|0,c[e>>2]|0,c[g>>2]|0,c[b+124>>2]|0);return}}function h2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c=(e|0)>-1?e:-e|0;g=(f|0)>-1?f:-f|0;h=(g|0)<(c|0)?g:c;if((d|0)>0){i=b;j=a;k=0}else{return}while(1){aIy(j|0,i|0,h)|0;a=k+1|0;if((a|0)<(d|0)){i=i+f|0;j=j+e|0;k=a}else{break}}return}function h3(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=a+112|0;g=c[f>>2]|0;if((g|0)<=0){return}h=a+64|0;i=a+108|0;j=e>>2;e=a+116|0;k=a+76|0;l=a+68|0;m=a+72|0;n=0;o=c[a+104>>2]|0;a=d;d=c[i>>2]|0;p=g;while(1){if((d|0)>0){g=0;q=c[h>>2]|0;while(1){r=c[(c[k>>2]|0)+(g<<2)>>2]|0;s=c[l>>2]|0;if((s|0)==0){t=0;u=0;v=0;w=0;x=0;y=0;z=0;A=0}else{B=0;C=0;D=0;E=0;F=0;while(1){G=c[a+(E+r<<2)>>2]|0;H=b[q+(E<<1)>>1]|0;I=((ab(G>>>17&32640,H)|0)>>>16)+(F&65535)|0;J=((ab(G>>>9&32640,H)|0)>>>16)+(B&65535)|0;K=((ab(G>>>1&32640,H)|0)>>>16)+(C&65535)|0;L=((ab(G<<7&32640,H)|0)>>>16)+(D&65535)|0;H=E+1|0;if(H>>>0<s>>>0){B=J&65535;C=K&65535;D=L&65535;E=H;F=I&65535}else{break}}F=K&65535;t=J&65535;u=0;v=0<<16|F>>>16;w=F<<16|0>>>16;x=0;y=L&65535;z=I<<16|0>>>16;A=0<<16|0>>>16}F=o+(g<<3)|0;c[F>>2]=y|A|w|u;c[F+4>>2]=x|z|v|t;F=g+1|0;M=c[i>>2]|0;if((F|0)<(M|0)){g=F;q=q+(c[m>>2]<<1)|0}else{break}}N=M;O=c[f>>2]|0}else{N=d;O=p}q=n+1|0;if((q|0)<(O|0)){n=q;o=o+(c[e>>2]>>3<<3)|0;a=a+(j<<2)|0;d=N;p=O}else{break}}return}function h4(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;a=((g<<15|0)/(e|0)|0)-32768|0;k=(g<<16|0)/(e|0)|0;g=((h<<15|0)/(f|0)|0)-32768|0;l=(h<<16|0)/(f|0)|0;h=(a|0)<0?0:a;a=d;if((f|0)<=0){return}d=j>>2;j=i>>2;if((e|0)<=0){return}i=(g|0)<0?0:g;g=b;b=0;while(1){m=ab(i>>16,d)|0;n=h;o=0;while(1){c[g+(o<<2)>>2]=c[a+((n>>16)+m<<2)>>2];p=o+1|0;if((p|0)<(e|0)){n=n+k|0;o=p}else{break}}o=b+1|0;if((o|0)<(f|0)){i=i+l|0;g=g+(j<<2)|0;b=o}else{break}}return}function h5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=a+4|0;f=d-(c[e>>2]|0)|0;if((b|0)<=0){return}d=a+12|0;g=a|0;h=a+8|0;a=0;do{i=(c[d>>2]|0)+(a<<2)|0;j=c[i>>2]|0;k=j-f|0;l=-j|0;do{if((k|0)>0){c[i>>2]=f;m=c[g>>2]|0;n=ab(c[h>>2]|0,a)|0;o=m+(n<<1)|0;p=c[e>>2]|0;if((k|0)>(p|0)){aIv(o|0,0,p<<1|0);break}else{q=o;aIC(m+(n+k<<1)|0,q|0,p-k<<1|0);aIv(q|0,0,k<<1|0);break}}}while(0);do{if((j|0)<0){k=(c[d>>2]|0)+(a<<2)|0;c[k>>2]=(c[k>>2]|0)-j;k=c[g>>2]|0;i=ab(c[h>>2]|0,a)|0;q=c[e>>2]|0;p=k+(i<<1)|0;if((q|0)<(l|0)){aIv(p|0,0,q<<1|0);break}else{aIC(p|0,k+(i-j<<1)|0,q+j<<1|0);aIv(k+(i+j+(c[e>>2]|0)<<1)|0,0,l<<1|0);break}}}while(0);a=a+1|0;}while((a|0)<(b|0));return}function h6(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aY=0,aZ=0,a$=0,a0=0,a1=0,a3=0,a4=0,a6=0,a7=0,a8=0;f=i;i=i+1824|0;h=f|0;j=f+8|0;k=f+1032|0;l=f+1040|0;m=f+1048|0;n=f+1112|0;o=f+1176|0;q=f+1184|0;r=f+1248|0;s=f+1312|0;t=f+1376|0;u=f+1440|0;v=f+1504|0;w=f+1568|0;x=f+1632|0;y=f+1696|0;z=f+1760|0;aIv(e|0,0,109528);c[e>>2]=0;A=d+4|0;B=A;while(1){C=c[B>>2]|0;if((C|0)==0){break}if((cP(725192,c[C+4>>2]|0)|0)==0){D=4027;break}else{B=C+12|0}}do{if((D|0)==4027){c[(dX()|0)>>2]=0;B=aX(c[C+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}if((B|0)==0){E=c[494446]|0;F=(E|0)!=0?E:c[p>>2]|0;a5(715560,55,1,F|0)|0;F=c[494446]|0;E=(F|0)!=0?F:c[p>>2]|0;a_(E|0)|0;G=0;i=f;return G|0}E=B>>>0<16?B:16;B=e+72|0;c[B>>2]=E;F=m|0;H=n|0;I=q|0;J=r|0;K=s|0;L=t|0;M=u|0;N=v|0;O=w|0;P=x|0;Q=y|0;R=z|0;L5665:do{if((E|0)!=0){S=0;while(1){bQ(F|0,64,708344,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;L5668:do{if(gQ(d,F,e+76+(S*4148|0)|0)|0){bQ(H|0,64,707840,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;a[o]=0;if(gR(d,H,o)|0){c[e+76+(S*4148|0)+4136>>2]=(a[o]&1)!=0?1:2}else{c[e+76+(S*4148|0)+4136>>2]=0}bQ(I|0,64,707088,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;U=A;while(1){V=c[U>>2]|0;if((V|0)==0){break}if((cP(I|0,c[V+4>>2]|0)|0)==0){D=4040;break}else{U=V+12|0}}do{if((D|0)==4040){D=0;U=64;W=0;X=J;Y=c[V+8>>2]|0;while(1){Z=U-1|0;if((Z|0)==0){D=4043;break}_=a[Y]|0;a[X]=_;if(_<<24>>24==0){$=W;break}else{U=Z;W=W+1|0;X=X+1|0;Y=Y+1|0}}do{if((D|0)==4043){D=0;a[X]=0;if((a[Y]|0)==0){$=W;break}else{aa=Y;ab=W}while(1){U=aa+1|0;Z=ab+1|0;if((a[U]|0)==0){$=Z;break}else{aa=U;ab=Z}}}}while(0);if($>>>0>=64){break}c[e+76+(S*4148|0)+4140>>2]=ib(J)|0}}while(0);aIv(K|0,0,64);bQ(L|0,64,706624,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;W=A;while(1){ac=c[W>>2]|0;if((ac|0)==0){break}if((cP(L|0,c[ac+4>>2]|0)|0)==0){D=4050;break}else{W=ac+12|0}}do{if((D|0)==4050){D=0;W=64;Y=0;X=K;Z=c[ac+8>>2]|0;while(1){U=W-1|0;if((U|0)==0){D=4053;break}_=a[Z]|0;a[X]=_;if(_<<24>>24==0){ad=Y;break}else{W=U;Y=Y+1|0;X=X+1|0;Z=Z+1|0}}do{if((D|0)==4053){D=0;a[X]=0;if((a[Z]|0)==0){ad=Y;break}else{ae=Z;af=Y}while(1){W=ae+1|0;U=af+1|0;if((a[W]|0)==0){ad=U;break}else{ae=W;af=U}}}}while(0);if(ad>>>0>=64){break}c[e+76+(S*4148|0)+4144>>2]=aX(K|0,0,0)|0}}while(0);aIv(M|0,0,64);aIv(N|0,0,64);aIv(O|0,0,64);bQ(P|0,64,725480,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;Y=A;while(1){ag=c[Y>>2]|0;if((ag|0)==0){break}if((cP(P|0,c[ag+4>>2]|0)|0)==0){D=4060;break}else{Y=ag+12|0}}L5707:do{if((D|0)==4060){D=0;Y=64;Z=M;X=c[ag+8>>2]|0;while(1){U=Y-1|0;if((U|0)==0){break}W=a[X]|0;a[Z]=W;if(W<<24>>24==0){break L5707}else{Y=U;Z=Z+1|0;X=X+1|0}}a[Z]=0;if((a[X]|0)==0){break}else{ah=X}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);bQ(P|0,64,725400,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;X=A;while(1){ai=c[X>>2]|0;if((ai|0)==0){break}if((cP(P|0,c[ai+4>>2]|0)|0)==0){D=4068;break}else{X=ai+12|0}}L5719:do{if((D|0)==4068){D=0;X=64;Z=N;Y=c[ai+8>>2]|0;while(1){U=X-1|0;if((U|0)==0){break}W=a[Y]|0;a[Z]=W;if(W<<24>>24==0){break L5719}else{X=U;Z=Z+1|0;Y=Y+1|0}}a[Z]=0;if((a[Y]|0)==0){break}else{aj=Y}do{aj=aj+1|0;}while((a[aj]|0)!=0)}}while(0);bQ(P|0,64,725280,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;Y=A;while(1){ak=c[Y>>2]|0;if((ak|0)==0){break}if((cP(P|0,c[ak+4>>2]|0)|0)==0){D=4076;break}else{Y=ak+12|0}}L5731:do{if((D|0)==4076){D=0;Y=64;Z=O;X=c[ak+8>>2]|0;while(1){U=Y-1|0;if((U|0)==0){break}W=a[X]|0;a[Z]=W;if(W<<24>>24==0){break L5731}else{Y=U;Z=Z+1|0;X=X+1|0}}a[Z]=0;if((a[X]|0)==0){break}else{al=X}do{al=al+1|0;}while((a[al]|0)!=0)}}while(0);L5740:do{if((a[M]|0)==0){if((a[N]|0)!=0){break}if((a[O]|0)==0){am=1;break L5668}}else{X=64;Z=N;Y=M;while(1){U=X-1|0;if((U|0)==0){D=4086;break}W=a[Y]|0;a[Z]=W;if(W<<24>>24==0){an=64;ao=O;ap=M;break}else{X=U;Z=Z+1|0;Y=Y+1|0}}do{if((D|0)==4086){D=0;a[Z]=0;if((a[Y]|0)==0){an=64;ao=O;ap=M;break}else{aq=Y}while(1){X=aq+1|0;if((a[X]|0)==0){an=64;ao=O;ap=M;break}else{aq=X}}}}while(0);while(1){Y=an-1|0;if((Y|0)==0){break}Z=a[ap]|0;a[ao]=Z;if(Z<<24>>24==0){break L5740}else{an=Y;ao=ao+1|0;ap=ap+1|0}}a[ao]=0;if((a[ap]|0)==0){break}else{ar=ap}do{ar=ar+1|0;}while((a[ar]|0)!=0)}}while(0);a[e+76+(S*4148|0)+4104|0]=1;Y=e+76+(S*4148|0)+4108|0;c[Y>>2]=0;Z=e+76+(S*4148|0)+4112|0;c[Z>>2]=0;X=e+76+(S*4148|0)+4116|0;g[X>>2]=1.0;U=e+76+(S*4148|0)+4120|0;g[U>>2]=1.0;bQ(R|0,64,698424,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;gR(d,R,e+76+(S*4148|0)+4132|0)|0;do{if((a[N]|0)!=0){if((cP(N|0,697496)|0)==0){c[Y>>2]=0;break}if((cP(N|0,697296)|0)==0){c[Y>>2]=2;break}if((cP(N|0,697120)|0)==0){c[Y>>2]=1;break}else{W=c[494446]|0;_=(W|0)!=0?W:c[p>>2]|0;a5(725144,40,1,_|0)|0;_=c[494446]|0;W=(_|0)!=0?_:c[p>>2]|0;a_(W|0)|0;am=0;break L5668}}}while(0);do{if((a[O]|0)!=0){if((cP(O|0,697496)|0)==0){c[Z>>2]=0;break}if((cP(O|0,697296)|0)==0){c[Z>>2]=2;break}if((cP(O|0,697120)|0)==0){c[Z>>2]=1;break}else{W=c[494446]|0;_=(W|0)!=0?W:c[p>>2]|0;a5(725144,40,1,_|0)|0;_=c[494446]|0;W=(_|0)!=0?_:c[p>>2]|0;a_(W|0)|0;am=0;break L5668}}}while(0);W=(c[Y>>2]|0)==1;bQ(Q|0,64,725088,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;L5781:do{if(W){_=A;while(1){as=c[_>>2]|0;if((as|0)==0){break}if((cP(Q|0,c[as+4>>2]|0)|0)==0){D=4111;break}else{_=as+12|0}}do{if((D|0)==4111){D=0;c[(dX()|0)>>2]=0;_=a2(c[as+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4124>>2]=_;break L5781}}while(0);bQ(Q|0,64,725032,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;_=A;while(1){at=c[_>>2]|0;if((at|0)==0){break L5781}if((cP(Q|0,c[at+4>>2]|0)|0)==0){break}else{_=at+12|0}}c[(dX()|0)>>2]=0;_=a2(c[at+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4124>>2]=_}else{_=A;while(1){au=c[_>>2]|0;if((au|0)==0){break}if((cP(Q|0,c[au+4>>2]|0)|0)==0){D=4120;break}else{_=au+12|0}}if((D|0)==4120){D=0;g[X>>2]=+aIt(c[au+8>>2]|0);break}bQ(Q|0,64,725032,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;_=A;while(1){av=c[_>>2]|0;if((av|0)==0){break L5781}if((cP(Q|0,c[av+4>>2]|0)|0)==0){break}else{_=av+12|0}}g[X>>2]=+aIt(c[av+8>>2]|0)}}while(0);X=(c[Z>>2]|0)==1;bQ(Q|0,64,725088,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;if(X){aw=A}else{X=A;while(1){ax=c[X>>2]|0;if((ax|0)==0){break}if((cP(Q|0,c[ax+4>>2]|0)|0)==0){D=4137;break}else{X=ax+12|0}}if((D|0)==4137){D=0;g[U>>2]=+aIt(c[ax+8>>2]|0);am=1;break}bQ(Q|0,64,724992,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;X=A;while(1){ay=c[X>>2]|0;if((ay|0)==0){am=1;break L5668}if((cP(Q|0,c[ay+4>>2]|0)|0)==0){break}else{X=ay+12|0}}g[U>>2]=+aIt(c[ay+8>>2]|0);am=1;break}while(1){az=c[aw>>2]|0;if((az|0)==0){break}if((cP(Q|0,c[az+4>>2]|0)|0)==0){D=4128;break}else{aw=az+12|0}}do{if((D|0)==4128){D=0;c[(dX()|0)>>2]=0;U=a2(c[az+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4128>>2]=U;am=1;break L5668}}while(0);bQ(Q|0,64,724992,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;U=A;while(1){aA=c[U>>2]|0;if((aA|0)==0){am=1;break L5668}if((cP(Q|0,c[aA+4>>2]|0)|0)==0){break}else{U=aA+12|0}}c[(dX()|0)>>2]=0;U=a2(c[aA+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){am=1;break}c[e+76+(S*4148|0)+4128>>2]=U;am=1}else{U=c[494446]|0;ei(((U|0)!=0?U:c[p>>2]|0)|0,725560,(T=i,i=i+8|0,c[T>>2]=F,T)|0)|0;i=T;U=c[494446]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;am=0}}while(0);if(!am){G=0;break}S=S+1|0;if(S>>>0>=(c[B>>2]|0)>>>0){break L5665}}i=f;return G|0}}while(0);B=j|0;Q=A;while(1){aB=c[Q>>2]|0;if((aB|0)==0){break}if((cP(705888,c[aB+4>>2]|0)|0)==0){D=4147;break}else{Q=aB+12|0}}L5836:do{if((D|0)==4147){Q=1024;O=0;N=B;R=c[aB+8>>2]|0;while(1){M=Q-1|0;if((M|0)==0){D=4150;break}P=a[R]|0;a[N]=P;if(P<<24>>24==0){aC=O;break}else{Q=M;O=O+1|0;N=N+1|0;R=R+1|0}}do{if((D|0)==4150){a[N]=0;if((a[R]|0)==0){aC=O;break}else{aD=R;aE=O}while(1){Q=aD+1|0;M=aE+1|0;if((a[Q]|0)==0){aC=M;break}else{aD=Q;aE=M}}}}while(0);if(aC>>>0>=1024){break}O=ee(B|0,706256,k|0)|0;if((O|0)==0){break}R=e+66444|0;N=O;L5848:while(1){O=c[R>>2]|0;if(O>>>0>=8){break L5836}M=e+66448+(O*4168|0)+64|0;O=A;while(1){aF=c[O>>2]|0;if((aF|0)==0){break L5848}if((cP(N|0,c[aF+4>>2]|0)|0)==0){break}else{O=aF+12|0}}O=4096;Q=0;P=M;E=c[aF+8>>2]|0;while(1){S=O-1|0;if((S|0)==0){D=4162;break}U=a[E]|0;a[P]=U;if(U<<24>>24==0){aG=Q;break}else{O=S;Q=Q+1|0;P=P+1|0;E=E+1|0}}do{if((D|0)==4162){D=0;a[P]=0;if((a[E]|0)==0){aG=Q;break}else{aH=E;aI=Q}while(1){O=aH+1|0;M=aI+1|0;if((a[O]|0)==0){aG=M;break}else{aH=O;aI=M}}}}while(0);if(aG>>>0>=4096){break}Q=64;E=e+66448+((c[R>>2]|0)*4168|0)|0;P=N;while(1){M=Q-1|0;if((M|0)==0){D=4169;break}O=a[P]|0;a[E]=O;if(O<<24>>24==0){break}else{Q=M;E=E+1|0;P=P+1|0}}do{if((D|0)==4169){D=0;a[E]=0;if((a[P]|0)==0){break}else{aJ=P}do{aJ=aJ+1|0;}while((a[aJ]|0)!=0)}}while(0);bQ(F|0,64,705552,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;a[l]=0;if(gR(d,F,l)|0){c[e+66448+((c[R>>2]|0)*4168|0)+4160>>2]=(a[l]&1)!=0?1:2}else{c[e+66448+((c[R>>2]|0)*4168|0)+4160>>2]=0}bQ(H|0,64,705144,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;P=A;while(1){aK=c[P>>2]|0;if((aK|0)==0){break}if((cP(H|0,c[aK+4>>2]|0)|0)==0){D=4177;break}else{P=aK+12|0}}do{if((D|0)==4177){D=0;P=64;E=0;Q=I;M=c[aK+8>>2]|0;while(1){O=P-1|0;if((O|0)==0){D=4180;break}S=a[M]|0;a[Q]=S;if(S<<24>>24==0){aL=E;break}else{P=O;E=E+1|0;Q=Q+1|0;M=M+1|0}}do{if((D|0)==4180){D=0;a[Q]=0;if((a[M]|0)==0){aL=E;break}else{aM=M;aN=E}while(1){P=aM+1|0;O=aN+1|0;if((a[P]|0)==0){aL=O;break}else{aM=P;aN=O}}}}while(0);if(aL>>>0>=64){break}E=ib(I)|0;c[e+66448+((c[R>>2]|0)*4168|0)+4164>>2]=E}}while(0);c[R>>2]=(c[R>>2]|0)+1;E=ee(0,706256,k|0)|0;if((E|0)==0){break L5836}else{N=E}}R=c[494446]|0;ei(((R|0)!=0?R:c[p>>2]|0)|0,726144,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;R=c[494446]|0;a_(((R|0)!=0?R:c[p>>2]|0)|0)|0;G=0;i=f;return G|0}}while(0);R=A;while(1){aO=c[R>>2]|0;if((aO|0)==0){G=1;D=4257;break}if((cP(704064,c[aO+4>>2]|0)|0)==0){break}else{R=aO+12|0}}if((D|0)==4257){i=f;return G|0}R=1024;E=0;M=B;Q=c[aO+8>>2]|0;while(1){O=R-1|0;if((O|0)==0){D=4191;break}P=a[Q]|0;a[M]=P;if(P<<24>>24==0){aP=E;break}else{R=O;E=E+1|0;M=M+1|0;Q=Q+1|0}}do{if((D|0)==4191){a[M]=0;if((a[Q]|0)==0){aP=E;break}else{aQ=Q;aR=E}while(1){R=aQ+1|0;O=aR+1|0;if((a[R]|0)==0){aP=O;break}else{aQ=R;aR=O}}}}while(0);if(aP>>>0>=1024){G=1;i=f;return G|0}E=ee(B|0,706256,h|0)|0;L5911:do{if((E|0)!=0){Q=e+99792|0;M=E;L5913:while(1){N=c[Q>>2]|0;if(N>>>0>=64){break L5911}O=64;R=e+99796+(N*80|0)|0;P=M;while(1){S=O-1|0;if((S|0)==0){D=4200;break}U=a[P]|0;a[R]=U;if(U<<24>>24==0){break}else{O=S;R=R+1|0;P=P+1|0}}do{if((D|0)==4200){D=0;a[R]=0;if((a[P]|0)==0){break}else{aS=P}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);bQ(F|0,64,701864,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bQ(H|0,64,701656,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bQ(I|0,64,701336,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bQ(J|0,64,701128,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bQ(K|0,64,700848,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;P=A;while(1){aT=c[P>>2]|0;if((aT|0)==0){D=4211;break L5913}if((cP(F|0,c[aT+4>>2]|0)|0)==0){break}else{P=aT+12|0}}P=64;R=0;O=L;S=c[aT+8>>2]|0;while(1){U=P-1|0;if((U|0)==0){D=4208;break}X=a[S]|0;a[O]=X;if(X<<24>>24==0){aU=R;break}else{P=U;R=R+1|0;O=O+1|0;S=S+1|0}}do{if((D|0)==4208){D=0;a[O]=0;if((a[S]|0)==0){aU=R;break}else{aV=S;aW=R}while(1){P=aV+1|0;U=aW+1|0;if((a[P]|0)==0){aU=U;break}else{aV=P;aW=U}}}}while(0);if(aU>>>0>=64){D=4211;break}do{if((cP(L|0,700720)|0)==0){c[e+99796+(N*80|0)+68>>2]=0;aY=A;D=4225}else{if((cP(L|0,700240)|0)==0){c[e+99796+(N*80|0)+68>>2]=2;aY=A;D=4225;break}if((cP(L|0,699624)|0)==0){c[e+99796+(N*80|0)+68>>2]=3;aY=A;D=4225;break}if((cP(L|0,699192)|0)==0){c[e+99796+(N*80|0)+68>>2]=1;aY=A;D=4225;break}if((cP(L|0,698728)|0)==0){c[e+99796+(N*80|0)+68>>2]=4;aY=A;D=4225;break}if((cP(L|0,698576)|0)!=0){D=4223;break L5913}c[e+99796+(N*80|0)+68>>2]=5;aZ=A}}while(0);L5953:do{if((D|0)==4225){while(1){D=0;a$=c[aY>>2]|0;if((a$|0)==0){a0=A;break}if((cP(I|0,c[a$+4>>2]|0)|0)==0){D=4227;break}else{aY=a$+12|0;D=4225}}do{if((D|0)==4227){D=0;c[(dX()|0)>>2]=0;R=aX(c[a$+8>>2]|0,0,0)|0;if((c[(dX()|0)>>2]|0)!=0){a0=A;break}if((R|0)==1){c[e+99796+(N*80|0)+72>>2]=2;aZ=A;break L5953}else if((R|0)==2){c[e+99796+(N*80|0)+72>>2]=3;aZ=A;break L5953}else{D=4231;break L5913}}}while(0);while(1){a1=c[a0>>2]|0;if((a1|0)==0){D=4236;break L5913}if((cP(H|0,c[a1+4>>2]|0)|0)==0){break}else{a0=a1+12|0}}c[(dX()|0)>>2]=0;R=aX(c[a1+8>>2]|0,0,16)|0;if((c[(dX()|0)>>2]|0)!=0){D=4236;break L5913}c[e+99796+(N*80|0)+72>>2]=1;c[e+99796+(N*80|0)+64>>2]=R;aZ=A}}while(0);while(1){a3=c[aZ>>2]|0;if((a3|0)==0){a4=A;break}if((cP(J|0,c[a3+4>>2]|0)|0)==0){D=4239;break}else{aZ=a3+12|0}}do{if((D|0)==4239){D=0;c[(dX()|0)>>2]=0;R=aX(c[a3+8>>2]|0,0,16)|0;if((c[(dX()|0)>>2]|0)!=0){a4=A;break}b[e+99796+(N*80|0)+76>>1]=R&65535;a4=A}}while(0);while(1){a6=c[a4>>2]|0;if((a6|0)==0){break}if((cP(K|0,c[a6+4>>2]|0)|0)==0){D=4243;break}else{a4=a6+12|0}}do{if((D|0)==4243){D=0;c[(dX()|0)>>2]=0;R=aX(c[a6+8>>2]|0,0,16)|0;if((c[(dX()|0)>>2]|0)!=0){break}b[e+99796+(N*80|0)+78>>1]=R&65535}}while(0);c[Q>>2]=(c[Q>>2]|0)+1;M=ee(0,706256,h|0)|0;if((M|0)==0){break L5911}}if((D|0)==4236){M=c[494446]|0;Q=(M|0)!=0?M:c[p>>2]|0;a5(726408,54,1,Q|0)|0;Q=c[494446]|0;M=(Q|0)!=0?Q:c[p>>2]|0;a_(M|0)|0;G=0;i=f;return G|0}else if((D|0)==4223){M=c[494446]|0;a5(726600,39,1,((M|0)!=0?M:c[p>>2]|0)|0)|0;M=c[494446]|0;a_(((M|0)!=0?M:c[p>>2]|0)|0)|0;G=0;i=f;return G|0}else if((D|0)==4211){M=c[494446]|0;a5(726720,54,1,((M|0)!=0?M:c[p>>2]|0)|0)|0;M=c[494446]|0;a_(((M|0)!=0?M:c[p>>2]|0)|0)|0;G=0;i=f;return G|0}else if((D|0)==4231){M=c[494446]|0;a5(693176,52,1,((M|0)!=0?M:c[p>>2]|0)|0)|0;M=c[494446]|0;a_(((M|0)!=0?M:c[p>>2]|0)|0)|0;G=0;i=f;return G|0}}}while(0);gQ(d,704872,e+104916|0)|0;K=e+109016|0;J=A;while(1){a7=c[J>>2]|0;if((a7|0)==0){G=1;D=4266;break}if((cP(704432,c[a7+4>>2]|0)|0)==0){break}else{J=a7+12|0}}if((D|0)==4266){i=f;return G|0}J=512;H=K;I=c[a7+8>>2]|0;while(1){L=J-1|0;if((L|0)==0){break}F=a[I]|0;a[H]=F;if(F<<24>>24==0){G=1;D=4261;break}else{J=L;H=H+1|0;I=I+1|0}}if((D|0)==4261){i=f;return G|0}a[H]=0;if((a[I]|0)==0){G=1;i=f;return G|0}else{a8=I}while(1){J=a8+1|0;if((a[J]|0)==0){G=1;break}else{a8=J}}i=f;return G|0}}while(0);a8=c[494446]|0;a5(727976,50,1,((a8|0)!=0?a8:c[p>>2]|0)|0)|0;a8=c[494446]|0;a_(((a8|0)!=0?a8:c[p>>2]|0)|0)|0;G=0;i=f;return G|0}function h7(){return 14317944|0}function h8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+8200|0;g=f|0;h=f+4104|0;c[g>>2]=b;j=f+8|0;k=e+8|0;while(1){l=c[k>>2]|0;if((l|0)==0){break}if((cP(720096,c[l>>2]|0)|0)==0){m=4273;break}else{k=l+8|0}}do{if((m|0)==4273){k=c[l+4>>2]|0;if((k|0)==0){break}else{n=4096;o=0;q=j;r=k}while(1){k=n-1|0;if((k|0)==0){m=4277;break}e=a[r]|0;a[q]=e;if(e<<24>>24==0){s=o;break}else{n=k;o=o+1|0;q=q+1|0;r=r+1|0}}do{if((m|0)==4277){a[q]=0;if((a[r]|0)==0){s=o;break}else{t=r;u=o}while(1){k=t+1|0;e=u+1|0;if((a[k]|0)==0){s=e;break}else{t=k;u=e}}}}while(0);if(s>>>0>=4096){i=f;return b|0}aIq(b);c[g>>2]=0;e=h|0;gJ(e,d,j);if((a[1820736]&1)==0){v=go(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}k=c[494446]|0;ei(((k|0)!=0?k:c[p>>2]|0)|0,726880,(k=i,i=i+8|0,c[k>>2]=e,k)|0)|0;i=k;k=c[494446]|0;a_(((k|0)!=0?k:c[p>>2]|0)|0)|0;v=go(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}}while(0);a[j]=0;i=f;return b|0}function h9(a,b){a=a|0;b=b|0;var c=0,d=0;if((a|0)==0){c=b;return c|0}d=ck(a|0,46)|0;a=(d|0)==0?14317944:d+1|0;if((cP(a|0,707480)|0)==0){c=0;return c|0}if((cP(a|0,727520)|0)==0){c=0;return c|0}if((cP(a|0,697792)|0)==0){c=2;return c|0}if((cP(a|0,727016)|0)==0){c=2;return c|0}else{return((cP(a|0,719736)|0)==0?2:b)|0}return 0}function ia(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+4096|0;f=e|0;g=b+72|0;h=c[g>>2]|0;if((h|0)!=0){j=f|0;k=0;l=h;while(1){h=b+76+(k*4148|0)|0;if((a[h]|0)==0){m=l}else{n=4096;o=j;p=h;while(1){q=n-1|0;if((q|0)==0){r=4307;break}s=a[p]|0;a[o]=s;if(s<<24>>24==0){break}else{n=q;o=o+1|0;p=p+1|0}}do{if((r|0)==4307){r=0;a[o]=0;if((a[p]|0)==0){break}else{t=p}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);gJ(h,d,j);m=c[g>>2]|0}p=k+1|0;if(p>>>0<m>>>0){k=p;l=m}else{break}}}m=b+66444|0;if((c[m>>2]|0)!=0){l=f|0;k=0;do{g=b+66448+(k*4168|0)+64|0;j=4096;t=l;p=g;while(1){o=j-1|0;if((o|0)==0){r=4314;break}n=a[p]|0;a[t]=n;if(n<<24>>24==0){break}else{j=o;t=t+1|0;p=p+1|0}}do{if((r|0)==4314){r=0;a[t]=0;if((a[p]|0)==0){break}else{u=p}do{u=u+1|0;}while((a[u]|0)!=0)}}while(0);gJ(g,d,l);k=k+1|0;}while(k>>>0<(c[m>>2]|0)>>>0)}m=b+104916|0;if((a[m]|0)==0){i=e;return}b=f|0;f=4096;k=b;l=m;while(1){u=f-1|0;if((u|0)==0){r=4321;break}p=a[l]|0;a[k]=p;if(p<<24>>24==0){break}else{f=u;k=k+1|0;l=l+1|0}}do{if((r|0)==4321){a[k]=0;if((a[l]|0)==0){break}else{v=l}do{v=v+1|0;}while((a[v]|0)!=0)}}while(0);gJ(m,d,b);i=e;return}function ib(a){a=a|0;var b=0,d=0,e=0;b=i;if((cP(a|0,696960)|0)==0){d=0;i=b;return d|0}if((cP(a|0,696848)|0)==0){d=1;i=b;return d|0}if((cP(a|0,696712)|0)==0){d=2;i=b;return d|0}if((cP(a|0,696552)|0)==0){d=3;i=b;return d|0}e=c[494446]|0;ei(((e|0)!=0?e:c[p>>2]|0)|0,725744,(e=i,i=i+8|0,c[e>>2]=a,e)|0)|0;i=e;e=c[494446]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;d=0;i=b;return d|0}function ic(b,e){b=b|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=aIp(1032)|0;if((b|0)==0){f=0;return f|0}if((c[b-4>>2]&3|0)!=0){aIv(b|0,0,1032)}g=b;h=~~+bK(+(e/10.0));i=b;j=(h|0)==0?1:h;c[i>>2]=j;h=aIp(ab(j*12800|0,j)|0)|0;k=b+1028|0;c[k>>2]=h;if((h|0)==0){aIq(b);f=0;return f|0}else{l=0;m=j;n=h}while(1){h=ab(ab(m*50|0,m)|0,l)|0;c[g+4+(l<<2)>>2]=n+h;j=l*7|0;o=c[i>>2]|0;p=0;q=o;while(1){r=p*5|0;s=0;t=q;u=q;while(1){v=s+r|0;w=((1<<(v&7)&(d[687656+((v>>>3)+j)|0]|0)|0)!=0)<<31>>31;if((t|0)==0){x=0;y=u}else{v=0;z=u;while(1){if((z|0)==0){A=0}else{B=v+h|0;C=0;D=z;while(1){a[n+(B+(ab((((ab(D,p)|0)+C|0)*5|0)+s|0,D)|0))|0]=w;E=C+1|0;if(E>>>0<o>>>0){C=E;D=o}else{A=o;break}}}D=v+1|0;if(D>>>0<A>>>0){v=D;z=A}else{x=A;y=A;break}}}z=s+1|0;if(z>>>0<5){s=z;t=x;u=y}else{break}}u=p+1|0;if(u>>>0<10){p=u;q=y}else{break}}q=l+1|0;if(q>>>0>=256){f=b;break}l=q;m=o;n=c[k>>2]|0}return f|0}function id(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=e|0;c[f>>2]=0;e=aIu(d|0)|0;if((e|0)==0){return}g=b+4|0;h=b;b=0;i=0;j=0;while(1){k=aIp(52)|0;if((k|0)==0){l=4369;break}if((c[k-4>>2]&3|0)!=0){aIv(k|0,0,52)}m=k;c[k>>2]=c[g+(a[d+i|0]<<2)>>2];n=c[h>>2]|0;o=n*5|0;c[k+4>>2]=o;p=n*10|0;c[k+8>>2]=p;c[k+12>>2]=o;c[k+32>>2]=o;c[k+36>>2]=p;c[k+40>>2]=0;c[k+44>>2]=p;c[k+24>>2]=b;c[k+28>>2]=0;c[k+48>>2]=0;if((i|0)==0){c[f>>2]=m;q=c[h>>2]|0}else{c[j+48>>2]=m;q=n}n=i+1|0;if(n>>>0<e>>>0){b=(q*6|0)+b|0;i=n;j=m}else{l=4368;break}}if((l|0)==4368){return}else if((l|0)==4369){return}}function ie(a,b){a=a|0;b=b|0;var d=0;a=b|0;b=c[a>>2]|0;if((b|0)==0){c[a>>2]=0;return}else{d=b}while(1){b=c[d+48>>2]|0;aIq(d);if((b|0)==0){break}else{d=b}}c[a>>2]=0;return}function ig(a){a=a|0;aIq(c[a+1028>>2]|0);aIq(a);return}function ih(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0;h=i;i=i+1912|0;j=h|0;k=h+16|0;l=h+784|0;m=h+792|0;n=h+840|0;o=h+856|0;q=h+1880|0;r=h+1888|0;s=h+1904|0;if((bx(b|0,723792)|0)!=0){c[s>>2]=0;if((go(b,s)|0)<0){t=c[494446]|0;u=(t|0)!=0?t:c[p>>2]|0;ei(u|0,707488,(v=i,i=i+8|0,c[v>>2]=b,v)|0)|0;i=v;u=c[494446]|0;t=(u|0)!=0?u:c[p>>2]|0;a_(t|0)|0;w=0;i=h;return w|0}t=c[s>>2]|0;if((a[t+2|0]|0)!=2){s=c[494446]|0;u=(s|0)!=0?s:c[p>>2]|0;a5(703160,56,1,u|0)|0;u=c[494446]|0;s=(u|0)!=0?u:c[p>>2]|0;a_(s|0)|0;aIq(t);w=0;i=h;return w|0}s=a[t+16|0]|0;u=d[t+13|0]<<8|d[t+12|0];x=d[t+15|0]<<8|d[t+14|0];if((a[1820736]&1)!=0){y=s&255;z=c[494446]|0;A=(z|0)!=0?z:c[p>>2]|0;ei(A|0,699912,(v=i,i=i+24|0,c[v>>2]=u,c[v+8>>2]=x,c[v+16>>2]=y,v)|0)|0;i=v;y=c[494446]|0;A=(y|0)!=0?y:c[p>>2]|0;a_(A|0)|0}A=ab(x,u)|0;y=aIp(A<<2)|0;z=y;B=e+8|0;c[B>>2]=z;c[e>>2]=u;c[e+4>>2]=x;if((y|0)==0){y=c[494446]|0;x=(y|0)!=0?y:c[p>>2]|0;a5(697736,52,1,x|0)|0;x=c[494446]|0;y=(x|0)!=0?x:c[p>>2]|0;a_(y|0)|0;aIq(t);w=0;i=h;return w|0}L6176:do{if((s<<24>>24|0)==24){if((A|0)==0){break}else{C=0;D=z}while(1){y=C*3|0;c[D+(C<<2)>>2]=d[t+(y+18)|0]<<g|d[t+(y+19)|0]<<8|d[t+(y+20)|0]<<f|-16777216;y=C+1|0;if(y>>>0>=A>>>0){break L6176}C=y;D=c[B>>2]|0}}else if((s<<24>>24|0)==32){if((A|0)==0){break}else{E=0;F=z}while(1){y=E<<2;c[F+(E<<2)>>2]=d[t+((y|1)+18)|0]<<8|d[t+(y+18)|0]<<g|d[t+((y|2)+18)|0]<<f|d[t+((y|3)+18)|0]<<24;y=E+1|0;if(y>>>0>=A>>>0){break L6176}E=y;F=c[B>>2]|0}}else{y=c[494446]|0;a5(695832,88,1,((y|0)!=0?y:c[p>>2]|0)|0)|0;y=c[494446]|0;a_(((y|0)!=0?y:c[p>>2]|0)|0)|0;aIq(t);aIq(c[B>>2]|0);c[B>>2]=0;w=0;i=h;return w|0}}while(0);aIq(t);w=1;i=h;return w|0}if((bx(b|0,727632)|0)==0){w=0;i=h;return w|0}if((a[1820736]&1)!=0){t=c[494446]|0;B=(t|0)!=0?t:c[p>>2]|0;a5(715360,38,1,B|0)|0;B=c[494446]|0;t=(B|0)!=0?B:c[p>>2]|0;a_(t|0)|0}t=e+8|0;B=e|0;F=e+4|0;e=n;E=q|0;q=r;c[t>>2]=0;c[B>>2]=0;c[F>>2]=0;A=c9(b|0,697480)|0;if((A|0)==0){w=0;i=h;return w|0}ev(A|0,0,2)|0;b=cf(A|0)|0;eD(A|0);aIv(m|0,0,48);c[e>>2]=c[632];c[e+4>>2]=c[633];c[e+8>>2]=c[634];c[e+12>>2]=c[635];aIv(o|0,0,1024);if((ec(E|0,1,8,A|0)|0)==8){L6202:do{if((aID(E|0,10848,8)|0)==0){z=cf(A|0)|0;do{if((z|0)<(b|0)&(z|0)>-1){s=l;D=s+1|0;C=s+2|0;y=s+3|0;x=r|0;u=r+4|0;G=r+8|0;H=n|0;I=n+4|0;J=n+8|0;K=n+9|0;L=n+10|0;M=n+11|0;N=n+12|0;O=k|0;P=0;Q=0;R=0;S=0;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;L6207:while(1){aIv(q|0,0,12);c[l>>2]=0;if((ec(s|0,1,4,A|0)|0)!=4){_=4407;break}c[x>>2]=d[D]<<16|d[s]<<24|d[C]<<8|d[y];if((ec(u|0,1,4,A|0)|0)==4){$=0}else{_=4407;break}while(1){if($>>>0>=4){_=4411;break}if((aID(u|0,c[684392+($<<3)>>2]|0,4)|0)==0){_=4410;break}else{$=$+1|0}}L6213:do{if((_|0)==4410){_=0;switch(c[684396+($<<3)>>2]|0){case 1:{_=4413;break L6207;break};case 2:{if(R|S|T){_=4415;break L6207}aIq(c[G>>2]|0);aa=c[x>>2]|0;ac=aa+4|0;ad=aIp(ac)|0;if((ad|0)==0){_=4417;break L6207}if((c[ad-4>>2]&3|0)!=0){aIv(ad|0,0,ac|0)}c[G>>2]=ad;if((ec(ad|0,1,ac|0,A|0)|0)!=(ac|0)){_=4421;break L6207}if((aa|0)!=13){_=4423;break L6207}aa=d[ad+1|0]<<16|d[ad]<<24|d[ad+2|0]<<8|d[ad+3|0];c[H>>2]=aa;ac=d[ad+5|0]<<16|d[ad+4|0]<<24|d[ad+6|0]<<8|d[ad+7|0];c[I>>2]=ac;ae=a[ad+8|0]|0;a[J]=ae;af=a[ad+9|0]|0;a[K]=af;ag=a[ad+10|0]|0;a[L]=ag;a[M]=a[ad+11|0]|0;ah=a[ad+12|0]|0;a[N]=ah;if((aa|0)==0|(ac|0)==0){_=4425;break L6207}switch(af<<24>>24){case 0:{ai=ae&255;aj=0;while(1){if(aj>>>0>=5){_=4433;break L6207}if((c[10824+(aj<<2)>>2]|0)==(ai|0)){break}else{aj=aj+1|0}}break};case 3:{aj=ae&255;ai=0;while(1){if(ai>>>0>=4){_=4436;break L6207}if((c[10808+(ai<<2)>>2]|0)==(aj|0)){break}else{ai=ai+1|0}}break};case 2:case 4:case 6:{if(!((ae<<24>>24|0)==8|(ae<<24>>24|0)==16)){_=4430;break L6207}break};default:{_=4437;break L6207}}if(ag<<24>>24!=0){_=4439;break L6207}aIq(ad);c[G>>2]=0;ak=U;al=0;am=0;an=1;ao=Q;ap=P;aq=af;ar=ac;as=ah;at=aa;au=ae;break L6213;break};case 4:{if(U|R^1|T|S){_=4444;break L6207}ai=c[x>>2]|0;if(((ai>>>0)%3|0|0)!=0){_=4446;break L6207}aj=(ai>>>0)/3|0;if(ai>>>0>770){_=4452;break L6207}if((ec(O|0,3,aj|0,A|0)|0)!=(aj|0)){_=4452;break L6207}if(ai>>>0>=3){ai=0;do{av=ai*3|0;c[o+(ai<<2)>>2]=d[k+av|0]<<16|d[k+(av+1)|0]<<8|d[k+(av+2)|0]|-16777216;ai=ai+1|0;}while(ai>>>0<aj>>>0)}if((ev(A|0,4,1)|0)>-1){ak=1;al=0;am=0;an=R;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z;break L6213}else{_=4452;break L6207}break};case 3:{if(T|R^1){_=4455;break L6207}if(!(V<<24>>24!=3|U)){_=4455;break L6207}aj=c[x>>2]|0;ai=aj+P|0;ae=aIr(Q,ai)|0;if((ae|0)==0){aw=Q;_=4459;break L6207}if((ec(ae+P|0,1,aj|0,A|0)|0)!=(aj|0)){aw=ae;_=4459;break L6207}if((ev(A|0,4,1)|0)<0){aw=ae;_=4459;break L6207}else{ak=U;al=0;am=1;an=R;ao=ae;ap=ai;aq=V;ar=W;as=X;at=Y;au=Z;break L6213}break};case 5:{if(!(R&S)){_=4461;break L6207}if((ev(A|0,4,1)|0)<0){_=4463;break L6207}else{ak=U;al=1;am=1;an=1;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z;break L6213}break};default:{_=4411;break L6213}}}}while(0);if((_|0)==4411){_=0;if((ev(A|0,(c[x>>2]|0)+4|0,1)|0)<0){_=4412;break}else{ak=U;al=T;am=S;an=R;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z}}ai=cf(A|0)|0;if((ai|0)<(b|0)&(ai|0)>-1){P=ap;Q=ao;R=an;S=am;T=al;U=ak;V=aq;W=ar;X=as;Y=at;Z=au}else{_=4465;break}}if((_|0)==4407){Z=c[p>>2]|0;ei(Z|0,726832,(v=i,i=i+8|0,c[v>>2]=613,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4412){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=620,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4413){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=624,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4415){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=628,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4417){c[G>>2]=0}else if((_|0)==4421){aIq(ad)}else if((_|0)==4423){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=154,v)|0)|0;i=v;_=4440}else if((_|0)==4425){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=165,v)|0)|0;i=v;_=4440}else if((_|0)==4430){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=170,v)|0)|0;i=v;_=4440}else if((_|0)==4433){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=186,v)|0)|0;i=v;_=4440}else if((_|0)==4436){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=202,v)|0)|0;i=v;_=4440}else if((_|0)==4437){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=205,v)|0)|0;i=v;_=4440}else if((_|0)==4439){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=217,v)|0)|0;i=v;_=4440}else if((_|0)==4444){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=638,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4446){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=641,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4452){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=644,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4455){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=651,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4459){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=654,v)|0)|0;i=v;ax=0;ay=aw;break L6202}else if((_|0)==4461){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=661,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4463){ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=664,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4465){if(!(an&am&al)){az=ao;break}c[m+36>>2]=0;c[m+40>>2]=0;c[m+24>>2]=0;c[m+8>>2]=0;Z=m+20|0;c[Z>>2]=0;c[m+44>>2]=0;Y=aIp(43784)|0;if((Y|0)==0){X=c[p>>2]|0;ei(X|0,726832,(v=i,i=i+8|0,c[v>>2]=675,v)|0)|0;i=v;ax=0;ay=ao;break L6202}X=m+28|0;c[X>>2]=Y;c[Y>>2]=0;c[Y+10992>>2]=0;c[Y+10996>>2]=0;c[Y+43780>>2]=1;c[Y+11e3>>2]=1;c[Y+11004>>2]=0;c[Y+11008>>2]=15;switch(aq&255|0){case 0:{aA=((ab(at,au&255)|0)+7|0)>>>3;break};case 2:{aA=((ab((au&255)*3|0,at)|0)+7|0)>>>3;break};case 3:{aA=((ab(at,au&255)|0)+7|0)>>>3;break};case 4:{aA=((ab((au&255)<<1,at)|0)+7|0)>>>3;break};case 6:{aA=((ab((au&255)<<2,at)|0)+7|0)>>>3;break};default:{aA=0}}Y=as<<24>>24==1;W=(ab(ar,aA+1|0)|0)<<(Y&1);V=aIp(W)|0;if((V|0)==0){U=c[p>>2]|0;ei(U|0,726832,(v=i,i=i+8|0,c[v>>2]=683,v)|0)|0;i=v;ax=0;ay=ao;break L6202}c[m>>2]=ao;c[m+4>>2]=ap;c[m+16>>2]=W;c[m+12>>2]=V;W=(jI(m)|0)==1;U=c[X>>2]|0;if((U|0)!=0){aIq(U);c[X>>2]=0}if(!W){W=c[p>>2]|0;ei(W|0,726832,(v=i,i=i+8|0,c[v>>2]=693,v)|0)|0;i=v;ax=V;ay=ao;break L6202}c[B>>2]=at;c[F>>2]=ar;W=aIp(ab(ar<<2,at)|0)|0;X=W;c[t>>2]=X;if((W|0)==0){W=c[p>>2]|0;ei(W|0,726832,(v=i,i=i+8|0,c[v>>2]=701,v)|0)|0;i=v;ax=V;ay=ao;break L6202}W=c[Z>>2]|0;Z=o|0;L6301:do{if(Y){U=j;T=j|0;S=j+4|0;R=j+9|0;P=j+8|0;x=0;O=W;N=V;M=at;L6303:while(1){L=c[10696+(x<<4)>>2]|0;do{if(M>>>0>L>>>0){K=c[I>>2]|0;J=c[10700+(x<<4)>>2]|0;if(K>>>0<=J>>>0){aB=N;aC=O;break}u=c[10704+(x<<4)>>2]|0;y=((M-1-L+u|0)>>>0)/(u>>>0)|0;C=c[10708+(x<<4)>>2]|0;s=((K-1-J+C|0)>>>0)/(C>>>0)|0;K=y<<2;aD=aIp(ab(s,K)|0)|0;D=aD;if((aD|0)==0){break L6303}c[U>>2]=c[e>>2];c[U+4>>2]=c[e+4>>2];c[U+8>>2]=c[e+8>>2];c[U+12>>2]=c[e+12>>2];c[T>>2]=y;c[S>>2]=s;switch(d[R]|0){case 0:{aE=((ab(d[P]|0,y)|0)+7|0)>>>3;break};case 2:{aE=((ab(y*3|0,d[P]|0)|0)+7|0)>>>3;break};case 3:{aE=((ab(d[P]|0,y)|0)+7|0)>>>3;break};case 4:{aE=((ab(y<<1,d[P]|0)|0)+7|0)>>>3;break};case 6:{aE=((ab(d[P]|0,K)|0)+7|0)>>>3;break};default:{aE=0}}K=ab(aE+1|0,s)|0;if(K>>>0>O>>>0){_=4495;break L6303}if(!(jH(D,j,N,K,Z)|0)){_=4497;break L6303}ai=N+K|0;ae=O-K|0;if(!((s|0)==0|(y|0)==0)){K=D;D=X+((ab(c[H>>2]|0,J)|0)+L<<2)|0;J=0;while(1){aj=D;aa=0;while(1){c[aj>>2]=c[K+(aa<<2)>>2];ah=aa+1|0;if(ah>>>0<y>>>0){aj=aj+(u<<2)|0;aa=ah}else{break}}aa=J+1|0;aj=D+((ab(c[H>>2]|0,C)|0)<<2)|0;if(aa>>>0<s>>>0){K=K+(y<<2)|0;D=aj;J=aa}else{break}}}aIq(aD);aB=ai;aC=ae}else{aB=N;aC=O}}while(0);L=x+1|0;if(L>>>0>=7){break L6301}x=L;O=aC;N=aB;M=c[H>>2]|0}if((_|0)==4495){aIq(aD)}else if((_|0)==4497){aIq(aD)}ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=706,v)|0)|0;i=v;ax=V;ay=ao;break L6202}else{if(jH(X,n,V,W,Z)|0){break}ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=709,v)|0)|0;i=v;ax=V;ay=ao;break L6202}}while(0);aS(A|0)|0;aIq(ao);aIq(V);if((f|0)==16&(g|0)==0){w=1;i=h;return w|0}Z=ab(c[F>>2]|0,c[B>>2]|0)|0;W=c[t>>2]|0;if((Z|0)==0){w=1;i=h;return w|0}else{aF=0}while(1){X=W+(aF<<2)|0;H=c[X>>2]|0;c[X>>2]=(H&255)<<g|H&-16777216|(H>>>16&255)<<f|H&65280;H=aF+1|0;if(H>>>0<Z>>>0){aF=H}else{w=1;break}}i=h;return w|0}if((_|0)==4440){aIq(ad);c[G>>2]=0}ei(c[p>>2]|0,726832,(v=i,i=i+8|0,c[v>>2]=631,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else{az=0}}while(0);z=c[p>>2]|0;ei(z|0,726832,(v=i,i=i+8|0,c[v>>2]=672,v)|0)|0;i=v;ax=0;ay=az}else{z=c[p>>2]|0;ei(z|0,726832,(v=i,i=i+8|0,c[v>>2]=606,v)|0)|0;i=v;ax=0;ay=0}}while(0);aS(A|0)|0;aG=ax;aH=ay}else{ay=c[p>>2]|0;ei(ay|0,726832,(v=i,i=i+8|0,c[v>>2]=603,v)|0)|0;i=v;aS(A|0)|0;aG=0;aH=0}aIq(c[t>>2]|0);aIq(aH);aIq(aG);w=0;i=h;return w|0}function ii(a,b,c){a=a|0;b=b|0;c=c|0;return-1|0}function ij(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function ik(a){a=a|0;return 1}function il(a){a=a|0;return 1}function im(a,b){a=a|0;b=b|0;return}function io(a){a=a|0;return}function ip(a){a=a|0;return 1}function iq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0.0,N=0,O=0.0,P=0.0,Q=0,R=0.0,S=0.0;d=~~(16777216.0/+h[b+16>>3]);e=c[b+8>>2]|0;if((e|0)==0){f=0;i=b+12|0;c[i>>2]=f;return}j=a+20|0;k=a+4|0;l=a+16|0;m=a+8|0;n=a+12|0;o=a;a=c[b>>2]|0;p=c[b+4>>2]|0;q=e;e=0;r=c[j>>2]|0;while(1){L6363:do{if((q|0)==0){s=a;t=r;u=4541}else{v=a;w=q;x=r;while(1){if(x>>>0<=16777215){y=x;z=w;A=v;break L6363}B=c[l>>2]|0;if((B|0)==0){C=c[n>>2]|0;c[l>>2]=C;D=C}else{D=B}B=D-1|0;c[l>>2]=B;E=+g[v>>2];g[(c[k>>2]|0)+(B<<2)>>2]=E;g[(c[k>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;B=v+8|0;E=+g[v+4>>2];g[(c[m>>2]|0)+(c[l>>2]<<2)>>2]=E;g[(c[m>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;C=(c[j>>2]|0)-16777216|0;c[j>>2]=C;F=w-1|0;if((F|0)==0){s=B;t=C;u=4541;break}else{v=B;w=F;x=C}}}}while(0);if((u|0)==4541){u=0;if(t>>>0<16777216){y=t;z=0;A=s}else{f=e;u=4548;break}}x=p;w=e;v=y;do{C=c[k>>2]|0;F=c[l>>2]|0;B=c[m>>2]|0;G=c[n>>2]|0;H=c[o>>2]|0;I=ab(G<<1,v>>>16)|0;J=I+G|0;E=+((v&65535)>>>0>>>0)*152587890625.0e-16;if((G|0)==0){K=0.0;L=0.0}else{M=0.0;N=0;O=0.0;while(1){P=+g[H+(N+I<<2)>>2]+E*+g[H+(J+N<<2)>>2];Q=N+F|0;R=O+ +g[C+(Q<<2)>>2]*P;S=M+ +g[B+(Q<<2)>>2]*P;Q=N+1|0;if(Q>>>0<G>>>0){M=S;N=Q;O=R}else{K=S;L=R;break}}}g[x>>2]=L;g[x+4>>2]=K;x=x+8|0;w=w+1|0;v=(c[j>>2]|0)+d|0;c[j>>2]=v;}while(v>>>0<16777216);if((z|0)==0){f=w;u=4549;break}else{a=A;p=x;q=z;e=w;r=v}}if((u|0)==4548){i=b+12|0;c[i>>2]=f;return}else if((u|0)==4549){i=b+12|0;c[i>>2]=f;return}}function ir(b){b=+b;var d=0,e=0,f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0,F=0.0,G=0.0,H=0;d=i;e=aIp(28)|0;if((e|0)==0){f=0;i=d;return f|0}if((c[e-4>>2]&3|0)!=0){aIv(e|0,0,28)}aIv(e|0,0,28);h=e+12|0;if(b<1.0){j=b*.825;k=~~+aa(+(16.0/b))+3&-4}else{j=.825;k=16}c[h>>2]=k;l=k<<9;m=aIp((l+(k<<2)<<2)+132|0)|0;k=m+132&-128;c[k-4>>2]=m;m=k;c[e+24>>2]=m;if((k|0)==0){aIq(c[m-4>>2]|0);aIq(e);f=0;i=d;return f|0}c[e>>2]=m;c[e+4>>2]=m+(l<<2);k=c[h>>2]|0;n=k<<1;c[e+8>>2]=m+(n+l<<2);b=1.0;o=0.0;q=1.0;r=1.0;s=0.0;l=0;while(1){t=s+r*q/(b*b);u=o+1.0;v=l+1|0;if(v>>>0<18){b=b*u;o=u;q=q*30.25;r=r*.25;s=t;l=v}else{break}}s=+(k|0)*.5;r=+(k<<8|0);if((k|0)>0){l=0;while(1){v=ab(l,n)|0;w=0;do{q=+((w<<8)+l|0)/r*2.0+-1.0;o=j*s*q*3.141592653589793;if(+Q(+o)<1.0e-5){x=1.0}else{x=+U(+o)/o}o=+R(+(1.0-q*q))*5.5;q=o*o;o=1.0;b=0.0;u=1.0;y=1.0;z=0.0;A=0;while(1){B=z+y*u/(o*o);C=b+1.0;D=A+1|0;if(D>>>0<18){o=o*C;b=C;u=q*u;y=y*.25;z=B;A=D}else{break}}g[m+(w+v<<2)>>2]=j*x*B/t;w=w+1|0;}while((w|0)<(k|0));w=l+1|0;if((w|0)<256){l=w}else{E=0;break}}while(1){l=E+1|0;w=ab(l,n)|0;v=E<<1;A=ab(v,k)|0;D=ab(v|1,k)|0;v=0;do{g[m+(v+D<<2)>>2]=+g[m+(v+w<<2)>>2]- +g[m+(v+A<<2)>>2];v=v+1|0;}while((v|0)<(k|0));if((l|0)<255){E=l}else{break}}E=k*510|0;n=k*511|0;v=0;do{B=+((v<<8)+256|0)/r*2.0+-1.0;x=j*s*B*3.141592653589793;if(+Q(+x)<1.0e-5){F=1.0}else{F=+U(+x)/x}x=+R(+(1.0-B*B))*5.5;B=x*x;x=1.0;z=0.0;y=1.0;u=1.0;q=0.0;A=0;while(1){G=q+u*y/(x*x);b=z+1.0;w=A+1|0;if(w>>>0<18){x=x*b;z=b;y=B*y;u=u*.25;q=G;A=w}else{break}}g[m+(v+n<<2)>>2]=j*F*G/t- +g[m+(v+E<<2)>>2];v=v+1|0;}while((v|0)<(k|0))}k=a[1820736]|0;if((k&1)==0){H=k}else{k=c[494446]|0;v=(k|0)!=0?k:c[p>>2]|0;a5(727600,30,1,v|0)|0;v=c[494446]|0;k=(v|0)!=0?v:c[p>>2]|0;a_(k|0)|0;H=a[1820736]|0}if((H&1)==0){f=e;i=d;return f|0}H=c[494446]|0;k=c[h>>2]|0;ei(((H|0)!=0?H:c[p>>2]|0)|0,715240,(H=i,i=i+16|0,c[H>>2]=8,c[H+8>>2]=k,H)|0)|0;i=H;H=c[494446]|0;a_(((H|0)!=0?H:c[p>>2]|0)|0)|0;f=e;i=d;return f|0}function is(a){a=a|0;if((a|0)==0){aIq(a);return}aIq(c[(c[a+24>>2]|0)-4>>2]|0);aIq(a);return}function it(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=aIu(e|0)|0;if(g>>>0<=c>>>0){h=c+1|0;do{if((h|0)==0){i=e}else{j=h;k=b;l=e;while(1){m=j-1|0;if((m|0)==0){n=4594;break}o=a[l]|0;a[k]=o;if(o<<24>>24==0){n=4648;break}else{j=m;k=k+1|0;l=l+1|0}}if((n|0)==4594){a[k]=0;i=l;break}else if((n|0)==4648){return}}}while(0);if((a[i]|0)==0){return}else{p=i}do{p=p+1|0;}while((a[p]|0)!=0);return}if(!f){f=c+1|0;p=c-2|0;L6458:do{if((p|0)==0){q=e;n=4602}else{i=p;h=b;j=e;while(1){m=i-1|0;if((m|0)==0){break}o=a[j]|0;a[h]=o;if(o<<24>>24==0){break L6458}else{i=m;h=h+1|0;j=j+1|0}}a[h]=0;q=j;n=4602}}while(0);do{if((n|0)==4602){if((a[q]|0)==0){break}else{r=q}do{r=r+1|0;}while((a[r]|0)!=0)}}while(0);r=aIu(b|0)|0;q=r>>>0>f>>>0?0:f-r|0;if((q|0)==0){s=714152}else{f=b+r|0;do{if((q|0)==1){t=714152;u=f}else{j=b+(r+1)|0;a[f]=46;if((q|0)==2){t=714153;u=j;break}h=b+(r+2)|0;a[j]=46;if((q|0)==3){t=714154;u=h;break}j=b+(r+3)|0;a[h]=46;if((q|0)==4){t=714155;u=j;break}a[j]=0;return}}while(0);a[u]=0;s=t}if((a[s]|0)==0){return}else{v=s}do{v=v+1|0;}while((a[v]|0)!=0);return}v=g-c|0;g=(d>>>0)%(((v<<1)+4|0)>>>0)|0;d=v+4|0;s=g-2|0;t=d+v-g|0;if(g>>>0<2){u=c+1|0;do{if((u|0)==0){w=e}else{q=u;r=b;f=e;while(1){j=q-1|0;if((j|0)==0){n=4614;break}h=a[f]|0;a[r]=h;if(h<<24>>24==0){n=4641;break}else{q=j;r=r+1|0;f=f+1|0}}if((n|0)==4641){return}else if((n|0)==4614){a[r]=0;w=f;break}}}while(0);if((a[w]|0)==0){return}else{x=w}do{x=x+1|0;}while((a[x]|0)!=0);return}if(g>>>0<(v+2|0)>>>0){x=e+s|0;s=c+1|0;do{if((s|0)==0){y=x}else{w=s;u=b;q=x;while(1){j=w-1|0;if((j|0)==0){n=4621;break}h=a[q]|0;a[u]=h;if(h<<24>>24==0){n=4647;break}else{w=j;u=u+1|0;q=q+1|0}}if((n|0)==4621){a[u]=0;y=q;break}else if((n|0)==4647){return}}}while(0);if((a[y]|0)==0){return}else{z=y}do{z=z+1|0;}while((a[z]|0)!=0);return}if(g>>>0<d>>>0){d=e+v|0;v=c+1|0;do{if((v|0)==0){A=d}else{g=v;z=b;y=d;while(1){x=g-1|0;if((x|0)==0){n=4628;break}s=a[y]|0;a[z]=s;if(s<<24>>24==0){n=4653;break}else{g=x;z=z+1|0;y=y+1|0}}if((n|0)==4653){return}else if((n|0)==4628){a[z]=0;A=y;break}}}while(0);if((a[A]|0)==0){return}else{B=A}do{B=B+1|0;}while((a[B]|0)!=0);return}else{B=e+t|0;t=c+1|0;do{if((t|0)==0){C=B}else{c=t;e=b;A=B;while(1){d=c-1|0;if((d|0)==0){n=4634;break}v=a[A]|0;a[e]=v;if(v<<24>>24==0){n=4649;break}else{c=d;e=e+1|0;A=A+1|0}}if((n|0)==4634){a[e]=0;C=A;break}else if((n|0)==4649){return}}}while(0);if((a[C]|0)==0){return}else{D=C}do{D=D+1|0;}while((a[D]|0)!=0);return}}function iu(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b+44|0;e=c[d>>2]|0;f=e+8|0;if((c[f>>2]|0)!=0){g=e|0;e=0;do{aIq(c[(c[g>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while(e>>>0<(c[f>>2]|0)>>>0)}c[f>>2]=0;do{if((c[b+113712>>2]|0)==0){h=4668}else{f=c[d>>2]|0;if((f|0)==0){break}e=f+8|0;g=f+4|0;i=c[g>>2]|0;if((c[e>>2]|0)>>>0<i>>>0){j=f|0}else{k=(i<<1)+2|0;c[g>>2]=k;g=f|0;c[g>>2]=aIr(c[g>>2]|0,k*12|0)|0;j=g}g=dv(724224)|0;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)>>2]=g;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=56;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1;h=4668}}while(0);do{if((h|0)==4668){j=c[d>>2]|0;if((j|0)==0){break}b=j+8|0;e=j+4|0;g=c[e>>2]|0;if((c[b>>2]|0)>>>0<g>>>0){l=j|0}else{k=(g<<1)+2|0;c[e>>2]=k;e=j|0;c[e>>2]=aIr(c[e>>2]|0,k*12|0)|0;l=e}e=dv(724184)|0;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)>>2]=e;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)+4>>2]=55;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)+8>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[d>>2]|0;if((b|0)==0){break}e=b+8|0;k=b+4|0;j=c[k>>2]|0;if((c[e>>2]|0)>>>0<j>>>0){m=b|0}else{g=(j<<1)+2|0;c[k>>2]=g;k=b|0;c[k>>2]=aIr(c[k>>2]|0,g*12|0)|0;m=k}k=dv(724120)|0;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)>>2]=k;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=58;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1;e=c[d>>2]|0;if((e|0)==0){break}k=e+8|0;g=e+4|0;b=c[g>>2]|0;if((c[k>>2]|0)>>>0<b>>>0){n=e|0}else{j=(b<<1)+2|0;c[g>>2]=j;g=e|0;c[g>>2]=aIr(c[g>>2]|0,j*12|0)|0;n=g}g=dv(723952)|0;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)>>2]=g;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)+4>>2]=5;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)+8>>2]=0;c[k>>2]=(c[k>>2]|0)+1;k=c[d>>2]|0;if((k|0)==0){break}g=k+8|0;j=k+4|0;e=c[j>>2]|0;if((c[g>>2]|0)>>>0<e>>>0){o=k|0}else{b=(e<<1)+2|0;c[j>>2]=b;j=k|0;c[j>>2]=aIr(c[j>>2]|0,b*12|0)|0;o=j}j=dv(723696)|0;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)>>2]=j;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)+4>>2]=59;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)+8>>2]=0;c[g>>2]=(c[g>>2]|0)+1;g=c[d>>2]|0;if((g|0)==0){break}j=g+8|0;b=g+4|0;k=c[b>>2]|0;if((c[j>>2]|0)>>>0<k>>>0){p=g|0}else{e=(k<<1)+2|0;c[b>>2]=e;b=g|0;c[b>>2]=aIr(c[b>>2]|0,e*12|0)|0;p=b}b=dv(723520)|0;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)>>2]=b;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)+4>>2]=60;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)+8>>2]=0;c[j>>2]=(c[j>>2]|0)+1;j=c[d>>2]|0;if((j|0)==0){break}b=j+8|0;e=j+4|0;g=c[e>>2]|0;if((c[b>>2]|0)>>>0<g>>>0){q=j|0}else{k=(g<<1)+2|0;c[e>>2]=k;e=j|0;c[e>>2]=aIr(c[e>>2]|0,k*12|0)|0;q=e}e=dv(723384)|0;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)>>2]=e;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)+4>>2]=61;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)+8>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[d>>2]|0;if((b|0)==0){break}e=b+8|0;k=b+4|0;j=c[k>>2]|0;if((c[e>>2]|0)>>>0<j>>>0){r=b|0}else{g=(j<<1)+2|0;c[k>>2]=g;k=b|0;c[k>>2]=aIr(c[k>>2]|0,g*12|0)|0;r=k}k=dv(723256)|0;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)>>2]=k;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=62;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1}}while(0);do{if((a[1977788]&1)!=0){if((a[1978861]&1)!=0){break}if((c[479934]|0)!=0){r=c[d>>2]|0;if((r|0)==0){return}q=r+8|0;p=r+4|0;o=c[p>>2]|0;if((c[q>>2]|0)>>>0<o>>>0){s=r|0}else{n=(o<<1)+2|0;c[p>>2]=n;p=r|0;c[p>>2]=aIr(c[p>>2]|0,n*12|0)|0;s=p}p=dv(723128)|0;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)>>2]=p;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)+4>>2]=69;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)+8>>2]=0;c[q>>2]=(c[q>>2]|0)+1}q=c[d>>2]|0;if((q|0)==0){return}p=q+8|0;n=q+4|0;r=c[n>>2]|0;if((c[p>>2]|0)>>>0<r>>>0){t=q|0}else{o=(r<<1)+2|0;c[n>>2]=o;n=q|0;c[n>>2]=aIr(c[n>>2]|0,o*12|0)|0;t=n}n=dv(723e3)|0;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)>>2]=n;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)+4>>2]=67;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)+8>>2]=0;c[p>>2]=(c[p>>2]|0)+1;p=c[d>>2]|0;if((p|0)==0){return}n=p+8|0;o=p+4|0;q=c[o>>2]|0;if((c[n>>2]|0)>>>0<q>>>0){u=p|0}else{r=(q<<1)+2|0;c[o>>2]=r;o=p|0;c[o>>2]=aIr(c[o>>2]|0,r*12|0)|0;u=o}o=dv(722880)|0;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)>>2]=o;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)+4>>2]=68;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)+8>>2]=0;c[n>>2]=(c[n>>2]|0)+1;n=c[d>>2]|0;if((n|0)==0){return}o=n+8|0;r=n+4|0;p=c[r>>2]|0;if((c[o>>2]|0)>>>0<p>>>0){v=n|0}else{q=(p<<1)+2|0;c[r>>2]=q;r=n|0;c[r>>2]=aIr(c[r>>2]|0,q*12|0)|0;v=r}r=dv(722712)|0;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)>>2]=r;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=72;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1;o=c[d>>2]|0;if((o|0)==0){return}r=o+8|0;q=o+4|0;n=c[q>>2]|0;if((c[r>>2]|0)>>>0<n>>>0){w=o|0}else{p=(n<<1)+2|0;c[q>>2]=p;q=o|0;c[q>>2]=aIr(c[q>>2]|0,p*12|0)|0;w=q}q=dv(722640)|0;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)>>2]=q;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)+4>>2]=86;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)+8>>2]=0;c[r>>2]=(c[r>>2]|0)+1;r=c[d>>2]|0;if((r|0)==0){return}q=r+8|0;p=r+4|0;o=c[p>>2]|0;if((c[q>>2]|0)>>>0<o>>>0){x=r|0}else{n=(o<<1)+2|0;c[p>>2]=n;p=r|0;c[p>>2]=aIr(c[p>>2]|0,n*12|0)|0;x=p}p=dv(722528)|0;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)>>2]=p;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)+4>>2]=80;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)+8>>2]=0;c[q>>2]=(c[q>>2]|0)+1}}while(0);x=c[d>>2]|0;if((x|0)==0){return}w=x+8|0;v=x+4|0;u=c[v>>2]|0;if((c[w>>2]|0)>>>0<u>>>0){y=x|0}else{t=(u<<1)+2|0;c[v>>2]=t;v=x|0;c[v>>2]=aIr(c[v>>2]|0,t*12|0)|0;y=v}v=dv(722256)|0;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)>>2]=v;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)+4>>2]=85;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)+8>>2]=0;c[w>>2]=(c[w>>2]|0)+1;w=c[d>>2]|0;if((w|0)==0){return}d=w+8|0;y=w+4|0;v=c[y>>2]|0;if((c[d>>2]|0)>>>0<v>>>0){z=w|0}else{t=(v<<1)+2|0;c[y>>2]=t;y=w|0;c[y>>2]=aIr(c[y>>2]|0,t*12|0)|0;z=y}y=dv(722080)|0;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)>>2]=y;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)+4>>2]=87;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)+8>>2]=0;c[d>>2]=(c[d>>2]|0)+1;return}function iv(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0;e=i;i=i+22120|0;f=e|0;h=e+16|0;j=e+528|0;k=e+1552|0;l=e+5648|0;m=e+9744|0;n=e+9768|0;o=e+9832|0;q=e+13928|0;r=e+18024|0;s=d+8|0;t=c[s>>2]|0;u=c[s+4>>2]|0;do{if((t&1|0)==0&(u&0|0)==0){if(!((t&2|0)==0&(u&0|0)==0)){v=1;break}if(!((t&4|0)==0&(u&0|0)==0)){v=2;break}if(!((t&8|0)==0&(u&0|0)==0)){v=3;break}if(!((t&32|0)==0&(u&0|0)==0)){v=5;break}if(!((t&16|0)==0&(u&0|0)==0)){v=4;break}if(!((t&128|0)==0&(u&0|0)==0)){v=8;break}v=(t&64|0)==0&(u&0|0)==0?10:7}else{v=0}}while(0);u=d+40|0;t=c[u>>2]|0;s=c[t+8>>2]|0;if((s|0)==0){w=0;x=0}else{y=s-1|0;s=c[t>>2]|0;w=c[s+(y*12|0)+4>>2]|0;x=c[s+(y*12|0)>>2]|0}y=c[3118488]|0;do{if((y|0)!=0){if((c[y+24>>2]|0)==0){break}fq[c[y+20>>2]&3](c[3118440]|0,969352,0,320,240,1.0)}}while(0);switch(w|0){case 69:case 62:case 61:case 59:case 58:case 26:case 5:case 4:case 60:{z=iw(d,v)|0;i=e;return z|0};default:{}}if((w-12|0)>>>0<2){y=n|0;n=c[u>>2]|0;s=n+8|0;t=c[s>>2]|0;A=(t|0)==0;if(A){B=0}else{B=c[(c[n>>2]|0)+((t-1|0)*12|0)+4>>2]|0}C=(a[1717413]&1)==0;D=C?1:c[478760]|0;E=C?1:c[478761]|0;L6686:do{switch(v|0){case 1:{do{if((B|0)==12){c[494432]=(c[494432]|0)+E;G=c[494434]|0;if(G>>>0<E>>>0){break}c[494434]=G-E}else{c[494434]=(c[494434]|0)+E}}while(0);G=c[(c[3118488]|0)+16>>2]|0;if((G|0)==0){break L6686}fi[G&255](c[3118440]|0);break};case 0:{do{if((B|0)==12){c[494432]=(c[494432]|0)-E;c[494434]=(c[494434]|0)+E}else{G=c[494434]|0;if(G>>>0<E>>>0){break}c[494434]=G-E}}while(0);G=c[(c[3118488]|0)+16>>2]|0;if((G|0)==0){break L6686}fi[G&255](c[3118440]|0);break};case 3:{do{if((B|0)==12){c[494431]=(c[494431]|0)+D;G=c[494433]|0;if(G>>>0<D>>>0){break}c[494433]=G-D}else{c[494433]=(c[494433]|0)+D}}while(0);G=c[(c[3118488]|0)+16>>2]|0;if((G|0)==0){break L6686}fi[G&255](c[3118440]|0);break};case 5:{G=d+48|0;if(!A){H=t-1|0;c[s>>2]=H;aIq(c[(c[n>>2]|0)+(H*12|0)>>2]|0)}if((G|0)!=0){c[G>>2]=c[(c[n>>2]|0)+((c[s>>2]|0)*12|0)+8>>2]}if((B|0)!=13){break L6686}H=c[u>>2]|0;I=c[G>>2]|0;if((H|0)==0){break L6686}G=H+8|0;J=H+4|0;K=c[J>>2]|0;if((c[G>>2]|0)>>>0<K>>>0){L=H|0}else{M=(K<<1)+2|0;c[J>>2]=M;J=H|0;c[J>>2]=aIr(c[J>>2]|0,M*12|0)|0;L=J}J=dv(14317944)|0;c[(c[L>>2]|0)+((c[G>>2]|0)*12|0)>>2]=J;c[(c[L>>2]|0)+((c[G>>2]|0)*12|0)+4>>2]=12;c[(c[L>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]=I;c[G>>2]=(c[G>>2]|0)+1;break};case 7:{G=d+48|0;if(!A){I=t-1|0;c[s>>2]=I;aIq(c[(c[n>>2]|0)+(I*12|0)>>2]|0)}if((G|0)==0){break L6686}c[G>>2]=c[(c[n>>2]|0)+((c[s>>2]|0)*12|0)+8>>2];break};case 4:{G=d+48|0;if(!A){I=t-1|0;c[s>>2]=I;aIq(c[(c[n>>2]|0)+(I*12|0)>>2]|0)}if((G|0)!=0){c[G>>2]=c[(c[n>>2]|0)+((c[s>>2]|0)*12|0)+8>>2]}if((B|0)!=12){break L6686}if((a[1717413]&1)!=0){break L6686}I=c[u>>2]|0;J=c[G>>2]|0;if((I|0)==0){break L6686}G=I+8|0;M=I+4|0;H=c[M>>2]|0;if((c[G>>2]|0)>>>0<H>>>0){N=I|0}else{K=(H<<1)+2|0;c[M>>2]=K;M=I|0;c[M>>2]=aIr(c[M>>2]|0,K*12|0)|0;N=M}M=dv(14317944)|0;c[(c[N>>2]|0)+((c[G>>2]|0)*12|0)>>2]=M;c[(c[N>>2]|0)+((c[G>>2]|0)*12|0)+4>>2]=13;c[(c[N>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]=J;c[G>>2]=(c[G>>2]|0)+1;break};case 8:{if(!C){break L6686}fj[c[(c[3118437]|0)+44>>2]&511](c[3118440]|0,m);if((B|0)==12){c[494433]=(c[494433]|0)+(c[494431]|0);c[494434]=(c[494434]|0)+(c[494432]|0);c[494431]=0;c[494432]=0}else{c[494433]=(c[m+16>>2]|0)-(c[494431]|0);c[494434]=(c[m+20>>2]|0)-(c[494432]|0)}G=c[(c[3118488]|0)+16>>2]|0;if((G|0)==0){break L6686}fi[G&255](c[3118440]|0);break};case 2:{do{if((B|0)==12){c[494431]=(c[494431]|0)-D;c[494433]=(c[494433]|0)+D}else{G=c[494433]|0;if(G>>>0<D>>>0){break}c[494433]=G-D}}while(0);G=c[(c[3118488]|0)+16>>2]|0;if((G|0)==0){break L6686}fi[G&255](c[3118440]|0);break};case 9:{a[d+53|0]=1;break};default:{}}}while(0);m=c[u>>2]|0;C=c[m+8>>2]|0;if((C|0)==0){O=B}else{O=c[(c[m>>2]|0)+((C-1|0)*12|0)+4>>2]|0}iy(d);if((a[1717413]&1)==0){if((O|0)==12){P=695512}else{P=(O|0)==13?695248:0}O=c[494431]|0;C=c[494432]|0;m=c[494433]|0;B=c[494434]|0;bQ(y|0,64,694960,(Q=i,i=i+40|0,c[Q>>2]=P,c[Q+8>>2]=O,c[Q+16>>2]=C,c[Q+24>>2]=m,c[Q+32>>2]=B,Q)|0)|0;i=Q}else{c[494431]=0;c[494432]=0;B=c[478760]|0;m=(c[494433]|0)-1+B|0;C=m-((m>>>0)%(B>>>0)|0)|0;c[494433]=C;O=c[478761]|0;P=(c[494434]|0)-1+O|0;N=P-((P>>>0)%(O>>>0)|0)|0;c[494434]=N;s=(m>>>0)/(B>>>0)|0;B=(P>>>0)/(O>>>0)|0;bQ(y|0,64,695944,(Q=i,i=i+40|0,c[Q>>2]=696104,c[Q+8>>2]=C,c[Q+16>>2]=N,c[Q+24>>2]=s,c[Q+32>>2]=B,Q)|0)|0;i=Q}if((a[y]|0)!=0){B=dv(y|0)|0;if((aIu(B|0)|0)>>>0>48){a[B+46|0]=46;a[B+47|0]=46;a[B+48|0]=46;a[B+49|0]=0}y=(aIu(B|0)|0)*6|0;s=y+15|0;N=(305-y|0)>>>1;C=d+28|0;O=c[C>>2]|0;P=d+32|0;m=N+5|0;n=c[P>>2]|0;t=y+5+m|0;A=n>>>1;if(t>>>0>m>>>0){L=112;do{G=ab(L,A)|0;J=L>>>1;M=m;do{K=((M>>>1)+J&1)+1|0;b[O+(M+G<<1)>>1]=(K<<13|K<<9|K<<5|12)&65535;M=M+1|0;}while(M>>>0<t>>>0);L=L+1|0;}while(L>>>0<128);R=c[C>>2]|0;S=c[P>>2]|0}else{R=O;S=n}n=y+10|0;y=N+n|0;O=S>>>1;if(y>>>0>N>>>0){L=107;do{t=ab(L,O)|0;A=L>>>1;M=N;do{G=((M>>>1)+A&1)+1|0;b[R+(M+t<<1)>>1]=(G<<13|G<<10|G<<5|12)&65535;M=M+1|0;}while(M>>>0<y>>>0);L=L+1|0;}while(L>>>0<112);T=c[C>>2]|0;U=c[P>>2]|0}else{T=R;U=S}S=N+s|0;s=cs(S|0,-5|0)|0;R=s;s=U>>>1;if(F){L=107;do{y=ab(L,s)|0;O=L>>>1;M=R;do{t=((M>>>1)+O&1)+1|0;b[T+(M+y<<1)>>1]=(t<<13|t<<10|t<<5|12)&65535;M=M+1|0;}while(M>>>0<S>>>0);L=L+1|0;}while(L>>>0<128);V=c[C>>2]|0;W=c[P>>2]|0}else{V=T;W=U}U=m+n|0;n=W>>>1;if(U>>>0>m>>>0){T=n<<7;L=m;do{S=(L>>>1&1)+1|0;b[V+(L+T<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;L=L+1|0;}while(L>>>0<U>>>0);L=n*129|0;T=m;do{S=(T>>>1&1)+1|0;b[V+(T+L<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;T=T+1|0;}while(T>>>0<U>>>0);T=n*130|0;L=m;do{S=2-(L>>>1&1)|0;b[V+(L+T<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;L=L+1|0;}while(L>>>0<U>>>0);L=n*131|0;T=m;do{S=2-(T>>>1&1)|0;b[V+(T+L<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;T=T+1|0;}while(T>>>0<U>>>0);T=n*132|0;n=m;do{L=(n>>>1&1)+1|0;b[V+(n+T<<1)>>1]=(L<<13|L<<10|L<<5|12)&65535;n=n+1|0;}while(n>>>0<U>>>0);X=c[C>>2]|0;Y=c[P>>2]|0}else{X=V;Y=W}W=Y>>>1;Y=112;do{V=ab(Y,W)|0;P=Y>>>1;C=N;do{U=((C>>>1)+P&1)+1|0;b[X+(C+V<<1)>>1]=(U<<13|U<<10|U<<5|12)&65535;C=C+1|0;}while(C>>>0<m>>>0);Y=Y+1|0;}while(Y>>>0<133);iz(d,N+8|0,115,B,0);aIq(B)}B=c[494433]|0;if((B|0)==0){c[494433]=D;Z=D}else{Z=B}B=c[494434]|0;if((B|0)==0){c[494434]=E;_=E}else{_=B}g[172559]=+(Z>>>0>>>0)/+(_>>>0>>>0);_=c[(c[3118488]|0)+16>>2]|0;if((_|0)==0){z=0;i=e;return z|0}fi[_&255](c[3118440]|0);z=0;i=e;return z|0}_=d+52|0;L6831:do{switch(((a[_]&1)==0?v:10)|0){case 6:{c[d+48>>2]=0;a[_]=1;$=0;break};case 7:{a[_]=1;Z=c[u>>2]|0;B=c[Z+8>>2]|0;if(B>>>0>1){E=d+48|0;D=(E|0)==0;N=Z;Z=B;do{B=N+8|0;if((Z|0)!=0){Y=Z-1|0;c[B>>2]=Y;aIq(c[(c[N>>2]|0)+(Y*12|0)>>2]|0)}if(!D){c[E>>2]=c[(c[N>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]}N=c[u>>2]|0;Z=c[N+8>>2]|0;}while(Z>>>0>1)}z=iw(d,6)|0;i=e;return z|0};case 9:{a[d+53|0]=1;$=0;break};case 1:{Z=d+48|0;N=(c[Z>>2]|0)+1|0;if(N>>>0<(c[(c[d+44>>2]|0)+8>>2]|0)>>>0){c[Z>>2]=N;$=0;break L6831}else{c[Z>>2]=0;$=0;break L6831}break};case 3:{Z=d+48|0;N=(c[Z>>2]|0)+8|0;E=c[(c[d+44>>2]|0)+8>>2]|0;if(N>>>0<E>>>0){c[Z>>2]=N;$=0;break L6831}else{c[Z>>2]=E-1;$=0;break L6831}break};case 5:{E=c[u>>2]|0;Z=E+8|0;if((c[Z>>2]|0)>>>0<=1){$=0;break L6831}a[_]=1;N=d+48|0;D=c[Z>>2]|0;if((D|0)!=0){B=D-1|0;c[Z>>2]=B;aIq(c[(c[E>>2]|0)+(B*12|0)>>2]|0)}if((N|0)==0){$=0;break L6831}c[N>>2]=c[(c[E>>2]|0)+((c[Z>>2]|0)*12|0)+8>>2];$=0;break};case 0:{Z=d+48|0;E=c[Z>>2]|0;if((E|0)==0){c[Z>>2]=(c[(c[d+44>>2]|0)+8>>2]|0)-1;$=0;break L6831}else{c[Z>>2]=E-1;$=0;break L6831}break};case 4:{E=c[d+44>>2]|0;if((c[E+8>>2]|0)==0){z=0;i=e;return z|0}Z=d+48|0;N=c[Z>>2]|0;B=c[E>>2]|0;E=c[B+(N*12|0)>>2]|0;D=c[B+(N*12|0)+4>>2]|0;B=D-31|0;do{if(!(B>>>0<24&((B>>>0)%3|0|0)==0|(D|0)==28)){if((D-73|0)>>>0<4|(D|0)==78|(D|0)==79){break}if((D|0)==88|(D|0)==71|(D|0)==57|(D|0)==1){break}Y=w-31|0;m=(w|0)==28;if(Y>>>0<24&((Y>>>0)%3|0|0)==0|m){if(m){m=q|0;gz(m,x,E);ix(d+4180|0,h9(m,3)|0,m)}else{gz(d+4256+(((Y>>>0)/3|0)*4148|0)|0,x,E)}a[_]=1;Y=c[u>>2]|0;m=c[Y+8>>2]|0;if((m|0)==0){aa=0}else{X=c[(c[Y>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((X|0)==26){$=0;break L6831}else{aa=X}}X=(Z|0)==0;W=aa;C=Y;Y=m;while(1){m=C+8|0;if((Y|0)!=0){V=Y-1|0;c[m>>2]=V;aIq(c[(c[C>>2]|0)+(V*12|0)>>2]|0)}if(!X){c[Z>>2]=c[(c[C>>2]|0)+((c[m>>2]|0)*12|0)+8>>2]}m=c[u>>2]|0;V=c[m+8>>2]|0;if((V|0)==0){ac=W}else{ac=c[(c[m>>2]|0)+((V-1|0)*12|0)+4>>2]|0}if((ac|0)==26){$=0;break L6831}else{W=ac;C=m;Y=V}}}switch(w|0){case 74:{Y=4096;C=1725621;W=x;while(1){X=Y-1|0;if((X|0)==0){ad=5042;break}V=a[W]|0;a[C]=V;if(V<<24>>24==0){break}else{Y=X;C=C+1|0;W=W+1|0}}do{if((ad|0)==5042){a[C]=0;if((a[W]|0)==0){break}else{ae=W}do{ae=ae+1|0;}while((a[ae]|0)!=0)}}while(0);a[_]=1;W=c[u>>2]|0;C=c[W+8>>2]|0;if((C|0)==0){af=0}else{Y=c[(c[W>>2]|0)+((C-1|0)*12|0)+4>>2]|0;if((Y|0)==61){$=0;break L6831}else{af=Y}}Y=(Z|0)==0;X=af;V=W;W=C;while(1){C=V+8|0;if((W|0)!=0){m=W-1|0;c[C>>2]=m;aIq(c[(c[V>>2]|0)+(m*12|0)>>2]|0)}if(!Y){c[Z>>2]=c[(c[V>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]}C=c[u>>2]|0;m=c[C+8>>2]|0;if((m|0)==0){ag=X}else{ag=c[(c[C>>2]|0)+((m-1|0)*12|0)+4>>2]|0}if((ag|0)==61){$=0;break L6831}else{X=ag;V=C;W=m}}break};case 71:{W=r|0;gz(W,x,E);V=h|0;gd(1,0);fD[c[479936]&127]()|0;X=fD[c[479934]&127]()|0;if((X|0)!=0){Y=X-1|0;aIv(f|0,0,16);c[f>>2]=W;X=c[479935]|0;fA[X&63](Y,f)|0;ge(Y);bQ(V|0,512,713048,(Q=i,i=i+8|0,c[Q>>2]=W,Q)|0)|0;i=Q;if((a[1820736]&1)!=0){Y=c[494446]|0;X=(Y|0)!=0?Y:c[p>>2]|0;ei(X|0,727024,(Q=i,i=i+8|0,c[Q>>2]=V,Q)|0)|0;i=Q;X=c[494446]|0;Y=(X|0)!=0?X:c[p>>2]|0;a_(Y|0)|0}Y=c[492315]|0;X=Y+4|0;m=c[X>>2]|0;if(m>>>0>1){C=Y|0;P=1;U=m;while(1){m=c[(c[C>>2]|0)+(P<<2)>>2]|0;if((m|0)==0){ah=U}else{aIq(c[m+8>>2]|0);aIq(c[(c[C>>2]|0)+(P<<2)>>2]|0);c[(c[C>>2]|0)+(P<<2)>>2]=0;ah=c[X>>2]|0}m=P+1|0;if(m>>>0<ah>>>0){P=m;U=ah}else{break}}}c[X>>2]=1;U=Y+12|0;aIq(c[U>>2]|0);c[U>>2]=0;U=c[492315]|0;P=U+4|0;L6945:do{if((c[P>>2]|0)>>>0<(c[U+8>>2]|0)>>>0){C=aIp(12)|0;do{if((C|0)!=0){if((c[C-4>>2]&3|0)==0){break}aIv(C|0,0,12)}}while(0);c[C+4>>2]=0;c[C>>2]=180;m=dv(V|0)|0;n=c[P>>2]|0;c[C+8>>2]=m;m=U|0;c[(c[m>>2]|0)+(n<<2)>>2]=C;n=c[P>>2]|0;c[P>>2]=n+1;if(n>>>0>1){ai=n}else{break}while(1){n=ai>>>1;T=c[m>>2]|0;L=T+(n<<2)|0;S=c[L>>2]|0;R=c[T+(ai<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[S+4>>2]|0)>>>0){break L6945}c[L>>2]=R;c[(c[m>>2]|0)+(ai<<2)>>2]=S;if(ai>>>0>3){ai=n}else{break}}}}while(0);gf(W);gg();gd(0,0)}P=1977776;U=c[P+4>>2]|0;V=1977776;c[V>>2]=c[P>>2]|1;c[V+4>>2]=U;a[_]=1;U=c[u>>2]|0;V=c[U+8>>2]|0;if((V|0)==0){aj=0;ak=U;al=V}else{P=c[(c[U>>2]|0)+((V-1|0)*12|0)+4>>2]|0;if((P|0)==4){$=-1;break L6831}else{aj=P;ak=U;al=V}}while(1){V=ak+8|0;if((al|0)==0){am=0;an=ak;ao=ak|0}else{U=al-1|0;c[V>>2]=U;P=ak|0;aIq(c[(c[P>>2]|0)+(U*12|0)>>2]|0);am=c[V>>2]|0;an=c[u>>2]|0;ao=P}c[Z>>2]=c[(c[ao>>2]|0)+(am*12|0)+8>>2];P=c[an+8>>2]|0;if((P|0)==0){ap=aj}else{ap=c[(c[an>>2]|0)+((P-1|0)*12|0)+4>>2]|0}if((ap|0)==4){$=-1;break L6831}else{aj=ap;ak=an;al=P}}break};case 79:{W=4096;P=1811460;V=x;while(1){U=W-1|0;if((U|0)==0){ad=5056;break}Y=a[V]|0;a[P]=Y;if(Y<<24>>24==0){break}else{W=U;P=P+1|0;V=V+1|0}}do{if((ad|0)==5056){a[P]=0;if((a[V]|0)==0){break}else{aq=V}do{aq=aq+1|0;}while((a[aq]|0)!=0)}}while(0);a[_]=1;V=c[u>>2]|0;P=c[V+8>>2]|0;if((P|0)==0){ar=0}else{W=c[(c[V>>2]|0)+((P-1|0)*12|0)+4>>2]|0;if((W|0)==61){$=0;break L6831}else{ar=W}}W=(Z|0)==0;U=ar;Y=V;V=P;while(1){P=Y+8|0;if((V|0)!=0){X=V-1|0;c[P>>2]=X;aIq(c[(c[Y>>2]|0)+(X*12|0)>>2]|0)}if(!W){c[Z>>2]=c[(c[Y>>2]|0)+((c[P>>2]|0)*12|0)+8>>2]}P=c[u>>2]|0;X=c[P+8>>2]|0;if((X|0)==0){as=U}else{as=c[(c[P>>2]|0)+((X-1|0)*12|0)+4>>2]|0}if((as|0)==61){$=0;break L6831}else{U=as;Y=P;V=X}}break};case 73:{V=4096;Y=1815593;U=x;while(1){W=V-1|0;if((W|0)==0){ad=4981;break}X=a[U]|0;a[Y]=X;if(X<<24>>24==0){break}else{V=W;Y=Y+1|0;U=U+1|0}}do{if((ad|0)==4981){a[Y]=0;if((a[U]|0)==0){break}else{at=U}do{at=at+1|0;}while((a[at]|0)!=0)}}while(0);U=4096;Y=d+54|0;V=x;while(1){W=U-1|0;if((W|0)==0){ad=4986;break}X=a[V]|0;a[Y]=X;if(X<<24>>24==0){break}else{U=W;Y=Y+1|0;V=V+1|0}}do{if((ad|0)==4986){a[Y]=0;if((a[V]|0)==0){break}else{au=V}do{au=au+1|0;}while((a[au]|0)!=0)}}while(0);a[_]=1;V=c[u>>2]|0;Y=c[V+8>>2]|0;if((Y|0)==0){av=0}else{U=c[(c[V>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((U|0)==61){$=0;break L6831}else{av=U}}U=(Z|0)==0;W=av;X=V;V=Y;while(1){Y=X+8|0;if((V|0)!=0){P=V-1|0;c[Y>>2]=P;aIq(c[(c[X>>2]|0)+(P*12|0)>>2]|0)}if(!U){c[Z>>2]=c[(c[X>>2]|0)+((c[Y>>2]|0)*12|0)+8>>2]}Y=c[u>>2]|0;P=c[Y+8>>2]|0;if((P|0)==0){aw=W}else{aw=c[(c[Y>>2]|0)+((P-1|0)*12|0)+4>>2]|0}if((aw|0)==61){$=0;break L6831}else{W=aw;X=Y;V=P}}break};case 88:{gz(1778680,x,E);V=c[3118482]|0;if((V|0)!=0){X=V+24|0;W=V+12|0;U=c[W>>2]|0;if((c[X>>2]|0)==0){ax=U}else{P=0;Y=U;while(1){aIq(c[Y+(P*136|0)>>2]|0);aIq(c[Y+(P*136|0)+8>>2]|0);U=P+1|0;m=c[W>>2]|0;if(U>>>0<(c[X>>2]|0)>>>0){P=U;Y=m}else{ax=m;break}}}aIq(ax);Y=c[V+4>>2]|0;if((Y|0)!=0){fj[c[Y>>2]&511](c[V>>2]|0,0)}aIq(V)}Y=hQ()|0;c[3118482]=Y;if((Y|0)==0){Y=c[494446]|0;P=(Y|0)!=0?Y:c[p>>2]|0;a5(715168,45,1,P|0)|0;P=c[494446]|0;Y=(P|0)!=0?P:c[p>>2]|0;a_(Y|0)|0}a[_]=1;Y=c[u>>2]|0;P=c[Y+8>>2]|0;if((P|0)==0){ay=0}else{X=c[(c[Y>>2]|0)+((P-1|0)*12|0)+4>>2]|0;if((X|0)==60){$=0;break L6831}else{ay=X}}X=(Z|0)==0;W=ay;m=Y;Y=P;while(1){P=m+8|0;if((Y|0)!=0){U=Y-1|0;c[P>>2]=U;aIq(c[(c[m>>2]|0)+(U*12|0)>>2]|0)}if(!X){c[Z>>2]=c[(c[m>>2]|0)+((c[P>>2]|0)*12|0)+8>>2]}P=c[u>>2]|0;U=c[P+8>>2]|0;if((U|0)==0){az=W}else{az=c[(c[P>>2]|0)+((U-1|0)*12|0)+4>>2]|0}if((az|0)==60){$=0;break L6831}else{W=az;m=P;Y=U}}break};case 75:{Y=4096;m=1894514;W=x;while(1){X=Y-1|0;if((X|0)==0){ad=5028;break}V=a[W]|0;a[m]=V;if(V<<24>>24==0){break}else{Y=X;m=m+1|0;W=W+1|0}}do{if((ad|0)==5028){a[m]=0;if((a[W]|0)==0){break}else{aA=W}do{aA=aA+1|0;}while((a[aA]|0)!=0)}}while(0);a[_]=1;W=c[u>>2]|0;m=c[W+8>>2]|0;if((m|0)==0){aB=0}else{Y=c[(c[W>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((Y|0)==61){$=0;break L6831}else{aB=Y}}Y=(Z|0)==0;X=aB;V=W;W=m;while(1){m=V+8|0;if((W|0)!=0){U=W-1|0;c[m>>2]=U;aIq(c[(c[V>>2]|0)+(U*12|0)>>2]|0)}if(!Y){c[Z>>2]=c[(c[V>>2]|0)+((c[m>>2]|0)*12|0)+8>>2]}m=c[u>>2]|0;U=c[m+8>>2]|0;if((U|0)==0){aC=X}else{aC=c[(c[m>>2]|0)+((U-1|0)*12|0)+4>>2]|0}if((aC|0)==61){$=0;break L6831}else{X=aC;V=m;W=U}}break};case 57:{a[_]=1;W=c[u>>2]|0;V=c[W+8>>2]|0;if((V|0)==0){aD=0}else{X=c[(c[W>>2]|0)+((V-1|0)*12|0)+4>>2]|0;if((X|0)==4){$=0;break L6831}else{aD=X}}X=(Z|0)==0;Y=aD;U=W;W=V;while(1){V=U+8|0;if((W|0)!=0){m=W-1|0;c[V>>2]=m;aIq(c[(c[U>>2]|0)+(m*12|0)>>2]|0)}if(!X){c[Z>>2]=c[(c[U>>2]|0)+((c[V>>2]|0)*12|0)+8>>2]}V=c[u>>2]|0;m=c[V+8>>2]|0;if((m|0)==0){aE=Y}else{aE=c[(c[V>>2]|0)+((m-1|0)*12|0)+4>>2]|0}if((aE|0)==4){$=0;break L6831}else{Y=aE;U=V;W=m}}break};case 76:{W=4096;U=1890418;Y=x;while(1){X=W-1|0;if((X|0)==0){ad=5e3;break}m=a[Y]|0;a[U]=m;if(m<<24>>24==0){break}else{W=X;U=U+1|0;Y=Y+1|0}}do{if((ad|0)==5e3){a[U]=0;if((a[Y]|0)==0){break}else{aF=Y}do{aF=aF+1|0;}while((a[aF]|0)!=0)}}while(0);a[_]=1;Y=c[u>>2]|0;U=c[Y+8>>2]|0;if((U|0)==0){aG=0}else{W=c[(c[Y>>2]|0)+((U-1|0)*12|0)+4>>2]|0;if((W|0)==61){$=0;break L6831}else{aG=W}}W=(Z|0)==0;X=aG;m=Y;Y=U;while(1){U=m+8|0;if((Y|0)!=0){V=Y-1|0;c[U>>2]=V;aIq(c[(c[m>>2]|0)+(V*12|0)>>2]|0)}if(!W){c[Z>>2]=c[(c[m>>2]|0)+((c[U>>2]|0)*12|0)+8>>2]}U=c[u>>2]|0;V=c[U+8>>2]|0;if((V|0)==0){aH=X}else{aH=c[(c[U>>2]|0)+((V-1|0)*12|0)+4>>2]|0}if((aH|0)==61){$=0;break L6831}else{X=aH;m=U;Y=V}}break};case 78:{Y=4096;m=1898610;X=x;while(1){W=Y-1|0;if((W|0)==0){ad=5014;break}V=a[X]|0;a[m]=V;if(V<<24>>24==0){break}else{Y=W;m=m+1|0;X=X+1|0}}do{if((ad|0)==5014){a[m]=0;if((a[X]|0)==0){break}else{aI=X}do{aI=aI+1|0;}while((a[aI]|0)!=0)}}while(0);a[_]=1;X=c[u>>2]|0;m=c[X+8>>2]|0;if((m|0)==0){aJ=0}else{Y=c[(c[X>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((Y|0)==61){$=0;break L6831}else{aJ=Y}}Y=(Z|0)==0;W=aJ;V=X;X=m;while(1){m=V+8|0;if((X|0)!=0){U=X-1|0;c[m>>2]=U;aIq(c[(c[V>>2]|0)+(U*12|0)>>2]|0)}if(!Y){c[Z>>2]=c[(c[V>>2]|0)+((c[m>>2]|0)*12|0)+8>>2]}m=c[u>>2]|0;U=c[m+8>>2]|0;if((U|0)==0){aK=W}else{aK=c[(c[m>>2]|0)+((U-1|0)*12|0)+4>>2]|0}if((aK|0)==61){$=0;break L6831}else{W=aK;V=m;X=U}}break};case 56:{X=c[c[(c[240672]|0)+113712>>2]>>2]|0;V=c[X+(N*12|0)>>2]|0;gW(131072,c[X+(N*12|0)+4>>2]|0)|0;X=(V|0)==0;a[(c[240672]|0)+4176|0]=X&1;L7129:do{if(X){a[1857650]=0}else{W=4096;Y=1857650;U=V;while(1){m=W-1|0;if((m|0)==0){break}P=a[U]|0;a[Y]=P;if(P<<24>>24==0){break L7129}else{W=m;Y=Y+1|0;U=U+1|0}}a[Y]=0;if((a[U]|0)==0){break}else{aL=U}do{aL=aL+1|0;}while((a[aL]|0)!=0)}}while(0);if((a[1820736]&1)!=0){V=c[494446]|0;X=(V|0)!=0?V:c[p>>2]|0;a5(701192,35,1,X|0)|0;X=c[494446]|0;V=(X|0)!=0?X:c[p>>2]|0;a_(V|0)|0}a[_]=1;V=c[u>>2]|0;X=c[V+8>>2]|0;if((X|0)==0){aM=0;aN=V;aO=X}else{U=c[(c[V>>2]|0)+((X-1|0)*12|0)+4>>2]|0;if((U|0)==4){$=-1;break L6831}else{aM=U;aN=V;aO=X}}while(1){X=aN+8|0;if((aO|0)==0){aP=0;aQ=aN;aR=aN|0}else{V=aO-1|0;c[X>>2]=V;U=aN|0;aIq(c[(c[U>>2]|0)+(V*12|0)>>2]|0);aP=c[X>>2]|0;aQ=c[u>>2]|0;aR=U}c[Z>>2]=c[(c[aR>>2]|0)+(aP*12|0)+8>>2];U=c[aQ+8>>2]|0;if((U|0)==0){aS=aM}else{aS=c[(c[aQ>>2]|0)+((U-1|0)*12|0)+4>>2]|0}if((aS|0)==4){$=-1;break L6831}else{aM=aS;aN=aQ;aO=U}}break};default:{gz(1857650,x,E);U=1977776;X=c[U+4>>2]|0;V=1977776;c[V>>2]=c[U>>2]|2;c[V+4>>2]=X;a[_]=1;X=c[u>>2]|0;V=c[X+8>>2]|0;if((V|0)==0){aT=0;aU=X;aV=V;ad=5070}else{U=c[(c[X>>2]|0)+((V-1|0)*12|0)+4>>2]|0;if((U|0)!=4){aT=U;aU=X;aV=V;ad=5070}}if((ad|0)==5070){while(1){ad=0;V=aU+8|0;if((aV|0)==0){aW=0;aX=aU;aY=aU|0}else{X=aV-1|0;c[V>>2]=X;U=aU|0;aIq(c[(c[U>>2]|0)+(X*12|0)>>2]|0);aW=c[V>>2]|0;aX=c[u>>2]|0;aY=U}c[Z>>2]=c[(c[aY>>2]|0)+(aW*12|0)+8>>2];U=c[aX+8>>2]|0;if((U|0)==0){aZ=aT}else{aZ=c[(c[aX>>2]|0)+((U-1|0)*12|0)+4>>2]|0}if((aZ|0)==4){break}else{aT=aZ;aU=aX;aV=U;ad=5070}}}a[d+53|0]=1;$=-1;break L6831}}}}while(0);N=o|0;gz(N,x,E);B=c[u>>2]|0;U=c[Z>>2]|0;if((B|0)!=0){V=B+8|0;X=B+4|0;Y=c[X>>2]|0;if((c[V>>2]|0)>>>0<Y>>>0){a$=B|0}else{W=(Y<<1)+2|0;c[X>>2]=W;X=B|0;c[X>>2]=aIr(c[X>>2]|0,W*12|0)|0;a$=X}X=dv(N|0)|0;c[(c[a$>>2]|0)+((c[V>>2]|0)*12|0)>>2]=X;c[(c[a$>>2]|0)+((c[V>>2]|0)*12|0)+4>>2]=D;c[(c[a$>>2]|0)+((c[V>>2]|0)*12|0)+8>>2]=U;c[V>>2]=(c[V>>2]|0)+1}c[Z>>2]=0;a[_]=1;$=0;break};case 2:{V=d+48|0;U=c[V>>2]|0;if(U>>>0>8){c[V>>2]=U-8;$=0;break L6831}else{c[V>>2]=0;$=0;break L6831}break};default:{$=0}}}while(0);a$=c[u>>2]|0;u=c[a$+8>>2]|0;if((u|0)==0){a0=w;a1=x}else{x=u-1|0;u=c[a$>>2]|0;a0=c[u+(x*12|0)+4>>2]|0;a1=c[u+(x*12|0)>>2]|0}L7168:do{if((a[_]&1)!=0){do{if((a0|0)!=1){x=a0-31|0;if(x>>>0<24&((x>>>0)%3|0|0)==0|(a0|0)==28){break}if((a0-73|0)>>>0<4|(a0|0)==78|(a0|0)==79){break}if(!((a0|0)==88|(a0|0)==71|(a0|0)==57|(a0|0)==56)){break L7168}}}while(0);a[_]=0;Z=d+44|0;D=c[Z>>2]|0;E=D+8|0;if((c[E>>2]|0)!=0){x=D|0;D=0;do{aIq(c[(c[x>>2]|0)+(D*12|0)>>2]|0);D=D+1|0;}while(D>>>0<(c[E>>2]|0)>>>0)}c[E>>2]=0;L7180:do{if((a0|0)==56){D=k|0;x=l|0;u=d+113712|0;a$=c[u>>2]|0;w=c[a$+4>>2]|0;if((w|0)==0){break}else{a2=0;a3=a$}while(1){a$=c[a3>>2]|0;o=c[a$+(a2*12|0)>>2]|0;ad=c[a$+(a2*12|0)+8>>2]|0;L7184:do{if((o|0)==0){a$=4096;aV=D;aX=ad;while(1){aU=a$-1|0;if((aU|0)==0){break}aZ=a[aX]|0;a[aV]=aZ;if(aZ<<24>>24==0){break L7184}else{a$=aU;aV=aV+1|0;aX=aX+1|0}}a[aV]=0;if((a[aX]|0)==0){break}else{a4=aX}do{a4=a4+1|0;}while((a[a4]|0)!=0)}else{aX=ck(o|0,47)|0;gA(x,(aX|0)==0?o:aX+1|0,14317944);bQ(D|0,4096,696840,(Q=i,i=i+16|0,c[Q>>2]=x,c[Q+8>>2]=ad,Q)|0)|0;i=Q}}while(0);ad=c[Z>>2]|0;if((ad|0)!=0){o=ad+8|0;aX=ad+4|0;aV=c[aX>>2]|0;if((c[o>>2]|0)>>>0<aV>>>0){a6=ad|0}else{a$=(aV<<1)+2|0;c[aX>>2]=a$;aX=ad|0;c[aX>>2]=aIr(c[aX>>2]|0,a$*12|0)|0;a6=aX}aX=dv(D|0)|0;c[(c[a6>>2]|0)+((c[o>>2]|0)*12|0)>>2]=aX;c[(c[a6>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=0;c[(c[a6>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1}o=a2+1|0;if(o>>>0>=w>>>0){break L7180}a2=o;a3=c[u>>2]|0}}else{u=c[Z>>2]|0;w=j|0;if((a[a1]|0)==0){if((u|0)==0){break}D=u+8|0;x=u+4|0;o=c[x>>2]|0;if((c[D>>2]|0)>>>0<o>>>0){a7=u|0}else{aX=(o<<1)+2|0;c[x>>2]=aX;x=u|0;c[x>>2]=aIr(c[x>>2]|0,aX*12|0)|0;a7=x}x=dv(698072)|0;c[(c[a7>>2]|0)+((c[D>>2]|0)*12|0)>>2]=x;c[(c[a7>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=a0;c[(c[a7>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;break}do{if((a0|0)==57){a8=14317944}else if((a0|0)==28){a8=697800}else{D=a0-31|0;if(D>>>0<24&((D>>>0)%3|0|0)==0){a8=697488;break}if((a0|0)==88){a8=697288;break}if((a0-73|0)>>>0<4|(a0|0)==78|(a0|0)==79){a8=14317944;break}D=c[d+4168>>2]|0;if((D|0)==0){a8=1915616;break}if((a[D]|0)==0){a[w]=0;a8=w;break}else{bQ(w|0,1024,697112,(Q=i,i=i+8|0,c[Q>>2]=D,Q)|0)|0;i=Q;a8=w;break}}}while(0);w=gy(a1,a8,1)|0;if((w|0)==0){break}D=w|0;x=w+4|0;dm(c[D>>2]|0,c[x>>2]|0,8,32);aX=(a0-73|0)>>>0<4|(a0|0)==78|(a0|0)==79;o=(u|0)==0;if(!(o|aX^1)){a$=u+8|0;ad=u+4|0;aV=c[ad>>2]|0;if((c[a$>>2]|0)>>>0<aV>>>0){a9=u|0}else{aU=(aV<<1)+2|0;c[ad>>2]=aU;ad=u|0;c[ad>>2]=aIr(c[ad>>2]|0,aU*12|0)|0;a9=ad}ad=dv(696936)|0;c[(c[a9>>2]|0)+((c[a$>>2]|0)*12|0)>>2]=ad;c[(c[a9>>2]|0)+((c[a$>>2]|0)*12|0)+4>>2]=3;c[(c[a9>>2]|0)+((c[a$>>2]|0)*12|0)+8>>2]=0;c[a$>>2]=(c[a$>>2]|0)+1}a$=c[x>>2]|0;do{if((a$|0)==0){ba=c[D>>2]|0}else{ad=u+8|0;aU=u+4|0;aV=u|0;if(aX){aZ=0;aT=a$;while(1){aW=c[D>>2]|0;do{if((a[aW+(aZ<<3)+4|0]&1)==0){bb=aT}else{aY=c[aW+(aZ<<3)>>2]|0;if((a[a1]|0)==0){bc=aY}else{aO=ck(aY|0,47)|0;bc=(aO|0)==0?aY:aO+1|0}if(o){bb=aT;break}aO=c[aU>>2]|0;if((c[ad>>2]|0)>>>0>=aO>>>0){aY=(aO<<1)+2|0;c[aU>>2]=aY;c[aV>>2]=aIr(c[aV>>2]|0,aY*12|0)|0}aY=dv(bc|0)|0;c[(c[aV>>2]|0)+((c[ad>>2]|0)*12|0)>>2]=aY;c[(c[aV>>2]|0)+((c[ad>>2]|0)*12|0)+4>>2]=a0;c[(c[aV>>2]|0)+((c[ad>>2]|0)*12|0)+8>>2]=0;c[ad>>2]=(c[ad>>2]|0)+1;bb=c[x>>2]|0}}while(0);aW=aZ+1|0;if(aW>>>0<bb>>>0){aZ=aW;aT=bb}else{bd=bb;break}}}else{aT=0;aZ=a$;while(1){aW=c[D>>2]|0;aY=a[aW+(aT<<3)+4|0]|0;aO=c[aW+(aT<<3)>>2]|0;if((a[a1]|0)==0){be=aO}else{aW=ck(aO|0,47)|0;be=(aW|0)==0?aO:aW+1|0}aW=(aY&1)!=0?a0:0;if(o){bf=aZ}else{aY=c[aU>>2]|0;if((c[ad>>2]|0)>>>0>=aY>>>0){aO=(aY<<1)+2|0;c[aU>>2]=aO;c[aV>>2]=aIr(c[aV>>2]|0,aO*12|0)|0}aO=dv(be|0)|0;c[(c[aV>>2]|0)+((c[ad>>2]|0)*12|0)>>2]=aO;c[(c[aV>>2]|0)+((c[ad>>2]|0)*12|0)+4>>2]=aW;c[(c[aV>>2]|0)+((c[ad>>2]|0)*12|0)+8>>2]=0;c[ad>>2]=(c[ad>>2]|0)+1;bf=c[x>>2]|0}aW=aT+1|0;if(aW>>>0<bf>>>0){aT=aW;aZ=bf}else{bd=bf;break}}}aZ=c[D>>2]|0;if((bd|0)==0){ba=aZ;break}else{bg=0;bh=aZ}while(1){aIq(c[bh+(bg<<3)>>2]|0);aZ=bg+1|0;aT=c[D>>2]|0;if(aZ>>>0<(c[x>>2]|0)>>>0){bg=aZ;bh=aT}else{ba=aT;break}}}}while(0);aIq(ba);aIq(w)}}while(0);E=d+48|0;x=c[(c[Z>>2]|0)+8>>2]|0;D=(x|0)==0;if(!((c[E>>2]|0)>>>0<x>>>0|D)){c[E>>2]=x-1;break}if(!D){break}c[E>>2]=0}}while(0);iy(d);z=$;i=e;return z|0}function iw(b,d){b=b|0;d=d|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0.0,U=0.0,V=0.0,W=0.0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0.0,aS=0,aT=0.0,aU=0,aV=0.0,aW=0,aX=0,aY=0,aZ=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a6=0,a7=0,a8=0.0,a9=0,ba=0.0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bL=0,bM=0,bN=0,bO=0,bP=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0;f=i;i=i+13184|0;j=f|0;k=f+128|0;l=f+192|0;m=f+256|0;n=f+320|0;o=f+384|0;q=f+448|0;r=f+512|0;s=f+4608|0;t=f+4672|0;u=f+8768|0;v=f+9024|0;w=f+9088|0;c[b+32>>2]=640;do{if((d|0)==6){x=0;y=0}else{z=c[b+48>>2]|0;A=c[c[b+44>>2]>>2]|0;B=c[A+(z*12|0)>>2]|0;C=c[A+(z*12|0)+4>>2]|0;if((C|0)==57){x=14317944;y=57;break}else if((C|0)==71){x=b+54|0;y=71;break}else{x=B;y=C;break}}}while(0);C=b+40|0;B=c[C>>2]|0;z=B+8|0;A=c[z>>2]|0;if((A|0)==0){D=0}else{D=c[(c[B>>2]|0)+((A-1|0)*12|0)+4>>2]|0}E=b+52|0;G=(a[E]&1)==0?d:10;L7277:do{switch(G|0){case 2:case 3:case 4:case 8:{d=(G|0)==4;if((y|0)==55&d){H=b+54|0;I=b+48|0;J=c[I>>2]|0;if((B|0)!=0){K=B+4|0;L=c[K>>2]|0;if(A>>>0<L>>>0){M=B|0}else{N=(L<<1)+2|0;c[K>>2]=N;K=B|0;c[K>>2]=aIr(c[K>>2]|0,N*12|0)|0;M=K}K=dv(H|0)|0;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)>>2]=K;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=1;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=J;c[z>>2]=(c[z>>2]|0)+1}c[I>>2]=0;a[E]=1;break L7277}do{if((y|0)==56){if(!d){break L7277}}else{if(((y-73|0)>>>0<4|(y|0)==78|(y|0)==79)&d){break}L7292:do{switch(y|0){case 69:case 62:case 61:case 59:case 58:case 26:case 5:case 4:case 60:case 71:case 57:{if(!d){break L7292}I=b+48|0;J=c[I>>2]|0;if((B|0)!=0){K=B+4|0;H=c[K>>2]|0;if(A>>>0<H>>>0){O=B|0}else{N=(H<<1)+2|0;c[K>>2]=N;K=B|0;c[K>>2]=aIr(c[K>>2]|0,N*12|0)|0;O=K}K=dv(x|0)|0;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)>>2]=K;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=J;c[z>>2]=(c[z>>2]|0)+1}c[I>>2]=0;a[E]=1;break L7277;break};default:{if(!((y|0)==12&d)){break L7292}I=c[b+48>>2]|0;if((B|0)!=0){J=B+4|0;K=c[J>>2]|0;if(A>>>0<K>>>0){P=B|0}else{N=(K<<1)+2|0;c[J>>2]=N;J=B|0;c[J>>2]=aIr(c[J>>2]|0,N*12|0)|0;P=J}J=dv(14317944)|0;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)>>2]=J;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=12;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=I;c[z>>2]=(c[z>>2]|0)+1}fj[c[(c[3118437]|0)+44>>2]&511](c[3118440]|0,1977724);g[172559]=+((c[494433]|0)>>>0>>>0)/+((c[494434]|0)>>>0>>>0);c[429354]=7;I=c[(c[3118488]|0)+12>>2]|0;if((I|0)==0){break L7277}fj[I&511](c[3118440]|0,7);break L7277}}}while(0);I=b+113708|0;J=c[I>>2]|0;if((y-6|0)>>>0<20){switch(y|0){case 16:{if((G|0)==8){a[1717392]=1;break L7277}else if((G|0)==2|(G|0)==3|(G|0)==4){a[1717392]=a[1717392]&1^1;break L7277}else{break L7277}break};case 11:{do{if((G|0)==8){c[429354]=4}else if((G|0)==2){N=c[429354]|0;if((N|0)==0){break}c[429354]=N-1}else if((G|0)==3){N=c[429354]|0;if(N>>>0>=7){break}c[429354]=N+1}}while(0);N=c[(c[3118488]|0)+12>>2]|0;if((N|0)==0){break L7277}fj[N&511](c[3118440]|0,c[429354]|0);break L7277;break};case 15:{if((G|0)==3){N=c[494437]|0;if(N>>>0<3){K=N+1|0;c[494437]=K;Q=K}else{Q=N}fj[c[(c[3118437]|0)+40>>2]&511](c[3118440]|0,Q);break L7277}else if((G|0)==2){N=c[494437]|0;if((N|0)==0){R=0}else{K=N-1|0;c[494437]=K;R=K}fj[c[(c[3118437]|0)+40>>2]&511](c[3118440]|0,R);break L7277}else if((G|0)==8){g[435525]=.004999999888241291;a[1742097]=1;fj[c[(c[3118437]|0)+40>>2]&511](c[3118440]|0,c[494437]|0);break L7277}else{break L7277}break};case 18:{if((G|0)==2){K=c[429350]|0;if((K|0)==0){break L7277}c[429350]=K-1;break L7277}else if((G|0)==3|(G|0)==4){K=c[429350]|0;if(K>>>0>=3){break L7277}c[429350]=K+1;break L7277}else if((G|0)==8){c[429350]=0;break L7277}else{break L7277}break};case 7:{if((G|0)==8){S=1}else{S=a[1717404]&1^1}a[1717404]=S;K=c[c[3118488]>>2]|0;if((K|0)==0){break L7277}fF[K&127](c[3118440]|0,1,(S&1)!=0);break L7277;break};case 14:{if(!d){break L7277}ga((a[1717376]&1)==0);break L7277;break};case 23:{if((G|0)==8){a[1717406]=1;break L7277}else if((G|0)==2|(G|0)==3|(G|0)==4){a[1717406]=a[1717406]&1^1;break L7277}else{break L7277}break};case 21:case 22:{K=(y|0)==21?1717368:1717372;T=+g[K>>2];if((G|0)==8){g[K>>2]=3.0;U=3.0}else if((G|0)==2){V=T+-1.0;g[K>>2]=V;U=V}else if((G|0)==3){V=T+1.0;g[K>>2]=V;U=V}else{U=T}V=+bK(+U);W=V>1.0?V:1.0;g[K>>2]=W;if(T==W){break L7277}if((a[1717376]&1)!=0){break L7277}ga(0);break L7277;break};case 24:{if((G|0)==8){K=1969088;c[K>>2]=0;c[K+4>>2]=0;break L7277}else if((G|0)!=4){break L7277}if((a[1725620]&1)!=0){break L7277}K=1969088;N=c[K>>2]|0;H=c[K+4>>2]|0;K=0;L=H>>>0>K>>>0|H>>>0==K>>>0&N>>>0>2048>>>0?2048:N;if(L>>>0<2){break L7277}else{X=0;Y=0;Z=0}do{N=1952704+(X<<3)|0;Z=aIF(c[N>>2]|0,c[N+4>>2]|0,Z,Y)|0;Y=F;X=X+1|0;}while(X>>>0<L>>>0);N=aIN(Z,Y,L,0)|0;W=1.0e6/(+(N>>>0)+ +(F|0)*4294967296.0);N=u|0;bQ(N|0,256,705576,(_=i,i=i+8|0,h[_>>3]=W,_)|0)|0;i=_;K=c[492315]|0;H=K+4|0;L7374:do{if((c[H>>2]|0)>>>0<(c[K+8>>2]|0)>>>0){$=aIp(12)|0;do{if(($|0)!=0){if((c[$-4>>2]&3|0)==0){break}aIv($|0,0,12)}}while(0);c[$+4>>2]=1;c[$>>2]=180;aa=dv(N|0)|0;ab=c[H>>2]|0;c[$+8>>2]=aa;aa=K|0;c[(c[aa>>2]|0)+(ab<<2)>>2]=$;ab=c[H>>2]|0;c[H>>2]=ab+1;if(ab>>>0>1){ac=ab}else{break}while(1){ab=ac>>>1;ad=c[aa>>2]|0;ae=ad+(ab<<2)|0;af=c[ae>>2]|0;ag=c[ad+(ac<<2)>>2]|0;if((c[ag+4>>2]|0)>>>0<=(c[af+4>>2]|0)>>>0){break L7374}c[ae>>2]=ag;c[(c[aa>>2]|0)+(ac<<2)>>2]=af;if(ac>>>0>3){ac=ab}else{break}}}}while(0);if((a[1820736]&1)!=0){H=c[494446]|0;K=(H|0)!=0?H:c[p>>2]|0;ei(K|0,727024,(_=i,i=i+8|0,c[_>>2]=N,_)|0)|0;i=_;K=c[494446]|0;H=(K|0)!=0?K:c[p>>2]|0;a_(H|0)|0}g[431404]=W;gD();T=+((c[433472]|0)>>>0>>>0)/+g[433474];h[239982]=T;h[239988]=T;fj[c[(c[3118437]|0)+8>>2]&511](c[3118440]|0,0);break L7277;break};case 10:{do{if((G|0)==8){a[1717413]=0}else{if((G-2|0)>>>0>=3){break}a[1717413]=a[1717413]&1^1}}while(0);N=c[(c[3118488]|0)+16>>2]|0;if((N|0)==0){break L7277}fi[N&255](c[3118440]|0);break L7277;break};case 17:{if((G|0)==8){a[1717393]=0;break L7277}else if((G|0)==2|(G|0)==3|(G|0)==4){a[1717393]=a[1717393]&1^1;break L7277}else{break L7277}break};case 20:{N=c[429349]|0;if((G|0)==8){c[429349]=1;ah=1}else if((G|0)==2){H=N-1|0;c[429349]=H;ah=H}else if((G|0)==3|(G|0)==4){H=N+1|0;c[429349]=H;ah=H}else{ah=N}H=ah>>>0<4?ah:4;K=H>>>0>1?H:1;c[429349]=K;H=c[3118437]|0;L=c[3118440]|0;if(!((N|0)!=(K|0)&(H|0)!=0&(L|0)!=0)){break L7277}fj[c[H+8>>2]&511](L,0);break L7277;break};case 9:{if((G|0)==2){L=c[494438]|0;if((L|0)==0){break L7277}c[494438]=L-1;L=c[(c[3118488]|0)+16>>2]|0;if((L|0)==0){break L7277}fi[L&255](c[3118440]|0);break L7277}else if((G|0)==8){c[494438]=0;L=c[(c[3118488]|0)+16>>2]|0;if((L|0)==0){break L7277}fi[L&255](c[3118440]|0);break L7277}else{if(!((G|0)==3&(c[494438]|0)==0)){break L7277}c[494438]=1;L=c[(c[3118488]|0)+16>>2]|0;if((L|0)==0){break L7277}fi[L&255](c[3118440]|0);break L7277}break};case 19:{if((G|0)==8){a[1717394]=0;break L7277}else if((G|0)==2|(G|0)==3|(G|0)==4){a[1717394]=a[1717394]&1^1;break L7277}else{break L7277}break};default:{break L7277}}}if((y-27|0)>>>0<28){L=w|0;H=y-31|0;K=y-32|0;N=y-33|0;if((y|0)==29){if(!((c[(c[3118437]|0)+20>>2]|0)!=0&d)){break L7277}if((a[1820736]&1)!=0){aa=c[494446]|0;$=(aa|0)!=0?aa:c[p>>2]|0;a5(724408,31,1,$|0)|0;$=c[494446]|0;aa=($|0)!=0?$:c[p>>2]|0;a_(aa|0)|0}aa=b+4252|0;$=c[aa>>2]|0;L7428:do{if(($|0)!=0){ab=3;af=0;while(1){ag=h9(b+4256+(af*4148|0)|0,3)|0;if(!((ag|0)==0|(ag|0)==2)){break L7428}if((ab|0)==3){ai=ag}else{if((ab|0)==(ag|0)){ai=ab}else{break L7428}}ag=af+1|0;if(ag>>>0<$>>>0){ab=ai;af=ag}else{break}}if((ai|0)==3){break}gz(L,(a[1725621]|0)!=0?1725621:1811460,(ai|0)==2?724368:724280);af=aIp(20)|0;if((af|0)==0){break L7277}if((c[af-4>>2]&3|0)!=0){aIv(af|0,0,20)}ab=af;af=q|0;ag=r|0;ae=s|0;ad=t|0;aj=j|0;bQ(aj|0,128,706248,(_=i,i=i+8|0,c[_>>2]=c[aa>>2],_)|0)|0;i=_;gS(ab,725192,aj);if((c[aa>>2]|0)!=0){ak=l|0;al=k|0;am=0;do{bQ(af|0,64,708344,(_=i,i=i+8|0,c[_>>2]=am,_)|0)|0;i=_;gS(ab,af,b+4256+(am*4148|0)|0);an=b+4256+(am*4148|0)+4136|0;if((c[an>>2]|0)!=0){bQ(af|0,64,707840,(_=i,i=i+8|0,c[_>>2]=am,_)|0)|0;i=_;gS(ab,af,(c[an>>2]|0)==1?729656:698704)}bQ(af|0,64,707088,(_=i,i=i+8|0,c[_>>2]=am,_)|0)|0;i=_;an=c[b+4256+(am*4148|0)+4140>>2]|0;if((an|0)==0){ao=696960}else if((an|0)==1){ao=696848}else if((an|0)==2){ao=696712}else if((an|0)==3){ao=696552}else{ao=696344}gS(ab,af,ao);an=b+4256+(am*4148|0)+4144|0;if((c[an>>2]|0)!=0){bQ(af|0,64,706624,(_=i,i=i+8|0,c[_>>2]=am,_)|0)|0;i=_;ap=c[an>>2]|0;bQ(aj|0,128,706248,(_=i,i=i+8|0,c[_>>2]=ap,_)|0)|0;i=_;gS(ab,af,aj)}bQ(ak|0,64,698424,(_=i,i=i+8|0,c[_>>2]=am,_)|0)|0;i=_;gS(ab,ak,(a[b+4256+(am*4148|0)+4132|0]&1)!=0?729656:698704);do{if((a[b+4256+(am*4148|0)+4104|0]&1)!=0){ap=c[b+4256+(am*4148|0)+4108>>2]|0;W=+g[b+4256+(am*4148|0)+4116>>2];an=c[b+4256+(am*4148|0)+4124>>2]|0;bQ(al|0,64,698080,(_=i,i=i+16|0,c[_>>2]=698328,c[_+8>>2]=am,_)|0)|0;i=_;if((ap|0)==1){aq=697120}else if((ap|0)==2){aq=697296}else if((ap|0)==0){aq=697496}else{aq=698512}gS(ab,al,aq);bQ(al|0,64,697888,(_=i,i=i+16|0,c[_>>2]=698328,c[_+8>>2]=am,_)|0)|0;i=_;if((ap|0)==1){bQ(aj|0,128,706248,(_=i,i=i+8|0,c[_>>2]=an,_)|0)|0;i=_;gS(ab,al,aj)}else{T=W;bQ(aj|0,128,692808,(_=i,i=i+8|0,h[_>>3]=T,_)|0)|0;i=_;gS(ab,al,aj)}an=c[b+4256+(am*4148|0)+4112>>2]|0;T=+g[b+4256+(am*4148|0)+4120>>2];ap=c[b+4256+(am*4148|0)+4128>>2]|0;bQ(al|0,64,698080,(_=i,i=i+16|0,c[_>>2]=698184,c[_+8>>2]=am,_)|0)|0;i=_;if((an|0)==1){ar=697120}else if((an|0)==0){ar=697496}else if((an|0)==2){ar=697296}else{ar=698512}gS(ab,al,ar);bQ(al|0,64,697888,(_=i,i=i+16|0,c[_>>2]=698184,c[_+8>>2]=am,_)|0)|0;i=_;if((an|0)==1){bQ(aj|0,128,706248,(_=i,i=i+8|0,c[_>>2]=ap,_)|0)|0;i=_;gS(ab,al,aj);break}else{W=T;bQ(aj|0,128,692808,(_=i,i=i+8|0,h[_>>3]=W,_)|0)|0;i=_;gS(ab,al,aj);break}}}while(0);am=am+1|0;}while(am>>>0<(c[aa>>2]|0)>>>0)}am=b+70624|0;do{if((c[am>>2]|0)!=0){aIv(ag|0,0,4096);al=4096;ak=ag;af=b+70628|0;while(1){ap=al-1|0;if((ap|0)==0){as=5348;break}an=a[af]|0;a[ak]=an;if(an<<24>>24==0){break}else{al=ap;ak=ak+1|0;af=af+1|0}}do{if((as|0)==5348){a[ak]=0;if((a[af]|0)==0){break}else{at=af}do{at=at+1|0;}while((a[at]|0)!=0)}}while(0);if((c[am>>2]|0)>>>0>1){af=1;do{ak=aIu(ag|0)|0;al=ak>>>0>4096?0:4096-ak|0;L7491:do{if((al|0)==0){au=706256;as=5355}else{ap=r+ak|0;do{if((al|0)==1){av=706256;aw=ap}else{an=r+(ak+1)|0;a[ap]=59;if((al|0)==2){av=706257;aw=an;break}a[an]=0;break L7491}}while(0);a[aw]=0;au=av;as=5355}}while(0);do{if((as|0)==5355){as=0;if((a[au]|0)==0){break}else{ax=au}do{ax=ax+1|0;}while((a[ax]|0)!=0)}}while(0);al=b+70628+(af*4168|0)|0;ak=aIu(ag|0)|0;ap=ak>>>0>4096?0:4096-ak|0;L7502:do{if((ap|0)==0){ay=al;as=5362}else{an=ap;az=r+ak|0;aA=al;while(1){aB=an-1|0;if((aB|0)==0){break}aC=a[aA]|0;a[az]=aC;if(aC<<24>>24==0){break L7502}else{an=aB;az=az+1|0;aA=aA+1|0}}a[az]=0;ay=aA;as=5362}}while(0);do{if((as|0)==5362){as=0;if((a[ay]|0)==0){break}else{aD=ay}do{aD=aD+1|0;}while((a[aD]|0)!=0)}}while(0);af=af+1|0;}while(af>>>0<(c[am>>2]|0)>>>0)}gS(ab,705888,ag);if((c[am>>2]|0)==0){break}else{aE=0}do{af=b+70628+(aE*4168|0)|0;gS(ab,af,b+70628+(aE*4168|0)+64|0);aA=b+70628+(aE*4168|0)+4160|0;if((c[aA>>2]|0)!=0){bQ(ae|0,64,705552,(_=i,i=i+8|0,c[_>>2]=af,_)|0)|0;i=_;gS(ab,ae,(c[aA>>2]|0)!=1?729656:698704)}bQ(ae|0,64,705144,(_=i,i=i+8|0,c[_>>2]=af,_)|0)|0;i=_;af=c[b+70628+(aE*4168|0)+4164>>2]|0;if((af|0)==1){aF=696848}else if((af|0)==2){aF=696712}else if((af|0)==3){aF=696552}else if((af|0)==0){aF=696960}else{aF=696344}gS(ab,ae,aF);aE=aE+1|0;}while(aE>>>0<(c[am>>2]|0)>>>0)}}while(0);am=b+109096|0;if((a[am]|0)!=0){gS(ab,704872,am)}am=b+113196|0;if((a[am]|0)!=0){gS(ab,704432,am)}am=b+103972|0;L7532:do{if((c[am>>2]|0)!=0){aIv(ad|0,0,4096);ae=4096;ag=ad;af=b+103976|0;while(1){aA=ae-1|0;if((aA|0)==0){as=5382;break}az=a[af]|0;a[ag]=az;if(az<<24>>24==0){break}else{ae=aA;ag=ag+1|0;af=af+1|0}}do{if((as|0)==5382){a[ag]=0;if((a[af]|0)==0){break}else{aG=af}do{aG=aG+1|0;}while((a[aG]|0)!=0)}}while(0);if((c[am>>2]|0)>>>0>1){af=1;do{ag=aIu(ad|0)|0;ae=ag>>>0>4096?0:4096-ag|0;L7545:do{if((ae|0)==0){aH=706256;as=5389}else{aA=t+ag|0;do{if((ae|0)==1){aI=706256;aJ=aA}else{az=t+(ag+1)|0;a[aA]=59;if((ae|0)==2){aI=706257;aJ=az;break}a[az]=0;break L7545}}while(0);a[aJ]=0;aH=aI;as=5389}}while(0);do{if((as|0)==5389){as=0;if((a[aH]|0)==0){break}else{aK=aH}do{aK=aK+1|0;}while((a[aK]|0)!=0)}}while(0);ae=b+103976+(af*80|0)|0;ag=aIu(ad|0)|0;aA=ag>>>0>4096?0:4096-ag|0;L7556:do{if((aA|0)==0){aL=ae;as=5396}else{az=aA;al=t+ag|0;ak=ae;while(1){ap=az-1|0;if((ap|0)==0){break}an=a[ak]|0;a[al]=an;if(an<<24>>24==0){break L7556}else{az=ap;al=al+1|0;ak=ak+1|0}}a[al]=0;aL=ak;as=5396}}while(0);do{if((as|0)==5396){as=0;if((a[aL]|0)==0){break}else{aM=aL}do{aM=aM+1|0;}while((a[aM]|0)!=0)}}while(0);af=af+1|0;}while(af>>>0<(c[am>>2]|0)>>>0)}gS(ab,704064,ad);if((c[am>>2]|0)==0){break}af=k|0;ak=l|0;al=m|0;ae=n|0;ag=o|0;aA=0;while(1){az=b+103976+(aA*80|0)|0;bQ(af|0,64,701864,(_=i,i=i+8|0,c[_>>2]=az,_)|0)|0;i=_;bQ(ak|0,64,701656,(_=i,i=i+8|0,c[_>>2]=az,_)|0)|0;i=_;bQ(al|0,64,701336,(_=i,i=i+8|0,c[_>>2]=az,_)|0)|0;i=_;bQ(ae|0,64,701128,(_=i,i=i+8|0,c[_>>2]=az,_)|0)|0;i=_;bQ(ag|0,64,700848,(_=i,i=i+8|0,c[_>>2]=az,_)|0)|0;i=_;switch(c[b+103976+(aA*80|0)+68>>2]|0){case 2:{aN=700240;break};case 3:{aN=699624;break};case 1:{aN=699192;break};case 4:{aN=698728;break};case 5:{aN=698576;break};case 0:{aN=700720;break};default:{aN=698512}}gS(ab,af,aN);bQ(aj|0,128,730104,(_=i,i=i+8|0,c[_>>2]=e[b+103976+(aA*80|0)+76>>1]|0,_)|0)|0;i=_;gS(ab,ae,aj);bQ(aj|0,128,730104,(_=i,i=i+8|0,c[_>>2]=e[b+103976+(aA*80|0)+78>>1]|0,_)|0)|0;i=_;gS(ab,ag,aj);az=c[b+103976+(aA*80|0)+72>>2]|0;if((az|0)==1){ap=c[b+103976+(aA*80|0)+64>>2]|0;bQ(aj|0,128,730104,(_=i,i=i+8|0,c[_>>2]=ap,_)|0)|0;i=_;gS(ab,ak,aj)}else if((az|0)==2){bQ(aj|0,128,706248,(_=i,i=i+8|0,c[_>>2]=1,_)|0)|0;i=_;gS(ab,al,aj)}else if((az|0)==3){bQ(aj|0,128,706248,(_=i,i=i+8|0,c[_>>2]=2,_)|0)|0;i=_;gS(ab,al,aj)}aA=aA+1|0;if(aA>>>0>=(c[am>>2]|0)>>>0){break L7532}}}}while(0);gT(ab,L)|0;gN(ab);ix(0,ai,L);break L7277}}while(0);L=h9(14317944,2)|0;ix(0,(L|0)==3?2:L,0);break L7277}else if((y|0)==30){do{if((G|0)==8){c[b+4252>>2]=0}else if((G|0)==2){L=b+4252|0;aa=c[L>>2]|0;if((aa|0)==0){break}c[L>>2]=aa-1}else if((G|0)==3|(G|0)==4){aa=b+4252|0;L=c[aa>>2]|0;if(L>>>0>=8){break}c[aa>>2]=L+1}}while(0);a[E]=1;break L7277}else if((y|0)==27){if((G|0)==8){a[1717404]=1;break L7277}else if((G|0)==2|(G|0)==3|(G|0)==4){a[1717404]=a[1717404]&1^1;break L7277}else{break L7277}}else{L=(y|0)==28;if(!(((H>>>0)%3|0|0)==0|L)){if(((K>>>0)%3|0|0)==0){aa=(K>>>0)/3|0;if((G|0)==2|(G|0)==3|(G|0)==4){$=b+4256+(aa*4148|0)+4136|0;c[$>>2]=(((c[$>>2]|0)+((G|0)==2?2:1)|0)>>>0)%3|0;break L7277}else if((G|0)==8){c[b+4256+(aa*4148|0)+4136>>2]=0;break L7277}else{break L7277}}if(((N>>>0)%3|0|0)!=0){break L7277}aa=(N>>>0)/3|0;if((G|0)==8){g[b+4256+(aa*4148|0)+4120>>2]=0.0;g[b+4256+(aa*4148|0)+4116>>2]=0.0;a[b+4256+(aa*4148|0)+4104|0]=0;break L7277}else if((G|0)==2|(G|0)==3|(G|0)==4){$=b+4256+(aa*4148|0)+4116|0;am=((~~+g[$>>2]+((G|0)==2?5:1)|0)>>>0)%6|0;a[b+4256+(aa*4148|0)+4104|0]=(am|0)!=0|0;W=+(am>>>0>>>0);g[b+4256+(aa*4148|0)+4120>>2]=W;g[$>>2]=W;break L7277}else{break L7277}}if(L){aO=b+4256+(((H>>>0)/3|0)*4148|0)|0}else{aO=0}if((G|0)==8){if((aO|0)==0){break L7277}a[aO|0]=0;break L7277}else if((G|0)!=4){break L7277}L=b+48|0;$=c[L>>2]|0;if((B|0)!=0){aa=B+4|0;am=c[aa>>2]|0;if(A>>>0<am>>>0){aP=B|0}else{aj=(am<<1)+2|0;c[aa>>2]=aj;aa=B|0;c[aa>>2]=aIr(c[aa>>2]|0,aj*12|0)|0;aP=aa}aa=dv(1725621)|0;c[(c[aP>>2]|0)+((c[z>>2]|0)*12|0)>>2]=aa;c[(c[aP>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[aP>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=$;c[z>>2]=(c[z>>2]|0)+1}c[L>>2]=0;a[E]=1;break L7277}}if(y>>>0>65535){L=y-65536|0;if((G|0)==2){$=c[479954]|0;aa=c[$+4100>>2]|0;aj=aa+(L<<4)+12|0;am=c[(c[aa+(L<<4)+8>>2]|0)+4>>2]|0;c[aj>>2]=(((c[aj>>2]|0)-1+am|0)>>>0)%(am>>>0)|0;a[$+4108|0]=1;break L7277}else if((G|0)==3|(G|0)==4){$=c[479954]|0;am=c[$+4100>>2]|0;aj=am+(L<<4)+12|0;c[aj>>2]=(((c[aj>>2]|0)+1|0)>>>0)%((c[(c[am+(L<<4)+8>>2]|0)+4>>2]|0)>>>0)|0;a[$+4108|0]=1;break L7277}else if((G|0)==8){$=c[479954]|0;c[(c[$+4100>>2]|0)+(L<<4)+12>>2]=0;a[$+4108|0]=1;break L7277}else{break L7277}}L7634:do{switch(y|0){case 90:{if((G|0)==2){W=+g[445695]+-.009999999776482582;g[445695]=W;aQ=1;aR=W;as=5544}else if((G|0)==3|(G|0)==4){W=+g[445695]+.009999999776482582;g[445695]=W;aQ=1;aR=W;as=5544}else if((G|0)==8){g[445695]=1.0;aS=1;aT=1.0}else{aQ=0;aR=+g[445695];as=5544}do{if((as|0)==5544){if(aR<.009999999776482582){g[445695]=.009999999776482582;aS=aQ;aT=.009999999776482582;break}if(aR<=2.0){aS=aQ;aT=aR;break}g[445695]=2.0;aS=aQ;aT=2.0}}while(0);ab=c[3118482]|0;if(!(aS&(ab|0)!=0)){break L7277}hP(ab,aT);break L7277;break};case 84:{if((G|0)==8|(G|0)==2){ab=1977776;$=c[ab+4>>2]|0;L=1977776;c[L>>2]=c[ab>>2]&-257;c[L+4>>2]=$;break L7277}else if((G|0)==3){$=1977776;L=c[$+4>>2]|0;ab=1977776;c[ab>>2]=c[$>>2]|256;c[ab+4>>2]=L;break L7277}else{break L7277}break};case 80:{if(!d){break L7277}gb();L=1977776;ab=c[L+4>>2]|0;$=1977776;c[$>>2]=c[L>>2]|1;c[$+4>>2]=ab;aU=-1;i=f;return aU|0};case 81:{if((G|0)==8){a[1919865]=0;break L7277}else{a[1919865]=a[1919865]&1^1;break L7277}break};case 82:{if((G|0)==3){W=+g[435525];if(W<.2){g[435525]=W+.001}a[1742097]=1;break L7277}else if((G|0)==8){g[435525]=.004999999888241291;a[1742097]=1;break L7277}else if((G|0)==2){W=+g[435525];if(W>0.0){T=W+-.001;g[435525]=T;aV=T}else{aV=W}if(aV<5.0e-4){a[1742097]=0;g[435525]=0.0;break L7277}else{a[1742097]=1;break L7277}}else{break L7277}break};case 93:{ab=1820740+(J<<2)|0;$=c[ab>>2]|0;L=0;while(1){if(L>>>0>=8){aW=0;break}if(($|0)==(c[6136+(L<<2)>>2]|0)){aW=L;break}else{L=L+1|0}}if((G|0)==2){aX=c[6136+((aW+7&7)<<2)>>2]|0}else if((G|0)==3|(G|0)==4){aX=c[6136+((aW+1&7)<<2)>>2]|0}else if((G|0)==8){aX=1}else{break L7277}c[ab>>2]=aX;fj[c[241024]&511](J,aX);break L7277;break};case 87:{if(!d){break L7277}L=1977776;$=c[L+4>>2]|0;am=1977776;c[am>>2]=c[L>>2]&-2;c[am+4>>2]=$;aU=-1;i=f;return aU|0};case 88:{if((G|0)==4){$=b+48|0;am=c[$>>2]|0;if((B|0)!=0){L=B+4|0;aj=c[L>>2]|0;if(A>>>0<aj>>>0){aY=B|0}else{aa=(aj<<1)+2|0;c[L>>2]=aa;L=B|0;c[L>>2]=aIr(c[L>>2]|0,aa*12|0)|0;aY=L}L=dv(1898610)|0;c[(c[aY>>2]|0)+((c[z>>2]|0)*12|0)>>2]=L;c[(c[aY>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=88;c[(c[aY>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=am;c[z>>2]=(c[z>>2]|0)+1}c[$>>2]=0;a[E]=1;break L7277}else if((G|0)!=8){break L7277}$=c[3118482]|0;if(($|0)!=0){am=$+24|0;L=$+12|0;aa=c[L>>2]|0;if((c[am>>2]|0)==0){aZ=aa}else{aj=0;ad=aa;while(1){aIq(c[ad+(aj*136|0)>>2]|0);aIq(c[ad+(aj*136|0)+8>>2]|0);aa=aj+1|0;aA=c[L>>2]|0;if(aa>>>0<(c[am>>2]|0)>>>0){aj=aa;ad=aA}else{aZ=aA;break}}}aIq(aZ);ad=c[$+4>>2]|0;if((ad|0)!=0){fj[c[ad>>2]&511](c[$>>2]|0,0)}aIq($)}c[3118482]=0;a[1778680]=0;break L7277;break};case 70:{ad=fD[c[479934]&127]()|0;aj=fD[c[479932]&127]()|0;if((G-3|0)>>>0<2){a$=1}else{am=(G|0)==2;if(am){a$=am<<31>>31}else{break L7277}}am=ad+1|0;gd(1,0);ge(((aj+am+a$|0)>>>0)%(am>>>0)|0);gd(0,0);break L7277;break};case 85:{if(!d){break L7277}am=1977776;aj=c[am+4>>2]|0|0;ad=1977776;c[ad>>2]=c[am>>2]&-1026|1024;c[ad+4>>2]=aj;aU=-1;i=f;return aU|0};case 86:{if(!d){break L7277}if((a[1977788]&1)==0){break L7277}aj=1977776;ad=c[aj+4>>2]|0;am=1977776;c[am>>2]=c[aj>>2]|1;c[am+4>>2]=ad;aU=-1;i=f;return aU|0};case 91:{if((G|0)==8){c[I>>2]=0;break L7277}else if((G|0)==2){if((J|0)==0){break L7277}c[I>>2]=J-1;break L7277}else if((G|0)==3){if(J>>>0>=7){break L7277}c[I>>2]=J+1;break L7277}else{break L7277}break};case 92:{ad=(c[3118438]|0)+20|0;if((c[ad>>2]|0)==0){am=1778060+(J<<2)|0;if((G|0)==8){c[am>>2]=J;a0=J}else if((G|0)==2){aj=(c[am>>2]|0)-1|0;c[am>>2]=aj;a0=aj}else if((G|0)==3){aj=(c[am>>2]|0)+1|0;c[am>>2]=aj;a0=aj}else{a0=c[am>>2]|0}if((a0|0)<-1){c[am>>2]=-1;break L7277}if((a0|0)<=7){break L7277}c[am>>2]=7;break L7277}else{am=1778092+(J<<2)|0;aj=c[am>>2]|0;if((G|0)==8){c[am>>2]=0;a1=0}else if((G|0)==2){L=aj-1|0;c[am>>2]=L;a1=L}else if((G|0)==3){L=aj+1|0;c[am>>2]=L;a1=L}else{a1=aj}aj=c[1778636+(J<<2)>>2]|0;if((aj|0)==1){a2=80}else if((aj|0)==2){a2=144}else if((aj|0)==0){a2=48}else{a2=16}fh[c[ad>>2]&15](c[3118441]|0,a1,J,0,a2);break L7277}break};case 74:{if((G|0)!=8){break L7277}a[1725621]=0;break L7277;break};case 79:{if((G|0)!=8){break L7277}a[1811460]=0;break L7277;break};case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:case 108:case 109:case 110:{ad=c[(c[3118438]|0)+20>>2]|0;if((ad|0)==0){break L7634}if((G|0)==2){a3=2}else if((G|0)==8){a3=8}else{aj=(G|0)==3;if(aj){a3=aj?4:0}else{break L7634}}aj=y-95|0;fh[ad&15](c[3118441]|0,c[1778092+(aj<<2)>>2]|0,J,c[6240+(aj<<2)>>2]|0,a3);break};case 73:{break};case 76:{if((G|0)!=8){break L7277}a[1890418]=0;break L7277;break};case 78:{if((G|0)!=8){break L7277}a[1898610]=0;break L7277;break};case 75:{if((G|0)!=8){break L7277}a[1894514]=0;break L7277;break};case 67:case 68:{if((G|0)==4){if((y|0)==67){f9()}else{f7()}aj=1977776;ad=c[aj+4>>2]|0;L=1977776;c[L>>2]=c[aj>>2]|1;c[L+4>>2]=ad;aU=-1;i=f;return aU|0}else if((G|0)==8){c[478750]=0;break L7277}else if((G|0)==2){ad=c[478750]|0;if((ad|0)==0){break L7277}c[478750]=ad-1;break L7277}else if((G|0)==3){c[478750]=(c[478750]|0)+1;break L7277}else{break L7277}break};case 94:{ad=1778636+(J<<2)|0;L=c[ad>>2]|0;aj=L+4|0;c[ad>>2]=aj;if((G|0)==8){c[ad>>2]=1;a4=1}else if((G|0)==2){am=L+3|0;c[ad>>2]=am;a4=am}else if((G|0)==3){am=L+5|0;c[ad>>2]=am;a4=am}else{a4=aj}aj=a4&3;c[ad>>2]=aj;ad=c[(c[3118438]|0)+20>>2]|0;if((ad|0)==0){break L7277}if((aj|0)==1){a6=64}else if((aj|0)==2){a6=128}else if((aj|0)==0){a6=32}else{break L7277}fh[ad&15](c[3118441]|0,c[1778092+(J<<2)>>2]|0,J,0,a6);break L7277;break};case 72:{if(!d){break L7277}do{if((a[1733847]&1)!=0|(c[479937]|0)!=0){ad=c[3118488]|0;do{if((ad|0)!=0){aj=c[ad+24>>2]|0;if((aj|0)==0){break}fF[aj&127](c[3118440]|0,0,0)}}while(0);if((c[3118437]|0)==0){break}f1()}}while(0);f0();break L7277;break};case 64:{if((G-3|0)>>>0<2){c[453891]=(c[453891]|0)+1;break L7277}if((G|0)==8){c[453891]=1;break L7277}else if((G|0)!=2){break L7277}$=c[453891]|0;if($>>>0<=1){break L7277}c[453891]=$-1;break L7277;break};case 65:{if((G-3|0)>>>0<2|(G|0)==2){a[1977790]=a[1977790]&1^1;break L7277}if((G|0)!=8){break L7277}a[1977790]=1;break L7277;break};case 63:{if((G|0)==8){a[1815556]=0;$=c[492317]|0;if(($|0)!=0){aIq(c[$>>2]|0);aIq(c[$+12>>2]|0);aIq($)}c[492317]=0;aIq(c[492318]|0);c[492318]=0;break L7277}else if(!((G|0)==4|(G|0)==3|(G|0)==2)){break L7277}$=a[1815556]&1;a[1815556]=$^1;if($<<24>>24==0){f6();break L7277}$=c[492317]|0;if(($|0)!=0){aIq(c[$>>2]|0);aIq(c[$+12>>2]|0);aIq($)}c[492317]=0;aIq(c[492318]|0);c[492318]=0;break L7277;break};case 89:{if((G|0)==3|(G|0)==4){W=+g[445694]+.009999999776482582;g[445694]=W;a7=1;a8=W;as=5533}else if((G|0)==8){g[445694]=1.0;a9=1;ba=1.0}else if((G|0)==2){W=+g[445694]+-.009999999776482582;g[445694]=W;a7=1;a8=W;as=5533}else{a7=0;a8=+g[445694];as=5533}do{if((as|0)==5533){if(a8<0.0){g[445694]=0.0;a9=a7;ba=0.0;break}if(a8<=1.0){a9=a7;ba=a8;break}g[445694]=1.0;a9=a7;ba=1.0}}while(0);$=c[3118482]|0;if(!(a9&($|0)!=0)){break L7277}fg[c[(c[$+4>>2]|0)+20>>2]&7](c[$>>2]|0,ba);break L7277;break};default:{break L7277}}}while(0);if((G|0)!=8){break L7277}a[1815593]=0;a[b+54|0]=0;break L7277}}while(0);d=b+48|0;J=c[d>>2]|0;if((B|0)!=0){I=B+4|0;H=c[I>>2]|0;if(A>>>0<H>>>0){bb=B|0}else{N=(H<<1)+2|0;c[I>>2]=N;I=B|0;c[I>>2]=aIr(c[I>>2]|0,N*12|0)|0;bb=I}I=dv(14317944)|0;c[(c[bb>>2]|0)+((c[z>>2]|0)*12|0)>>2]=I;c[(c[bb>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[bb>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=J;c[z>>2]=(c[z>>2]|0)+1}c[d>>2]=0;a[E]=1;break};case 6:{c[b+48>>2]=0;a[E]=1;break};case 9:{a[b+53|0]=1;break};case 0:{d=b+48|0;J=c[d>>2]|0;if((J|0)==0){c[d>>2]=(c[(c[b+44>>2]|0)+8>>2]|0)-1;break L7277}else{c[d>>2]=J-1;break L7277}break};case 5:{if(A>>>0<=1){break L7277}J=b+48|0;d=A-1|0;c[z>>2]=d;I=B|0;aIq(c[(c[I>>2]|0)+(d*12|0)>>2]|0);if((J|0)!=0){c[J>>2]=c[(c[I>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]}a[E]=1;break};case 1:{I=b+48|0;J=(c[I>>2]|0)+1|0;if(J>>>0<(c[(c[b+44>>2]|0)+8>>2]|0)>>>0){c[I>>2]=J;break L7277}else{c[I>>2]=0;break L7277}break};default:{}}}while(0);z=c[C>>2]|0;C=c[z+8>>2]|0;if((C|0)==0){bc=D}else{bc=c[(c[z>>2]|0)+((C-1|0)*12|0)+4>>2]|0}L7868:do{if(!((a[E]&1)==0|(bc|0)==1)){C=bc-31|0;if(C>>>0<24&((C>>>0)%3|0|0)==0|(bc|0)==28){break}if((bc-73|0)>>>0<4|(bc|0)==78|(bc|0)==79){break}if((bc|0)==88|(bc|0)==71|(bc|0)==57|(bc|0)==56){break}a[E]=0;switch(bc|0){case 59:{C=b+44|0;z=c[C>>2]|0;D=z+8|0;if((c[D>>2]|0)!=0){B=z|0;z=0;do{aIq(c[(c[B>>2]|0)+(z*12|0)>>2]|0);z=z+1|0;}while(z>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;z=c[C>>2]|0;if((z|0)==0){break L7868}B=z+8|0;A=z+4|0;bb=c[A>>2]|0;if((c[B>>2]|0)>>>0<bb>>>0){bd=z|0}else{y=(bb<<1)+2|0;c[A>>2]=y;A=z|0;c[A>>2]=aIr(c[A>>2]|0,y*12|0)|0;bd=A}A=dv(690264)|0;c[(c[bd>>2]|0)+((c[B>>2]|0)*12|0)>>2]=A;c[(c[bd>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=81;c[(c[bd>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[C>>2]|0;if((B|0)==0){break L7868}A=B+8|0;y=B+4|0;z=c[y>>2]|0;if((c[A>>2]|0)>>>0<z>>>0){be=B|0}else{bb=(z<<1)+2|0;c[y>>2]=bb;y=B|0;c[y>>2]=aIr(c[y>>2]|0,bb*12|0)|0;be=y}y=dv(731120)|0;c[(c[be>>2]|0)+((c[A>>2]|0)*12|0)>>2]=y;c[(c[be>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=82;c[(c[be>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;break L7868;break};case 69:{A=b+44|0;y=c[A>>2]|0;bb=y+8|0;if((c[bb>>2]|0)!=0){B=y|0;y=0;do{aIq(c[(c[B>>2]|0)+(y*12|0)>>2]|0);y=y+1|0;}while(y>>>0<(c[bb>>2]|0)>>>0)}c[bb>>2]=0;y=c[A>>2]|0;if((y|0)==0){break L7868}B=y+8|0;C=y+4|0;D=c[C>>2]|0;if((c[B>>2]|0)>>>0<D>>>0){bf=y|0}else{z=(D<<1)+2|0;c[C>>2]=z;C=y|0;c[C>>2]=aIr(c[C>>2]|0,z*12|0)|0;bf=C}C=dv(690488)|0;c[(c[bf>>2]|0)+((c[B>>2]|0)*12|0)>>2]=C;c[(c[bf>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=70;c[(c[bf>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[A>>2]|0;if((B|0)==0){break L7868}C=B+8|0;z=B+4|0;y=c[z>>2]|0;if((c[C>>2]|0)>>>0<y>>>0){bg=B|0}else{D=(y<<1)+2|0;c[z>>2]=D;z=B|0;c[z>>2]=aIr(c[z>>2]|0,D*12|0)|0;bg=z}z=dv(690384)|0;c[(c[bg>>2]|0)+((c[C>>2]|0)*12|0)>>2]=z;c[(c[bg>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=71;c[(c[bg>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;break L7868;break};case 60:{C=b+44|0;z=c[C>>2]|0;D=z+8|0;if((c[D>>2]|0)!=0){B=z|0;z=0;do{aIq(c[(c[B>>2]|0)+(z*12|0)>>2]|0);z=z+1|0;}while(z>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;z=c[C>>2]|0;do{if((z|0)!=0){B=z+8|0;A=z+4|0;bb=c[A>>2]|0;if((c[B>>2]|0)>>>0<bb>>>0){bh=z|0}else{y=(bb<<1)+2|0;c[A>>2]=y;A=z|0;c[A>>2]=aIr(c[A>>2]|0,y*12|0)|0;bh=A}A=dv(728152)|0;c[(c[bh>>2]|0)+((c[B>>2]|0)*12|0)>>2]=A;c[(c[bh>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=88;c[(c[bh>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[C>>2]|0;if((B|0)==0){break}A=B+8|0;y=B+4|0;bb=c[y>>2]|0;if((c[A>>2]|0)>>>0<bb>>>0){bi=B|0}else{G=(bb<<1)+2|0;c[y>>2]=G;y=B|0;c[y>>2]=aIr(c[y>>2]|0,G*12|0)|0;bi=y}y=dv(727864)|0;c[(c[bi>>2]|0)+((c[A>>2]|0)*12|0)>>2]=y;c[(c[bi>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=89;c[(c[bi>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break}y=A+8|0;G=A+4|0;B=c[G>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){bj=A|0}else{bb=(B<<1)+2|0;c[G>>2]=bb;G=A|0;c[G>>2]=aIr(c[G>>2]|0,bb*12|0)|0;bj=G}G=dv(727640)|0;c[(c[bj>>2]|0)+((c[y>>2]|0)*12|0)>>2]=G;c[(c[bj>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=90;c[(c[bj>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break}G=y+8|0;bb=y+4|0;A=c[bb>>2]|0;if((c[G>>2]|0)>>>0<A>>>0){bk=y|0}else{B=(A<<1)+2|0;c[bb>>2]=B;bb=y|0;c[bb>>2]=aIr(c[bb>>2]|0,B*12|0)|0;bk=bb}bb=dv(727416)|0;c[(c[bk>>2]|0)+((c[G>>2]|0)*12|0)>>2]=bb;c[(c[bk>>2]|0)+((c[G>>2]|0)*12|0)+4>>2]=91;c[(c[bk>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]=0;c[G>>2]=(c[G>>2]|0)+1;G=c[C>>2]|0;if((G|0)==0){break}bb=G+8|0;B=G+4|0;y=c[B>>2]|0;if((c[bb>>2]|0)>>>0<y>>>0){bl=G|0}else{A=(y<<1)+2|0;c[B>>2]=A;B=G|0;c[B>>2]=aIr(c[B>>2]|0,A*12|0)|0;bl=B}B=dv(727328)|0;c[(c[bl>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=B;c[(c[bl>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=92;c[(c[bl>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[C>>2]|0;if((bb|0)==0){break}B=bb+8|0;A=bb+4|0;G=c[A>>2]|0;if((c[B>>2]|0)>>>0<G>>>0){bm=bb|0}else{y=(G<<1)+2|0;c[A>>2]=y;A=bb|0;c[A>>2]=aIr(c[A>>2]|0,y*12|0)|0;bm=A}A=dv(727096)|0;c[(c[bm>>2]|0)+((c[B>>2]|0)*12|0)>>2]=A;c[(c[bm>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=93;c[(c[bm>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1}}while(0);z=c[3118438]|0;if((z|0)==0){break L7868}if((c[z+20>>2]|0)==0){break L7868}z=c[C>>2]|0;if((z|0)==0){break L7868}D=z+8|0;B=z+4|0;A=c[B>>2]|0;if((c[D>>2]|0)>>>0<A>>>0){bn=z|0}else{y=(A<<1)+2|0;c[B>>2]=y;B=z|0;c[B>>2]=aIr(c[B>>2]|0,y*12|0)|0;bn=B}B=dv(726864)|0;c[(c[bn>>2]|0)+((c[D>>2]|0)*12|0)>>2]=B;c[(c[bn>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=94;c[(c[bn>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L7868}B=D+8|0;y=D+4|0;z=c[y>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){bo=D|0}else{A=(z<<1)+2|0;c[y>>2]=A;y=D|0;c[y>>2]=aIr(c[y>>2]|0,A*12|0)|0;bo=y}y=dv(726712)|0;c[(c[bo>>2]|0)+((c[B>>2]|0)*12|0)>>2]=y;c[(c[bo>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=95;c[(c[bo>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[C>>2]|0;if((B|0)==0){break L7868}y=B+8|0;A=B+4|0;D=c[A>>2]|0;if((c[y>>2]|0)>>>0<D>>>0){bp=B|0}else{z=(D<<1)+2|0;c[A>>2]=z;A=B|0;c[A>>2]=aIr(c[A>>2]|0,z*12|0)|0;bp=A}A=dv(726592)|0;c[(c[bp>>2]|0)+((c[y>>2]|0)*12|0)>>2]=A;c[(c[bp>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=96;c[(c[bp>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7868}A=y+8|0;z=y+4|0;B=c[z>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bq=y|0}else{D=(B<<1)+2|0;c[z>>2]=D;z=y|0;c[z>>2]=aIr(c[z>>2]|0,D*12|0)|0;bq=z}z=dv(726392)|0;c[(c[bq>>2]|0)+((c[A>>2]|0)*12|0)>>2]=z;c[(c[bq>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=97;c[(c[bq>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L7868}z=A+8|0;D=A+4|0;y=c[D>>2]|0;if((c[z>>2]|0)>>>0<y>>>0){br=A|0}else{B=(y<<1)+2|0;c[D>>2]=B;D=A|0;c[D>>2]=aIr(c[D>>2]|0,B*12|0)|0;br=D}D=dv(726136)|0;c[(c[br>>2]|0)+((c[z>>2]|0)*12|0)>>2]=D;c[(c[br>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=98;c[(c[br>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[C>>2]|0;if((z|0)==0){break L7868}D=z+8|0;B=z+4|0;A=c[B>>2]|0;if((c[D>>2]|0)>>>0<A>>>0){bs=z|0}else{y=(A<<1)+2|0;c[B>>2]=y;B=z|0;c[B>>2]=aIr(c[B>>2]|0,y*12|0)|0;bs=B}B=dv(725736)|0;c[(c[bs>>2]|0)+((c[D>>2]|0)*12|0)>>2]=B;c[(c[bs>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=99;c[(c[bs>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L7868}B=D+8|0;y=D+4|0;z=c[y>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){bt=D|0}else{A=(z<<1)+2|0;c[y>>2]=A;y=D|0;c[y>>2]=aIr(c[y>>2]|0,A*12|0)|0;bt=y}y=dv(725552)|0;c[(c[bt>>2]|0)+((c[B>>2]|0)*12|0)>>2]=y;c[(c[bt>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=100;c[(c[bt>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[C>>2]|0;if((B|0)==0){break L7868}y=B+8|0;A=B+4|0;D=c[A>>2]|0;if((c[y>>2]|0)>>>0<D>>>0){bu=B|0}else{z=(D<<1)+2|0;c[A>>2]=z;A=B|0;c[A>>2]=aIr(c[A>>2]|0,z*12|0)|0;bu=A}A=dv(725472)|0;c[(c[bu>>2]|0)+((c[y>>2]|0)*12|0)>>2]=A;c[(c[bu>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=101;c[(c[bu>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7868}A=y+8|0;z=y+4|0;B=c[z>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bv=y|0}else{D=(B<<1)+2|0;c[z>>2]=D;z=y|0;c[z>>2]=aIr(c[z>>2]|0,D*12|0)|0;bv=z}z=dv(725392)|0;c[(c[bv>>2]|0)+((c[A>>2]|0)*12|0)>>2]=z;c[(c[bv>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=102;c[(c[bv>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L7868}z=A+8|0;D=A+4|0;y=c[D>>2]|0;if((c[z>>2]|0)>>>0<y>>>0){bw=A|0}else{B=(y<<1)+2|0;c[D>>2]=B;D=A|0;c[D>>2]=aIr(c[D>>2]|0,B*12|0)|0;bw=D}D=dv(725272)|0;c[(c[bw>>2]|0)+((c[z>>2]|0)*12|0)>>2]=D;c[(c[bw>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=103;c[(c[bw>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[C>>2]|0;if((z|0)==0){break L7868}D=z+8|0;B=z+4|0;A=c[B>>2]|0;if((c[D>>2]|0)>>>0<A>>>0){bx=z|0}else{y=(A<<1)+2|0;c[B>>2]=y;B=z|0;c[B>>2]=aIr(c[B>>2]|0,y*12|0)|0;bx=B}B=dv(725136)|0;c[(c[bx>>2]|0)+((c[D>>2]|0)*12|0)>>2]=B;c[(c[bx>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=104;c[(c[bx>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L7868}B=D+8|0;y=D+4|0;z=c[y>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){by=D|0}else{A=(z<<1)+2|0;c[y>>2]=A;y=D|0;c[y>>2]=aIr(c[y>>2]|0,A*12|0)|0;by=y}y=dv(725080)|0;c[(c[by>>2]|0)+((c[B>>2]|0)*12|0)>>2]=y;c[(c[by>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=105;c[(c[by>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[C>>2]|0;if((B|0)==0){break L7868}y=B+8|0;A=B+4|0;D=c[A>>2]|0;if((c[y>>2]|0)>>>0<D>>>0){bz=B|0}else{z=(D<<1)+2|0;c[A>>2]=z;A=B|0;c[A>>2]=aIr(c[A>>2]|0,z*12|0)|0;bz=A}A=dv(725024)|0;c[(c[bz>>2]|0)+((c[y>>2]|0)*12|0)>>2]=A;c[(c[bz>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=106;c[(c[bz>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7868}A=y+8|0;z=y+4|0;B=c[z>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bA=y|0}else{D=(B<<1)+2|0;c[z>>2]=D;z=y|0;c[z>>2]=aIr(c[z>>2]|0,D*12|0)|0;bA=z}z=dv(724896)|0;c[(c[bA>>2]|0)+((c[A>>2]|0)*12|0)>>2]=z;c[(c[bA>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=107;c[(c[bA>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L7868}z=A+8|0;D=A+4|0;y=c[D>>2]|0;if((c[z>>2]|0)>>>0<y>>>0){bB=A|0}else{B=(y<<1)+2|0;c[D>>2]=B;D=A|0;c[D>>2]=aIr(c[D>>2]|0,B*12|0)|0;bB=D}D=dv(724696)|0;c[(c[bB>>2]|0)+((c[z>>2]|0)*12|0)>>2]=D;c[(c[bB>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=108;c[(c[bB>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[C>>2]|0;if((z|0)==0){break L7868}D=z+8|0;B=z+4|0;A=c[B>>2]|0;if((c[D>>2]|0)>>>0<A>>>0){bC=z|0}else{y=(A<<1)+2|0;c[B>>2]=y;B=z|0;c[B>>2]=aIr(c[B>>2]|0,y*12|0)|0;bC=B}B=dv(724592)|0;c[(c[bC>>2]|0)+((c[D>>2]|0)*12|0)>>2]=B;c[(c[bC>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=109;c[(c[bC>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L7868}B=D+8|0;y=D+4|0;z=c[y>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){bD=D|0}else{A=(z<<1)+2|0;c[y>>2]=A;y=D|0;c[y>>2]=aIr(c[y>>2]|0,A*12|0)|0;bD=y}y=dv(724520)|0;c[(c[bD>>2]|0)+((c[B>>2]|0)*12|0)>>2]=y;c[(c[bD>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=110;c[(c[bD>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;break L7868;break};case 5:{B=b+44|0;y=c[B>>2]|0;A=y+8|0;if((c[A>>2]|0)!=0){D=y|0;y=0;do{aIq(c[(c[D>>2]|0)+(y*12|0)>>2]|0);y=y+1|0;}while(y>>>0<(c[A>>2]|0)>>>0)}c[A>>2]=0;y=c[B>>2]|0;if((y|0)==0){break L7868}D=y+8|0;C=y+4|0;z=c[C>>2]|0;if((c[D>>2]|0)>>>0<z>>>0){bE=y|0}else{bb=(z<<1)+2|0;c[C>>2]=bb;C=y|0;c[C>>2]=aIr(c[C>>2]|0,bb*12|0)|0;bE=C}C=dv(693392)|0;c[(c[bE>>2]|0)+((c[D>>2]|0)*12|0)>>2]=C;c[(c[bE>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=26;c[(c[bE>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[B>>2]|0;if((D|0)==0){break L7868}C=D+8|0;bb=D+4|0;y=c[bb>>2]|0;if((c[C>>2]|0)>>>0<y>>>0){bF=D|0}else{z=(y<<1)+2|0;c[bb>>2]=z;bb=D|0;c[bb>>2]=aIr(c[bb>>2]|0,z*12|0)|0;bF=bb}bb=dv(693160)|0;c[(c[bF>>2]|0)+((c[C>>2]|0)*12|0)>>2]=bb;c[(c[bF>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=10;c[(c[bF>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[B>>2]|0;if((C|0)==0){break L7868}bb=C+8|0;z=C+4|0;D=c[z>>2]|0;if((c[bb>>2]|0)>>>0<D>>>0){bG=C|0}else{y=(D<<1)+2|0;c[z>>2]=y;z=C|0;c[z>>2]=aIr(c[z>>2]|0,y*12|0)|0;bG=z}z=dv(692816)|0;c[(c[bG>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=z;c[(c[bG>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=11;c[(c[bG>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[B>>2]|0;if((bb|0)==0){break L7868}z=bb+8|0;y=bb+4|0;C=c[y>>2]|0;if((c[z>>2]|0)>>>0<C>>>0){bH=bb|0}else{D=(C<<1)+2|0;c[y>>2]=D;y=bb|0;c[y>>2]=aIr(c[y>>2]|0,D*12|0)|0;bH=y}y=dv(692656)|0;c[(c[bH>>2]|0)+((c[z>>2]|0)*12|0)>>2]=y;c[(c[bH>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=12;c[(c[bH>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[B>>2]|0;if((z|0)==0){break L7868}y=z+8|0;D=z+4|0;bb=c[D>>2]|0;if((c[y>>2]|0)>>>0<bb>>>0){bI=z|0}else{C=(bb<<1)+2|0;c[D>>2]=C;D=z|0;c[D>>2]=aIr(c[D>>2]|0,C*12|0)|0;bI=D}D=dv(692560)|0;c[(c[bI>>2]|0)+((c[y>>2]|0)*12|0)>>2]=D;c[(c[bI>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=14;c[(c[bI>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[B>>2]|0;if((y|0)==0){break L7868}D=y+8|0;C=y+4|0;z=c[C>>2]|0;if((c[D>>2]|0)>>>0<z>>>0){bJ=y|0}else{bb=(z<<1)+2|0;c[C>>2]=bb;C=y|0;c[C>>2]=aIr(c[C>>2]|0,bb*12|0)|0;bJ=C}C=dv(692424)|0;c[(c[bJ>>2]|0)+((c[D>>2]|0)*12|0)>>2]=C;c[(c[bJ>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=15;c[(c[bJ>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[B>>2]|0;if((D|0)==0){break L7868}C=D+8|0;bb=D+4|0;y=c[bb>>2]|0;if((c[C>>2]|0)>>>0<y>>>0){bL=D|0}else{z=(y<<1)+2|0;c[bb>>2]=z;bb=D|0;c[bb>>2]=aIr(c[bb>>2]|0,z*12|0)|0;bL=bb}bb=dv(692304)|0;c[(c[bL>>2]|0)+((c[C>>2]|0)*12|0)>>2]=bb;c[(c[bL>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=16;c[(c[bL>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[B>>2]|0;if((C|0)==0){break L7868}bb=C+8|0;z=C+4|0;D=c[z>>2]|0;if((c[bb>>2]|0)>>>0<D>>>0){bM=C|0}else{y=(D<<1)+2|0;c[z>>2]=y;z=C|0;c[z>>2]=aIr(c[z>>2]|0,y*12|0)|0;bM=z}z=dv(692040)|0;c[(c[bM>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=z;c[(c[bM>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=17;c[(c[bM>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[B>>2]|0;if((bb|0)==0){break L7868}z=bb+8|0;y=bb+4|0;C=c[y>>2]|0;if((c[z>>2]|0)>>>0<C>>>0){bN=bb|0}else{D=(C<<1)+2|0;c[y>>2]=D;y=bb|0;c[y>>2]=aIr(c[y>>2]|0,D*12|0)|0;bN=y}y=dv(691872)|0;c[(c[bN>>2]|0)+((c[z>>2]|0)*12|0)>>2]=y;c[(c[bN>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=18;c[(c[bN>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[B>>2]|0;if((z|0)==0){break L7868}y=z+8|0;D=z+4|0;bb=c[D>>2]|0;if((c[y>>2]|0)>>>0<bb>>>0){bO=z|0}else{C=(bb<<1)+2|0;c[D>>2]=C;D=z|0;c[D>>2]=aIr(c[D>>2]|0,C*12|0)|0;bO=D}D=dv(691688)|0;c[(c[bO>>2]|0)+((c[y>>2]|0)*12|0)>>2]=D;c[(c[bO>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=19;c[(c[bO>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[B>>2]|0;if((y|0)==0){break L7868}D=y+8|0;C=y+4|0;z=c[C>>2]|0;if((c[D>>2]|0)>>>0<z>>>0){bP=y|0}else{bb=(z<<1)+2|0;c[C>>2]=bb;C=y|0;c[C>>2]=aIr(c[C>>2]|0,bb*12|0)|0;bP=C}C=dv(691272)|0;c[(c[bP>>2]|0)+((c[D>>2]|0)*12|0)>>2]=C;c[(c[bP>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=20;c[(c[bP>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[B>>2]|0;if((D|0)==0){break L7868}C=D+8|0;bb=D+4|0;y=c[bb>>2]|0;if((c[C>>2]|0)>>>0<y>>>0){bR=D|0}else{z=(y<<1)+2|0;c[bb>>2]=z;bb=D|0;c[bb>>2]=aIr(c[bb>>2]|0,z*12|0)|0;bR=bb}bb=dv(691056)|0;c[(c[bR>>2]|0)+((c[C>>2]|0)*12|0)>>2]=bb;c[(c[bR>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=21;c[(c[bR>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[B>>2]|0;if((C|0)==0){break L7868}bb=C+8|0;z=C+4|0;D=c[z>>2]|0;if((c[bb>>2]|0)>>>0<D>>>0){bS=C|0}else{y=(D<<1)+2|0;c[z>>2]=y;z=C|0;c[z>>2]=aIr(c[z>>2]|0,y*12|0)|0;bS=z}z=dv(690840)|0;c[(c[bS>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=z;c[(c[bS>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=22;c[(c[bS>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[B>>2]|0;if((bb|0)==0){break L7868}z=bb+8|0;y=bb+4|0;C=c[y>>2]|0;if((c[z>>2]|0)>>>0<C>>>0){bT=bb|0}else{D=(C<<1)+2|0;c[y>>2]=D;y=bb|0;c[y>>2]=aIr(c[y>>2]|0,D*12|0)|0;bT=y}y=dv(690680)|0;c[(c[bT>>2]|0)+((c[z>>2]|0)*12|0)>>2]=y;c[(c[bT>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=23;c[(c[bT>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[B>>2]|0;if((z|0)==0){break L7868}y=z+8|0;D=z+4|0;bb=c[D>>2]|0;if((c[y>>2]|0)>>>0<bb>>>0){bU=z|0}else{C=(bb<<1)+2|0;c[D>>2]=C;D=z|0;c[D>>2]=aIr(c[D>>2]|0,C*12|0)|0;bU=D}D=dv(690608)|0;c[(c[bU>>2]|0)+((c[y>>2]|0)*12|0)>>2]=D;c[(c[bU>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=24;c[(c[bU>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;break L7868;break};case 61:{y=b+44|0;D=c[y>>2]|0;C=D+8|0;if((c[C>>2]|0)!=0){z=D|0;D=0;do{aIq(c[(c[z>>2]|0)+(D*12|0)>>2]|0);D=D+1|0;}while(D>>>0<(c[C>>2]|0)>>>0)}c[C>>2]=0;D=c[y>>2]|0;if((D|0)==0){break L7868}z=D+8|0;B=D+4|0;A=c[B>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){bV=D|0}else{bb=(A<<1)+2|0;c[B>>2]=bb;B=D|0;c[B>>2]=aIr(c[B>>2]|0,bb*12|0)|0;bV=B}B=dv(729784)|0;c[(c[bV>>2]|0)+((c[z>>2]|0)*12|0)>>2]=B;c[(c[bV>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=73;c[(c[bV>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[y>>2]|0;if((z|0)==0){break L7868}B=z+8|0;bb=z+4|0;D=c[bb>>2]|0;if((c[B>>2]|0)>>>0<D>>>0){bW=z|0}else{A=(D<<1)+2|0;c[bb>>2]=A;bb=z|0;c[bb>>2]=aIr(c[bb>>2]|0,A*12|0)|0;bW=bb}bb=dv(729632)|0;c[(c[bW>>2]|0)+((c[B>>2]|0)*12|0)>>2]=bb;c[(c[bW>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=74;c[(c[bW>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[y>>2]|0;if((B|0)==0){break L7868}bb=B+8|0;A=B+4|0;z=c[A>>2]|0;if((c[bb>>2]|0)>>>0<z>>>0){bX=B|0}else{D=(z<<1)+2|0;c[A>>2]=D;A=B|0;c[A>>2]=aIr(c[A>>2]|0,D*12|0)|0;bX=A}A=dv(729512)|0;c[(c[bX>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=A;c[(c[bX>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=75;c[(c[bX>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[y>>2]|0;if((bb|0)==0){break L7868}A=bb+8|0;D=bb+4|0;B=c[D>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bY=bb|0}else{z=(B<<1)+2|0;c[D>>2]=z;D=bb|0;c[D>>2]=aIr(c[D>>2]|0,z*12|0)|0;bY=D}D=dv(729128)|0;c[(c[bY>>2]|0)+((c[A>>2]|0)*12|0)>>2]=D;c[(c[bY>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=76;c[(c[bY>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[y>>2]|0;if((A|0)==0){break L7868}D=A+8|0;z=A+4|0;bb=c[z>>2]|0;if((c[D>>2]|0)>>>0<bb>>>0){bZ=A|0}else{B=(bb<<1)+2|0;c[z>>2]=B;z=A|0;c[z>>2]=aIr(c[z>>2]|0,B*12|0)|0;bZ=z}z=dv(728960)|0;c[(c[bZ>>2]|0)+((c[D>>2]|0)*12|0)>>2]=z;c[(c[bZ>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=78;c[(c[bZ>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[y>>2]|0;if((D|0)==0){break L7868}z=D+8|0;B=D+4|0;A=c[B>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){b_=D|0}else{bb=(A<<1)+2|0;c[B>>2]=bb;B=D|0;c[B>>2]=aIr(c[B>>2]|0,bb*12|0)|0;b_=B}B=dv(728664)|0;c[(c[b_>>2]|0)+((c[z>>2]|0)*12|0)>>2]=B;c[(c[b_>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=79;c[(c[b_>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;break L7868;break};case 62:{z=b+44|0;B=c[z>>2]|0;bb=B+8|0;if((c[bb>>2]|0)!=0){D=B|0;B=0;do{aIq(c[(c[D>>2]|0)+(B*12|0)>>2]|0);B=B+1|0;}while(B>>>0<(c[bb>>2]|0)>>>0)}c[bb>>2]=0;B=c[z>>2]|0;if((B|0)==0){break L7868}D=B+8|0;y=B+4|0;C=c[y>>2]|0;if((c[D>>2]|0)>>>0<C>>>0){b$=B|0}else{A=(C<<1)+2|0;c[y>>2]=A;y=B|0;c[y>>2]=aIr(c[y>>2]|0,A*12|0)|0;b$=y}y=dv(730440)|0;c[(c[b$>>2]|0)+((c[D>>2]|0)*12|0)>>2]=y;c[(c[b$>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=63;c[(c[b$>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[z>>2]|0;if((D|0)==0){break L7868}y=D+8|0;A=D+4|0;B=c[A>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){b0=D|0}else{C=(B<<1)+2|0;c[A>>2]=C;A=D|0;c[A>>2]=aIr(c[A>>2]|0,C*12|0)|0;b0=A}A=dv(730264)|0;c[(c[b0>>2]|0)+((c[y>>2]|0)*12|0)>>2]=A;c[(c[b0>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=64;c[(c[b0>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[z>>2]|0;if((y|0)==0){break L7868}A=y+8|0;C=y+4|0;D=c[C>>2]|0;if((c[A>>2]|0)>>>0<D>>>0){b1=y|0}else{B=(D<<1)+2|0;c[C>>2]=B;C=y|0;c[C>>2]=aIr(c[C>>2]|0,B*12|0)|0;b1=C}C=dv(730112)|0;c[(c[b1>>2]|0)+((c[A>>2]|0)*12|0)>>2]=C;c[(c[b1>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=65;c[(c[b1>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[z>>2]|0;if((A|0)==0){break L7868}C=A+8|0;B=A+4|0;y=c[B>>2]|0;if((c[C>>2]|0)>>>0<y>>>0){b2=A|0}else{D=(y<<1)+2|0;c[B>>2]=D;B=A|0;c[B>>2]=aIr(c[B>>2]|0,D*12|0)|0;b2=B}B=dv(729952)|0;c[(c[b2>>2]|0)+((c[C>>2]|0)*12|0)>>2]=B;c[(c[b2>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=84;c[(c[b2>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;break L7868;break};case 58:{C=b+44|0;B=c[C>>2]|0;D=B+8|0;if((c[D>>2]|0)!=0){A=B|0;B=0;do{aIq(c[(c[A>>2]|0)+(B*12|0)>>2]|0);B=B+1|0;}while(B>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;B=c[479954]|0;if((B|0)==0){A=c[C>>2]|0;if((A|0)==0){break L7868}z=A+8|0;bb=A+4|0;y=c[bb>>2]|0;if((c[z>>2]|0)>>>0<y>>>0){b3=A|0}else{G=(y<<1)+2|0;c[bb>>2]=G;bb=A|0;c[bb>>2]=aIr(c[bb>>2]|0,G*12|0)|0;b3=bb}bb=dv(730904)|0;c[(c[b3>>2]|0)+((c[z>>2]|0)*12|0)>>2]=bb;c[(c[b3>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=65535;c[(c[b3>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;break L7868}z=c[B+4104>>2]|0;if((z|0)==0){break L7868}else{b4=0;b5=B}while(1){B=c[C>>2]|0;bb=c[(c[b5+4100>>2]|0)+(b4<<4)>>2]|0;G=b4+65536|0;if((B|0)!=0){A=B+8|0;y=B+4|0;a9=c[y>>2]|0;if((c[A>>2]|0)>>>0<a9>>>0){b6=B|0}else{a7=(a9<<1)+2|0;c[y>>2]=a7;y=B|0;c[y>>2]=aIr(c[y>>2]|0,a7*12|0)|0;b6=y}y=dv(bb|0)|0;c[(c[b6>>2]|0)+((c[A>>2]|0)*12|0)>>2]=y;c[(c[b6>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=G;c[(c[b6>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1}A=b4+1|0;if(A>>>0>=z>>>0){break L7868}b4=A;b5=c[479954]|0}break};case 26:{z=v|0;C=b+44|0;D=c[C>>2]|0;A=D+8|0;if((c[A>>2]|0)!=0){G=D|0;D=0;do{aIq(c[(c[G>>2]|0)+(D*12|0)>>2]|0);D=D+1|0;}while(D>>>0<(c[A>>2]|0)>>>0)}c[A>>2]=0;D=c[C>>2]|0;do{if((D|0)!=0){G=D+8|0;y=D+4|0;bb=c[y>>2]|0;if((c[G>>2]|0)>>>0<bb>>>0){b7=D|0}else{a7=(bb<<1)+2|0;c[y>>2]=a7;y=D|0;c[y>>2]=aIr(c[y>>2]|0,a7*12|0)|0;b7=y}y=dv(694792)|0;c[(c[b7>>2]|0)+((c[G>>2]|0)*12|0)>>2]=y;c[(c[b7>>2]|0)+((c[G>>2]|0)*12|0)+4>>2]=29;c[(c[b7>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]=0;c[G>>2]=(c[G>>2]|0)+1;G=c[C>>2]|0;if((G|0)==0){break}y=G+8|0;a7=G+4|0;bb=c[a7>>2]|0;if((c[y>>2]|0)>>>0<bb>>>0){b8=G|0}else{B=(bb<<1)+2|0;c[a7>>2]=B;a7=G|0;c[a7>>2]=aIr(c[a7>>2]|0,B*12|0)|0;b8=a7}a7=dv(694680)|0;c[(c[b8>>2]|0)+((c[y>>2]|0)*12|0)>>2]=a7;c[(c[b8>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=27;c[(c[b8>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break}a7=y+8|0;B=y+4|0;G=c[B>>2]|0;if((c[a7>>2]|0)>>>0<G>>>0){b9=y|0}else{bb=(G<<1)+2|0;c[B>>2]=bb;B=y|0;c[B>>2]=aIr(c[B>>2]|0,bb*12|0)|0;b9=B}B=dv(694552)|0;c[(c[b9>>2]|0)+((c[a7>>2]|0)*12|0)>>2]=B;c[(c[b9>>2]|0)+((c[a7>>2]|0)*12|0)+4>>2]=28;c[(c[b9>>2]|0)+((c[a7>>2]|0)*12|0)+8>>2]=0;c[a7>>2]=(c[a7>>2]|0)+1;a7=c[C>>2]|0;if((a7|0)==0){break}B=a7+8|0;bb=a7+4|0;y=c[bb>>2]|0;if((c[B>>2]|0)>>>0<y>>>0){ca=a7|0}else{G=(y<<1)+2|0;c[bb>>2]=G;bb=a7|0;c[bb>>2]=aIr(c[bb>>2]|0,G*12|0)|0;ca=bb}bb=dv(694464)|0;c[(c[ca>>2]|0)+((c[B>>2]|0)*12|0)>>2]=bb;c[(c[ca>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=30;c[(c[ca>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1}}while(0);D=b+4252|0;if((c[D>>2]|0)==0){break L7868}else{cb=0}do{bQ(z|0,64,694296,(_=i,i=i+8|0,c[_>>2]=cb,_)|0)|0;i=_;A=c[C>>2]|0;B=cb*3|0;bb=B+31|0;if((A|0)!=0){G=A+8|0;a7=A+4|0;y=c[a7>>2]|0;if((c[G>>2]|0)>>>0<y>>>0){cc=A|0}else{a9=(y<<1)+2|0;c[a7>>2]=a9;a7=A|0;c[a7>>2]=aIr(c[a7>>2]|0,a9*12|0)|0;cc=a7}a7=dv(z|0)|0;c[(c[cc>>2]|0)+((c[G>>2]|0)*12|0)>>2]=a7;c[(c[cc>>2]|0)+((c[G>>2]|0)*12|0)+4>>2]=bb;c[(c[cc>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]=0;c[G>>2]=(c[G>>2]|0)+1}bQ(z|0,64,694112,(_=i,i=i+8|0,c[_>>2]=cb,_)|0)|0;i=_;G=c[C>>2]|0;bb=B+32|0;if((G|0)!=0){a7=G+8|0;a9=G+4|0;A=c[a9>>2]|0;if((c[a7>>2]|0)>>>0<A>>>0){cd=G|0}else{y=(A<<1)+2|0;c[a9>>2]=y;a9=G|0;c[a9>>2]=aIr(c[a9>>2]|0,y*12|0)|0;cd=a9}a9=dv(z|0)|0;c[(c[cd>>2]|0)+((c[a7>>2]|0)*12|0)>>2]=a9;c[(c[cd>>2]|0)+((c[a7>>2]|0)*12|0)+4>>2]=bb;c[(c[cd>>2]|0)+((c[a7>>2]|0)*12|0)+8>>2]=0;c[a7>>2]=(c[a7>>2]|0)+1}bQ(z|0,64,693848,(_=i,i=i+8|0,c[_>>2]=cb,_)|0)|0;i=_;a7=c[C>>2]|0;bb=B+33|0;if((a7|0)!=0){B=a7+8|0;a9=a7+4|0;y=c[a9>>2]|0;if((c[B>>2]|0)>>>0<y>>>0){ce=a7|0}else{G=(y<<1)+2|0;c[a9>>2]=G;a9=a7|0;c[a9>>2]=aIr(c[a9>>2]|0,G*12|0)|0;ce=a9}a9=dv(z|0)|0;c[(c[ce>>2]|0)+((c[B>>2]|0)*12|0)>>2]=a9;c[(c[ce>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=bb;c[(c[ce>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1}cb=cb+1|0;}while(cb>>>0<(c[D>>2]|0)>>>0);break};default:{iu(b);break L7868}}}}while(0);iy(b);aU=0;i=f;return aU|0}function ix(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;if((a[1820736]&1)!=0){g=c[494446]|0;h=(g|0)!=0?g:c[p>>2]|0;g=(e|0)!=0?e:696536;ei(h|0,696672,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;h=c[494446]|0;g=(h|0)!=0?h:c[p>>2]|0;a_(g|0)|0}if(!(fp[c[(c[3118437]|0)+20>>2]&63](c[3118440]|0,d,e)|0)){d=c[494446]|0;g=(d|0)!=0?d:c[p>>2]|0;a5(696296,46,1,g|0)|0;g=c[494446]|0;d=(g|0)!=0?g:c[p>>2]|0;a_(d|0)|0;a[1721516]=0;i=f;return}d=(e|0)!=0;g=4096;h=1717420;j=d?e:14317944;while(1){k=g-1|0;if((k|0)==0){l=5921;break}m=a[j]|0;a[h]=m;if(m<<24>>24==0){break}else{g=k;h=h+1|0;j=j+1|0}}do{if((l|0)==5921){a[h]=0;if((a[j]|0)==0){break}else{n=j}do{n=n+1|0;}while((a[n]|0)!=0)}}while(0);a[1721516]=1;if((b|0)==0|d^1){i=f;return}d=gP(e,0)|0;if((d|0)!=0){h6(d,b)|0;ia(b,e);gN(d)}a[(c[240672]|0)+52|0]=1;i=f;return}function iy(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0.0,aG=0.0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0;e=i;i=i+1480|0;f=e|0;j=e+256|0;k=e+512|0;l=e+576|0;m=e+832|0;n=e+1088|0;o=e+1160|0;p=e+1416|0;do{if((a[d+52|0]&1)!=0){q=1977776;if((c[q>>2]&4|0)==0&(c[q+4>>2]&0|0)==0){break}if((a[d+53|0]&1)!=0){break}i=e;return}}while(0);q=d+48|0;r=c[q>>2]|0;s=r+17|0;t=d+44|0;u=c[(c[t>>2]|0)+8>>2]|0;v=s>>>0>u>>>0?u:s;s=u>>>0>17?r>>>0<8?0:r-8|0:0;r=(v-s|0)>>>0>17?s+17|0:v;v=d+28|0;u=c[v>>2]|0;w=d+32|0;x=(c[w>>2]|0)>>>1;y=0;do{z=ab(y,x)|0;A=y>>>1;B=0;do{C=((B>>>1)+A&1)+1|0;b[u+(B+z<<1)>>1]=(C<<9|C<<13|C<<5|12)&65535;B=B+1|0;}while(B>>>0<320);y=y+1|0;}while(y>>>0<240);y=c[v>>2]|0;u=(c[w>>2]|0)>>>1;x=u*5|0;B=5;do{z=(B>>>1&1)+1|0;b[y+(B+x<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=u*6|0;x=5;do{z=2-(x>>>1&1)|0;b[y+(x+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=u*7|0;B=5;do{z=2-(B>>>1&1)|0;b[y+(B+x<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=u<<3;x=5;do{z=(x>>>1&1)+1|0;b[y+(x+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=u*9|0;u=5;do{B=(u>>>1&1)+1|0;b[y+(u+x<<1)>>1]=(B<<10|B<<13|B<<5|12)&65535;u=u+1|0;}while(u>>>0<315);u=c[v>>2]|0;x=(c[w>>2]|0)>>>1;y=x*230|0;B=5;do{z=2-(B>>>1&1)|0;b[u+(B+y<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=x*231|0;y=5;do{z=2-(y>>>1&1)|0;b[u+(y+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;y=y+1|0;}while(y>>>0<315);y=x*232|0;B=5;do{z=(B>>>1&1)+1|0;b[u+(B+y<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=x*233|0;y=5;do{z=(y>>>1&1)+1|0;b[u+(y+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;y=y+1|0;}while(y>>>0<315);y=x*234|0;x=5;do{B=2-(x>>>1&1)|0;b[u+(x+y<<1)>>1]=(B<<10|B<<13|B<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=c[v>>2]|0;y=(c[w>>2]|0)>>>1;u=5;do{B=ab(u,y)|0;z=u>>>1&1;A=z+1|0;C=(A<<10|A<<13|A<<5|12)&65535;b[x+(B+5<<1)>>1]=C;A=2-z|0;z=(A<<10|A<<13|A<<5|12)&65535;b[x+(B+6<<1)>>1]=z;b[x+(B+7<<1)>>1]=z;b[x+(B+8<<1)>>1]=C;b[x+(B+9<<1)>>1]=C;u=u+1|0;}while(u>>>0<235);u=c[v>>2]|0;v=(c[w>>2]|0)>>>1;w=5;do{x=ab(w,v)|0;y=w>>>1&1;C=2-y|0;B=(C<<10|C<<13|C<<5|12)&65535;b[u+(x+310<<1)>>1]=B;b[u+(x+311<<1)>>1]=B;C=y+1|0;y=(C<<10|C<<13|C<<5|12)&65535;b[u+(x+312<<1)>>1]=y;b[u+(x+313<<1)>>1]=y;b[u+(x+314<<1)>>1]=B;w=w+1|0;}while(w>>>0<235);w=c[d+40>>2]|0;u=c[w+8>>2]|0;L8323:do{if((u|0)==0){D=0;E=0;G=5967}else{v=u-1|0;B=c[w>>2]|0;x=c[B+(v*12|0)>>2]|0;y=c[B+(v*12|0)+4>>2]|0;switch(y|0){case 5:{a[f|0]=86;a[f+1|0]=73;a[f+2|0]=68;a[f+3|0]=69;a[f+4|0]=79;a[f+5|0]=32;a[f+6|0]=79;a[f+7|0]=80;a[f+8|0]=84;a[f+9|0]=73;a[f+10|0]=79;a[f+11|0]=78;a[f+12|0]=83;a[f+13|0]=0;H=5;break L8323;break};case 26:{a[f|0]=83;a[f+1|0]=72;a[f+2|0]=65;a[f+3|0]=68;a[f+4|0]=69;a[f+5|0]=82;a[f+6|0]=32;a[f+7|0]=79;a[f+8|0]=80;a[f+9|0]=84;a[f+10|0]=73;a[f+11|0]=79;a[f+12|0]=78;a[f+13|0]=83;a[f+14|0]=0;H=26;break L8323;break};case 59:{a[f|0]=65;a[f+1|0]=85;a[f+2|0]=68;a[f+3|0]=73;a[f+4|0]=79;a[f+5|0]=32;a[f+6|0]=79;a[f+7|0]=80;a[f+8|0]=84;a[f+9|0]=73;a[f+10|0]=79;a[f+11|0]=78;a[f+12|0]=83;a[f+13|0]=0;H=59;break L8323;break};case 69:{a[f|0]=68;a[f+1|0]=73;a[f+2|0]=83;a[f+3|0]=75;a[f+4|0]=32;a[f+5|0]=79;a[f+6|0]=80;a[f+7|0]=84;a[f+8|0]=73;a[f+9|0]=79;a[f+10|0]=78;a[f+11|0]=83;a[f+12|0]=0;H=69;break L8323;break};case 58:{a[f|0]=67;a[f+1|0]=79;a[f+2|0]=82;a[f+3|0]=69;a[f+4|0]=32;a[f+5|0]=79;a[f+6|0]=80;a[f+7|0]=84;a[f+8|0]=73;a[f+9|0]=79;a[f+10|0]=78;a[f+11|0]=83;a[f+12|0]=0;H=58;break L8323;break};case 57:{bQ(f|0,256,707432,(I=i,i=i+8|0,c[I>>2]=x,I)|0)|0;i=I;H=57;break L8323;break};case 71:{bQ(f|0,256,703120,(I=i,i=i+8|0,c[I>>2]=x,I)|0)|0;i=I;H=71;break L8323;break};default:{D=x;E=y;G=5967;break L8323}}}}while(0);L8333:do{if((G|0)==5967){w=E-31|0;if(w>>>0<24&((w>>>0)%3|0|0)==0|(E|0)==28){w=f|0;bQ(w|0,256,730880,(I=i,i=i+8|0,c[I>>2]=D,I)|0)|0;i=I;H=E;break}if((E-60|0)>>>0<3|(E|0)==12|(E|0)==13|(E|0)==4){w=f|0;bQ(w|0,256,728584,(I=i,i=i+8|0,c[I>>2]=D,I)|0)|0;i=I;H=E;break}switch(E|0){case 74:{bQ(f|0,256,722456,(I=i,i=i+8|0,c[I>>2]=D,I)|0)|0;i=I;H=74;break L8333;break};case 73:{bQ(f|0,256,723864,(I=i,i=i+8|0,c[I>>2]=D,I)|0)|0;i=I;H=73;break L8333;break};case 75:{bQ(f|0,256,721048,(I=i,i=i+8|0,c[I>>2]=D,I)|0)|0;i=I;H=75;break L8333;break};case 79:{bQ(f|0,256,718072,(I=i,i=i+8|0,c[I>>2]=D,I)|0)|0;i=I;H=79;break L8333;break};case 88:{bQ(f|0,256,724800,(I=i,i=i+8|0,c[I>>2]=D,I)|0)|0;i=I;H=88;break L8333;break};case 78:{bQ(f|0,256,719e3,(I=i,i=i+8|0,c[I>>2]=D,I)|0)|0;i=I;H=78;break L8333;break};case 76:{bQ(f|0,256,720008,(I=i,i=i+8|0,c[I>>2]=D,I)|0)|0;i=I;H=76;break L8333;break};case 56:{a[f|0]=76;a[f+1|0]=79;a[f+2|0]=65;a[f+3|0]=68;a[f+4|0]=32;a[f+5|0]=72;a[f+6|0]=73;a[f+7|0]=83;a[f+8|0]=84;a[f+9|0]=79;a[f+10|0]=82;a[f+11|0]=89;a[f+12|0]=0;H=56;break L8333;break};default:{w=c[d+4160>>2]|0;u=(w|0)==0?c[478756]|0:w;bQ(f|0,256,715784,(I=i,i=i+16|0,c[I>>2]=(u|0)==0?717064:u,c[I+8>>2]=D,I)|0)|0;i=I;H=E;break L8333}}}}while(0);E=j|0;it(E,45,((c[494386]|0)>>>0)/15|0,f|0,1);iz(d,30,15,E,1);E=c[d+4160>>2]|0;f=(E|0)==0?c[478756]|0:E;E=c[d+4164>>2]|0;j=(E|0)==0?c[478757]|0:E;E=k|0;bQ(E|0,64,714136,(I=i,i=i+24|0,c[I>>2]=712768,c[I+8>>2]=(f|0)==0?717064:f,c[I+16>>2]=(j|0)==0?14317944:j,I)|0)|0;i=I;iz(d,30,216,E,1);if(s>>>0>=r>>>0){i=e;return}E=d+113708|0;j=m|0;f=o|0;o=p|0;p=l|0;l=n+8|0;k=n|0;D=n;u=(H|0)==60?24:(H|0)==61?24:19;w=H-31|0;y=w>>>0<24&((w>>>0)%3|0|0)==0|(H|0)==28;w=m+1|0;x=m+2|0;v=m+3|0;B=m+4|0;C=m+5|0;z=m+6|0;A=m+7|0;J=m+8|0;K=m+9|0;L=m+10|0;M=d+4252|0;N=(H-73|0)>>>0<4|(H|0)==78|(H|0)==79;O=(H|0)==56;P=m+11|0;Q=m+12|0;S=m+13|0;T=m+14|0;U=m+15|0;V=m+16|0;W=m+17|0;X=m+18|0;m=n+9|0;Y=n+10|0;Z=n+11|0;_=n+12|0;$=n+13|0;aa=n+14|0;ac=n+15|0;n=s;s=27;while(1){ad=c[c[t>>2]>>2]|0;ae=c[ad+(n*12|0)>>2]|0;af=c[ad+(n*12|0)+4>>2]|0;ad=c[E>>2]|0;L8357:do{if((af-27|0)>>>0<28){do{if(y){ag=af-31|0;if(!(ag>>>0<24&((ag>>>0)%3|0|0)==0|(af|0)==28)){break}a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break L8357}}while(0);if((af|0)==29){a[j]=0;ah=u;ai=29;break}else if((af|0)==28){a[j]=46;a[w]=46;a[x]=46;a[v]=0;ah=u;ai=28;break}else if((af|0)==27){bQ(j|0,256,710232,(I=i,i=i+8|0,c[I>>2]=(a[1717404]&1)!=0?709552:709128,I)|0)|0;i=I;ah=u;ai=27;break}else if((af|0)==30){bQ(j|0,256,705880,(I=i,i=i+8|0,c[I>>2]=c[M>>2],I)|0)|0;i=I;ah=u;ai=30;break}else{ag=af-31|0;aj=(ag>>>0)/3|0;ak=(ag>>>0)%3|0;if((ak|0)==0){ag=d+4256+(aj*4148|0)|0;if((a[ag]|0)==0){a[j]=78;a[w]=47;a[x]=65;a[v]=0;ah=u;ai=af;break}else{gH(j,ag,256);ah=u;ai=af;break}}else if((ak|0)==1){ag=c[d+4256+(aj*4148|0)+4136>>2]|0;if((ag|0)==0){a[j]=68;a[w]=111;a[x]=110;a[v]=39;a[B]=116;a[C]=32;a[z]=99;a[A]=97;a[J]=114;a[K]=101;a[L]=0;ah=u;ai=af;break}else if((ag|0)==1){a[j]=76;a[w]=105;a[x]=110;a[v]=101;a[B]=97;a[C]=114;a[z]=0;ah=u;ai=af;break}else if((ag|0)==2){a[j]=78;a[w]=101;a[x]=97;a[v]=114;a[B]=101;a[C]=115;a[z]=116;a[A]=0;ah=u;ai=af;break}else{ah=u;ai=af;break}}else if((ak|0)==2){ak=~~+g[d+4256+(aj*4148|0)+4116>>2];if((ak|0)==0){a[j]=68;a[w]=111;a[x]=110;a[v]=39;a[B]=116;a[C]=32;a[z]=99;a[A]=97;a[J]=114;a[K]=101;a[L]=0;ah=u;ai=af;break}else{bQ(j|0,256,728592,(I=i,i=i+8|0,c[I>>2]=ak,I)|0)|0;i=I;ah=u;ai=af;break}}else{ah=u;ai=af;break}}}else{do{if(!((H|0)==88|(H|0)==71|(H|0)==57)){if(N){break}if(O){a[j]=0;ah=0;ai=af;break L8357}if(af>>>0>65535){ak=af-65536|0;aj=c[(c[479954]|0)+4100>>2]|0;ag=256;al=j;am=c[(c[c[aj+(ak<<4)+8>>2]>>2]|0)+(c[aj+(ak<<4)+12>>2]<<3)>>2]|0;while(1){ak=ag-1|0;if((ak|0)==0){break}aj=a[am]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=af;break L8357}else{ag=ak;al=al+1|0;am=am+1|0}}a[al]=0;if((a[am]|0)==0){ah=u;ai=af;break L8357}else{an=am}while(1){ag=an+1|0;if((a[ag]|0)==0){ah=u;ai=af;break L8357}else{an=ag}}}switch(af|0){case 21:{bQ(j|0,256,705544,(I=i,i=i+8|0,h[I>>3]=+g[429342],I)|0)|0;i=I;ah=u;ai=21;break L8357;break};case 70:{am=fD[c[479934]&127]()|0;al=fD[c[479932]&127]()|0;if(al>>>0<am>>>0){am=al+1|0;bQ(j|0,256,705880,(I=i,i=i+8|0,c[I>>2]=am,I)|0)|0;i=I;ah=u;ai=70;break L8357}else{a[j]=78;a[w]=111;a[x]=32;a[v]=68;a[B]=105;a[C]=115;a[z]=107;a[A]=0;ah=u;ai=70;break L8357}break};case 67:case 68:{bQ(j|0,256,706248,(I=i,i=i+8|0,c[I>>2]=c[478750],I)|0)|0;i=I;ah=u;ai=af;break L8357;break};case 81:{am=256;al=j;ag=(a[1919865]&1)!=0?708336:707768;while(1){ak=am-1|0;if((ak|0)==0){break}aj=a[ag]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=81;break L8357}else{am=ak;al=al+1|0;ag=ag+1|0}}a[al]=0;if((a[ag]|0)==0){ah=u;ai=81;break L8357}else{ao=ag}while(1){am=ao+1|0;if((a[am]|0)==0){ah=u;ai=81;break L8357}else{ao=am}}break};case 93:{switch(c[1820740+(ad<<2)>>2]|0){case 1:{ap=256;aq=j;ar=701120;break};case 5:{ap=256;aq=j;ar=700824;break};case 257:{ap=256;aq=j;ar=700704;break};case 2:{ap=256;aq=j;ar=700160;break};case 516:{ap=256;aq=j;ar=699608;break};case 772:{ap=256;aq=j;ar=699176;break};case 260:{ap=256;aq=j;ar=698712;break};case 0:{ap=256;aq=j;ar=701328;break};default:{ap=256;aq=j;ar=698568}}while(1){ag=ap-1|0;if((ag|0)==0){break}al=a[ar]|0;a[aq]=al;if(al<<24>>24==0){ah=u;ai=93;break L8357}else{ap=ag;aq=aq+1|0;ar=ar+1|0}}a[aq]=0;if((a[ar]|0)==0){ah=u;ai=93;break L8357}else{as=ar}while(1){ag=as+1|0;if((a[ag]|0)==0){ah=u;ai=93;break L8357}else{as=ag}}break};case 75:{ag=256;al=j;am=(a[1894514]|0)!=0?1894514:703512;while(1){ak=ag-1|0;if((ak|0)==0){break}aj=a[am]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=75;break L8357}else{ag=ak;al=al+1|0;am=am+1|0}}a[al]=0;if((a[am]|0)==0){ah=u;ai=75;break L8357}else{at=am}while(1){ag=at+1|0;if((a[ag]|0)==0){ah=u;ai=75;break L8357}else{at=ag}}break};case 94:{am=c[1778636+(ad<<2)>>2]|0;if((am|0)==2){a[j]=82;a[w]=105;a[x]=103;a[v]=104;a[B]=116;a[C]=32;a[z]=83;a[A]=116;a[J]=105;a[K]=99;a[L]=107;a[P]=0;ah=u;ai=94;break L8357}else if((am|0)==3){a[j]=68;a[w]=117;a[x]=97;a[v]=108;a[B]=32;a[C]=65;a[z]=110;a[A]=97;a[J]=108;a[K]=111;a[L]=103;a[P]=0;ah=u;ai=94;break L8357}else if((am|0)==1){a[j]=76;a[w]=101;a[x]=102;a[v]=116;a[B]=32;a[C]=83;a[z]=116;a[A]=105;a[J]=99;a[K]=107;a[L]=0;ah=u;ai=94;break L8357}else if((am|0)==0){a[j]=78;a[w]=111;a[x]=110;a[v]=101;a[B]=0;ah=u;ai=94;break L8357}else{ah=u;ai=94;break L8357}break};case 79:{am=256;al=j;ag=(a[1811460]|0)!=0?1811460:703512;while(1){ak=am-1|0;if((ak|0)==0){break}aj=a[ag]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=79;break L8357}else{am=ak;al=al+1|0;ag=ag+1|0}}a[al]=0;if((a[ag]|0)==0){ah=u;ai=79;break L8357}else{au=ag}while(1){am=au+1|0;if((a[am]|0)==0){ah=u;ai=79;break L8357}else{au=am}}break};case 15:{ag=256;al=j;am=2552+(c[494437]<<5)|0;while(1){ak=ag-1|0;if((ak|0)==0){break}aj=a[am]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=15;break L8357}else{ag=ak;al=al+1|0;am=am+1|0}}a[al]=0;if((a[am]|0)==0){ah=u;ai=15;break L8357}else{av=am}while(1){ag=av+1|0;if((a[ag]|0)==0){ah=u;ai=15;break L8357}else{av=ag}}break};case 76:{am=256;al=j;ag=(a[1890418]|0)!=0?1890418:703512;while(1){ak=am-1|0;if((ak|0)==0){break}aj=a[ag]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=76;break L8357}else{am=ak;al=al+1|0;ag=ag+1|0}}a[al]=0;if((a[ag]|0)==0){ah=u;ai=76;break L8357}else{aw=ag}while(1){am=aw+1|0;if((a[am]|0)==0){ah=u;ai=76;break L8357}else{aw=am}}break};case 22:{bQ(j|0,256,705544,(I=i,i=i+8|0,h[I>>3]=+g[429343],I)|0)|0;i=I;ah=u;ai=22;break L8357;break};case 88:{ag=ck(1778680,47)|0;al=256;am=j;ak=(ag|0)==0?1778680:ag+1|0;while(1){ag=al-1|0;if((ag|0)==0){break}aj=a[ak]|0;a[am]=aj;if(aj<<24>>24==0){ah=u;ai=88;break L8357}else{al=ag;am=am+1|0;ak=ak+1|0}}a[am]=0;if((a[ak]|0)==0){ah=u;ai=88;break L8357}else{ax=ak}while(1){al=ax+1|0;if((a[al]|0)==0){ah=u;ai=88;break L8357}else{ax=al}}break};case 24:{do{if((a[1725620]&1)==0){ak=1969088;am=c[ak>>2]|0;al=c[ak+4>>2]|0;ak=0;ag=al>>>0>ak>>>0|al>>>0==ak>>>0&am>>>0>2048>>>0?2048:am;if(ag>>>0<2){break}else{ay=0;az=0;aA=0}do{am=1952704+(ay<<3)|0;aA=aIF(c[am>>2]|0,c[am+4>>2]|0,aA,az)|0;az=F;ay=ay+1|0;}while(ay>>>0<ag>>>0);am=aIN(aA,az,ag,0)|0;ak=F;al=0;aj=0;aB=0;do{aC=1952704+(aB<<3)|0;aD=aIG(c[aC>>2]|0,c[aC+4>>2]|0,am,ak)|0;aC=F;aE=aIP(aD,aC,aD,aC)|0;aj=aIF(aE,F,aj,al)|0;al=F;aB=aB+1|0;}while(aB>>>0<ag>>>0);aF=+(am>>>0)+ +(ak|0)*4294967296.0;aG=+R(+((+(aj>>>0)+ +(al|0)*4294967296.0)/+((ag-1|0)>>>0>>>0)))/aF*100.0;bQ(j|0,256,705104,(I=i,i=i+24|0,h[I>>3]=1.0e6/aF,h[I+8>>3]=aG,c[I+16>>2]=ag,I)|0)|0;i=I;ah=u;ai=24;break L8357}}while(0);a[j]=78;a[w]=47;a[x]=65;a[v]=0;ah=u;ai=24;break L8357;break};case 16:{aB=256;aE=j;aC=(a[1717392]&1)!=0?708336:707768;while(1){aD=aB-1|0;if((aD|0)==0){break}aH=a[aC]|0;a[aE]=aH;if(aH<<24>>24==0){ah=u;ai=16;break L8357}else{aB=aD;aE=aE+1|0;aC=aC+1|0}}a[aE]=0;if((a[aC]|0)==0){ah=u;ai=16;break L8357}else{aI=aC}while(1){aB=aI+1|0;if((a[aB]|0)==0){ah=u;ai=16;break L8357}else{aI=aB}}break};case 8:{aC=1977776;bQ(j|0,256,((c[aC>>2]&65536|0)!=0|(c[aC+4>>2]&0|0)!=0?708336:707768)|0,(I=i,i=i+1|0,i=i+7>>3<<3,c[I>>2]=0,I)|0)|0;i=I;ah=u;ai=8;break L8357;break};case 7:{if((a[1717404]&1)==0){a[j]=80;a[w]=111;a[x]=105;a[v]=110;a[B]=116;a[C]=32;a[z]=102;a[A]=105;a[J]=108;a[K]=116;a[L]=101;a[P]=114;a[Q]=105;a[S]=110;a[T]=103;a[U]=0;ah=u;ai=7;break L8357}else{a[j]=66;a[w]=105;a[x]=108;a[v]=105;a[B]=110;a[C]=101;a[z]=97;a[A]=114;a[J]=32;a[K]=102;a[L]=105;a[P]=108;a[Q]=116;a[S]=101;a[T]=114;a[U]=105;a[V]=110;a[W]=103;a[X]=0;ah=u;ai=7;break L8357}break};case 11:{aC=256;aE=j;aB=689696+((c[429354]|0)*68|0)|0;while(1){aD=aC-1|0;if((aD|0)==0){break}aH=a[aB]|0;a[aE]=aH;if(aH<<24>>24==0){ah=u;ai=11;break L8357}else{aC=aD;aE=aE+1|0;aB=aB+1|0}}a[aE]=0;if((a[aB]|0)==0){ah=u;ai=11;break L8357}else{aJ=aB}while(1){aC=aJ+1|0;if((a[aC]|0)==0){ah=u;ai=11;break L8357}else{aJ=aC}}break};case 55:case 56:case 58:case 12:case 14:case 5:case 59:case 69:case 26:case 28:case 57:case 71:case 60:case 61:case 62:{a[j]=46;a[w]=46;a[x]=46;a[v]=0;ah=u;ai=af;break L8357;break};case 1:{a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break L8357;break};case 63:{aB=256;aE=j;aC=(a[1815556]&1)!=0?708336:707768;while(1){aD=aB-1|0;if((aD|0)==0){break}aH=a[aC]|0;a[aE]=aH;if(aH<<24>>24==0){ah=u;ai=63;break L8357}else{aB=aD;aE=aE+1|0;aC=aC+1|0}}a[aE]=0;if((a[aC]|0)==0){ah=u;ai=63;break L8357}else{aK=aC}while(1){aB=aK+1|0;if((a[aB]|0)==0){ah=u;ai=63;break L8357}else{aK=aB}}break};case 64:{bQ(j|0,256,705880,(I=i,i=i+8|0,c[I>>2]=c[453891],I)|0)|0;i=I;ah=u;ai=64;break L8357;break};case 17:{aC=256;aE=j;aB=(a[1717393]&1)!=0?708336:707768;while(1){aD=aC-1|0;if((aD|0)==0){break}aH=a[aB]|0;a[aE]=aH;if(aH<<24>>24==0){ah=u;ai=17;break L8357}else{aC=aD;aE=aE+1|0;aB=aB+1|0}}a[aE]=0;if((a[aB]|0)==0){ah=u;ai=17;break L8357}else{aL=aB}while(1){aC=aL+1|0;if((a[aC]|0)==0){ah=u;ai=17;break L8357}else{aL=aC}}break};case 19:{aB=256;aE=j;aC=(a[1717394]&1)!=0?708336:707768;while(1){aD=aB-1|0;if((aD|0)==0){break}aH=a[aC]|0;a[aE]=aH;if(aH<<24>>24==0){ah=u;ai=19;break L8357}else{aB=aD;aE=aE+1|0;aC=aC+1|0}}a[aE]=0;if((a[aC]|0)==0){ah=u;ai=19;break L8357}else{aM=aC}while(1){aB=aM+1|0;if((a[aB]|0)==0){ah=u;ai=19;break L8357}else{aM=aB}}break};case 65:{aC=256;aE=j;aB=(a[1977790]&1)!=0?708336:707768;while(1){aD=aC-1|0;if((aD|0)==0){break}aH=a[aB]|0;a[aE]=aH;if(aH<<24>>24==0){ah=u;ai=65;break L8357}else{aC=aD;aE=aE+1|0;aB=aB+1|0}}a[aE]=0;if((a[aB]|0)==0){ah=u;ai=65;break L8357}else{aN=aB}while(1){aC=aN+1|0;if((a[aC]|0)==0){ah=u;ai=65;break L8357}else{aN=aC}}break};case 74:{aB=256;aE=j;aC=(a[1725621]|0)!=0?1725621:704048;while(1){aD=aB-1|0;if((aD|0)==0){break}aH=a[aC]|0;a[aE]=aH;if(aH<<24>>24==0){ah=u;ai=74;break L8357}else{aB=aD;aE=aE+1|0;aC=aC+1|0}}a[aE]=0;if((a[aC]|0)==0){ah=u;ai=74;break L8357}else{aO=aC}while(1){aB=aO+1|0;if((a[aB]|0)==0){ah=u;ai=74;break L8357}else{aO=aB}}break};case 20:{bQ(j|0,256,705880,(I=i,i=i+8|0,c[I>>2]=c[429349],I)|0)|0;i=I;ah=u;ai=20;break L8357;break};case 90:{bQ(j|0,256,702416,(I=i,i=i+8|0,h[I>>3]=+g[445695],I)|0)|0;i=I;ah=u;ai=90;break L8357;break};case 91:{bQ(j|0,256,702152,(I=i,i=i+8|0,c[I>>2]=ad+1,I)|0)|0;i=I;ah=u;ai=91;break L8357;break};case 82:{bQ(j|0,256,704424,(I=i,i=i+8|0,h[I>>3]=+g[435525],I)|0)|0;i=I;ah=u;ai=82;break L8357;break};case 84:{aC=1977776;bQ(j|0,256,((c[aC>>2]&256|0)!=0|(c[aC+4>>2]&0|0)!=0?708336:707768)|0,(I=i,i=i+1|0,i=i+7>>3<<3,c[I>>2]=0,I)|0)|0;i=I;ah=u;ai=84;break L8357;break};case 73:{aC=256;aE=j;aB=(a[1815593]|0)!=0?1815593:704048;while(1){aD=aC-1|0;if((aD|0)==0){break}aH=a[aB]|0;a[aE]=aH;if(aH<<24>>24==0){ah=u;ai=73;break L8357}else{aC=aD;aE=aE+1|0;aB=aB+1|0}}a[aE]=0;if((a[aB]|0)==0){ah=u;ai=73;break L8357}else{aP=aB}while(1){aC=aP+1|0;if((a[aC]|0)==0){ah=u;ai=73;break L8357}else{aP=aC}}break};case 89:{bQ(j|0,256,702416,(I=i,i=i+8|0,h[I>>3]=+g[445694],I)|0)|0;i=I;ah=u;ai=89;break L8357;break};case 0:{a[j]=40;a[w]=70;a[x]=73;a[v]=76;a[B]=69;a[C]=41;a[z]=0;ah=6;ai=0;break L8357;break};case 66:{aB=256;aE=j;aC=(c[453895]|0)!=0?708336:707768;while(1){aD=aB-1|0;if((aD|0)==0){break}aH=a[aC]|0;a[aE]=aH;if(aH<<24>>24==0){ah=u;ai=66;break L8357}else{aB=aD;aE=aE+1|0;aC=aC+1|0}}a[aE]=0;if((a[aC]|0)==0){ah=u;ai=66;break L8357}else{aQ=aC}while(1){aB=aQ+1|0;if((a[aB]|0)==0){ah=u;ai=66;break L8357}else{aQ=aB}}break};case 92:{aC=c[1778060+(ad<<2)>>2]|0;if(aC>>>0>=8){a[j]=68;a[w]=105;a[x]=115;a[v]=97;a[B]=98;a[C]=108;a[z]=101;a[A]=100;a[J]=0;ah=u;ai=92;break L8357}aE=1778124+(aC<<6)|0;if((a[aE]|0)==0){bQ(j|0,256,701848,(I=i,i=i+8|0,c[I>>2]=aC,I)|0)|0;i=I;ah=u;ai=92;break L8357}else{aR=256;aS=j;aT=aE}while(1){aE=aR-1|0;if((aE|0)==0){break}aC=a[aT]|0;a[aS]=aC;if(aC<<24>>24==0){ah=u;ai=92;break L8357}else{aR=aE;aS=aS+1|0;aT=aT+1|0}}a[aS]=0;if((a[aT]|0)==0){ah=u;ai=92;break L8357}else{aU=aT}while(1){aE=aU+1|0;if((a[aE]|0)==0){ah=u;ai=92;break L8357}else{aU=aE}}break};case 78:{aE=256;aC=j;aB=(a[1898610]|0)!=0?1898610:704048;while(1){aD=aE-1|0;if((aD|0)==0){break}aH=a[aB]|0;a[aC]=aH;if(aH<<24>>24==0){ah=u;ai=78;break L8357}else{aE=aD;aC=aC+1|0;aB=aB+1|0}}a[aC]=0;if((a[aB]|0)==0){ah=u;ai=78;break L8357}else{aV=aB}while(1){aE=aV+1|0;if((a[aE]|0)==0){ah=u;ai=78;break L8357}else{aV=aE}}break};case 9:{bQ(j|0,256,706248,(I=i,i=i+8|0,c[I>>2]=c[494438],I)|0)|0;i=I;ah=u;ai=9;break L8357;break};case 18:{bQ(j|0,256,705880,(I=i,i=i+8|0,c[I>>2]=c[429350],I)|0)|0;i=I;ah=u;ai=18;break L8357;break};case 23:{aB=256;aC=j;aE=(a[1717406]&1)!=0?708336:707768;while(1){aD=aB-1|0;if((aD|0)==0){break}aH=a[aE]|0;a[aC]=aH;if(aH<<24>>24==0){ah=u;ai=23;break L8357}else{aB=aD;aC=aC+1|0;aE=aE+1|0}}a[aC]=0;if((a[aE]|0)==0){ah=u;ai=23;break L8357}else{aW=aE}while(1){aB=aW+1|0;if((a[aB]|0)==0){ah=u;ai=23;break L8357}else{aW=aB}}break};case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:case 108:case 109:case 110:{aE=c[6240+(af-95<<2)>>2]|0;a[l]=85;a[m]=110;a[Y]=107;a[Z]=110;a[_]=111;a[$]=119;a[aa]=110;a[ac]=0;aC=1742208+(ad*2240|0)+(aE*40|0)+16|0;aE=c[aC+4>>2]|0;c[k>>2]=c[aC>>2];c[k+4>>2]=aE;aE=c[(c[3118438]|0)+20>>2]|0;if((aE|0)==0){aX=256;aY=j;aZ=l}else{fh[aE&15](D,0,0,0,256);aX=256;aY=j;aZ=l}while(1){aE=aX-1|0;if((aE|0)==0){break}aC=a[aZ]|0;a[aY]=aC;if(aC<<24>>24==0){ah=u;ai=af;break L8357}else{aX=aE;aY=aY+1|0;aZ=aZ+1|0}}a[aY]=0;if((a[aZ]|0)==0){ah=u;ai=af;break L8357}else{a_=aZ}while(1){aE=a_+1|0;if((a[aE]|0)==0){ah=u;ai=af;break L8357}else{a_=aE}}break};case 10:{aE=256;aC=j;aB=(a[1717413]&1)!=0?708336:707768;while(1){aD=aE-1|0;if((aD|0)==0){break}aH=a[aB]|0;a[aC]=aH;if(aH<<24>>24==0){ah=u;ai=10;break L8357}else{aE=aD;aC=aC+1|0;aB=aB+1|0}}a[aC]=0;if((a[aB]|0)==0){ah=u;ai=10;break L8357}else{a$=aB}while(1){aE=a$+1|0;if((a[aE]|0)==0){ah=u;ai=10;break L8357}else{a$=aE}}break};default:{a[j]=0;ah=0;ai=af;break L8357}}}}while(0);if((af|0)==3){a[j]=0;ah=0;ai=3;break}else if((af|0)==0){a[j]=40;a[w]=70;a[x]=73;a[v]=76;a[B]=69;a[C]=41;a[z]=0;ah=6;ai=0;break}else{a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break}}}while(0);af=(n|0)==(c[q>>2]|0);ad=256;aB=f;aC=ae;while(1){aE=ad-1|0;if((aE|0)==0){G=6156;break}aD=a[aC]|0;a[aB]=aD;if(aD<<24>>24==0){a0=64;a1=o;a2=j;break}else{ad=aE;aB=aB+1|0;aC=aC+1|0}}do{if((G|0)==6156){G=0;a[aB]=0;if((a[aC]|0)==0){a0=64;a1=o;a2=j;break}else{a3=aC}while(1){ad=a3+1|0;if((a[ad]|0)==0){a0=64;a1=o;a2=j;break}else{a3=ad}}}}while(0);while(1){aC=a0-1|0;if((aC|0)==0){G=6160;break}aB=a[a2]|0;a[a1]=aB;if(aB<<24>>24==0){break}else{a0=aC;a1=a1+1|0;a2=a2+1|0}}do{if((G|0)==6160){G=0;a[a1]=0;if((a[a2]|0)==0){break}else{a4=a2}do{a4=a4+1|0;}while((a[a4]|0)!=0)}}while(0);if(ai>>>0<2){aC=-3-ah|0;it(f,aC+48|0,((c[494386]|0)>>>0)/15|0,ae,af);a5=aC}else{it(o,ah,((c[494386]|0)>>>0)/15|0,j,af);a5=-3-ah|0}aC=a5+48|0;bQ(p|0,256,698168,(I=i,i=i+48|0,c[I>>2]=af?62:32,c[I+8>>2]=aC,c[I+16>>2]=aC,c[I+24>>2]=f,c[I+32>>2]=ah,c[I+40>>2]=o,I)|0)|0;i=I;iz(d,15,s,p,af);aC=n+1|0;if(aC>>>0<r>>>0){n=aC;s=s+11|0}else{break}}i=e;return}function iz(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=a[h]|0;if(j<<24>>24==0){return}k=e+4152|0;l=i?32639:-1;i=e+32|0;m=e+28|0;e=h;h=f;f=j;while(1){j=h+4|0;n=h+3|0;o=h+2|0;p=h+1|0;q=0;r=f;while(1){s=q*5|0;t=q+g|0;u=c[k>>2]|0;if((1<<(s&7)&(d[u+((s>>3)+((r&255)*7|0))|0]|0)|0)==0){v=r;w=u}else{u=(ab((c[i>>2]|0)>>>1,t)|0)+h|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;v=a[e]|0;w=c[k>>2]|0}u=s+1|0;if(((d[w+(((v&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){x=v;y=w}else{u=p+(ab((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;x=a[e]|0;y=c[k>>2]|0}u=s+2|0;if(((d[y+(((x&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){z=x;A=y}else{u=o+(ab((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;z=a[e]|0;A=c[k>>2]|0}u=s+3|0;if(((d[A+(((z&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){B=z;C=A}else{u=n+(ab((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;B=a[e]|0;C=c[k>>2]|0}u=s+4|0;if(((d[C+(((B&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)!=0){u=j+(ab((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l}u=q+1|0;if((u|0)>=10){break}q=u;r=a[e]|0}r=e+1|0;q=a[r]|0;if(q<<24>>24==0){break}else{e=r;h=h+6|0;f=q}}return}function iA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+16|0;f=e|0;g=a+4|0;h=c[g>>2]|0;L8657:do{if((h|0)==0){j=0}else{k=a|0;l=c[k>>2]|0;L8659:do{if((b|0)==0){m=0;while(1){do{if((c[l+(m*12|0)>>2]|0)==0){if((cP(c[l+(m*12|0)+4>>2]|0,1795076)|0)!=0){break}if((cP(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L8659}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L8657}}}else{m=0;while(1){o=c[l+(m*12|0)>>2]|0;do{if((o|0)!=0){if((cP(b|0,o|0)|0)!=0){break}if((cP(c[l+(m*12|0)+4>>2]|0,1795076)|0)!=0){break}if((cP(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L8659}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L8657}}}}while(0);if((n|0)==0){i=e;return}m=f;o=l+(n*12|0)|0;c[m>>2]=c[o>>2];c[m+4>>2]=c[o+4>>2];c[m+8>>2]=c[o+8>>2];aIC(l+12|0,l|0,n*12|0|0);o=c[k>>2]|0;c[o>>2]=c[m>>2];c[o+4>>2]=c[m+4>>2];c[o+8>>2]=c[m+8>>2];i=e;return}}while(0);n=a+8|0;f=c[n>>2]|0;if((j|0)==(f|0)){h=j-1|0;j=a|0;m=c[j>>2]|0;o=m+(h*12|0)|0;aIq(c[o>>2]|0);aIq(c[m+(h*12|0)+4>>2]|0);aIq(c[m+(h*12|0)+8>>2]|0);aIv(o|0,0,12);c[g>>2]=(c[g>>2]|0)-1;p=c[n>>2]|0;q=j}else{p=f;q=a|0}a=c[q>>2]|0;aIC(a+12|0,a|0,(p*12|0)-12|0);if((b|0)==0){r=0}else{r=dv(b|0)|0}c[c[q>>2]>>2]=r;r=dv(1795076)|0;c[(c[q>>2]|0)+4>>2]=r;r=dv(d|0)|0;c[(c[q>>2]|0)+8>>2]=r;c[g>>2]=(c[g>>2]|0)+1;i=e;return}function iB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;if((a|0)==0){i=b;return}d=a+12|0;e=c[d>>2]|0;do{if((e|0)!=0){f=c9(e|0,727320)|0;if((f|0)==0){break}g=a+4|0;if((c[g>>2]|0)!=0){h=a|0;j=0;do{k=c[h>>2]|0;l=c[k+(j*12|0)>>2]|0;m=c[k+(j*12|0)+4>>2]|0;n=c[k+(j*12|0)+8>>2]|0;ei(f|0,714880,(k=i,i=i+24|0,c[k>>2]=(l|0)==0?14317944:l,c[k+8>>2]=m,c[k+16>>2]=n,k)|0)|0;i=k;j=j+1|0;}while(j>>>0<(c[g>>2]|0)>>>0)}aS(f|0)|0}}while(0);aIq(c[d>>2]|0);d=a+8|0;e=a|0;g=c[e>>2]|0;if((c[d>>2]|0)==0){o=g}else{j=0;h=g;while(1){g=h+(j*12|0)|0;aIq(c[g>>2]|0);aIq(c[h+(j*12|0)+4>>2]|0);aIq(c[h+(j*12|0)+8>>2]|0);aIv(g|0,0,12);g=j+1|0;k=c[e>>2]|0;if(g>>>0<(c[d>>2]|0)>>>0){j=g;h=k}else{o=k;break}}}aIq(o);aIq(a);i=b;return}function iC(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+72|0;h=f|0;j=f+8|0;k=f+40|0;l=b+4|0;m=c[l>>2]|0;if((m|0)==0){i=f;return}if((fD[c[m+16>>2]&127]()|0)==0){i=f;return}m=j|0;a[m]=0;n=c[l>>2]|0;do{if((n|0)==0){o=6251}else{fj[c[n+28>>2]&511](1,j);q=c[l>>2]|0;if((q|0)==0){o=6251;break}r=fD[c[q+16>>2]&127]()|0;q=c[l>>2]|0;s=k|0;a[s]=0;if((q|0)==0){t=0;u=s;break}fj[c[q+28>>2]&511](r,k);r=c[l>>2]|0;if((r|0)==0){t=0;u=s;break}do{if((fD[c[r+16>>2]&127]()|0)==1){if((a[m]&1)!=0){break}i=f;return}}while(0);r=c[l>>2]|0;if((r|0)==0){t=0;u=s;break}t=fD[c[r+16>>2]&127]()|0;u=s}}while(0);if((o|0)==6251){n=k|0;a[n]=0;t=0;u=n}n=t-1|0;k=b+1636|0;c[k>>2]=n;if((a[u]&1)==0){v=n}else{c[k>>2]=t;v=t}if((a[m]&1)==0){g[j+12>>2]=1.0;g[j+16>>2]=1.0;c[j+8>>2]=0;c[j+4>>2]=0;a[m]=1}j=b+1124|0;t=j;aIy(j|0,m|0,32)|0;if((v|0)>1){v=1;while(1){m=v+1|0;j=t+(v<<5)|0;n=j|0;a[n]=0;u=c[l>>2]|0;if((u|0)==0){o=6266}else{fj[c[u+28>>2]&511](m,j);if((a[n]&1)==0){o=6266}}if((o|0)==6266){o=0;g[t+(v<<5)+16>>2]=1.0;g[t+(v<<5)+12>>2]=1.0;c[t+(v<<5)+8>>2]=0;c[t+(v<<5)+4>>2]=0;a[n]=1}if((m|0)<(c[k>>2]|0)){v=m}else{break}}}iD(b,d,e,c[b+1728>>2]|0,c[b+1732>>2]|0);e=c[k>>2]|0;if((e|0)>0){d=b+740|0;v=0;while(1){m=(c[d+(v*24|0)>>2]|0)-1|0;n=m>>>1|m;m=n>>>2|n;n=m>>>4|m;m=n>>>8|n;n=(m>>>16|m)+1|0;c[d+(v*24|0)+16>>2]=n;m=(c[d+(v*24|0)+4>>2]|0)-1|0;j=m>>>1|m;m=j>>>2|j;j=m>>>4|m;m=j>>>8|j;j=(m>>>16|m)+1|0;c[d+(v*24|0)+20>>2]=j;if((a[1820736]&1)!=0){m=c[494446]|0;u=(m|0)!=0?m:c[p>>2]|0;ei(u|0,720536,(w=i,i=i+24|0,c[w>>2]=v,c[w+8>>2]=n,c[w+16>>2]=j,w)|0)|0;i=w;j=c[494446]|0;n=(j|0)!=0?j:c[p>>2]|0;a_(n|0)|0}n=v+1|0;j=c[k>>2]|0;if((n|0)<(j|0)){v=n}else{x=j;break}}}else{x=e}e=b+676|0;v=e;d=e;bA(x|0,d|0);x=(a[1717404]&1)!=0?9729:9728;if((c[k>>2]|0)>0){e=b+740|0;j=b+2584|0;n=0;do{aZ(3553,c[v+(n<<2)>>2]|0);a[h]=0;u=c[l>>2]|0;do{if((u|0)==0){y=33071;z=x}else{m=n+2|0;if(fA[c[u+20>>2]&63](m,h)|0){A=(a[h]&1)!=0?9729:9728}else{A=x}r=c[l>>2]|0;if((r|0)==0){y=33071;z=A;break}q=fl[c[r+24>>2]&255](m)|0;if((q|0)==3){y=33648;z=A;break}else if((q|0)==0|(q|0)==1){y=33071;z=A;break}else if((q|0)==2){y=10497;z=A;break}else{y=0;z=A;break}}}while(0);e2(3553,10240,z|0);e2(3553,10241,z|0);e2(3553,10242,y|0);e2(3553,10243,y|0);do{if((a[t+(n<<5)|0]&1)==0){o=6294}else{if((a[t+(n<<5)+28|0]&1)==0){o=6294;break}do{if((a[j]&1)==0){u=a4(7939)|0;if((u|0)==0){B=0;break}B=(bx(u|0,701296)|0)!=0}else{B=0}}while(0);if((a[1820736]&1)!=0){u=c[494446]|0;s=(u|0)!=0?u:c[p>>2]|0;u=B?728536:726296;ei(s|0,730808,(w=i,i=i+16|0,c[w>>2]=701296,c[w+8>>2]=u,w)|0)|0;i=w;u=c[494446]|0;s=(u|0)!=0?u:c[p>>2]|0;a_(s|0)|0}if(!B){s=c[494446]|0;u=(s|0)!=0?s:c[p>>2]|0;a5(701048,67,1,u|0)|0;u=c[494446]|0;s=(u|0)!=0?u:c[p>>2]|0;a_(s|0)|0}if((a[1820736]&1)!=0){s=c[494446]|0;u=(s|0)!=0?s:c[p>>2]|0;ei(u|0,700776,(w=i,i=i+8|0,c[w>>2]=n,w)|0)|0;i=w;u=c[494446]|0;s=(u|0)!=0?u:c[p>>2]|0;a_(s|0)|0}d8(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5126,0)}}while(0);if((o|0)==6294){o=0;d8(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5121,0)}n=n+1|0;}while((n|0)<(c[k>>2]|0))}aZ(3553,0);aZ(3553,0);n=b+612|0;e=n;w=n;dT(c[k>>2]|0,w|0);n=0;while(1){if((n|0)>=(c[k>>2]|0)){o=6300;break}b2(36160,c[e+(n<<2)>>2]|0);dy(36160,36064,3553,c[v+(n<<2)>>2]|0,0);if((cp(36160)|0)==36053){n=n+1|0}else{o=6299;break}}if((o|0)==6299){b9(c[k>>2]|0,w|0);w=c[494446]|0;n=(w|0)!=0?w:c[p>>2]|0;a5(701560,94,1,n|0)|0;n=c[494446]|0;w=(n|0)!=0?n:c[p>>2]|0;a_(w|0)|0;bh(c[k>>2]|0,d|0);d=c[494446]|0;k=(d|0)!=0?d:c[p>>2]|0;a5(727240,78,1,k|0)|0;k=c[494446]|0;d=(k|0)!=0?k:c[p>>2]|0;a_(d|0)|0;i=f;return}else if((o|0)==6300){a[b+1640|0]=1;i=f;return}}function iD(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0.0,r=0.0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+8|0;j=h|0;k=c[a+1832>>2]|0;l=c[a+1836>>2]|0;c[j>>2]=0;dY(3379,j|0);m=a+1636|0;if((c[m>>2]|0)<=0){i=h;return}n=a+1124|0;o=a+740|0;q=+(f>>>0>>>0);r=+(e>>>0>>>0);e=b;b=d;d=k;k=l;l=0;f=0;while(1){a=c[n+(f<<5)+4>>2]|0;if((a|0)==2){s=~~(r*+g[n+(f<<5)+12>>2]);c[o+(f*24|0)+8>>2]=s;c[o+(f*24|0)>>2]=s}else if((a|0)==1){s=c[n+(f<<5)+20>>2]|0;c[o+(f*24|0)+8>>2]=s;c[o+(f*24|0)>>2]=s}else if((a|0)==0){t=+g[n+(f<<5)+12>>2];c[o+(f*24|0)>>2]=~~(+(e>>>0>>>0)*t);c[o+(f*24|0)+8>>2]=~~(+(d>>>0>>>0)*t)}a=c[n+(f<<5)+8>>2]|0;if((a|0)==1){s=c[n+(f<<5)+24>>2]|0;c[o+(f*24|0)+12>>2]=s;c[o+(f*24|0)+4>>2]=s}else if((a|0)==0){t=+g[n+(f<<5)+16>>2];c[o+(f*24|0)+4>>2]=~~(+(b>>>0>>>0)*t);c[o+(f*24|0)+12>>2]=~~(+(k>>>0>>>0)*t)}else if((a|0)==2){a=~~(q*+g[n+(f<<5)+16>>2]);c[o+(f*24|0)+12>>2]=a;c[o+(f*24|0)+4>>2]=a}a=o+(f*24|0)|0;s=c[a>>2]|0;u=c[j>>2]|0;if(s>>>0>u>>>0){c[a>>2]=u;v=1;w=u}else{v=l;w=s}s=o+(f*24|0)+4|0;x=c[s>>2]|0;if(x>>>0>u>>>0){c[s>>2]=u;y=1;z=u}else{y=v;z=x}x=o+(f*24|0)+8|0;A=c[x>>2]|0;if(A>>>0>u>>>0){c[x>>2]=u;B=1;C=u}else{B=y;C=A}A=o+(f*24|0)+12|0;D=c[A>>2]|0;if(D>>>0>u>>>0){c[A>>2]=u;E=6326}else{if(B){E=6326}else{F=0;G=w;H=z;I=C;J=D}}if((E|0)==6326){E=0;D=c[494446]|0;K=(D|0)!=0?D:c[p>>2]|0;ei(K|0,700608,(K=i,i=i+16|0,c[K>>2]=u,c[K+8>>2]=u,K)|0)|0;i=K;K=c[494446]|0;u=(K|0)!=0?K:c[p>>2]|0;a_(u|0)|0;F=1;G=c[a>>2]|0;H=c[s>>2]|0;I=c[x>>2]|0;J=c[A>>2]|0}A=f+1|0;if((A|0)<(c[m>>2]|0)){e=G;b=H;d=I;k=J;l=F;f=A}else{break}}i=h;return}function iE(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+64|0;j=h|0;k=c[(c[b>>2]|0)+24>>2]|0;if((k|0)==0){l=+(d>>>0>>>0)/+(e>>>0>>>0)}else{l=+ft[k&3](d,e)}do{if((a[1717413]&1)==0){if((a[b+1714|0]&1)==0){c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=d;c[b+1748>>2]=e;m=d;n=e;o=0;p=0;break}q=+g[478770];do{if((c[429354]|0)==7){k=c[494434]|0;r=c[494433]|0;s=k;t=(c[b+1732>>2]|0)-(c[494432]|0)-k|0;u=c[494431]|0}else{if(+Q(+(l-q))<9999999747378752.0e-20){r=d;s=e;t=0;u=0;break}if(l>q){v=(q/l+-1.0)*.5+.5;w=+(d>>>0>>>0);k=~~+bK(+(w*(.5-v)));r=~~+bK(+(w*2.0*v));s=e;t=0;u=k;break}else{v=(l/q+-1.0)*.5+.5;w=+(e>>>0>>>0);k=~~+bK(+(w*(.5-v)));r=d;s=~~+bK(+(w*2.0*v));t=k;u=0;break}}}while(0);c[b+1736>>2]=u;c[b+1740>>2]=t;c[b+1744>>2]=r;c[b+1748>>2]=s;m=r;n=s;o=u;p=t}else{k=b+1736|0;x=(a[b+1714|0]&1)==0;if((c[429354]|0)==7){y=c[494433]|0;z=c[494434]|0;A=y;B=z;C=d-y|0;D=e-z|0}else{z=c[478761]|0;y=~~+bK(+(+g[478770]*+(z>>>0>>>0)));do{if(y>>>0>d>>>0|z>>>0>e>>>0){E=0;F=0}else{if(x){E=(d>>>0)%(y>>>0)|0;F=(e>>>0)%(z>>>0)|0;break}else{G=(d>>>0)/(y>>>0)|0;H=(e>>>0)/(z>>>0)|0;I=G>>>0<H>>>0?G:H;H=d-(ab(I,y)|0)|0;E=H;F=e-(ab(I,z)|0)|0;break}}}while(0);A=d-E|0;B=e-F|0;C=E;D=F}c[b+1744>>2]=A;c[b+1748>>2]=B;z=(C|0)/2|0;c[k>>2]=z;y=(D|0)/2|0;c[b+1740>>2]=y;m=A;n=B;o=z;p=y}}while(0);eK(o|0,p|0,m|0,n|0);p=b+1936|0;aIv(p|0,0,48);g[b+1996>>2]=1.0;g[p>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;if(f){l=+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0;q=+T(+l);v=+U(+l);aIv(j|0,0,60);g[j+40>>2]=1.0;g[j+60>>2]=1.0;g[j>>2]=q;g[j+20>>2]=q;g[j+16>>2]=-0.0-v;g[j+4>>2]=v;i7(b+1872|0,j,p);J=b+1760|0;K=J;c[K>>2]=m;L=b+1764|0;M=L;c[M>>2]=n;i=h;return}else{j=b+1872|0;aIy(j|0,p|0,64)|0;J=b+1760|0;K=J;c[K>>2]=m;L=b+1764|0;M=L;c[M>>2]=n;i=h;return}}function iF(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+8|0;h=f|0;j=aIp(2592)|0;if((j|0)==0){k=0;i=f;return k|0}if((c[j-4>>2]&3|0)!=0){aIv(j|0,0,2592)}l=j;m=c[479942]|0;n=c[479943]|0;L8865:do{if((a[1717336]|0)==0){do{if((bi(12448)|0)!=0){if(!(jk()|0)){break}o=j;c[o>>2]=672464;q=672464;r=o;break L8865}}while(0);c[j>>2]=0;s=6373}else{o=(cP(719896,1717336)|0)==0;t=o?672464:0;if(!o){o=c[494446]|0;u=(o|0)!=0?o:c[p>>2]|0;ei(u|0,701792,(v=i,i=i+8|0,c[v>>2]=1717336,v)|0)|0;i=v;u=c[494446]|0;o=(u|0)!=0?u:c[p>>2]|0;a_(o|0)|0;s=6373;break}if(!(fp[c[t+8>>2]&63](1,m,n)|0)){o=c[494446]|0;u=(o|0)!=0?o:c[p>>2]|0;ei(u|0,702352,(v=i,i=i+16|0,c[v>>2]=702640,c[v+8>>2]=1717336,v)|0)|0;i=v;u=c[494446]|0;o=(u|0)!=0?u:c[p>>2]|0;a_(o|0)|0;s=6373;break}if(fD[c[t>>2]&127]()|0){o=j;c[o>>2]=t;q=t;r=o;break}else{o=c[494446]|0;u=(o|0)!=0?o:c[p>>2]|0;o=c[t+68>>2]|0;ei(u|0,702096,(v=i,i=i+8|0,c[v>>2]=o,v)|0)|0;i=v;o=c[494446]|0;u=(o|0)!=0?o:c[p>>2]|0;a_(u|0)|0;s=6373;break}}}while(0);if((s|0)==6373){aIq(j);k=0;i=f;return k|0}n=j+2476|0;m=b;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];c[n+12>>2]=c[m+12>>2];c[n+16>>2]=c[m+16>>2];if((a[1820736]&1)==0){w=q}else{m=c[494446]|0;n=(m|0)!=0?m:c[p>>2]|0;m=c[q+68>>2]|0;ei(n|0,714096,(v=i,i=i+8|0,c[v>>2]=m,v)|0)|0;i=v;m=c[494446]|0;n=(m|0)!=0?m:c[p>>2]|0;a_(n|0)|0;w=c[r>>2]|0}n=j+1720|0;m=j+1724|0;fj[c[w+20>>2]&511](n,m);if((a[1820736]&1)!=0){w=c[494446]|0;q=(w|0)!=0?w:c[p>>2]|0;w=c[n>>2]|0;u=c[m>>2]|0;ei(q|0,712720,(v=i,i=i+16|0,c[v>>2]=w,c[v+8>>2]=u,v)|0)|0;i=v;u=c[494446]|0;w=(u|0)!=0?u:c[p>>2]|0;a_(w|0)|0}w=b+9|0;fi[c[(c[r>>2]|0)+12>>2]&255]((a[w]&1)!=0?c[429349]|0:0);u=c[b>>2]|0;q=c[b+4>>2]|0;o=b+8|0;t=(a[o]&1)!=0;if(t&(u|0)==0&(q|0)==0){y=c[n>>2]|0;z=c[m>>2]|0}else{y=u;z=q}if(!(fp[c[(c[r>>2]|0)+16>>2]&63](y,z,t)|0)){aIq(j);k=0;i=f;return k|0}dK()|0;t=a4(7936)|0;z=a4(7937)|0;if((a[1820736]&1)!=0){y=c[494446]|0;q=(y|0)!=0?y:c[p>>2]|0;ei(q|0,711592,(v=i,i=i+16|0,c[v>>2]=t,c[v+8>>2]=z,v)|0)|0;i=v;z=c[494446]|0;t=(z|0)!=0?z:c[p>>2]|0;a_(t|0)|0}t=a4(7938)|0;if((a[1820736]&1)!=0){z=c[494446]|0;q=(z|0)!=0?z:c[p>>2]|0;ei(q|0,711008,(v=i,i=i+8|0,c[v>>2]=t,v)|0)|0;i=v;t=c[494446]|0;q=(t|0)!=0?t:c[p>>2]|0;a_(q|0)|0}q=c[(c[r>>2]|0)+52>>2]|0;t=6304;z=719360;do{y=fl[q&255](z)|0;u=c[t+4>>2]|0;x=y;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;x=x>>8;a[u+2|0]=x&255;x=x>>8;a[u+3|0]=x&255;t=t+8|0;z=c[t>>2]|0;}while((z|0)!=0);eF(770,771);a[12473924]=0;z=j+2584|0;do{if((a[z]&1)==0){t=a4(7939)|0;if((t|0)==0){A=0;break}A=(bx(t|0,704408)|0)!=0}else{A=0}}while(0);if((a[1820736]&1)!=0){t=c[494446]|0;q=(t|0)!=0?t:c[p>>2]|0;t=A?728536:726296;ei(q|0,730808,(v=i,i=i+16|0,c[v>>2]=704408,c[v+8>>2]=t,v)|0)|0;i=v;t=c[494446]|0;q=(t|0)!=0?t:c[p>>2]|0;a_(q|0)|0}do{if(A){if((a[1820736]&1)==0){break}q=c[494446]|0;t=(q|0)!=0?q:c[p>>2]|0;a5(703992,52,1,t|0)|0;t=c[494446]|0;q=(t|0)!=0?t:c[p>>2]|0;a_(q|0)|0}else{a[12473924]=1;q=c[494446]|0;t=(q|0)!=0?q:c[p>>2]|0;a5(703392,117,1,t|0)|0;t=c[494446]|0;q=(t|0)!=0?t:c[p>>2]|0;a_(q|0)|0}}while(0);a[j+8|0]=a[w]&1;a[j+1713|0]=a[o]&1;o=j+1728|0;w=j+1732|0;fj[c[(c[r>>2]|0)+20>>2]&511](o,w);if((a[1820736]&1)!=0){A=c[494446]|0;q=(A|0)!=0?A:c[p>>2]|0;A=c[o>>2]|0;t=c[w>>2]|0;ei(q|0,710192,(v=i,i=i+16|0,c[v>>2]=A,c[v+8>>2]=t,v)|0)|0;i=v;t=c[494446]|0;A=(t|0)!=0?t:c[p>>2]|0;a_(A|0)|0}if((c[n>>2]|0)==0){if((c[m>>2]|0)!=0){s=6401}}else{s=6401}if((s|0)==6401){c[n>>2]=c[o>>2];c[m>>2]=c[w>>2]}m=j+2016|0;c[m>>2]=(a[1919766]&1)!=0?264:232;n=j+48|0;c[n>>2]=4;A=(c[479937]|0)==2;t=j+1710|0;a[t]=A&1;if(A){c[n>>2]=1}A=j+2020|0;c[A>>2]=72;c[427256]=c[(c[r>>2]|0)+52>>2];q=c[479942]|0;u=c[479943]|0;a[1709032]=a[z]&1;c[427254]=q;c[427252]=u;if((a[1721516]&1)==0){B=0}else{B=(a[1717420]|0)!=0?1717420:0}u=h9(B,2)|0;do{if((u|0)==2){if((a[1820736]&1)!=0){q=c[494446]|0;z=(q|0)!=0?q:c[p>>2]|0;a5(705832,44,1,z|0)|0;z=c[494446]|0;q=(z|0)!=0?z:c[p>>2]|0;a_(q|0)|0}q=j+4|0;c[q>>2]=672352;if(jr(B)|0){break}z=c[494446]|0;y=(z|0)!=0?z:c[p>>2]|0;a5(704792,73,1,y|0)|0;y=c[494446]|0;z=(y|0)!=0?y:c[p>>2]|0;a_(z|0)|0;if(fl[c[c[q>>2]>>2]&255](0)|0){break}q=c[494446]|0;z=(q|0)!=0?q:c[p>>2]|0;a5(709504,47,1,z|0)|0;z=c[494446]|0;q=(z|0)!=0?z:c[p>>2]|0;a_(q|0)|0;fG[c[(c[r>>2]|0)+4>>2]&16383]();aIq(j);k=0;i=f;return k|0}else if((u|0)==3){if((a[1820736]&1)==0){break}q=c[494446]|0;a5(706200,41,1,((q|0)!=0?q:c[p>>2]|0)|0)|0;q=c[494446]|0;a_(((q|0)!=0?q:c[p>>2]|0)|0)|0}else{q=c[494446]|0;a5(705448,89,1,((q|0)!=0?q:c[p>>2]|0)|0)|0;q=c[494446]|0;a_(((q|0)!=0?q:c[p>>2]|0)|0)|0}}while(0);u=j+4|0;B=c[u>>2]|0;if((B|0)!=0){q=(fD[c[B+40>>2]&127]()|0)+1|0;B=c[n>>2]|0;c[n>>2]=q>>>0>B>>>0?q:B}B=a[1820736]|0;if((B&1)==0){C=B}else{B=c[494446]|0;q=(B|0)!=0?B:c[p>>2]|0;B=c[n>>2]|0;ei(q|0,699864,(v=i,i=i+8|0,c[v>>2]=B,v)|0)|0;i=v;B=c[494446]|0;q=(B|0)!=0?B:c[p>>2]|0;a_(q|0)|0;C=a[1820736]|0}if((C&1)!=0){C=c[494446]|0;q=(C|0)!=0?C:c[p>>2]|0;C=c[u>>2]|0;if((C|0)==0){D=0}else{D=fD[c[C+16>>2]&127]()|0}ei(q|0,709088,(v=i,i=i+8|0,c[v>>2]=D,v)|0)|0;i=v;v=c[494446]|0;D=(v|0)!=0?v:c[p>>2]|0;a_(D|0)|0}D=c[b+12>>2]<<8;v=j+1832|0;c[v>>2]=D;q=j+1836|0;c[q>>2]=D;a[j+1714|0]=a[b+10|0]&1;D=c[u>>2]|0;if((D|0)!=0){fi[c[D+12>>2]&255](0)}iE(j,c[o>>2]|0,c[w>>2]|0,1);D=c[u>>2]|0;if((D|0)!=0){fi[c[D+12>>2]&255](1)}iE(j,c[o>>2]|0,c[w>>2]|0,1);a[h]=0;w=c[u>>2]|0;do{if((w|0)==0){s=6430}else{if(!(fA[c[w+20>>2]&63](1,h)|0)){s=6430;break}c[j+468>>2]=(a[h]&1)!=0?9729:9728}}while(0);if((s|0)==6430){c[j+468>>2]=(a[b+11|0]&1)!=0?9729:9728}s=c[u>>2]|0;do{if((s|0)==0){E=33071}else{u=fl[c[s+24>>2]&255](1)|0;if((u|0)==2){E=10497;break}else if((u|0)==3){E=33648;break}else if((u|0)==0|(u|0)==1){E=33071;break}else{E=0;break}}}while(0);c[j+2040>>2]=E;E=(a[b+16|0]&1)!=0;s=E?32993:6407;u=j+2028|0;c[u>>2]=s;h=j+2032|0;c[h>>2]=s;c[j+2036>>2]=E?5121:33635;c[j+2044>>2]=E?4:2;if(!((a[12473924]&1)==0|E^1)){c[u>>2]=6408;c[h>>2]=6408}dg(2929);dg(2884);dg(3024);h=j+1840|0;aIy(h|0,1464,32)|0;c[j+2e3>>2]=c[m>>2];c[j+2008>>2]=h;c[j+2004>>2]=c[A>>2];c[j+2012>>2]=1464;A=ab(c[q>>2]|0,c[v>>2]|0)|0;h=A<<2;m=A>>>0>65535;if(m){F=(A&1073741823|0)==(A|0)?h:-1}else{F=h}u=aIp(F)|0;do{if((u|0)!=0){if((c[u-4>>2]&3|0)==0){break}aIv(u|0,0,F|0)}}while(0);c[j+472>>2]=u;if(m){G=(A&1073741823|0)==(A|0)?h:-1}else{G=h}h=aIp(G)|0;if((h|0)==0){c[j+476>>2]=0;fG[c[(c[r>>2]|0)+4>>2]&16383]();aIq(j);k=0;i=f;return k|0}if((c[h-4>>2]&3|0)!=0){aIv(h|0,0,G|0)}c[j+476>>2]=h;i5(j,b);do{if((c[n>>2]|0)!=0){b=j+1768|0;h=j+1800|0;G=0;do{c[b+(G<<2)>>2]=c[v>>2];c[h+(G<<2)>>2]=c[q>>2];G=G+1|0;H=c[n>>2]|0;}while(G>>>0<H>>>0);if((H|0)==0){break}G=j+12|0;h=j+52|0;b=0;do{c[h+(b*52|0)>>2]=c[G>>2];g[h+(b*52|0)+4>>2]=+((c[v>>2]|0)>>>0>>>0);g[h+(b*52|0)+12>>2]=+((c[v>>2]|0)>>>0>>>0);g[h+(b*52|0)+8>>2]=+((c[q>>2]|0)>>>0>>>0);g[h+(b*52|0)+16>>2]=+((c[q>>2]|0)>>>0>>>0);A=h+(b*52|0)+20|0;aIy(A|0,1464,32)|0;b=b+1|0;}while(b>>>0<(c[n>>2]|0)>>>0)}}while(0);iC(j,c[v>>2]|0,c[q>>2]|0);do{if((a[t]&1)!=0){if(i6(l,c[v>>2]|0,c[q>>2]|0)|0){break}fG[c[(c[r>>2]|0)+4>>2]&16383]();aIq(j);k=0;i=f;return k|0}}while(0);if(!((d|0)==0|(e|0)==0)){fj[c[(c[r>>2]|0)+48>>2]&511](d,e)}if((a[1733820]&1)!=0){c[j+2052>>2]=i9(j,1729717,+g[433454])|0?672272:0}switch(dK()|0){case 0:{k=j;i=f;return k|0};case 1285:{e=c[494446]|0;a5(707040,40,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[494446]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;break};case 1282:{e=c[494446]|0;a5(707720,44,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[494446]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;break};case 1281:{e=c[494446]|0;a5(708288,40,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[494446]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;break};case 1280:{e=c[494446]|0;a5(708656,39,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[494446]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;break};default:{e=c[494446]|0;a5(706576,45,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[494446]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0}}fG[c[(c[r>>2]|0)+4>>2]&16383]();aIq(j);k=0;i=f;return k|0}function iG(b,d,e,f,h,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ac=0,ad=0.0,ae=0,af=0.0,ag=0.0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0;k=i;i=i+992|0;l=k|0;m=k+64|0;n=k+96|0;o=k+928|0;q=k+936|0;r=b+4|0;s=c[r>>2]|0;if((s|0)!=0){fi[c[s+12>>2]&255](1)}s=b+1640|0;if((a[s]&1)!=0){iD(b,e,f,c[b+1760>>2]|0,c[b+1764>>2]|0);aZ(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);b2(36160,c[b+612>>2]|0);t=c[b+740>>2]|0;u=c[b+744>>2]|0;v=c[(c[b>>2]|0)+24>>2]|0;if((v|0)!=0){+ft[v&3](t,u)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=t;c[b+1748>>2]=u;eK(0,0,t|0,u|0);u=b+1936|0;aIv(u|0,0,48);g[b+1996>>2]=1.0;g[u>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;t=b+1872|0;aIy(t|0,u|0,64)|0;c[b+2e3>>2]=264}u=b+1711|0;do{if((a[u]&1)!=0){a[u]=0;t=b;v=b+1728|0;w=b+1732|0;fj[c[(c[t>>2]|0)+36>>2]&511](c[v>>2]|0,c[w>>2]|0);if((a[s]&1)==0){iE(b,c[v>>2]|0,c[w>>2]|0,1);break}w=b+1636|0;if((c[w>>2]|0)>0){v=b+740|0;x=v;y=b+612|0;z=y;A=b+676|0;B=0;while(1){C=c[x+(B*24|0)+8>>2]|0;D=x+(B*24|0)+16|0;E=c[x+(B*24|0)+12>>2]|0;F=x+(B*24|0)+20|0;if(C>>>0>(c[D>>2]|0)>>>0){G=6492}else{if(E>>>0>(c[F>>2]|0)>>>0){G=6492}}do{if((G|0)==6492){G=0;H=(C>>>0>E>>>0?C:E)-1|0;I=H>>>1|H;H=I>>>2|I;I=H>>>4|H;H=I>>>8|I;I=(H>>>16|H)+1|0;c[F>>2]=I;c[D>>2]=I;b2(36160,c[z+(B<<2)>>2]|0);I=A+(B<<2)|0;aZ(3553,c[I>>2]|0);d8(3553,0,32993,c[D>>2]|0,c[F>>2]|0,0,32993,5121,0);dy(36160,36064,3553,c[I>>2]|0,0);if((cp(36160)|0)!=36053){I=c[494446]|0;H=(I|0)!=0?I:c[p>>2]|0;a5(716992,50,1,H|0)|0;H=c[494446]|0;I=(H|0)!=0?H:c[p>>2]|0;a_(I|0)|0}if((a[1820736]&1)==0){break}I=c[494446]|0;H=(I|0)!=0?I:c[p>>2]|0;I=c[D>>2]|0;J=c[F>>2]|0;ei(H|0,715736,(H=i,i=i+24|0,c[H>>2]=B,c[H+8>>2]=I,c[H+16>>2]=J,H)|0)|0;i=H;H=c[494446]|0;J=(H|0)!=0?H:c[p>>2]|0;a_(J|0)|0}}while(0);F=B+1|0;if((F|0)<(c[w>>2]|0)){B=F}else{K=y;L=v;break}}}else{K=b+612|0;L=b+740|0}aZ(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);b2(36160,c[K>>2]|0);v=c[L>>2]|0;y=c[b+744>>2]|0;B=c[(c[t>>2]|0)+24>>2]|0;if((B|0)!=0){+ft[B&3](v,y)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=v;c[b+1748>>2]=y;eK(0,0,v|0,y|0);y=b+1936|0;aIv(y|0,0,48);g[b+1996>>2]=1.0;g[y>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;v=b+1872|0;aIy(v|0,y|0,64)|0;c[b+2e3>>2]=264}}while(0);L=b+44|0;K=c[L>>2]|0;L9059:do{if((d|0)==0){aZ(3553,c[b+12+(K<<2)>>2]|0);M=b+1708|0}else{u=b+48|0;y=((K+1|0)>>>0)%((c[u>>2]|0)>>>0)|0;c[L>>2]=y;aZ(3553,c[b+12+(y<<2)>>2]|0);y=b+1708|0;if((a[y]&1)!=0){M=y;break}v=c[L>>2]|0;B=b+1768|0;w=B+(v<<2)|0;if((c[w>>2]|0)==(e|0)){if((c[b+1800+(v<<2)>>2]|0)==(f|0)){G=6506}else{G=6504}}else{G=6504}do{if((G|0)==6504){A=b+472|0;if((c[A>>2]|0)==0){G=6506;break}c[w>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;fb(3317,(e<<2&4^4)+4|0);z=b+1832|0;x=b+1836|0;ea(3553,0,0,0,c[z>>2]|0,c[x>>2]|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[A>>2]|0);N=+(e>>>0>>>0)/+((c[z>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[x>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==6506){w=c[u>>2]|0;t=((v-1+w|0)>>>0)%(w>>>0)|0;if((c[B+(t<<2)>>2]|0)==(e|0)){if((c[b+1800+(t<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[b+2472|0]&1)!=0){c[o>>2]=0;B=ff[c[(c[b>>2]|0)+60>>2]&3](d,e,f,h,(c[b+2044>>2]|0)==4,c[L>>2]|0,o)|0;v=c[o>>2]|0;if((v|0)==0){u=c[494446]|0;t=(u|0)!=0?u:c[p>>2]|0;a5(717992,55,1,t|0)|0;t=c[494446]|0;u=(t|0)!=0?t:c[p>>2]|0;a_(u|0)|0;M=y;break}if(!B){M=y;break}fj[c[3579642]&511](3553,v);M=y;break}v=b+2044|0;B=ab(c[v>>2]|0,e)|0;do{if((B&1|0)==0){if((B&2|0)!=0){P=2;break}P=(B&4^4)+4|0}else{P=1}}while(0);fb(3317,P|0);B=c[v>>2]|0;do{if((B|0)==4){if((a[12473924]&1)==0){break}u=b+476|0;t=c[u>>2]|0;w=b+480|0;x=w;z=w;w=b+484|0;if((c[z>>2]|0)==(e|0)){if((c[w>>2]|0)!=(f|0)){G=6521}}else{G=6521}if((G|0)==6521){c[z>>2]=e;c[w>>2]=f;c[b+492>>2]=e;c[b+496>>2]=f;c[b+504>>2]=0;c[b+508>>2]=1;c[b+512>>2]=1;hR(x)|0}c[b+488>>2]=h;c[b+500>>2]=e<<2;h1(x,t,d);ea(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y;break L9059}}while(0);if(((h>>>0)/(B>>>0)|0|0)==(e|0)){ea(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,d|0);M=y;break}v=ab(B,e)|0;u=b+476|0;if((f|0)!=0){t=c[u>>2]|0;x=d;w=0;while(1){aIy(t|0,x|0,v)|0;z=w+1|0;if(z>>>0<f>>>0){t=t+v|0;x=x+h|0;w=z}else{break}}}ea(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y}}while(0);if((a[M]&1)!=0){h=c[L>>2]|0;d=b+1768|0;P=d+(h<<2)|0;if((c[P>>2]|0)==(e|0)){if((c[b+1800+(h<<2)>>2]|0)==(f|0)){G=6535}else{G=6533}}else{G=6533}do{if((G|0)==6533){if((c[b+472>>2]|0)==0){G=6535;break}c[P>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;N=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==6535){P=c[b+48>>2]|0;o=((h-1+P|0)>>>0)%(P>>>0)|0;if((c[d+(o<<2)>>2]|0)==(e|0)){if((c[b+1800+(o<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[s]&1)==0){b2(36160,0);iE(b,c[b+1728>>2]|0,c[b+1732>>2]|0,1)}dg(2929);dg(2960);dg(2884);dg(3024);dg(3042);eF(770,771);aO(0.0,0.0,0.0,1.0)}d=q;aIv(d|0,0,52);c[q>>2]=c[b+12+(c[L>>2]<<2)>>2];g[q+4>>2]=+(e>>>0>>>0);g[q+8>>2]=+(f>>>0>>>0);L=b+1832|0;g[q+12>>2]=+((c[L>>2]|0)>>>0>>>0);h=b+1836|0;g[q+16>>2]=+((c[h>>2]|0)>>>0>>>0);G=q+20|0;o=b+1840|0;aIy(G|0,o|0,32)|0;dl(16384);if((a[1717394]&1)!=0){fG[c[(c[b>>2]|0)+44>>2]&16383]();dl(16384)}G=c[r>>2]|0;do{if((G|0)==0){P=b+2e3|0;K=b+1872|0;Q=P;R=P;S=K;T=K}else{fm[c[G+8>>2]&3](e,f,c[L>>2]|0,c[h>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[494386]|0,q,b+52|0,0,0);K=c[r>>2]|0;P=b+2e3|0;w=P;x=b+1872|0;v=x;if((K|0)==0){Q=P;R=w;S=x;T=v;break}t=c[K+32>>2]|0;fl[t&255](w)|0;t=c[r>>2]|0;if((t|0)==0){Q=P;R=w;S=x;T=v;break}K=c[t+36>>2]|0;fl[K&255](v)|0;Q=P;R=w;S=x;T=v}}while(0);db(5,0,4);if((a[s]&1)!=0){s=m;aIv(s|0,0,32);h=b+2008|0;c[h>>2]=m;L=b+1636|0;f=c[L>>2]|0;e=b+740|0;G=m+8|0;v=m+24|0;x=m+20|0;w=m+28|0;if((f|0)>1){m=b+676|0;P=b+612|0;K=b;t=b+1740|0;B=b+1736|0;z=b+1744|0;A=b+1748|0;F=b+1936|0;D=b+52|0;E=n|0;C=F;J=b+1956|0;H=b+1976|0;I=b+1996|0;U=b+1984|0;V=b+1988|0;W=b+1992|0;X=1;Y=0;while(1){Z=X-1|0;_=e+(Z*24|0)|0;N=+((c[_>>2]|0)>>>0>>>0);$=e+(Z*24|0)+16|0;O=+((c[$>>2]|0)>>>0>>>0);aa=N/O;ac=e+(Z*24|0)+4|0;ad=+((c[ac>>2]|0)>>>0>>>0);ae=e+(Z*24|0)+20|0;af=+((c[ae>>2]|0)>>>0>>>0);ag=ad/af;g[G>>2]=aa;g[v>>2]=aa;g[x>>2]=ag;g[w>>2]=ag;ah=m+(Z<<2)|0;c[n+(Z*52|0)>>2]=c[ah>>2];g[n+(Z*52|0)+4>>2]=N;g[n+(Z*52|0)+8>>2]=ad;g[n+(Z*52|0)+12>>2]=O;g[n+(Z*52|0)+16>>2]=af;ai=n+(Z*52|0)+20|0;aIy(ai|0,s|0,32)|0;b2(36160,c[P+(X<<2)>>2]|0);ai=c[r>>2]|0;if((ai|0)!=0){fi[c[ai+12>>2]&255](X+1|0)}aZ(3553,c[ah>>2]|0);dl(16384);ah=c[e+(X*24|0)>>2]|0;ai=c[e+(X*24|0)+4>>2]|0;Z=c[(c[K>>2]|0)+24>>2]|0;if((Z|0)!=0){+ft[Z&3](ah,ai)}c[t>>2]=0;c[B>>2]=0;c[z>>2]=ah;c[A>>2]=ai;eK(0,0,ah|0,ai|0);aIv(F|0,0,48);g[I>>2]=1.0;g[C>>2]=2.0;g[J>>2]=2.0;g[H>>2]=-1.0;g[U>>2]=-1.0;g[V>>2]=-1.0;g[W>>2]=-0.0;aIy(S|0,F|0,64)|0;ai=c[r>>2]|0;do{if((ai|0)!=0){fm[c[ai+8>>2]&3](c[_>>2]|0,c[ac>>2]|0,c[$>>2]|0,c[ae>>2]|0,c[z>>2]|0,c[A>>2]|0,c[494386]|0,q,D,E,Y);ah=c[r>>2]|0;if((ah|0)==0){break}Z=c[ah+32>>2]|0;fl[Z&255](R)|0;Z=c[r>>2]|0;if((Z|0)==0){break}ah=c[Z+36>>2]|0;fl[ah&255](T)|0}}while(0);db(5,0,4);ae=Y+1|0;$=X+1|0;ac=c[L>>2]|0;if(($|0)<(ac|0)){X=$;Y=ae}else{aj=ae;ak=ac;break}}}else{aj=0;ak=f}f=ak-1|0;ak=e+(f*24|0)|0;Y=e+(f*24|0)+16|0;af=+((c[ak>>2]|0)>>>0>>>0)/+((c[Y>>2]|0)>>>0>>>0);X=e+(f*24|0)+4|0;E=e+(f*24|0)+20|0;O=+((c[X>>2]|0)>>>0>>>0)/+((c[E>>2]|0)>>>0>>>0);g[G>>2]=af;g[v>>2]=af;g[x>>2]=O;g[w>>2]=O;b2(36160,0);w=c[r>>2]|0;if((w|0)!=0){fi[c[w+12>>2]&255]((c[L>>2]|0)+1|0)}aZ(3553,c[b+676+((c[L>>2]|0)-1<<2)>>2]|0);dl(16384);iE(b,c[b+1728>>2]|0,c[b+1732>>2]|0,1);L=c[r>>2]|0;do{if((L|0)==0){c[Q>>2]=c[b+2016>>2]}else{fm[c[L+8>>2]&3](c[ak>>2]|0,c[X>>2]|0,c[Y>>2]|0,c[E>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[494386]|0,q,b+52|0,n|0,aj);w=c[r>>2]|0;c[Q>>2]=c[b+2016>>2];if((w|0)==0){break}x=c[w+32>>2]|0;fl[x&255](R)|0;x=c[r>>2]|0;if((x|0)==0){break}w=c[x+36>>2]|0;fl[w&255](T)|0}}while(0);db(5,0,4);c[h>>2]=o}h=b+52|0;aIC(b+104|0,h|0,((c[b+48>>2]|0)*52|0)-52|0);aIy(h|0,d|0,52)|0;do{if((a[b+2576|0]&1)!=0){d=c[b+2572>>2]|0;if((d|0)==0){break}h=l|0;g[h>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2580>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;T=Q;c[T>>2]=232;aj=b+2008|0;c[aj>>2]=1464;n=b+2004|0;c[n>>2]=h;aZ(3553,d|0);d=c[r>>2]|0;do{if((d|0)!=0){fi[c[d+12>>2]&255](15);h=c[r>>2]|0;q=b+1936|0;if((h|0)==0){break}E=c[h+32>>2]|0;fl[E&255](R)|0;E=c[r>>2]|0;if((E|0)==0){break}h=c[E+36>>2]|0;fl[h&255](q)|0}}while(0);eq(3042);if((a[b+2577|0]&1)==0){db(5,0,4)}else{eK(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);db(5,0,4);eK(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}dg(3042);c[T>>2]=c[b+2016>>2];c[aj>>2]=o;c[n>>2]=c[b+2020>>2]}}while(0);do{if((j|0)!=0){d=c[b+2052>>2]|0;if((d|0)==0){break}fF[c[d+8>>2]&127](b,j,0)}}while(0);if((a[b+2496|0]&1)!=0){aZ(3553,c[b+2500>>2]|0);j=l|0;g[j>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2568>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;l=c[r>>2]|0;if((l|0)!=0){fi[c[l+12>>2]&255](15)}eq(3042);l=Q;c[l>>2]=b+2536;Q=b+2008|0;c[Q>>2]=b+2504;d=b+2004|0;c[d>>2]=j;j=b+1936|0;q=c[r>>2]|0;do{if((q|0)!=0){h=c[q+32>>2]|0;fl[h&255](R)|0;h=c[r>>2]|0;if((h|0)==0){break}E=c[h+36>>2]|0;fl[E&255](j)|0}}while(0);if((a[b+2497|0]&1)==0){db(5,0,4)}else{eK(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);db(5,0,4);eK(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}dg(3042);c[l>>2]=c[b+2016>>2];c[Q>>2]=o;c[d>>2]=c[b+2020>>2]}d=b;fG[c[(c[d>>2]|0)+28>>2]&16383]();if((a[M]&1)==0){al=c[d>>2]|0;am=al+44|0;an=c[am>>2]|0;fG[an&16383]();ao=c[494386]|0;ap=ao+1|0;c[494386]=ap;i=k;return 1}M=c[r>>2]|0;if((M|0)!=0){fi[c[M+12>>2]&255](0)}aZ(3553,0);al=c[d>>2]|0;am=al+44|0;an=c[am>>2]|0;fG[an&16383]();ao=c[494386]|0;ap=ao+1|0;c[494386]=ap;i=k;return 1}function iH(a,b){a=a|0;b=b|0;c[b>>2]=672328;return}function iI(a,b){a=a|0;b=b|0;c[b>>2]=672288;return}function iJ(a){a=a|0;return c[a+1644+(((((c[a+44>>2]|0)+1|0)>>>0)%((c[a+48>>2]|0)>>>0)|0)<<2)>>2]|0}function iK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;if((a[1820736]&1)!=0){f=c[494446]|0;g=(f|0)!=0?f:c[p>>2]|0;f=d?719984:718976;ei(g|0,720992,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;g=c[494446]|0;f=(g|0)!=0?g:c[p>>2]|0;a_(f|0)|0}fi[c[(c[b>>2]|0)+12>>2]&255](d?0:c[429349]|0);i=e;return}function iL(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;f=d+8|0;fh[c[(c[b>>2]|0)+32>>2]&15](e,f,b+1728|0,b+1732|0,c[494386]|0);do{if((a[e]&1)==0){if((a[f]&1)==0){break}a[b+1711|0]=1}else{a[b+1712|0]=1}}while(0);i=d;return(a[b+1712|0]&1)==0|0}function iM(a){a=a|0;return fD[c[(c[a>>2]|0)+40>>2]&127]()|0}function iN(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+8|0;h=f|0;j=b;if((d|0)==3){k=0;i=f;return k|0}l=b+4|0;m=c[l>>2]|0;if((m|0)!=0){fG[c[m+4>>2]&16383]()}m=(d|0)==2;c[l>>2]=m?672352:0;if(!m){m=c[494446]|0;d=(m|0)!=0?m:c[p>>2]|0;ei(d|0,707360,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;d=c[494446]|0;m=(d|0)!=0?d:c[p>>2]|0;a_(m|0)|0;k=0;i=f;return k|0}m=b+1640|0;if((a[m]&1)!=0){d=b+1636|0;bh(c[d>>2]|0,b+676|0);o=b+612|0;b9(c[d>>2]|0,o|0);a[m]=0;c[d>>2]=0;aIv(o|0,0,128)}o=b+44|0;d=b+12|0;aZ(3553,c[d+(c[o>>2]<<2)>>2]|0);if(!(fl[c[c[l>>2]>>2]&255](e)|0)){e=c[494446]|0;m=(e|0)!=0?e:c[p>>2]|0;a5(703032,81,1,m|0)|0;m=c[494446]|0;e=(m|0)!=0?m:c[p>>2]|0;a_(e|0)|0;if(fl[c[c[l>>2]>>2]&255](0)|0){k=0;i=f;return k|0}c[l>>2]=0;k=0;i=f;return k|0}a[h]=0;e=c[l>>2]|0;if((e|0)==0){q=6622}else{if(!(fA[c[e+20>>2]&63](1,h)|0)){q=6622}}if((q|0)==6622){a[h]=a[1717404]&1}e=c[l>>2]|0;do{if((e|0)==0){r=33071}else{m=fl[c[e+24>>2]&255](1)|0;if((m|0)==3){r=33648;break}else if((m|0)==0|(m|0)==1){r=33071;break}else if((m|0)==2){r=10497;break}else{r=0;break}}}while(0);e=a[h]&1;a[b+2487|0]=e;h=e<<24>>24!=0?9729:9728;e=b+468|0;m=b+2040|0;if((h|0)==(c[e>>2]|0)){if((r|0)!=(c[m>>2]|0)){q=6630}}else{q=6630}if((q|0)==6630){c[e>>2]=h;c[m>>2]=r;r=b+48|0;h=c[r>>2]|0;if((h|0)!=0){q=0;s=h;while(1){h=c[j+12+(q<<2)>>2]|0;if((h|0)==0){t=s}else{aZ(3553,h|0);e2(3553,10242,c[m>>2]|0);e2(3553,10243,c[m>>2]|0);e2(3553,10240,c[e>>2]|0);e2(3553,10241,c[e>>2]|0);t=c[r>>2]|0}h=q+1|0;if(h>>>0<t>>>0){q=h;s=t}else{break}}}aZ(3553,c[j+12+(c[o>>2]<<2)>>2]|0)}t=c[l>>2]|0;do{if((t|0)!=0){s=(fD[c[t+40>>2]&127]()|0)+1|0;q=b+48|0;r=c[q>>2]|0;if(s>>>0<=r>>>0){break}e=b+1708|0;if((a[e]&1)!=0){b9(r|0,b+1644|0)}if((a[b+1709|0]&1)!=0){bO(c[q>>2]|0,b+1676|0)}a[e]=0;e=d;bh(c[q>>2]|0,e|0);c[q>>2]=s;if((a[1820736]&1)!=0){r=c[494446]|0;m=(r|0)!=0?r:c[p>>2]|0;ei(m|0,699864,(n=i,i=i+8|0,c[n>>2]=s,n)|0)|0;i=n;s=c[494446]|0;m=(s|0)!=0?s:c[p>>2]|0;a_(m|0)|0}c[o>>2]=0;i5(b,b+2476|0);do{if((c[q>>2]|0)!=0){m=b+1832|0;s=b+1768|0;r=b+1836|0;h=b+1800|0;u=0;do{c[s+(u<<2)>>2]=c[m>>2];c[h+(u<<2)>>2]=c[r>>2];u=u+1|0;v=c[q>>2]|0;}while(u>>>0<v>>>0);if((v|0)==0){break}u=b+52|0;h=0;do{c[u+(h*52|0)>>2]=c[e>>2];g[u+(h*52|0)+4>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+12>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+8>>2]=+((c[r>>2]|0)>>>0>>>0);g[u+(h*52|0)+16>>2]=+((c[r>>2]|0)>>>0>>>0);s=u+(h*52|0)+20|0;aIy(s|0,1464,32)|0;h=h+1|0;}while(h>>>0<(c[q>>2]|0)>>>0)}}while(0);if((a[b+1710|0]&1)==0){break}q=c[b+1832>>2]|0;e=c[b+1836>>2]|0;i6(j,q,e)|0}}while(0);iC(b,c[b+1832>>2]|0,c[b+1836>>2]|0);j=c[l>>2]|0;if((j|0)!=0){fi[c[j+12>>2]&255](0)}j=b+1728|0;v=b+1732|0;iE(b,c[j>>2]|0,c[v>>2]|0,1);o=c[l>>2]|0;if((o|0)!=0){fi[c[o+12>>2]&255](1)}iE(b,c[j>>2]|0,c[v>>2]|0,1);k=1;i=f;return k|0}function iO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[b+2052>>2]|0;if((d|0)!=0){fi[c[d+4>>2]&255](b)}d=b+4|0;e=c[d>>2]|0;if((e|0)!=0){fG[c[e+4>>2]&16383]()}c[d>>2]=0;d=b+48|0;bh(c[d>>2]|0,b+12|0);e=b+2572|0;if((c[e>>2]|0)!=0){bh(1,e|0)}e=b+2500|0;if((c[e>>2]|0)!=0){bh(1,e|0)}e=b+544|0;aIq(c[e>>2]|0);aIq(c[b+556>>2]|0);aIq(c[b+560>>2]|0);aIq(c[b+572>>2]|0);aIq(c[b+584>>2]|0);aIq(c[b+576>>2]|0);aIq(c[b+600>>2]|0);aIv(e|0,0,64);e=b+1640|0;if((a[e]&1)!=0){f=b+1636|0;bh(c[f>>2]|0,b+676|0);g=b+612|0;b9(c[f>>2]|0,g|0);a[e]=0;c[f>>2]=0;aIv(g|0,0,128)}g=b+1708|0;if((a[g]&1)!=0){b9(c[d>>2]|0,b+1644|0)}if((a[b+1709|0]&1)==0){a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;fG[k&16383]();l=b+472|0;m=l;n=c[m>>2]|0;aIq(n);o=b+476|0;p=o;q=c[p>>2]|0;aIq(q);aIq(b);return}bO(c[d>>2]|0,b+1676|0);a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;fG[k&16383]();l=b+472|0;m=l;n=c[m>>2]|0;aIq(n);o=b+476|0;p=o;q=c[p>>2]|0;aIq(q);aIq(b);return}function iP(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=d;c[e>>2]=c[168062];c[e+4>>2]=c[168063];c[e+8>>2]=c[168064];c[e+12>>2]=c[168065];c[e+16>>2]=c[168066];a[d+9|0]=a[1717392]&1;a[d+10|0]=0;a[d+11|0]=a[1717404]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[429354]|0)==7){c[d>>2]=c[494433];c[d+4>>2]=c[494434]}e=iF(d,0,0)|0;c[3118440]=e;c[3118488]=672288;c[e+2052>>2]=i9(e,1729717,+g[433454])|0?672272:0;i=b;return}function iQ(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=c[3118440]|0;if((e|0)==0){i=b;return}c[3118440]=0;iO(e);e=d;c[e>>2]=c[168062];c[e+4>>2]=c[168063];c[e+8>>2]=c[168064];c[e+12>>2]=c[168065];c[e+16>>2]=c[168066];a[d+9|0]=a[1717392]&1;a[d+10|0]=0;a[d+11|0]=a[1717404]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[429354]|0)==7){c[d>>2]=c[494433];c[d+4>>2]=c[494434]}e=iF(d,0,0)|0;c[3118440]=e;c[3118488]=672288;c[e+2052>>2]=i9(e,1729717,+g[433454])|0?672272:0;i=b;return}function iR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0.0,j=0.0,k=0.0;d=i;i=i+64|0;e=d|0;f=b*90|0;c[a+1716>>2]=f;b=a+1936|0;aIv(b|0,0,48);g[a+1996>>2]=1.0;g[b>>2]=2.0;g[a+1956>>2]=2.0;g[a+1976>>2]=-1.0;g[a+1984>>2]=-1.0;g[a+1988>>2]=-1.0;g[a+1992>>2]=-0.0;h=+(f>>>0>>>0)*3.141592653589793/180.0;j=+T(+h);k=+U(+h);aIv(e|0,0,60);g[e+40>>2]=1.0;g[e+60>>2]=1.0;g[e>>2]=j;g[e+20>>2]=j;g[e+16>>2]=-0.0-k;g[e+4>>2]=k;i7(a+1872|0,e,b);i=d;return}function iS(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+1736|0;e=b;c[e>>2]=c[d>>2];c[e+4>>2]=c[d+4>>2];c[e+8>>2]=c[d+8>>2];c[e+12>>2]=c[d+12>>2];c[e+16>>2]=c[d+16>>2];c[e+20>>2]=c[d+20>>2];c[b+16>>2]=c[a+1728>>2];d=a+1732|0;c[b+20>>2]=c[d>>2];a=b+4|0;c[a>>2]=(c[d>>2]|0)-((c[b+12>>2]|0)+(c[a>>2]|0));return}function iT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((a[b+1708|0]&1)==0){if((a[b+1640|0]&1)!=0){e=6693}}else{e=6693}if((e|0)==6693){b2(36160,0)}e=b+1736|0;f=b+1744|0;g=(c[f>>2]|0)*3|0;do{if((g&1|0)==0){if((g&2|0)!=0){h=2;break}h=(g&4^4)+4|0}else{h=1}}while(0);fb(3333,h|0);h=b+1748|0;dS(c[e>>2]|0,c[b+1740>>2]|0,c[f>>2]|0,c[h>>2]|0,6407,5121,d|0);b=ab(c[h>>2]|0,c[f>>2]|0)|0;f=0;h=d;while(1){d=h+2|0;e=a[d]|0;a[d]=a[h]|0;a[h]=e;e=f+1|0;if(e>>>0>b>>>0){break}else{f=e;h=h+3|0}}return 1}function iU(a,b){a=a|0;b=b|0;return fl[c[(c[a>>2]|0)+52>>2]&255](b)|0}function iV(b){b=b|0;a[b+1711|0]=1;return}function iW(b,c,d){b=b|0;c=c|0;d=d|0;a[b+2576|0]=c&1;a[b+2577|0]=d&1;return}function iX(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;g[a+2504>>2]=b;g[a+2508>>2]=c;f=b+d;g[a+2512>>2]=f;g[a+2516>>2]=c;g[a+2520>>2]=b;b=c+e;g[a+2524>>2]=b;g[a+2528>>2]=f;g[a+2532>>2]=b;return}function iY(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;f=1.0-c;g[a+2536>>2]=b;g[a+2540>>2]=f;c=b+d;g[a+2544>>2]=c;g[a+2548>>2]=f;g[a+2552>>2]=b;b=f-e;g[a+2556>>2]=b;g[a+2560>>2]=c;g[a+2564>>2]=b;return}function iZ(b,c){b=b|0;c=c|0;a[b+2497|0]=c&1;return}function i_(a,b){a=a|0;b=+b;g[a+2568>>2]=b;return}function i$(b,d){b=b|0;d=d|0;var e=0,f=0.0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;L9342:do{if((d|0)==6){if((a[1977788]&1)==0){break}f=+g[478764];if(f>0.0){g[172542]=f;break}else{g[172542]=+((c[478760]|0)>>>0>>>0)/+((c[478761]|0)>>>0>>>0);break}}else if((d|0)==5){h=c[478760]|0;j=c[478761]|0;if((h|0)==0|(j|0)==0){break}k=h>>>0<j>>>0?h:j;if(k>>>0>1){l=1;m=1;while(1){if(((h>>>0)%(l>>>0)|0|0)==0){n=((j>>>0)%(l>>>0)|0|0)==0?l:m}else{n=m}o=l+1|0;if(o>>>0<k>>>0){l=o;m=n}else{p=n;break}}}else{p=1}m=(h>>>0)/(p>>>0)|0;l=(j>>>0)/(p>>>0)|0;bQ(690036,64,708920,(k=i,i=i+16|0,c[k>>2]=m,c[k+8>>2]=l,k)|0)|0;i=k;g[172525]=+(m>>>0>>>0)/+(l>>>0>>>0)}else if((d|0)==4){f=+g[429352];if(f>=0.0){g[172508]=f;break}f=+g[478764];do{if(f>0.0){if((a[1717412]&1)==0){break}g[172508]=f;break L9342}}while(0);g[172508]=+((c[478760]|0)>>>0>>>0)/+((c[478761]|0)>>>0>>>0)}}while(0);g[478770]=+g[689760+(d*68|0)>>2];a[b+1714|0]=1;a[b+1711|0]=1;i=e;return}function i0(b,d,e,f,h,i){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=+i;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=b+2572|0;k=c[j>>2]|0;if((k|0)==0){bA(1,j|0);aZ(3553,c[j>>2]|0);e2(3553,10242,33071);e2(3553,10243,33071);e2(3553,10240,9729);e2(3553,10241,9729)}else{aZ(3553,k|0)}g[b+2580>>2]=i;k=ab(e?4:2,f)|0;if((k&2|0)==0){l=(k&4^4)+4|0}else{l=2}fb(3317,l|0);if(e){e=(a[12473924]&1)!=0?6408:32993;d8(3553,0,e|0,f|0,h|0,0,e|0,5121,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;aZ(3553,s|0);return}else{d8(3553,0,6408,f|0,h|0,0,6408,32819,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;aZ(3553,s|0);return}}function i1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+2052>>2]|0;if((e|0)==0){return}fF[c[e+8>>2]&127](a,b,d);return}function i2(a,b){a=a|0;b=b|0;var d=0;d=c[(c[a>>2]|0)+64>>2]|0;if((d|0)==0){return}fi[d&255](b);return}function i3(b,d){b=b|0;d=d|0;var e=0;a[b+2496|0]=d&1;e=c[(c[b>>2]|0)+64>>2]|0;if((e|0)==0){return}if((a[b+1713|0]&1)==0){return}fi[e&255](d);return}function i4(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0;h=b+2500|0;i=c[h>>2]|0;if((i|0)==0){bA(1,h|0);j=c[h>>2]|0}else{j=i}aZ(3553,j|0);e2(3553,10242,33071);e2(3553,10243,33071);e2(3553,10240,9729);e2(3553,10241,9729);fb(3317,(e<<2&4^4)+4|0);j=(a[12473924]&1)!=0?6408:32993;d8(3553,0,j|0,e|0,f|0,0,j|0,5121,d|0);g[b+2504>>2]=0.0;g[b+2508>>2]=0.0;g[b+2512>>2]=1.0;g[b+2516>>2]=0.0;g[b+2520>>2]=0.0;g[b+2524>>2]=1.0;g[b+2528>>2]=1.0;g[b+2532>>2]=1.0;g[b+2536>>2]=0.0;g[b+2540>>2]=1.0;g[b+2544>>2]=1.0;g[b+2548>>2]=1.0;g[b+2552>>2]=0.0;g[b+2556>>2]=0.0;g[b+2560>>2]=1.0;g[b+2564>>2]=0.0;return 1}function i5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;f=b+1710|0;g=a[f]|0;if((g&1)==0&(c[3579642]|0)!=0){h=(fl[c[(c[b>>2]|0)+56>>2]&255](d)|0)&1;j=h;k=a[f]|0}else{j=0;k=g}g=b+2472|0;a[g]=j;j=c[b+2028>>2]|0;f=c[b+2032>>2]|0;h=c[b+2036>>2]|0;do{if((k&1)==0){l=j;m=h;n=f}else{if((c[b+2044>>2]|0)!=4){l=j;m=h;n=f;break}d=b+2584|0;do{if((a[d]&1)==0){o=a4(7939)|0;if((o|0)==0){q=0;break}q=(bx(o|0,724784)|0)!=0}else{q=0}}while(0);if((a[1820736]&1)!=0){o=c[494446]|0;r=(o|0)!=0?o:c[p>>2]|0;o=q?728536:726296;ei(r|0,730808,(s=i,i=i+16|0,c[s>>2]=724784,c[s+8>>2]=o,s)|0)|0;i=s;o=c[494446]|0;r=(o|0)!=0?o:c[p>>2]|0;a_(r|0)|0}if(q){l=6408;m=5121;n=6408;break}do{if((a[d]&1)==0){r=a4(7939)|0;if((r|0)==0){t=0;break}t=(bx(r|0,723800)|0)!=0}else{t=0}}while(0);if((a[1820736]&1)!=0){d=c[494446]|0;r=(d|0)!=0?d:c[p>>2]|0;d=t?728536:726296;ei(r|0,730808,(s=i,i=i+16|0,c[s>>2]=723800,c[s+8>>2]=d,s)|0)|0;i=s;d=c[494446]|0;r=(d|0)!=0?d:c[p>>2]|0;a_(r|0)|0}if(t){l=6408;m=5121;n=6408;break}r=c[494446]|0;d=(r|0)!=0?r:c[p>>2]|0;a5(722352,76,1,d|0)|0;d=c[494446]|0;r=(d|0)!=0?d:c[p>>2]|0;a_(r|0)|0;l=6407;m=33635;n=6407}}while(0);t=b+48|0;s=b+12|0;q=s;bA(c[t>>2]|0,s|0);if((c[t>>2]|0)==0){u=b+44|0;v=u;w=c[v>>2]|0;x=q+(w<<2)|0;y=c[x>>2]|0;aZ(3553,y|0);i=e;return}s=b+2040|0;f=b+468|0;h=b+1832|0;j=b+1836|0;k=b+472|0;r=0;do{aZ(3553,c[q+(r<<2)>>2]|0);e2(3553,10242,c[s>>2]|0);e2(3553,10243,c[s>>2]|0);e2(3553,10240,c[f>>2]|0);e2(3553,10241,c[f>>2]|0);if((a[g]&1)==0){d8(3553,0,l|0,c[h>>2]|0,c[j>>2]|0,0,n|0,m|0,c[k>>2]|0)}r=r+1|0;}while(r>>>0<(c[t>>2]|0)>>>0);u=b+44|0;v=u;w=c[v>>2]|0;x=q+(w<<2)|0;y=c[x>>2]|0;aZ(3553,y|0);i=e;return}
function i6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f|0;h=f+8|0;if((a[1820736]&1)!=0){j=c[494446]|0;k=(j|0)!=0?j:c[p>>2]|0;ei(k|0,697656,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;k=c[494446]|0;j=(k|0)!=0?k:c[p>>2]|0;a_(j|0)|0}c[g>>2]=0;c[h>>2]=0;dY(3379,g|0);dY(34024,h|0);if((a[1820736]&1)!=0){j=c[494446]|0;k=(j|0)!=0?j:c[p>>2]|0;j=c[g>>2]|0;g=c[h>>2]|0;ei(k|0,695728,(l=i,i=i+16|0,c[l>>2]=j,c[l+8>>2]=g,l)|0)|0;i=l;g=c[494446]|0;j=(g|0)!=0?g:c[p>>2]|0;a_(j|0)|0}aZ(3553,0);j=b+48|0;dT(c[j>>2]|0,b+1644|0);g=(a[1919764]&1)==0;k=(a[1919765]&1)!=0;do{if(k){do{if((a[b+2584|0]&1)==0){h=a4(7939)|0;if((h|0)==0){m=0;break}m=(bx(h|0,693784)|0)!=0}else{m=0}}while(0);if((a[1820736]&1)!=0){h=c[494446]|0;n=(h|0)!=0?h:c[p>>2]|0;h=m?728536:726296;ei(n|0,730808,(l=i,i=i+16|0,c[l>>2]=693784,c[l+8>>2]=h,l)|0)|0;i=l;h=c[494446]|0;n=(h|0)!=0?h:c[p>>2]|0;a_(n|0)|0}if(m){break}else{o=0}i=f;return o|0}}while(0);L9452:do{if(g){if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=6804;break L9452}b2(36160,c[b+1644+(m<<2)>>2]|0);dy(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=cp(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=6803;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=6804;break L9452}b2(36160,c[b+1644+(m<<2)>>2]|0);dy(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=cp(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=6803;break}}}}else{cZ(c[j>>2]|0,b+1676|0);a[b+1709|0]=1;if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=6804;break L9452}b2(36160,c[b+1644+(m<<2)>>2]|0);dy(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;c7(36161,c[n>>2]|0);cj(36161,35056,d|0,e|0);c7(36161,0);dU(36160,36096,36161,c[n>>2]|0);dU(36160,36128,36161,c[n>>2]|0);n=cp(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=6803;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=6804;break L9452}b2(36160,c[b+1644+(m<<2)>>2]|0);dy(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;c7(36161,c[n>>2]|0);cj(36161,33189,d|0,e|0);c7(36161,0);dU(36160,36096,36161,c[n>>2]|0);n=cp(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=6803;break}}}}}while(0);if((q|0)==6804){b2(36160,0);a[b+1708|0]=1;o=1;i=f;return o|0}else if((q|0)==6803){q=c[494446]|0;ei(((q|0)!=0?q:c[p>>2]|0)|0,691576,(l=i,i=i+16|0,c[l>>2]=r,c[l+8>>2]=s,l)|0)|0;i=l;l=c[494446]|0;a_(((l|0)!=0?l:c[p>>2]|0)|0)|0;o=0;i=f;return o|0}return 0}function i7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0.0,A=0,B=0.0,C=0,D=0.0;d=i;i=i+64|0;e=d|0;f=+g[c>>2];h=+g[c+4>>2];j=+g[c+8>>2];k=+g[c+12>>2];l=+g[c+16>>2];m=+g[c+20>>2];n=+g[c+24>>2];o=+g[c+28>>2];p=+g[c+32>>2];q=+g[c+36>>2];r=+g[c+40>>2];s=+g[c+44>>2];t=+g[c+48>>2];u=+g[c+52>>2];v=+g[c+56>>2];w=+g[c+60>>2];c=0;do{x=+g[b+(c<<2)>>2];y=c+4|0;z=+g[b+(y<<2)>>2];A=c+8|0;B=+g[b+(A<<2)>>2];C=c+12|0;D=+g[b+(C<<2)>>2];g[e+(c<<2)>>2]=x*f+0.0+z*h+B*j+D*k;g[e+(y<<2)>>2]=x*l+0.0+z*m+B*n+D*o;g[e+(A<<2)>>2]=x*p+0.0+z*q+B*r+D*s;g[e+(C<<2)>>2]=x*t+0.0+z*u+B*v+D*w;c=c+1|0;}while(c>>>0<4);c=a;a=e;aIy(c|0,a|0,64)|0;i=d;return}function i8(a){a=a|0;var b=0;b=c[a+2048>>2]|0;if((b|0)==0){return}fi[c[(c[a+2056>>2]|0)+12>>2]&255](b);bh(1,a+2060|0);b=c[a+2076>>2]|0;if((b|0)==0){return}aIq(b);return}function i9(b,d,e){b=b|0;d=d|0;e=+e;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0;d=i;if((a[1733820]&1)==0){f=0;i=d;return f|0}h=b+2056|0;j=b+2048|0;k=ic((a[1729717]|0)!=0?1729717:14317944,+g[433454])|0;c[j>>2]=k;if((k|0)==0){k=c[494446]|0;l=(k|0)!=0?k:c[p>>2]|0;ei(l|0,727688,(m=i,i=i+8|0,c[m>>2]=723880,m)|0)|0;i=m;l=c[494446]|0;k=(l|0)!=0?l:c[p>>2]|0;a_(k|0)|0;c[h>>2]=0;c[j>>2]=0;j=c[494446]|0;k=(j|0)!=0?j:c[p>>2]|0;a5(727040,49,1,k|0)|0;k=c[494446]|0;j=(k|0)!=0?k:c[p>>2]|0;a_(j|0)|0;f=0;i=d;return f|0}if((a[1820736]&1)!=0){j=c[494446]|0;k=(j|0)!=0?j:c[p>>2]|0;ei(k|0,724e3,(m=i,i=i+8|0,c[m>>2]=723880,m)|0)|0;i=m;m=c[494446]|0;k=(m|0)!=0?m:c[p>>2]|0;a_(k|0)|0}c[h>>2]=687632;h=b+2060|0;bA(1,h|0);aZ(3553,c[h>>2]|0);e2(3553,10242,33071);e2(3553,10243,33071);e2(3553,10240,9729);e2(3553,10241,9729);aZ(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);dY(3379,b+2064|0);e=+g[433458];g[b+2344>>2]=e;n=+g[433459];g[b+2348>>2]=n;o=+g[433460];g[b+2352>>2]=o;g[b+2356>>2]=1.0;q=+g[433458];g[b+2360>>2]=q;r=+g[433459];g[b+2364>>2]=r;s=+g[433460];g[b+2368>>2]=s;g[b+2372>>2]=1.0;t=+g[433458];g[b+2376>>2]=t;u=+g[433459];g[b+2380>>2]=u;v=+g[433460];g[b+2384>>2]=v;g[b+2388>>2]=1.0;w=+g[433458];g[b+2392>>2]=w;x=+g[433459];g[b+2396>>2]=x;y=+g[433460];g[b+2400>>2]=y;g[b+2404>>2]=1.0;g[b+2408>>2]=e*.3;g[b+2412>>2]=n*.3;g[b+2416>>2]=o*.3;g[b+2420>>2]=1.0;g[b+2424>>2]=q*.3;g[b+2428>>2]=r*.3;g[b+2432>>2]=s*.3;g[b+2436>>2]=1.0;g[b+2440>>2]=t*.3;g[b+2444>>2]=u*.3;g[b+2448>>2]=v*.3;g[b+2452>>2]=1.0;g[b+2456>>2]=w*.3;g[b+2460>>2]=x*.3;g[b+2464>>2]=y*.3;g[b+2468>>2]=1.0;f=1;i=d;return f|0}function ja(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0.0,af=0.0,ag=0.0,ah=0.0;f=i;i=i+168|0;h=f|0;j=f+64|0;k=f+96|0;l=f+128|0;m=f+160|0;do{if((e|0)==0){n=+g[433456];o=+g[433457];if((a[1733821]&1)==0){p=n;q=o;r=1.0;break}p=n;q=o;r=+((c[b+1744>>2]|0)>>>0>>>0)/+((c[b+1720>>2]|0)>>>0>>>0)}else{p=+g[e>>2];q=+g[e+4>>2];r=+g[e+8>>2]}}while(0);e=b+2048|0;if((c[e>>2]|0)==0){i=f;return}s=b+4|0;t=c[s>>2]|0;if((t|0)!=0){fi[c[t+12>>2]&255](15)}iE(b,c[b+1728>>2]|0,c[b+1732>>2]|0,0);eq(3042);aZ(3553,c[b+2060>>2]|0);t=l|0;u=b+2e3|0;v=u;w=b+2008|0;c[w>>2]=t;x=b+2080|0;if((cP(x|0,d|0)|0)==0){y=c[b+2336>>2]|0;z=c[b+2340>>2]|0;A=b+2068|0;B=b+2072|0}else{C=b+2056|0;fF[c[(c[C>>2]|0)+4>>2]&127](c[e>>2]|0,d,m);D=c[m>>2]|0;E=c[D+24>>2]|0;F=(c[D+4>>2]|0)+E|0;G=c[D+28>>2]|0;H=(c[D+8>>2]|0)+G|0;I=c[D+48>>2]|0;if((I|0)==0){J=H;K=G;L=F;M=E}else{N=H;H=G;G=F;F=E;E=I;while(1){I=c[E+24>>2]|0;O=(c[E+4>>2]|0)+I|0;P=c[E+28>>2]|0;Q=(c[E+8>>2]|0)+P|0;R=(I|0)<(F|0)?I:F;I=(O|0)>(G|0)?O:G;O=(P|0)<(H|0)?P:H;P=(Q|0)>(N|0)?Q:N;Q=c[E+48>>2]|0;if((Q|0)==0){J=P;K=O;L=I;M=R;break}else{N=P;H=O;G=I;F=R;E=Q}}}E=L-M|0;L=J-K|0;J=E-1|0;F=J>>>1|J;J=F>>>2|F;F=J>>>4|J;J=F>>>8|F;F=(J>>>16|J)+1|0;J=L-1|0;G=J>>>1|J;J=G>>>2|G;G=J>>>4|J;J=G>>>8|G;G=(J>>>16|J)+1|0;J=c[b+2064>>2]|0;H=(F|0)>(J|0)?J:F;F=(G|0)>(J|0)?J:G;G=b+2068|0;J=c[G>>2]|0;N=b+2072|0;do{if((H|0)>(J|0)){S=6843}else{Q=c[N>>2]|0;if((F|0)>(Q|0)){S=6843;break}V=J;W=Q;X=b+2076|0}}while(0);if((S|0)==6843){J=b+2076|0;Q=c[J>>2]|0;c[J>>2]=aIr(Q,ab(H<<2,F)|0)|0;d8(3553,0,6408,H|0,F|0,0,6408,5121,0);c[G>>2]=H;c[N>>2]=F;V=H;W=F;X=J}J=c[X>>2]|0;aIv(J|0,0,ab(W<<2,V)|0);if((D|0)!=0){V=D;do{D=c[X>>2]|0;W=c[G>>2]|0;J=c[N>>2]|0;F=(c[V+24>>2]|0)-M|0;H=c[V+8>>2]|0;Q=J-H+(K-(c[V+28>>2]|0))|0;R=Q-1|0;I=c[V>>2]|0;O=(F|0)<0;P=(c[V+4>>2]|0)+(O?F:0)|0;Y=(R|0)<0;Z=(Y?R:0)+H|0;if(O){_=I+(-F|0)|0;$=0}else{_=I;$=F}if(Y){aa=_+(ab(c[V+12>>2]|0,1-Q|0)|0)|0;ac=0}else{aa=_;ac=R}R=($+P|0)>(W|0)?W-$|0:P;P=(ac+Z|0)>(J|0)?J-ac|0:Z;do{if((P|0)>0){Z=V+12|0;if((R|0)<=0){break}J=aa;Q=D+((ab(ac,W)|0)+$<<2)|0;Y=0;while(1){F=Q;I=0;while(1){a[F]=-1;a[F+1|0]=-1;a[F+2|0]=-1;a[F+3|0]=a[J+I|0]|0;O=I+1|0;if((O|0)<(R|0)){F=F+4|0;I=O}else{break}}I=Y+1|0;if((I|0)<(P|0)){J=J+(c[Z>>2]|0)|0;Q=Q+(W<<2)|0;Y=I}else{break}}}}while(0);V=c[V+48>>2]|0;}while((V|0)!=0)}fb(3317,8);ea(3553,0,0,0,c[G>>2]|0,c[N>>2]|0,6408,5121,c[X>>2]|0);fj[c[(c[C>>2]|0)+8>>2]&511](c[e>>2]|0,m);m=256;e=x;x=d;while(1){d=m-1|0;if((d|0)==0){S=6859;break}C=a[x]|0;a[e]=C;if(C<<24>>24==0){break}else{m=d;e=e+1|0;x=x+1|0}}do{if((S|0)==6859){a[e]=0;if((a[x]|0)==0){break}else{ad=x}do{ad=ad+1|0;}while((a[ad]|0)!=0)}}while(0);c[b+2336>>2]=E;c[b+2340>>2]=L;y=E;z=L;A=G;B=N}N=j|0;G=k|0;o=+(y|0);n=+((c[b+1744>>2]|0)>>>0>>>0);ae=p+r*o/n;af=+(z|0);ag=+((c[b+1748>>2]|0)>>>0>>>0);ah=q+r*af/ag;g[N>>2]=p;g[j+8>>2]=ae;g[j+16>>2]=p;g[j+24>>2]=ae;g[j+4>>2]=ah;g[j+12>>2]=ah;g[j+20>>2]=q;g[j+28>>2]=q;r=2.0/n;n=2.0/ag;ag=p-r;g[G>>2]=ag;p=ah-n;g[k+4>>2]=p;ah=ae-r;g[k+8>>2]=ah;g[k+12>>2]=p;g[k+16>>2]=ag;ag=q-n;g[k+20>>2]=ag;g[k+24>>2]=ah;g[k+28>>2]=ag;ag=o/+(c[A>>2]|0);o=1.0-af/+(c[B>>2]|0);g[t>>2]=0.0;g[l+8>>2]=ag;g[l+16>>2]=0.0;g[l+24>>2]=ag;g[l+4>>2]=o;g[l+12>>2]=o;g[l+20>>2]=1.0;g[l+28>>2]=1.0;l=u;c[l>>2]=G;G=b+2004|0;c[G>>2]=b+2408;u=b+1872|0;t=c[s>>2]|0;do{if((t|0)!=0){B=c[t+32>>2]|0;fl[B&255](v)|0;B=c[s>>2]|0;if((B|0)==0){break}A=c[B+36>>2]|0;fl[A&255](u)|0}}while(0);db(5,0,4);c[l>>2]=N;c[G>>2]=b+2344;N=c[s>>2]|0;do{if((N|0)!=0){t=c[N+32>>2]|0;fl[t&255](v)|0;t=c[s>>2]|0;if((t|0)==0){break}A=c[t+36>>2]|0;fl[A&255](u)|0}}while(0);db(5,0,4);c[l>>2]=c[b+2016>>2];c[w>>2]=b+1840;c[G>>2]=c[b+2020>>2];aZ(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);dg(3042);G=b+1936|0;aIv(G|0,0,48);g[b+1996>>2]=1.0;g[G>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;o=+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0;ag=+T(+o);af=+U(+o);aIv(h|0,0,60);g[h+40>>2]=1.0;g[h+60>>2]=1.0;g[h>>2]=ag;g[h+20>>2]=ag;g[h+16>>2]=-0.0-af;g[h+4>>2]=af;i7(u,h,G);i=f;return}function jb(a){a=a|0;return}function jc(a,b){a=a|0;b=b|0;return}function jd(){return}function je(a){a=a|0;return 0}function jf(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return 0}function jg(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;if(a[675072]|0){e=0}else{a[675072]=1;e=1}return e|0}function jh(a,b){a=a|0;b=b|0;c[a>>2]=c[455180];c[b>>2]=c[455182];return}function ji(){return a[675072]|0}function jj(a,b){a=a|0;b=b|0;return+(+(a>>>0>>>0)/+(b>>>0>>>0))}function jk(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;if((a[1820736]&1)!=0){g=c[494446]|0;h=(g|0)!=0?g:c[p>>2]|0;a5(714696,45,1,h|0)|0;h=c[494446]|0;g=(h|0)!=0?h:c[p>>2]|0;a_(g|0)|0}if(a[675072]|0){if((a[1820736]&1)==0){j=1;i=b;return j|0}g=c[494446]|0;h=(g|0)!=0?g:c[p>>2]|0;a5(707288,64,1,h|0)|0;h=c[494446]|0;g=(h|0)!=0?h:c[p>>2]|0;a_(g|0)|0;j=1;i=b;return j|0}g=e7(0)|0;c[494718]=g;do{if((g|0)!=0){do{if((cE(g|0,0,0)|0)!=0){if((el(c[494718]|0,672416,1978896,1,f|0)|0)==0){break}h=bc(c[494718]|0,c[494724]|0,0,672400)|0;c[494720]=h;if((h|0)==0){break}h=eh(c[494718]|0,c[494724]|0,0,0)|0;c[494716]=h;if((h|0)==0){break}if((dB(c[494718]|0,h|0,h|0,c[494720]|0)|0)==0){break}h=c[494718]|0;k=c[494716]|0;fa(h|0,k|0,12375,d|0)|0;k=c[494718]|0;h=c[494716]|0;fa(k|0,h|0,12374,e|0)|0;h=c[d>>2]|0;c[455180]=h;k=c[e>>2]|0;c[455182]=k;if((a[1820736]&1)==0){j=1;i=b;return j|0}l=c[494446]|0;m=(l|0)!=0?l:c[p>>2]|0;ei(m|0,702936,(m=i,i=i+16|0,c[m>>2]=h,c[m+8>>2]=k,m)|0)|0;i=m;m=c[494446]|0;k=(m|0)!=0?m:c[p>>2]|0;a_(k|0)|0;j=1;i=b;return j|0}}while(0);k=c[494718]|0;if((k|0)==0){break}dB(k|0,0,0,0)|0;k=c[494720]|0;if((k|0)!=0){m=c[494718]|0;dp(m|0,k|0)|0}k=c[494716]|0;if((k|0)!=0){m=c[494718]|0;aW(m|0,k|0)|0}k=c[494718]|0;ca(k|0)|0}}while(0);c[494720]=0;c[494716]=0;c[494718]=0;c[494724]=0;a[675072]=0;j=0;i=b;return j|0}function jl(){var b=0,d=0;b=c[494718]|0;if((b|0)!=0){dB(b|0,0,0,0)|0;b=c[494720]|0;if((b|0)!=0){d=c[494718]|0;dp(d|0,b|0)|0}b=c[494716]|0;if((b|0)!=0){d=c[494718]|0;aW(d|0,b|0)|0}b=c[494718]|0;ca(b|0)|0}c[494720]=0;c[494716]=0;c[494718]=0;c[494724]=0;a[675072]=0;return}function jm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)==1){d=(bi(12448)|0)!=0}else{d=0}return d|0}function jn(){var b=0,d=0,e=0.0,f=0,g=0,j=0,k=0,l=0,m=0;b=i;i=i+128|0;d=b|0;a[d]=0;e=+bb()*1.0e3;f=~~e>>>0;g=+Q(e)>=1.0?e>0.0?(ag(+P(e/4294967296.0),4294967295.0)|0)>>>0:~~+aa((e- +(~~e>>>0))/4294967296.0)>>>0:0;do{if((c[494386]|0)==0){c[429318]=f;c[429319]=g;c[429316]=f;c[429317]=g;bQ(d|0,128,710232,(j=i,i=i+8|0,c[j>>2]=1977548,j)|0)|0;i=j}else{k=1969088;l=c[k>>2]|0;m=aIF(l,c[k+4>>2]|0,1,0)|0;k=1969088;c[k>>2]=m;c[k+4>>2]=F;k=aIG(f,g,c[429318]|0,c[429319]|0)|0;m=1952704+((l&2047)<<3)|0;c[m>>2]=k;c[m+4>>2]=F;c[429318]=f;c[429319]=g;m=c[494386]|0;if((m&255|0)==0){k=aIG(f,g,c[429316]|0,c[429317]|0)|0;c[429316]=f;c[429317]=g;e=256.0e6/(+(k>>>0)+ +(F|0)*4294967296.0);bQ(d|0,128,692984,(j=i,i=i+24|0,c[j>>2]=1977548,h[j+8>>3]=e,c[j+16>>2]=m,j)|0)|0;i=j;break}else{i=b;return}}}while(0);if((a[1820736]&1)==0){i=b;return}g=c[494446]|0;ei(((g|0)!=0?g:c[p>>2]|0)|0,727024,(j=i,i=i+8|0,c[j>>2]=d,j)|0)|0;i=j;j=c[494446]|0;a_(((j|0)!=0?j:c[p>>2]|0)|0)|0;i=b;return}function jo(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;g=i;i=i+24|0;h=g|0;j=g+8|0;cy(h|0,j|0,g+16|0);k=c[h>>2]|0;c[e>>2]=k;h=c[j>>2]|0;c[f>>2]=h;a[d]=(c[e>>2]|0)==(c[455180]|0)&(h|0)==(c[455182]|0)&1^1;c[455180]=k;c[455182]=h;a[b]=0;i=g;return}function jp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;c[a>>2]=0;d=aIp(48)|0;if((d|0)==0){return}if((c[d-4>>2]&3|0)!=0){aIv(d|0,0,48)}e=bo()|0;c[d+44>>2]=e;if((e|0)==0){aIq(d);return}aIv(962744,0,1292);e=9880;f=276;while(1){c[962744+(f<<2)>>2]=c[e>>2];g=c[e+12>>2]|0;if((g|0)==0){break}else{e=e+8|0;f=g}}c[a>>2]=670112;c[b>>2]=d;return}function jq(a){a=a|0;return ce(a|0)|0}function jr(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aY=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0.0,cY=0.0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0;e=i;i=i+848|0;f=e|0;j=e+64|0;k=e+128|0;l=e+192|0;m=e+256|0;n=e+320|0;o=e+384|0;q=e+448|0;r=e+512|0;s=e+576|0;t=e+640|0;u=e+704|0;v=e+768|0;w=e+832|0;x=aIp(109528)|0;if((x|0)==0){c[427250]=0;y=0;i=e;return y|0}if((c[x-4>>2]&3|0)!=0){aIv(x|0,0,109528)}z=x;c[427250]=z;L9656:do{if((d|0)==0){A=c[494446]|0;B=(A|0)!=0?A:c[p>>2]|0;a5(707224,59,1,B|0)|0;B=c[494446]|0;A=(B|0)!=0?B:c[p>>2]|0;a_(A|0)|0;c[(c[427250]|0)+72>>2]=1;A=dv(((a[1709032]&1)!=0?698976:699384)|0)|0;c[(c[427250]|0)+4172>>2]=A;A=dv(((a[1709032]&1)!=0?700016:700432)|0)|0;B=c[427250]|0;c[B+4176>>2]=A;a[B+4|0]=1}else{B=ck(d|0,46)|0;A=(B|0)==0?14317944:B+1|0;if((cP(A|0,719736)|0)==0){B=4096;C=x+76|0;D=d;while(1){E=B-1|0;if((E|0)==0){F=6952;break}G=a[D]|0;a[C]=G;if(G<<24>>24==0){break}else{B=E;C=C+1|0;D=D+1|0}}do{if((F|0)==6952){a[C]=0;if((a[D]|0)==0){break}else{H=D}do{H=H+1|0;}while((a[H]|0)!=0)}}while(0);c[x+72>>2]=1;a[x+4|0]=1;break}do{if((cP(A|0,727016)|0)==0){D=gP(d,0)|0;if((D|0)==0){break}C=h6(D,c[427250]|0)|0;a[(c[427250]|0)+4|0]=1;gN(D);if(C){break L9656}}else{C=v|0;if((a[1820736]&1)!=0){D=c[494446]|0;B=(D|0)!=0?D:c[p>>2]|0;ei(B|0,703288,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;B=c[494446]|0;D=(B|0)!=0?B:c[p>>2]|0;a_(D|0)|0}D=hz(d)|0;B=(D|0)!=0;L9676:do{if(B){E=D|0;G=c[E>>2]|0;if((G|0)==0){break}else{J=G}L9679:while(1){do{if((c[J+20>>2]|0)==0){if((cP(c[J>>2]|0,697792)|0)!=0){break}K=J+8|0;G=K;while(1){L=c[G>>2]|0;if((L|0)==0){F=6973;break}if((cP(695928,c[L>>2]|0)|0)==0){F=6968;break}else{G=L+8|0}}L9687:do{if((F|0)==6968){F=0;G=c[L+4>>2]|0;if((G|0)==0){F=6973;break}else{M=64;N=C;O=G}while(1){G=M-1|0;if((G|0)==0){break}P=a[O]|0;a[N]=P;if(P<<24>>24==0){break L9687}else{M=G;N=N+1|0;O=O+1|0}}a[N]=0;if((a[O]|0)==0){break}else{Q=O}do{Q=Q+1|0;}while((a[Q]|0)!=0)}}while(0);if((F|0)==6973){F=0;a[C]=0}if((cP(C|0,693840)|0)==0){break L9679}}}while(0);G=c[J+16>>2]|0;if((G|0)==0){break L9676}else{J=G}}c[x>>2]=2;G=K;while(1){R=c[G>>2]|0;if((R|0)==0){F=6983;break}if((cP(691680,c[R>>2]|0)|0)==0){F=6978;break}else{G=R+8|0}}L9703:do{if((F|0)==6978){G=c[R+4>>2]|0;if((G|0)==0){F=6983;break}else{S=64;T=C;U=G}while(1){G=S-1|0;if((G|0)==0){break}P=a[U]|0;a[T]=P;if(P<<24>>24==0){break L9703}else{S=G;T=T+1|0;U=U+1|0}}a[T]=0;if((a[U]|0)==0){break}else{V=U}do{V=V+1|0;}while((a[V]|0)!=0)}}while(0);if((F|0)==6983){a[C]=0}G=x+4|0;a[G]=(cP(C|0,730896)|0)==0|0;P=x+5|0;W=K;while(1){X=c[W>>2]|0;if((X|0)==0){F=6988;break}if((cP(728656,c[X>>2]|0)|0)==0){F=6987;break}else{W=X+8|0}}do{if((F|0)==6987){W=c[X+4>>2]|0;if((W|0)==0){F=6988;break}else{Y=64;Z=0;_=P;$=W}while(1){W=Y-1|0;if((W|0)==0){F=6991;break}aa=a[$]|0;a[_]=aa;if(aa<<24>>24==0){ab=Z;break}else{Y=W;Z=Z+1|0;_=_+1|0;$=$+1|0}}do{if((F|0)==6991){a[_]=0;if((a[$]|0)==0){ab=Z;break}else{ac=$;ad=Z}while(1){W=ac+1|0;aa=ad+1|0;if((a[W]|0)==0){ab=aa;break}else{ac=W;ad=aa}}}}while(0);if(ab>>>0>=64){break}if((a[1820736]&1)==0){break}aa=c[494446]|0;ei(((aa|0)!=0?aa:c[p>>2]|0)|0,726336,(I=i,i=i+8|0,c[I>>2]=P,I)|0)|0;i=I;aa=c[494446]|0;a_(((aa|0)!=0?aa:c[p>>2]|0)|0)|0}}while(0);if((F|0)==6988){a[P]=0}do{if((a[G]&1)==0){aa=c[494446]|0;W=(aa|0)!=0?aa:c[p>>2]|0;a5(723888,57,1,W|0)|0;W=c[494446]|0;aa=(W|0)!=0?W:c[p>>2]|0;a_(aa|0)|0}else{if((a[1820736]&1)==0){break}aa=c[494446]|0;W=(aa|0)!=0?aa:c[p>>2]|0;a5(724840,54,1,W|0)|0;W=c[494446]|0;aa=(W|0)!=0?W:c[p>>2]|0;a_(aa|0)|0}}while(0);P=c[J+12>>2]|0;aa=x+72|0;L9737:do{if((P|0)==0){F=7321}else{W=f|0;ae=j|0;af=k|0;ag=l|0;ah=m|0;ai=n|0;aj=o|0;ak=q|0;al=r|0;am=s|0;an=t|0;ao=u|0;ap=x+66444|0;aq=x+99792|0;ar=x+109012|0;as=x+109016|0;at=P;L9739:while(1){if((c[aa>>2]|0)>>>0>=16){break L9737}do{if((c[at+20>>2]|0)==0){au=at+4|0;av=c[au>>2]|0;if((av|0)==0){break}aw=dv(av|0)|0;if((aw|0)==0){break}av=c[aa>>2]|0;ax=c[at>>2]|0;if((cP(ax|0,722520)|0)==0){ay=z+76+(av*4148|0)+4096|0;if((c[ay>>2]|0)!=0){F=7009;break L9739}az=h8(aw,d,at)|0;if((az|0)==0){F=7011;break L9739}c[ay>>2]=az;break}if((cP(ax|0,718088)|0)!=0){if((cP(ax|0,714160)|0)==0){aIq(aw);az=c[ap>>2]|0;if(az>>>0>7){ay=c[494446]|0;aA=(ay|0)!=0?ay:c[p>>2]|0;a5(692672,58,1,aA|0)|0;aA=c[494446]|0;ay=(aA|0)!=0?aA:c[p>>2]|0;a_(ay|0)|0;break}ay=z+66448+(az*4168|0)|0;aA=at+8|0;aB=aA;while(1){aC=c[aB>>2]|0;if((aC|0)==0){F=7178;break}if((cP(694816,c[aC>>2]|0)|0)==0){F=7173;break}else{aB=aC+8|0}}L9761:do{if((F|0)==7173){F=0;aB=c[aC+4>>2]|0;if((aB|0)==0){F=7178;break}else{aD=64;aE=ay;aF=aB}while(1){aB=aD-1|0;if((aB|0)==0){break}aG=a[aF]|0;a[aE]=aG;if(aG<<24>>24==0){break L9761}else{aD=aB;aE=aE+1|0;aF=aF+1|0}}a[aE]=0;if((a[aF]|0)==0){break}else{aH=aF}do{aH=aH+1|0;}while((a[aH]|0)!=0)}}while(0);if((F|0)==7178){F=0;a[ay]=0}aB=z+66448+(az*4168|0)+64|0;aG=aA;while(1){aI=c[aG>>2]|0;if((aI|0)==0){F=7187;break}if((cP(692584,c[aI>>2]|0)|0)==0){F=7182;break}else{aG=aI+8|0}}L9775:do{if((F|0)==7182){F=0;aG=c[aI+4>>2]|0;if((aG|0)==0){F=7187;break}else{aJ=4096;aK=aB;aL=aG}while(1){aG=aJ-1|0;if((aG|0)==0){break}aM=a[aL]|0;a[aK]=aM;if(aM<<24>>24==0){break L9775}else{aJ=aG;aK=aK+1|0;aL=aL+1|0}}a[aK]=0;if((a[aL]|0)==0){break}else{aN=aL}do{aN=aN+1|0;}while((a[aN]|0)!=0)}}while(0);if((F|0)==7187){F=0;a[aB]=0}aIv(W|0,0,64);aG=aA;while(1){aO=c[aG>>2]|0;if((aO|0)==0){F=7196;break}if((cP(692440,c[aO>>2]|0)|0)==0){F=7191;break}else{aG=aO+8|0}}L9789:do{if((F|0)==7191){F=0;aG=c[aO+4>>2]|0;if((aG|0)==0){F=7196;break}else{aP=64;aQ=W;aR=aG}while(1){aG=aP-1|0;if((aG|0)==0){break}aA=a[aR]|0;a[aQ]=aA;if(aA<<24>>24==0){break L9789}else{aP=aG;aQ=aQ+1|0;aR=aR+1|0}}a[aQ]=0;if((a[aR]|0)==0){break}else{aS=aR}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);if((F|0)==7196){F=0;a[W]=0}if((a[ay]|0)==0){F=7198;break L9739}if((a[aB]|0)==0){F=7200;break L9739}do{if((cP(W|0,691896)|0)==0){c[z+66448+(az*4168|0)+4160>>2]=1}else{if((cP(W|0,691728)|0)==0){c[z+66448+(az*4168|0)+4160>>2]=2;break}if((a[W]|0)!=0){F=7207;break L9739}c[z+66448+(az*4168|0)+4160>>2]=0}}while(0);c[ap>>2]=(c[ap>>2]|0)+1;break}if((cP(ax|0,711680)|0)!=0){if((cP(ax|0,710240)|0)!=0){break}aIq(aw);if((c[ar>>2]|0)!=0){F=7294;break L9739}az=at+8|0;aB=az;while(1){aT=c[aB>>2]|0;if((aT|0)==0){F=7303;break}if((cP(696e3,c[aT>>2]|0)|0)==0){F=7298;break}else{aB=aT+8|0}}L9818:do{if((F|0)==7298){F=0;aB=c[aT+4>>2]|0;if((aB|0)==0){F=7303;break}else{aU=512;aV=as;aW=aB}while(1){aB=aU-1|0;if((aB|0)==0){break}ax=a[aW]|0;a[aV]=ax;if(ax<<24>>24==0){aY=az;break L9818}else{aU=aB;aV=aV+1|0;aW=aW+1|0}}a[aV]=0;if((a[aW]|0)==0){aY=az;break}else{a$=aW}while(1){aB=a$+1|0;if((a[aB]|0)==0){aY=az;break}else{a$=aB}}}}while(0);if((F|0)==7303){F=0;a[as]=0;aY=az}while(1){a0=c[aY>>2]|0;if((a0|0)==0){F=7311;break}if((cP(695928,c[a0>>2]|0)|0)==0){F=7306;break}else{aY=a0+8|0}}L9831:do{if((F|0)==7306){F=0;az=c[a0+4>>2]|0;if((az|0)==0){F=7311;break}else{a1=64;a2=W;a3=az}while(1){az=a1-1|0;if((az|0)==0){break}aB=a[a3]|0;a[a2]=aB;if(aB<<24>>24==0){break L9831}else{a1=az;a2=a2+1|0;a3=a3+1|0}}a[a2]=0;if((a[a3]|0)==0){break}else{a4=a3}do{a4=a4+1|0;}while((a[a4]|0)!=0)}}while(0);if((F|0)==7311){F=0;a[W]=0}if((cP(W|0,698576)|0)!=0){F=7313;break L9739}az=c[au>>2]|0;if((az|0)==0){F=7315;break L9739}aB=dv(az|0)|0;c[ar>>2]=aB;if((aB|0)==0){F=7319;break L9739}az=h8(aB,d,at)|0;c[ar>>2]=az;if((az|0)==0){F=7318;break L9739}else{break}}aIq(aw);az=c[aq>>2]|0;if(az>>>0>63){F=7212;break L9739}aB=z+99796+(az*80|0)|0;ax=at+8|0;ay=ax;while(1){a6=c[ay>>2]|0;if((a6|0)==0){F=7221;break}if((cP(694816,c[a6>>2]|0)|0)==0){F=7216;break}else{ay=a6+8|0}}L9850:do{if((F|0)==7216){F=0;ay=c[a6+4>>2]|0;if((ay|0)==0){F=7221;break}else{a7=64;a8=aB;a9=ay}while(1){ay=a7-1|0;if((ay|0)==0){break}au=a[a9]|0;a[a8]=au;if(au<<24>>24==0){ba=ax;break L9850}else{a7=ay;a8=a8+1|0;a9=a9+1|0}}a[a8]=0;if((a[a9]|0)==0){ba=ax;break}else{bb=a9}while(1){ay=bb+1|0;if((a[ay]|0)==0){ba=ax;break}else{bb=ay}}}}while(0);if((F|0)==7221){F=0;a[aB]=0;ba=ax}while(1){bc=c[ba>>2]|0;if((bc|0)==0){F=7229;break}if((cP(694696,c[bc>>2]|0)|0)==0){F=7224;break}else{ba=bc+8|0}}L9863:do{if((F|0)==7224){F=0;ay=c[bc+4>>2]|0;if((ay|0)==0){F=7229;break}else{bd=64;be=W;bf=ay}while(1){ay=bd-1|0;if((ay|0)==0){break}au=a[bf]|0;a[be]=au;if(au<<24>>24==0){bg=ax;break L9863}else{bd=ay;be=be+1|0;bf=bf+1|0}}a[be]=0;if((a[bf]|0)==0){bg=ax;break}else{bh=bf}while(1){ay=bh+1|0;if((a[ay]|0)==0){bg=ax;break}else{bh=ay}}}}while(0);if((F|0)==7229){F=0;a[W]=0;bg=ax}while(1){bi=c[bg>>2]|0;if((bi|0)==0){F=7237;break}if((cP(694576,c[bi>>2]|0)|0)==0){F=7232;break}else{bg=bi+8|0}}L9876:do{if((F|0)==7232){F=0;ay=c[bi+4>>2]|0;if((ay|0)==0){F=7237;break}else{bj=64;bk=ae;bl=ay}while(1){ay=bj-1|0;if((ay|0)==0){break}au=a[bl]|0;a[bk]=au;if(au<<24>>24==0){bm=ax;break L9876}else{bj=ay;bk=bk+1|0;bl=bl+1|0}}a[bk]=0;if((a[bl]|0)==0){bm=ax;break}else{bn=bl}while(1){ay=bn+1|0;if((a[ay]|0)==0){bm=ax;break}else{bn=ay}}}}while(0);if((F|0)==7237){F=0;a[ae]=0;bm=ax}while(1){bo=c[bm>>2]|0;if((bo|0)==0){F=7245;break}if((cP(694480,c[bo>>2]|0)|0)==0){F=7240;break}else{bm=bo+8|0}}L9889:do{if((F|0)==7240){F=0;ay=c[bo+4>>2]|0;if((ay|0)==0){F=7245;break}else{bp=64;bq=af;br=ay}while(1){ay=bp-1|0;if((ay|0)==0){break}au=a[br]|0;a[bq]=au;if(au<<24>>24==0){bs=ax;break L9889}else{bp=ay;bq=bq+1|0;br=br+1|0}}a[bq]=0;if((a[br]|0)==0){bs=ax;break}else{bt=br}while(1){ay=bt+1|0;if((a[ay]|0)==0){bs=ax;break}else{bt=ay}}}}while(0);if((F|0)==7245){F=0;a[af]=0;bs=ax}while(1){bu=c[bs>>2]|0;if((bu|0)==0){F=7253;break}if((cP(694312,c[bu>>2]|0)|0)==0){F=7248;break}else{bs=bu+8|0}}L9902:do{if((F|0)==7248){F=0;ay=c[bu+4>>2]|0;if((ay|0)==0){F=7253;break}else{bv=64;bw=ag;bx=ay}while(1){ay=bv-1|0;if((ay|0)==0){break}au=a[bx]|0;a[bw]=au;if(au<<24>>24==0){by=ax;break L9902}else{bv=ay;bw=bw+1|0;bx=bx+1|0}}a[bw]=0;if((a[bx]|0)==0){by=ax;break}else{bz=bx}while(1){ay=bz+1|0;if((a[ay]|0)==0){by=ax;break}else{bz=ay}}}}while(0);if((F|0)==7253){F=0;a[ag]=0;by=ax}while(1){bB=c[by>>2]|0;if((bB|0)==0){F=7261;break}if((cP(694136,c[bB>>2]|0)|0)==0){F=7256;break}else{by=bB+8|0}}L9915:do{if((F|0)==7256){F=0;ax=c[bB+4>>2]|0;if((ax|0)==0){F=7261;break}else{bC=64;bD=ah;bE=ax}while(1){ax=bC-1|0;if((ax|0)==0){break}ay=a[bE]|0;a[bD]=ay;if(ay<<24>>24==0){break L9915}else{bC=ax;bD=bD+1|0;bE=bE+1|0}}a[bD]=0;if((a[bE]|0)==0){break}else{bF=bE}do{bF=bF+1|0;}while((a[bF]|0)!=0)}}while(0);if((F|0)==7261){F=0;a[ah]=0}if((a[W]|0)==0){F=7264;break L9739}if((a[aB]|0)==0){F=7264;break L9739}do{if((cP(W|0,700720)|0)==0){c[z+99796+(az*80|0)+68>>2]=0;F=7278}else{if((cP(W|0,699192)|0)==0){c[z+99796+(az*80|0)+68>>2]=1;F=7278;break}if((cP(W|0,700240)|0)==0){c[z+99796+(az*80|0)+68>>2]=2;F=7278;break}if((cP(W|0,699624)|0)==0){c[z+99796+(az*80|0)+68>>2]=3;F=7278;break}if((cP(W|0,698728)|0)==0){c[z+99796+(az*80|0)+68>>2]=4;F=7278;break}if((cP(W|0,698576)|0)!=0){F=7276;break L9739}c[z+99796+(az*80|0)+68>>2]=5}}while(0);do{if((F|0)==7278){F=0;if((a[af]|0)==0){if((a[ae]|0)==0){F=7285;break L9739}c[z+99796+(az*80|0)+64>>2]=aX(ae|0,0,16)|0;c[z+99796+(az*80|0)+72>>2]=1;break}aB=aX(af|0,0,0)|0;if((aB|0)==1){c[z+99796+(az*80|0)+72>>2]=2;break}else if((aB|0)==2){c[z+99796+(az*80|0)+72>>2]=3;break}else{F=7282;break L9739}}}while(0);if((a[ag]|0)!=0){b[z+99796+(az*80|0)+76>>1]=(aX(ag|0,0,16)|0)&65535}if((a[ah]|0)!=0){b[z+99796+(az*80|0)+78>>1]=(aX(ah|0,0,16)|0)&65535}c[aq>>2]=(c[aq>>2]|0)+1;break}if((a[G]&1)!=0){if((c[z+76+(av*4148|0)+4096>>2]|0)==0){F=7016;break L9739}}aB=h8(aw,d,at)|0;if((aB|0)==0){F=7018;break L9739}c[z+76+(av*4148|0)+4100>>2]=aB;aB=z+76+(av*4148|0)+4144|0;c[aB>>2]=0;ax=z+76+(av*4148|0)+4136|0;c[ax>>2]=0;ay=z+76+(av*4148|0)+4132|0;a[ay]=0;au=z+76+(av*4148|0)+4116|0;g[au>>2]=1.0;aG=z+76+(av*4148|0)+4120|0;g[aG>>2]=1.0;aA=z+76+(av*4148|0)+4112|0;c[aA>>2]=0;aM=z+76+(av*4148|0)+4108|0;c[aM>>2]=0;bG=z+76+(av*4148|0)+4104|0;a[bG]=0;bH=at+8|0;bI=bH;while(1){bJ=c[bI>>2]|0;if((bJ|0)==0){F=7023;break}if((cP(692440,c[bJ>>2]|0)|0)==0){F=7022;break}else{bI=bJ+8|0}}do{if((F|0)==7022){F=0;bI=c[bJ+4>>2]|0;if((bI|0)==0){F=7023;break}else{bK=64;bL=0;bM=W;bN=bI}while(1){bI=bK-1|0;if((bI|0)==0){F=7026;break}az=a[bN]|0;a[bM]=az;if(az<<24>>24==0){bO=bL;break}else{bK=bI;bL=bL+1|0;bM=bM+1|0;bN=bN+1|0}}do{if((F|0)==7026){F=0;a[bM]=0;if((a[bN]|0)==0){bO=bL;break}else{bP=bN;bQ=bL}while(1){bI=bP+1|0;az=bQ+1|0;if((a[bI]|0)==0){bO=az;break}else{bP=bI;bQ=az}}}}while(0);if(bO>>>0>=64){bR=bH;F=7036;break}if((cP(W|0,691728)|0)==0){c[ax>>2]=2;if((a[1820736]&1)==0){bR=bH;F=7036;break}az=c[494446]|0;bI=(az|0)!=0?az:c[p>>2]|0;a5(691080,42,1,bI|0)|0;bI=c[494446]|0;az=(bI|0)!=0?bI:c[p>>2]|0;a_(az|0)|0;bR=bH;F=7036;break}if((cP(W|0,691896)|0)!=0){az=c[494446]|0;bI=(az|0)!=0?az:c[p>>2]|0;a5(690704,54,1,bI|0)|0;bI=c[494446]|0;az=(bI|0)!=0?bI:c[p>>2]|0;a_(az|0)|0;bS=0;break}c[ax>>2]=1;if((a[1820736]&1)==0){bR=bH;F=7036;break}az=c[494446]|0;a5(690864,41,1,((az|0)!=0?az:c[p>>2]|0)|0)|0;az=c[494446]|0;a_(((az|0)!=0?az:c[p>>2]|0)|0)|0;bR=bH;F=7036}}while(0);if((F|0)==7023){F=0;a[W]=0;bR=bH;F=7036}do{if((F|0)==7036){while(1){F=0;bT=c[bR>>2]|0;if((bT|0)==0){F=7043;break}if((cP(690632,c[bT>>2]|0)|0)==0){F=7038;break}else{bR=bT+8|0;F=7036}}L9993:do{if((F|0)==7038){F=0;ax=c[bT+4>>2]|0;if((ax|0)==0){F=7043;break}else{bU=64;bV=ae;bW=ax}while(1){ax=bU-1|0;if((ax|0)==0){break}az=a[bW]|0;a[bV]=az;if(az<<24>>24==0){bX=bH;break L9993}else{bU=ax;bV=bV+1|0;bW=bW+1|0}}a[bV]=0;if((a[bW]|0)==0){bX=bH;break}else{bY=bW}while(1){ax=bY+1|0;if((a[ax]|0)==0){bX=bH;break}else{bY=ax}}}}while(0);if((F|0)==7043){F=0;a[ae]=0;bX=bH}while(1){bZ=c[bX>>2]|0;if((bZ|0)==0){F=7051;break}if((cP(690504,c[bZ>>2]|0)|0)==0){F=7046;break}else{bX=bZ+8|0}}L10006:do{if((F|0)==7046){F=0;ax=c[bZ+4>>2]|0;if((ax|0)==0){F=7051;break}else{b_=64;b$=af;b0=ax}while(1){ax=b_-1|0;if((ax|0)==0){break}az=a[b0]|0;a[b$]=az;if(az<<24>>24==0){b1=bH;break L10006}else{b_=ax;b$=b$+1|0;b0=b0+1|0}}a[b$]=0;if((a[b0]|0)==0){b1=bH;break}else{b2=b0}while(1){ax=b2+1|0;if((a[ax]|0)==0){b1=bH;break}else{b2=ax}}}}while(0);if((F|0)==7051){F=0;a[af]=0;b1=bH}while(1){b3=c[b1>>2]|0;if((b3|0)==0){F=7059;break}if((cP(690408,c[b3>>2]|0)|0)==0){F=7054;break}else{b1=b3+8|0}}L10019:do{if((F|0)==7054){F=0;ax=c[b3+4>>2]|0;if((ax|0)==0){F=7059;break}else{b4=64;b5=ag;b6=ax}while(1){ax=b4-1|0;if((ax|0)==0){break}az=a[b6]|0;a[b5]=az;if(az<<24>>24==0){b7=bH;break L10019}else{b4=ax;b5=b5+1|0;b6=b6+1|0}}a[b5]=0;if((a[b6]|0)==0){b7=bH;break}else{b8=b6}while(1){ax=b8+1|0;if((a[ax]|0)==0){b7=bH;break}else{b8=ax}}}}while(0);if((F|0)==7059){F=0;a[ag]=0;b7=bH}while(1){b9=c[b7>>2]|0;if((b9|0)==0){F=7067;break}if((cP(690280,c[b9>>2]|0)|0)==0){F=7062;break}else{b7=b9+8|0}}L10032:do{if((F|0)==7062){F=0;ax=c[b9+4>>2]|0;if((ax|0)==0){F=7067;break}else{ca=64;cb=ah;cc=ax}while(1){ax=ca-1|0;if((ax|0)==0){break}az=a[cc]|0;a[cb]=az;if(az<<24>>24==0){cd=bH;break L10032}else{ca=ax;cb=cb+1|0;cc=cc+1|0}}a[cb]=0;if((a[cc]|0)==0){cd=bH;break}else{ce=cc}while(1){ax=ce+1|0;if((a[ax]|0)==0){cd=bH;break}else{ce=ax}}}}while(0);if((F|0)==7067){F=0;a[ah]=0;cd=bH}while(1){cf=c[cd>>2]|0;if((cf|0)==0){F=7075;break}if((cP(731144,c[cf>>2]|0)|0)==0){F=7070;break}else{cd=cf+8|0}}L10045:do{if((F|0)==7070){F=0;ax=c[cf+4>>2]|0;if((ax|0)==0){F=7075;break}else{cg=64;ch=ai;ci=ax}while(1){ax=cg-1|0;if((ax|0)==0){break}az=a[ci]|0;a[ch]=az;if(az<<24>>24==0){cj=bH;break L10045}else{cg=ax;ch=ch+1|0;ci=ci+1|0}}a[ch]=0;if((a[ci]|0)==0){cj=bH;break}else{cl=ci}while(1){ax=cl+1|0;if((a[ax]|0)==0){cj=bH;break}else{cl=ax}}}}while(0);if((F|0)==7075){F=0;a[ai]=0;cj=bH}while(1){cm=c[cj>>2]|0;if((cm|0)==0){F=7083;break}if((cP(730976,c[cm>>2]|0)|0)==0){F=7078;break}else{cj=cm+8|0}}L10058:do{if((F|0)==7078){F=0;ax=c[cm+4>>2]|0;if((ax|0)==0){F=7083;break}else{cn=64;co=aj;cp=ax}while(1){ax=cn-1|0;if((ax|0)==0){break}az=a[cp]|0;a[co]=az;if(az<<24>>24==0){cq=bH;break L10058}else{cn=ax;co=co+1|0;cp=cp+1|0}}a[co]=0;if((a[cp]|0)==0){cq=bH;break}else{cr=cp}while(1){ax=cr+1|0;if((a[ax]|0)==0){cq=bH;break}else{cr=ax}}}}while(0);if((F|0)==7083){F=0;a[aj]=0;cq=bH}while(1){cs=c[cq>>2]|0;if((cs|0)==0){F=7091;break}if((cP(730448,c[cs>>2]|0)|0)==0){F=7086;break}else{cq=cs+8|0}}L10071:do{if((F|0)==7086){F=0;ax=c[cs+4>>2]|0;if((ax|0)==0){F=7091;break}else{ct=64;cu=ak;cv=ax}while(1){ax=ct-1|0;if((ax|0)==0){break}az=a[cv]|0;a[cu]=az;if(az<<24>>24==0){cw=bH;break L10071}else{ct=ax;cu=cu+1|0;cv=cv+1|0}}a[cu]=0;if((a[cv]|0)==0){cw=bH;break}else{cx=cv}while(1){ax=cx+1|0;if((a[ax]|0)==0){cw=bH;break}else{cx=ax}}}}while(0);if((F|0)==7091){F=0;a[ak]=0;cw=bH}while(1){cy=c[cw>>2]|0;if((cy|0)==0){F=7099;break}if((cP(730288,c[cy>>2]|0)|0)==0){F=7094;break}else{cw=cy+8|0}}L10084:do{if((F|0)==7094){F=0;ax=c[cy+4>>2]|0;if((ax|0)==0){F=7099;break}else{cz=64;cA=al;cB=ax}while(1){ax=cz-1|0;if((ax|0)==0){break}az=a[cB]|0;a[cA]=az;if(az<<24>>24==0){cC=bH;break L10084}else{cz=ax;cA=cA+1|0;cB=cB+1|0}}a[cA]=0;if((a[cB]|0)==0){cC=bH;break}else{cD=cB}while(1){ax=cD+1|0;if((a[ax]|0)==0){cC=bH;break}else{cD=ax}}}}while(0);if((F|0)==7099){F=0;a[al]=0;cC=bH}while(1){cE=c[cC>>2]|0;if((cE|0)==0){F=7107;break}if((cP(730136,c[cE>>2]|0)|0)==0){F=7102;break}else{cC=cE+8|0}}L10097:do{if((F|0)==7102){F=0;ax=c[cE+4>>2]|0;if((ax|0)==0){F=7107;break}else{cF=64;cG=am;cH=ax}while(1){ax=cF-1|0;if((ax|0)==0){break}az=a[cH]|0;a[cG]=az;if(az<<24>>24==0){cI=bH;break L10097}else{cF=ax;cG=cG+1|0;cH=cH+1|0}}a[cG]=0;if((a[cH]|0)==0){cI=bH;break}else{cJ=cH}while(1){ax=cJ+1|0;if((a[ax]|0)==0){cI=bH;break}else{cJ=ax}}}}while(0);if((F|0)==7107){F=0;a[am]=0;cI=bH}while(1){cK=c[cI>>2]|0;if((cK|0)==0){F=7115;break}if((cP(729976,c[cK>>2]|0)|0)==0){F=7110;break}else{cI=cK+8|0}}L10110:do{if((F|0)==7110){F=0;ax=c[cK+4>>2]|0;if((ax|0)==0){F=7115;break}else{cL=64;cM=an;cN=ax}while(1){ax=cL-1|0;if((ax|0)==0){break}az=a[cN]|0;a[cM]=az;if(az<<24>>24==0){cO=bH;break L10110}else{cL=ax;cM=cM+1|0;cN=cN+1|0}}a[cM]=0;if((a[cN]|0)==0){cO=bH;break}else{cQ=cN}while(1){ax=cQ+1|0;if((a[ax]|0)==0){cO=bH;break}else{cQ=ax}}}}while(0);if((F|0)==7115){F=0;a[an]=0;cO=bH}while(1){cR=c[cO>>2]|0;if((cR|0)==0){F=7123;break}if((cP(729808,c[cR>>2]|0)|0)==0){F=7118;break}else{cO=cR+8|0}}L10123:do{if((F|0)==7118){F=0;ax=c[cR+4>>2]|0;if((ax|0)==0){F=7123;break}else{cS=64;cT=ao;cU=ax}while(1){ax=cS-1|0;if((ax|0)==0){break}az=a[cU]|0;a[cT]=az;if(az<<24>>24==0){break L10123}else{cS=ax;cT=cT+1|0;cU=cU+1|0}}a[cT]=0;if((a[cU]|0)==0){break}else{cV=cU}do{cV=cV+1|0;}while((a[cV]|0)!=0)}}while(0);if((F|0)==7123){F=0;a[ao]=0}a[ay]=(cP(ao|0,729656)|0)==0|0;do{if((a[an]|0)!=0){ax=aX(an|0,0,0)|0;c[aB>>2]=ax;if((a[1820736]&1)==0){break}az=c[494446]|0;bI=(az|0)!=0?az:c[p>>2]|0;ei(bI|0,729536,(I=i,i=i+8|0,c[I>>2]=ax,I)|0)|0;i=I;ax=c[494446]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;a_(bI|0)|0}}while(0);do{if((a[ae]|0)==0){cW=0}else{cX=+aIt(ae);g[au>>2]=cX;g[aG>>2]=cX;a[bG]=1;if((a[1820736]&1)==0){cW=1;break}bI=c[494446]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cY=cX;ei(ax|0,729152,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;ax=c[494446]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;a_(bI|0)|0;cW=1}}while(0);if((a[af]|0)==0){cZ=cW}else{cY=+aIt(af);g[au>>2]=cY;a[bG]=1;if((a[1820736]&1)!=0){bI=c[494446]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cX=cY;ei(ax|0,728984,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[494446]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;a_(bI|0)|0}cZ=cW+1|0}if((a[ag]|0)==0){c_=cW}else{cX=+aIt(ag);g[aG>>2]=cX;a[bG]=1;if((a[1820736]&1)!=0){bI=c[494446]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cY=cX;ei(ax|0,728704,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;ax=c[494446]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;a_(bI|0)|0}c_=cW+1|0}if((a[ah]|0)==0){c$=cZ;c0=c_}else{bI=aX(ah|0,0,0)|0;c[z+76+(av*4148|0)+4128>>2]=bI;c[z+76+(av*4148|0)+4124>>2]=bI;a[bG]=1;c[aA>>2]=1;c[aM>>2]=1;if((a[1820736]&1)!=0){ax=c[494446]|0;az=(ax|0)!=0?ax:c[p>>2]|0;ei(az|0,728168,(I=i,i=i+8|0,c[I>>2]=bI,I)|0)|0;i=I;bI=c[494446]|0;az=(bI|0)!=0?bI:c[p>>2]|0;a_(az|0)|0}c$=cZ+1|0;c0=c_+1|0}if((a[ai]|0)==0){c1=c$}else{az=aX(ai|0,0,0)|0;c[z+76+(av*4148|0)+4124>>2]=az;a[bG]=1;c[aM>>2]=1;if((a[1820736]&1)!=0){bI=c[494446]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;ei(ax|0,727880,(I=i,i=i+8|0,c[I>>2]=az,I)|0)|0;i=I;az=c[494446]|0;ax=(az|0)!=0?az:c[p>>2]|0;a_(ax|0)|0}c1=c$+1|0}if((a[aj]|0)==0){c2=c0}else{ax=aX(aj|0,0,0)|0;c[z+76+(av*4148|0)+4128>>2]=ax;a[bG]=1;c[aA>>2]=1;if((a[1820736]&1)!=0){az=c[494446]|0;bI=(az|0)!=0?az:c[p>>2]|0;ei(bI|0,727656,(I=i,i=i+8|0,c[I>>2]=ax,I)|0)|0;i=I;ax=c[494446]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;a_(bI|0)|0}c2=c0+1|0}if((a[ak]|0)==0){c4=c1;c5=c2}else{cY=+aIt(ak);g[aG>>2]=cY;g[au>>2]=cY;a[bG]=1;c[aA>>2]=2;c[aM>>2]=2;if((a[1820736]&1)!=0){bI=c[494446]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cX=cY;ei(ax|0,727424,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[494446]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;a_(bI|0)|0}c4=c1+1|0;c5=c2+1|0}if((a[al]|0)==0){c6=c4}else{cX=+aIt(al);g[au>>2]=cX;a[bG]=1;c[aM>>2]=2;if((a[1820736]&1)!=0){bI=c[494446]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cY=cX;ei(ax|0,727336,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;ax=c[494446]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;a_(bI|0)|0}c6=c4+1|0}if((a[am]|0)==0){c7=c5}else{cY=+aIt(am);g[aG>>2]=cY;a[bG]=1;c[aA>>2]=2;if((a[1820736]&1)!=0){bI=c[494446]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cX=cY;ei(ax|0,727112,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[494446]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;a_(bI|0)|0}c7=c5+1|0}if(c6>>>0>1){bS=0;break}bS=c7>>>0<2}}while(0);if(!bS){F=7165;break L9739}c[aa>>2]=(c[aa>>2]|0)+1}}while(0);aA=c[at+16>>2]|0;if((aA|0)==0){F=7321;break L9737}else{at=aA}}if((F|0)==7294){at=c[494446]|0;am=(at|0)!=0?at:c[p>>2]|0;a5(696120,46,1,am|0)|0;am=c[494446]|0;at=(am|0)!=0?am:c[p>>2]|0;a_(at|0)|0;F=7319}else if((F|0)==7276){at=c[494446]|0;a5(693408,56,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7291}else if((F|0)==7282){at=c[494446]|0;a5(693176,52,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7291}else if((F|0)==7165){at=c[494446]|0;a5(715864,78,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;break L9676}else if((F|0)==7264){at=c[494446]|0;a5(693936,57,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7291}else if((F|0)==7313){at=c[494446]|0;a5(695536,52,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7319}else if((F|0)==7315){c[ar>>2]=0;F=7319}else if((F|0)==7009){at=c[494446]|0;a5(721096,75,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;aIq(aw);break L9676}else if((F|0)==7011){at=c[494446]|0;a5(719072,74,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;break L9676}else if((F|0)==7207){at=c[494446]|0;a5(691296,46,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7209}else if((F|0)==7200){at=c[494446]|0;a5(692056,57,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7209}else if((F|0)==7318){at=c[494446]|0;a5(695272,48,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7319}else if((F|0)==7198){at=c[494446]|0;a5(692312,51,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7209}else if((F|0)==7212){at=c[494446]|0;a5(694984,51,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7291}else if((F|0)==7018){at=c[494446]|0;a5(719072,74,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;break L9676}else if((F|0)==7285){at=c[494446]|0;a5(692832,65,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7291}else if((F|0)==7016){at=c[494446]|0;a5(717104,98,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;aIq(aw);break L9676}if((F|0)==7291){at=c[494446]|0;am=(at|0)!=0?at:c[p>>2]|0;a5(711040,46,1,am|0)|0;am=c[494446]|0;at=(am|0)!=0?am:c[p>>2]|0;a_(at|0)|0;break L9676}else if((F|0)==7209){at=c[494446]|0;a5(712832,51,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;break L9676}else if((F|0)==7319){at=c[494446]|0;a5(709560,40,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[494446]|0;a_(((at|0)!=0?at:c[p>>2]|0)|0)|0;break L9676}}}while(0);do{if((F|0)==7321){if((c[aa>>2]|0)!=0){break}G=c[494446]|0;P=(G|0)!=0?G:c[p>>2]|0;a5(709136,82,1,P|0)|0;P=c[494446]|0;G=(P|0)!=0?P:c[p>>2]|0;a_(G|0)|0;break L9676}}while(0);aa=c[E>>2]|0;if((aa|0)!=0){hB(aa)}aIq(D);break L9656}else{aa=c[494446]|0;ei(((aa|0)!=0?aa:c[p>>2]|0)|0,699960,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;aa=c[494446]|0;a_(((aa|0)!=0?aa:c[p>>2]|0)|0)|0}}while(0);C=c[494446]|0;aa=(C|0)!=0?C:c[p>>2]|0;a5(708696,51,1,aa|0)|0;aa=c[494446]|0;C=(aa|0)!=0?aa:c[p>>2]|0;a_(C|0)|0;if(!B){break}C=c[D>>2]|0;if((C|0)!=0){hB(C)}aIq(D)}}while(0);A=c[494446]|0;C=(A|0)!=0?A:c[p>>2]|0;a5(714632,56,1,C|0)|0;C=c[494446]|0;A=(C|0)!=0?C:c[p>>2]|0;a_(A|0)|0;y=0;i=e;return y|0}}while(0);ia(c[427250]|0,d);d=(a[1709032]&1)==0;L10232:do{if((a[(c[427250]|0)+4|0]&1)==0){aw=c[494446]|0;bS=(aw|0)!=0?aw:c[p>>2]|0;a5(702840,90,1,bS|0)|0;bS=c[494446]|0;aw=(bS|0)!=0?bS:c[p>>2]|0;a_(aw|0)|0}else{aw=jD(d?699384:698976,d?700432:700016,0)|0;c[429110]=aw;if((aw|0)==0){aw=c[494446]|0;bS=(aw|0)!=0?aw:c[p>>2]|0;a5(699800,60,1,bS|0)|0;bS=c[494446]|0;aw=(bS|0)!=0?bS:c[p>>2]|0;a_(aw|0)|0;break}else{c8=0}while(1){c9=c[427250]|0;if(c8>>>0>=(c[c9+72>>2]|0)>>>0){F=7345;break}da=c9+76+(c8*4148|0)|0;aw=c9+76+(c8*4148|0)+4096|0;if((a[da]|0)==0){db=c[aw>>2]|0;dc=c[c9+76+(c8*4148|0)+4100>>2]|0}else{if((go(da,aw)|0)<1){F=7342;break}bS=dv(c[aw>>2]|0)|0;c[c9+76+(c8*4148|0)+4100>>2]=bS;if((bS|0)==0){F=7342;break}c7=c[aw>>2]|0;if((c7|0)==0){F=7342;break}else{db=c7;dc=bS}}a[da]=0;bS=jD(db,dc,c8)|0;c7=c8+1|0;c[1716440+(c7<<2)>>2]=bS;if((bS|0)==0){F=7344;break}else{c8=c7}}if((F|0)==7342){c7=c[494446]|0;bS=(c7|0)!=0?c7:c[p>>2]|0;ei(bS|0,706520,(I=i,i=i+8|0,c[I>>2]=da,I)|0)|0;i=I;bS=c[494446]|0;c7=(bS|0)!=0?bS:c[p>>2]|0;a_(c7|0)|0;break}else if((F|0)==7344){c7=c[494446]|0;ei(((c7|0)!=0?c7:c[p>>2]|0)|0,706144,(I=i,i=i+8|0,c[I>>2]=c8,I)|0)|0;i=I;c7=c[494446]|0;a_(((c7|0)!=0?c7:c[p>>2]|0)|0)|0;break}else if((F|0)==7345){c7=w;L10250:do{if((c[c9+66444>>2]|0)==0){dd=0}else{bA(1,1716400);bS=c[427250]|0;if((c[bS+66444>>2]|0)==0){dd=0;break}aw=w|0;c6=w+4|0;c5=w+8|0;c4=0;c2=bS;while(1){if((a[1820736]&1)==0){de=c2}else{bS=c[494446]|0;c1=(bS|0)!=0?bS:c[p>>2]|0;bS=c2+66448+(c4*4168|0)+64|0;ei(c1|0,707664,(I=i,i=i+8|0,c[I>>2]=bS,I)|0)|0;i=I;bS=c[494446]|0;c1=(bS|0)!=0?bS:c[p>>2]|0;a_(c1|0)|0;de=c[427250]|0}aIv(c7|0,0,12);c1=de+66448+(c4*4168|0)+64|0;if((a[12473924]&1)==0){if(!(ih(c1,w,16,0)|0)){break}}else{if(!(ih(c1,w,0,16)|0)){break}}aZ(3553,c[1716400+(c4<<2)>>2]|0);e2(3553,10242,33071);e2(3553,10243,33071);c1=(c[(c[427250]|0)+66448+(c4*4168|0)+4160>>2]|0)==2?9728:9729;e2(3553,10240,c1|0);e2(3553,10241,c1|0);fb(3317,4);c1=(a[12473924]&1)!=0?6408:32993;bS=c[c5>>2]|0;d8(3553,0,c1|0,c[aw>>2]|0,c[c6>>2]|0,0,c1|0,5121,bS|0);aZ(3553,0);aIq(bS);bS=c4+1|0;c1=c[427250]|0;if(bS>>>0<(c[c1+66444>>2]|0)>>>0){c4=bS;c2=c1}else{dd=0;break L10250}}c2=c[494446]|0;ei(((c2|0)!=0?c2:c[p>>2]|0)|0,706976,(I=i,i=i+8|0,c[I>>2]=(c[427250]|0)+66448+(c4*4168|0)+64,I)|0)|0;i=I;c2=c[494446]|0;a_(((c2|0)!=0?c2:c[p>>2]|0)|0)|0;c2=c[494446]|0;a5(697600,48,1,((c2|0)!=0?c2:c[p>>2]|0)|0)|0;c2=c[494446]|0;a_(((c2|0)!=0?c2:c[p>>2]|0)|0)|0;break L10232}}while(0);do{jE(dd,c[1716440+(dd<<2)>>2]|0,1709040+(dd*460|0)|0);dd=dd+1|0;df=c[427250]|0;}while(dd>>>0<=(c[df+72>>2]|0)>>>0);do{if((c[df+99792>>2]|0)!=0){c7=fl[c[241052]&255](2)|0;c2=c[427250]|0;c6=c[c2+99792>>2]|0;aw=aIp(12)|0;if((aw|0)==0){c[429108]=0}else{if((c[aw-4>>2]&3|0)!=0){aIv(aw|0,0,12)}c5=aw;D=(c6|0)==0;do{if(D){dg=0}else{B=c6*112|0;if(c6>>>0<=65535){dg=B;break}dg=((B>>>0)/(c6>>>0)|0|0)==112?B:-1}}while(0);c4=aIp(dg)|0;do{if((c4|0)!=0){if((c[c4-4>>2]&3|0)==0){break}aIv(c4|0,0,dg|0)}}while(0);B=c4;c1=aw;c[c1>>2]=B;c[aw+4>>2]=c6;L10282:do{if(!D){bS=aw+8|0;c0=aw+10|0;z=(c7|0)==0?937464:c7;c$=0;c_=B;while(1){cZ=64;cW=c_+(c$*112|0)|0;cV=c2+99796+(c$*80|0)|0;while(1){cU=cZ-1|0;if((cU|0)==0){F=7372;break}cT=a[cV]|0;a[cW]=cT;if(cT<<24>>24==0){break}else{cZ=cU;cW=cW+1|0;cV=cV+1|0}}do{if((F|0)==7372){F=0;a[cW]=0;if((a[cV]|0)==0){break}else{dh=cV}do{dh=dh+1|0;}while((a[dh]|0)!=0)}}while(0);c[(c[c1>>2]|0)+(c$*112|0)+76>>2]=c[c2+99796+(c$*80|0)+64>>2];c[(c[c1>>2]|0)+(c$*112|0)+84>>2]=c[c2+99796+(c$*80|0)+68>>2];cV=b[c2+99796+(c$*80|0)+76>>1]|0;b[(c[c1>>2]|0)+(c$*112|0)+80>>1]=cV<<16>>16==0?-1:cV;b[(c[c1>>2]|0)+(c$*112|0)+82>>1]=b[c2+99796+(c$*80|0)+78>>1]|0;cV=c[c2+99796+(c$*80|0)+72>>2]|0;if((cV|0)==1){c[(c[c1>>2]|0)+(c$*112|0)+72>>2]=z}else if((cV|0)==2){c[(c[c1>>2]|0)+(c$*112|0)+68>>2]=bS;a[(c[c1>>2]|0)+(c$*112|0)+64|0]=1}else if((cV|0)==3){c[(c[c1>>2]|0)+(c$*112|0)+68>>2]=c0;a[(c[c1>>2]|0)+(c$*112|0)+64|0]=1}else{c[(c[c1>>2]|0)+(c$*112|0)+72>>2]=937464}cV=c$+1|0;if(cV>>>0>=c6>>>0){break L10282}c$=cV;c_=c[c1>>2]|0}}}while(0);c[429108]=c5;if((aw|0)!=0){break}}c1=c[494446]|0;c6=(c1|0)!=0?c1:c[p>>2]|0;a5(695672,50,1,c6|0)|0;c6=c[494446]|0;c1=(c6|0)!=0?c6:c[p>>2]|0;a_(c1|0)|0}}while(0);a[672240]=1;c1=c[427250]|0;c6=c1+72|0;c[1716440+((c[c6>>2]|0)+1<<2)>>2]=c[429110];c2=1709040+(((c[c6>>2]|0)+1|0)*460|0)|0;aIy(c2|0,1709040,460)|0;if((a[c1+4|0]&1)==0){c[429125]=c[429110];aIy(1715940,1709040,460)|0}else{c1=(a[1709032]&1)!=0;c2=jD(c1?728304:730544,c1?691424:693592,15)|0;c[429125]=c2;jE(0,c2,1715940)}if((c[429284]|0)!=0){c2=0;do{c3(c[1717024+(c2<<2)>>2]|0);c2=c2+1|0;}while(c2>>>0<(c[429284]|0)>>>0)}c[429284]=0;c2=0;while(1){ez(1,1692360+(c2*1040|0)|0);ez(1,1692880+(c2*1040|0)|0);c1=c2+1|0;if(c1>>>0<16){c2=c1}else{y=1;break}}i=e;return y|0}}}while(0);js();y=0;i=e;return y|0}function js(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;d6(0);f=e;g=e;h=0;do{j=c[1716440+(h<<2)>>2]|0;do{if((j|0)!=0){if((h|0)!=0&(j|0)==(c[429110]|0)){break}c[e>>2]=0;c[e+4>>2]=0;b1(j|0,2,d|0,g|0);if((c[d>>2]|0)>0){k=0;do{l=f+(k<<2)|0;cU(j|0,c[l>>2]|0);bn(c[l>>2]|0);k=k+1|0;}while((k|0)<(c[d>>2]|0))}cg(j|0)}}while(0);h=h+1|0;}while(h>>>0<16);h=c[427250]|0;do{if((h|0)==0){m=0}else{d=c[h+66444>>2]|0;if((d|0)==0){m=h;break}bh(d|0,1716400);m=c[427250]|0}}while(0);aIv(1716440,0,64);aIv(1709040,0,7360);a[672240]=0;c[3579464]=0;if((m|0)!=0){if((c[m+72>>2]|0)==0){n=m}else{h=0;d=m;while(1){aIq(c[d+76+(h*4148|0)+4096>>2]|0);aIq(c[(c[427250]|0)+76+(h*4148|0)+4100>>2]|0);m=h+1|0;f=c[427250]|0;if(m>>>0<(c[f+72>>2]|0)>>>0){h=m;d=f}else{n=f;break}}}aIq(c[n+109012>>2]|0);aIq(c[427250]|0);c[427250]=0}n=c[429108]|0;if((n|0)!=0){aIq(c[n>>2]|0);aIq(n)}c[429108]=0;if((c[429284]|0)!=0){n=0;do{c3(c[1717024+(n<<2)>>2]|0);n=n+1|0;}while(n>>>0<(c[429284]|0)>>>0)}c[429284]=0;n=0;do{d=1692360+(n*1040|0)|0;if((c[d>>2]|0)!=0){e6(1,d|0)}d=1692880+(n*1040|0)|0;if((c[d>>2]|0)!=0){e6(1,d|0)}n=n+1|0;}while(n>>>0<16);aIv(1692360,0,16640);i=b;return}function jt(){return c[(c[427250]|0)+72>>2]|0}function ju(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==0|a[672240]^1){e=0;return e|0}f=c[(c[427250]|0)+76+((b-1|0)*4148|0)+4136>>2]|0;if((f|0)==0){e=0;return e|0}a[d]=(f|0)==1|0;e=1;return e|0}function jv(b){b=b|0;var d=0;if((b|0)==0|a[672240]^1){d=0;return d|0}d=c[(c[427250]|0)+76+((b-1|0)*4148|0)+4140>>2]|0;return d|0}function jw(e,f,h,j,k,l,m,n,o,p,q){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;r=i;i=i+920|0;s=r|0;t=r+512|0;u=r+896|0;v=r+904|0;w=r+912|0;if(!(a[672240]|0)){i=r;return}y=c[3579464]|0;if((c[1716440+(y<<2)>>2]|0)==0){i=r;return}z=t|0;A=u|0;g[A>>2]=+(e>>>0>>>0);g[u+4>>2]=+(f>>>0>>>0);f=v|0;g[f>>2]=+(k>>>0>>>0);g[v+4>>2]=+(l>>>0>>>0);l=w|0;g[l>>2]=+(h>>>0>>>0);g[w+4>>2]=+(j>>>0>>>0);j=c[1709060+(y*460|0)>>2]|0;if((j|0)>-1){ba(j|0,1,A|0)}A=c[1709064+(y*460|0)>>2]|0;if((A|0)>-1){ba(A|0,1,f|0)}f=c[1709068+(y*460|0)>>2]|0;if((f|0)>-1){ba(f|0,1,l|0)}l=c[1709072+(y*460|0)>>2]|0;f=c[3579464]|0;if((l|0)>-1&(f|0)!=0){A=c[(c[427250]|0)+76+((f-1|0)*4148|0)+4144>>2]|0;if((A|0)==0){B=m}else{B=(m>>>0)%(A>>>0)|0}bL(l|0,B|0);C=B}else{C=m}m=c[1709080+(y*460|0)>>2]|0;if((m|0)>-1){bL(m|0,((a[1969280]&1)!=0?-1:1)|0)}m=c[427250]|0;if((c[m+66444>>2]|0)==0){D=0}else{B=0;l=m;while(1){m=1709084+(y*460|0)+(B<<2)|0;if((c[m>>2]|0)>-1){cM(B+33985|0);aZ(3553,c[1716400+(B<<2)>>2]|0);A=B+1|0;bL(c[m>>2]|0,A|0);E=c[427250]|0;F=A}else{E=l;F=B+1|0}A=c[E+66444>>2]|0;if(F>>>0<A>>>0){B=F;l=E}else{D=A;break}}}E=D+1|0;do{if((c[3579464]|0)>>>0>1){l=1709116+(y*460|0)|0;if((c[l>>2]|0)>-1){cM(D+33985|0);bL(c[l>>2]|0,E|0);aZ(3553,c[n>>2]|0)}l=D+2|0;F=c[1709124+(y*460|0)>>2]|0;if((F|0)>-1){ba(F|0,1,n+12|0)}F=c[1709120+(y*460|0)>>2]|0;if((F|0)>-1){ba(F|0,1,n+4|0)}F=c[1709128+(y*460|0)>>2]|0;if((F|0)>-1){c[t>>2]=F;c[t+4>>2]=2;c[t+8>>2]=0;F=t+12|0;B=s;A=n+20|0;aIy(B|0,A|0,32)|0;G=8;H=1;I=F}else{G=0;H=0;I=z}if((q|0)==0){J=I;K=H;L=l;M=G;N=0;break}cM(q+33985+D|0);aZ(3553,c[p+((q-1|0)*52|0)>>2]|0);F=I;A=H;B=l;l=0;m=G;while(1){f=c[1709132+(y*460|0)+(l<<4)>>2]|0;if((f|0)!=0){bL(f|0,B|0)}f=c[1709132+(y*460|0)+(l<<4)+8>>2]|0;if((f|0)>-1){ba(f|0,1,p+(l*52|0)+12|0)}f=c[1709132+(y*460|0)+(l<<4)+4>>2]|0;if((f|0)>-1){ba(f|0,1,p+(l*52|0)+4|0)}f=c[1709132+(y*460|0)+(l<<4)+12>>2]|0;if((f|0)>-1){c[F>>2]=f;c[F+4>>2]=2;c[F+8>>2]=m<<2;f=A+1|0;j=F+12|0;w=s+(m<<2)|0;h=p+(l*52|0)+20|0;aIy(w|0,h|0,32)|0;O=m+8|0;P=f;Q=j}else{O=m;P=A;Q=F}j=l+1|0;if(j>>>0<q>>>0){F=Q;A=P;B=B+1|0;l=j;m=O}else{break}}J=Q;K=P;L=q+2+D|0;M=O;N=0}else{cM(D+33985|0);aZ(3553,0);if((c[(c[427250]|0)+72>>2]|0)==0){J=z;K=0;L=E;M=0;N=0;break}m=D+33986|0;l=0;while(1){cM(m+l|0);aZ(3553,0);B=l+1|0;if(B>>>0<(c[(c[427250]|0)+72>>2]|0)>>>0){l=B}else{J=z;K=0;L=E;M=0;N=0;break}}}}while(0);while(1){E=1709388+(y*460|0)+(N<<4)|0;if((c[E>>2]|0)>-1){cM(L+33984|0);aZ(3553,c[o+(N*52|0)>>2]|0);bL(c[E>>2]|0,L|0);R=L+1|0}else{R=L}E=c[1709388+(y*460|0)+(N<<4)+8>>2]|0;if((E|0)>-1){ba(E|0,1,o+(N*52|0)+12|0)}E=c[1709388+(y*460|0)+(N<<4)+4>>2]|0;if((E|0)>-1){ba(E|0,1,o+(N*52|0)+4|0)}E=c[1709388+(y*460|0)+(N<<4)+12>>2]|0;if((E|0)>-1){c[J>>2]=E;c[J+4>>2]=2;c[J+8>>2]=M<<2;E=K+1|0;D=J+12|0;O=s+(M<<2)|0;q=o+(N*52|0)+20|0;aIy(O|0,q|0,32)|0;S=M+8|0;T=E;U=D}else{S=M;T=K;U=J}D=N+1|0;if(D>>>0<7){J=U;K=T;L=R+1|0;M=S;N=D}else{break}}if((S|0)!=0){N=c[3579464]|0;jC(c[1692880+(N*1040|0)>>2]|0,1692884+(N*1040|0)|0,1693396+(N*1040|0)|0,s|0,S,z,T)}cM(33984);T=c[429108]|0;if((T|0)==0){i=r;return}if((c[3579464]|0)==1){z=c[T+4>>2]|0;S=z>>>0<64?z:64;z=c[3118438]|0;if((z|0)!=0){s=4;N=0;M=0;R=z;while(1){z=c[312+(s-4<<2)>>2]|0;V=((fk[c[R+8>>2]&15](c[3118441]|0,360,0,1,0,z)|0)<<16>>16!=0)<<s|N;W=((fk[c[(c[3118438]|0)+8>>2]&15](c[3118441]|0,360,1,1,0,z)|0)<<16>>16!=0)<<s|M;z=s+1|0;if(z>>>0>=16){break}s=z;N=V&65535;M=W&65535;R=c[3118438]|0}R=T+8|0;x=W<<16|V&65535;b[R>>1]=x&65535;b[R+2>>1]=x>>16}L10467:do{if((S|0)!=0){R=T|0;V=0;while(1){W=c[R>>2]|0;c[1716504+(V<<3)>>2]=W+(V*112|0);switch(c[W+(V*112|0)+84>>2]|0){case 0:{if((a[W+(V*112|0)+64|0]&1)==0){X=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{X=b[c[W+(V*112|0)+68>>2]>>1]|0}M=b[W+(V*112|0)+80>>1]&X;N=b[W+(V*112|0)+82>>1]|0;g[1716508+(V<<3)>>2]=N<<16>>16==0|M<<16>>16==N<<16>>16?+((M&65535)>>>0):0.0;break};case 1:{M=W+(V*112|0)+88|0;N=c[M>>2]|0;s=(a[W+(V*112|0)+64|0]&1)==0;if(s){Y=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{Y=b[c[W+(V*112|0)+68>>2]>>1]|0}z=b[W+(V*112|0)+80>>1]|0;L=z&Y;K=b[W+(V*112|0)+82>>1]|0;U=K<<16>>16==0;J=W+(V*112|0)+92|0;if((N|0)==((U|L<<16>>16==K<<16>>16?L&65535:0)|0)){Z=c[J>>2]|0}else{c[J>>2]=N;if(s){_=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{_=b[c[W+(V*112|0)+68>>2]>>1]|0}s=_&z;c[M>>2]=U|s<<16>>16==K<<16>>16?s&65535:0;Z=N}g[1716508+(V<<3)>>2]=+(Z>>>0>>>0);break};case 2:{N=W+(V*112|0)+104|0;s=(a[W+(V*112|0)+64|0]&1)==0;if(s){$=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{$=b[c[W+(V*112|0)+68>>2]>>1]|0}K=b[W+(V*112|0)+80>>1]|0;U=K&$;M=b[W+(V*112|0)+82>>1]|0;z=M<<16>>16==0;if((c[N>>2]|0)==((z|U<<16>>16==M<<16>>16?U&65535:0)|0)){aa=c[W+(V*112|0)+96>>2]|0}else{if(s){ab=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ab=b[c[W+(V*112|0)+68>>2]>>1]|0}s=ab&K;c[N>>2]=z|s<<16>>16==M<<16>>16?s&65535:0;c[W+(V*112|0)+96>>2]=C;aa=C}g[1716508+(V<<3)>>2]=+(aa|0);break};case 3:{s=W+(V*112|0)+104|0;M=(a[W+(V*112|0)+64|0]&1)==0;if(M){ac=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ac=b[c[W+(V*112|0)+68>>2]>>1]|0}z=b[W+(V*112|0)+80>>1]|0;N=z&ac;K=b[W+(V*112|0)+82>>1]|0;U=K<<16>>16==0;if((c[s>>2]|0)==((U|N<<16>>16==K<<16>>16?N&65535:0)|0)){ad=c[W+(V*112|0)+108>>2]|0}else{if(M){ae=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ae=b[c[W+(V*112|0)+68>>2]>>1]|0}M=ae&z;c[s>>2]=U|M<<16>>16==K<<16>>16?M&65535:0;M=W+(V*112|0)+108|0;K=(c[M>>2]|0)+1|0;c[M>>2]=K;ad=K}g[1716508+(V<<3)>>2]=+(ad|0);break};case 4:{K=W+(V*112|0)+104|0;M=(a[W+(V*112|0)+64|0]&1)==0;if(M){af=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{af=b[c[W+(V*112|0)+68>>2]>>1]|0}U=b[W+(V*112|0)+80>>1]|0;s=U&af;z=b[W+(V*112|0)+82>>1]|0;N=z<<16>>16==0;if((c[K>>2]|0)==((N|s<<16>>16==z<<16>>16?s&65535:0)|0)){ag=c[W+(V*112|0)+100>>2]|0}else{if(M){ah=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ah=b[c[W+(V*112|0)+68>>2]>>1]|0}M=ah&U;c[K>>2]=N|M<<16>>16==z<<16>>16?M&65535:0;M=W+(V*112|0)+96|0;z=c[M>>2]|0;c[W+(V*112|0)+100>>2]=z;c[M>>2]=C;ag=z}g[1716508+(V<<3)>>2]=+(ag|0);break};default:{}}V=V+1|0;if(V>>>0>=S>>>0){break L10467}}}}while(0);c[429254]=S;ai=S}else{ai=c[429254]|0}if((ai|0)==0){i=r;return}else{aj=0}do{ai=dG(c[1716440+(c[3579464]<<2)>>2]|0,c[1716504+(aj<<3)>>2]|0)|0;bE(ai|0,+(+g[1716508+(aj<<3)>>2]));aj=aj+1|0;}while(aj>>>0<(c[429254]|0)>>>0);i=r;return}function jx(b){b=b|0;var d=0;if(!(a[672240]|0)){return}if((c[429284]|0)!=0){d=0;do{c3(c[1717024+(d<<2)>>2]|0);d=d+1|0;}while(d>>>0<(c[429284]|0)>>>0)}c[429284]=0;c[3579464]=b;d6(c[1716440+(b<<2)>>2]|0);return}function jy(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(!(a[672240]|0)){b=0;return b|0}d=c[(c[427250]|0)+72>>2]|0;if((d|0)==0){b=0;return b|0}else{e=0;f=1}while(1){if((c[1709388+(f*460|0)>>2]|0)>-1){g=(e|0)==0?1:e}else{g=e}if((c[1709404+(f*460|0)>>2]|0)>-1){h=g>>>0<2?2:g}else{h=g}if((c[1709420+(f*460|0)>>2]|0)>-1){i=h>>>0<3?3:h}else{i=h}if((c[1709436+(f*460|0)>>2]|0)>-1){j=i>>>0<4?4:i}else{j=i}if((c[1709452+(f*460|0)>>2]|0)>-1){k=j>>>0<5?5:j}else{k=j}if((c[1709468+(f*460|0)>>2]|0)>-1){l=k>>>0<6?6:k}else{l=k}if((c[1709484+(f*460|0)>>2]|0)>-1){m=l>>>0<7?7:l}else{m=l}n=f+1|0;if(n>>>0>d>>>0){b=m;break}else{e=m;f=n}}return b|0}function jz(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0|a[672240]^1){a[d|0]=0;return}else{e=d|0;d=(c[427250]|0)+76+((b-1|0)*4148|0)+4104|0;aIy(e|0,d|0,32)|0;return}}function jA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+560|0;e=d|0;f=d+512|0;if(!(a[672240]|0)){g=0;i=d;return g|0}if((a[(c[427250]|0)+4|0]&1)==0){g=0;i=d;return g|0}h=f|0;j=c[3579464]|0;k=c[1709044+(j*460|0)>>2]|0;if((k|0)>-1){c[f>>2]=k;c[f+4>>2]=2;c[f+8>>2]=0;k=f+12|0;f=e;l=c[b+8>>2]|0;aIy(f|0,l|0,32)|0;m=k;n=1;o=8}else{m=h;n=0;o=0}k=c[1709048+(j*460|0)>>2]|0;if((k|0)>-1){c[m>>2]=k;c[m+4>>2]=2;c[m+8>>2]=o<<2;k=n+1|0;l=m+12|0;f=e+(o<<2)|0;p=c[b>>2]|0;aIy(f|0,p|0,32)|0;q=l;r=k;s=o+8|0}else{q=m;r=n;s=o}o=c[1709052+(j*460|0)>>2]|0;if((o|0)>-1){c[q>>2]=o;c[q+4>>2]=4;c[q+8>>2]=s<<2;o=r+1|0;n=q+12|0;m=e+(s<<2)|0;k=c[b+4>>2]|0;aIy(m|0,k|0,64)|0;t=n;u=o;v=s+16|0}else{t=q;u=r;v=s}s=c[1709056+(j*460|0)>>2]|0;if((s|0)>-1){c[t>>2]=s;c[t+4>>2]=2;c[t+8>>2]=v<<2;t=u+1|0;s=e+(v<<2)|0;r=c[b+12>>2]|0;aIy(s|0,r|0,32)|0;w=t;x=v+8|0}else{w=u;x=v}if((x|0)==0){g=1;i=d;return g|0}jC(c[1692360+(j*1040|0)>>2]|0,1692364+(j*1040|0)|0,1692876+(j*1040|0)|0,e|0,x,h,w);g=1;i=d;return g|0}function jB(b){b=b|0;var d=0,e=0;if(!(a[672240]|0)){d=0;return d|0}if((a[(c[427250]|0)+4|0]&1)==0){d=0;return d|0}e=c[1709040+((c[3579464]|0)*460|0)>>2]|0;if((e|0)<=-1){d=1;return d|0}eV(e|0,1,0,b|0);d=1;return d|0}function jC(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;bY(34962,a|0);if((c[d>>2]|0)==(f|0)){a=e;i=b;j=f<<2;if((aID(a|0,i|0,j|0)|0)!=0){k=i;l=a;m=j;n=7615}}else{k=b;l=e;m=f<<2;n=7615}if((n|0)==7615){aIy(k|0,l|0,m)|0;dE(34962,m|0,l|0,35044);c[d>>2]=f}if((h|0)==0){bY(34962,0);return}else{o=0}do{f=c[g+(o*12|0)>>2]|0;dr(f|0);d=c[429284]|0;c[429284]=d+1;c[1717024+(d<<2)>>2]=f;bW(f|0,c[g+(o*12|0)+4>>2]|0,5126,0,0,c[g+(o*12|0)+8>>2]|0);o=o+1|0;}while(o>>>0<h>>>0);bY(34962,0);return}function jD(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=i;i=i+88|0;g=f|0;h=f+64|0;j=f+72|0;k=f+80|0;l=eG()|0;if((l|0)==0){m=0;i=f;return m|0}n=(b|0)!=0;do{if(n){if((a[1820736]&1)!=0){o=c[494446]|0;q=(o|0)!=0?o:c[p>>2]|0;a5(705792,37,1,q|0)|0;q=c[494446]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0}o=bJ(35633)|0;if(jG(o,705432,b)|0){cl(l|0,o|0);break}o=c[494446]|0;q=(o|0)!=0?o:c[p>>2]|0;ei(q|0,705040,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;q=c[494446]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;m=0;i=f;return m|0}}while(0);b=(d|0)!=0;do{if(b){if((a[1820736]&1)!=0){o=c[494446]|0;q=(o|0)!=0?o:c[p>>2]|0;a5(704752,39,1,q|0)|0;q=c[494446]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0}o=bJ(35632)|0;if(jG(o,704384,d)|0){cl(l|0,o|0);break}o=c[494446]|0;q=(o|0)!=0?o:c[p>>2]|0;ei(q|0,703928,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;q=c[494446]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;m=0;i=f;return m|0}}while(0);if(!(n|b)){m=l;i=f;return m|0}if((a[1820736]&1)!=0){b=c[494446]|0;n=(b|0)!=0?b:c[p>>2]|0;a5(703352,33,1,n|0)|0;n=c[494446]|0;b=(n|0)!=0?n:c[p>>2]|0;a_(b|0)|0}bP(l|0);dN(l|0,35714,k|0);c[h>>2]=0;dN(l|0,35716,j|0);b=c[j>>2]|0;do{if((b|0)!=0){j=aIp(b)|0;if((j|0)==0){break}d9(l|0,b|0,h|0,j|0);do{if((c[h>>2]|0)>0){if((a[1820736]&1)==0){break}n=c[494446]|0;d=(n|0)!=0?n:c[p>>2]|0;ei(d|0,702320,(r=i,i=i+8|0,c[r>>2]=j,r)|0)|0;i=r;d=c[494446]|0;n=(d|0)!=0?d:c[p>>2]|0;a_(n|0)|0}}while(0);aIq(j)}}while(0);if((c[k>>2]|0)!=1){k=c[494446]|0;h=(k|0)!=0?k:c[p>>2]|0;ei(h|0,702584,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;e=c[494446]|0;h=(e|0)!=0?e:c[p>>2]|0;a_(h|0)|0;m=0;i=f;return m|0}d6(l|0);d6(l|0);h=g|0;bQ(h|0,64,709496,(r=i,i=i+16|0,c[r>>2]=(c[427250]|0)+5,c[r+8>>2]=709080,r)|0)|0;i=r;g=dG(l|0,h|0)|0;L10670:do{if((g|0)>-1){s=g}else{e=0;while(1){if(e>>>0>=2){s=-1;break L10670}bQ(h|0,64,709496,(r=i,i=i+16|0,c[r>>2]=c[672232+(e<<2)>>2],c[r+8>>2]=709080,r)|0)|0;i=r;k=dG(l|0,h|0)|0;if((k|0)>-1){s=k;break}else{e=e+1|0}}}}while(0);bL(s|0,0);d6(0);m=l;i=f;return m|0}function jE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e+64|0;d6(b|0);g=e|0;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=726280,h)|0)|0;i=h;j=dG(b|0,g|0)|0;L10677:do{if((j|0)>-1){k=j}else{l=0;while(1){if(l>>>0>=2){k=-1;break L10677}bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(l<<2)>>2],c[h+8>>2]=726280,h)|0)|0;i=h;m=dG(b|0,g|0)|0;if((m|0)>-1){k=m;break}else{l=l+1|0}}}}while(0);c[d>>2]=k;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=724768,h)|0)|0;i=h;k=dG(b|0,g|0)|0;L10682:do{if((k|0)>-1){n=k}else{j=0;while(1){if(j>>>0>=2){n=-1;break L10682}bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(j<<2)>>2],c[h+8>>2]=724768,h)|0)|0;i=h;l=eB(b|0,g|0)|0;if((l|0)>-1){n=l;break}else{j=j+1|0}}}}while(0);c[d+4>>2]=n;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=723776,h)|0)|0;i=h;n=dG(b|0,g|0)|0;L10687:do{if((n|0)>-1){o=n}else{k=0;while(1){if(k>>>0>=2){o=-1;break L10687}bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(k<<2)>>2],c[h+8>>2]=723776,h)|0)|0;i=h;j=eB(b|0,g|0)|0;if((j|0)>-1){o=j;break}else{k=k+1|0}}}}while(0);c[d+8>>2]=o;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=722344,h)|0)|0;i=h;o=dG(b|0,g|0)|0;L10692:do{if((o|0)>-1){p=o}else{n=0;while(1){if(n>>>0>=2){p=-1;break L10692}bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(n<<2)>>2],c[h+8>>2]=722344,h)|0)|0;i=h;k=eB(b|0,g|0)|0;if((k|0)>-1){p=k;break}else{n=n+1|0}}}}while(0);c[d+12>>2]=p;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=720976,h)|0)|0;i=h;p=dG(b|0,g|0)|0;L10697:do{if((p|0)>-1){q=p}else{o=0;while(1){if(o>>>0>=2){q=-1;break L10697}bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(o<<2)>>2],c[h+8>>2]=720976,h)|0)|0;i=h;n=eB(b|0,g|0)|0;if((n|0)>-1){q=n;break}else{o=o+1|0}}}}while(0);c[d+16>>2]=q;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=719968,h)|0)|0;i=h;q=dG(b|0,g|0)|0;L10702:do{if((q|0)>-1){r=q}else{p=0;while(1){if(p>>>0>=2){r=-1;break L10702}bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(p<<2)>>2],c[h+8>>2]=719968,h)|0)|0;i=h;o=dG(b|0,g|0)|0;if((o|0)>-1){r=o;break}else{p=p+1|0}}}}while(0);c[d+20>>2]=r;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=718896,h)|0)|0;i=h;r=dG(b|0,g|0)|0;L10707:do{if((r|0)>-1){s=r}else{q=0;while(1){if(q>>>0>=2){s=-1;break L10707}bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(q<<2)>>2],c[h+8>>2]=718896,h)|0)|0;i=h;p=dG(b|0,g|0)|0;if((p|0)>-1){s=p;break}else{q=q+1|0}}}}while(0);c[d+24>>2]=s;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=717976,h)|0)|0;i=h;s=dG(b|0,g|0)|0;L10712:do{if((s|0)>-1){t=s}else{r=0;while(1){if(r>>>0>=2){t=-1;break L10712}bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(r<<2)>>2],c[h+8>>2]=717976,h)|0)|0;i=h;q=dG(b|0,g|0)|0;if((q|0)>-1){t=q;break}else{r=r+1|0}}}}while(0);c[d+28>>2]=t;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=716976,h)|0)|0;i=h;t=dG(b|0,g|0)|0;L10717:do{if((t|0)>-1){u=t}else{s=0;while(1){if(s>>>0>=2){u=-1;break L10717}bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(s<<2)>>2],c[h+8>>2]=716976,h)|0)|0;i=h;r=dG(b|0,g|0)|0;if((r|0)>-1){u=r;break}else{s=s+1|0}}}}while(0);c[d+32>>2]=u;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=715720,h)|0)|0;i=h;u=dG(b|0,g|0)|0;L10722:do{if((u|0)>-1){v=u}else{t=0;while(1){if(t>>>0>=2){v=-1;break L10722}bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(t<<2)>>2],c[h+8>>2]=715720,h)|0)|0;i=h;s=dG(b|0,g|0)|0;if((s|0)>-1){v=s;break}else{t=t+1|0}}}}while(0);c[d+40>>2]=v;v=c[427250]|0;if((c[v+66444>>2]|0)!=0){g=0;u=v;do{c[d+44+(g<<2)>>2]=dG(b|0,u+66448+(g*4168|0)|0)|0;g=g+1|0;u=c[427250]|0;}while(g>>>0<(c[u+66444>>2]|0)>>>0)}u=d+76|0;aIv(u|0,-1|0,16);jF(b,u,714088);g=f|0;if(a>>>0>1){bQ(g|0,64,712704,(h=i,i=i+8|0,c[h>>2]=a,h)|0)|0;i=h;jF(b,u,g);w=0}else{w=0}while(1){u=w+1|0;bQ(g|0,64,711584,(h=i,i=i+8|0,c[h>>2]=u,h)|0)|0;i=h;f=d+92+(w<<4)|0;aIv(f|0,-1|0,16);jF(b,f,g);if((w|0)!=0&u>>>0<a>>>0){v=a-w|0;bQ(g|0,64,712704,(h=i,i=i+8|0,c[h>>2]=v,h)|0)|0;i=h;jF(b,f,g)}if(u>>>0<16){w=u}else{break}}w=d+348|0;aIv(w|0,-1|0,16);jF(b,w,711e3);bQ(g|0,64,710184,(h=i,i=i+8|0,c[h>>2]=1,h)|0)|0;i=h;w=d+364|0;aIv(w|0,-1|0,16);jF(b,w,g);bQ(g|0,64,710184,(h=i,i=i+8|0,c[h>>2]=2,h)|0)|0;i=h;w=d+380|0;aIv(w|0,-1|0,16);jF(b,w,g);bQ(g|0,64,710184,(h=i,i=i+8|0,c[h>>2]=3,h)|0)|0;i=h;w=d+396|0;aIv(w|0,-1|0,16);jF(b,w,g);bQ(g|0,64,710184,(h=i,i=i+8|0,c[h>>2]=4,h)|0)|0;i=h;w=d+412|0;aIv(w|0,-1|0,16);jF(b,w,g);bQ(g|0,64,710184,(h=i,i=i+8|0,c[h>>2]=5,h)|0)|0;i=h;w=d+428|0;aIv(w|0,-1|0,16);jF(b,w,g);bQ(g|0,64,710184,(h=i,i=i+8|0,c[h>>2]=6,h)|0)|0;i=h;h=d+444|0;aIv(h|0,-1|0,16);jF(b,h,g);d6(0);i=e;return}function jF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+320|0;f=e|0;g=e+64|0;bQ(g|0,64,709496,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=709080,h)|0)|0;i=h;j=e+128|0;bQ(j|0,64,709496,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=717976,h)|0)|0;i=h;k=e+192|0;bQ(k|0,64,709496,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=719968,h)|0)|0;i=h;l=e+256|0;bQ(l|0,64,709496,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=724768,h)|0)|0;i=h;d=b|0;if((c[d>>2]|0)<0){m=f|0;n=(c[427250]|0)+5|0;bQ(m|0,64,709496,(h=i,i=i+16|0,c[h>>2]=n,c[h+8>>2]=g,h)|0)|0;i=h;n=dG(a|0,m|0)|0;L10742:do{if((n|0)>-1){o=n}else{p=0;while(1){if(p>>>0>=2){o=-1;break L10742}bQ(m|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(p<<2)>>2],c[h+8>>2]=g,h)|0)|0;i=h;q=dG(a|0,m|0)|0;if((q|0)>-1){o=q;break}else{p=p+1|0}}}}while(0);c[d>>2]=o}o=b+8|0;if((c[o>>2]|0)<0){d=f|0;m=(c[427250]|0)+5|0;bQ(d|0,64,709496,(h=i,i=i+16|0,c[h>>2]=m,c[h+8>>2]=j,h)|0)|0;i=h;m=dG(a|0,d|0)|0;L10750:do{if((m|0)>-1){r=m}else{g=0;while(1){if(g>>>0>=2){r=-1;break L10750}bQ(d|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(g<<2)>>2],c[h+8>>2]=j,h)|0)|0;i=h;n=dG(a|0,d|0)|0;if((n|0)>-1){r=n;break}else{g=g+1|0}}}}while(0);c[o>>2]=r}r=b+4|0;if((c[r>>2]|0)<0){o=f|0;d=(c[427250]|0)+5|0;bQ(o|0,64,709496,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=k,h)|0)|0;i=h;d=dG(a|0,o|0)|0;L10758:do{if((d|0)>-1){s=d}else{j=0;while(1){if(j>>>0>=2){s=-1;break L10758}bQ(o|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(j<<2)>>2],c[h+8>>2]=k,h)|0)|0;i=h;m=dG(a|0,o|0)|0;if((m|0)>-1){s=m;break}else{j=j+1|0}}}}while(0);c[r>>2]=s}s=b+12|0;if((c[s>>2]|0)>=0){i=e;return}b=f|0;bQ(b|0,64,709496,(h=i,i=i+16|0,c[h>>2]=(c[427250]|0)+5,c[h+8>>2]=l,h)|0)|0;i=h;f=dG(a|0,b|0)|0;L10767:do{if((f|0)>-1){t=f}else{r=0;while(1){if(r>>>0>=2){t=-1;break L10767}bQ(b|0,64,709496,(h=i,i=i+16|0,c[h>>2]=c[672232+(r<<2)>>2],c[h+8>>2]=l,h)|0)|0;i=h;o=eB(a|0,b|0)|0;if((o|0)>-1){t=o;break}else{r=r+1|0}}}}while(0);c[s>>2]=t;i=e;return}function jG(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=i;i=i+72|0;g=f|0;h=f+8|0;j=f+48|0;k=f+64|0;l=f+16|0;aIv(l|0,0,32);do{if((a[1709032]&1)!=0){if((bx(e|0,702080)|0)!=0){break}m=((c[427252]|0)*10|0)+((c[427254]|0)*100|0)|0;if((m|0)==310){n=140}else if((m|0)==320){n=150}else if((m|0)==300){n=130}else{n=m}bQ(l|0,32,701776,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;if((a[1820736]&1)==0){break}m=c[494446]|0;q=(m|0)!=0?m:c[p>>2]|0;ei(q|0,701512,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;q=c[494446]|0;m=(q|0)!=0?q:c[p>>2]|0;a_(m|0)|0}}while(0);n=j|0;c[n>>2]=l;c[j+4>>2]=d;c[j+8>>2]=e;bU(b|0,3,n|0,0);be(b|0);cV(b|0,35713,k|0);c[g>>2]=0;cV(b|0,35716,h|0);n=c[h>>2]|0;if((n|0)==0){r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}h=aIp(n)|0;if((h|0)==0){r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}ef(b|0,n|0,g|0,h|0);do{if((c[g>>2]|0)>0){if((a[1820736]&1)==0){break}n=c[494446]|0;b=(n|0)!=0?n:c[p>>2]|0;ei(b|0,701264,(o=i,i=i+8|0,c[o>>2]=h,o)|0)|0;i=o;b=c[494446]|0;n=(b|0)!=0?b:c[p>>2]|0;a_(n|0)|0}}while(0);aIq(h);r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}function jH(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=i;k=e|0;l=e+4|0;m=e+9|0;switch(d[m]|0){case 0:{n=d[e+8|0]|0;o=((ab(c[k>>2]|0,n)|0)+7|0)>>>3;q=(n+7|0)>>>3;break};case 3:{n=d[e+8|0]|0;o=((ab(c[k>>2]|0,n)|0)+7|0)>>>3;q=(n+7|0)>>>3;break};case 6:{n=d[e+8|0]<<2;o=((ab(n,c[k>>2]|0)|0)+7|0)>>>3;q=(n+7|0)>>>3;break};case 2:{n=(d[e+8|0]|0)*3|0;o=((ab(n,c[k>>2]|0)|0)+7|0)>>>3;q=(n+7|0)>>>3;break};case 4:{n=d[e+8|0]<<1;o=((ab(n,c[k>>2]|0)|0)+7|0)>>>3;q=(n+7|0)>>>3;break};default:{o=0;q=0}}n=o+1|0;if((ab(c[l>>2]|0,n)|0)>>>0>g>>>0){r=0;i=j;return r|0}g=aIp(o)|0;do{if((g|0)!=0){if((c[g-4>>2]&3|0)==0){break}aIv(g|0,0,o|0)}}while(0);s=aIp(o)|0;L10810:do{if((s|0)==0){t=c[p>>2]|0;ei(t|0,726832,(u=i,i=i+8|0,c[u>>2]=394,u)|0)|0;i=u;v=0}else{if((c[s-4>>2]&3|0)!=0){aIv(s|0,0,o|0)}if((c[l>>2]|0)==0){v=1;break}t=e+8|0;w=(q|0)==0;x=(o|0)==0;y=0;z=f;A=b;L10816:while(1){L10818:do{switch(d[z]|0){case 4:{if(w){B=0}else{C=0;while(1){D=C+1|0;a[s+C|0]=(a[z+D|0]|0)+(a[g+C|0]|0)&255;if(D>>>0<q>>>0){C=D}else{B=q;break}}}if(B>>>0<o>>>0){E=B}else{break L10818}while(1){C=E-B|0;D=a[s+C|0]|0;F=D&255;G=a[g+E|0]|0;H=G&255;I=a[g+C|0]|0;C=I&255;J=H+F-C|0;K=J-F|0;F=(K|0)>-1?K:-K|0;K=J-H|0;H=(K|0)>-1?K:-K|0;K=J-C|0;C=(K|0)>-1?K:-K|0;if((F|0)>(H|0)|(F|0)>(C|0)){L=(H|0)>(C|0)?I:G}else{L=D}D=E+1|0;a[s+E|0]=(a[z+D|0]|0)+L&255;if(D>>>0<o>>>0){E=D}else{break}}break};case 1:{if(w){M=0}else{D=0;while(1){G=D+1|0;a[s+D|0]=a[z+G|0]|0;if(G>>>0<q>>>0){D=G}else{M=q;break}}}if(M>>>0<o>>>0){N=M}else{break L10818}while(1){D=N+1|0;a[s+N|0]=(a[z+D|0]|0)+(a[s+(N-M)|0]|0)&255;if(D>>>0<o>>>0){N=D}else{break}}break};case 0:{D=z+1|0;aIy(s|0,D|0,o)|0;break};case 2:{if(x){break L10818}else{O=0}while(1){D=O+1|0;a[s+O|0]=(a[z+D|0]|0)+(a[g+O|0]|0)&255;if(D>>>0<o>>>0){O=D}else{break}}break};case 3:{if(w){P=0}else{D=0;while(1){G=D+1|0;a[s+D|0]=((d[g+D|0]|0)>>>1)+(a[z+G|0]|0)&255;if(G>>>0<q>>>0){D=G}else{P=q;break}}}if(P>>>0<o>>>0){Q=P}else{break L10818}while(1){D=Q+1|0;a[s+Q|0]=(((d[g+Q|0]|0)+(d[s+(Q-P)|0]|0)|0)>>>1)+(d[z+D|0]|0)&255;if(D>>>0<o>>>0){Q=D}else{break}}break};default:{break L10816}}}while(0);L10848:do{switch(a[m]|0){case 0:{D=c[k>>2]|0;G=a[t]|0;I=G&255;if(G<<24>>24==16){if((D|0)==0){break L10848}else{R=0}while(1){c[A+(R<<2)>>2]=(d[s+(R<<1)|0]|0)*65793|0|-16777216;R=R+1|0;if(R>>>0>=D>>>0){break L10848}}}G=(1<<I)-1|0;if((D|0)==0){break L10848}C=8-I|0;H=(c[684344+(I<<2)>>2]|0)*65793|0;F=0;K=0;while(1){c[A+(K<<2)>>2]=ab(H,(d[s+(F>>>3)|0]|0)>>>((C-(F&7)|0)>>>0)&G)|0|-16777216;J=K+1|0;if(J>>>0<D>>>0){F=F+I|0;K=J}else{break}}break};case 2:{K=c[k>>2]|0;I=(d[t]|0)>>>3;if((K|0)==0){break L10848}F=I<<1;D=F+I|0;G=0;C=s;while(1){c[A+(G<<2)>>2]=d[C]<<16|d[C+I|0]<<8|d[C+F|0]|-16777216;H=G+1|0;if(H>>>0<K>>>0){G=H;C=C+D|0}else{break}}break};case 3:{D=c[k>>2]|0;C=d[t]|0;G=(1<<C)-1|0;if((D|0)==0){break L10848}K=8-C|0;F=0;I=0;while(1){c[A+(I<<2)>>2]=c[h+(((d[s+(F>>>3)|0]|0)>>>((K-(F&7)|0)>>>0)&G)<<2)>>2];H=I+1|0;if(H>>>0<D>>>0){F=F+C|0;I=H}else{break}}break};case 4:{I=c[k>>2]|0;C=(d[t]|0)>>>3;if((I|0)==0){break L10848}F=C<<1;D=0;G=s;while(1){c[A+(D<<2)>>2]=d[G+C|0]<<24|((d[G]|0)*65793|0);K=D+1|0;if(K>>>0<I>>>0){D=K;G=G+F|0}else{break}}break};case 6:{F=c[k>>2]|0;G=(d[t]|0)>>>3;if((F|0)==0){break L10848}D=G<<1;I=D+G|0;C=I+G|0;K=0;H=s;while(1){c[A+(K<<2)>>2]=d[H+G|0]<<8|d[H]<<16|d[H+D|0]|d[H+I|0]<<24;J=K+1|0;if(J>>>0<F>>>0){K=J;H=H+C|0}else{break}}break};default:{}}}while(0);aIy(g|0,s|0,o)|0;C=y+1|0;if(C>>>0<(c[l>>2]|0)>>>0){y=C;z=z+n|0;A=A+(c[k>>2]<<2)|0}else{v=1;break L10810}}ei(c[p>>2]|0,726832,(u=i,i=i+8|0,c[u>>2]=439,u)|0)|0;i=u;v=0}}while(0);aIq(s);aIq(g);r=v;i=j;return r|0}function jI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+16|0;d=b|0;e=b+8|0;if((a|0)==0){f=-2;i=b;return f|0}g=c[a+28>>2]|0;if((g|0)==0){f=-2;i=b;return f|0}h=g;j=(c[h+11008>>2]|0)>0?9:8;k=a+4|0;l=c[k>>2]|0;m=h+11e3|0;n=c[m>>2]|0;c[m>>2]=0;m=h+43780|0;if((c[m>>2]|0)<0){f=-3;i=b;return f|0}o=h+11004|0;c[o>>2]=c[o>>2]|1;if((n|0)!=0){c[d>>2]=c[k>>2];n=a+16|0;c[e>>2]=c[n>>2];o=g;p=a|0;q=a+12|0;r=c[q>>2]|0;s=jJ(o,c[p>>2]|0,d,r,r,e,j|4)|0;c[m>>2]=s;r=c[d>>2]|0;c[p>>2]=(c[p>>2]|0)+r;c[k>>2]=(c[k>>2]|0)-r;p=a+8|0;c[p>>2]=(c[p>>2]|0)+r;c[a+40>>2]=c[o+28>>2];o=c[e>>2]|0;c[q>>2]=(c[q>>2]|0)+o;c[n>>2]=(c[n>>2]|0)-o;n=a+20|0;c[n>>2]=(c[n>>2]|0)+o;if((s|0)<0){f=-3;i=b;return f|0}if((s|0)==0){f=1;i=b;return f|0}c[m>>2]=-1;f=-5;i=b;return f|0}s=h+10996|0;o=c[s>>2]|0;if((o|0)!=0){n=a+16|0;q=c[n>>2]|0;r=o>>>0<q>>>0?o:q;q=a+12|0;o=c[q>>2]|0;p=h+10992|0;t=(c[p>>2]|0)+(h+11012)|0;aIy(o|0,t|0,r)|0;c[q>>2]=(c[q>>2]|0)+r;c[n>>2]=(c[n>>2]|0)-r;n=a+20|0;c[n>>2]=(c[n>>2]|0)+r;n=c[s>>2]|0;c[s>>2]=n-r;c[p>>2]=(c[p>>2]|0)+r&32767;if((c[m>>2]|0)!=0){f=0;i=b;return f|0}f=(n|0)==(r|0)|0;i=b;return f|0}r=h+10992|0;n=g;g=a|0;p=h+11012|0;q=a+8|0;t=n+28|0;o=a+40|0;u=a+16|0;v=a+12|0;w=a+20|0;a=c[r>>2]|0;L10906:do{if((l|0)==0){x=a;while(1){c[d>>2]=c[k>>2];c[e>>2]=32768-x;y=jJ(n,c[g>>2]|0,d,p,h+11012+x|0,e,j)|0;c[m>>2]=y;z=c[d>>2]|0;c[g>>2]=(c[g>>2]|0)+z;c[k>>2]=(c[k>>2]|0)-z;c[q>>2]=(c[q>>2]|0)+z;c[o>>2]=c[t>>2];z=c[e>>2]|0;c[s>>2]=z;A=c[u>>2]|0;B=z>>>0<A>>>0?z:A;A=c[v>>2]|0;z=(c[r>>2]|0)+(h+11012)|0;aIy(A|0,z|0,B)|0;c[v>>2]=(c[v>>2]|0)+B;c[u>>2]=(c[u>>2]|0)-B;c[w>>2]=(c[w>>2]|0)+B;z=(c[s>>2]|0)-B|0;c[s>>2]=z;A=(c[r>>2]|0)+B&32767;c[r>>2]=A;if((y|0)<0){f=-3;C=7822;break}if((y|0)==1){f=-5;C=7821;break}else if((y|0)==0){D=z;break L10906}if((c[u>>2]|0)==0){f=-5;C=7816;break}else{x=A}}if((C|0)==7821){i=b;return f|0}else if((C|0)==7822){i=b;return f|0}else if((C|0)==7816){i=b;return f|0}}else{x=a;while(1){c[d>>2]=c[k>>2];c[e>>2]=32768-x;A=jJ(n,c[g>>2]|0,d,p,h+11012+x|0,e,j)|0;c[m>>2]=A;z=c[d>>2]|0;c[g>>2]=(c[g>>2]|0)+z;c[k>>2]=(c[k>>2]|0)-z;c[q>>2]=(c[q>>2]|0)+z;c[o>>2]=c[t>>2];z=c[e>>2]|0;c[s>>2]=z;y=c[u>>2]|0;B=z>>>0<y>>>0?z:y;y=c[v>>2]|0;z=(c[r>>2]|0)+(h+11012)|0;aIy(y|0,z|0,B)|0;c[v>>2]=(c[v>>2]|0)+B;c[u>>2]=(c[u>>2]|0)-B;c[w>>2]=(c[w>>2]|0)+B;z=(c[s>>2]|0)-B|0;c[s>>2]=z;y=(c[r>>2]|0)+B&32767;c[r>>2]=y;if((A|0)<0){f=-3;C=7813;break}if((A|0)==0){D=z;break L10906}if((c[u>>2]|0)==0){f=-5;C=7819;break}else{x=y}}if((C|0)==7819){i=b;return f|0}else if((C|0)==7813){i=b;return f|0}}}while(0);f=(D|0)!=0?-5:1;i=b;return f|0}function jJ(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gj=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0,hQ=0,hR=0,hS=0,hT=0,hU=0,hV=0,hW=0,hX=0,hY=0,hZ=0,h_=0,h$=0,h0=0,h1=0,h2=0,h3=0,h4=0,h5=0,h6=0,h7=0,h8=0,h9=0,ia=0,ib=0,ic=0,id=0,ie=0,ig=0,ih=0,ii=0,ij=0,ik=0,il=0,im=0,io=0,ip=0,iq=0,ir=0,is=0,it=0,iu=0,iv=0,iw=0,ix=0,iy=0,iz=0,iA=0,iB=0,iC=0,iD=0,iE=0,iF=0,iG=0,iH=0,iI=0,iJ=0,iK=0,iL=0,iM=0,iN=0,iO=0,iP=0,iQ=0,iR=0,iS=0,iT=0,iU=0,iV=0,iW=0,iX=0,iY=0,iZ=0,i_=0,i$=0,i0=0,i1=0,i2=0,i3=0,i4=0,i5=0,i6=0,i7=0,i8=0,i9=0,ja=0,jb=0,jc=0,jd=0,je=0,jf=0,jg=0,jh=0,ji=0,jj=0,jk=0,jl=0,jm=0,jn=0,jo=0,jp=0,jq=0,jr=0,js=0,jt=0,ju=0,jv=0,jw=0,jx=0,jy=0,jz=0,jA=0,jB=0,jC=0,jD=0,jE=0,jF=0,jG=0,jH=0,jI=0,jJ=0,jK=0,jL=0,jM=0,jN=0,jO=0,jP=0,jQ=0,jR=0,jS=0,jT=0,jU=0,jV=0,jW=0,jX=0,jY=0,jZ=0,j_=0,j$=0,j0=0,j1=0,j2=0,j3=0,j4=0,j5=0,j6=0,j7=0,j8=0,j9=0,ka=0,kb=0,kc=0,kd=0,ke=0,kf=0,kg=0,kh=0,ki=0,kj=0,kk=0,kl=0,km=0,kn=0,ko=0,kp=0,kq=0,kr=0,ks=0,kt=0,ku=0,kv=0,kw=0,kx=0,ky=0,kz=0,kA=0,kB=0,kC=0,kD=0,kE=0,kF=0,kG=0,kH=0,kI=0,kJ=0,kK=0,kL=0,kM=0,kN=0,kO=0,kP=0,kQ=0,kR=0,kS=0,kT=0,kU=0,kV=0,kW=0,kX=0,kY=0,kZ=0,k_=0,k$=0,k0=0,k1=0,k2=0,k3=0,k4=0,k5=0,k6=0,k7=0,k8=0,k9=0,la=0,lb=0,lc=0,ld=0,le=0,lf=0,lg=0,lh=0,li=0,lj=0,lk=0,ll=0,lm=0,ln=0,lo=0,lp=0,lq=0,lr=0,ls=0,lt=0,lu=0,lv=0,lw=0,lx=0,ly=0,lz=0,lA=0,lB=0,lC=0,lD=0,lE=0,lF=0,lG=0,lH=0,lI=0,lJ=0,lK=0,lL=0,lM=0,lN=0,lO=0,lP=0,lQ=0,lR=0,lS=0,lT=0,lU=0,lV=0,lW=0,lX=0,lY=0,lZ=0,l_=0,l$=0,l0=0,l1=0,l2=0,l3=0,l4=0,l5=0,l6=0,l7=0,l8=0,l9=0,ma=0,mb=0,mc=0,md=0,me=0,mf=0,mg=0,mh=0,mi=0,mj=0,mk=0,ml=0,mm=0,mn=0,mo=0,mp=0,mq=0,mr=0,ms=0,mt=0,mu=0,mv=0,mw=0,mx=0,my=0,mz=0,mA=0,mB=0,mC=0,mD=0,mE=0,mF=0,mG=0,mH=0,mI=0,mJ=0,mK=0,mL=0,mM=0,mN=0,mO=0,mP=0,mQ=0,mR=0,mS=0,mT=0,mU=0,mV=0,mW=0,mX=0,mY=0,mZ=0,m_=0,m$=0,m0=0,m1=0,m2=0,m3=0,m4=0,m5=0;m=i;i=i+136|0;n=m|0;o=m+72|0;p=c[g>>2]|0;q=f+p|0;r=c[k>>2]|0;s=j+r|0;t=(l&4|0)!=0;if(t){u=-1}else{u=j+~h+r|0}r=u+1|0;if((r&u|0)!=0|j>>>0<h>>>0){c[k>>2]=0;c[g>>2]=0;v=-3;i=m;return v|0}w=e+4|0;y=c[w>>2]|0;z=e+56|0;A=c[z>>2]|0;B=e+32|0;C=c[B>>2]|0;D=e+36|0;E=c[D>>2]|0;F=e+40|0;G=c[F>>2]|0;H=e+60|0;I=c[H>>2]|0;J=e|0;L10932:do{switch(c[J>>2]|0){case 37:{K=y;L=C;M=E;N=G;O=A;P=I;Q=f;R=j;S=8085;break};case 27:{if((p|0)<=0){T=y;U=C;V=E;W=G;X=A;Y=I;Z=f;_=j;S=8077;break L10932}$=d[f]|0;aa=y;ab=C;ac=E;ad=G;ae=A;af=I;ag=f+1|0;ah=j;S=8082;break};case 41:{if((p|0)<=0){ai=y;aj=C;ak=E;al=G;am=A;an=I;ao=f;ap=j;S=8111;break L10932}aq=d[f]|0;ar=y;as=C;at=E;au=G;av=A;aw=I;ax=f+1|0;ay=j;S=8116;break};case 42:{if((p|0)<=0){az=y;aA=C;aB=E;aC=G;aD=A;aE=I;aF=f;aG=j;S=8119;break L10932}aH=d[f]|0;aI=y;aJ=C;aK=E;aL=G;aM=A;aN=I;aO=f+1|0;aP=j;S=8124;break};case 53:{aQ=y;aR=C;aS=E;aT=G;aU=A;aV=I;aW=f;aX=j;S=8088;break};case 1:{if((p|0)<=0){aY=y;aZ=C;a_=E;a$=G;a0=A;S=7834;break L10932}c[e+8>>2]=d[f]|0;a1=y;a2=C;a3=E;a4=G;a5=A;a6=f+1|0;S=7840;break};case 2:{if((p|0)<=0){a7=y;a8=C;a9=E;ba=G;bb=A;bc=f;S=7841;break L10932}bd=d[f]|0;c[e+12>>2]=bd;be=y;bf=C;bg=G;bh=A;bi=f+1|0;bj=bd;S=7847;break};case 32:{if((p|0)<=0){bk=y;bl=C;bm=E;bn=G;bo=A;bp=I;bq=f;br=j;S=8100;break L10932}bs=d[f]|0;bt=y;bu=C;bv=E;bw=G;bx=A;by=I;bz=f+1|0;bA=j;S=8105;break};case 0:{c[e+12>>2]=0;bd=e+8|0;c[bd>>2]=0;c[e+28>>2]=1;c[e+16>>2]=1;if((l&1|0)==0){bB=0;bC=0;bD=0;bE=0;bF=0;bG=I;bH=f;bI=j;S=7855;break L10932}if((p|0)<1){aY=0;aZ=0;a_=0;a$=0;a0=0;S=7834;break L10932}c[bd>>2]=d[f]|0;a1=0;a2=0;a3=0;a4=0;a5=0;a6=f+1|0;S=7840;break};case 34:{bJ=y;bK=C;bL=E;bM=G;bN=A;bO=I;bP=f;bQ=j;S=8125;break};case 36:{bR=y;bS=C;bT=E;bU=G;bV=A;bW=f;S=7854;break};case 3:{if((p|0)<=0){bX=y;bY=C;bZ=E;b_=G;b$=A;b0=I;b1=f;b2=j;S=7857;break L10932}b3=y;b4=C;b5=E;b6=G;b7=A;b8=d[f]|0;b9=I;ca=f+1|0;cb=j;S=7862;break};case 5:{if((p|0)<=0){cc=y;cd=C;ce=E;cf=G;cg=A;ch=I;ci=f;cj=j;S=7866;break L10932}ck=y;cl=C;cm=E;cn=G;co=A;cp=d[f]|0;cq=I;cr=f+1|0;cs=j;S=7871;break};case 6:{if((p|0)<=0){ct=y;cu=C;cv=E;cw=G;cx=A;cy=I;cz=f;cA=j;S=7877;break L10932}cB=y;cC=C;cD=E;cE=G;cF=A;cG=d[f]|0;cH=I;cI=f+1|0;cJ=j;S=7882;break};case 7:{if((p|0)<=0){cK=y;cL=C;cM=E;cN=G;cO=A;cP=I;cQ=f;cR=j;S=7885;break L10932}a[e+10528+E|0]=a[f]|0;cS=y;cT=C;cU=E;cV=G;cW=A;cX=I;cY=f+1|0;cZ=j;S=7891;break};case 39:{c_=y;c$=C;c0=E;c1=G;c2=A;c3=I;c4=f;c5=j;S=7893;break};case 51:{if((p|0)<=0){c6=y;c7=C;c8=E;c9=G;da=A;db=I;dc=f;dd=j;S=7897;break L10932}de=y;df=C;dg=E;dh=G;di=A;dj=d[f]|0;dk=I;dl=f+1|0;dm=j;S=7902;break};case 52:{dn=y;dp=C;dq=E;dr=G;ds=A;dt=I;du=f;dv=j;S=7904;break};case 9:{dw=y;dx=C;dy=E;dz=G;dA=A;dB=I;dC=f;dD=j;S=7908;break};case 38:{dE=y;dF=C;dG=E;dH=G;dI=A;dJ=I;dK=f;dL=j;S=7910;break};case 40:{dM=y;dN=C;dO=E;dP=G;dQ=A;dR=I;dS=f;dT=j;S=7913;break};case 10:{dU=y;dV=C;dW=E;dX=G;dY=A;dZ=I;d_=f;d$=j;S=7915;break};case 11:{if((p|0)<=0){d0=y;d1=C;d2=E;d3=G;d4=A;d5=I;d6=f;d7=j;S=7919;break L10932}d8=y;d9=C;ea=E;eb=G;ec=d[f]|0;ed=A;ee=I;ef=f+1|0;eg=j;S=7924;break};case 14:{if((p|0)<=0){eh=y;ei=C;ej=E;ek=G;el=A;em=I;en=f;eo=j;S=7930;break L10932}ep=y;eq=C;er=E;es=d[f]|0;et=G;eu=A;ev=I;ew=f+1|0;ex=j;S=7935;break};case 35:{ey=y;ez=C;eA=E;eB=G;eC=A;eD=I;eE=f;eF=j;S=7945;break};case 16:{if((p|0)<=0){eG=y;eH=C;eI=E;eJ=G;eK=A;eL=I;eM=f;eN=j;S=7975;break L10932}eO=d[f]|0;eP=y;eQ=C;eR=E;eS=G;eT=A;eU=I;eV=f+1|0;eW=j;S=7980;break};case 17:{eX=y;eY=C;eZ=E;e_=G;e$=A;e0=I;e1=f;e2=j;S=7988;break};case 18:{if((p|0)<=0){e3=y;e4=C;e5=E;e6=G;e7=A;e8=I;e9=f;fa=j;S=7991;break L10932}fb=d[f]|0;fc=y;fd=C;fe=E;ff=G;fg=A;fh=I;fi=f+1|0;fj=j;S=7996;break};case 21:{fk=y;fl=C;fm=E;fn=G;fo=A;fp=I;fq=f;fr=j;S=8001;break};case 23:{if((p|0)<=0){fs=y;ft=C;fu=E;fv=G;fw=A;fx=I;fy=f;fz=j;S=8014;break L10932}fA=d[f]|0;fB=y;fC=C;fD=E;fE=G;fF=A;fG=I;fH=f+1|0;fI=j;S=8019;break};case 24:{fJ=y;fK=C;fL=E;fM=G;fN=A;fO=I;fP=f;fQ=j;S=8025;break};case 25:{if((p|0)<=0){fR=y;fS=C;fT=E;fU=G;fV=A;fW=I;fX=f;fY=j;S=8048;break L10932}fZ=d[f]|0;f_=y;f$=C;f0=E;f1=G;f2=A;f3=I;f4=f+1|0;f5=j;S=8053;break};case 26:{if((p|0)<=0){f6=y;f7=C;f8=E;f9=G;ga=A;gb=I;gc=f;gd=j;S=8064;break L10932}ge=d[f]|0;gf=y;gg=C;gh=E;gi=G;gj=A;gk=I;gl=f+1|0;gm=j;S=8069;break};default:{gn=-1;go=y;gp=C;gq=E;gr=G;gs=A;gt=I;gu=f;gv=j;S=8126}}}while(0);do{if((S|0)==7834){if((l&2|0)==0){c[e+8>>2]=0;a1=aY;a2=aZ;a3=a_;a4=a$;a5=a0;a6=f;S=7840;break}else{c[J>>2]=1;gn=1;go=aY;gp=aZ;gq=a_;gr=a$;gs=a0;gt=I;gu=f;gv=j;S=8126;break}}}while(0);do{if((S|0)==7840){if(a6>>>0>=q>>>0){a7=a1;a8=a2;a9=a3;ba=a4;bb=a5;bc=a6;S=7841;break}a0=d[a6]|0;c[e+12>>2]=a0;be=a1;bf=a2;bg=a4;bh=a5;bi=a6+1|0;bj=a0;S=7847}}while(0);do{if((S|0)==7841){if((l&2|0)==0){c[e+12>>2]=0;be=a7;bf=a8;bg=ba;bh=bb;bi=bc;bj=0;S=7847;break}else{c[J>>2]=2;gn=1;go=a7;gp=a8;gq=a9;gr=ba;gs=bb;gt=I;gu=bc;gv=j;S=8126;break}}}while(0);if((S|0)==7847){bc=c[e+8>>2]|0;if((((bc<<8|bj)>>>0)%31|0|bj&32|0)==0){gw=(bc&15|0)!=8|0}else{gw=1}if(t){gx=gw}else{bj=1<<(bc>>>4)+8;if(bj>>>0>32768){gy=1}else{gy=r>>>0<bj>>>0|0}gx=gy|gw}if((gx|0)==0){bB=be;bC=bf;bD=0;bE=bg;bF=bh;bG=I;bH=bi;bI=j;S=7855}else{bR=be;bS=bf;bT=gx;bU=bg;bV=bh;bW=bi;S=7854}}if((S|0)==7854){c[J>>2]=36;gn=-1;go=bR;gp=bS;gq=bT;gr=bU;gs=bV;gt=I;gu=bW;gv=j;S=8126}L10998:while(1){do{if((S|0)==8116){S=0;bW=aq<<ar|av;I=ar+8|0;if(ar>>>0>4294967287){gz=I;gA=as;gB=at;gC=au;gD=bW;gE=aw;gF=ax;gG=ay;S=8110}else{gH=I;gI=as;gJ=at;gK=au;gL=bW;gM=aw;gN=ax;gO=ay;S=8117}}else if((S|0)==8119){S=0;if((l&2|0)==0){aH=0;aI=az;aJ=aA;aK=aB;aL=aC;aM=aD;aN=aE;aO=aF;aP=aG;S=8124;continue L10998}c[J>>2]=42;gn=1;go=az;gp=aA;gq=aB;gr=aC;gs=aD;gt=aE;gu=aF;gv=aG;S=8126;continue L10998}else if((S|0)==8085){S=0;c[J>>2]=37;gn=-1;go=K;gp=L;gq=M;gr=N;gs=O;gt=P;gu=Q;gv=R;S=8126;continue L10998}else if((S|0)==7857){S=0;if((l&2|0)==0){b3=bX;b4=bY;b5=bZ;b6=b_;b7=b$;b8=0;b9=b0;ca=b1;cb=b2;S=7862;continue L10998}c[J>>2]=3;gn=1;go=bX;gp=bY;gq=bZ;gr=b_;gs=b$;gt=b0;gu=b1;gv=b2;S=8126;continue L10998}else if((S|0)==8124){S=0;bW=e+16|0;c[bW>>2]=c[bW>>2]<<8|aH;gP=aI;gQ=aJ;gR=aK+1|0;gS=aL;gT=aM;gU=aN;gV=aO;gW=aP;S=8107}else if((S|0)==8111){S=0;if((l&2|0)==0){aq=0;ar=ai;as=aj;at=ak;au=al;av=am;aw=an;ax=ao;ay=ap;S=8116;continue L10998}c[J>>2]=41;gn=1;go=ai;gp=aj;gq=ak;gr=al;gs=am;gt=an;gu=ao;gv=ap;S=8126;continue L10998}else if((S|0)==8088){S=0;if(aX>>>0<s>>>0){a[aX]=a[h+(aV-aR&u)|0]|0;gX=aQ;gY=aR;gZ=aS;g_=aT;g$=aU;g0=aV+1|0;g1=aW;g2=aX+1|0;S=8087;break}else{c[J>>2]=53;gn=2;go=aQ;gp=aR;gq=aS;gr=aT;gs=aU;gt=aV;gu=aW;gv=aX;S=8126;continue L10998}}else if((S|0)==8105){S=0;bW=bs<<bt|bx;I=bt+8|0;if(I>>>0<(I&7)>>>0){g3=I;g4=bu;g5=bv;g6=bw;g7=bW;g8=by;g9=bz;ha=bA;S=8099}else{hb=I;hc=bu;hd=bw;he=bW;hf=by;hg=bz;hh=bA;S=8106}}else if((S|0)==8100){S=0;if((l&2|0)==0){bs=0;bt=bk;bu=bl;bv=bm;bw=bn;bx=bo;by=bp;bz=bq;bA=br;S=8105;continue L10998}c[J>>2]=32;gn=1;go=bk;gp=bl;gq=bm;gr=bn;gs=bo;gt=bp;gu=bq;gv=br;S=8126;continue L10998}else if((S|0)==8082){S=0;bW=$<<aa|ae;I=aa+8|0;if(I>>>0<ad>>>0){hi=I;hj=ab;hk=ac;hl=ad;hm=bW;hn=af;ho=ag;hp=ah;S=8076}else{hq=I;hr=ab;hs=ac;ht=ad;hu=bW;hv=ag;hw=ah;S=8083}}else if((S|0)==8125){S=0;c[J>>2]=34;gn=0;go=bJ;gp=bK;gq=bL;gr=bM;gs=bN;gt=bO;gu=bP;gv=bQ;S=8126;continue L10998}else if((S|0)==8126){S=0;c[w>>2]=go;c[z>>2]=gs;c[B>>2]=gp;c[D>>2]=gq;c[F>>2]=gr;c[H>>2]=gt;c[g>>2]=gu-f;hx=gv-j|0;c[k>>2]=hx;if((l&9|0)!=0&(gn|0)>-1){break L10998}else{v=gn;S=8142;break L10998}}else if((S|0)==7855){S=0;if(bB>>>0<3){hy=bB;hz=bC;hA=bD;hB=bE;hC=bF;hD=bG;hE=bH;hF=bI;S=7856}else{hG=bB;hH=bC;hI=bD;hJ=bE;hK=bF;hL=bG;hM=bH;hN=bI;S=7863}}else if((S|0)==8077){S=0;if((l&2|0)==0){$=0;aa=T;ab=U;ac=V;ad=W;ae=X;af=Y;ag=Z;ah=_;S=8082;continue L10998}c[J>>2]=27;gn=1;go=T;gp=U;gq=V;gr=W;gs=X;gt=Y;gu=Z;gv=_;S=8126;continue L10998}else if((S|0)==7862){S=0;bW=b8<<b3|b7;I=b3+8|0;if(I>>>0<3){hy=I;hz=b4;hA=b5;hB=b6;hC=bW;hD=b9;hE=ca;hF=cb;S=7856}else{hG=I;hH=b4;hI=b5;hJ=b6;hK=bW;hL=b9;hM=ca;hN=cb;S=7863}}else if((S|0)==7866){S=0;if((l&2|0)==0){ck=cc;cl=cd;cm=ce;cn=cf;co=cg;cp=0;cq=ch;cr=ci;cs=cj;S=7871;continue L10998}c[J>>2]=5;gn=1;go=cc;gp=cd;gq=ce;gr=cf;gs=cg;gt=ch;gu=ci;gv=cj;S=8126;continue L10998}else if((S|0)==7871){S=0;bW=cp<<ck|co;I=ck+8|0;if(I>>>0<(I&7)>>>0){hO=I;hP=cl;hQ=cm;hR=cn;hS=bW;hT=cq;hU=cr;hV=cs;S=7865}else{hW=I;hX=cl;hY=cn;hZ=bW;h_=cq;h$=cr;h0=cs;S=7872}}else if((S|0)==7877){S=0;if((l&2|0)==0){cB=ct;cC=cu;cD=cv;cE=cw;cF=cx;cG=0;cH=cy;cI=cz;cJ=cA;S=7882;continue L10998}c[J>>2]=6;gn=1;go=ct;gp=cu;gq=cv;gr=cw;gs=cx;gt=cy;gu=cz;gv=cA;S=8126;continue L10998}else if((S|0)==7882){S=0;bW=cG<<cB|cF;I=cB+8|0;if(cB>>>0>4294967287){h1=I;h2=cC;h3=cD;h4=cE;h5=bW;h6=cH;h7=cI;h8=cJ;S=7876}else{h9=I;ia=cC;ib=cD;ic=cE;id=bW;ie=cH;ig=cI;ih=cJ;S=7883}}else if((S|0)==7885){S=0;if((l&2|0)==0){a[e+10528+cM|0]=0;cS=cK;cT=cL;cU=cM;cV=cN;cW=cO;cX=cP;cY=cQ;cZ=cR;S=7891;continue L10998}else{c[J>>2]=7;gn=1;go=cK;gp=cL;gq=cM;gr=cN;gs=cO;gt=cP;gu=cQ;gv=cR;S=8126;continue L10998}}else if((S|0)==7891){S=0;ii=cS;ij=cT;ik=cU+1|0;il=cV;im=cW;io=cX;ip=cY;iq=cZ;S=7873}else if((S|0)==7893){S=0;c[J>>2]=39;gn=-1;go=c_;gp=c$;gq=c0;gr=c1;gs=c2;gt=c3;gu=c4;gv=c5;S=8126;continue L10998}else if((S|0)==7897){S=0;if((l&2|0)==0){de=c6;df=c7;dg=c8;dh=c9;di=da;dj=0;dk=db;dl=dc;dm=dd;S=7902;continue L10998}c[J>>2]=51;gn=1;go=c6;gp=c7;gq=c8;gr=c9;gs=da;gt=db;gu=dc;gv=dd;S=8126;continue L10998}else if((S|0)==7902){S=0;bW=dj<<de|di;I=de+8|0;if(de>>>0>4294967287){ir=I;is=df;it=dg;iu=dh;iv=bW;iw=dk;ix=dl;iy=dm;S=7896}else{iz=I;iA=dg;iB=dh;iC=bW;iD=dk;iE=dl;iF=dm;S=7903}}else if((S|0)==7904){S=0;if(dv>>>0<s>>>0){a[dv]=dp&255;iG=dn;iH=dp;iI=dq-1|0;iJ=dr;iK=ds;iL=dt;iM=du;iN=dv+1|0;S=7894;break}else{c[J>>2]=52;gn=2;go=dn;gp=dp;gq=dq;gr=dr;gs=ds;gt=dt;gu=du;gv=dv;S=8126;continue L10998}}else if((S|0)==7908){S=0;if(dD>>>0<s>>>0){dE=dw;dF=dx;dG=dy;dH=dz;dI=dA;dJ=dB;dK=dC;dL=dD;S=7910;continue L10998}c[J>>2]=9;gn=2;go=dw;gp=dx;gq=dy;gr=dz;gs=dA;gt=dB;gu=dC;gv=dD;S=8126;continue L10998}else if((S|0)==7910){S=0;if(dK>>>0<q>>>0){bW=s-dL|0;I=q-dK|0;bV=bW>>>0<I>>>0?bW:I;I=bV>>>0<dG>>>0?bV:dG;aIy(dL|0,dK|0,I)|0;iO=dE;iP=dF;iQ=dG-I|0;iR=dH;iS=dI;iT=dJ;iU=dK+I|0;iV=dL+I|0;S=7907;break}if((l&2|0)==0){dM=dE;dN=dF;dO=dG;dP=dH;dQ=dI;dR=dJ;dS=dK;dT=dL;S=7913;continue L10998}c[J>>2]=38;gn=1;go=dE;gp=dF;gq=dG;gr=dH;gs=dI;gt=dJ;gu=dK;gv=dL;S=8126;continue L10998}else if((S|0)==7913){S=0;c[J>>2]=40;gn=-1;go=dM;gp=dN;gq=dO;gr=dP;gs=dQ;gt=dR;gu=dS;gv=dT;S=8126;continue L10998}else if((S|0)==7915){S=0;c[J>>2]=10;gn=-1;go=dU;gp=dV;gq=dW;gr=dX;gs=dY;gt=dZ;gu=d_;gv=d$;S=8126;continue L10998}else if((S|0)==7919){S=0;if((l&2|0)==0){d8=d0;d9=d1;ea=d2;eb=d3;ec=0;ed=d4;ee=d5;ef=d6;eg=d7;S=7924;continue L10998}c[J>>2]=11;gn=1;go=d0;gp=d1;gq=d2;gr=d3;gs=d4;gt=d5;gu=d6;gv=d7;S=8126;continue L10998}else if((S|0)==7924){S=0;I=ec<<d8|ed;bV=d8+8|0;bW=a[728264+ea|0]|0;if(bV>>>0<bW<<24>>24>>>0){iW=bV;iX=d9;iY=ea;iZ=eb;i_=I;i$=ee;i0=ef;i1=eg;S=7918}else{i2=bV;i3=d9;i4=ea;i5=eb;i6=I;i7=ee;i8=ef;i9=eg;ja=bW;S=7925}}else if((S|0)==7930){S=0;if((l&2|0)==0){ep=eh;eq=ei;er=ej;es=0;et=ek;eu=el;ev=em;ew=en;ex=eo;S=7935;continue L10998}c[J>>2]=14;gn=1;go=eh;gp=ei;gq=ej;gr=ek;gs=el;gt=em;gu=en;gv=eo;S=8126;continue L10998}else if((S|0)==7935){S=0;bW=es<<ep|eu;I=ep+8|0;if(I>>>0<3){jb=I;jc=eq;jd=er;je=et;jf=bW;jg=ev;jh=ew;ji=ex;S=7929}else{jj=I;jk=eq;jl=er;jm=et;jn=bW;jo=ev;jp=ew;jq=ex;S=7936}}else if((S|0)==7945){S=0;c[J>>2]=35;gn=-1;go=ey;gp=ez;gq=eA;gr=eB;gs=eC;gt=eD;gu=eE;gv=eF;S=8126;continue L10998}else if((S|0)==7975){S=0;if((l&2|0)==0){eO=0;eP=eG;eQ=eH;eR=eI;eS=eJ;eT=eK;eU=eL;eV=eM;eW=eN;S=7980;continue L10998}c[J>>2]=16;gn=1;go=eG;gp=eH;gq=eI;gr=eJ;gs=eK;gt=eL;gu=eM;gv=eN;S=8126;continue L10998}else if((S|0)==7980){S=0;bW=eO<<eP|eT;I=eP+8|0;if(I>>>0<15){jr=I;js=eQ;jt=eR;ju=eS;jv=bW;jw=eU;jx=eV;jy=eW;S=7968}else{jz=I;jA=eR;jB=eS;jC=bW;jD=eU;jE=eV;jF=eW;S=7982}}else if((S|0)==7988){S=0;c[J>>2]=17;gn=-1;go=eX;gp=eY;gq=eZ;gr=e_;gs=e$;gt=e0;gu=e1;gv=e2;S=8126;continue L10998}else if((S|0)==7991){S=0;if((l&2|0)==0){fb=0;fc=e3;fd=e4;fe=e5;ff=e6;fg=e7;fh=e8;fi=e9;fj=fa;S=7996;continue L10998}c[J>>2]=18;gn=1;go=e3;gp=e4;gq=e5;gr=e6;gs=e7;gt=e8;gu=e9;gv=fa;S=8126;continue L10998}else if((S|0)==7996){S=0;bW=fb<<fc|fg;I=fc+8|0;if(I>>>0<ff>>>0){jG=I;jH=fd;jI=fe;jJ=ff;jK=bW;jL=fh;jM=fi;jN=fj;S=7990}else{jO=I;jP=fd;jQ=fe;jR=ff;jS=bW;jT=fh;jU=fi;jV=fj;S=7997}}else if((S|0)==8001){S=0;c[J>>2]=21;gn=-1;go=fk;gp=fl;gq=fm;gr=fn;gs=fo;gt=fp;gu=fq;gv=fr;S=8126;continue L10998}else if((S|0)==8014){S=0;if((l&2|0)==0){fA=0;fB=fs;fC=ft;fD=fu;fE=fv;fF=fw;fG=fx;fH=fy;fI=fz;S=8019;continue L10998}c[J>>2]=23;gn=1;go=fs;gp=ft;gq=fu;gr=fv;gs=fw;gt=fx;gu=fy;gv=fz;S=8126;continue L10998}else if((S|0)==8019){S=0;bW=fA<<fB|fF;I=fB+8|0;if(I>>>0<15){jW=I;jX=fC;jY=fD;jZ=fE;j_=bW;j$=fG;j0=fH;j1=fI;S=8007}else{j2=I;j3=fC;j4=fE;j5=bW;j6=fG;j7=fH;j8=fI;S=8021}}else if((S|0)==8025){S=0;if(fQ>>>0<s>>>0){a[fQ]=fL&255;j9=fJ;ka=fK;kb=fL;kc=fM;kd=fN;ke=fO;kf=fP;kg=fQ+1|0;S=8028;break}else{c[J>>2]=24;gn=2;go=fJ;gp=fK;gq=fL;gr=fM;gs=fN;gt=fO;gu=fP;gv=fQ;S=8126;continue L10998}}else if((S|0)==8048){S=0;if((l&2|0)==0){fZ=0;f_=fR;f$=fS;f0=fT;f1=fU;f2=fV;f3=fW;f4=fX;f5=fY;S=8053;continue L10998}c[J>>2]=25;gn=1;go=fR;gp=fS;gq=fT;gr=fU;gs=fV;gt=fW;gu=fX;gv=fY;S=8126;continue L10998}else if((S|0)==8053){S=0;bW=fZ<<f_|f2;I=f_+8|0;if(I>>>0<f1>>>0){kh=I;ki=f$;kj=f0;kk=f1;kl=bW;km=f3;kn=f4;ko=f5;S=8047}else{kp=I;kq=f$;kr=f0;ks=f1;kt=bW;ku=f3;kv=f4;kw=f5;S=8054}}else if((S|0)==8064){S=0;if((l&2|0)==0){ge=0;gf=f6;gg=f7;gh=f8;gi=f9;gj=ga;gk=gb;gl=gc;gm=gd;S=8069;continue L10998}c[J>>2]=26;gn=1;go=f6;gp=f7;gq=f8;gr=f9;gs=ga;gt=gb;gu=gc;gv=gd;S=8126;continue L10998}else if((S|0)==8069){S=0;bW=ge<<gf|gj;I=gf+8|0;if(I>>>0<15){kx=I;ky=gg;kz=gh;kA=gi;kB=bW;kC=gk;kD=gl;kE=gm;S=8057}else{kF=I;kG=gh;kH=bW;kI=gk;kJ=gl;kK=gm;S=8071}}}while(0);if((S|0)==7856){S=0;if(hE>>>0>=q>>>0){bX=hy;bY=hz;bZ=hA;b_=hB;b$=hC;b0=hD;b1=hE;b2=hF;S=7857;continue}b3=hy;b4=hz;b5=hA;b6=hB;b7=hC;b8=d[hE]|0;b9=hD;ca=hE+1|0;cb=hF;S=7862;continue}do{if((S|0)==7863){S=0;bW=hK&7;c[e+20>>2]=bW;I=hK>>>3;bV=hG-3|0;bU=bW>>>1;bW=e+24|0;c[bW>>2]=bU;if((bU|0)==0){if(bV>>>0<(bV&7)>>>0){hO=bV;hP=hH;hQ=hI;hR=hJ;hS=I;hT=hL;hU=hM;hV=hN;S=7865;break}else{hW=bV;hX=hH;hY=hJ;hZ=I;h_=hL;h$=hM;h0=hN;S=7872;break}}else if((bU|0)==3){dU=bV;dV=hH;dW=hI;dX=hJ;dY=I;dZ=hL;d_=hM;d$=hN;S=7915;continue L10998}else if((bU|0)==1){c[e+44>>2]=288;c[e+48>>2]=32;aIv(e+3552|0,5,32);aIv(e+64|0,8,144);aIv(e+208|0,9,112);aIv(e+320|0,7,24);bU=e+344|0;bT=bU|0;x=134744072;a[bT]=x&255;x=x>>8;a[bT+1|0]=x&255;x=x>>8;a[bT+2|0]=x&255;x=x>>8;a[bT+3|0]=x&255;bT=bU+4|0;x=134744072;a[bT]=x&255;x=x>>8;a[bT+1|0]=x&255;x=x>>8;a[bT+2|0]=x&255;x=x>>8;a[bT+3|0]=x&255;kL=bV;kM=hH;kN=hI;kO=hJ;kP=I;kQ=hL;kR=hM;kS=hN;kT=bW;kU=1;S=7939;break}else{kV=bV;kW=hH;kX=0;kY=hJ;kZ=I;k_=hL;k$=hM;k0=hN;S=7916;break}}}while(0);if((S|0)==7865){S=0;if(hU>>>0>=q>>>0){cc=hO;cd=hP;ce=hQ;cf=hR;cg=hS;ch=hT;ci=hU;cj=hV;S=7866;continue}ck=hO;cl=hP;cm=hQ;cn=hR;co=hS;cp=d[hU]|0;cq=hT;cr=hU+1|0;cs=hV;S=7871;continue}else if((S|0)==7872){S=0;I=hW&7;ii=hW-I|0;ij=hX;ik=0;il=hY;im=hZ>>>(I>>>0);io=h_;ip=h$;iq=h0;S=7873}do{if((S|0)==7873){S=0;if(ik>>>0>=4){I=d[e+10529|0]<<8|d[e+10528|0];if((I|0)==((d[e+10531|0]<<8|d[e+10530|0])^65535|0)){iG=ii;iH=ij;iI=I;iJ=il;iK=im;iL=io;iM=ip;iN=iq;S=7894;break}else{c_=ii;c$=ij;c0=I;c1=il;c2=im;c3=io;c4=ip;c5=iq;S=7893;continue L10998}}if((ii|0)!=0){if(ii>>>0<8){h1=ii;h2=ij;h3=ik;h4=il;h5=im;h6=io;h7=ip;h8=iq;S=7876;break}else{h9=ii;ia=ij;ib=ik;ic=il;id=im;ie=io;ig=ip;ih=iq;S=7883;break}}if(ip>>>0>=q>>>0){cK=0;cL=ij;cM=ik;cN=il;cO=im;cP=io;cQ=ip;cR=iq;S=7885;continue L10998}a[e+10528+ik|0]=a[ip]|0;cS=0;cT=ij;cU=ik;cV=il;cW=im;cX=io;cY=ip+1|0;cZ=iq;S=7891;continue L10998}}while(0);do{if((S|0)==7876){S=0;if(h7>>>0>=q>>>0){ct=h1;cu=h2;cv=h3;cw=h4;cx=h5;cy=h6;cz=h7;cA=h8;S=7877;continue L10998}cB=h1;cC=h2;cD=h3;cE=h4;cF=h5;cG=d[h7]|0;cH=h6;cI=h7+1|0;cJ=h8;S=7882;continue L10998}else if((S|0)==7883){S=0;a[e+10528+ib|0]=id&255;cS=h9-8|0;cT=ia;cU=ib;cV=ic;cW=id>>>8;cX=ie;cY=ig;cZ=ih;S=7891;continue L10998}else if((S|0)==7894){S=0;if((iI|0)==0|(iG|0)==0){iO=iG;iP=iH;iQ=iI;iR=iJ;iS=iK;iT=iL;iU=iM;iV=iN;S=7907;break}if(iG>>>0<8){ir=iG;is=iH;it=iI;iu=iJ;iv=iK;iw=iL;ix=iM;iy=iN;S=7896}else{iz=iG;iA=iI;iB=iJ;iC=iK;iD=iL;iE=iM;iF=iN;S=7903}}}while(0);if((S|0)==7896){S=0;if(ix>>>0>=q>>>0){c6=ir;c7=is;c8=it;c9=iu;da=iv;db=iw;dc=ix;dd=iy;S=7897;continue}de=ir;df=is;dg=it;dh=iu;di=iv;dj=d[ix]|0;dk=iw;dl=ix+1|0;dm=iy;S=7902;continue}else if((S|0)==7903){S=0;dn=iz-8|0;dp=iC&255;dq=iA;dr=iB;ds=iC>>>8;dt=iD;du=iE;dv=iF;S=7904;continue}else if((S|0)==7907){S=0;if((iQ|0)==0){k1=iO;k2=iP;k3=0;k4=iR;k5=iS;k6=iT;k7=iU;k8=iV;S=8096}else{dw=iO;dx=iP;dy=iQ;dz=iR;dA=iS;dB=iT;dC=iU;dD=iV;S=7908;continue}}L11111:while(1){L11112:do{if((S|0)==8117){S=0;aH=gL&255;aI=gH-8|0;aJ=gI;aK=gJ;aL=gK;aM=gL>>>8;aN=gM;aO=gN;aP=gO;S=8124;continue L10998}else if((S|0)==8087){S=0;I=gZ-1|0;if((gZ|0)==0){j9=gX;ka=gY;kb=I;kc=g_;kd=g$;ke=g0;kf=g1;kg=g2;S=8028;continue L11111}else{aQ=gX;aR=gY;aS=I;aT=g_;aU=g$;aV=g0;aW=g1;aX=g2;S=8088;continue L10998}}else if((S|0)==8083){S=0;k9=hq-ht|0;la=((1<<ht)-1&hu)+hr|0;lb=hs;lc=ht;ld=hu>>>(ht>>>0);le=hv;lf=hw;S=8084}else if((S|0)==8076){S=0;if(ho>>>0<q>>>0){S=8081;break L11111}else{T=hi;U=hj;V=hk;W=hl;X=hm;Y=hn;Z=ho;_=hp;S=8077;continue L10998}}else if((S|0)==8107){S=0;if(gR>>>0>=4){bJ=gP;bK=gQ;bL=gR;bM=gS;bN=gT;bO=gU;bP=gV;bQ=gW;S=8125;continue L10998}if((gP|0)==0){S=8118;break L11111}if(gP>>>0<8){gz=gP;gA=gQ;gB=gR;gC=gS;gD=gT;gE=gU;gF=gV;gG=gW;S=8110;continue L11111}else{gH=gP;gI=gQ;gJ=gR;gK=gS;gL=gT;gM=gU;gN=gV;gO=gW;S=8117;continue L11111}}else if((S|0)==8110){S=0;if(gF>>>0<q>>>0){S=8115;break L11111}else{ai=gz;aj=gA;ak=gB;al=gC;am=gD;an=gE;ao=gF;ap=gG;S=8111;continue L10998}}else if((S|0)==8106){S=0;I=hb&7;gP=hb-I|0;gQ=hc;gR=0;gS=hd;gT=he>>>(I>>>0);gU=hf;gV=hg;gW=hh;S=8107;continue L11111}else if((S|0)==8096){S=0;if((c[e+20>>2]&1|0)==0){bB=k1;bC=k2;bD=k3;bE=k4;bF=k5;bG=k6;bH=k7;bI=k8;S=7855;continue L10998}if((l&1|0)==0){bJ=k1;bK=k2;bL=k3;bM=k4;bN=k5;bO=k6;bP=k7;bQ=k8;S=8125;continue L10998}if(k1>>>0<(k1&7)>>>0){g3=k1;g4=k2;g5=k3;g6=k4;g7=k5;g8=k6;g9=k7;ha=k8;S=8099;continue L11111}else{hb=k1;hc=k2;hd=k4;he=k5;hf=k6;hg=k7;hh=k8;S=8106;continue L11111}}else if((S|0)==8099){S=0;if(g9>>>0<q>>>0){S=8104;break L11111}else{bk=g3;bl=g4;bm=g5;bn=g6;bo=g7;bp=g8;bq=g9;br=ha;S=8100;continue L10998}}else if((S|0)==7916){S=0;if(kX>>>0<3){I=a[728264+kX|0]|0;if(kV>>>0<I<<24>>24>>>0){iW=kV;iX=kW;iY=kX;iZ=kY;i_=kZ;i$=k_;i0=k$;i1=k0;S=7918;continue L11111}else{i2=kV;i3=kW;i4=kX;i5=kY;i6=kZ;i7=k_;i8=k$;i9=k0;ja=I;S=7925;continue L11111}}else{aIv(e+7040|0,0,288);lg=kV;lh=kW;li=0;lj=kY;lk=kZ;ll=k_;lm=k$;ln=k0;S=7927;break}}else if((S|0)==7918){S=0;if(i0>>>0<q>>>0){S=7923;break L11111}else{d0=iW;d1=iX;d2=iY;d3=iZ;d4=i_;d5=i$;d6=i0;d7=i1;S=7919;continue L10998}}else if((S|0)==7925){S=0;I=ja<<24>>24;c[e+44+(i4<<2)>>2]=(c[912+(i4<<2)>>2]|0)+(i6&(1<<I)-1);kV=i2-I|0;kW=i3;kX=i4+1|0;kY=i5;kZ=i6>>>(I>>>0);k_=i7;k$=i8;k0=i9;S=7916;continue L11111}else if((S|0)==7929){S=0;if(jh>>>0<q>>>0){S=7934;break L11111}else{eh=jb;ei=jc;ej=jd;ek=je;el=jf;em=jg;en=jh;eo=ji;S=7930;continue L10998}}else if((S|0)==7936){S=0;a[(d[1056+jl|0]|0)+(e+7040)|0]=jn&7;lg=jj-3|0;lh=jk;li=jl+1|0;lj=jm;lk=jn>>>3;ll=jo;lm=jp;ln=jq;S=7927}else if((S|0)==7939){S=0;if((kU|0)<=-1){j9=kL;ka=kM;kb=kN;kc=kO;kd=kP;ke=kQ;kf=kR;kg=kS;S=8028;continue L11111}aIv(o|0,0,64);aIv(e+64+(kU*3488|0)+288|0,0,3200);I=c[kT>>2]|0;bV=c[e+44+(I<<2)>>2]|0;if((bV|0)==0){lo=0;lp=0;lq=0;lr=0;ls=0;lt=0;lu=0;lv=0;lw=0;lx=0;ly=0;lz=0;lA=0;lB=0;lC=0;lD=0}else{bW=0;do{bT=o+(d[e+64+(kU*3488|0)+bW|0]<<2)|0;c[bT>>2]=(c[bT>>2]|0)+1;bW=bW+1|0;}while(bW>>>0<bV>>>0);lo=c[o+4>>2]|0;lp=c[o+8>>2]|0;lq=c[o+12>>2]|0;lr=c[o+16>>2]|0;ls=c[o+20>>2]|0;lt=c[o+24>>2]|0;lu=c[o+28>>2]|0;lv=c[o+32>>2]|0;lw=c[o+36>>2]|0;lx=c[o+40>>2]|0;ly=c[o+44>>2]|0;lz=c[o+48>>2]|0;lA=c[o+52>>2]|0;lB=c[o+56>>2]|0;lC=c[o+60>>2]|0;lD=bV}c[n+4>>2]=0;c[n>>2]=0;bW=lo<<1;c[n+8>>2]=bW;bT=bW+lp<<1;c[n+12>>2]=bT;bW=bT+lq<<1;c[n+16>>2]=bW;bT=bW+lr<<1;c[n+20>>2]=bT;bW=bT+ls<<1;c[n+24>>2]=bW;bT=bW+lt<<1;c[n+28>>2]=bT;bW=bT+lu<<1;c[n+32>>2]=bW;bT=bW+lv<<1;c[n+36>>2]=bT;bW=bT+lw<<1;c[n+40>>2]=bW;bT=bW+lx<<1;c[n+44>>2]=bT;bW=bT+ly<<1;c[n+48>>2]=bW;bT=bW+lz<<1;c[n+52>>2]=bT;bW=bT+lA<<1;c[n+56>>2]=bW;bT=bW+lB<<1;c[n+60>>2]=bT;bW=bT+lC<<1;c[n+64>>2]=bW;if((bW|0)!=65536&(lB+lC+lA+lz+ly+lx+lw+lv+lu+lt+ls+lr+lq+lp+lo|0)>>>0>1){ey=kL;ez=kM;eA=kN;eB=kO;eC=kP;eD=kQ;eE=kR;eF=kS;S=7945;continue L10998}if((lD|0)==0){lE=I}else{bW=-1;bT=0;while(1){bU=a[e+64+(kU*3488|0)+bT|0]|0;bS=bU&255;L11145:do{if(bU<<24>>24==0){lF=bW}else{bR=n+(bS<<2)|0;bi=c[bR>>2]|0;c[bR>>2]=bi+1;bR=0;bh=bS;bg=bi;while(1){lG=bR<<1|bg&1;bi=bh-1|0;if((bi|0)==0){break}else{bR=lG;bh=bi;bg=bg>>>1}}if((bU&255)<11){bg=(bS<<9|bT)&65535;if(lG>>>0>=1024){lF=bW;break}bh=1<<bS;bi=lG;while(1){b[e+64+(kU*3488|0)+288+(bi<<1)>>1]=bg;gx=bi+bh|0;if(gx>>>0<1024){bi=gx}else{lF=bW;break L11145}}}bi=e+64+(kU*3488|0)+288+((lG&1023)<<1)|0;bh=b[bi>>1]|0;if(bh<<16>>16==0){b[bi>>1]=bW&65535;lH=bW;lI=bW-2|0}else{lH=bh<<16>>16;lI=bW}bh=bR>>>9;bi=lH-(bh&1)|0;if((bU&255)>11){bg=lI;gx=bS;bf=bh&4194303;bh=bi;while(1){be=e+64+(kU*3488|0)+2336+(~bh<<1)|0;gw=b[be>>1]|0;if(gw<<16>>16==0){b[be>>1]=bg&65535;lJ=bg;lK=bg-2|0}else{lJ=gw<<16>>16;lK=bg}gw=gx-1|0;be=bf>>>1;gy=lJ-(be&1)|0;if(gw>>>0>11){bg=lK;gx=gw;bf=be;bh=gy}else{lL=lK;lM=gy;break}}}else{lL=lI;lM=bi}b[e+64+(kU*3488|0)+2336+(~lM<<1)>>1]=bT&65535;lF=lL}}while(0);bS=bT+1|0;bU=c[kT>>2]|0;if(bS>>>0<(c[e+44+(bU<<2)>>2]|0)>>>0){bW=lF;bT=bS}else{lE=bU;break}}}if((lE|0)==2){lN=kL;lO=kM;lP=0;lQ=kO;lR=kP;lS=kQ;lT=kR;lU=kS;S=7965;break}lV=kL;lW=kM;lX=kN;lY=kO;lZ=kP;l_=kQ;l$=kR;l0=kS;l1=lE;l2=e+24|0;S=8003}else if((S|0)==7968){S=0;bT=b[e+7328+((jv&1023)<<1)>>1]|0;bW=bT<<16>>16;if(bT<<16>>16>-1){bT=bW>>9;if((bT|0)==0|jr>>>0<bT>>>0){S=7974;break L11111}else{jz=jr;jA=jt;jB=ju;jC=jv;jD=jw;jE=jx;jF=jy;S=7982;continue L11111}}if(jr>>>0>10){l3=10;l4=bW}else{S=7974;break L11111}while(1){l5=b[e+9376+((jv>>>(l3>>>0)&1)+~l4<<1)>>1]|0;if(l5<<16>>16>=0){jz=jr;jA=jt;jB=ju;jC=jv;jD=jw;jE=jx;jF=jy;S=7982;continue L11111}if(jr>>>0<(l3+2|0)>>>0){break}else{l3=l3+1|0;l4=l5<<16>>16}}if(l5<<16>>16>-1){jz=jr;jA=jt;jB=ju;jC=jv;jD=jw;jE=jx;jF=jy;S=7982;continue L11111}else{S=7974;break L11111}}else if((S|0)==7982){S=0;bW=b[e+7328+((jC&1023)<<1)>>1]|0;bT=bW<<16>>16;if(bW<<16>>16>-1){l6=bT>>9;l7=bT&511}else{bW=10;I=bT;while(1){bT=bW+1|0;bV=b[e+9376+((jC>>>(bW>>>0)&1)+~I<<1)>>1]|0;bU=bV<<16>>16;if(bV<<16>>16<0){bW=bT;I=bU}else{l6=bT;l7=bU;break}}}I=jC>>>(l6>>>0);bW=jz-l6|0;if(l7>>>0<16){a[e+10532+jA|0]=l7&255;lN=bW;lO=l7;lP=jA+1|0;lQ=jB;lR=I;lS=jD;lT=jE;lU=jF;S=7965;break}if((l7|0)==16&(jA|0)==0){eX=bW;eY=16;eZ=0;e_=jB;e$=I;e0=jD;e1=jE;e2=jF;S=7988;continue L10998}bU=a[726240+(l7-16)|0]|0;if(bW>>>0<bU>>>0){jG=bW;jH=l7;jI=jA;jJ=bU;jK=I;jL=jD;jM=jE;jN=jF;S=7990;continue L11111}else{jO=bW;jP=l7;jQ=jA;jR=bU;jS=I;jT=jD;jU=jE;jV=jF;S=7997;continue L11111}}else if((S|0)==7990){S=0;if(jM>>>0<q>>>0){S=7995;break L11111}else{e3=jG;e4=jH;e5=jI;e6=jJ;e7=jK;e8=jL;e9=jM;fa=jN;S=7991;continue L10998}}else if((S|0)==7997){S=0;I=(a[724736+(jP-16)|0]|0)+((1<<jR)-1&jS)|0;if((jP|0)==16){l8=a[jQ-1+(e+10532)|0]|0}else{l8=0}aIv(e+10532+jQ|0,l8|0,I|0);lN=jO-jR|0;lO=jP;lP=I+jQ|0;lQ=jR;lR=jS>>>(jR>>>0);lS=jT;lT=jU;lU=jV;S=7965}else if((S|0)==8007){S=0;I=b[e+352+((j_&1023)<<1)>>1]|0;bU=I<<16>>16;if(I<<16>>16>-1){I=bU>>9;if((I|0)==0|jW>>>0<I>>>0){S=8013;break L11111}else{j2=jW;j3=jX;j4=jZ;j5=j_;j6=j$;j7=j0;j8=j1;S=8021;continue L11111}}if(jW>>>0>10){l9=10;ma=bU}else{S=8013;break L11111}while(1){mb=b[e+2400+((j_>>>(l9>>>0)&1)+~ma<<1)>>1]|0;if(mb<<16>>16>=0){j2=jW;j3=jX;j4=jZ;j5=j_;j6=j$;j7=j0;j8=j1;S=8021;continue L11111}if(jW>>>0<(l9+2|0)>>>0){break}else{l9=l9+1|0;ma=mb<<16>>16}}if(mb<<16>>16>-1){j2=jW;j3=jX;j4=jZ;j5=j_;j6=j$;j7=j0;j8=j1;S=8021;continue L11111}else{S=8013;break L11111}}else if((S|0)==8021){S=0;bU=b[e+352+((j5&1023)<<1)>>1]|0;I=bU<<16>>16;if(bU<<16>>16>-1){mc=I>>9;md=I&511}else{bU=10;bW=I;while(1){I=bU+1|0;bT=b[e+2400+((j5>>>(bU>>>0)&1)+~bW<<1)>>1]|0;bV=bT<<16>>16;if(bT<<16>>16<0){bU=I;bW=bV}else{mc=I;md=bV;break}}}bW=j5>>>(mc>>>0);bU=j2-mc|0;if(md>>>0>255){me=bU;mf=j3;mg=md;mh=j4;mi=bW;mj=j6;mk=j7;ml=j8;S=8044}else{fJ=bU;fK=j3;fL=md;fM=j4;fN=bW;fO=j6;fP=j7;fQ=j8;S=8025;continue L10998}}else if((S|0)==8028){S=0;bW=q;bU=bW-kf|0;L11209:do{if((bU|0)<4){mm=kg;mn=kf;mo=kd;mp=kb;mq=j9;mr=bU}else{bV=s;I=kg;bT=kf;bS=kd;bh=kb;bf=j9;gx=bU;while(1){if((bV-I|0)<2){mm=I;mn=bT;mo=bS;mp=bh;mq=bf;mr=gx;break L11209}if(bf>>>0<15){ms=bf+16|0;mt=(d[bT+1|0]<<8|d[bT])<<bf|bS;mu=bT+2|0}else{ms=bf;mt=bS;mu=bT}bg=b[e+352+((mt&1023)<<1)>>1]|0;bR=bg<<16>>16;if(bg<<16>>16>-1){mv=bR>>9;mw=bR}else{bg=10;gy=bR;while(1){bR=bg+1|0;be=b[e+2400+((mt>>>(bg>>>0)&1)+~gy<<1)>>1]|0;gw=be<<16>>16;if(be<<16>>16<0){bg=bR;gy=gw}else{mv=bR;mw=gw;break}}}gy=mt>>>(mv>>>0);bg=ms-mv|0;if((mw&256|0)!=0){me=bg;mf=ka;mg=mw;mh=kc;mi=gy;mj=ke;mk=mu;ml=I;S=8044;break L11112}if(bg>>>0<15){mx=bg+16|0;my=(d[mu+1|0]<<8|d[mu])<<bg|gy;mz=mu+2|0}else{mx=bg;my=gy;mz=mu}gy=b[e+352+((my&1023)<<1)>>1]|0;bg=gy<<16>>16;if(gy<<16>>16>-1){mA=bg>>9;mB=bg}else{gy=10;bi=bg;while(1){bg=gy+1|0;gw=b[e+2400+((my>>>(gy>>>0)&1)+~bi<<1)>>1]|0;bR=gw<<16>>16;if(gw<<16>>16<0){gy=bg;bi=bR}else{mA=bg;mB=bR;break}}}mC=my>>>(mA>>>0);mD=mx-mA|0;a[I]=mw&255;if((mB&256|0)!=0){break}a[I+1|0]=mB&255;bi=I+2|0;gy=bW-mz|0;if((gy|0)<4){mm=bi;mn=mz;mo=mC;mp=mw;mq=mD;mr=gy;break L11209}else{I=bi;bT=mz;bS=mC;bh=mw;bf=mD;gx=gy}}me=mD;mf=ka;mg=mB;mh=kc;mi=mC;mj=ke;mk=mz;ml=I+1|0;S=8044;break L11112}}while(0);if(mq>>>0>=15){j2=mq;j3=ka;j4=kc;j5=mo;j6=ke;j7=mn;j8=mm;S=8021;continue L11111}if((mr|0)<2){jW=mq;jX=ka;jY=mp;jZ=kc;j_=mo;j$=ke;j0=mn;j1=mm;S=8007;continue L11111}j2=mq+16|0;j3=ka;j4=kc;j5=d[mn]<<mq|mo|d[mn+1|0]<<mq+8;j6=ke;j7=mn+2|0;j8=mm;S=8021;continue L11111}else if((S|0)==8047){S=0;if(kn>>>0<q>>>0){S=8052;break L11111}else{fR=kh;fS=ki;fT=kj;fU=kk;fV=kl;fW=km;fX=kn;fY=ko;S=8048;continue L10998}}else if((S|0)==8054){S=0;mE=kp-ks|0;mF=kq;mG=((1<<ks)-1&kt)+kr|0;mH=ks;mI=kt>>>(ks>>>0);mJ=ku;mK=kv;mL=kw}else if((S|0)==8057){S=0;bW=b[e+3840+((kB&1023)<<1)>>1]|0;bU=bW<<16>>16;if(bW<<16>>16>-1){bW=bU>>9;if((bW|0)==0|kx>>>0<bW>>>0){S=8063;break L11111}else{kF=kx;kG=kz;kH=kB;kI=kC;kJ=kD;kK=kE;S=8071;continue L11111}}if(kx>>>0>10){mM=10;mN=bU}else{S=8063;break L11111}while(1){mO=b[e+5888+((kB>>>(mM>>>0)&1)+~mN<<1)>>1]|0;if(mO<<16>>16>=0){kF=kx;kG=kz;kH=kB;kI=kC;kJ=kD;kK=kE;S=8071;continue L11111}if(kx>>>0<(mM+2|0)>>>0){break}else{mM=mM+1|0;mN=mO<<16>>16}}if(mO<<16>>16>-1){kF=kx;kG=kz;kH=kB;kI=kC;kJ=kD;kK=kE;S=8071;continue L11111}else{S=8063;break L11111}}else if((S|0)==8071){S=0;bU=b[e+3840+((kH&1023)<<1)>>1]|0;bW=bU<<16>>16;if(bU<<16>>16>-1){mP=bW>>9;mQ=bW&511}else{bU=10;gx=bW;while(1){bW=bU+1|0;bf=b[e+5888+((kH>>>(bU>>>0)&1)+~gx<<1)>>1]|0;bh=bf<<16>>16;if(bf<<16>>16<0){bU=bW;gx=bh}else{mP=bW;mQ=bh;break}}}gx=kH>>>(mP>>>0);bU=kF-mP|0;bh=c[1208+(mQ<<2)>>2]|0;bW=c[1336+(mQ<<2)>>2]|0;if((mQ-4|0)>>>0>=26){k9=bU;la=bW;lb=kG;lc=bh;ld=gx;le=kJ;lf=kK;S=8084;break}if(bU>>>0<bh>>>0){hi=bU;hj=bW;hk=kG;hl=bh;hm=gx;hn=kI;ho=kJ;hp=kK;S=8076;continue L11111}else{hq=bU;hr=bW;hs=kG;ht=bh;hu=gx;hv=kJ;hw=kK;S=8083;continue L11111}}}while(0);do{if((S|0)==8084){S=0;gx=lf-h|0;if(!(la>>>0<=gx>>>0|t^1)){K=k9;L=la;M=lb;N=lc;O=ld;P=gx;Q=le;R=lf;S=8085;continue L10998}bh=h+(gx-la&u)|0;if(((lf>>>0>bh>>>0?lf:bh)+lb|0)>>>0>s>>>0){gX=k9;gY=la;gZ=lb;g_=lc;g$=ld;g0=gx;g1=le;g2=lf;S=8087;continue L11111}else{mR=bh;mS=lb;mT=lf}while(1){a[mT]=a[mR]|0;a[mT+1|0]=a[mR+1|0]|0;a[mT+2|0]=a[mR+2|0]|0;mU=mT+3|0;mV=mR+3|0;mW=mS-3|0;if((mW|0)>2){mR=mV;mS=mW;mT=mU}else{break}}if((mW|0)<=0){j9=k9;ka=la;kb=mW;kc=lc;kd=ld;ke=gx;kf=le;kg=mU;S=8028;continue L11111}a[mU]=a[mV]|0;if((mW|0)>1){a[mT+4|0]=a[mR+4|0]|0}j9=k9;ka=la;kb=mW;kc=lc;kd=ld;ke=gx;kf=le;kg=mT+mS|0;S=8028;continue L11111}else if((S|0)==7927){S=0;bh=e+52|0;if(li>>>0<(c[bh>>2]|0)>>>0){if(lg>>>0<3){jb=lg;jc=lh;jd=li;je=lj;jf=lk;jg=ll;jh=lm;ji=ln;S=7929;continue L11111}else{jj=lg;jk=lh;jl=li;jm=lj;jn=lk;jo=ll;jp=lm;jq=ln;S=7936;continue L11111}}else{c[bh>>2]=19;bh=e+24|0;kL=lg;kM=lh;kN=li;kO=lj;kP=lk;kQ=ll;kR=lm;kS=ln;kT=bh;kU=c[bh>>2]|0;S=7939;continue L11111}}else if((S|0)==7965){S=0;bh=c[e+44>>2]|0;bW=c[e+48>>2]|0;bU=bW+bh|0;if(lP>>>0>=bU>>>0){if((bU|0)!=(lP|0)){fk=lN;fl=lO;fm=lP;fn=lQ;fo=lR;fp=lS;fq=lT;fr=lU;S=8001;continue L10998}bU=e+64|0;bf=e+10532|0;aIy(bU|0,bf|0,bh)|0;bf=e+3552|0;bU=e+10532+bh|0;aIy(bf|0,bU|0,bW)|0;bW=e+24|0;lV=lN;lW=lO;lX=lP;lY=lQ;lZ=lR;l_=lS;l$=lT;l0=lU;l1=c[bW>>2]|0;l2=bW;S=8003;break}if(lN>>>0>=15){jz=lN;jA=lP;jB=lQ;jC=lR;jD=lS;jE=lT;jF=lU;S=7982;continue L11111}if((q-lT|0)<2){jr=lN;js=lO;jt=lP;ju=lQ;jv=lR;jw=lS;jx=lT;jy=lU;S=7968;continue L11111}jz=lN+16|0;jA=lP;jB=lQ;jC=d[lT]<<lN|lR|d[lT+1|0]<<lN+8;jD=lS;jE=lT+2|0;jF=lU;S=7982;continue L11111}else if((S|0)==8044){S=0;bW=mg&511;if((bW|0)==256){k1=me;k2=mf;k3=256;k4=mh;k5=mi;k6=mj;k7=mk;k8=ml;S=8096;continue L11111}bU=bW-257|0;bf=c[928+(bU<<2)>>2]|0;bh=c[1080+(bU<<2)>>2]|0;if((bW-265|0)>>>0>=20){mE=me;mF=mf;mG=bh;mH=bf;mI=mi;mJ=mj;mK=mk;mL=ml;break}if(me>>>0<bf>>>0){kh=me;ki=mf;kj=bh;kk=bf;kl=mi;km=mj;kn=mk;ko=ml;S=8047;continue L11111}else{kp=me;kq=mf;kr=bh;ks=bf;kt=mi;ku=mj;kv=mk;kw=ml;S=8054;continue L11111}}}while(0);if((S|0)==8003){S=0;bf=l1-1|0;c[l2>>2]=bf;kL=lV;kM=lW;kN=lX;kO=lY;kP=lZ;kQ=l_;kR=l$;kS=l0;kT=l2;kU=bf;S=7939;continue}if(mE>>>0>=15){kF=mE;kG=mG;kH=mI;kI=mJ;kJ=mK;kK=mL;S=8071;continue}if((q-mK|0)<2){kx=mE;ky=mF;kz=mG;kA=mH;kB=mI;kC=mJ;kD=mK;kE=mL;S=8057;continue}kF=mE+16|0;kG=mG;kH=d[mK]<<mE|mI|d[mK+1|0]<<mE+8;kI=mJ;kJ=mK+2|0;kK=mL;S=8071}if((S|0)==8115){S=0;aq=d[gF]|0;ar=gz;as=gA;at=gB;au=gC;av=gD;aw=gE;ax=gF+1|0;ay=gG;S=8116;continue}else if((S|0)==8118){S=0;if(gV>>>0>=q>>>0){az=0;aA=gQ;aB=gR;aC=gS;aD=gT;aE=gU;aF=gV;aG=gW;S=8119;continue}aH=d[gV]|0;aI=0;aJ=gQ;aK=gR;aL=gS;aM=gT;aN=gU;aO=gV+1|0;aP=gW;S=8124;continue}else if((S|0)==8104){S=0;bs=d[g9]|0;bt=g3;bu=g4;bv=g5;bw=g6;bx=g7;by=g8;bz=g9+1|0;bA=ha;S=8105;continue}else if((S|0)==8081){S=0;$=d[ho]|0;aa=hi;ab=hj;ac=hk;ad=hl;ae=hm;af=hn;ag=ho+1|0;ah=hp;S=8082;continue}else if((S|0)==7923){S=0;d8=iW;d9=iX;ea=iY;eb=iZ;ec=d[i0]|0;ed=i_;ee=i$;ef=i0+1|0;eg=i1;S=7924;continue}else if((S|0)==7934){S=0;ep=jb;eq=jc;er=jd;es=d[jh]|0;et=je;eu=jf;ev=jg;ew=jh+1|0;ex=ji;S=7935;continue}else if((S|0)==7974){S=0;if(jx>>>0>=q>>>0){eG=jr;eH=js;eI=jt;eJ=ju;eK=jv;eL=jw;eM=jx;eN=jy;S=7975;continue}eO=d[jx]|0;eP=jr;eQ=js;eR=jt;eS=ju;eT=jv;eU=jw;eV=jx+1|0;eW=jy;S=7980;continue}else if((S|0)==7995){S=0;fb=d[jM]|0;fc=jG;fd=jH;fe=jI;ff=jJ;fg=jK;fh=jL;fi=jM+1|0;fj=jN;S=7996;continue}else if((S|0)==8013){S=0;if(j0>>>0>=q>>>0){fs=jW;ft=jX;fu=jY;fv=jZ;fw=j_;fx=j$;fy=j0;fz=j1;S=8014;continue}fA=d[j0]|0;fB=jW;fC=jX;fD=jY;fE=jZ;fF=j_;fG=j$;fH=j0+1|0;fI=j1;S=8019;continue}else if((S|0)==8052){S=0;fZ=d[kn]|0;f_=kh;f$=ki;f0=kj;f1=kk;f2=kl;f3=km;f4=kn+1|0;f5=ko;S=8053;continue}else if((S|0)==8063){S=0;if(kD>>>0>=q>>>0){f6=kx;f7=ky;f8=kz;f9=kA;ga=kB;gb=kC;gc=kD;gd=kE;S=8064;continue}ge=d[kD]|0;gf=kx;gg=ky;gh=kz;gi=kA;gj=kB;gk=kC;gl=kD+1|0;gm=kE;S=8069;continue}}if((S|0)==8142){i=m;return v|0}S=e+28|0;kE=c[S>>2]|0;gm=kE&65535;kD=kE>>>16;if((gv|0)==(j|0)){mX=gm;mY=kD}else{gv=j;j=hx;kE=gm;gm=kD;kD=(hx>>>0)%5552|0;while(1){if(kD>>>0>7){hx=gv;gl=0;kC=kE;gk=gm;while(1){kB=(d[hx]|0)+kC|0;gj=kB+(d[hx+1|0]|0)|0;kA=gj+(d[hx+2|0]|0)|0;gi=kA+(d[hx+3|0]|0)|0;kz=gi+(d[hx+4|0]|0)|0;gh=kz+(d[hx+5|0]|0)|0;ky=gh+(d[hx+6|0]|0)|0;gg=ky+(d[hx+7|0]|0)|0;kx=kB+gk+gj+kA+gi+kz+gh+ky+gg|0;ky=gl+8|0;gh=hx+8|0;if((ky|7)>>>0<kD>>>0){hx=gh;gl=ky;kC=gg;gk=kx}else{mZ=gh;m_=ky;m$=gg;m0=kx;break}}}else{mZ=gv;m_=0;m$=kE;m0=gm}if(m_>>>0<kD>>>0){gk=mZ;kC=m_;gl=m$;hx=m0;while(1){m1=(d[gk]|0)+gl|0;m2=m1+hx|0;kx=kC+1|0;if(kx>>>0<kD>>>0){gk=gk+1|0;kC=kx;gl=m1;hx=m2}else{break}}m3=mZ+(kD-m_)|0;m4=m1;m5=m2}else{m3=mZ;m4=m$;m5=m0}hx=(m4>>>0)%65521|0;gl=(m5>>>0)%65521|0;if((j|0)==(kD|0)){mX=hx;mY=gl;break}else{gv=m3;j=j-kD|0;kE=hx;gm=gl;kD=5552}}}kD=mY<<16|mX;c[S>>2]=kD;if((gn|0)!=0){v=gn;i=m;return v|0}if((l&1|0)==0){v=0;i=m;return v|0}else{i=m;return((kD|0)==(c[e+16>>2]|0)?0:-2)|0}return 0}function jK(a){a=a|0;return-1|0}function jL(){var c=0,f=0;c=b[7158924]|0;f=c&65535;a[968008]=0;b[7158924]=(c+1&65535)+(d[962727]|0)&65535;return e[822600+(f>>>8&2|f&15360|f<<1&1020)>>1]|0|0}function jM(c){c=c|0;var d=0,e=0,f=0;d=b[7158924]|0;e=d&65535;a[968008]=0;if((a[962713]|0)<0){f=e&16383}else{f=e>>>6&64|e&8255|e<<1&8064}a[822600+f|0]=c&255;b[7158924]=d+1&65535;return}function jN(){var c=0,f=0;c=e[993832]|0;a[968008]=0;f=b[7158924]|0;b[993832]=d[822600+(f&16383)|0]|0;b[7158924]=(f+1&65535)+(d[962727]|0)&65535;return c|0}function jO(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=a[736792]|0;if((d|0)==0){if((f<<24>>24|0)==3){c[291167]=100;c[291168]=92;c[291169]=278;c[291170]=84}else if((f<<24>>24|0)==1){oy(e)}d=c[494748]|0;if(d>>>0<e>>>0){g=c[494746]|0;h=((e-1-d+g|0)>>>0)/(g>>>0)|0;fj[c[3579684]&511](c[494738]|0,h);c[494738]=(c[494738]|0)+(h<<1<<2);g=ab(c[494746]|0,h)|0;c[494748]=(c[494748]|0)+g}fG[c[3579686]&16383]();i=a[736792]&2;a[736792]=i;return}if((f<<24>>24|0)==2){c[291167]=2;c[291168]=206;c[291169]=22;c[291170]=26;b[7159324]=0;a[14318710]=0;aIv(14318700,0,7);b[7159340]=c[3579662]&65535;g=c[494748]|0;if(g>>>0<e>>>0){h=c[494746]|0;d=((e-1-g+h|0)>>>0)/(h>>>0)|0;fj[c[3579684]&511](c[494738]|0,d);c[494738]=(c[494738]|0)+(d<<1<<2);h=ab(c[494746]|0,d)|0;c[494748]=(c[494748]|0)+h}fG[c[3579686]&16383]()}else if((f<<24>>24|0)==0){c[3579678]=e;b[7159324]=0;a[14318710]=0;aIv(14318700,0,7);b[7159340]=c[3579662]&65535;f=c[494748]|0;if(f>>>0<e>>>0){h=c[494746]|0;d=((e-1-f+h|0)>>>0)/(h>>>0)|0;fj[c[3579684]&511](c[494738]|0,d);c[494738]=(c[494738]|0)+(d<<1<<2);h=ab(c[494746]|0,d)|0;c[494748]=(c[494748]|0)+h}fG[c[3579686]&16383]()}i=a[736792]|1;a[736792]=i;return}function jP(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a[968008]=0;g=b[468728]|0;L11352:do{if((g&8)==0){if((a[962713]&64)==0){break}h=c[496910]|0;do{if((h|0)>0){i=c[496914]|0;j=c[496912]|0;k=(((c[291649]|0)-i|0)>>>0)/(j>>>0)|0;if((k|0)>0){l=h-k|0;c[496910]=l;m=g&-257;b[468728]=m;if((l|0)<1){n=m|512;b[468728]=n;c[496910]=0;o=0;p=n}else{o=l;p=m}m=(ab(k,j)|0)+i|0;c[496914]=m;q=o;r=p;s=m}else{q=h;r=g;s=i}i=r&-513;b[468728]=i;if((q|0)<4){t=q;u=i;break}i=s+j|0;c[496914]=i;c[291649]=i;break L11352}else{i=g&-513;b[468728]=i;t=h;u=i}}while(0);h=t+1|0;c[496910]=h;b[468728]=(h<<6&256|u&65535)&65535}}while(0);u=b[7158924]|0;t=u&65535;do{if((a[12474208]&2)==0){g=t>>>8&2|t&15360|t<<1&1020;s=822600+g|0;if((t&1|0)==0){v=f}else{v=(f>>>8|f<<8)&65535}if((v|0)==(e[s>>1]|0|0)){break}b[s>>1]=v&65535;s=g>>>5;g=14315776+s|0;q=a[g]|0;if(q<<24>>24==0){r=b[7158912]|0;b[7158912]=r+1&65535;b[14311680+((r&65535)<<1)>>1]=s&65535}a[g]=(q&255|1<<(t>>>1&7))&255}else{q=t&31;g=12474e3+(q<<1)|0;s=f>>>3&448|f&63;if((s|0)==(e[g>>1]|0|0)){break}b[g>>1]=s&65535;j7(q,s);if((q|0)!=(a[12736648]&15|16|0)){break}j7(64,s)}}while(0);b[7158924]=((d[962727]|0)+1&65535)+u&65535;return}function jQ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a[968008]=0;do{if((d[12474208]|0)<3){g=e[780032]|0;h=((g-1+(((c[3579678]|0)>>>0)/3420|0)|0)>>>0)%(g>>>0)|0;do{if(h>>>0>(e[444104]|0)>>>0&(h|0)<(c[3446841]|0)){if((a[12473444]&a[765107])<<24>>24!=0){break}b[444104]=h&65535;kv(h)}}while(0);h=b[7158924]|0;g=h&65535;i=g&16383;j=822600+i|0;k=f&65535;if((d[j]|0|0)==(f|0)){l=k;m=h;break}a[j]=f&255;j=i>>>5;i=14315776+j|0;n=a[i]|0;if(n<<24>>24==0){o=b[7158912]|0;b[7158912]=o+1&65535;b[14311680+((o&65535)<<1)>>1]=j&65535}a[i]=(n&255|1<<(g>>>2&7))&255;l=k;m=h}else{h=b[7158924]|0;k=h&65535;if((k&1|0)==0){c[3118616]=f;l=f&65535;m=h;break}g=12474e3+(k&62)|0;n=c[3118616]|f<<8;i=n&65535;if((n|0)==(e[g>>1]|0|0)){l=i;m=h;break}j=k>>>1&31;b[g>>1]=i;j7(j,n);if((j|0)!=(a[12736648]&15|16|0)){l=i;m=h;break}j7(64,n);l=i;m=h}}while(0);b[993832]=l;b[7158924]=m+1&65535;return}function jR(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[968008]=0;do{if((d[12474208]|0)<3){g=e[780032]|0;h=((g-1+(((c[3579678]|0)>>>0)/3420|0)|0)>>>0)%(g>>>0)|0;do{if(h>>>0>(e[444104]|0)>>>0&(h|0)<(c[3446841]|0)){if((a[12473444]&a[765107])<<24>>24!=0){break}b[444104]=h&65535;kv(h)}}while(0);h=b[7158924]|0;g=h&65535;i=g&16383;j=822600+i|0;if((d[j]|0|0)==(f|0)){k=h;break}a[j]=f&255;j=i>>>5;i=14315776+j|0;l=a[i]|0;if(l<<24>>24==0){m=b[7158912]|0;b[7158912]=m+1&65535;b[14311680+((m&65535)<<1)>>1]=j&65535}a[i]=(l&255|1<<(g>>>2&7))&255;k=h}else{h=b[7158924]|0;g=h&31;l=12474e3+(g<<1)|0;if((e[l>>1]|0|0)==(f|0)){k=h;break}b[l>>1]=f&65535;j7(g,f);if((g|0)!=(a[12736648]&15|16|0)){k=h;break}j7(64,f);k=h}}while(0);b[993832]=f&65535;b[7158924]=k+1&65535;return}function jS(c){c=c|0;var f=0,g=0,h=0,i=0,j=0,k=0;a[968008]=0;f=b[7158924]|0;g=f&65535;do{if((a[12474208]&2)==0){h=g&16383;i=822600+h|0;if((d[i]|0|0)==(c|0)){break}a[i]=c&255;i=h>>>5;h=14315776+i|0;j=a[h]|0;if(j<<24>>24==0){k=b[7158912]|0;b[7158912]=k+1&65535;b[14311680+((k&65535)<<1)>>1]=i&65535}a[h]=(j&255|1<<(g>>>2&7))&255}else{j=g&31;h=12474e3+(j<<1)|0;if((e[h>>1]|0|0)==(c|0)){break}b[h>>1]=c&65535;j7(j,c);if((j|0)!=(a[12736648]&15|16|0)){break}j7(64,c)}}while(0);b[7158924]=((d[962727]|0)+1&65535)+f&65535;return}function jT(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;i=a[962713]|0;j=(i&4)==0;if(j&f>>>0>10){return}switch(f|0){case 13:{a[962725]=g&255;b[846168]=g<<10&65535;return};case 16:{a[962728]=g&255;k=g&3;a[964272]=a[2520+k|0]|0;a[964288]=a[684384+k|0]|0;b[482140]=b[2544+((g>>>4&3)<<1)>>1]|0;return};case 17:{a[962729]=g&255;k=g&31;l=g>>>7&1;m=l^1;n=d[962724]<<2&4|16;if((k|0)==0){a[12474216+(l*3|0)|0]=0;a[12474217+(l*3|0)|0]=n&255;a[12474218+(l*3|0)|0]=1;a[12474218+(m*3|0)|0]=0;return}a[12474216+(m*3|0)|0]=0;o=n&255;if(k>>>0>n>>>0){a[12474217+(m*3|0)|0]=o;a[12474218+(m*3|0)|0]=1;a[12474218+(l*3|0)|0]=0;return}else{a[12474217+(l*3|0)|0]=o;o=k&255;a[12474217+(m*3|0)|0]=o;a[12474216+(l*3|0)|0]=o;a[12474221]=1;a[12474218]=1;return}break};case 12:{o=d[962724]^g;l=g&255;a[962724]=l;do{if((o&8|0)!=0){m=e[12474e3+(d[12736648]<<1)>>1]|0;k=(a[962712]&4)==0;n=k?m&73:m;m=(l&8)==0;if(m){p=b[965448+(n<<1)>>1]|0;b[483748]=p;b[483812]=p;q=p}else{b[483748]=b[966472+(n<<1)>>1]|0;b[483812]=b[965448+(n<<1)>>1]|0;q=b[964424+(n<<1)>>1]|0}b[483876]=q;n=1;do{p=e[12474e3+(n<<1)>>1]|0;r=k?p&73:p;if(m){p=b[965448+(r<<1)>>1]|0;b[967496+(n<<1)>>1]=p;b[967496+((n|64)<<1)>>1]=p;b[967496+((n|128)<<1)>>1]=p}else{b[967496+(n<<1)>>1]=b[966472+(r<<1)>>1]|0;b[967496+((n|64)<<1)>>1]=b[965448+(r<<1)>>1]|0;b[967496+((n|128)<<1)>>1]=b[964424+(r<<1)>>1]|0}n=n+1|0;}while((n|0)<64);n=(a[1692312]|0)!=0;if((g&8|0)==0){c[240674]=n?32:90;break}else{c[240674]=n?30:86;break}}}while(0);if((o&6|0)!=0){c[3446844]=c[3446844]|2}if((o&1|0)==0){return}o=g&1;q=d[962715]<<10;do{if((o|0)==0){b[484128]=q&-2048;b[478036]=d[962717]<<9;b[478040]=-512;b[478044]=511;c[423088]=680856;l=d[962729]|0;n=l&31;m=l>>>7;l=m^1;if((n|0)==0){a[12474216+(m*3|0)|0]=0;a[12474217+(m*3|0)|0]=16;a[12474218+(m*3|0)|0]=1;a[12474218+(l*3|0)|0]=0;s=214;break}a[12474216+(l*3|0)|0]=0;if(n>>>0>16){a[12474217+(l*3|0)|0]=16;a[12474218+(l*3|0)|0]=1;a[12474218+(m*3|0)|0]=0;s=214;break}else{a[12474217+(m*3|0)|0]=16;k=n&255;a[12474217+(l*3|0)|0]=k;a[12474216+(m*3|0)|0]=k;a[12474221]=1;a[12474218]=1;s=214;break}}else{b[484128]=q&-4096;b[478036]=d[962717]<<9&-1024;b[478040]=-1024;b[478044]=1023;c[423088]=677432;k=d[962729]|0;m=k&31;l=k>>>7;k=l^1;if((m|0)==0){a[12474216+(l*3|0)|0]=0;a[12474217+(l*3|0)|0]=20;a[12474218+(l*3|0)|0]=1;a[12474218+(k*3|0)|0]=0;s=190;break}a[12474216+(k*3|0)|0]=0;if(m>>>0>20){a[12474217+(k*3|0)|0]=20;a[12474218+(k*3|0)|0]=1;a[12474218+(l*3|0)|0]=0;s=190;break}else{a[12474217+(l*3|0)|0]=20;n=m&255;a[12474217+(k*3|0)|0]=n;a[12474216+(l*3|0)|0]=n;a[12474221]=1;a[12474218]=1;s=190;break}}}while(0);c[496912]=s<<((a[12474208]&15)>>>0<3);s=e[444104]|0;do{if((s|0)<(c[3446841]|0)){if(((c[290364]|0)+860|0)>>>0<h>>>0){break}c[3446840]=o<<6|256;kv(s);return}}while(0);if((s|0)==((e[780032]|0)-1|0)){c[3446840]=o<<6|256;return}else{c[3446844]=c[3446844]|2;return}break};case 11:{a[962723]=g&255;a[1692328]=a[671832+(g&3)|0]|0;o=(a[1692312]|0)!=0;if((g&4|0)==0){c[240676]=o?146:106;return}else{c[240676]=o?252:198;return}break};case 0:{o=d[962712]^g;a[962712]=g&255;do{if(!((o&16|0)==0|(a[1692344]|0)==0)){if((a[888136]&i)<<24>>24!=0){fi[c[239016]&255](6);break}if((g&16|0)==0){fi[c[239016]&255](0);break}else{fi[c[239014]&255](4);break}}}while(0);s=(a[937424]|0)<0;do{if((o&4|0)!=0&s){if((a[962713]&4)==0){q=0;do{j7(q,e[12474e3+(q<<1)>>1]|0);q=q+1|0;}while((q|0)<32);j7(64,e[12474e3+(d[12736648]<<1&30|32)>>1]|0);break}q=e[12474e3+(d[12736648]<<1)>>1]|0;n=(a[962712]&4)==0;l=n?q&73:q;q=(a[962724]&8)==0;if(q){k=b[965448+(l<<1)>>1]|0;b[483748]=k;b[483812]=k;t=k}else{b[483748]=b[966472+(l<<1)>>1]|0;b[483812]=b[965448+(l<<1)>>1]|0;t=b[964424+(l<<1)>>1]|0}b[483876]=t;l=1;do{k=e[12474e3+(l<<1)>>1]|0;m=n?k&73:k;if(q){k=b[965448+(m<<1)>>1]|0;b[967496+(l<<1)>>1]=k;b[967496+((l|64)<<1)>>1]=k;b[967496+((l|128)<<1)>>1]=k}else{b[967496+(l<<1)>>1]=b[966472+(m<<1)>>1]|0;b[967496+((l|64)<<1)>>1]=b[965448+(m<<1)>>1]|0;b[967496+((l|128)<<1)>>1]=b[964424+(m<<1)>>1]|0}l=l+1|0;}while((l|0)<64)}}while(0);if(!((o&2|0)!=0&s)){return}if((a[962713]&4)==0){return}if((g&2|0)==0){c[423080]=0;return}s=c[423080]|0;if((s|0)==0){o=((h>>>0)/3420|0)-1|0;if((o|0)>(e[444100]|0)){u=o-(e[780032]|0)|0}else{u=o}if((a[1692200]|0)==0){v=u}else{o=u<<d[1692312];v=o>>>8&1|o&-2}w=v<<8&65280|d[(c[423088]|0)+((h>>>0)%3420|0)|0]}else{w=s&65535}c[423080]=w|65536;return};case 2:{a[962714]=g&255;b[484136]=g<<10&65535&-8192;w=e[444104]|0;if((w|0)>=(c[3446841]|0)){return}if((i&64)==0){return}if(((c[290364]|0)+860|0)>>>0<h>>>0){return}kv(w);return};case 3:{a[962715]=g&255;b[484128]=((a[962724]&1)==0?-2048:-4096)&(g<<10&65535);w=e[444104]|0;if((w|0)>=(c[3446841]|0)){return}if((i&64)==0){return}if(((c[290364]|0)+860|0)>>>0<h>>>0){return}kv(w);return};case 4:{a[962716]=g&255;b[484132]=g<<13&65535;w=e[444104]|0;if((w|0)>=(c[3446841]|0)){return}if((i&64)==0){return}if(((c[290364]|0)+860|0)>>>0<h>>>0){return}kv(w);return};case 5:{a[962717]=g&255;b[478036]=e[478040]&g<<9&65535;return};case 7:{a[962719]=g&255;w=g&63;if((w|0)==(d[12736648]|0)){return}a[12736648]=w&255;do{if(j){j7(64,e[12474e3+(g<<1&30|32)>>1]|0)}else{s=e[12474e3+(w<<1)>>1]|0;v=(a[962712]&4)==0?s&73:s;if((a[962724]&8)==0){s=b[965448+(v<<1)>>1]|0;b[483748]=s;b[483812]=s;b[483876]=s;break}else{b[483748]=b[966472+(v<<1)>>1]|0;b[483812]=b[965448+(v<<1)>>1]|0;b[483876]=b[964424+(v<<1)>>1]|0;break}}}while(0);w=e[444104]|0;if((w|0)>=(c[3446841]|0)){return}if(((c[290364]|0)+860|0)>>>0<h>>>0){return}kw(w);return};case 8:{w=e[780032]|0;j=((((((a[937424]|0)>-1?h+15|0:h)>>>0)/3420|0)-1+w|0)>>>0)%(w>>>0)|0;do{if(j>>>0>(e[444104]|0)>>>0&(j|0)<(c[3446841]|0)){if((a[12473444]&a[765107])<<24>>24!=0){break}b[444104]=j&65535;kv(j)}}while(0);a[962720]=g&255;return};case 1:{j=i&255^g;a[962713]=g&255;do{if((j&64|0)!=0){i=e[444104]|0;if((i|0)>=(c[3446841]|0)){break}w=h-(c[290364]|0)-860|0;if((w|0)<1){if((g&64|0)!=0&(d[968248]|0)>5&(w|0)>-501){a[968248]=5}kv(i);break}if((a[937424]|0)>=0){break}if((a[962724]&1)==0){x=((w|0)/10|0)+16|0}else{x=(w|0)/8|0}w=c[3446840]|0;if((x|0)>=(w|0)){break}if((g&64|0)==0){aIv(x+1560104|0,64,w-x|0);kw(i);break}else{kv(i);i=e[444104]|0;aIv(1560104,64,x|0);kw(i);break}}}while(0);do{if(!((j&32|0)==0|(a[888136]|0)==0)){if((g&32|0)!=0){fi[c[239014]&255](6);break}x=c[239016]|0;if((a[962712]&a[1692344])<<24>>24==0){fi[x&255](0);break}else{fi[x&255](4);break}}}while(0);x=(a[937424]|0)<0;do{if((j&8|0)!=0&x){if((g&4|0)==0){break}if((b[468728]&8)==0){i=g&8;c[3446841]=i<<1|224;w=a[888176]|0;c[3446839]=8-i+((w&255)*24|0)&-(a[12474175]&1);y=w}else{c[3446844]=c[3446844]|2;y=a[888176]|0}b[444100]=b[296+((g>>>2&3)<<2)+((y&255)<<1)>>1]|0}}while(0);if((j&4|0)==0){return}if(!x){a[962713]=a[962713]&-5;return}do{if((g&4|0)==0){c[242004]=134;c[222054]=96;c[240676]=206;c[240674]=98;x=0;do{j7(x,e[12474e3+(x<<1)>>1]|0);x=x+1|0;}while((x|0)<32);j7(64,e[12474e3+(d[12736648]<<1&30|32)>>1]|0);c[222046]=26;c[222040]=104;c[222048]=4;c[222042]=6;if((b[468728]&8)==0){c[3446841]=192;c[3446839]=ab(-(a[12474175]&1)&24,(d[888176]|0)+1|0)|0}else{c[3446844]=c[3446844]|2}x=c[423080]|0;do{if((x|0)==0){z=d[(c[423088]|0)+((h>>>0)%3420|0)|0]|0;A=8315}else{if((a[962713]&4)==0){z=x&255;A=8315;break}else{B=x&65535;break}}}while(0);if((A|0)==8315){x=((h>>>0)/3420|0)-1|0;if((x|0)>(e[444100]|0)){C=x-(e[780032]|0)|0}else{C=x}if((a[1692200]|0)==0){D=C}else{x=C<<d[1692312];D=x>>>8&1|x&-2}B=D<<8&65280|z}c[423080]=B|65536;E=512}else{c[242004]=110;c[222054]=138;x=a[1692312]|0;j=(a[962723]&4)!=0;if(x<<24>>24==0){c[240676]=j?198:106;y=a[962724]|0;F=(y&8)!=0?86:90;G=y}else{c[240676]=j?252:146;j=a[962724]|0;F=(j&8)!=0?30:32;G=j}c[240674]=F;j=e[12474e3+(d[12736648]<<1)>>1]|0;y=a[962712]|0;w=(y&4)==0;i=w?j&73:j;j=(G&8)==0;if(j){v=b[965448+(i<<1)>>1]|0;b[483748]=v;b[483812]=v;H=v}else{b[483748]=b[966472+(i<<1)>>1]|0;b[483812]=b[965448+(i<<1)>>1]|0;H=b[964424+(i<<1)>>1]|0}b[483876]=H;i=1;do{v=e[12474e3+(i<<1)>>1]|0;s=w?v&73:v;if(j){v=b[965448+(s<<1)>>1]|0;b[967496+(i<<1)>>1]=v;b[967496+((i|64)<<1)>>1]=v;b[967496+((i|128)<<1)>>1]=v}else{b[967496+(i<<1)>>1]=b[966472+(s<<1)>>1]|0;b[967496+((i|64)<<1)>>1]=b[965448+(s<<1)>>1]|0;b[967496+((i|128)<<1)>>1]=b[964424+(s<<1)>>1]|0}i=i+1|0;}while((i|0)<64);c[222046]=126;c[222040]=12;c[222048]=74;c[222042]=8;if((b[468728]&8)==0){i=g&8;c[3446841]=i<<1|224;c[3446839]=8-i+((d[888176]|0)*24|0)&-(a[12474175]&1)}else{c[3446844]=c[3446844]|2}c[423080]=0;if((y&2)==0){E=2048;break}i=((h>>>0)/3420|0)-1|0;if((i|0)>(e[444100]|0)){I=i-(e[780032]|0)|0}else{I=i}if((a[1692200]|0)==0){J=I}else{i=I<<(x&255);J=i>>>8&1|i&-2}c[423080]=d[(c[423088]|0)+((h>>>0)%3420|0)|0]|J<<8&65280|65536;E=2048}}while(0);b[7158912]=E;J=E&65535;aIv(14315776,-1|0,J|0);E=0;do{b[14311680+(E<<1)>>1]=E&65535;E=E+1|0;}while((E|0)<(J|0));b[444100]=b[296+((g>>>2&3)<<2)+(d[888176]<<1)>>1]|0;return};default:{a[962712+f|0]=g&255;return}}}function jU(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[968008]|0)==0){b[7158924]=(b[7158924]&16128|f&255)&65535;b[7158920]=f&65535;a[968008]=1;return}g=f>>>6&3;a[12474208]=g;h=e[7158920]|0;i=h|f<<8;j=i&65535;b[7158924]=j&16383;a[968008]=0;if((g<<24>>24|0)==2){k=a[962712]|0;l=a[962713]&24|k&6;jT(f&15,h,c[3579678]|0);h=a[962712]|0;f=h&255;m=a[962713]&24|f&6;n=h^k;if((l|0)==(m|0)){return}l=a[937424]|0;do{if((l&255)>32){if((m|0)==22){k=a[888176]|0;b[444100]=b[300+((k&255)<<1)>>1]|0;o=224;p=k}else if((m|0)==14){k=a[888176]|0;b[444100]=b[308+((k&255)<<1)>>1]|0;o=240;p=k}else{k=a[888176]|0;b[444100]=b[296+((k&255)<<1)>>1]|0;o=192;p=k}if((o|0)==(c[3446841]|0)){break}if((b[468728]&8)!=0){c[3446844]=c[3446844]|2;break}c[3446841]=o;if((a[12474175]&1)!=0){c[3446839]=240-o+((p&255)*48|0)>>1;break}if(l<<24>>24!=64|(a[12474177]|0)!=0){c[3446839]=0;break}else{c[3446839]=(144-o|0)/2|0;break}}}while(0);switch(m|0){case 24:{c[240676]=324;break};case 18:{c[240676]=90;break};case 16:{c[240676]=88;break};case 0:{c[240676]=212;break};case 2:{c[240676]=218;break};case 8:{c[240676]=168;break};case 26:{c[240676]=324;break};case 10:{c[240676]=60;break};default:{c[240676]=206}}if((n&4)==0){return}n=(f&4|0)==0;c[242004]=n?186:134;c[240674]=n?136:98;b[7158912]=n?0:512;n=0;do{j7(n,e[12474e3+(n<<1)>>1]|0);n=n+1|0;}while((n|0)<32);j7(64,e[12474e3+(d[12736648]<<1&30|32)>>1]|0);return}else if((g<<24>>24|0)==0){b[993832]=d[822600+(i&16383)|0]|0;b[7158924]=j+1&16383;return}else{return}}function jV(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;if((a[968008]|0)==0){b[7158920]=f&65535;a[968008]=1;return}g=f>>>6&255;h=g&3;a[12474208]=h;i=e[7158920]|0;j=i|f<<8;k=j&65535;b[7158924]=k&16383;a[968008]=0;if(h<<24>>24==0){b[993832]=d[822600+(j&16383)|0]|0;b[7158924]=k+1&16383;return}if((g&2)==0){return}g=f&7;jT(g,i,c[3579678]|0);if(g>>>0>=2){return}switch(a[962713]&24|a[962712]&2|0){case 10:{c[240676]=60;return};case 24:{c[240676]=324;return};case 0:{c[240676]=212;return};case 2:{c[240676]=218;return};case 18:{c[240676]=90;return};case 16:{c[240676]=88;return};case 8:{c[240676]=168;return};case 26:{c[240676]=324;return};default:{return}}}function jW(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b[468728]|0;h=(g&8)==0;if(h){i=((d[962713]|0)>>>6&1^1)&255}else{i=1}j=a[12473968]|0;k=(d[(a[962724]&1)+(676104+(i<<1))|0]|0)>>>((j&1)>>>0);if(h){l=(c[290364]|0)+3420|0}else{l=(e[780032]|0)*3420|0}h=l-f|0;l=((ab(h,k)|0)>>>0)/3420|0;i=c[3118496]|0;if(i>>>0<l>>>0){m=((i*3420|0)>>>0)/(k>>>0)|0;n=i}else{m=h;n=l}if((j&255)<2){c[291649]=m+f}else{b[468728]=g|2;c[3118498]=m+f}if((n|0)<=0){return}c[3118496]=i-n;fi[c[676112+((a[962735]&255)>>>4<<2)>>2]&255](n);if((c[3118496]|0)!=0){return}n=(((d[962734]|0)<<8|(d[962733]|0))+(d[962731]|0)&65535)+((d[962732]|0)<<8)&65535;a[962733]=n&255;a[962734]=(n&65535)>>>8&255;a[962732]=0;a[962731]=0;n=c[3118616]|0;if((n|0)<=-1){return}jX(n);c[3118616]=-1;return}function jX(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;do{if((a[968008]|0)==0){if((c[3118496]|0)!=0&(d[12473968]|0)<2){c[3118616]=f;return}if((f&49152|0)==32768){jT(f>>>8&31,f&255,c[291649]|0)}else{a[968008]=a[962713]&4}b[7158924]=(e[7158920]|f&16383)&65535;a[12474208]=(a[12474208]&60|f>>>14&3)&255}else{a[968008]=0;g=f<<14;b[7158920]=g&65535;h=(b[7158924]&16383|g)&65535;b[7158924]=h;g=f>>>2;i=(a[12474208]&3|g&60)&255;a[12474208]=i;if((g&32|0)==0){break}if((a[962713]&16)==0){break}g=a[962735]|0;j=g&255;k=j>>>6;if((k|0)==2){b[6236980]=256;break}else if((k|0)==3){k=d[962732]<<8|d[962731];c[3118496]=(k|0)==0?65536:k;b[6236988]=d[962734]<<8|d[962733];a[12473968]=3;jW(c[291649]|0);break}else{k=d[962732]<<8|d[962731];l=(k|0)==0?65536:k;c[3118496]=l;b[6236988]=d[962734]<<8|d[962733];if((a[937424]|0)==-124){if((j&112|0)==(((d[10441816]|0)>>>1)+16|0)){m=8536}else{m=8534}}else{m=8534}do{if((m|0)==8534){if((c[234362]|0)==0){break}if((g&96)==0){m=8536}}}while(0);if((m|0)==8536){b[7158924]=(d[962727]|0)+h&65535;c[3118496]=l-1}a[12473968]=(i&6)==0|0;jW(c[291649]|0);break}}}while(0);c[496912]=((a[962724]&1)!=0?190:214)<<((a[12474208]&15)>>>0<3);return}function jY(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=e[780032]|0;g=((((d>>>0)/3420|0)-1+f|0)>>>0)%(f>>>0)|0;f=a[937424]|0;do{if(f<<24>>24<0){h=b[468728]|0;if((h&2)==0|(c[3118496]|0)!=0|(c[3118498]|0)>>>0>d>>>0){break}b[468728]=h&253}}while(0);do{if(g>>>0>(e[444104]|0)>>>0){b[444104]=g&65535;h=c[3446841]|0;if((g|0)==(h+1|0)){b[468728]=b[468728]|128;i=f;break}if((g|0)>=(h|0)){i=f;break}if((a[12473444]&a[765107])<<24>>24!=0){i=f;break}kv(g);i=a[937424]|0}else{i=f}}while(0);f=b[468728]|0;h=f&65535;a[968008]=0;j=f&-225;b[468728]=j;f=i<<24>>24<0;do{if(f){i=(a[962713]&64)==0?h|8:h;if(((d>>>0)%3420|0)>>>0>=588){k=i;break}k=i|4}else{k=(a[962712]&4)==0?h:h|31}}while(0);do{if((k&32|0)==0){l=k}else{h=e[468756]|0;if((g|0)!=(h>>>8|0)){l=k;break}if(f){if(((d>>>0)%3420|0)>>>0>=105){l=k;break}b[468728]=j|32;l=k&-33;break}else{i=a[(c[423088]|0)+(((d+535|0)>>>0)%3420|0)|0]|0;if(!((i&255)>>>0<(h&255)>>>0|(i&255)>243)){l=k;break}b[468728]=j|32;l=k&-33;break}}}while(0);a[888136]=0;a[1692344]=0;a[14318709]=0;return l|0}function jZ(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a[968008]=0;f=b[468728]|0;L11872:do{if((f&8)==0){if((a[962713]&64)==0){break}g=c[496910]|0;do{if((g|0)>0){h=c[496914]|0;i=c[496912]|0;j=(((c[291649]|0)-h|0)>>>0)/(i>>>0)|0;if((j|0)>0){k=g-j|0;c[496910]=k;l=f&-257;b[468728]=l;if((k|0)<1){m=l|512;b[468728]=m;c[496910]=0;n=0;o=m}else{n=k;o=l}l=(ab(j,i)|0)+h|0;c[496914]=l;p=n;q=o;r=l}else{p=g;q=f;r=h}h=q&-513;b[468728]=h;if((p|0)<4){s=p;t=h;break}h=r+i|0;c[496914]=h;c[291649]=h;break L11872}else{h=f&-513;b[468728]=h;s=g;t=h}}while(0);g=s+1|0;c[496910]=g;b[468728]=(g<<6&256|t&65535)&65535}}while(0);j2(e);if((b[6236980]&256)==0){return}b[6236980]=e>>>8&65535;e=(d[962732]|0)<<8|(d[962731]|0);c[3118496]=(e|0)==0?65536:e;a[12473968]=2;jW(c[291649]|0);return}function j_(){var c=0,e=0,f=0,g=0,h=0;a[968008]=0;c=a[12474208]&15;if((c|0)==8){e=b[7158924]|0;f=b[12474e3+(e&126)>>1]|0;g=f<<3&3584|f<<2&224|f<<1&14;h=e}else if((c|0)==4){e=b[7158924]|0;g=b[822464+(e&126)>>1]|0;h=e}else if((c|0)==0){e=b[7158924]|0;g=b[822600+(e&65534)>>1]|0;h=e}else if((c|0)==12){c=b[7158924]|0;g=b[822600+(c&65534)>>1]&255;h=c}else{g=0;h=b[7158924]|0}b[7158924]=(d[962727]|0)+h&65535;return g&65535|0}function j$(){var c=0,f=0,g=0,h=0,i=0,j=0;a[968008]=0;c=a[12474208]&15;if((c|0)==8){f=b[7158924]|0;g=f&65535;h=e[12474e3+(g&126)>>1]|0;i=(g&1|0)==0?h<<2&224|h<<1&14:h>>>5&14;j=f}else if((c|0)==4){f=b[7158924]|0;i=d[822464+(f&127)|0]|0;j=f}else if((c|0)==0){c=b[7158924]|0;i=d[822600+(c&65535)|0]|0;j=c}else{i=0;j=b[7158924]|0}b[7158924]=(d[962727]|0)+j&65535;return i|0}function j0(c){c=c|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[12474208]&31)!=1){f=ab(d[962727]|0,c)|0;g=(e[7158924]|0)+f&65535;b[7158924]=g;return}f=b[478040]|0;h=b[478036]|0;i=b[6236980]&255;j=b[478044]|0;k=d[962727]|0;l=b[7158924]|0;m=c&65535;n=c;c=l;while(1){if((c&f)<<16>>16==h<<16>>16){a[956096+(c&j&65535)|0]=i}o=c&65535;a[822600+o|0]=i;p=o>>>5;q=14315776+p|0;r=a[q]|0;if(r<<24>>24==0){s=b[7158912]|0;b[7158912]=s+1&65535;b[14311680+((s&65535)<<1)>>1]=p&65535}a[q]=(r&255|1<<(o>>>2&7))&255;o=n-1|0;if((o|0)==0){break}else{n=o;c=c+k&65535}}g=(ab(k,m)|0)+l&65535;b[7158924]=g;return}function j1(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a[968008]=0;g=a[12474208]&15;h=f&65535;do{if((g|0)==1){i=b[7158924]|0;j=i&65535;k=j^1;if((k&(e[478040]|0)|0)==(e[478036]|0|0)){a[956096+((e[478044]|0)&k^1)|0]=f&255}l=822600+j|0;if((d[l]|0|0)==(f|0)){m=h;n=i;break}a[l]=f&255;l=k>>>5;j=14315776+l|0;o=a[j]|0;if(o<<24>>24==0){p=b[7158912]|0;b[7158912]=p+1&65535;b[14311680+((p&65535)<<1)>>1]=l&65535}a[j]=(o&255|1<<(k>>>2&7))&255;m=h;n=i}else if((g|0)==3){i=b[7158924]|0;k=i&65535;o=12474e3+(k&126)|0;j=e[o>>1]|0;if((k&1|0)==0){q=f>>>2&56|f>>>1&7|j&448}else{q=j&63|f<<5&448}l=q&65535;if((q|0)==(j|0)){m=l;n=i;break}j=k>>>1;k=j&63;b[o>>1]=l;do{if((j&15|0)!=0){o=(a[962712]&4)==0?q&73:q;if((a[962724]&8)==0){p=b[965448+(o<<1)>>1]|0;b[967496+(k<<1)>>1]=p;b[967496+((k|64)<<1)>>1]=p;b[967496+((k|128)<<1)>>1]=p;break}else{b[967496+(k<<1)>>1]=b[966472+(o<<1)>>1]|0;b[967496+((k|64)<<1)>>1]=b[965448+(o<<1)>>1]|0;b[967496+((k|128)<<1)>>1]=b[964424+(o<<1)>>1]|0;break}}}while(0);if((k|0)!=(d[12736648]|0|0)){m=l;n=i;break}j=(a[962712]&4)==0?q&73:q;if((a[962724]&8)==0){o=b[965448+(j<<1)>>1]|0;b[483748]=o;b[483812]=o;b[483876]=o;m=l;n=i;break}else{b[483748]=b[966472+(j<<1)>>1]|0;b[483812]=b[965448+(j<<1)>>1]|0;b[483876]=b[964424+(j<<1)>>1]|0;m=l;n=i;break}}else if((g|0)==5){j=b[7158924]|0;a[822464+(j&127)|0]=f&255;m=h;n=j}else{m=h;n=b[7158924]|0}}while(0);b[7158924]=n+(d[962727]|0)&65535;if((b[6236980]&256)==0){return}b[6236980]=m;m=(d[962732]|0)<<8|(d[962731]|0);c[3118496]=(m|0)==0?65536:m;a[12473968]=2;jW(c[3579678]|0);return}function j2(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a[12474208]&15;do{if((g|0)==5){b[822464+(b[7158924]&126)>>1]=f&65535;if((a[962723]&4)==0){break}h=e[444104]|0;if((h|0)>=(c[3446841]|0)){break}if((a[962713]&64)==0){break}if((c[291649]|0)>>>0>((c[290364]|0)+860|0)>>>0){break}kv(h)}else if((g|0)==3){h=e[7158924]|0;i=12474e3+(h&126)|0;j=f>>>3&448|f>>>2&56|f>>>1&7;if((j|0)==(e[i>>1]|0|0)){break}k=h>>>1;h=k&63;b[i>>1]=j&65535;do{if((k&15|0)!=0){i=(a[962712]&4)==0?j&73:j;if((a[962724]&8)==0){l=b[965448+(i<<1)>>1]|0;b[967496+(h<<1)>>1]=l;b[967496+((h|64)<<1)>>1]=l;b[967496+((h|128)<<1)>>1]=l;break}else{b[967496+(h<<1)>>1]=b[966472+(i<<1)>>1]|0;b[967496+((h|64)<<1)>>1]=b[965448+(i<<1)>>1]|0;b[967496+((h|128)<<1)>>1]=b[964424+(i<<1)>>1]|0;break}}}while(0);do{if((h|0)==(d[12736648]|0|0)){k=(a[962712]&4)==0?j&73:j;if((a[962724]&8)==0){i=b[965448+(k<<1)>>1]|0;b[483748]=i;b[483812]=i;b[483876]=i;break}else{b[483748]=b[966472+(k<<1)>>1]|0;b[483812]=b[965448+(k<<1)>>1]|0;b[483876]=b[964424+(k<<1)>>1]|0;break}}}while(0);j=e[444104]|0;if((j|0)>=(c[3446841]|0)){break}if((a[962713]&64)==0){break}if((c[291649]|0)>>>0>((c[290364]|0)+860|0)>>>0){break}kw(j)}else if((g|0)==1){j=e[7158924]|0;h=j&65534;k=822600+h|0;if((j&1|0)==0){m=f}else{m=(f>>>8|f<<8)&65535}if(((e[478040]|0)&h|0)==(e[478036]|0|0)){b[956096+((e[478044]|0)&h)>>1]=m&65535}if((m|0)==(e[k>>1]|0|0)){break}b[k>>1]=m&65535;k=j>>>5;h=14315776+k|0;i=a[h]|0;if(i<<24>>24==0){l=b[7158912]|0;b[7158912]=l+1&65535;b[14311680+((l&65535)<<1)>>1]=k&65535}a[h]=(i&255|1<<(j>>>2&7))&255}}while(0);b[7158924]=(b[7158924]|0)+(d[962727]|0)&65535;return}function j3(a){a=a|0;var f=0,g=0,h=0,i=0,j=0;f=(e[6236988]|0)<<1|(d[962735]|0)<<17;g=a;do{a=f>>>16;h=c[1161472+(a*20|0)>>2]|0;if((h|0)==0){i=b[(c[1161464+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{i=(fl[h&255](f)|0)&65535}j=f+2|0;f=(d[962735]|0)<<17|j&131071;j2(i&65535);g=g-1|0;}while((g|0)!=0);b[6236988]=j>>>1&65535;return}function j4(c){c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a[962735]|0;f=(e[6236988]|0)<<1;g=(f|(d&255)<<17)+2|0;j2(e[756920+(f&65534)>>1]|0);f=c-1|0;if((f|0)==0){h=g>>>1&65535;b[6236988]=h;return}else{i=d;j=g;k=f}while(1){f=a[962735]|0;l=(j&131071|(i&255)<<17)+2|0;j2(e[756920+(j&65535)>>1]|0);g=k-1|0;if((g|0)==0){break}else{i=f;j=l;k=g}}h=l>>>1&65535;b[6236988]=h;return}function j5(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=e[6236988]<<1|d[962735]<<17;h=f;do{do{if(g>>>0<10551296){if((a[736792]|0)==3){i=-1;break}i=b[756920+(g&65535)>>1]|0}else{if(g>>>0>=10551328){i=b[756920+(g&65535)>>1]|0;break}f=g>>>1&15;j=f-1|0;if(j>>>0<3){k=d[f+1692187|0]|0;l=(fD[c[964252+(j<<3)>>2]&127]()|0)&255;m=d[1692184+f|0]&(k|128)|l&(k&127^-129)}else{m=d[1692184+f|0]|0}i=(m<<8|m)&65535}}while(0);n=g+2|0;g=d[962735]<<17|n&131071;j2(i&65535);h=h-1|0;}while((h|0)!=0);b[6236988]=n>>>1&65535;return}function j6(c){c=c|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[12474208]&30)!=16){f=ab(d[962727]|0,c)|0;b[7158924]=(e[7158924]|0)+f&65535;g=(e[6236988]|0)+c&65535;b[6236988]=g;return}f=b[6236988]|0;h=b[478040]|0;i=b[478036]|0;j=b[478044]|0;k=d[962727]|0;l=b[7158924]|0;m=c&65535;n=c+65535|0;o=f;p=c;c=l;while(1){q=a[822600+(o&65535^1)|0]|0;if((c&h)<<16>>16==i<<16>>16){a[956096+(c&j&65535^1)|0]=q}r=c&65535;a[822600+(r^1)|0]=q;q=r>>>5;s=14315776+q|0;t=a[s]|0;if(t<<24>>24==0){u=b[7158912]|0;b[7158912]=u+1&65535;b[14311680+((u&65535)<<1)>>1]=q&65535}a[s]=(t&255|1<<(r>>>2&7))&255;r=p-1|0;if((r|0)==0){break}else{o=o+1&65535;p=r;c=c+k&65535}}b[7158924]=(ab(k,m)|0)+l&65535;g=((n&65535)+1&65535)+f&65535;b[6236988]=g;return}function j7(c,e){c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a[937424]|0;g=f&255;do{if((g|0)==64){h=e&15;i=e>>>4&15;j=e>>>8&15;k=(h>>>3<<11|h<<12|i<<7|j<<1|j>>>3|i>>>2<<5)&65535}else if((g|0)==16){i=c&15;if((i|0)==0){k=b[864+((a[962719]&15)<<1)>>1]|0;break}else{k=b[864+(i<<1)>>1]|0;break}}else{do{if((a[962712]&4)==0){if((g&128|0)!=0){l=0;break}if(f<<24>>24==65){l=e;break}i=c&15;if((i|0)==0){l=d[896+(a[962719]&15)|0]|0;break}else{l=d[896+i|0]|0;break}}else{l=e}}while(0);k=b[964296+((l&63)<<1)>>1]|0}}while(0);if((a[962712]&4)!=0){b[967496+(c<<1)>>1]=k;b[967496+((c|32)<<1)>>1]=k;b[967496+((c|128)<<1)>>1]=k;b[967496+((c|160)<<1)>>1]=k;return}if((c|0)==64){m=8710}else{if((a[962719]&15|16|0)==(c|0)){m=8710}}if((m|0)==8710){b[483812]=k;b[483764]=k;b[483796]=k;b[483892]=k;b[483924]=k}if((c&15|0)==0){return}b[967496+(c<<1)>>1]=k;b[967496+((c|32)<<1)>>1]=k;b[967496+((c|128)<<1)>>1]=k;b[967496+((c|160)<<1)>>1]=k;return}function j8(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0;c=(d[962715]|0)<<6;e=(d[962716]|0)<<11&14336|b&7;f=32;g=1560104;h=822600+((d[962714]|0)<<10&15360|b<<2&992)|0;while(1){b=d[h]|0;i=d[822600+(b>>>3|c)|0]|0;j=d[822600+(e|b<<3)|0]|0;a[g]=(i>>>(j>>>7<<2>>>0)&15|16)&255;a[g+1|0]=(i>>>((j>>>6<<2&4)>>>0)&15|16)&255;a[g+2|0]=(i>>>((j>>>5<<2&4)>>>0)&15|16)&255;a[g+3|0]=(i>>>((j>>>4<<2&4)>>>0)&15|16)&255;a[g+4|0]=(i>>>((j>>>3<<2&4)>>>0)&15|16)&255;a[g+5|0]=(i>>>((j&4)>>>0)&15|16)&255;a[g+6|0]=(i>>>((j>>>1<<2&4)>>>0)&15|16)&255;a[g+7|0]=(i>>>((j<<2&4)>>>0)&15|16)&255;j=f-1|0;if((j|0)==0){break}else{f=j;g=g+8|0;h=h+1|0}}return}function j9(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0;c=a[962719]|0;e=822600+(((d[962714]|0)<<10&15360)+((b>>3)*40|0))|0;f=(d[962716]|0)<<11&14336|b&7;b=1560104;g=b|0;x=1077952576;a[g]=x&255;x=x>>8;a[g+1|0]=x&255;x=x>>8;a[g+2|0]=x&255;x=x>>8;a[g+3|0]=x&255;g=b+4|0;x=1077952576;a[g]=x&255;x=x>>8;a[g+1|0]=x&255;x=x>>8;a[g+2|0]=x&255;x=x>>8;a[g+3|0]=x&255;g=c&255;c=40;b=e;e=1560112;while(1){h=d[822600+((d[b]|0)+f)|0]|0;a[e]=(g>>>(h>>>7<<2>>>0)&15|16)&255;a[e+1|0]=(g>>>((h>>>6<<2&4)>>>0)&15|16)&255;a[e+2|0]=(g>>>((h>>>5<<2&4)>>>0)&15|16)&255;a[e+3|0]=(g>>>((h>>>4<<2&4)>>>0)&15|16)&255;a[e+4|0]=(g>>>((h>>>3<<2&4)>>>0)&15|16)&255;a[e+5|0]=(g>>>((h&4)>>>0)&15|16)&255;h=c-1|0;if((h|0)==0){break}else{c=h;b=b+1|0;e=e+6|0}}e=1560352;b=e|0;x=1077952576;a[b]=x&255;x=x>>8;a[b+1|0]=x&255;x=x>>8;a[b+2|0]=x&255;x=x>>8;a[b+3|0]=x&255;b=e+4|0;x=1077952576;a[b]=x&255;x=x>>8;a[b+1|0]=x&255;x=x>>8;a[b+2|0]=x&255;x=x>>8;a[b+3|0]=x&255;return}function ka(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0;c=a[962719]|0;e=822600+(((d[962714]|0)<<10&15360)+((b>>3)*40|0))|0;f=(d[962716]|0)<<11^-14337;g=((d[937424]|0)>32?f|6144:f)&65535&(b<<5&6144|8192)|b&7;b=1560104;f=b|0;x=1077952576;a[f]=x&255;x=x>>8;a[f+1|0]=x&255;x=x>>8;a[f+2|0]=x&255;x=x>>8;a[f+3|0]=x&255;f=b+4|0;x=1077952576;a[f]=x&255;x=x>>8;a[f+1|0]=x&255;x=x>>8;a[f+2|0]=x&255;x=x>>8;a[f+3|0]=x&255;f=c&255;c=e;e=1560112;b=40;while(1){h=d[822600+(g|(d[c]|0)<<3)|0]|0;a[e]=(f>>>(h>>>7<<2>>>0)&15|16)&255;a[e+1|0]=(f>>>((h>>>6<<2&4)>>>0)&15|16)&255;a[e+2|0]=(f>>>((h>>>5<<2&4)>>>0)&15|16)&255;a[e+3|0]=(f>>>((h>>>4<<2&4)>>>0)&15|16)&255;a[e+4|0]=(f>>>((h>>>3<<2&4)>>>0)&15|16)&255;a[e+5|0]=(f>>>((h&4)>>>0)&15|16)&255;h=b-1|0;if((h|0)==0){break}else{c=c+1|0;e=e+6|0;b=h}}b=1560352;e=b|0;x=1077952576;a[e]=x&255;x=x>>8;a[e+1|0]=x&255;x=x>>8;a[e+2|0]=x&255;x=x>>8;a[e+3|0]=x&255;e=b+4|0;x=1077952576;a[e]=x&255;x=x>>8;a[e+1|0]=x&255;x=x>>8;a[e+2|0]=x&255;x=x>>8;a[e+3|0]=x&255;return}function kb(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=(d[962715]|0)<<6;e=(d[962716]|0)<<11^-14337;if((d[937424]|0)>32){f=e|6144;g=c|-8193}else{f=e;g=c|-16321}c=b<<5&6144|8192;e=b&7;h=g&65535&c|e;i=f&65535&c|e;e=822600+((d[962714]|0)<<10&15360|b<<2&992)|0;b=1560104;c=32;while(1){f=(d[e]|0)<<3;j=d[822600+(h|f&g&65535)|0]|0;k=d[822600+(i|f&65535)|0]|0;a[b]=(j>>>(k>>>7<<2>>>0)&15|16)&255;a[b+1|0]=(j>>>((k>>>6<<2&4)>>>0)&15|16)&255;a[b+2|0]=(j>>>((k>>>5<<2&4)>>>0)&15|16)&255;a[b+3|0]=(j>>>((k>>>4<<2&4)>>>0)&15|16)&255;a[b+4|0]=(j>>>((k>>>3<<2&4)>>>0)&15|16)&255;a[b+5|0]=(j>>>((k&4)>>>0)&15|16)&255;a[b+6|0]=(j>>>((k>>>1<<2&4)>>>0)&15|16)&255;a[b+7|0]=(j>>>((k<<2&4)>>>0)&15|16)&255;k=c-1|0;if((k|0)==0){break}else{e=e+1|0;b=b+8|0;c=k}}return}function kc(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0;c=(d[962716]|0)<<11&14336|b>>>2&7;e=32;f=822600+((d[962714]|0)<<10&15360|b<<2&992)|0;b=1560104;while(1){g=a[822600+(c|(d[f]|0)<<3)|0]|0;aIv(b|0,(g&255)>>>4|16|0,4);h=e-1|0;aIv(b+4|0,g&15|16|0,4);if((h|0)==0){break}else{e=h;f=f+1|0;b=b+8|0}}return}function kd(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0;c=(d[962716]|0)<<11^-14337;e=((d[937424]|0)>32?c|6144:c)&65535&(b<<5&6144|8192)|b>>>2&7;c=822600+((d[962714]|0)<<10&15360|b<<2&992)|0;b=1560104;f=32;while(1){g=a[822600+(e|(d[c]|0)<<3)|0]|0;aIv(b|0,(g&255)>>>4|16|0,4);h=f-1|0;aIv(b+4|0,g&15|16|0,4);if((h|0)==0){break}else{c=c+1|0;b=b+8|0;f=h}}return}function ke(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;c=a[962719]|0;b=1560104;d=b|0;x=1077952576;a[d]=x&255;x=x>>8;a[d+1|0]=x&255;x=x>>8;a[d+2|0]=x&255;x=x>>8;a[d+3|0]=x&255;d=b+4|0;x=1077952576;a[d]=x&255;x=x>>8;a[d+1|0]=x&255;x=x>>8;a[d+2|0]=x&255;x=x>>8;a[d+3|0]=x&255;d=(c&255)>>>4|16;b=c&15|16;c=1560112;e=40;while(1){aIv(c|0,d|0,4);a[c+4|0]=b;a[c+5|0]=b;f=e-1|0;if((f|0)==0){break}else{c=c+6|0;e=f}}e=1560352;c=e|0;x=1077952576;a[c]=x&255;x=x>>8;a[c+1|0]=x&255;x=x>>8;a[c+2|0]=x&255;x=x>>8;a[c+3|0]=x&255;c=e+4|0;x=1077952576;a[c]=x&255;x=x>>8;a[c+1|0]=x&255;x=x>>8;a[c+2|0]=x&255;x=x>>8;a[c+3|0]=x&255;return}function kf(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=a[962712]|0;if((g&64)!=0&(b|0)<16){h=256}else{h=d[962720]|0}i=h&7;j=(e[411296]|0)+b|0;k=(d[962714]|0)<<10^-15361;l=(d[937424]|0)>32?k|1024:k;if((c[3446841]|0)>192){k=(j|0)%256|0;m=k;n=(k>>>3<<6)+(l&14080)|0}else{k=(j|0)%224|0;m=k;n=(k>>>3<<6)+14336&(l&65535)}k=256-h>>3;if((i|0)==0){o=k}else{aIv(1560104,0,i|0);o=k+1|0}k=f>>3;if((k|0)<=0){return}f=l&65535;l=b>>>3<<6;h=(f&14080)+l|0;j=b<<3&56;b=f&l+14336;l=822600+n|0;n=0;f=o;o=1560072+(i|32)|0;i=m<<3&56;m=g;while(1){if((n|0)==24&m<<24>>24<0){p=j;q=822600+((c[3446841]|0)>192?h:b)|0}else{p=i;q=l}g=e[q+(((f|0)%(k|0)|0)<<1)>>1]|0;r=c[689664+((g>>>11&3)<<2)>>2]|0;s=g<<6&131008|p;c[o>>2]=c[13787392+s>>2]|r;c[o+4>>2]=c[s+13787396>>2]|r;r=n+1|0;if((r|0)>=(k|0)){break}l=q;n=r;f=f+1|0;o=o+8|0;i=p;m=a[962712]|0}return}function kg(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=c[822600+(((d[1692328]&b)<<2)+(e[846168]|0))>>2]|0;h=c[205616]|0;i=d[964288]|0;j=e[482140]|0;k=d[964272]|0;l=d[962730]|0;m=l<<3&248;n=l>>>7;l=f>>4;f=g>>>16&15;o=i+1|0;p=o-(i&g>>>20)|0;q=j&(h>>>16)+b;r=822600+((q>>>3<<k&8128)+(e[484132]|0))|0;s=q<<3&56;if((f|0)==0){t=1560104}else{q=f|16;f=c[r+((p+255&i)<<2)>>2]|0;u=c[689664+((f>>>13&7)<<2)>>2]|0;v=f<<6&524224|s;c[1560072+q>>2]=c[13787392+v>>2]|u;c[q+1560076>>2]=c[13787392+(v|4)>>2]|u;u=c[689664+(f>>>29<<2)>>2]|0;v=f>>>10&524224|s;c[q+1560080>>2]=c[13787392+v>>2]|u;c[q+1560084>>2]=c[13787392+(v|4)>>2]|u;t=q+1560088|0}if((l|0)>0){q=t;t=0;u=p;while(1){p=c[r+((u&i)<<2)>>2]|0;v=c[689664+((p>>>13&7)<<2)>>2]|0;f=p<<6&524224|s;c[q>>2]=c[13787392+f>>2]|v;c[q+4>>2]=c[13787392+(f|4)>>2]|v;v=c[689664+(p>>>29<<2)>>2]|0;f=p>>>10&524224|s;c[q+8>>2]=c[13787392+f>>2]|v;c[q+12>>2]=c[13787392+(f|4)>>2]|v;v=t+1|0;if((v|0)<(l|0)){q=q+16|0;t=v;u=u+1|0}else{break}}}do{if((n|0)==((m|0)<=(b|0)|0)){w=0;x=l}else{u=a[12474221]|0;if((a[12474218]|0)==0){y=l;z=0}else{t=a[12474216]|0;q=t&255;s=a[12474217]|0;r=s&255;v=g&15;f=q+(o-(i&g>>>4))|0;p=j&h+b;A=822600+((e[484136]|0)+(p>>>3<<k&8128))|0;B=p<<3&56;if((v|0)==0){C=(q<<4)+32|0}else{p=(q<<4)+(v|16)|0;v=c[A+(((t<<24>>24==0?f+255|0:f)&i)<<2)>>2]|0;D=c[689664+((v>>>13&7)<<2)>>2]|0;E=v<<6&524224|B;c[1560584+p>>2]=c[13787392+E>>2]|D;c[p+1560588>>2]=c[13787392+(E|4)>>2]|D;D=c[689664+(v>>>29<<2)>>2]|0;E=v>>>10&524224|B;c[p+1560592>>2]=c[13787392+E>>2]|D;c[p+1560596>>2]=c[13787392+(E|4)>>2]|D;C=p+16|0}if((t&255)<(s&255)){s=1560584+C|0;t=q;q=f;while(1){f=c[A+((q&i)<<2)>>2]|0;p=c[689664+((f>>>13&7)<<2)>>2]|0;D=f<<6&524224|B;c[s>>2]=c[13787392+D>>2]|p;c[s+4>>2]=c[13787392+(D|4)>>2]|p;p=c[689664+(f>>>29<<2)>>2]|0;D=f>>>10&524224|B;c[s+8>>2]=c[13787392+D>>2]|p;c[s+12>>2]=c[13787392+(D|4)>>2]|p;p=t+1|0;if((p|0)<(r|0)){s=s+16|0;t=p;q=q+1|0}else{break}}}y=d[12474220]|0;z=d[12474219]|0}if(u<<24>>24!=0){w=z;x=y;break}return}}while(0);y=822600+(b>>3<<(a[962724]&1|6)|e[484128])|0;z=b<<3&56;if((w|0)>=(x|0)){return}b=(w<<4)+1560616|0;i=w;while(1){w=c[y+(i<<2)>>2]|0;C=c[689664+((w>>>13&7)<<2)>>2]|0;k=w<<6&524224|z;c[b>>2]=c[13787392+k>>2]|C;c[b+4>>2]=c[13787392+(k|4)>>2]|C;C=c[689664+(w>>>29<<2)>>2]|0;k=w>>>10&524224|z;c[b+8>>2]=c[13787392+k>>2]|C;c[b+12>>2]=c[13787392+(k|4)>>2]|C;C=i+1|0;if((C|0)<(x|0)){b=b+16|0;i=C}else{break}}return}function kh(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=c[822600+(((d[1692328]&b)<<2)+(e[846168]|0))>>2]|0;h=d[964288]|0;i=e[482140]|0;j=d[964272]|0;k=d[962730]|0;l=k<<3&248;m=k>>>7;k=f>>4;f=g>>>16&15;n=h+1|0;o=n-(h&g>>>20)|0;if((a[962724]&1)==0){p=0}else{q=c[205635]|0;p=q>>>16&q}if((f|0)==0){r=1560104}else{q=p+b&i;s=q<<3&56;t=f|16;f=c[822600+((e[484132]|0)+(q>>>3<<j&8128))+((o+255&h)<<2)>>2]|0;q=c[689664+((f>>>13&7)<<2)>>2]|0;u=f<<6&524224|s;c[1560072+t>>2]=c[13787392+u>>2]|q;c[t+1560076>>2]=c[13787392+(u|4)>>2]|q;q=c[689664+(f>>>29<<2)>>2]|0;u=f>>>10&524224|s;c[t+1560080>>2]=c[13787392+u>>2]|q;c[t+1560084>>2]=c[13787392+(u|4)>>2]|q;r=t+1560088|0}L12155:do{if((k|0)>0){t=e[484132]|0;q=r;u=0;s=o;while(1){f=((c[822464+(u<<2)>>2]|0)>>>16)+b&i;v=f<<3&56;w=c[822600+((f>>>3<<j&8128)+t)+((s&h)<<2)>>2]|0;f=c[689664+((w>>>13&7)<<2)>>2]|0;x=v|w<<6&524224;c[q>>2]=c[13787392+x>>2]|f;c[q+4>>2]=c[13787392+(x|4)>>2]|f;f=c[689664+(w>>>29<<2)>>2]|0;x=v|w>>>10&524224;c[q+8>>2]=c[13787392+x>>2]|f;c[q+12>>2]=c[13787392+(x|4)>>2]|f;f=u+1|0;if((f|0)>=(k|0)){break L12155}q=q+16|0;u=f;s=s+1|0}}}while(0);do{if((m|0)==((l|0)<=(b|0)|0)){y=0;z=k}else{o=a[12474221]|0;if((a[12474218]|0)==0){A=k;B=0}else{r=a[12474216]|0;s=r&255;u=a[12474217]|0;q=u&255;t=g&15;f=s+(n-(h&g>>>4))|0;if((t|0)==0){C=(s<<4)+32|0}else{x=p+b&i;w=x<<3&56;v=(s<<4)+(t|16)|0;t=c[822600+((e[484136]|0)+(x>>>3<<j&8128))+(((r<<24>>24==0?f+255|0:f)&h)<<2)>>2]|0;x=c[689664+((t>>>13&7)<<2)>>2]|0;D=t<<6&524224|w;c[1560584+v>>2]=c[13787392+D>>2]|x;c[v+1560588>>2]=c[13787392+(D|4)>>2]|x;x=c[689664+(t>>>29<<2)>>2]|0;D=t>>>10&524224|w;c[v+1560592>>2]=c[13787392+D>>2]|x;c[v+1560596>>2]=c[13787392+(D|4)>>2]|x;C=v+16|0}L12169:do{if((r&255)<(u&255)){v=e[484136]|0;x=1560584+C|0;D=s;w=f;while(1){t=(c[822464+(D<<2)>>2]|0)+b&i;E=t<<3&56;F=c[822600+((t>>>3<<j&8128)+v)+((w&h)<<2)>>2]|0;t=c[689664+((F>>>13&7)<<2)>>2]|0;G=F<<6&524224|E;c[x>>2]=c[13787392+G>>2]|t;c[x+4>>2]=c[13787392+(G|4)>>2]|t;t=c[689664+(F>>>29<<2)>>2]|0;G=F>>>10&524224|E;c[x+8>>2]=c[13787392+G>>2]|t;c[x+12>>2]=c[13787392+(G|4)>>2]|t;t=D+1|0;if((t|0)>=(q|0)){break L12169}x=x+16|0;D=t;w=w+1|0}}}while(0);A=d[12474220]|0;B=d[12474219]|0}if(o<<24>>24!=0){y=B;z=A;break}return}}while(0);A=822600+(b>>3<<(a[962724]&1|6)|e[484128])|0;B=b<<3&56;if((y|0)>=(z|0)){return}b=(y<<4)+1560616|0;h=y;while(1){y=c[A+(h<<2)>>2]|0;j=c[689664+((y>>>13&7)<<2)>>2]|0;i=y<<6&524224|B;c[b>>2]=c[13787392+i>>2]|j;c[b+4>>2]=c[13787392+(i|4)>>2]|j;j=c[689664+(y>>>29<<2)>>2]|0;i=y>>>10&524224|B;c[b+8>>2]=c[13787392+i>>2]|j;c[b+12>>2]=c[13787392+(i|4)>>2]|j;j=h+1|0;if((j|0)<(z|0)){b=b+16|0;h=j}else{break}}return}function ki(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=d[968080]|0;h=c[822600+(((d[1692328]&b)<<2)+(e[846168]|0))>>2]|0;i=c[205616]|0;j=d[964288]|0;k=e[482140]|0;l=d[964272]|0;m=d[962730]|0;n=m<<3&248;o=m>>>7;m=f>>4;f=h>>>16&15;p=j+1|0;q=p-(j&h>>>20)|0;r=k&(i>>>17)+b;s=822600+((r>>>3<<l&8128)+(e[484132]|0))|0;t=(r<<1&14|g)<<3;if((f|0)==0){u=1560104}else{r=f|16;f=c[s+((q+255&j)<<2)>>2]|0;v=c[689664+((f>>>13&7)<<2)>>2]|0;w=(f<<6&393216|t|f<<7&130944)^f>>>6&64;c[1560072+r>>2]=c[13787392+w>>2]|v;c[r+1560076>>2]=c[13787392+(w|4)>>2]|v;v=c[689664+(f>>>29<<2)>>2]|0;w=(f>>>10&393216|t|f>>>9&130944)^f>>>22&64;c[r+1560080>>2]=c[13787392+w>>2]|v;c[r+1560084>>2]=c[13787392+(w|4)>>2]|v;u=r+1560088|0}if((m|0)>0){r=u;u=0;v=q;while(1){q=c[s+((v&j)<<2)>>2]|0;w=c[689664+((q>>>13&7)<<2)>>2]|0;f=(q<<6&393216|t|q<<7&130944)^q>>>6&64;c[r>>2]=c[13787392+f>>2]|w;c[r+4>>2]=c[13787392+(f|4)>>2]|w;w=c[689664+(q>>>29<<2)>>2]|0;f=(q>>>10&393216|t|q>>>9&130944)^q>>>22&64;c[r+8>>2]=c[13787392+f>>2]|w;c[r+12>>2]=c[13787392+(f|4)>>2]|w;w=u+1|0;if((w|0)<(m|0)){r=r+16|0;u=w;v=v+1|0}else{break}}}do{if((o|0)==((n|0)<=(b|0)|0)){x=0;y=m}else{v=a[12474221]|0;if((a[12474218]|0)==0){z=m;A=0}else{u=a[12474216]|0;r=u&255;t=a[12474217]|0;s=t&255;w=h&15;f=r+(p-(j&h>>>4))|0;q=k&(i>>>1)+b;B=822600+((e[484136]|0)+(q>>>3<<l&8128))|0;C=(q<<1&14|g)<<3;if((w|0)==0){D=(r<<4)+32|0}else{q=(r<<4)+(w|16)|0;w=c[B+(((u<<24>>24==0?f+255|0:f)&j)<<2)>>2]|0;E=c[689664+((w>>>13&7)<<2)>>2]|0;F=(w<<6&393216|C|w<<7&130944)^w>>>6&64;c[1560584+q>>2]=c[13787392+F>>2]|E;c[q+1560588>>2]=c[13787392+(F|4)>>2]|E;E=c[689664+(w>>>29<<2)>>2]|0;F=(w>>>10&393216|C|w>>>9&130944)^w>>>22&64;c[q+1560592>>2]=c[13787392+F>>2]|E;c[q+1560596>>2]=c[13787392+(F|4)>>2]|E;D=q+16|0}if((u&255)<(t&255)){t=1560584+D|0;u=r;r=f;while(1){f=c[B+((r&j)<<2)>>2]|0;q=c[689664+((f>>>13&7)<<2)>>2]|0;E=(f<<6&393216|C|f<<7&130944)^f>>>6&64;c[t>>2]=c[13787392+E>>2]|q;c[t+4>>2]=c[13787392+(E|4)>>2]|q;q=c[689664+(f>>>29<<2)>>2]|0;E=(f>>>10&393216|C|f>>>9&130944)^f>>>22&64;c[t+8>>2]=c[13787392+E>>2]|q;c[t+12>>2]=c[13787392+(E|4)>>2]|q;q=u+1|0;if((q|0)<(s|0)){t=t+16|0;u=q;r=r+1|0}else{break}}}z=d[12474220]|0;A=d[12474219]|0}if(v<<24>>24!=0){x=A;y=z;break}return}}while(0);z=822600+(b>>3<<(a[962724]&1|6)|e[484128])|0;A=(g|b<<1&14)<<3;if((x|0)>=(y|0)){return}b=(x<<4)+1560616|0;g=x;while(1){x=c[z+(g<<2)>>2]|0;j=c[689664+((x>>>13&7)<<2)>>2]|0;D=(x<<6&393216|A|x<<7&130944)^x>>>6&64;c[b>>2]=c[13787392+D>>2]|j;c[b+4>>2]=c[13787392+(D|4)>>2]|j;j=c[689664+(x>>>29<<2)>>2]|0;D=(x>>>10&393216|A|x>>>9&130944)^x>>>22&64;c[b+8>>2]=c[13787392+D>>2]|j;c[b+12>>2]=c[13787392+(D|4)>>2]|j;j=g+1|0;if((j|0)<(y|0)){b=b+16|0;g=j}else{break}}return}function kj(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=d[968080]|0;h=c[822600+(((d[1692328]&b)<<2)+(e[846168]|0))>>2]|0;i=d[964288]|0;j=e[482140]|0;k=d[964272]|0;l=d[962730]|0;m=l<<3&248;n=l>>>7;l=f>>4;f=h>>>16&15;o=i+1|0;p=o-(i&h>>>20)|0;if((a[962724]&1)==0){q=0}else{r=c[205635]|0;q=r>>>1&r>>>17}if((f|0)==0){s=1560104}else{r=q+b&j;t=(r<<1&14|g)<<3;u=f|16;f=c[822600+((e[484132]|0)+(r>>>3<<k&8128))+((p+255&i)<<2)>>2]|0;r=c[689664+((f>>>13&7)<<2)>>2]|0;v=(f<<6&393216|t|f<<7&130944)^f>>>6&64;c[1560072+u>>2]=c[13787392+v>>2]|r;c[u+1560076>>2]=c[13787392+(v|4)>>2]|r;r=c[689664+(f>>>29<<2)>>2]|0;v=(f>>>10&393216|t|f>>>9&130944)^f>>>22&64;c[u+1560080>>2]=c[13787392+v>>2]|r;c[u+1560084>>2]=c[13787392+(v|4)>>2]|r;s=u+1560088|0}L12221:do{if((l|0)>0){u=e[484132]|0;r=s;v=0;f=p;while(1){t=((c[822464+(v<<2)>>2]|0)>>>17)+b&j;w=(t<<1&14|g)<<3;x=c[822600+((t>>>3<<k&8128)+u)+((f&i)<<2)>>2]|0;t=c[689664+((x>>>13&7)<<2)>>2]|0;y=(x<<7&130944|x<<6&393216|w)^x>>>6&64;c[r>>2]=c[13787392+y>>2]|t;c[r+4>>2]=c[13787392+(y|4)>>2]|t;t=c[689664+(x>>>29<<2)>>2]|0;y=(x>>>9&130944|x>>>10&393216|w)^x>>>22&64;c[r+8>>2]=c[13787392+y>>2]|t;c[r+12>>2]=c[13787392+(y|4)>>2]|t;t=v+1|0;if((t|0)>=(l|0)){break L12221}r=r+16|0;v=t;f=f+1|0}}}while(0);do{if((n|0)==((m|0)<=(b|0)|0)){z=0;A=l}else{p=a[12474221]|0;if((a[12474218]|0)==0){B=l;C=0}else{s=a[12474216]|0;f=s&255;v=a[12474217]|0;r=v&255;u=h&15;t=f+(o-(i&h>>>4))|0;if((u|0)==0){D=(f<<4)+32|0}else{y=q+b&j;x=(y<<1&14|g)<<3;w=(f<<4)+(u|16)|0;u=c[822600+((e[484136]|0)+(y>>>3<<k&8128))+(((s<<24>>24==0?t+255|0:t)&i)<<2)>>2]|0;y=c[689664+((u>>>13&7)<<2)>>2]|0;E=(u<<6&393216|x|u<<7&130944)^u>>>6&64;c[1560584+w>>2]=c[13787392+E>>2]|y;c[w+1560588>>2]=c[13787392+(E|4)>>2]|y;y=c[689664+(u>>>29<<2)>>2]|0;E=(u>>>10&393216|x|u>>>9&130944)^u>>>22&64;c[w+1560592>>2]=c[13787392+E>>2]|y;c[w+1560596>>2]=c[13787392+(E|4)>>2]|y;D=w+16|0}L12235:do{if((s&255)<(v&255)){w=e[484136]|0;y=1560584+D|0;E=f;u=t;while(1){x=((c[822464+(E<<2)>>2]|0)>>>1)+b&j;F=(x<<1&14|g)<<3;G=c[822600+((x>>>3<<k&8128)+w)+((u&i)<<2)>>2]|0;x=c[689664+((G>>>13&7)<<2)>>2]|0;H=(G<<7&130944|G<<6&393216|F)^G>>>6&64;c[y>>2]=c[13787392+H>>2]|x;c[y+4>>2]=c[13787392+(H|4)>>2]|x;x=c[689664+(G>>>29<<2)>>2]|0;H=(G>>>9&130944|G>>>10&393216|F)^G>>>22&64;c[y+8>>2]=c[13787392+H>>2]|x;c[y+12>>2]=c[13787392+(H|4)>>2]|x;x=E+1|0;if((x|0)>=(r|0)){break L12235}y=y+16|0;E=x;u=u+1|0}}}while(0);B=d[12474220]|0;C=d[12474219]|0}if(p<<24>>24!=0){z=C;A=B;break}return}}while(0);B=822600+(b>>3<<(a[962724]&1|6)|e[484128])|0;C=(g|b<<1&14)<<3;if((z|0)>=(A|0)){return}b=(z<<4)+1560616|0;g=z;while(1){z=c[B+(g<<2)>>2]|0;i=c[689664+((z>>>13&7)<<2)>>2]|0;k=(z<<6&393216|C|z<<7&130944)^z>>>6&64;c[b>>2]=c[13787392+k>>2]|i;c[b+4>>2]=c[13787392+(k|4)>>2]|i;i=c[689664+(z>>>29<<2)>>2]|0;k=(z>>>10&393216|C|z>>>9&130944)^z>>>22&64;c[b+8>>2]=c[13787392+k>>2]|i;c[b+12>>2]=c[13787392+(k|4)>>2]|i;i=g+1|0;if((i|0)<(A|0)){b=b+16|0;g=i}else{break}}return}function kk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;i=i+8|0;h=g|0;j=a[962713]|0;k=j&255;l=k>>>1;m=8<<(l&1)<<(k&1);n=b[468728]|d[937504];b[468728]=n;a[937504]=0;o=a[968248]|0;if(o<<24>>24!=0){p=d[962718]<<11&14336;q=h|0;r=h+1|0;s=o&255;o=((l|65534)^1)&((k|65533)^2);if((j&1)==0){j=0;k=n;while(1){l=b[968094+(j<<3)>>1]|0;t=(e[968090+(j<<3)>>1]|0)-((l&128)>>>2&32)|0;u=t+32|0;if((t+m|0)>256){v=0;w=256-t|0}else{v=(t|0)<0?-t|0:0;w=m}t=e[968088+(j<<3)>>1]|p|(o&e[968092+(j<<3)>>1])<<3;a[q]=a[822600+t|0]|0;a[r]=a[t+822616|0]|0;if((v|0)<(w|0)){t=l&255&15;l=v;x=k;do{y=1560072+(u+l)|0;z=d[y]|0;a[y]=a[1494520+(t&-((d[h+(l>>>3&1)|0]|0)>>>((l&7^7)>>>0)&1)|z<<8)|0]|0;x=(z>>>2&32|x&65535)&65535;l=l+1|0;}while((l|0)<(w|0));b[468728]=x;A=x}else{A=k}l=j+1|0;if((l|0)<(s|0)){j=l;k=A}else{break}}}else{A=0;k=n;while(1){n=b[968094+(A<<3)>>1]|0;j=(e[968090+(A<<3)>>1]|0)-((n&128)>>>2&32)|0;w=j+32|0;if((j+m|0)>256){B=0;C=256-j|0}else{B=(j|0)<0?-j|0:0;C=m}v=e[968088+(A<<3)>>1]|p|(o&e[968092+(A<<3)>>1])<<3;a[q]=a[822600+v|0]|0;a[r]=a[v+822616|0]|0;if((B|0)<(C|0)){v=n&255&15;n=j+33|0;j=B;l=k;do{t=v&-((d[h+(j>>>4&1)|0]|0)>>>((j>>>1&7^7)>>>0)&1);u=1560072+(w+j)|0;z=d[u]|0;a[u]=a[1494520+(t|z<<8)|0]|0;u=1560072+(n+j)|0;y=d[u]|0;a[u]=a[1494520+(y<<8|t)|0]|0;l=(z>>>2&32|l&65535|y>>>2&32)&65535;j=j+2|0;}while((j|0)<(C|0));b[468728]=l;D=l}else{D=k}j=A+1|0;if((j|0)<(s|0)){A=j;k=D}else{break}}}}if((a[937424]|0)!=64|(a[12474177]|0)!=0){i=g;return}D=e[444104]|0;k=c[3446841]|0;if((D|0)>=(k|0)){i=g;return}if((D-((k-144|0)/2|0)|0)>>>0>143){aIv(1560104,64,f|0);i=g;return}if((c[3446838]|0)<=0){i=g;return}aIv(1560104,64,48);aIv(1560312,64,48);i=g;return}function kl(c){c=c|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=c;g=1560616;h=1560104;while(1){a[h]=a[1166840+(d[h]<<8|d[g])|0]|0;i=f-1|0;if((i|0)==0){break}else{f=i;g=g+1|0;h=h+1|0}}h=d[968248]|0;g=0;f=0;i=0;while(1){if((g|0)>=(h|0)){j=0;k=8899;break}l=b[968090+(g<<3)>>1]|0;m=l&65535;if(l<<16>>16==0){n=(a[937504]|0)==0?f:1}else{a[937504]=1;n=f}l=m-128|0;o=e[968094+(g<<3)>>1]|0;p=(o<<1&24)+8|0;q=p+i|0;do{if((p+l|0)>0&(l|0)<(c|0)&(n|0)==0){r=e[968092+(g<<3)>>1]|0;s=e[968088+(g<<3)>>1]|0;t=r>>>9&112;u=r&6144;v=u>>>3|o<<4|s>>>1&12;w=((q|0)>(c|0)?c-i|0:p)>>3;x=s<<3&56;if((w|0)<=0){break}s=0;y=1560072+(m-96)|0;while(1){z=13787392+(((d[968280+(s+v)|0]|0)+r&2047|u)<<6|x)|0;A=0;while(1){B=d[z]|0;if((B&15|0)!=0){C=y+A|0;D=d[C]|0;a[C]=a[1232376+(B|t|D<<8)|0]|0;b[468728]=(e[468728]|D>>>2&32)&65535}D=A+1|0;if((D|0)<8){z=z+1|0;A=D}else{break}}A=s+1|0;if((A|0)<(w|0)){s=A;y=y+8|0}else{break}}}}while(0);if((q|0)>=(c|0)){j=1;k=8898;break}g=g+1|0;f=n;i=q}if((k|0)==8898){a[937504]=j;return}else if((k|0)==8899){a[937504]=j;return}}function km(c){c=c|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=a[968080]|0;g=c;h=1560616;i=1560104;while(1){a[i]=a[1166840+(d[i]<<8|d[h])|0]|0;j=g-1|0;if((j|0)==0){break}else{g=j;h=h+1|0;i=i+1|0}}i=f&255;f=d[968248]|0;h=0;g=0;j=0;while(1){if((h|0)>=(f|0)){k=0;l=8918;break}m=b[968090+(h<<3)>>1]|0;n=m&65535;if(m<<16>>16==0){o=(a[937504]|0)==0?g:1}else{a[937504]=1;o=g}m=n-128|0;p=e[968094+(h<<3)>>1]|0;q=(p<<1&24)+8|0;r=q+j|0;do{if((q+m|0)>0&(m|0)<(c|0)&(o|0)==0){s=e[968092+(h<<3)>>1]|0;t=e[968088+(h<<3)>>1]|0;u=s>>>9&112;v=s&6144;w=v>>>3|p<<4|t>>>1&12;x=((r|0)>(c|0)?c-j|0:q)>>3;y=(t<<1&14|i)<<3;if((x|0)<=0){break}t=s>>>6&64;z=0;A=1560072+(n-96)|0;while(1){B=13787392+((((d[968280+(z+w)|0]|0)+s<<1&2046|v)<<6|y)^t)|0;C=0;while(1){D=d[B]|0;if((D&15|0)!=0){E=A+C|0;F=d[E]|0;a[E]=a[1232376+(D|u|F<<8)|0]|0;b[468728]=(e[468728]|F>>>2&32)&65535}F=C+1|0;if((F|0)<8){B=B+1|0;C=F}else{break}}C=z+1|0;if((C|0)<(x|0)){z=C;A=A+8|0}else{break}}}}while(0);if((r|0)>=(c|0)){k=1;l=8919;break}h=h+1|0;g=o;j=r}if((l|0)==8918){a[937504]=k;return}else if((l|0)==8919){a[937504]=k;return}}function kn(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;g=d[962713]|0;h=((g>>>1|65534)^1)&(d[962718]<<6^65087);i=a[937424]|0;if(i<<24>>24>-1){j=8<<(g&1);if((i&255)>32){k=j;l=8922}else{m=h&65535;n=j}}else{k=8;l=8922}if((l|0)==8922){m=(h|192)&65535;n=k}k=b[468728]|d[937504];b[468728]=k;a[937504]=0;h=a[968248]|0;if(h<<24>>24!=0){l=(i&255)<33;j=a[962712]&8;g=h&255;h=e[444104]<<8;o=0;p=n;n=k;while(1){k=(o|0)==4&l?8:p;q=((b[968092+(o<<3)>>1]|256)&m&65535)<<6|e[968088+(o<<3)>>1]<<3;r=(e[968090+(o<<3)>>1]|0)-j|0;if((r|0)<0){s=q-r|0;t=r+k|0;u=0}else{s=q;t=(r+k|0)>(f|0)?f-r|0:k;u=r}r=13787392+s|0;q=u+32|0;v=(t|0)>0;do{if((k|0)>8){if(!v){w=n;break}x=u+14|0;y=u+13|0;z=r;A=0;B=n;while(1){C=z+1|0;D=a[z]|0;E=D&255;do{if((E&15|0)==0){F=B}else{G=1560072+(A+q)|0;H=d[G]<<8;a[G]=a[1494520+(H|E)|0]|0;do{if((H&32768|0)==0){I=B}else{if((B&32)!=0){I=B;break}b[468756]=(h|(y+A|0)>>>1)&65535;G=B|32;b[468728]=G;I=G}}while(0);H=1560072+((A|1)+q)|0;G=(d[H]<<8|D&255)&65535;a[H]=a[1494520+G|0]|0;if((G&32768|0)==0){F=I;break}if((I&32)!=0){F=I;break}b[468756]=(h|(x+A|0)>>>1)&65535;G=I|32;b[468728]=G;F=G}}while(0);D=A+2|0;if((D|0)<(t|0)){z=C;A=D;B=F}else{w=F;break}}}else{if(!v){w=n;break}B=u+13|0;A=r;z=0;x=n;while(1){y=A+1|0;D=d[A]|0;do{if((D&15|0)==0){J=x}else{E=1560072+(z+q)|0;G=d[E]<<8;a[E]=a[1494520+(G|D)|0]|0;if((G&32768|0)==0){J=x;break}if((x&32)!=0){J=x;break}b[468756]=(h|(B+z|0)>>>1)&65535;G=x|32;b[468728]=G;J=G}}while(0);D=z+1|0;if((D|0)<(t|0)){A=y;z=D;x=J}else{w=J;break}}}}while(0);q=o+1|0;if((q|0)<(g|0)){o=q;p=k;n=w}else{break}}}if(i<<24>>24!=64|(a[12474177]|0)!=0){return}i=e[444104]|0;w=c[3446841]|0;if((i|0)>=(w|0)){return}if((i-((w-144|0)/2|0)|0)>>>0>143){aIv(1560104,64,f|0);return}if((c[3446838]|0)<=0){return}aIv(1560104,64,48);aIv(1560312,64,48);return}function ko(c){c=c|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=c;g=1560616;h=1560104;while(1){a[h]=a[1297912+(d[h]<<8|d[g])|0]|0;i=f-1|0;if((i|0)==0){break}else{f=i;g=g+1|0;h=h+1|0}}aIv(1560584,0,c+64|0);h=d[968248]|0;g=0;f=0;i=0;while(1){if((g|0)>=(h|0)){j=8978;break}k=b[968090+(g<<3)>>1]|0;l=k&65535;if(k<<16>>16==0){m=(a[937504]|0)==0?f:1}else{a[937504]=1;m=f}k=l-128|0;n=e[968094+(g<<3)>>1]|0;o=(n<<1&24)+8|0;p=o+i|0;do{if((o+k|0)>0&(k|0)<(c|0)&(m|0)==0){q=e[968092+(g<<3)>>1]|0;r=e[968088+(g<<3)>>1]|0;s=q>>>9&112;t=q&6144;u=t>>>3|n<<4|r>>>1&12;v=((p|0)>(c|0)?c-i|0:o)>>3;w=r<<3&56;if((v|0)<=0){break}r=0;x=1560584+(l-96)|0;while(1){y=13787392+(((d[968280+(r+u)|0]|0)+q&2047|t)<<6|w)|0;z=0;while(1){A=d[y]|0;if((A&15|0)!=0){B=x+z|0;C=d[B]|0;a[B]=a[1363448+(A|s|C<<8)|0]|0;b[468728]=(e[468728]|C>>>2&32)&65535}C=z+1|0;if((C|0)<8){y=y+1|0;z=C}else{break}}z=r+1|0;if((z|0)<(v|0)){r=z;x=x+8|0}else{break}}}}while(0);if((p|0)>=(c|0)){j=8976;break}g=g+1|0;f=m;i=p}if((j|0)==8976){a[937504]=1;i=c;m=1560616;f=1560104;while(1){a[f]=a[1428984+(d[f]<<8|d[m])|0]|0;g=i-1|0;if((g|0)==0){break}else{i=g;m=m+1|0;f=f+1|0}}return}else if((j|0)==8978){a[937504]=0;j=c;c=1560616;f=1560104;while(1){a[f]=a[1428984+(d[f]<<8|d[c])|0]|0;m=j-1|0;if((m|0)==0){break}else{j=m;c=c+1|0;f=f+1|0}}return}}function kp(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d[962713]|0;L12434:do{if((f&16|0)==0){g=(d[962717]|0)<<7&16256;h=f&1;i=8<<(f>>>1&1)<<h;j=0;k=0;while(1){l=j<<2;m=a[822600+(l+g)|0]|0;n=m&255;o=k&255;if(m<<24>>24==-48){p=j;q=o;break L12434}r=e-((m&255)>223?n|-256:n)|0;if((r|0)>-1&(r|0)<(i|0)){if((k|0)==4){break}b[968088+(k<<3)>>1]=r>>h&65535;b[968090+(k<<3)>>1]=d[822600+((l|1)+g)|0]|0;b[968092+(k<<3)>>1]=d[822600+((l|2)+g)|0]|0;b[968094+(k<<3)>>1]=d[822600+((l|3)+g)|0]|0;s=k+1|0}else{s=k}l=j+1|0;if((l|0)<32){j=l;k=s}else{p=l;q=s&255;break L12434}}if((c[3446841]|0)<=(e|0)){p=j;q=o;break}a[937504]=64;p=j;q=o}else{p=0;q=0}}while(0);a[968248]=q;b[468728]=(b[468728]&224|p&31)&65535;return}function kq(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[962713]|0;g=(f<<2&8)+8|0;h=(d[962717]|0)<<7^-16257;i=a[937424]|0;j=((i&255)>32?h|128:h)&65535;h=j&16128;k=c[3446841]|0;l=k+16|0;m=i<<24>>24>-1?f&1:0;f=0;i=0;while(1){n=a[822600+(f+h)|0]|0;o=n&255;p=i&255;if((o|0)==(l|0)){q=p;r=9003;break}s=e-((n&255)>239?o|-256:o)>>m;if((s|0)>-1&(s|0)<(g|0)){if((i|0)==8){r=8997;break}b[968088+(i<<3)>>1]=s&65535;s=f<<1;b[968090+(i<<3)>>1]=d[822600+((s+128&j)+h)|0]|0;b[968092+(i<<3)>>1]=d[822600+((s+129&j)+h)|0]|0;t=i+1|0}else{t=i}s=f+1|0;if((s|0)<64){f=s;i=t}else{q=t&255;r=9005;break}}if((r|0)==9003){a[968248]=q;return}else if((r|0)==8997){if(!((e|0)>-1&(k|0)>(e|0))){q=p;a[968248]=q;return}a[937504]=64;q=p;a[968248]=q;return}else if((r|0)==9005){a[968248]=q;return}}function kr(c){c=c|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=(d[962724]|0)<<2&4|16;g=822600+(e[478036]|0)|0;h=c+129|0;c=d[1692312]|0;i=f<<2;j=0;k=0;L12463:while(1){l=e[956096+((j|1)<<1)>>1]|0;m=l>>>8;n=h-((e[956096+(j<<1)>>1]|0)>>>(c>>>0)&511)|0;do{if((n|0)>-1){if((n|0)>=((m<<3&24)+8|0)){o=k;break}if((k|0)==(f|0)){p=9010;break L12463}b[968092+(k<<3)>>1]=b[g+((j|2)<<1)>>1]|0;b[968090+(k<<3)>>1]=b[g+((j|3)<<1)>>1]&511;b[968088+(k<<3)>>1]=n&65535;b[968094+(k<<3)>>1]=m&15;o=k+1|0}else{o=k}}while(0);m=l<<2&508;if((m|0)==0){q=o;p=9015;break}n=i-1|0;if((n|0)==0){q=o;p=9017;break}else{i=n;j=m;k=o}}if((p|0)==9017){r=q&255;a[968248]=r;return}else if((p|0)==9010){b[468728]=b[468728]|64;q=f;r=q&255;a[968248]=r;return}else if((p|0)==9015){r=q&255;a[968248]=r;return}}function ks(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((b|0)>0){f=0}else{return}do{g=e[14311680+(f<<1)>>1]|0;h=14315776+g|0;i=d[h]|0;j=g<<6;k=g<<5;g=0;l=0;while(1){if((1<<l&i|0)!=0){m=l<<2|k;n=l<<3;o=n^56;p=0;q=(c[12474504+((e[822600+m>>1]|0)<<2)>>2]|0)>>>2|c[12474504+((e[822600+(m|2)>>1]|0)<<2)>>2];m=0;while(1){r=q&15;a[13787392+((m|n)+j)|0]=r;s=m^7;a[13787392+((n|s|32768)+j)|0]=r;a[13787392+((o|m|65536)+j)|0]=r;a[13787392+((o|s|98304)+j)|0]=r;r=p+1&255;if((r&255)<8){p=r;q=q>>>4;m=r&255}else{break}}}m=g+1&255;if((m&255)<8){g=m;l=m&255}else{break}}a[h]=0;f=f+1|0;}while((f|0)<(b|0));return}function kt(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((b|0)>0){f=0}else{return}do{g=e[14311680+(f<<1)>>1]|0;h=14315776+g|0;i=d[h]|0;j=g<<6;k=g<<5;g=0;l=0;while(1){if((1<<l&i|0)!=0){m=l<<3;n=m^56;o=0;p=c[822600+(l<<2|k)>>2]|0;q=0;while(1){r=p&15;s=q^3;a[13787392+((s|m)+j)|0]=r;t=q^4;a[13787392+((m|t|131072)+j)|0]=r;a[13787392+((n|s|262144)+j)|0]=r;a[13787392+((n|t|393216)+j)|0]=r;r=o+1&255;if((r&255)<8){o=r;p=p>>>4;q=r&255}else{break}}}q=g+1&255;if((q&255)<8){g=q;l=q&255}else{break}}a[h]=0;f=f+1|0;}while((f|0)<(b|0));return}function ku(c){c=c|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=a[968080]|0;g=c;h=1560616;i=1560104;while(1){a[i]=a[1297912+(d[i]<<8|d[h])|0]|0;j=g-1|0;if((j|0)==0){break}else{g=j;h=h+1|0;i=i+1|0}}i=f&255;aIv(1560584,0,c+64|0);f=d[968248]|0;h=0;g=0;j=0;while(1){if((h|0)>=(f|0)){k=9057;break}l=b[968090+(h<<3)>>1]|0;m=l&65535;if(l<<16>>16==0){n=(a[937504]|0)==0?g:1}else{a[937504]=1;n=g}l=m-128|0;o=e[968094+(h<<3)>>1]|0;p=(o<<1&24)+8|0;q=p+j|0;do{if((p+l|0)>0&(l|0)<(c|0)&(n|0)==0){r=e[968092+(h<<3)>>1]|0;s=e[968088+(h<<3)>>1]|0;t=r>>>9&112;u=r&6144;v=u>>>3|o<<4|s>>>1&12;w=((q|0)>(c|0)?c-j|0:p)>>3;x=(s<<1&14|i)<<3;if((w|0)<=0){break}s=r>>>6&64;y=0;z=1560584+(m-96)|0;while(1){A=13787392+((((d[968280+(y+v)|0]|0)+r<<1&2046|u)<<6|x)^s)|0;B=0;while(1){C=d[A]|0;if((C&15|0)!=0){D=z+B|0;E=d[D]|0;a[D]=a[1363448+(C|t|E<<8)|0]|0;b[468728]=(e[468728]|E>>>2&32)&65535}E=B+1|0;if((E|0)<8){A=A+1|0;B=E}else{break}}B=y+1|0;if((B|0)<(w|0)){y=B;z=z+8|0}else{break}}}}while(0);if((q|0)>=(c|0)){k=9055;break}h=h+1|0;g=n;j=q}if((k|0)==9055){a[937504]=1;j=c;n=1560616;g=1560104;while(1){a[g]=a[1428984+(d[g]<<8|d[n])|0]|0;h=j-1|0;if((h|0)==0){break}else{j=h;n=n+1|0;g=g+1|0}}return}else if((k|0)==9057){a[937504]=0;k=c;c=1560616;g=1560104;while(1){a[g]=a[1428984+(d[g]<<8|d[c])|0]|0;n=k-1|0;if((n|0)==0){break}else{k=n;c=c+1|0;g=g+1|0}}return}}function kv(e){e=e|0;var f=0,g=0,h=0;f=c[3446840]|0;do{if((a[962713]&64)==0){if((a[937424]|0)>-1){b[468728]=b[468728]|d[937504];a[937504]=0;fi[c[242004]&255](e)}aIv(1560104,64,f|0)}else{g=b[7158912]|0;if(g<<16>>16!=0){fi[c[222054]&255](g&65535);b[7158912]=0}fj[c[240676]&511](e,f);fi[c[240674]&255](f);if((a[962712]&32)!=0&(d[937424]|0)>16){g=1560104;h=g|0;x=1077952576;a[h]=x&255;x=x>>8;a[h+1|0]=x&255;x=x>>8;a[h+2|0]=x&255;x=x>>8;a[h+3|0]=x&255;h=g+4|0;x=1077952576;a[h]=x&255;x=x>>8;a[h+1|0]=x&255;x=x>>8;a[h+2|0]=x&255;x=x>>8;a[h+3|0]=x&255}if(((c[3446841]|0)-1|0)<=(e|0)){break}fi[c[242004]&255](e)}}while(0);h=c[3446838]|0;if((h|0)<=0){kw(e);return}aIv(1560072+(32-h)|0,64,h|0);aIv(f+1560104|0,64,h|0);kw(e);return}function kw(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;g=c[3446838]|0;h=(g<<1)+(c[3446840]|0)|0;i=32-g|0;g=1560072+i|0;j=((c[3446839]|0)+f|0)%(e[780032]|0)|0;if((j|0)<0){return}if((a[1692200]|0)==0|(a[12474178]|0)==0){k=j}else{k=(d[968080]|0)+(j<<1)|0}if((a[12474176]|0)==0){j=ab(c[3446837]|0,k)|0;f=(c[3446834]|0)+j|0;j=g;l=h;while(1){b[f>>1]=b[967496+(d[j]<<1)>>1]|0;m=l-1|0;if((m|0)==0){break}else{f=f+2|0;j=j+1|0;l=m}}return}if((a[962724]&1)==0){l=(h|0)/3|0;j=(l*-3|0)+h|0;f=-(j>>>1&1)|0;m=e[483748]|0;n=c[235932]|0;o=(m<<10&30720|m&1920|m>>>9&120)*21|0;m=n+o|0;p=e[967496+(d[g]<<1)>>1]&f;q=(p<<10&30720|p&1920|p>>>9&120)*21|0;p=e[967496+(d[1560072+(i+(f&1))|0]<<1)>>1]&(f|-(j&1));f=(p<<10&30720|p&1920|p>>>9&120)*21|0;p=ab(c[3446837]|0,k)|0;r=c[3446834]|0;s=r+p|0;if((h+2|0)>>>0<5){t=s;u=m;v=m;w=f;x=q;y=m}else{z=p+(l*14|0)|0;p=l;l=s;s=m;A=m;B=f;f=q;q=m;C=1560072+(i+j)|0;while(1){D=n+B|0;E=n+f|0;j=e[967496+(d[C]<<1)>>1]|0;F=(j<<10&30720|j&1920|j>>>9&120)*21|0;G=n+F|0;j=(c[n+(f+76)>>2]|0)+(c[G>>2]|0)+(c[n+(B+124)>>2]|0)+(c[q+28>>2]|0)+(c[A+104>>2]|0)+(c[s+152>>2]|0)|0;H=j>>>9&3148803;I=539494914-H|0;J=(I|j)&I-H;b[l>>1]=(J>>>13&63488|J>>>8&2016|J>>>4&31)&65535;J=(c[n+(f+80)>>2]|0)+(c[n+(F|4)>>2]|0)+(c[n+(B+128)>>2]|0)+(c[q+32>>2]|0)+(c[A+108>>2]|0)+(c[s+156>>2]|0)|0;H=J>>>9&3148803;I=539494914-H|0;j=(I|J)&I-H;b[l+2>>1]=(j>>>13&63488|j>>>8&2016|j>>>4&31)&65535;j=e[967496+(d[C+1|0]<<1)>>1]|0;K=(j<<10&30720|j&1920|j>>>9&120)*21|0;j=(c[n+(K+56)>>2]|0)+(c[n+(F+8)>>2]|0)+(c[n+(B+132)>>2]|0)+(c[q+36>>2]|0)+(c[n+(f+84)>>2]|0)+(c[s+160>>2]|0)|0;H=j>>>9&3148803;I=539494914-H|0;J=(I|j)&I-H;b[l+4>>1]=(J>>>13&63488|J>>>8&2016|J>>>4&31)&65535;J=(c[n+(K+60)>>2]|0)+(c[n+(F+12)>>2]|0)+(c[n+(B+136)>>2]|0)+(c[q+40>>2]|0)+(c[n+(f+88)>>2]|0)+(c[s+164>>2]|0)|0;H=J>>>9&3148803;I=539494914-H|0;j=(I|J)&I-H;b[l+6>>1]=(j>>>13&63488|j>>>8&2016|j>>>4&31)&65535;j=e[967496+(d[C+2|0]<<1)>>1]|0;L=(j<<10&30720|j&1920|j>>>9&120)*21|0;j=(c[n+(K+64)>>2]|0)+(c[n+(F+16)>>2]|0)+(c[n+(L+112)>>2]|0)+(c[q+44>>2]|0)+(c[n+(f+92)>>2]|0)+(c[n+(B+140)>>2]|0)|0;H=j>>>9&3148803;I=539494914-H|0;J=(I|j)&I-H;b[l+8>>1]=(J>>>13&63488|J>>>8&2016|J>>>4&31)&65535;J=(c[n+(K+68)>>2]|0)+(c[n+(F+20)>>2]|0)+(c[n+(L+116)>>2]|0)+(c[q+48>>2]|0)+(c[n+(f+96)>>2]|0)+(c[n+(B+144)>>2]|0)|0;H=J>>>9&3148803;I=539494914-H|0;j=(I|J)&I-H;b[l+10>>1]=(j>>>13&63488|j>>>8&2016|j>>>4&31)&65535;j=(c[n+(K+72)>>2]|0)+(c[n+(F+24)>>2]|0)+(c[n+(L+120)>>2]|0)+(c[q+52>>2]|0)+(c[n+(f+100)>>2]|0)+(c[n+(B+148)>>2]|0)|0;F=j>>>9&3148803;H=539494914-F|0;I=(H|j)&H-F;b[l+12>>1]=(I>>>13&63488|I>>>8&2016|I>>>4&31)&65535;I=p-1|0;if((I|0)==0){break}else{p=I;l=l+14|0;s=D;A=E;B=L;f=K;q=G;C=C+3|0}}t=r+z|0;u=D;v=E;w=L;x=K;y=G}G=(c[n+(x+76)>>2]|0)+(c[m>>2]|0)+(c[n+(w+124)>>2]|0)+(c[y+28>>2]|0)+(c[v+104>>2]|0)+(c[u+152>>2]|0)|0;m=G>>>9&3148803;K=539494914-m|0;L=(K|G)&K-m;b[t>>1]=(L>>>13&63488|L>>>8&2016|L>>>4&31)&65535;L=(c[n+(x+80)>>2]|0)+(c[n+(o|4)>>2]|0)+(c[n+(w+128)>>2]|0)+(c[y+32>>2]|0)+(c[v+108>>2]|0)+(c[u+156>>2]|0)|0;v=L>>>9&3148803;m=539494914-v|0;K=(m|L)&m-v;b[t+2>>1]=(K>>>13&63488|K>>>8&2016|K>>>4&31)&65535;K=(c[n+(o+56)>>2]|0)+(c[n+(o+8)>>2]|0)+(c[n+(w+132)>>2]|0)+(c[y+36>>2]|0)+(c[n+(x+84)>>2]|0)+(c[u+160>>2]|0)|0;v=K>>>9&3148803;m=539494914-v|0;L=(m|K)&m-v;b[t+4>>1]=(L>>>13&63488|L>>>8&2016|L>>>4&31)&65535;L=(c[n+(o+60)>>2]|0)+(c[n+(o+12)>>2]|0)+(c[n+(w+136)>>2]|0)+(c[y+40>>2]|0)+(c[n+(x+88)>>2]|0)+(c[u+164>>2]|0)|0;u=L>>>9&3148803;v=539494914-u|0;m=(v|L)&v-u;b[t+6>>1]=(m>>>13&63488|m>>>8&2016|m>>>4&31)&65535;m=(c[n+(o+64)>>2]|0)+(c[n+(o+16)>>2]|0)+(c[n+(o+112)>>2]|0)+(c[y+44>>2]|0)+(c[n+(x+92)>>2]|0)+(c[n+(w+140)>>2]|0)|0;u=m>>>9&3148803;v=539494914-u|0;L=(v|m)&v-u;b[t+8>>1]=(L>>>13&63488|L>>>8&2016|L>>>4&31)&65535;L=(c[n+(o+68)>>2]|0)+(c[n+(o+20)>>2]|0)+(c[n+(o+116)>>2]|0)+(c[y+48>>2]|0)+(c[n+(x+96)>>2]|0)+(c[n+(w+144)>>2]|0)|0;u=L>>>9&3148803;v=539494914-u|0;m=(v|L)&v-u;b[t+10>>1]=(m>>>13&63488|m>>>8&2016|m>>>4&31)&65535;m=(c[n+(o+72)>>2]|0)+(c[n+(o+24)>>2]|0)+(c[n+(o+120)>>2]|0)+(c[y+52>>2]|0)+(c[n+(x+100)>>2]|0)+(c[n+(w+148)>>2]|0)|0;w=m>>>9&3148803;n=539494914-w|0;x=(n|m)&n-w;b[t+12>>1]=(x>>>13&63488|x>>>8&2016|x>>>4&31)&65535;return}else{x=(h|0)/4|0;h=e[483748]|0;t=c[290362]|0;w=(h<<9&14336|h&1792|h>>>8&224)<<2;h=t+w|0;n=e[967496+(d[g]<<1)>>1]|0;g=(n<<9&14336|n&1792|n>>>8&224)<<2;n=e[967496+(d[i+1560073|0]<<1)>>1]|0;m=t+((n<<9&14336|n&1792|n>>>8&224)<<2)|0;n=i+1560075|0;y=e[967496+(d[i+1560074|0]<<1)>>1]|0;i=(y<<9&14336|y&1792|y>>>8&224)<<2;y=ab(c[3446837]|0,k)|0;k=c[3446834]|0;o=k+y|0;u=x-1|0;v=e[967496+(d[n]<<1)>>1]|0;if((u|0)==0){M=o;N=h;O=h;P=h;Q=i;R=m;S=g;T=h;U=v}else{L=(x<<4)-16+y|0;y=o;o=h;x=h;K=h;G=i;i=m;m=g;g=h;E=n;n=u;u=v;while(1){V=t+G|0;W=t+m|0;v=(u<<9&14336|u&1792|u>>>8&224)<<2;X=t+v|0;D=(c[t+(m+88)>>2]|0)+(c[X>>2]|0)+(c[i+16>>2]|0)+(c[t+(G+72)>>2]|0)+(c[g+32>>2]|0)+(c[K+120>>2]|0)+(c[x+48>>2]|0)+(c[o+104>>2]|0)|0;z=D>>>9&3148803;r=539494914-z|0;C=(r|D)&r-z;b[y>>1]=(C>>>13&63488|C>>>8&2016|C>>>4&31)&65535;C=(c[t+(m+92)>>2]|0)+(c[t+(v|4)>>2]|0)+(c[i+20>>2]|0)+(c[t+(G+76)>>2]|0)+(c[g+36>>2]|0)+(c[K+124>>2]|0)+(c[x+52>>2]|0)+(c[o+108>>2]|0)|0;z=C>>>9&3148803;r=539494914-z|0;D=(r|C)&r-z;b[y+2>>1]=(D>>>13&63488|D>>>8&2016|D>>>4&31)&65535;D=e[967496+(d[E+1|0]<<1)>>1]|0;Y=(D<<9&14336|D&1792|D>>>8&224)<<2;D=(c[t+(Y|64)>>2]|0)+(c[t+(v|8)>>2]|0)+(c[i+24>>2]|0)+(c[t+(G+80)>>2]|0)+(c[g+40>>2]|0)+(c[t+(m+96)>>2]|0)+(c[x+56>>2]|0)+(c[o+112>>2]|0)|0;z=D>>>9&3148803;r=539494914-z|0;C=(r|D)&r-z;b[y+4>>1]=(C>>>13&63488|C>>>8&2016|C>>>4&31)&65535;C=(c[t+(Y|68)>>2]|0)+(c[t+(v|12)>>2]|0)+(c[i+28>>2]|0)+(c[t+(G+84)>>2]|0)+(c[g+44>>2]|0)+(c[t+(m+100)>>2]|0)+(c[x+60>>2]|0)+(c[o+116>>2]|0)|0;z=C>>>9&3148803;r=539494914-z|0;D=(r|C)&r-z;b[y+6>>1]=(D>>>13&63488|D>>>8&2016|D>>>4&31)&65535;D=e[967496+(d[E+2|0]<<1)>>1]|0;z=(D<<9&14336|D&1792|D>>>8&224)<<2;Z=t+z|0;D=(c[t+(Y|72)>>2]|0)+(c[t+(v|16)>>2]|0)+(c[Z>>2]|0)+(c[t+(G+88)>>2]|0)+(c[g+48>>2]|0)+(c[t+(m+104)>>2]|0)+(c[i+32>>2]|0)+(c[o+120>>2]|0)|0;r=D>>>9&3148803;C=539494914-r|0;q=(C|D)&C-r;b[y+8>>1]=(q>>>13&63488|q>>>8&2016|q>>>4&31)&65535;q=(c[t+(Y|76)>>2]|0)+(c[t+(v|20)>>2]|0)+(c[t+(z|4)>>2]|0)+(c[t+(G+92)>>2]|0)+(c[g+52>>2]|0)+(c[t+(m+108)>>2]|0)+(c[i+36>>2]|0)+(c[o+124>>2]|0)|0;r=q>>>9&3148803;C=539494914-r|0;D=(C|q)&C-r;b[y+10>>1]=(D>>>13&63488|D>>>8&2016|D>>>4&31)&65535;D=E+4|0;r=e[967496+(d[E+3|0]<<1)>>1]|0;_=(r<<9&14336|r&1792|r>>>8&224)<<2;r=(c[t+(Y|80)>>2]|0)+(c[t+(v|24)>>2]|0)+(c[t+(z|8)>>2]|0)+(c[t+(_|64)>>2]|0)+(c[g+56>>2]|0)+(c[t+(m+112)>>2]|0)+(c[i+40>>2]|0)+(c[t+(G+96)>>2]|0)|0;C=r>>>9&3148803;q=539494914-C|0;f=(q|r)&q-C;b[y+12>>1]=(f>>>13&63488|f>>>8&2016|f>>>4&31)&65535;f=(c[t+(Y|84)>>2]|0)+(c[t+(v|28)>>2]|0)+(c[t+(z|12)>>2]|0)+(c[t+(_|68)>>2]|0)+(c[g+60>>2]|0)+(c[t+(m+116)>>2]|0)+(c[i+44>>2]|0)+(c[t+(G+100)>>2]|0)|0;z=f>>>9&3148803;v=539494914-z|0;C=(v|f)&v-z;b[y+14>>1]=(C>>>13&63488|C>>>8&2016|C>>>4&31)&65535;C=n-1|0;$=e[967496+(d[D]<<1)>>1]|0;if((C|0)==0){break}else{y=y+16|0;o=V;x=i;K=W;G=_;i=Z;m=Y;g=X;E=D;n=C;u=$}}M=k+L|0;N=V;O=i;P=W;Q=_;R=Z;S=Y;T=X;U=$}$=(U<<9&14336|U&1792|U>>>8&224)<<2;U=(c[t+(S+88)>>2]|0)+(c[t+$>>2]|0)+(c[R+16>>2]|0)+(c[t+(Q+72)>>2]|0)+(c[T+32>>2]|0)+(c[P+120>>2]|0)+(c[O+48>>2]|0)+(c[N+104>>2]|0)|0;X=U>>>9&3148803;Y=539494914-X|0;Z=(Y|U)&Y-X;b[M>>1]=(Z>>>13&63488|Z>>>8&2016|Z>>>4&31)&65535;Z=(c[t+(S+92)>>2]|0)+(c[t+($|4)>>2]|0)+(c[R+20>>2]|0)+(c[t+(Q+76)>>2]|0)+(c[T+36>>2]|0)+(c[P+124>>2]|0)+(c[O+52>>2]|0)+(c[N+108>>2]|0)|0;P=Z>>>9&3148803;X=539494914-P|0;Y=(X|Z)&X-P;b[M+2>>1]=(Y>>>13&63488|Y>>>8&2016|Y>>>4&31)&65535;Y=t+(w|64)|0;P=(c[Y>>2]|0)+(c[t+($|8)>>2]|0)+(c[R+24>>2]|0)+(c[t+(Q+80)>>2]|0)+(c[T+40>>2]|0)+(c[t+(S+96)>>2]|0)+(c[O+56>>2]|0)+(c[N+112>>2]|0)|0;X=P>>>9&3148803;Z=539494914-X|0;U=(Z|P)&Z-X;b[M+4>>1]=(U>>>13&63488|U>>>8&2016|U>>>4&31)&65535;U=t+(w|68)|0;X=(c[U>>2]|0)+(c[t+($|12)>>2]|0)+(c[R+28>>2]|0)+(c[t+(Q+84)>>2]|0)+(c[T+44>>2]|0)+(c[t+(S+100)>>2]|0)+(c[O+60>>2]|0)+(c[N+116>>2]|0)|0;O=X>>>9&3148803;Z=539494914-O|0;P=(Z|X)&Z-O;b[M+6>>1]=(P>>>13&63488|P>>>8&2016|P>>>4&31)&65535;P=(c[t+(w|72)>>2]|0)+(c[t+($|16)>>2]|0)+(c[h>>2]|0)+(c[t+(Q+88)>>2]|0)+(c[T+48>>2]|0)+(c[t+(S+104)>>2]|0)+(c[R+32>>2]|0)+(c[N+120>>2]|0)|0;h=P>>>9&3148803;O=539494914-h|0;Z=(O|P)&O-h;b[M+8>>1]=(Z>>>13&63488|Z>>>8&2016|Z>>>4&31)&65535;Z=(c[t+(w|76)>>2]|0)+(c[t+($|20)>>2]|0)+(c[t+(w|4)>>2]|0)+(c[t+(Q+92)>>2]|0)+(c[T+52>>2]|0)+(c[t+(S+108)>>2]|0)+(c[R+36>>2]|0)+(c[N+124>>2]|0)|0;N=Z>>>9&3148803;h=539494914-N|0;O=(h|Z)&h-N;b[M+10>>1]=(O>>>13&63488|O>>>8&2016|O>>>4&31)&65535;O=(c[t+(w|80)>>2]|0)+(c[t+($|24)>>2]|0)+(c[t+(w|8)>>2]|0)+(c[Y>>2]|0)+(c[T+56>>2]|0)+(c[t+(S+112)>>2]|0)+(c[R+40>>2]|0)+(c[t+(Q+96)>>2]|0)|0;Y=O>>>9&3148803;N=539494914-Y|0;h=(N|O)&N-Y;b[M+12>>1]=(h>>>13&63488|h>>>8&2016|h>>>4&31)&65535;h=(c[t+(w|84)>>2]|0)+(c[t+($|28)>>2]|0)+(c[t+(w|12)>>2]|0)+(c[U>>2]|0)+(c[T+60>>2]|0)+(c[t+(S+116)>>2]|0)+(c[R+44>>2]|0)+(c[t+(Q+100)>>2]|0)|0;Q=h>>>9&3148803;t=539494914-Q|0;R=(t|h)&t-Q;b[M+14>>1]=(R>>>13&63488|R>>>8&2016|R>>>4&31)&65535;return}}function kx(){var a=0,d=0,e=0,f=0,g=0.0;a=c[235925]|0;if((a|0)!=0){d=a|0;e=c[d+4>>2]|0;f=a+8|0;c[f>>2]=(c[d>>2]|0)>>>1|e<<31;c[f+4>>2]=e>>>1|0<<31;c[a+20>>2]=0;aIv(a+24|0,0,(c[a+16>>2]<<2)+72|0)}a=c[235926]|0;if((a|0)!=0){e=a|0;f=c[e+4>>2]|0;d=a+8|0;c[d>>2]=(c[e>>2]|0)>>>1|f<<31;c[d+4>>2]=f>>>1|0<<31;c[a+20>>2]=0;aIv(a+24|0,0,(c[a+16>>2]<<2)+72|0)}a=c[235927]|0;if((a|0)!=0){f=a|0;d=c[f+4>>2]|0;e=a+8|0;c[e>>2]=(c[f>>2]|0)>>>1|d<<31;c[e+4>>2]=d>>>1|0<<31;c[a+20>>2]=0;aIv(a+24|0,0,(c[a+16>>2]<<2)+72|0)}a=c[235928]|0;if((a|0)!=0){d=a|0;e=c[d+4>>2]|0;f=a+8|0;c[f>>2]=(c[d>>2]|0)>>>1|e<<31;c[f+4>>2]=e>>>1|0<<31;c[a+20>>2]=0;aIv(a+24|0,0,(c[a+16>>2]<<2)+72|0)}a=c[235929]|0;if((a|0)!=0){e=a|0;f=c[e+4>>2]|0;d=a+8|0;c[d>>2]=(c[e>>2]|0)>>>1|f<<31;c[d+4>>2]=f>>>1|0<<31;c[a+20>>2]=0;aIv(a+24|0,0,(c[a+16>>2]<<2)+72|0)}a=c[235930]|0;if((a|0)!=0){f=a|0;d=c[f+4>>2]|0;e=a+8|0;c[e>>2]=(c[f>>2]|0)>>>1|d<<31;c[e+4>>2]=d>>>1|0<<31;c[a+20>>2]=0;aIv(a+24|0,0,(c[a+16>>2]<<2)+72|0)}b[780028]=0;b[481244]=0;a=b[6237078]|0;d=b[6237079]|0;e=c[235920]|0;aIv(12473504,0,104);g=+(e|0);h[1559188]=+U(+(+(a<<16>>16|0)/g*3.141592653589793))*2.0;h[1559193]=+U(+(+(d<<16>>16|0)/g*3.141592653589793))*2.0;h[1559201]=+(b[6237080]|0)/100.0;h[1559202]=+(b[6237081]|0)/100.0;h[1559203]=+(b[6237082]|0)/100.0;return}function ky(){var f=0.0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;aIv(756920,0,65536);aIv(736800,0,8192);f=+((e[780032]|0)*3420|0|0);g=~~(+(aQ()|0)/2147483647.0*f);c[291649]=g-((g>>>0)%7|0);c[3579678]=g-((g>>>0)%15|0);g=a[937424]|0;h=g&255;if((h&129|0)==128){do{if(g<<24>>24==-124){aIv(11629664,0,512);a[11630189]=0;b[(c[290366]|0)+112>>1]=255;b[(c[290366]|0)+114>>1]=-1;b[5814832]=2;b[5814833]=1;i=0;j=11359328;k=11097184;l=11228256;while(1){b[j>>1]=b[k>>1]|0;b[j+2>>1]=b[l>>1]|0;m=i+1|0;if((m|0)<65536){i=m;j=j+4|0;k=k+2|0;l=l+2|0}else{break}}l=d[10441816]|0;k=l+32|0;j=l+36|0;if(k>>>0<j>>>0){i=k;do{c[1161464+(i*20|0)>>2]=(i<<16&196608)+11359328;aIv(1161468+(i*20|0)|0,0,16);c[744992+(i<<3)>>2]=0;c[744996+(i<<3)>>2]=0;i=i+1|0;}while((i|0)<(j|0))}aIv(957284,0,16);aIv(957304,0,16);aIv(957324,0,16);aIv(957344,0,16);c[239341]=166;c[239342]=58;c[239343]=164;c[239344]=224;c[239346]=166;c[239347]=58;c[239348]=164;c[239349]=224;j=l+2|0;if(j>>>0<k>>>0){i=j;do{c[1161464+(i*20|0)>>2]=10572896;c[1161464+((i+1|0)*20|0)>>2]=10638432;i=i+4|0;}while((i|0)<(k|0))}b[5814836]=-1;b[5814837]=-1;b[5814859]=256;b[5814864]=15;aIv(11629730,-1|0,10);a[11629670]=1;aIv(11630176,0,13);aIv(1166584,0,12);aIv(962240,0,12);c[2994359]=0;c[2994360]=0;c[2994362]=0;c[2994363]=0;a[11977464]=(c[2994361]|0)!=0?9:0;c[2994365]=1024;b[5989539]=0;b[5989538]=0;a[11629668]=0;a[11958668]=-1;a[11958669]=0;a[11958678]=0;a[11958679]=0;a[11958688]=0;a[11958689]=0;a[11958690]=0;a[11958691]=-128;a[11958680]=0;a[11958681]=0;a[11958682]=0;a[11958683]=1;c[2989673]=0;c[2989674]=0;c[2989671]=0;c[2907548]=0;aIv(11979080,0,65676);c[2994803]=11979219;a[11979093]=-1;a[11979109]=-1;a[11979125]=-1;a[11979141]=-1;a[11979157]=-1;a[11979173]=-1;a[11979189]=-1;a[11979205]=-1;c[3011189]=0;k=c[3184684]|0;i=k|0;l=c[i+4>>2]|0;j=k+8|0;c[j>>2]=(c[i>>2]|0)>>>1|l<<31;c[j+4>>2]=l>>>1|0<<31;c[k+20>>2]=0;aIv(k+24|0,0,(c[k+16>>2]<<2)+72|0);k=c[3184678]|0;l=k|0;j=c[l+4>>2]|0;i=k+8|0;c[i>>2]=(c[l>>2]|0)>>>1|j<<31;c[i+4>>2]=j>>>1|0<<31;c[k+20>>2]=0;aIv(k+24|0,0,(c[k+16>>2]<<2)+72|0);c[240563]=0;c[240597]=0;c[240588]=0;c[240595]=1792;c[240596]=0;c[962328+(c[240589]<<2)>>2]=c[240580];c[240589]=4;c[240580]=c[240586];c[240581]=4;k=c[239280]|0;c[240580]=e[k+2>>1]|e[k>>1]<<16;c[240581]=8;c[240581]=e[k+6>>1]|e[k+4>>1]<<16;c[240563]=(c[240563]|0)+160;c[240597]=c[240597]|2}else{if((b[6236743]|0)!=0){k=c[3118360]|0;j=0;do{c[1161464+(j*20|0)>>2]=1987672+(j<<16&k);j=j+1|0;}while((j|0)<64)}j=c[234362]|0;if((j|0)!=0){k=j+2048|0;aIy(k|0,1989720,129024)|0;c[234368]=j+262144;c[1087031]=0;c[j+263168>>2]=-65536;b[j+263194>>1]=1024;b[j+263190>>1]=0;b[j+263186>>1]=0}j=d[12474173]|0;if((j|0)==1){if((a[1717144]|0)==0){break}k=e[858576]|0;if((k&32|0)!=0){b[1987672+(c[429315]|0)>>1]=b[858613]|0}if((k&16|0)!=0){b[1987672+(c[429314]|0)>>1]=b[858612]|0}if((k&8|0)!=0){b[1987672+(c[429313]|0)>>1]=b[858611]|0}if((k&4|0)!=0){b[1987672+(c[429312]|0)>>1]=b[858610]|0}if((k&2|0)!=0){b[1987672+(c[429311]|0)>>1]=b[858609]|0}if((k&1|0)!=0){b[1987672+(c[429310]|0)>>1]=b[858608]|0}aIv(1717152,0,112);c[290366]=c[429287];c[290369]=298;c[290370]=114;c[290368]=0;break}else if((j|0)==3){if((a[12473444]&8)==0){break}k=c[3118360]|0;c[290606]=1987672+(k&3145728);c[290611]=1987672+(k&3211264);c[290616]=1987672+(k&3276800);c[290621]=1987672+(k&3342336);c[290626]=1987672+(k&3407872);c[290631]=1987672+(k&3473408);c[290636]=1987672+(k&3538944);c[290641]=1987672+(k&3604480);c[290646]=1987672+(k&3670016);c[290651]=1987672+(k&3735552);c[290656]=1987672+(k&3801088);c[290661]=1987672+(k&3866624);c[290666]=1987672+(k&3932160);c[290671]=1987672+(k&3997696);c[290676]=1987672+(k&4063232);c[290681]=1987672+(k&4128768);break}else if((j|0)==2){if((a[14317872]|0)==0){break}aIv(14317928,0,16);aIv(14317884,0,42);c[290366]=c[3579469];aIv(c[3579470]|0,-1|0,65536);break}else{break}}}while(0);c[291167]=100;c[291168]=92;c[291169]=278;c[291170]=84;a[736792]=0;c[186760]=0;do{if(!(g<<24>>24!=-128|(a[12474172]&1)==0)){c[222056]=0;c[291327]=198;c[291328]=50;c[291329]=178;c[291330]=166;c[186632]=96;c[186633]=54;c[291367]=198;c[291368]=50;c[291369]=178;c[291370]=166;c[186648]=96;c[186649]=54;c[291407]=198;c[291408]=50;c[291409]=178;c[291410]=166;c[186664]=96;c[186665]=54;c[291447]=198;c[291448]=50;c[291449]=178;c[291450]=166;c[186680]=96;c[186681]=54;if((a[937440]|0)>=0){break}c[3118358]=c[290366];c[290366]=12736656}}while(0);c[291683]=0;c[291687]=1;c[291674]=0;c[291681]=1792;c[291682]=0;a[670072]=0;c[1166672+(c[291675]<<2)>>2]=c[291666];c[291675]=4;c[291666]=c[291672];c[291667]=4;j=c[290366]|0;c[291666]=e[j+2>>1]|e[j>>1]<<16;c[291667]=8;c[291667]=e[j+6>>1]|e[j+4>>1]<<16;c[291687]=0;c[291649]=(c[291649]|0)+280}else{if(g<<24>>24==17){n=9151}else{if((h&32|0)!=0&(a[9808]|0)==0){n=9151}}if((n|0)==9151){aIv(756920,-16|0,65536)}a[13787384]=0;a[13787385]=0;a[13787386]=1;a[13787387]=2;j=a[12474460]|0;switch(j&255|0){case 16:case 17:{a[12474456]=0;a[12474457]=0;a[12474458]=1;a[12474459]=2;break};case 32:case 33:case 34:{c[3118614]=0;break};default:{a[12474456]=0;a[12474457]=0;a[12474458]=1;a[12474459]=0}}k=a[13787389]|0;do{if((k&255)>1){c[235940]=6181976;c[235938]=13787384;a[943744]=a[13787388]|0;a[943736]=k}else{c[235940]=1987672;c[235938]=12474456;a[943744]=j;a[943736]=a[12474461]|0;if((g&32)==0){break}a[756920]=-88}}while(0);a[1692198]=k<<24>>24!=0?-32:-88;ni();if((a[13787389]|0)==1){c[186834]=6181976}c[291683]=c[291683]|2}b[7159324]=0;a[14318710]=0;aIv(14318700,0,7);b[7159340]=c[3579662]&65535;k=g<<24>>24==-127;do{if(k){b[7159334]=-8191;b[7159326]=-8193;a[14318700]=4;o=a[9808]|0;n=9172}else{do{if((g&32)!=0){if((a[12474172]&1)!=0){if((a[937440]&32)!=0){break}}b[7159326]=-8193}}while(0);j=a[9808]|0;if((g&-127)<<24>>24!=-128){o=j;n=9172;break}i=a[12474172]&1|j;a[1692184]=i;aIv(1692185,0,6);a[1692191]=-1;a[1692192]=0;a[1692193]=0;a[1692194]=-1;a[1692195]=0;a[1692196]=0;a[1692197]=-5;a[1692198]=0;a[1692199]=0;if(g<<24>>24==-124){break}a[1692184]=i|32}}while(0);if((n|0)==9172){a[1692184]=(o&255)>>>1|-128;a[1692185]=0;a[1692186]=-1;a[1692187]=0;a[1692188]=-1;a[1692189]=0;a[1692190]=-1;a[1692197]=k?16:48;a[1692198]=0;a[1692199]=-1}k=((c[3446840]|0)/2|0)&65535;o=((c[3446841]|0)/2|0)&65535;n=0;do{switch(d[1692288+n|0]|0){case 5:{b[1692240+(n<<2)>>1]=128;a[968024+(n>>2)|0]=64;break};case 6:{b[1692240+(n<<2)>>1]=128;b[1692242+(n<<2)>>1]=128;i=n>>2;a[937520+(i<<1)|0]=64;a[937521+(i<<1)|0]=0;break};case 4:{b[1692240+(n<<2)>>1]=k;b[1692242+(n<<2)>>1]=o;a[1561104]=64;a[1561096]=4;break};case 3:{b[1692240+(n<<2)>>1]=0;b[1692242+(n<<2)>>1]=0;a[969344]=96;a[969336]=0;a[11160]=0;a[969328]=n&255;break};case 8:{b[846120]=128;b[846121]=128;a[937416]=1;a[1496]=1;break};case 10:{i=n>>2;a[14317864+(i<<1)|0]=64;a[14317865+(i<<1)|0]=0;break};case 9:{b[1692240+(n<<2)>>1]=128;b[1692242+(n<<2)>>1]=128;b[1692240+(n+1<<2)>>1]=128;i=n>>2;a[756912+(i*3|0)|0]=64;a[756913+(i*3|0)|0]=0;a[756914+(i*3|0)|0]=0;break};case 2:case 0:case 1:{a[1717280+(n*3|0)|0]=64;a[1717281+(n*3|0)|0]=0;a[1717282+(n*3|0)|0]=0;a[968032]=0;break};default:{}}n=n+1|0;}while((n|0)<8);if((a[1692304]|0)==11){a[937384]=96;a[937385]=0}if((a[1692296]|0)==11){a[937398]=96;a[937399]=0}n=c[3446834]|0;aIv(n|0,0,ab(c[3446836]|0,c[3446837]|0)|0);aIv(1560072,0,1024);aIv(967496,0,512);aIv(13787392,0,524288);a[968248]=0;b[468756]=0;a[937504]=0;aIv(956096,0,1024);aIv(822600,0,65536);aIv(12474e3,0,128);aIv(822464,0,128);aIv(962712,0,32);b[7158924]=0;b[7158920]=0;a[12474208]=0;a[968008]=0;a[12736648]=0;a[1692344]=0;a[888136]=0;b[6236980]=0;b[6236988]=0;a[12473968]=0;c[3118496]=0;c[3118498]=0;a[968080]=0;a[1692312]=0;a[1692200]=0;c[496910]=0;c[496914]=0;c[3118616]=-1;b[484136]=0;b[484132]=0;b[484128]=0;b[478036]=0;b[846168]=0;b[411296]=0;a[1692328]=0;a[964272]=6;a[964288]=15;b[482140]=255;b[478040]=-512;b[478044]=511;b[7158912]=0;aIv(14315776,0,2048);aIv(14311680,0,4096);c[423080]=65536;c[423088]=680856;n=a[888176]|0;o=n&255;b[444100]=b[296+(o<<1)>>1]|0;b[444104]=(b[780032]|0)-1&65535;a[12474216]=0;a[12474217]=16;a[12474218]=1;a[12474221]=0;c[496912]=214;if(g<<24>>24<0){p=n&255|512}else{p=0}b[468728]=p;c[3446840]=256;c[3446841]=192;c[3446842]=256;c[3446843]=192;p=a[12474175]|0;n=p&255;k=n&2;do{if(g<<24>>24!=64|(a[12474177]|0)!=0){c[3446838]=k*7|0;q=ab(o+1|0,-(n&1)&24)|0}else{c[3446838]=(k|0)!=0?14:-48;if((p&1)==0){q=-24;break}q=(o*24|0)+24|0}}while(0);c[3446839]=q;c[222054]=96;q=g<<24>>24>-1;c[240676]=q?212:206;c[240674]=q?136:98;c[242004]=q?186:134;c[222046]=26;c[222048]=4;switch(h|0){case 64:{c[222040]=200;c[222042]=6;break};case 17:case 32:case 33:case 65:{c[222040]=100;c[222042]=6;break};case 16:{c[222040]=114;c[222042]=6;break};default:{c[222040]=104;c[222042]=6}}L12727:do{if(g<<24>>24==16){jT(1,128,0);a[962722]=-1;r=0}else{do{if((g&32)!=0){if((a[12474172]&1)!=0){if((a[937440]&32)!=0){break}}jT(0,54,0);jT(1,128,0);h=a[962713]|0;a[962714]=-1;b[484136]=-8192;q=b[444104]|0;o=q&65535;p=c[3446841]|0;do{if((o|0)<(p|0)){if((h&64)==0){s=h;t=q;u=p;break}kv(o);s=a[962713]|0;t=b[444104]|0;u=c[3446841]|0}else{s=h;t=q;u=p}}while(0);a[962715]=-1;b[484128]=(a[962724]&1)==0?-2048:-4096;p=t&65535;do{if((p|0)<(u|0)){if((s&64)==0){v=s;w=t;x=u;break}kv(p);v=a[962713]|0;w=b[444104]|0;x=c[3446841]|0}else{v=s;w=t;x=u}}while(0);a[962716]=-1;b[484132]=-8192;p=w&65535;do{if((p|0)<(x|0)){if((v&64)==0){break}kv(p)}}while(0);a[962717]=-1;b[478036]=b[478040]&-512;a[962718]=-1;a[962722]=-1;c[240676]=206;c[240674]=98;c[242004]=134;r=0;break L12727}}while(0);if(!((g<<24>>24|0)==(-128|0)|(g<<24>>24|0)==(-124|0))){r=0;break}if((a[12474172]&1)==0|(a[937440]|0)<0){r=0;break}jT(0,4,0);jT(1,4,0);a[962722]=-1;jT(12,129,0);if((a[962713]&4)==0){r=0;break}a[962727]=2;r=0}}while(0);do{j7(r,0);r=r+1|0;}while((r|0)<32);r=a[937424]|0;g=r&255;if((g|0)==16){y=b[864+((a[962719]&15)<<1)>>1]|0}else if((g|0)==64){y=0}else{do{if((a[962712]&4)==0){if((g&128|0)!=0|r<<24>>24==65){z=0;break}z=a[896+(a[962719]&15)|0]&63}else{z=0}}while(0);y=b[964296+(z<<1)>>1]|0}z=(a[962712]&4)==0;b[483812]=y;if(z){b[483764]=y;b[483796]=y;b[483892]=y;b[483924]=y;A=c[3579686]|0;fG[A&16383]();c[3645554]=1;c[3645555]=15;c[3645565]=0;c[3645569]=1;c[3645573]=0;c[3645574]=0;c[3645581]=0;c[3645582]=0;c[3645556]=1;c[3645557]=15;c[3645566]=0;c[3645570]=1;c[3645575]=0;c[3645576]=0;c[3645583]=0;c[3645584]=0;c[3645558]=1;c[3645559]=15;c[3645567]=0;c[3645571]=1;c[3645577]=0;c[3645578]=0;c[3645585]=0;c[3645586]=0;c[3645560]=1;c[3645561]=15;c[3645568]=0;c[3645572]=1;c[3645579]=0;c[3645580]=0;c[3645587]=0;c[3645588]=0;c[3645562]=0;c[3645563]=32768;c[3645564]=16;c[3645589]=0;c[494740]=0;c[494742]=0;c[494738]=1979e3;c[494748]=0;c[494744]=0;kx();return}else{b[483844]=y;b[483940]=y;b[483972]=y;A=c[3579686]|0;fG[A&16383]();c[3645554]=1;c[3645555]=15;c[3645565]=0;c[3645569]=1;c[3645573]=0;c[3645574]=0;c[3645581]=0;c[3645582]=0;c[3645556]=1;c[3645557]=15;c[3645566]=0;c[3645570]=1;c[3645575]=0;c[3645576]=0;c[3645583]=0;c[3645584]=0;c[3645558]=1;c[3645559]=15;c[3645567]=0;c[3645571]=1;c[3645577]=0;c[3645578]=0;c[3645585]=0;c[3645586]=0;c[3645560]=1;c[3645561]=15;c[3645568]=0;c[3645572]=1;c[3645579]=0;c[3645580]=0;c[3645587]=0;c[3645588]=0;c[3645562]=0;c[3645563]=32768;c[3645564]=16;c[3645589]=0;c[494740]=0;c[494742]=0;c[494738]=1979e3;c[494748]=0;c[494744]=0;kx();return}}function kz(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=d[962722]|0;c[290364]=0;b[444104]=(b[780032]|0)-1&65535;c[496910]=0;c[496914]=0;lO();g=c[3446844]|0;h=a[1692200]|0;if((g&2|0)==0){i=h}else{j=a[962724]|0;k=(j&255)>>>1&1;a[1692200]=k;do{if(h<<24>>24==k<<24>>24){c[3446844]=g&-3;l=a[962713]|0}else{m=(j&6)==6;a[1692312]=m&1;a[968080]=1;c[3446844]=5;n=a[962713]|0;if((n&4)==0){l=n;break}o=(a[962723]&4)!=0;if(m){c[240676]=o?252:146;c[240674]=(j&8)!=0?30:32;l=n;break}else{c[240676]=o?198:106;c[240674]=(j&8)!=0?86:90;l=n;break}}}while(0);g=l&255;if((g&4|0)==0){c[3446841]=192;p=ab(-(a[12474175]&1)&24,(d[888176]|0)+1|0)|0}else{l=g<<1&16|224;c[3446841]=l;p=240-l+((d[888176]|0)*48|0)>>1&-(a[12474175]&1)}c[3446839]=p;c[3446840]=(j&255)<<6&64|256;i=k}k=b[468728]&-795|512;b[468728]=k;j=a[968080]^1;a[968080]=j;if(i<<24>>24!=0){b[468728]=(j&255)<<4|k}if((c[3118496]|0)!=0){jW(0)}if((c[3446839]|0)>0){k=e[444104]|0;j=c[3446838]|0;aIv(1560072+(32-j)|0,64,(c[3446840]|0)+(j<<1)|0);kw(k)}if((a[962713]&64)!=0){fi[c[242004]&255](-1)}IE(3420);if((a[736792]|0)==1){oy(3420)}else{c[3579678]=3420}if((c[234362]|0)!=0){nO()}k=(c[290364]|0)+3420|0;c[290364]=k;j=0;i=f;f=k;while(1){b[444104]=j&65535;lO();k=i-1|0;do{if((k|0)<0){p=d[962722]|0;a[1692344]=16;if((a[962712]&16)==0){q=p;break}c[291682]=c[291682]|1024;q=p}else{q=k}}while(0);if((c[3118496]|0)!=0){jW(f)}kv(j);IE((c[290364]|0)+3420|0);k=(c[290364]|0)+3420|0;if((a[736792]|0)==1){oy(k)}else{c[3579678]=k}if((c[234362]|0)!=0){nO()}r=(c[290364]|0)+3420|0;c[290364]=r;s=j+1|0;t=c[3446841]|0;if((s|0)<(t|0)){j=s;i=q;f=r}else{break}}b[444104]=s&65535;b[468728]=b[468728]|8;f=c[3446839]|0;i=(e[780032]|0)-f|0;k=f+t|0;f=c[3446840]|0;if(!((f|0)==(c[3446842]|0)&(t|0)==(c[3446843]|0))){c[3446842]=f;c[3446843]=t;c[3446844]=c[3446844]|1}lO();do{if((q-1|0)<0){a[1692344]=16;if((a[962712]&16)==0){break}c[291682]=c[291682]|1024}}while(0);if((c[3118496]|0)!=0){jW(r)}if((s|0)<(k|0)){r=c[3446838]|0;aIv(1560072+(32-r)|0,64,(c[3446840]|0)+(r<<1)|0);kw(s)}aIn();IE((c[290364]|0)+588|0);b[468728]=b[468728]|128;IE((c[290364]|0)+788|0);s=(c[290364]|0)+788|0;if((a[736792]|0)==1){oy(s)}else{c[3579678]=s}a[888136]=32;if((a[962713]&32)!=0){c[291682]=1536}a[14318709]=1;IE((c[290364]|0)+3420|0);s=(c[290364]|0)+3420|0;if((a[736792]|0)==1){oy(s)}else{c[3579678]=s}if((c[234362]|0)!=0){nO()}s=(c[290364]|0)+3420|0;c[290364]=s;r=j+2|0;j=1;q=s;while(1){b[444104]=r&65535;lO();if(!((r|0)>=(k|0)&(r|0)<(i|0))){s=c[3446838]|0;aIv(1560072+(32-s)|0,64,(c[3446840]|0)+(s<<1)|0);kw(r)}if((j|0)==0){u=q}else{IE(q+788|0);s=c[290364]|0;t=s+788|0;if((a[736792]|0)==1){oy(t);v=c[290364]|0}else{c[3579678]=t;v=s}a[14318709]=0;u=v}IE(u+3420|0);s=(c[290364]|0)+3420|0;if((a[736792]|0)==1){oy(s)}else{c[3579678]=s}if((c[234362]|0)!=0){nO()}w=(c[290364]|0)+3420|0;c[290364]=w;s=r+1|0;if((s|0)<((e[780032]|0)-1|0)){r=s;j=0;q=w}else{break}}c[291649]=(c[291649]|0)-w;c[3579678]=(c[3579678]|0)-w;return}function kA(a,b){a=a|0;b=b|0;return}function kB(){return 127}function kC(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d[962722]|0;c[290364]=0;b[444104]=(b[780032]|0)-1&65535;c[496910]=0;c[496914]=0;lO();g=c[3446844]|0;do{if((g&2|0)==0){h=a[937424]|0;i=9325}else{c[3446844]=g&-3;j=a[937424]|0;if(j<<24>>24>=0){k=a[962713]&24|a[962712]&6;if((k|0)==14){c[3446841]=240;l=240}else if((k|0)==22){c[3446841]=224;l=224}else{c[3446841]=192;l=192}if((a[12474175]&1)!=0){c[3446839]=240-l+((d[888176]|0)*48|0)>>1;h=j;i=9325;break}if(j<<24>>24!=64|(a[12474177]|0)!=0){c[3446839]=0;h=j;i=9325;break}else{c[3446839]=(144-l|0)/2|0;i=9335;break}}k=a[1692200]|0;m=a[962724]|0;n=(m&255)>>>1&1;a[1692200]=n;do{if(k<<24>>24==n<<24>>24){o=a[962713]|0}else{p=(m&6)==6;a[1692312]=p&1;a[968080]=1;c[3446844]=5;q=a[962713]|0;if((q&4)==0){o=q;break}r=(a[962723]&4)!=0;if(p){c[240676]=r?252:146;c[240674]=32;o=q;break}else{c[240676]=r?198:106;c[240674]=90;o=q;break}}}while(0);n=o&255;if((n&4|0)==0){c[3446841]=192;s=ab(-(a[12474175]&1)&24,(d[888176]|0)+1|0)|0}else{k=n<<1&16|224;c[3446841]=k;s=240-k+((d[888176]|0)*48|0)>>1&-(a[12474175]&1)}c[3446839]=s;c[3446840]=(m&255)<<6&64|256;h=j;i=9325}}while(0);do{if((i|0)==9325){if((h<<24>>24|0)==64|(h<<24>>24|0)==16){i=9335;break}do{if((b[846136]&128)==0){a[11096]=0;t=h}else{if(a[11096]|0){t=h;break}a[11096]=1;if((a[14318707]|0)==0){if((a[14318704]|0)==0){u=a[14318648]|0}else{a[14318704]=0;s=(b[7159324]|0)+1&65535;b[7159324]=s;u=s&255}a[14318702]=0;b[7159326]=(b[7159326]|0)-2&65535;s=c[3579663]|0;fj[c[186764]&511](s,u);fj[c[186764]&511](s+1&65535,a[14318649]|0);c[3579662]=102;b[7159340]=102;c[3579678]=(c[3579678]|0)+165;v=a[937424]|0}else{v=h}a[14318707]=0;t=v}}while(0);j=a[12473444]&a[765107];if(t<<24>>24>=0){w=j;i=9342;break}m=b[468728]&229;b[468728]=m;s=a[968080]^1;a[968080]=s;if((a[1692200]|0)!=0){b[468728]=(s&255)<<4|m}if((c[3118496]|0)==0){x=t}else{jW(0);x=a[937424]|0}if(x<<24>>24>-1){w=j;i=9342}else{y=j}}}while(0);if((i|0)==9335){w=a[12473444]&a[765107];i=9342}do{if((i|0)==9342){if((a[962713]&64)==0){y=w;break}fi[c[240674]&255](c[3446840]|0);y=w}}while(0);if((c[3446839]|0)>0){w=e[444104]|0;i=c[3446838]|0;aIv(1560072+(32-i)|0,64,(c[3446840]|0)+(i<<1)|0);kw(w)}if((a[962713]&64)!=0|(a[937424]|0)>-1){fi[c[242004]&255](-1)}oy(3420);w=(c[290364]|0)+3420|0;c[290364]=w;b[411296]=d[962721]|0;i=(y&1)==0;y=0;x=f;f=w;while(1){if((c[3118496]|0)!=0){jW(f)}do{if((e[444104]|0)!=(y|0)){b[444104]=y&65535;if(!i){break}kv(y)}}while(0);lO();w=x-1|0;do{if((w|0)<0){t=d[962722]|0;a[1692344]=16;if((a[962712]&16)==0){z=t;break}v=c[3579678]|0;if(((v>>>0)%3420|0|0)==0){oy(v+1|0)}a[14318709]=1;z=t}else{z=w}}while(0);oy((c[290364]|0)+3420|0);w=(c[290364]|0)+3420|0;c[290364]=w;A=y+1|0;B=c[3446841]|0;if((A|0)<(B|0)){y=A;x=z;f=w}else{break}}b[444104]=A&65535;if((a[937424]|0)<0){b[468728]=b[468728]|8}f=c[3446839]|0;x=(e[780032]|0)-f|0;i=f+B|0;f=c[3446840]|0;if(!((f|0)==(c[3446842]|0)&(B|0)==(c[3446843]|0))){c[3446842]=f;c[3446843]=B;c[3446844]=c[3446844]|1}lO();do{if((z-1|0)<0){a[1692344]=16;if((a[962712]&16)==0){break}B=c[3579678]|0;if(((B>>>0)%3420|0|0)==0){oy(B+1|0)}a[14318709]=1}}while(0);if((c[3118496]|0)!=0){jW(c[290364]|0)}if((A|0)<(i|0)){z=c[3446838]|0;aIv(1560072+(32-z)|0,64,(c[3446840]|0)+(z<<1)|0);kw(A)}aIn();oy((c[290364]|0)+3420|0);do{if((e[444104]|0)==(A|0)){b[468728]=b[468728]|128;a[888136]=32;if((a[962713]&32)==0){break}a[14318709]=1}}while(0);c[290364]=(c[290364]|0)+3420;A=y+2|0;do{b[444104]=A&65535;lO();do{if((a[937424]|0)>-1){if((A|0)<=((e[780032]|0)-16|0)){break}fi[c[240674]&255](c[3446840]|0);fi[c[242004]&255](A-(e[780032]|0)|0)}}while(0);if(!((A|0)>=(i|0)&(A|0)<(x|0))){y=c[3446838]|0;aIv(1560072+(32-y)|0,64,(c[3446840]|0)+(y<<1)|0);kw(A)}oy((c[290364]|0)+3420|0);C=(c[290364]|0)+3420|0;c[290364]=C;A=A+1|0;}while((A|0)<((e[780032]|0)-1|0));c[3579678]=(c[3579678]|0)-C;return}function kD(b,e,f){b=b|0;e=e|0;f=f|0;var g=0;if((b|0)==0){a[1692198]=e&255;nj((e^255)&255);return}if((a[9808]|0)>=0){a[1692199]=(e&90|5)&255;a[1692197]=(e<<4&16|e<<3&32)&255;return}fj[c[241062]&511](e<<1&96,a[1692199]<<5&96^96);fj[c[241064]&511](e>>>1&96,a[1692199]<<3&96^96);b=a[1692199]|0;if(b<<24>>24<0){g=9388}else{if((e&128|0)==0){g=9388}else{g=9390}}do{if((g|0)==9388){if((b&32)!=0){break}if((e&32|0)!=0){g=9390}}}while(0);if((g|0)==9390){c[423080]=d[(c[423088]|0)+((f>>>0)%3420|0)|0]|65536}a[1692199]=e&255;return}function kE(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=(fD[c[241063]&127]()|0)&255;f=(fD[c[241065]&127]()|0)&255;g=d[1692199]|0;if((b|0)==0){b=f<<6&192|e&63;if((g&1|0)!=0){h=b;return h|0}h=b&223|g<<1&32;return h|0}b=a[1692197]|0;i=f>>>2&15|e&64|f<<1&128|b&255;a[1692197]=b|16;if((g&8|0)==0){j=i&127|g&128}else{j=i}if((g&2|0)==0){k=j&-65|g<<1&64}else{k=j}if((g&4|0)!=0){h=k;return h|0}h=k&-9|g>>>3&8;return h|0}function kF(a,b){a=a|0;b=b|0;return}function kG(a,b){a=a|0;b=b|0;return}function kH(b,d){b=b|0;d=d|0;if((a[12474170]|0)!=0){return}c[291683]=c[291683]|2;c[291649]=c[291650];return}function kI(b,d){b=b|0;d=d|0;if((a[12474170]|0)!=0){return}c[291683]=c[291683]|2;c[291649]=c[291650];return}function kJ(a){a=a|0;var b=0;b=c[291667]|0;return d[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+((b&65535|a&1)^1)|0]|0|0}function kK(a){a=a|0;a=c[291667]|0;return e[(c[1161464+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0|0}function kL(b){b=b|0;var e=0;if((a[12474170]|0)==0){c[291683]=c[291683]|2;c[291649]=c[291650]}e=c[291667]|0;return d[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+((e&65535|b&1)^1)|0]|0}function kM(b){b=b|0;if((a[12474170]|0)==0){c[291683]=c[291683]|2;c[291649]=c[291650]}b=c[291667]|0;return e[(c[1161464+((b>>>16&255)*20|0)>>2]|0)+(b&65535)>>1]|0}function kN(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;aIv(962496,0,188);if((a[937424]|0)<0){g=e+256|0;aIy(962496,g|0,16)|0;g=e+272|0;aIy(962514,g|0,16)|0;a[962532]=a[e+288|0]|0;g=1;h=1;while(1){j=a[e+(g+288)|0]|0;if((a[962532+(h-1)|0]|0)==32&j<<24>>24==32){k=h}else{a[962532+h|0]=j;k=h+1|0}j=g+1|0;if((j|0)<48){g=j;h=k}else{break}}a[962532+k|0]=0;a[962582]=a[e+336|0]|0;k=1;h=1;while(1){g=a[e+(k+336)|0]|0;if((a[962582+(h-1)|0]|0)==32&g<<24>>24==32){l=h}else{a[962582+h|0]=g;l=h+1|0}g=k+1|0;if((g|0)<48){k=g;h=l}else{break}}a[962582+l|0]=0;l=e+384|0;b[481316]=(w=d[l]|d[l+1|0]<<8,w<<16>>16);l=e+386|0;aIy(962636,l|0,12)|0;l=e+398|0;h=(w=d[l]|d[l+1|0]<<8,w<<16>>16);b[481325]=h;l=e+416|0;c[240664]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e+420|0;c[240665]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e+496|0;aIy(962664,l|0,16)|0;b[481325]=b5(h|0)|0;h=(c[3118359]|0)-512|0;if((h|0)>0){l=0;k=0;while(1){g=(d[l+1988184|0]<<8|d[(l|1)+1988184|0])+k&65535;j=l+2|0;if((j|0)<(h|0)){l=j;k=g}else{m=g;break}}}else{m=0}b[481326]=m;b[481341]=0;m=0;k=0;while(1){l=e+(m+400)|0;h=0;g=k;while(1){if((a[l]|0)==(a[10856+(h<<4)|0]|0)){j=(1<<h|g&65535)&65535;b[481341]=j;n=j}else{n=g}j=h+1|0;if((j|0)<14){h=j;g=n}else{break}}g=m+1|0;if((g|0)<14){m=g;k=n}else{break}}i=f;return}do{if((aID(e+8176|0,692024,8)|0)==0){o=8176}else{if((aID(e+16368|0,692024,8)|0)==0){o=16368;break}n=(aID(e+32752|0,692024,8)|0)==0;if(n){o=n?32752:0;break}i=f;return}}while(0);n=o&65535;b[481325]=d[e+(n|11)|0]<<8|a[e+(n|10)|0];o=e+(n|14)|0;ci(962636,726792,(k=i,i=i+8|0,c[k>>2]=a[o]>>4,k)|0)|0;i=k;ci(962638,714488,(k=i,i=i+8|0,c[k>>2]=a[e+(n|13)|0]|0,k)|0)|0;i=k;ci(962640,714488,(k=i,i=i+8|0,c[k>>2]=a[e+(n|12)|0]|0,k)|0)|0;i=k;ci(962642,707136,(k=i,i=i+8|0,c[k>>2]=a[o]&15,k)|0)|0;i=k;o=e+(n|15)|0;n=a[o]>>4;switch(n|0){case 4:{aIy(962664,699672,11)|0;break};case 6:{aIy(962664,695640,10)|0;break};case 5:{aIy(962664,697552,9)|0;break};case 3:{aIy(962664,702696,10)|0;break};case 7:{aIy(962664,693544,17)|0;break};default:{ci(962664,691384,(k=i,i=i+8|0,c[k>>2]=n,k)|0)|0;i=k}}c[240664]=0;switch(a[o]&15|0){case 10:{c[240665]=8191;i=f;return};case 15:{c[240665]=131071;i=f;return};case 1:{c[240665]=524287;i=f;return};case 2:{c[240665]=1048575;i=f;return};case 13:{c[240665]=49151;i=f;return};case 12:{c[240665]=32767;i=f;return};case 14:{c[240665]=65535;i=f;return};case 0:{c[240665]=262143;i=f;return};case 11:{c[240665]=16383;i=f;return};default:{i=f;return}}}function kO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;switch(d[937424]|0|0){case 32:case 33:{b=a[937440]|0;e=b&255;do{if((e&32|0)!=0){if((e&12|0)==((d[9808]|0)>>>4|0)){f=-1}else{break}return f|0}}while(0);a[937440]=b&-97;if((c[3118359]|0)>>>0>=4194305){f=0;return f|0}b=d[9808]|0;if((b|0)==128){g=aH6(14582880,6181976,4194304,0)|0}else if((b|0)==192){g=aH6(14583392,6181976,4194304,0)|0}else{g=aH6(14583136,6181976,4194304,0)|0}if((g|0)<=0){f=g;return f|0}a[937440]=a[937440]&-48|(d[9808]|0)>>>4|32;f=g;return f|0};case 132:{g=d[937440]|0;do{if((g&16|0)==0){h=a[9808]|0}else{b=a[9808]|0;if((g&12|0)==((b&255)>>>4|0)){f=-1}else{h=b;break}return f|0}}while(0);g=h&255;if((g|0)==128){i=aH6(14585968,10441824,131072,0)|0}else if((g|0)==192){i=aH6(14586480,10441824,131072,0)|0}else{i=aH6(14586224,10441824,131072,0)|0}if((i|0)>0){j=0}else{f=i;return f|0}do{g=j+10441824|0;h=a[g]|0;b=(j|1)+10441824|0;a[g]=a[b]|0;a[b]=h;j=j+2|0;}while((j|0)<(i|0));a[937440]=a[937440]&-32|(d[9808]|0)>>>4|16;f=i;return f|0};case 64:case 65:{i=a[937440]|0;if((i&64)!=0){f=-1;return f|0}a[937440]=i&-97;if((c[3118359]|0)>>>0>=4194305){f=0;return f|0}i=aH6(14583912,6181976,1048576,0)|0;if((i|0)<=0){f=i;return f|0}a[937440]=a[937440]|64;f=i;return f|0};default:{f=0;return f|0}}return 0}function kP(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b>>>13&3;if((e|0)==2){f=c[291649]|0;g=c[494748]|0;if(g>>>0<f>>>0){h=c[494746]|0;i=((f-1-g+h|0)>>>0)/(h>>>0)|0;fj[c[3579684]&511](c[494738]|0,i);c[494738]=(c[494738]|0)+(i<<1<<2);h=ab(c[494746]|0,i)|0;c[494748]=(c[494748]|0)+h}j=d[749762]|0;return j|0}else if((e|0)==3){if((b&65280|0)!=32512){j=255;return j|0}if((a[12474170]|0)==0){c[291683]=c[291683]|2;c[291649]=c[291650]}e=c[291667]|0;j=d[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+((e&65535|b&1)^1)|0]|0;return j|0}else{j=d[736800+(b&8191)|0]|0;return j|0}return 0}function kQ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b>>>13&3;if((e|0)==2){f=c[291649]|0;g=c[494748]|0;if(g>>>0<f>>>0){h=c[494746]|0;i=((f-1-g+h|0)>>>0)/(h>>>0)|0;fj[c[3579684]&511](c[494738]|0,i);c[494738]=(c[494738]|0)+(i<<1<<2);h=ab(c[494746]|0,i)|0;c[494748]=(c[494748]|0)+h}j=d[749762]|0;k=j<<8;l=k|j;return l|0}else if((e|0)==3){if((b&65280|0)!=32512){j=255;k=j<<8;l=k|j;return l|0}if((a[12474170]|0)==0){c[291683]=c[291683]|2;c[291649]=c[291650]}e=c[291667]|0;j=d[(c[1161464+((e>>>16&255)*20|0)>>2]|0)+((e&65535|b&1)^1)|0]|0;k=j<<8;l=k|j;return l|0}else{j=d[736800+(b&8191)|0]|0;k=j<<8;l=k|j;return l|0}return 0}function kR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>>13&3;if((e|0)==3){f=b>>>8&127;if((f|0)==96){c[186760]=((c[186760]|0)>>>1|d<<23)&16744448;return}else if((f|0)==127){if((a[12474170]|0)!=0){return}c[291683]=c[291683]|2;c[291649]=c[291650];return}else{return}}else if((e|0)==2){e=c[291649]|0;f=b&3;do{if((b&1|0)!=0){g=c[494748]|0;if(g>>>0>=e>>>0){break}h=c[494746]|0;i=((e-1-g+h|0)>>>0)/(h>>>0)|0;fj[c[3579684]&511](c[494738]|0,i);c[494738]=(c[494738]|0)+(i<<1<<2);h=ab(c[494746]|0,i)|0;c[494748]=(c[494748]|0)+h}}while(0);fj[c[3579682]&511](f,d);return}else{a[736800+(b&8191)|0]=d&255;c[291649]=(c[291649]|0)+8;return}}function kS(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=d>>>8;d=b>>>13&3;if((d|0)==3){f=b>>>8&127;if((f|0)==96){c[186760]=((c[186760]|0)>>>1|e<<23)&16744448;return}else if((f|0)==127){if((a[12474170]|0)!=0){return}c[291683]=c[291683]|2;c[291649]=c[291650];return}else{return}}else if((d|0)==2){d=c[291649]|0;f=b&3;do{if((b&1|0)!=0){g=c[494748]|0;if(g>>>0>=d>>>0){break}h=c[494746]|0;i=((d-1-g+h|0)>>>0)/(h>>>0)|0;fj[c[3579684]&511](c[494738]|0,i);c[494738]=(c[494738]|0)+(i<<1<<2);h=ab(c[494746]|0,i)|0;c[494748]=(c[494748]|0)+h}}while(0);fj[c[3579682]&511](f,e);return}else{a[736800+(b&8191)|0]=e&255;c[291649]=(c[291649]|0)+8;return}}function kT(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;switch(b>>>8&255|0){case 48:{f=c[3118372]|0;if((f|0)==0){g=c[291667]|0;h=d[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+((g&65535|b&1)^1)|0]|0;return h|0}g=fl[f&255](b)|0;if((b&1|0)==0){h=g>>>8;return h|0}else{h=g&255;return h|0}break};case 65:{g=b&1;do{if((a[12474172]&1)==0){i=g}else{if((g|0)==0){i=0;break}if((a[937440]|0)<0){j=(c[290366]|0)==(c[3118358]|0)|0}else{j=1}f=c[291667]|0;h=a[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535^1)|0]&254|j;return h|0}}while(0);j=c[291667]|0;h=d[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+((j&65535|i)^1)|0]|0;return h|0};case 32:{do{if((a[937424]|0)==-124){i=b&63;if((i|0)==15){j=(((c[291649]|0)*3184|0)>>>0)/3420|0;do{if((c[240597]|0)==0&(c[240563]|0)>>>0<j>>>0){ahk();if((c[240597]|0)!=0){c[240563]=j;break}c[240564]=j;if((c[240563]|0)>>>0>=j>>>0){break}do{g=c[240581]|0;c[240581]=g+2;f=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;c[240587]=f;fG[c[11976+(f<<2)>>2]&16383]();f=(c[240563]|0)+(d[537288+(c[240587]|0)|0]|0)|0;c[240563]=f;}while(f>>>0<j>>>0)}}while(0);do{if((c[291648]|0)==32768){j=c[291649]|0;if(j>>>0>(c[291647]|0)>>>0){k=j;l=9613;break}j=c[291667]|0;if((j|0)!=(c[291646]|0)){break}c[291649]=c[291650];c[291683]=32768;f=c[291673]|0;g=j;do{g=g-2|0;c[291667]=g;}while((f|0)!=(e[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0))}else{c[291648]=32768;k=c[291649]|0;l=9613}}while(0);if((l|0)==9613){c[291647]=k+840;c[291646]=c[291667]}h=d[11629678]|0;return h|0}else if((i|0)==3){do{if((c[291648]|0)==8){g=c[291649]|0;if(g>>>0>(c[291647]|0)>>>0){m=g;l=9600;break}g=c[291667]|0;if((g|0)!=(c[291646]|0)){break}c[291649]=c[291650];c[291683]=8;f=c[291673]|0;j=g;do{j=j-2|0;c[291667]=j;}while((f|0)!=(e[(c[1161464+((j>>>16&255)*20|0)>>2]|0)+(j&65535)>>1]|0))}else{c[291648]=8;m=c[291649]|0;l=9600}}while(0);if((l|0)==9600){c[291647]=m+840;c[291646]=c[291667]}h=d[11629666]|0;return h|0}else{if(i>>>0>=48){break}L13277:do{if(i>>>0>31){j=c[291648]|0;f=1<<i-16;do{if((j|0)==(f|0)){g=c[291649]|0;if(g>>>0>(c[291647]|0)>>>0){n=g;break}g=c[291667]|0;if((g|0)!=(c[291646]|0)){break L13277}c[291649]=c[291650];c[291683]=j;o=c[291673]|0;p=g;while(1){p=p-2|0;c[291667]=p;if((o|0)==(e[(c[1161464+((p>>>16&255)*20|0)>>2]|0)+(p&65535)>>1]|0)){break L13277}}}else{c[291648]=f;n=c[291649]|0}}while(0);c[291647]=n+840;c[291646]=c[291667]}}while(0);f=11629664+(i>>>1<<1)|0;if((b&1|0)==0){h=d[f+1|0]|0;return h|0}else{h=d[f]|0;return h|0}}}}while(0);n=c[291667]|0;h=d[(c[1161464+((n>>>16&255)*20|0)>>2]|0)+((n&65535|b&1)^1)|0]|0;return h|0};case 0:{if((b&224|0)!=0){n=c[291667]|0;h=d[(c[1161464+((n>>>16&255)*20|0)>>2]|0)+((n&65535|b&1)^1)|0]|0;return h|0}n=b>>>1&15;m=n-1|0;if(m>>>0<3){l=d[n+1692187|0]|0;k=(fD[c[964252+(m<<3)>>2]&127]()|0)&255;h=d[1692184+n|0]&(l|128)|k&(l&127^-129);return h|0}else{h=d[1692184+n|0]|0;return h|0}break};case 16:case 18:case 19:case 64:case 68:case 80:{n=c[291667]|0;h=d[(c[1161464+((n>>>16&255)*20|0)>>2]|0)+((n&65535|b&1)^1)|0]|0;return h|0};case 17:{n=b&1;l=c[291667]|0;if((n|0)!=0){h=d[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+((l&65535|n)^1)|0]|0;return h|0}n=d[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535^1)|0]|0;if((a[736792]|0)==3){h=n&254;return h|0}else{h=n|1;return h|0}break};default:{if((a[12474170]|0)==0){c[291683]=c[291683]|2;c[291649]=c[291650]}n=c[291667]|0;h=d[(c[1161464+((n>>>16&255)*20|0)>>2]|0)+((n&65535|b&1)^1)|0]|0;return h|0}}return 0}function kU(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;switch(f>>>8&255|0){case 32:{do{if((a[937424]|0)==-124){g=f&63;if((g|0)==2){do{if((c[291648]|0)==8){h=c[291649]|0;if(h>>>0>(c[291647]|0)>>>0){i=h;j=9680;break}h=c[291667]|0;if((h|0)!=(c[291646]|0)){break}c[291649]=c[291650];c[291683]=8;k=c[291673]|0;l=h;do{l=l-2|0;c[291667]=l;}while((k|0)!=(e[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0))}else{c[291648]=8;i=c[291649]|0;j=9680}}while(0);if((j|0)==9680){c[291647]=i+840;c[291646]=c[291667]}m=e[5814833]|0;return m|0}else if((g|0)==12){m=(((((((c[291649]|0)*3184|0)>>>0)/3420|0)-(c[2907545]|0)|0)>>>0)/1536|0)+(e[5814838]|0)&4095;return m|0}else if((g|0)==6){m=e[(c[290366]|0)+114>>1]|0;return m|0}else if((g|0)==8){l=a[11958668]|0;do{if((l&2)==0){k=b[5979336]|0;h=b5(b[(k&16382)+11958700>>1]|0)|0;b[5979336]=k+2&65535;k=(b[5979335]|0)-2&65535;b[5979335]=k;if(k<<16>>16>=1){n=h;break}b[5979335]=-4096;a[11958668]=l&-75|10;do{if((a[11958669]&64)!=0){k=a[11630188]|32;a[11630188]=k;o=a[11629714]|0;if((o&32)==0){break}c[240596]=d[670008+((k&o&255)>>>1)|0]<<8}}while(0);a[11629669]=a[11629669]&7|-128;n=h}else{n=-1}}while(0);m=n&65535;return m|0}else{if(g>>>0>=48){break}L13353:do{if(g>>>0>31){l=c[291648]|0;o=1<<g-16;do{if((l|0)==(o|0)){k=c[291649]|0;if(k>>>0>(c[291647]|0)>>>0){p=k;break}k=c[291667]|0;if((k|0)!=(c[291646]|0)){break L13353}c[291649]=c[291650];c[291683]=l;q=c[291673]|0;r=k;while(1){r=r-2|0;c[291667]=r;if((q|0)==(e[(c[1161464+((r>>>16&255)*20|0)>>2]|0)+(r&65535)>>1]|0)){break L13353}}}else{c[291648]=o;p=c[291649]|0}}while(0);c[291647]=p+840;c[291646]=c[291667]}}while(0);m=e[11629664+(g>>>1<<1)>>1]|0;return m|0}}}while(0);p=c[291667]|0;m=e[(c[1161464+((p>>>16&255)*20|0)>>2]|0)+(p&65535)>>1]|0;return m|0};case 17:{p=c[291667]|0;n=e[(c[1161464+((p>>>16&255)*20|0)>>2]|0)+(p&65535)>>1]|0;if((a[736792]|0)==3){m=n&65279;return m|0}else{m=n|256;return m|0}break};case 0:{if((f&224|0)!=0){n=c[291667]|0;m=e[(c[1161464+((n>>>16&255)*20|0)>>2]|0)+(n&65535)>>1]|0;return m|0}n=f>>>1&15;p=n-1|0;if(p>>>0<3){i=d[n+1692187|0]|0;j=(fD[c[964252+(p<<3)>>2]&127]()|0)&255;s=d[1692184+n|0]&(i|128)|j&(i&127^-129)}else{s=d[1692184+n|0]|0}m=s<<8|s;return m|0};case 48:{s=c[3118372]|0;if((s|0)==0){n=c[291667]|0;m=e[(c[1161464+((n>>>16&255)*20|0)>>2]|0)+(n&65535)>>1]|0;return m|0}else{m=fl[s&255](f)|0;return m|0}break};case 16:case 18:case 19:case 64:case 65:case 68:{s=c[291667]|0;m=e[(c[1161464+((s>>>16&255)*20|0)>>2]|0)+(s&65535)>>1]|0;return m|0};case 80:{if((f&253|0)==0){m=e[2174019]|0;return m|0}if((f&255|0)==4){f=b[2174013]|0;b[2174013]=f&-2;m=f&65535;return m|0}else{f=c[291667]|0;m=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;return m|0}break};default:{if((a[12474170]|0)==0){c[291683]=c[291683]|2;c[291649]=c[291650]}f=c[291667]|0;m=e[(c[1161464+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;return m|0}}return 0}function kV(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;switch(b>>>8&255|0){case 18:{if((b&1|0)!=0){return}jO(f&1,c[291649]|0);return};case 65:{if((a[12474172]&1)==0){return}if(!((b&1|0)!=0&(a[937440]|0)<0)){return}if((f&1|0)==0){c[290366]=12736656;return}else{c[290366]=c[3118358];return}break};case 16:case 19:case 64:case 68:case 80:{return};case 17:{if((b&1|0)!=0){return}g=c[291649]|0;h=a[736792]|0;if((f&1|0)==0){if(h<<24>>24==3){c[3579678]=g;c[291167]=100;c[291168]=92;c[291169]=278;c[291170]=84}i=h&1}else{if(h<<24>>24==1){oy(g);c[291167]=2;c[291168]=206;c[291169]=22;c[291170]=26;j=a[736792]|0}else{j=h}i=j|2}a[736792]=i;return};case 32:{if((a[937424]|0)!=-124){return}i=f&255;switch(b&63|0){case 2:{a[11629667]=i;return};case 3:{j=(((c[291649]|0)*3184|0)>>>0)/3420|0;h=c[240597]|0;do{if((h|0)==0&(c[240563]|0)>>>0<j>>>0){ahk();g=c[240597]|0;if((g|0)!=0){c[240563]=j;k=g;l=9777;break}c[240564]=j;if((c[240563]|0)>>>0>=j>>>0){break}do{g=c[240581]|0;c[240581]=g+2;m=e[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]|0;c[240587]=m;fG[c[11976+(m<<2)>>2]&16383]();m=(c[240563]|0)+(d[537288+(c[240587]|0)|0]|0)|0;c[240563]=m;}while(m>>>0<j>>>0);k=c[240597]|0;l=9777}else{k=h;l=9777}}while(0);do{if((l|0)==9777){if((k&12|0)==0){break}c[240563]=j;c[240597]=0}}while(0);c[291648]=c[291648]&-13;c[240562]=c[240562]&-13;j=f&192;k=j<<11;h=d[10441816]|0;c[1161464+((h+2|0)*20|0)>>2]=k+10572896;c[1161464+((h+3|0)*20|0)>>2]=k+10638432;k=d[11629666]|0;h=(f&2|0)!=0;do{if((k&4|0)==0){if(!h){break}a[11630189]=1;a[11629666]=(k&60|f&194)&255;return}else{if(h){a[11630189]=1;break}a[11629666]=(j|k&61|2)&255;return}}while(0);a[11629666]=(k&63|j)&255;return};case 1:{do{if((f&1|0)==0){c[240597]=c[240597]|2}else{if((a[11629664]&1)==0){c[240597]=0;c[240588]=0;c[240595]=1792;c[240596]=0;c[962328+(c[240589]<<2)>>2]=c[240580];c[240589]=4;c[240580]=c[240586];c[240581]=4;j=c[239280]|0;c[240580]=e[j+2>>1]|e[j>>1]<<16;c[240581]=8;c[240581]=e[j+6>>1]|e[j+4>>1]<<16;c[240563]=(c[240563]|0)+160}j=c[240597]|0;if((f&2|0)==0){c[240597]=j&-3;break}else{c[240597]=j|2;break}}}while(0);a[11629664]=i;return};case 14:{n=i;break};case 0:{if((f&1|0)==0){return}j=a[11629714]|0;if((j&4)==0){return}k=(((c[291649]|0)*3184|0)>>>0)/3420|0;if((c[240597]|0)==0&(c[240563]|0)>>>0<k>>>0){ahk();do{if((c[240597]|0)==0){c[240564]=k;if((c[240563]|0)>>>0>=k>>>0){break}do{h=c[240581]|0;c[240581]=h+2;m=e[(c[957120+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]|0;c[240587]=m;fG[c[11976+(m<<2)>>2]&16383]();m=(c[240563]|0)+(d[537288+(c[240587]|0)|0]|0)|0;c[240563]=m;}while(m>>>0<k>>>0)}else{c[240563]=k}}while(0);o=a[11629714]|0}else{o=j}a[11629665]=a[11629665]|1;j=a[11630188]|4;a[11630188]=j;c[240596]=d[670008+((j&o&255)>>>1)|0]<<8;return};case 15:{n=(f>>>7&1|f<<1)&255;break};default:{if((b&48|0)!=16){return}o=b&30;j=(((c[291649]|0)*3184|0)>>>0)/3420|0;k=c[240597]|0;do{if((k|0)==0&(c[240563]|0)>>>0<j>>>0){ahk();m=c[240597]|0;if((m|0)!=0){c[240563]=j;p=m;break}c[240564]=j;if((c[240563]|0)>>>0>=j>>>0){p=0;break}do{m=c[240581]|0;c[240581]=m+2;h=e[(c[957120+((m>>>16&255)*20|0)>>2]|0)+(m&65535)>>1]|0;c[240587]=h;fG[c[11976+(h<<2)>>2]&16383]();h=(c[240563]|0)+(d[537288+(c[240587]|0)|0]|0)|0;c[240563]=h;}while(h>>>0<j>>>0);p=c[240597]|0}else{p=k}}while(0);k=3<<o;if((p&k|0)!=0){c[240563]=j;c[240597]=0}j=~k;c[291648]=c[291648]&j;c[240562]=c[240562]&j;j=11629664+((b>>>1&255)<<1)|0;if((b&1|0)==0){a[j+1|0]=i;return}else{a[j]=i;return}}}i=(((c[291649]|0)*3184|0)>>>0)/3420|0;j=c[240597]|0;do{if((j|0)==0&(c[240563]|0)>>>0<i>>>0){ahk();k=c[240597]|0;if((k|0)!=0){c[240563]=i;q=k;l=9793;break}c[240564]=i;if((c[240563]|0)>>>0>=i>>>0){break}do{k=c[240581]|0;c[240581]=k+2;p=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;c[240587]=p;fG[c[11976+(p<<2)>>2]&16383]();p=(c[240563]|0)+(d[537288+(c[240587]|0)|0]|0)|0;c[240563]=p;}while(p>>>0<i>>>0);q=c[240597]|0;l=9793}else{q=j;l=9793}}while(0);do{if((l|0)==9793){if((q&49152|0)==0){break}c[240563]=i;c[240597]=0}}while(0);c[291648]=c[291648]&-49153;c[240562]=c[240562]&-49153;a[11629679]=n;return};case 0:{if((b&225|0)!=1){return}n=b>>>1&15;switch(n|0){case 1:case 2:case 3:{i=f&255;a[1692184+n|0]=i;fj[c[964248+(n-1<<3)>>2]&511](i,a[n+1692187|0]|0);return};case 4:case 5:case 6:{i=1692184+n|0;if((d[i]|0)==(f|0)){return}q=f&255;a[i]=q;fj[c[964248+(n-4<<3)>>2]&511](a[1692184+(n-3)|0]|0,q);return};case 9:case 12:case 15:{a[1692184+n|0]=f&255&-8;return};case 7:case 10:case 13:{a[1692184+n|0]=f&255;return};default:{return}}break};case 48:{fj[c[3118373]&511](b,f);return};default:{if((a[12474170]|0)!=0){return}c[291683]=c[291683]|2;c[291649]=c[291650];return}}}function kW(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;switch(f>>>8&255|0){case 16:case 19:case 65:case 68:{return};case 32:{if((a[937424]|0)!=-124){return}h=f&62;if((h|0)==0){do{if((g&1|0)==0){c[240597]=c[240597]|2}else{if((a[11629664]&1)==0){c[240597]=0;c[240588]=0;c[240595]=1792;c[240596]=0;c[962328+(c[240589]<<2)>>2]=c[240580];c[240589]=4;c[240580]=c[240586];c[240581]=4;i=c[239280]|0;c[240580]=e[i+2>>1]|e[i>>1]<<16;c[240581]=8;c[240581]=e[i+6>>1]|e[i+4>>1]<<16;c[240563]=(c[240563]|0)+160}i=c[240597]|0;if((g&2|0)==0){c[240597]=i&-3;break}else{c[240597]=i|2;break}}}while(0);do{if((g&256|0)!=0){i=a[11629714]|0;if((i&4)==0){break}a[11629665]=a[11629665]|1;j=a[11630188]|4;a[11630188]=j;c[240596]=d[670008+((j&i&255)>>>1)|0]<<8}}while(0);a[11629664]=g&255;return}else if((h|0)==6){b[(c[290366]|0)+114>>1]=g&65535;return}else if((h|0)==14){i=(((c[291649]|0)*3184|0)>>>0)/3420|0;j=c[240597]|0;do{if((j|0)==0&(c[240563]|0)>>>0<i>>>0){ahk();k=c[240597]|0;if((k|0)!=0){c[240563]=i;l=k;m=9901;break}c[240564]=i;if((c[240563]|0)>>>0>=i>>>0){break}do{k=c[240581]|0;c[240581]=k+2;n=e[(c[957120+((k>>>16&255)*20|0)>>2]|0)+(k&65535)>>1]|0;c[240587]=n;fG[c[11976+(n<<2)>>2]&16383]();n=(c[240563]|0)+(d[537288+(c[240587]|0)|0]|0)|0;c[240563]=n;}while(n>>>0<i>>>0);l=c[240597]|0;m=9901}else{l=j;m=9901}}while(0);do{if((m|0)==9901){if((l&49152|0)==0){break}c[240563]=i;c[240597]=0}}while(0);c[291648]=c[291648]&-49153;c[240562]=c[240562]&-49153;a[11629679]=g&255;return}else if((h|0)==2){h=(((c[291649]|0)*3184|0)>>>0)/3420|0;i=c[240597]|0;do{if((i|0)==0&(c[240563]|0)>>>0<h>>>0){ahk();l=c[240597]|0;if((l|0)!=0){c[240563]=h;o=l;m=9885;break}c[240564]=h;if((c[240563]|0)>>>0>=h>>>0){break}do{l=c[240581]|0;c[240581]=l+2;j=e[(c[957120+((l>>>16&255)*20|0)>>2]|0)+(l&65535)>>1]|0;c[240587]=j;fG[c[11976+(j<<2)>>2]&16383]();j=(c[240563]|0)+(d[537288+(c[240587]|0)|0]|0)|0;c[240563]=j;}while(j>>>0<h>>>0);o=c[240597]|0;m=9885}else{o=i;m=9885}}while(0);do{if((m|0)==9885){if((o&12|0)==0){break}c[240563]=h;c[240597]=0}}while(0);c[291648]=c[291648]&-13;c[240562]=c[240562]&-13;h=g<<11&393216;o=d[10441816]|0;c[1161464+((o+2|0)*20|0)>>2]=h+10572896;c[1161464+((o+3|0)*20|0)>>2]=h+10638432;h=(g&2|0)!=0;do{if((a[11629666]&4)==0){if(!h){break}a[11630189]=1;b[5814833]=(b[5814833]&60|g&65474)&65535;return}else{if(h){a[11630189]=1;break}b[5814833]=(g&65472|b[5814833]&61|2)&65535;return}}while(0);b[5814833]=(b[5814833]&63|g&65472)&65535;return}else{if((f&48|0)!=16){return}h=f&30;o=(((c[291649]|0)*3184|0)>>>0)/3420|0;m=c[240597]|0;do{if((m|0)==0&(c[240563]|0)>>>0<o>>>0){ahk();i=c[240597]|0;if((i|0)!=0){c[240563]=o;p=i;break}c[240564]=o;if((c[240563]|0)>>>0>=o>>>0){p=0;break}do{i=c[240581]|0;c[240581]=i+2;j=e[(c[957120+((i>>>16&255)*20|0)>>2]|0)+(i&65535)>>1]|0;c[240587]=j;fG[c[11976+(j<<2)>>2]&16383]();j=(c[240563]|0)+(d[537288+(c[240587]|0)|0]|0)|0;c[240563]=j;}while(j>>>0<o>>>0);p=c[240597]|0}else{p=m}}while(0);m=3<<h;if((p&m|0)!=0){c[240563]=o;c[240597]=0}o=~m;c[291648]=c[291648]&o;c[240562]=c[240562]&o;b[11629664+((f>>>1&255)<<1)>>1]=g&65535;return}break};case 18:{jO(g>>>8&1,c[291649]|0);return};case 64:{if((a[12474172]&1)==0){return}o=f&3;a[888224+o|0]=g>>>8&255;a[o+888225|0]=g&255;o=(aID(888224,720944,4)|0)==0;m=o?150:198;p=o?110:50;h=o?216:178;j=o?264:166;i=o?108:96;l=o?116:54;c[291327]=m;c[291328]=p;c[291329]=h;c[291330]=j;c[186632]=i;c[186633]=l;c[291367]=m;c[291368]=p;c[291369]=h;c[291370]=j;c[186648]=i;c[186649]=l;c[291407]=m;c[291408]=p;c[291409]=h;c[291410]=j;c[186664]=i;c[186665]=l;c[291447]=m;c[291448]=p;c[291449]=h;c[291450]=j;c[186680]=i;c[186681]=l;return};case 17:{l=c[291649]|0;i=a[736792]|0;if((g&256|0)==0){if(i<<24>>24==3){c[3579678]=l;c[291167]=100;c[291168]=92;c[291169]=278;c[291170]=84}q=i&1}else{if(i<<24>>24==1){oy(l);c[291167]=2;c[291168]=206;c[291169]=22;c[291170]=26;r=a[736792]|0}else{r=i}q=r|2}a[736792]=q;return};case 0:{if((f&224|0)!=0){return}q=f>>>1&15;switch(q|0){case 1:case 2:case 3:{r=g&255;a[1692184+q|0]=r;fj[c[964248+(q-1<<3)>>2]&511](r,a[q+1692187|0]|0);return};case 9:case 12:case 15:{a[1692184+q|0]=g&255&-8;return};case 4:case 5:case 6:{r=1692184+q|0;i=g&255;if((a[r]|0)==i<<24>>24){return}a[r]=i;fj[c[964248+(q-4<<3)>>2]&511](a[1692184+(q-3)|0]|0,i);return};case 7:case 10:case 13:{a[1692184+q|0]=g&255;return};default:{return}}break};case 80:{if((f&253|0)!=0){return}b[2174019]=g&65535;b[2174013]=b[2174013]|2;c[1087031]=c[1087031]&-8193;return};case 48:{fj[c[3118373]&511](f,g);return};default:{if((a[12474170]|0)!=0){return}c[291683]=c[291683]|2;c[291649]=c[291650];return}}}function kX(a){a=a|0;var f=0,g=0;switch(a&255|0){case 16:case 17:{f=255;break};case 5:{f=b[846120]>>8;break};case 11:{f=b[846121]&255;break};case 7:{f=b[846120]&255;break};case 3:{f=~e[846136];break};case 18:{f=128;break};case 13:{f=0;break};case 9:{f=b[846121]>>8;break};case 1:{f=(d[9808]|0)>>>1;break};default:{g=c[291667]|0;f=d[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+((g&65535|a&1)^1)|0]|0}}return f|0}function kY(a){a=a|0;var f=0,g=0,h=0;switch(a&254|1|0){case 7:{f=b[846120]&255;break};case 17:{f=255;break};case 11:{f=b[846121]&255;break};case 9:{f=b[846121]>>8;break};case 5:{f=b[846120]>>8;break};case 13:{f=0;break};case 3:{f=~e[846136];break};case 1:{f=(d[9808]|0)>>>1;break};default:{g=c[291667]|0;f=d[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+(g&65534)|0]|0}}switch(a&255|0){case 16:case 17:{h=255;break};case 13:{h=0;break};case 7:{h=b[846120]&255;break};case 11:{h=b[846121]&255;break};case 18:{h=128;break};case 3:{h=~e[846136];break};case 1:{h=(d[9808]|0)>>>1;break};case 5:{h=b[846120]>>8;break};case 9:{h=b[846121]>>8;break};default:{g=c[291667]|0;h=d[(c[1161464+((g>>>16&255)*20|0)>>2]|0)+((g&65535|a&1)^1)|0]|0}}return h<<8|f|0}function kZ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;switch(f&253|0){case 1:{g=(fD[c[222048]&127]()|0)&255;return g|0};case 8:case 12:{h=c[291649]|0;i=c[423080]|0;do{if((i|0)==0){j=d[(c[423088]|0)+((h>>>0)%3420|0)|0]|0;k=10003}else{if((a[962713]&4)==0){j=i&255;k=10003;break}else{l=i&65535;break}}}while(0);if((k|0)==10003){i=((h>>>0)/3420|0)-1|0;if((i|0)>(e[444100]|0)){m=i-(e[780032]|0)|0}else{m=i}if((a[1692200]|0)==0){n=m}else{i=m<<d[1692312];n=i>>>8&1|i&-2}l=n<<8&65280|j}g=l>>>8;return g|0};case 24:case 25:case 28:case 29:{l=c[291667]|0;g=d[(c[1161464+((l>>>16&255)*20|0)>>2]|0)+((l&65535|f&1)^1)|0]|0;return g|0};case 5:{l=c[291649]|0;j=c[496910]|0;do{if((j|0)>0){n=c[496914]|0;i=c[496912]|0;m=((l-n|0)>>>0)/(i>>>0)|0;if((m|0)<=0){break}h=j-m|0;c[496910]=h;o=b[468728]&-257;b[468728]=o;if((h|0)<1){b[468728]=o|512;c[496910]=0}c[496914]=(ab(m,i)|0)+n}}while(0);j=b[468728]|0;if((j&2)==0|(c[3118496]|0)!=0|(c[3118498]|0)>>>0>l>>>0){p=j}else{n=j&-3;b[468728]=n;p=n}n=p&65535;a[968008]=0;b[468728]=p&-97;p=(a[962713]&64)==0?n|8:n;g=(((l>>>0)%3420|0)>>>0<588?p|4:p)&255;return g|0};case 0:{g=(fD[c[222048]&127]()|0)>>>8;return g|0};case 9:case 13:{p=c[291649]|0;l=c[423080]|0;do{if((l|0)==0){q=d[(c[423088]|0)+((p>>>0)%3420|0)|0]|0;k=10014}else{if((a[962713]&4)==0){q=l&255;k=10014;break}else{r=l&65535;break}}}while(0);if((k|0)==10014){k=((p>>>0)/3420|0)-1|0;if((k|0)>(e[444100]|0)){s=k-(e[780032]|0)|0}else{s=k}if((a[1692200]|0)==0){t=s}else{k=s<<d[1692312];t=k>>>8&1|k&-2}r=t<<8&65280|q}g=r&255;return g|0};case 4:{r=c[291649]|0;q=c[496910]|0;do{if((q|0)>0){t=c[496914]|0;k=c[496912]|0;s=((r-t|0)>>>0)/(k>>>0)|0;if((s|0)<=0){break}p=q-s|0;c[496910]=p;l=b[468728]&-257;b[468728]=l;if((p|0)<1){b[468728]=l|512;c[496910]=0}c[496914]=(ab(s,k)|0)+t}}while(0);q=b[468728]|0;if((q&2)==0|(c[3118496]|0)!=0|(c[3118498]|0)>>>0>r>>>0){u=q}else{r=q&-3;b[468728]=r;u=r}a[968008]=0;b[468728]=u&-97;r=c[291667]|0;g=a[(c[1161464+((r>>>16&255)*20|0)>>2]|0)+(r&65535^1)|0]&252|(u&65535)>>>8&3;return g|0};default:{if((a[12474170]|0)==0){c[291683]=c[291683]|2;c[291649]=c[291650]}u=c[291667]|0;g=d[(c[1161464+((u>>>16&255)*20|0)>>2]|0)+((u&65535|f&1)^1)|0]|0;return g|0}}return 0}function k_(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;switch(f&252|0){case 4:{f=c[291649]|0;g=c[496910]|0;do{if((g|0)>0){h=c[496914]|0;i=c[496912]|0;j=((f-h|0)>>>0)/(i>>>0)|0;if((j|0)<=0){break}k=g-j|0;c[496910]=k;l=b[468728]&-257;b[468728]=l;if((k|0)<1){b[468728]=l|512;c[496910]=0}c[496914]=(ab(j,i)|0)+h}}while(0);g=b[468728]|0;if((g&2)==0|(c[3118496]|0)!=0|(c[3118498]|0)>>>0>f>>>0){m=g}else{h=g&-3;b[468728]=h;m=h}h=m&65535;a[968008]=0;b[468728]=m&-97;m=(a[962713]&64)==0?h|8:h;h=c[291667]|0;n=b[(c[1161464+((h>>>16&255)*20|0)>>2]|0)+(h&65535)>>1]&64512|(((f>>>0)%3420|0)>>>0<588?m|4:m)&1023;return n|0};case 0:{n=fD[c[222048]&127]()|0;return n|0};case 8:case 12:{m=c[291649]|0;f=c[423080]|0;do{if((f|0)==0){o=d[(c[423088]|0)+((m>>>0)%3420|0)|0]|0}else{if((a[962713]&4)==0){o=f&255;break}n=f&65535;return n|0}}while(0);f=((m>>>0)/3420|0)-1|0;if((f|0)>(e[444100]|0)){p=f-(e[780032]|0)|0}else{p=f}if((a[1692200]|0)==0){q=p}else{f=p<<d[1692312];q=f>>>8&1|f&-2}n=q<<8&65280|o;return n|0};case 24:case 28:{o=c[291667]|0;n=e[(c[1161464+((o>>>16&255)*20|0)>>2]|0)+(o&65535)>>1]|0;return n|0};default:{if((a[12474170]|0)==0){c[291683]=c[291683]|2;c[291649]=c[291650]}o=c[291667]|0;n=e[(c[1161464+((o>>>16&255)*20|0)>>2]|0)+(o&65535)>>1]|0;return n|0}}return 0}function k$(b,d){b=b|0;d=d|0;switch(b&252|0){case 4:{jX(d<<8|d);return};case 0:{fi[c[222046]&255](d<<8|d);return};case 16:case 20:{if((b&1|0)==0){return}ox(c[291649]|0,d);return};case 24:case 28:{return};default:{if((a[12474170]|0)!=0){return}c[291683]=c[291683]|2;c[291649]=c[291650];return}}}function k0(b,d){b=b|0;d=d|0;switch(b&252|0){case 0:{fi[c[222046]&255](d);return};case 16:case 20:{ox(c[291649]|0,d&255);return};case 4:{jX(d);return};case 24:case 28:{return};default:{if((a[12474170]|0)!=0){return}c[291683]=c[291683]|2;c[291649]=c[291650];return}}}function k1(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=b>>>13&7;if((d|0)==2){e=c[3579678]|0;f=c[494748]|0;if(f>>>0<e>>>0){g=c[494746]|0;h=((e-1-f+g|0)>>>0)/(g>>>0)|0;fj[c[3579684]&511](c[494738]|0,h);c[494738]=(c[494738]|0)+(h<<1<<2);g=ab(c[494746]|0,h)|0;c[494748]=(c[494748]|0)+g}i=a[749762]|0;return i|0}else if((d|0)==0|(d|0)==1){i=a[736800+(b&8191)|0]|0;return i|0}else if((d|0)==3){if((b&-256|0)!=32512){i=-1;return i|0}i=(fl[c[186632]&255](b)|0)&255;return i|0}else{d=c[186760]|0;g=d|b&32767;b=d>>>16;d=c[744992+(b<<3)>>2]|0;if((d|0)==0){i=a[(c[1161464+(b*20|0)>>2]|0)+(g&65535^1)|0]|0;return i|0}else{i=(fl[d&255](g)|0)&255;return i|0}}return 0}function k2(a,b){a=a|0;b=b|0;return}function k3(b){b=b|0;var d=0;if((a[937424]|0)!=32){d=-1;return d|0}b=(e[7159324]|0)+65535|0;d=a[(c[747336+((b>>>10&63)<<2)>>2]|0)+(b&1023)|0]|0;return d|0}function k4(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b>>>13&7;if((e|0)==2){f=c[3579678]|0;g=b&3;h=d&255;do{if((b&1|0)!=0){i=c[494748]|0;if(i>>>0>=f>>>0){break}j=c[494746]|0;k=((f-1-i+j|0)>>>0)/(j>>>0)|0;fj[c[3579684]&511](c[494738]|0,k);c[494738]=(c[494738]|0)+(k<<1<<2);j=ab(c[494746]|0,k)|0;c[494748]=(c[494748]|0)+j}}while(0);fj[c[3579682]&511](g,h);return}else if((e|0)==3){h=b>>>8;if((h|0)==127){fj[c[186633]&511](b,d&255);return}else if((h|0)==96){c[186760]=((c[186760]|0)>>>1|(d&255)<<23)&16744448;return}else{return}}else if((e|0)==0|(e|0)==1){a[736800+(b&8191)|0]=d;return}else{e=c[186760]|0;h=e|b&32767;b=e>>>16;e=c[744996+(b<<3)>>2]|0;if((e|0)==0){a[(c[1161464+(b*20|0)>>2]|0)+(h&65535^1)|0]=d;return}else{fj[e&511](h,d&255);return}}}function k5(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;switch(f&193|0){case 129:{h=g&255;i=d[968008]|0;if((i|0)==3){a[968008]=0;j=b[7158920]|0;b[7158924]=b[7158924]&16383|j<<14;k=(j&65535)>>>2;a[12474208]=(a[12474208]&3|k&60)&255;if((k&32|0)==0){return}if((a[962713]&16)==0){return}k=(d[962735]|0)>>>6;if((k|0)==3){j=(d[962732]|0)<<8|(d[962731]|0);c[3118496]=(j|0)==0?65536:j;b[6236988]=(d[962734]|0)<<8|(d[962733]|0);a[12473968]=3;jW(c[3579678]|0);return}else if((k|0)==2){b[6236980]=256;return}else{return}}else if((i|0)==2){b[7158920]=g&255;a[968008]=3;return}else if((i|0)==0){b[7158920]=g&255;a[968008]=1;return}else if((i|0)==1){i=e[7158920]|0;k=b[7158924]&49152|h<<8&16128|i;j=k&65535;b[7158924]=j;l=h>>>6;m=(a[12474208]&60|l)&255;a[12474208]=m;if((l|0)==2){jT(h&31,i,c[3579678]|0);a[968008]=0;return}i=(d[962713]|0)>>>1&2;a[968008]=i;if(i<<24>>24!=0){return}if((m&3)!=0){return}b[993832]=d[822600+(k&16383)|0]|0;b[7158924]=(j+1&65535)+(d[962727]|0)&65535;return}else{return}break};case 1:{kD(1,g&255,(c[3579678]|0)+550|0);return};case 64:case 65:{ox(c[3579678]|0,g&255);return};case 128:{fi[c[222040]&255](g&255);return};default:{if((f&240)>>>0<=239){return}if((a[12474148]&1)==0){return}j=c[3579678]|0;k=f&3;m=g&255;do{if((f&1|0)!=0){g=c[494748]|0;if(g>>>0>=j>>>0){break}i=c[494746]|0;h=((j-1-g+i|0)>>>0)/(i>>>0)|0;fj[c[3579684]&511](c[494738]|0,h);c[494738]=(c[494738]|0)+(h<<1<<2);i=ab(c[494746]|0,h)|0;c[494748]=(c[494748]|0)+i}}while(0);fj[c[3579682]&511](k,m);return}}}function k6(b){b=b|0;var f=0,g=0,h=0,i=0;f=b&193;if((f|0)==128){g=(fD[c[222042]&127]()|0)&255;return g|0}else if((f|0)==65){h=c[423080]|0;if((h|0)==0){g=a[(c[423088]|0)+((((c[3579678]|0)-15|0)>>>0)%3420|0)|0]|0;return g|0}else{g=h&255;return g|0}}else if((f|0)==129){g=(jY(c[3579678]|0)|0)&255;return g|0}else if((f|0)==64){f=(c[3579678]|0)-15|0;h=c[423080]|0;do{if((h|0)!=0){if((a[962713]&4)==0){break}g=h>>>8&255;return g|0}}while(0);h=((f>>>0)/3420|0)-1|0;if((h|0)>(e[444100]|0)){i=h-(e[780032]|0)|0}else{i=h}if((a[1692200]|0)==0){g=i&255;return g|0}h=i<<d[1692312];g=(h>>>8&1|h&254)&255;return g|0}else{h=b&255;if((h-192|0)>>>0<2|(h|0)==220|(h|0)==221){g=(kE(b&1)|0)&255;return g|0}do{if(h>>>0>239){if((a[12474148]&1)==0){break}g=a[756893]|-8;return g|0}}while(0);if((a[937424]|0)!=32){g=-1;return g|0}h=(e[7159324]|0)+65535|0;g=a[(c[747336+((h>>>10&63)<<2)>>2]|0)+(h&1023)|0]|0;return g|0}return 0}function k7(e,f){e=e|0;f=f|0;var g=0;switch(e&193|0){case 64:case 65:{ox(c[3579678]|0,f&255);return};case 129:{jU(f&255);return};case 128:{fi[c[222040]&255](f&255);return};case 0:case 1:{g=e&255;if(g>>>0>=7){kD(e&1,f&255,(c[3579678]|0)+520|0);return}if((a[937424]|0)!=64){return}switch(g|0){case 5:{a[1692189]=f&-8;return};case 6:{a[1692190]=f;ou(c[3579678]|0,b[6237075]|0,d[12474146]|0,f&255);return};case 3:{a[1692187]=f;return};case 2:{a[1692186]=f;return};case 1:{a[1692185]=f;return};default:{return}}break};default:{return}}}
function aGr(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;e=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&255;g=f>>>(e>>>0);if((e|0)==0){c[240594]=0;c[240591]=f;c[240592]=f;c[240593]=0;return}c[240563]=(c[240563]|0)+(e<<3);h=(a&128|0)!=0;if(e>>>0<8){if(h){i=d[11504+e|0]|0|g}else{i=g}c[b>>2]=c[b>>2]&-256|i;g=f<<9-e;c[240594]=g;c[240590]=g;c[240591]=i;c[240592]=i;c[240593]=0;return}i=c[b>>2]|0;if(h){c[b>>2]=i|255;c[240594]=256;c[240590]=256;c[240591]=128;c[240592]=-1;c[240593]=0;return}else{c[b>>2]=i&-256;aIv(962360,0,20);return}}function aGs(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]&255;e=a>>>(d>>>0);if((d|0)==0){c[240594]=0;c[240591]=a;c[240592]=a;c[240593]=0;return}c[240563]=(c[240563]|0)+(d<<3);f=c[b>>2]&-256;if(d>>>0<9){c[b>>2]=f|e;g=a<<9-d;c[240594]=g;c[240590]=g;c[240591]=0;c[240592]=e;c[240593]=0;return}else{c[b>>2]=f;aIv(962360,0,20);return}}function aGt(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&65535;g=f>>>(d>>>0);if((d|0)==0){c[240594]=0;c[240591]=f>>>8;c[240592]=f;c[240593]=0;return}c[240563]=(c[240563]|0)+(d<<3);h=(a&32768|0)!=0;if(d>>>0<16){if(h){i=e[11840+(d<<1)>>1]|0|g}else{i=g}c[b>>2]=c[b>>2]&-65536|i;g=f>>>((d-1|0)>>>0)<<8;c[240590]=g;c[240594]=g;c[240591]=i>>>8;c[240592]=i;c[240593]=0;return}i=c[b>>2]|0;if(h){c[b>>2]=i|65535;c[240594]=256;c[240590]=256;c[240591]=128;c[240592]=-1;c[240593]=0;return}else{c[b>>2]=i&-65536;aIv(962360,0,20);return}}function aGu(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]&65535;e=a>>>(d>>>0);if((d|0)==0){c[240594]=0;c[240591]=a>>>8;c[240592]=a;c[240593]=0;return}c[240563]=(c[240563]|0)+(d<<3);f=c[b>>2]&-65536;if(d>>>0<17){c[b>>2]=f|e;g=a>>>((d-1|0)>>>0)<<8;c[240590]=g;c[240594]=g;c[240591]=0;c[240592]=e;c[240593]=0;return}else{c[b>>2]=f;aIv(962360,0,20);return}}function aGv(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&15;f=c[b>>2]&65535;g=(f>>>(e>>>0)|f<<16-e)&65535;if((a|0)==0){h=f;i=0}else{c[240563]=(c[240563]|0)+(a<<3);c[b>>2]=c[b>>2]&-65536|g;h=g;i=f>>>((d+15&15)>>>0)<<8}c[240594]=i;c[240591]=h>>>8;c[240592]=h;c[240593]=0;return}function aGw(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e>>>(a>>>0);c[240563]=(a<<3)+(c[240563]|0);if((e|0)<0){g=c[11576+(a<<2)>>2]|f}else{g=f}c[b>>2]=g;c[240591]=g>>>24;c[240592]=g;c[240593]=0;g=e<<8-d;c[240594]=g;c[240590]=g;return}function aGx(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e>>>(a>>>0);c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f;c[240591]=0;c[240592]=f;f=e<<8-d;c[240594]=f;c[240590]=f;c[240593]=0;return}function aGy(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=32-d|0;g=d^31;h=((f>>>0<32?e<<f:0)|e>>>(a>>>0))&~(1<<g)|((c[240590]|0)>>>8&1)<<g;c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=h;b=((1<<d&e|0)!=0)<<8;c[240590]=b;c[240594]=b;c[240591]=h>>>24;c[240592]=h;c[240593]=0;return}function aGz(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e>>>(a>>>0)|e<<(d^31);c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f;c[240591]=f>>>24;c[240592]=f;c[240594]=e<<8-d;c[240593]=0;return}function aGA(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a>>>(d>>>0);if((d|0)==0){c[240594]=0;c[240591]=a>>>24;c[240592]=a;c[240593]=0;return}c[240563]=(c[240563]|0)+(d<<3);if(d>>>0<32){c[b>>2]=e;f=a>>>((d-1|0)>>>0)<<8;c[240590]=f;c[240594]=f;c[240591]=0;c[240592]=e;c[240593]=0;return}c[b>>2]=0;if((d|0)==32){g=a>>>23&256}else{g=0}c[240594]=g;c[240590]=g;c[240591]=0;c[240592]=0;c[240593]=0;return}function aGB(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=(d>>>0)%33|0;e=c[b>>2]|0;f=33-a|0;g=32-a|0;h=c[240590]|0;i=((a>>>0<32?e>>>(a>>>0):0)|(f>>>0<32?e<<f:0))&~(1<<g)|(h>>>8&1)<<g;if((d|0)!=0){c[240563]=(c[240563]|0)+(d<<3)}if((a|0)==0){j=e;k=h;c[240594]=k;l=j>>>24;c[240591]=l;c[240592]=j;c[240593]=0;return}c[b>>2]=i;b=((1<<a-1&e|0)!=0)<<8;c[240590]=b;j=i;k=b;c[240594]=k;l=j>>>24;c[240591]=l;c[240592]=j;c[240593]=0;return}function aGC(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&31;f=c[b>>2]|0;g=32-e|0;h=(g>>>0<32?f<<g:0)|f>>>(e>>>0);if((a|0)==0){i=f;j=0}else{c[240563]=(c[240563]|0)+(a<<3);c[b>>2]=h;i=h;j=f>>>((d+31&31)>>>0)<<8}c[240594]=j;c[240591]=i>>>24;c[240592]=i;c[240593]=0;return}function aGD(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;e=(a>>>9)+7&7;a=e+1|0;f=c[b>>2]|0;g=(f&255)<<a;h=g&255;c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=h|c[b>>2]&-256;c[240594]=g;c[240590]=g;c[240591]=h;c[240592]=h;h=d[e+11506|0]|0;e=h&f;if((e|0)==0){i=0;c[240593]=i;return}if((e|0)!=(h|0)){i=128;c[240593]=i;return}i=(a>>>0>7)<<7;c[240593]=i;return}function aGE(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a>>>(d>>>0);if((d|0)==0){c[240594]=0;c[240591]=a>>>24;c[240592]=a;c[240593]=0;return}c[240563]=(c[240563]|0)+(d<<3);f=(a|0)<0;if(d>>>0<32){if(f){g=c[11576+(d<<2)>>2]|e}else{g=e}c[b>>2]=g;e=a>>>((d-1|0)>>>0)<<8;c[240590]=e;c[240594]=e;c[240591]=g>>>24;c[240592]=g;c[240593]=0;return}if(f){c[b>>2]=-1;c[240594]=256;c[240590]=256;c[240591]=128;c[240592]=-1;c[240593]=0;return}else{c[b>>2]=0;aIv(962360,0,20);return}}function aGF(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=g>>>1;h=(g&32768|0)==0?f:f|32768;f=c[957136+(d*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=h&65535;i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;j=g<<8;c[240590]=j;c[240594]=j;return}else{fj[f&511](a&16777215,h);i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;j=g<<8;c[240590]=j;c[240594]=j;return}}function aGG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g>>>1;h=(g&32768|0)==0?f:f|32768;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h&65535;i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;j=g<<8;c[240590]=j;c[240594]=j;return}else{fj[f&511](d&16777215,h);i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;j=g<<8;c[240590]=j;c[240594]=j;return}}function aGH(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g>>>1;h=(g&32768|0)==0?f:f|32768;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h&65535;i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;j=g<<8;c[240590]=j;c[240594]=j;return}else{fj[f&511](d&16777215,h);i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;j=g<<8;c[240590]=j;c[240594]=j;return}}function aGI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=g>>>1;h=(g&32768|0)==0?d:d|32768;d=c[957136+(a*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=h&65535;i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;j=g<<8;c[240590]=j;c[240594]=j;return}else{fj[d&511](f&16777215,h);i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;j=g<<8;c[240590]=j;c[240594]=j;return}}function aGJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=h>>>1;f=(h&32768|0)==0?a:a|32768;a=c[957136+(g*20|0)>>2]|0;if((a|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=f&65535;i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;j=h<<8;c[240590]=j;c[240594]=j;return}else{fj[a&511](d&16777215,f);i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;j=h<<8;c[240590]=j;c[240594]=j;return}}function aGK(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g>>>1;h=(g&32768|0)==0?f:f|32768;f=c[957136+(a*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=h&65535;i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;j=g<<8;c[240590]=j;c[240594]=j;return}else{fj[f&511](d&16777215,h);i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;j=g<<8;c[240590]=j;c[240594]=j;return}}function aGL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=h>>>1;i=(h&32768|0)==0?d:d|32768;d=c[957136+(g*20|0)>>2]|0;if((d|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=i&65535;j=i>>>8;c[240591]=j;c[240592]=i;c[240593]=0;k=h<<8;c[240590]=k;c[240594]=k;return}else{fj[d&511](f&16777215,i);j=i>>>8;c[240591]=j;c[240592]=i;c[240593]=0;k=h<<8;c[240590]=k;c[240594]=k;return}}function aGM(){var a=0,b=0,d=0,e=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=(c[b>>2]&255)<<d;e=a&255;c[240563]=(d<<3)+(c[240563]|0);c[b>>2]=e|c[b>>2]&-256;c[240591]=e;c[240592]=e;c[240594]=a;c[240590]=a;c[240593]=0;return}function aGN(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[240590]&256|c[b>>2]&255;f=e<<a|e>>>((8-d|0)>>>0);c[240563]=(a<<3)+(c[240563]|0);c[240590]=f;c[240594]=f;a=f&255;c[b>>2]=a|c[b>>2]&-256;c[240591]=a;c[240592]=a;c[240593]=0;return}function aGO(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=a>>>9;a=(d+7&7)+1|0;e=d&7;d=c[b>>2]&255;f=(d>>>((8-e|0)>>>0)|d<<e)&255;c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f|c[b>>2]&-256;c[240591]=f;c[240592]=f;c[240594]=d<<a;c[240593]=0;return}function aGP(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;e=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&255;g=f<<e;h=g&255;if((e|0)==0){c[240594]=0;c[240591]=f;c[240592]=f;c[240593]=0;return}c[240563]=(c[240563]|0)+(e<<3);i=c[b>>2]&-256;if(e>>>0<8){c[b>>2]=i|h;c[240594]=g;c[240590]=g;c[240591]=h;c[240592]=h;h=d[e+11505|0]|0;g=h&a;if((g|0)==0){j=0}else{j=((g|0)!=(h|0))<<7}c[240593]=j;return}else{c[b>>2]=i;if((e|0)==8){k=a<<8&256}else{k=0}c[240594]=k;c[240590]=k;c[240591]=0;c[240592]=0;c[240593]=((f|0)!=0)<<7;return}}function aGQ(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[240594]=c[240590];c[240591]=c[b>>2];e=c[b>>2]&255;c[240592]=e;c[240593]=0;return}else{a=(d>>>0)%9|0;f=c[240590]&256|c[b>>2]&255;g=f<<a|f>>>((9-a|0)>>>0);c[240563]=(c[240563]|0)+(d<<3);c[240590]=g;c[240594]=g;d=g&255;c[b>>2]=d|c[b>>2]&-256;c[240591]=d;e=d;c[240592]=e;c[240593]=0;return}}function aGR(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&7;d=c[b>>2]|0;f=d&255;g=f<<e;h=(g|f>>>((8-e|0)>>>0))&255;if((a|0)==0){c[240594]=0;c[240591]=f;c[240592]=f;c[240593]=0;return}c[240563]=(c[240563]|0)+(a<<3);if((e|0)==0){c[240594]=d<<8&256;c[240591]=f;c[240592]=f;c[240593]=0;return}else{c[b>>2]=c[b>>2]&-256|h;c[240594]=g;c[240591]=h;c[240592]=h;c[240593]=0;return}}function aGS(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;f=c[b>>2]|0;g=f&65535;h=g<<a&65535;c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=h|c[b>>2]&-65536;c[240591]=h>>>8;c[240592]=h;h=g>>>((d^7)>>>0);c[240594]=h;c[240590]=h;h=e[11840+(d+2<<1)>>1]|0;d=h&f;if((d|0)==0){i=0;c[240593]=i;return}i=((d|0)!=(h|0))<<7;c[240593]=i;return}function aGT(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]&65535;f=e<<a&65535;c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f|c[b>>2]&-65536;c[240591]=f>>>8;c[240592]=f;f=e>>>((d^7)>>>0);c[240594]=f;c[240590]=f;c[240593]=0;return}function aGU(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=(c[240590]|0)>>>8<<16&65536|c[b>>2]&65535;f=e<<a|e>>>((16-d|0)>>>0);c[240563]=(a<<3)+(c[240563]|0);a=f>>>8;c[240590]=a;c[240594]=a;a=f&65535;c[b>>2]=a|c[b>>2]&-65536;c[240591]=a>>>8;c[240592]=a;c[240593]=0;return}function aGV(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]&65535;f=(e<<a|e>>>((d^15)>>>0))&65535;c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f|c[b>>2]&-65536;c[240591]=f>>>8;c[240592]=f;c[240594]=e>>>((d^7)>>>0);c[240593]=0;return}function aGW(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&65535;g=f<<d;h=g&65535;if((d|0)==0){c[240594]=0;c[240591]=f>>>8;c[240592]=f;c[240593]=0;return}c[240563]=(c[240563]|0)+(d<<3);i=c[b>>2]&-65536;if(d>>>0<16){c[b>>2]=i|h;j=g>>>8;c[240594]=j;c[240590]=j;c[240591]=h>>>8;c[240592]=h;h=e[11840+(d+1<<1)>>1]|0;j=h&a;if((j|0)==0){k=0}else{k=((j|0)!=(h|0))<<7}c[240593]=k;return}else{c[b>>2]=i;if((d|0)==16){l=a<<8&256}else{l=0}c[240594]=l;c[240590]=l;c[240591]=0;c[240592]=0;c[240593]=((f|0)!=0)<<7;return}}function aGX(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[240594]=c[240590];c[240591]=(c[b>>2]|0)>>>8;e=c[b>>2]&65535;c[240592]=e;c[240593]=0;return}else{a=(d>>>0)%17|0;f=(c[240590]|0)>>>8<<16&65536|c[b>>2]&65535;g=f<<a|f>>>((17-a|0)>>>0);c[240563]=(c[240563]|0)+(d<<3);d=g>>>8;c[240590]=d;c[240594]=d;d=g&65535;c[b>>2]=d|c[b>>2]&-65536;c[240591]=d>>>8;e=d;c[240592]=e;c[240593]=0;return}}function aGY(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&15;d=c[b>>2]|0;f=d&65535;g=f<<e;h=(g|f>>>((16-e|0)>>>0))&65535;if((a|0)==0){c[240594]=0;c[240591]=f>>>8;c[240592]=f;c[240593]=0;return}c[240563]=(c[240563]|0)+(a<<3);if((e|0)==0){c[240594]=d<<8&256;c[240591]=f>>>8;c[240592]=f;c[240593]=0;return}else{c[b>>2]=c[b>>2]&-65536|h;c[240594]=g>>>8;c[240591]=h>>>8;c[240592]=h;c[240593]=0;return}}function aGZ(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e<<a;c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f;c[240591]=f>>>24;c[240592]=f;f=e>>>((23-d|0)>>>0);c[240594]=f;c[240590]=f;f=c[11576+(d+2<<2)>>2]|0;d=f&e;if((d|0)==0){g=0;c[240593]=g;return}g=((d|0)!=(f|0))<<7;c[240593]=g;return}function aG_(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e<<a;c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f;c[240591]=f>>>24;c[240592]=f;f=e>>>((23-d|0)>>>0);c[240594]=f;c[240590]=f;c[240593]=0;return}function aG$(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=32-d|0;g=((f>>>0<32?e>>>(f>>>0):0)|e<<a)&~(1<<d)|((c[240590]|0)>>>8&1)<<d;c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=g;b=((1<<(d^31)&e|0)!=0)<<8;c[240590]=b;c[240594]=b;c[240591]=g>>>24;c[240592]=g;c[240593]=0;return}function aG0(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e<<a|e>>>((d^31)>>>0);c[240563]=(a<<3)+(c[240563]|0);c[b>>2]=f;c[240591]=f>>>24;c[240592]=f;c[240594]=e>>>((23-d|0)>>>0);c[240593]=0;return}function aG1(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a<<d;if((d|0)==0){c[240594]=0;c[240591]=a>>>24;c[240592]=a;c[240593]=0;return}c[240563]=(c[240563]|0)+(d<<3);if(d>>>0<32){c[b>>2]=e;f=a>>>((32-d|0)>>>0)<<8;c[240594]=f;c[240590]=f;c[240591]=e>>>24;c[240592]=e;e=c[11576+(d+1<<2)>>2]|0;f=e&a;if((f|0)==0){g=0}else{g=((f|0)!=(e|0))<<7}c[240593]=g;return}else{c[b>>2]=0;if((d|0)==32){h=a<<8&256}else{h=0}c[240594]=h;c[240590]=h;c[240591]=0;c[240592]=0;c[240593]=((a|0)!=0)<<7;return}}function aG2(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]&255;e=a<<d;f=e&255;if((d|0)==0){c[240594]=0;c[240591]=a;c[240592]=a;c[240593]=0;return}c[240563]=(c[240563]|0)+(d<<3);a=c[b>>2]&-256;if(d>>>0<9){c[b>>2]=a|f;c[240594]=e;c[240590]=e;c[240591]=f;c[240592]=f;c[240593]=0;return}else{c[b>>2]=a;aIv(962360,0,20);return}}function aG3(){var a=0,b=0,d=0,e=0,f=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]&65535;e=a<<d;f=e&65535;if((d|0)==0){c[240594]=0;c[240591]=a>>>8;c[240592]=a;c[240593]=0;return}c[240563]=(c[240563]|0)+(d<<3);a=c[b>>2]&-65536;if(d>>>0<17){c[b>>2]=a|f;d=e>>>8;c[240594]=d;c[240590]=d;c[240591]=f>>>8;c[240592]=f;c[240593]=0;return}else{c[b>>2]=a;aIv(962360,0,20);return}}function aG4(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a<<d;if((d|0)==0){c[240594]=0;c[240591]=a>>>24;c[240592]=a;c[240593]=0;return}c[240563]=(c[240563]|0)+(d<<3);if(d>>>0<32){c[b>>2]=e;f=a>>>((32-d|0)>>>0)<<8;c[240594]=f;c[240590]=f;c[240591]=e>>>24;c[240592]=e;c[240593]=0;return}c[b>>2]=0;if((d|0)==32){g=a<<8&256}else{g=0}c[240594]=g;c[240590]=g;c[240591]=0;c[240592]=0;c[240593]=0;return}function aG5(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]&63;a=(d>>>0)%33|0;e=c[b>>2]|0;f=33-a|0;g=a-1|0;h=c[240590]|0;i=((a>>>0<32?e<<a:0)|(f>>>0<32?e>>>(f>>>0):0))&~(1<<g)|(h>>>8&1)<<g;if((d|0)!=0){c[240563]=(c[240563]|0)+(d<<3)}if((a|0)==0){j=e;k=h;c[240594]=k;l=j>>>24;c[240591]=l;c[240592]=j;c[240593]=0;return}c[b>>2]=i;b=((1<<32-a&e|0)!=0)<<8;c[240590]=b;j=i;k=b;c[240594]=k;l=j>>>24;c[240591]=l;c[240592]=j;c[240593]=0;return}function aG6(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[240587]|0;b=962260+((a&7)<<2)|0;d=c[962260+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&31;d=c[b>>2]|0;f=32-e|0;g=(f>>>0<32?d>>>(f>>>0):0)|d<<e;if((a|0)==0){h=d;i=0}else{c[240563]=(c[240563]|0)+(a<<3);c[b>>2]=g;h=g;i=d>>>((f&31)>>>0)<<8}c[240594]=i;c[240591]=h>>>24;c[240592]=h;c[240593]=0;return}function aG7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=g<<1;h=f&65534;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f&65535}else{fj[i&511](a&16777215,h)}c[240591]=h>>>8;c[240592]=h;h=g>>>7;c[240594]=h;c[240590]=h;h=g&49152;if((h|0)==0){j=0;c[240593]=j;return}j=((h|0)!=49152)<<7;c[240593]=j;return}function aG8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g<<1;h=f&65534;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535}else{fj[i&511](d&16777215,h)}c[240591]=h>>>8;c[240592]=h;h=g>>>7;c[240594]=h;c[240590]=h;h=g&49152;if((h|0)==0){j=0;c[240593]=j;return}j=((h|0)!=49152)<<7;c[240593]=j;return}function aG9(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g<<1;h=f&65534;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535}else{fj[i&511](d&16777215,h)}c[240591]=h>>>8;c[240592]=h;h=g>>>7;c[240594]=h;c[240590]=h;h=g&49152;if((h|0)==0){j=0;c[240593]=j;return}j=((h|0)!=49152)<<7;c[240593]=j;return}function aHa(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=g<<1;h=d&65534;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535}else{fj[i&511](f&16777215,h)}c[240591]=h>>>8;c[240592]=h;h=g>>>7;c[240594]=h;c[240590]=h;h=g&49152;if((h|0)==0){j=0;c[240593]=j;return}j=((h|0)!=49152)<<7;c[240593]=j;return}function aHb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=h<<1;f=a&65534;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=a&65535}else{fj[i&511](d&16777215,f)}c[240591]=f>>>8;c[240592]=f;f=h>>>7;c[240594]=f;c[240590]=f;f=h&49152;if((f|0)==0){j=0;c[240593]=j;return}j=((f|0)!=49152)<<7;c[240593]=j;return}function aHc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g<<1;h=f&65534;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535}else{fj[i&511](d&16777215,h)}c[240591]=h>>>8;c[240592]=h;h=g>>>7;c[240594]=h;c[240590]=h;h=g&49152;if((h|0)==0){j=0;c[240593]=j;return}j=((h|0)!=49152)<<7;c[240593]=j;return}function aHd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=h<<1;i=d&65534;j=c[957136+(g*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=d&65535}else{fj[j&511](f&16777215,i)}c[240591]=i>>>8;c[240592]=i;i=h>>>7;c[240594]=i;c[240590]=i;i=h&49152;if((i|0)==0){k=0;c[240593]=k;return}k=((i|0)!=49152)<<7;c[240593]=k;return}function aHe(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=g>>>1;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f&65535;c[240591]=0;c[240592]=f;i=g<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}else{fj[h&511](a&16777215,f);c[240591]=0;c[240592]=f;i=g<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}}function aHf(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g>>>1;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;c[240591]=0;c[240592]=f;i=g<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}else{fj[h&511](d&16777215,f);c[240591]=0;c[240592]=f;i=g<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}}function aHg(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g>>>1;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;c[240591]=0;c[240592]=f;i=g<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}else{fj[h&511](d&16777215,f);c[240591]=0;c[240592]=f;i=g<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}}function aHh(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=g>>>1;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;c[240591]=0;c[240592]=d;i=g<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}else{fj[h&511](f&16777215,d);c[240591]=0;c[240592]=d;i=g<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}}function aHi(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=h>>>1;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=a&65535;c[240591]=0;c[240592]=a;i=h<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}else{fj[f&511](d&16777215,a);c[240591]=0;c[240592]=a;i=h<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}}function aHj(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g>>>1;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;c[240591]=0;c[240592]=f;i=g<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}else{fj[h&511](d&16777215,f);c[240591]=0;c[240592]=f;i=g<<8;c[240590]=i;c[240594]=i;c[240593]=0;return}}function aHk(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=h>>>1;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=d&65535;c[240591]=0;c[240592]=d;j=h<<8;c[240590]=j;c[240594]=j;c[240593]=0;return}else{fj[i&511](f&16777215,d);c[240591]=0;c[240592]=d;j=h<<8;c[240590]=j;c[240594]=j;c[240593]=0;return}}function aHl(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=g<<1;h=f&65534;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f&65535}else{fj[i&511](a&16777215,h)}c[240591]=h>>>8;c[240592]=h;h=g>>>7;c[240594]=h;c[240590]=h;c[240593]=0;return}function aHm(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g<<1;h=f&65534;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240590]=k;c[240593]=0;return}else{fj[i&511](d&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240590]=k;c[240593]=0;return}}function aHn(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g<<1;h=f&65534;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240590]=k;c[240593]=0;return}else{fj[i&511](d&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240590]=k;c[240593]=0;return}}function aHo(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=g<<1;h=d&65534;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240590]=k;c[240593]=0;return}else{fj[i&511](f&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240590]=k;c[240593]=0;return}}function aHp(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=h<<1;f=a&65534;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=a&65535;j=f>>>8;c[240591]=j;c[240592]=f;k=h>>>7;c[240594]=k;c[240590]=k;c[240593]=0;return}else{fj[i&511](d&16777215,f);j=f>>>8;c[240591]=j;c[240592]=f;k=h>>>7;c[240594]=k;c[240590]=k;c[240593]=0;return}}function aHq(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g<<1;h=f&65534;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240590]=k;c[240593]=0;return}else{fj[i&511](d&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240590]=k;c[240593]=0;return}}function aHr(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=h<<1;i=d&65534;j=c[957136+(g*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=d&65535;k=i>>>8;c[240591]=k;c[240592]=i;l=h>>>7;c[240594]=l;c[240590]=l;c[240593]=0;return}else{fj[j&511](f&16777215,i);k=i>>>8;c[240591]=k;c[240592]=i;l=h>>>7;c[240594]=l;c[240590]=l;c[240593]=0;return}}function aHs(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=((c[240590]|0)>>>8<<16&65536|g)>>>1;h=(f|g<<16)>>>8;c[240590]=h;c[240594]=h;h=f&65535;g=c[957136+(d*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f&65535;i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;return}else{fj[g&511](a&16777215,h);i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;return}}function aHt(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=((c[240590]|0)>>>8<<16&65536|g)>>>1;h=(f|g<<16)>>>8;c[240590]=h;c[240594]=h;h=f&65535;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;return}else{fj[g&511](d&16777215,h);i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;return}}function aHu(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=((c[240590]|0)>>>8<<16&65536|g)>>>1;h=(f|g<<16)>>>8;c[240590]=h;c[240594]=h;h=f&65535;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;return}else{fj[g&511](d&16777215,h);i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;return}}function aHv(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=((c[240590]|0)>>>8<<16&65536|g)>>>1;h=(d|g<<16)>>>8;c[240590]=h;c[240594]=h;h=d&65535;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;return}else{fj[g&511](f&16777215,h);i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;return}}function aHw(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=((c[240590]|0)>>>8<<16&65536|h)>>>1;f=(a|h<<16)>>>8;c[240590]=f;c[240594]=f;f=a&65535;h=c[957136+(g*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=a&65535;i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;return}else{fj[h&511](d&16777215,f);i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;return}}function aHx(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=((c[240590]|0)>>>8<<16&65536|g)>>>1;h=(f|g<<16)>>>8;c[240590]=h;c[240594]=h;h=f&65535;g=c[957136+(a*20|0)>>2]|0;if((g|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;return}else{fj[g&511](d&16777215,h);i=h>>>8;c[240591]=i;c[240592]=h;c[240593]=0;return}}function aHy(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=((c[240590]|0)>>>8<<16&65536|h)>>>1;i=(d|h<<16)>>>8;c[240590]=i;c[240594]=i;i=d&65535;h=c[957136+(g*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=d&65535;j=i>>>8;c[240591]=j;c[240592]=i;c[240593]=0;return}else{fj[h&511](f&16777215,i);j=i>>>8;c[240591]=j;c[240592]=i;c[240593]=0;return}}function aHz(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=(c[240590]|0)>>>8<<16&65536|g;g=f<<1|f>>>16;f=g>>>8;c[240590]=f;c[240594]=f;f=g&65535;h=c[957136+(d*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=g&65535;i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;return}else{fj[h&511](a&16777215,f);i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;return}}function aHA(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=(c[240590]|0)>>>8<<16&65536|g;g=f<<1|f>>>16;f=g>>>8;c[240590]=f;c[240594]=f;f=g&65535;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;return}else{fj[h&511](d&16777215,f);i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;return}}function aHB(){var a=0,d=0,f=0,g=0,h=0,i=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=(c[240590]|0)>>>8<<16&65536|g;g=f<<1|f>>>16;f=g>>>8;c[240590]=f;c[240594]=f;f=g&65535;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;return}else{fj[h&511](d&16777215,f);i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;return}}function aHC(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=(c[240590]|0)>>>8<<16&65536|g;g=d<<1|d>>>16;d=g>>>8;c[240590]=d;c[240594]=d;d=g&65535;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=g&65535;i=d>>>8;c[240591]=i;c[240592]=d;c[240593]=0;return}else{fj[h&511](f&16777215,d);i=d>>>8;c[240591]=i;c[240592]=d;c[240593]=0;return}}function aHD(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=(c[240590]|0)>>>8<<16&65536|h;h=a<<1|a>>>16;a=h>>>8;c[240590]=a;c[240594]=a;a=h&65535;f=c[957136+(g*20|0)>>2]|0;if((f|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=h&65535;i=a>>>8;c[240591]=i;c[240592]=a;c[240593]=0;return}else{fj[f&511](d&16777215,a);i=a>>>8;c[240591]=i;c[240592]=a;c[240593]=0;return}}function aHE(){var a=0,d=0,f=0,g=0,h=0,i=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=(c[240590]|0)>>>8<<16&65536|g;g=f<<1|f>>>16;f=g>>>8;c[240590]=f;c[240594]=f;f=g&65535;h=c[957136+(a*20|0)>>2]|0;if((h|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=g&65535;i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;return}else{fj[h&511](d&16777215,f);i=f>>>8;c[240591]=i;c[240592]=f;c[240593]=0;return}}function aHF(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=(c[240590]|0)>>>8<<16&65536|h;h=d<<1|d>>>16;d=h>>>8;c[240590]=d;c[240594]=d;d=h&65535;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=h&65535;j=d>>>8;c[240591]=j;c[240592]=d;c[240593]=0;return}else{fj[i&511](f&16777215,d);j=d>>>8;c[240591]=j;c[240592]=d;c[240593]=0;return}}function aHG(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=g>>>1|g<<15;h=f&65535;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g<<8;c[240594]=k;c[240593]=0;return}else{fj[i&511](a&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g<<8;c[240594]=k;c[240593]=0;return}}function aHH(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g>>>1|g<<15;h=f&65535;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g<<8;c[240594]=k;c[240593]=0;return}else{fj[i&511](d&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g<<8;c[240594]=k;c[240593]=0;return}}function aHI(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g>>>1|g<<15;h=f&65535;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g<<8;c[240594]=k;c[240593]=0;return}else{fj[i&511](d&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g<<8;c[240594]=k;c[240593]=0;return}}function aHJ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=g>>>1|g<<15;h=d&65535;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g<<8;c[240594]=k;c[240593]=0;return}else{fj[i&511](f&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g<<8;c[240594]=k;c[240593]=0;return}}function aHK(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=h>>>1|h<<15;f=a&65535;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=a&65535;j=f>>>8;c[240591]=j;c[240592]=f;k=h<<8;c[240594]=k;c[240593]=0;return}else{fj[i&511](d&16777215,f);j=f>>>8;c[240591]=j;c[240592]=f;k=h<<8;c[240594]=k;c[240593]=0;return}}function aHL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g>>>1|g<<15;h=f&65535;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g<<8;c[240594]=k;c[240593]=0;return}else{fj[i&511](d&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g<<8;c[240594]=k;c[240593]=0;return}}function aHM(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=h>>>1|h<<15;i=d&65535;j=c[957136+(g*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=d&65535;k=i>>>8;c[240591]=k;c[240592]=i;l=h<<8;c[240594]=l;c[240593]=0;return}else{fj[j&511](f&16777215,i);k=i>>>8;c[240591]=k;c[240592]=i;l=h<<8;c[240594]=l;c[240593]=0;return}}function aHN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=a>>>16&255;f=c[957128+(d*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]|0}else{g=fl[f&255](a&16777215)|0}f=g<<1|g>>>15;h=f&65535;i=c[957136+(d*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(d*20|0)>>2]|0)+(a&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240593]=0;return}else{fj[i&511](a&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240593]=0;return}}function aHO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=c[a>>2]|0;c[a>>2]=d+2;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g<<1|g>>>15;h=f&65535;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240593]=0;return}else{fj[i&511](d&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240593]=0;return}}function aHP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=962260+((c[240587]&7|8)<<2)|0;d=(c[a>>2]|0)-2|0;c[a>>2]=d;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g<<1|g>>>15;h=f&65535;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240593]=0;return}else{fj[i&511](d&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240593]=0;return}}function aHQ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=(b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0)+a|0;a=f>>>16&255;d=c[957128+(a*20|0)>>2]|0;if((d|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]|0}else{g=fl[d&255](f&16777215)|0}d=g<<1|g>>>15;h=d&65535;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(f&65535)>>1]=d&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240593]=0;return}else{fj[i&511](f&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240593]=0;return}}function aHR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[962260+((c[240587]&7|8)<<2)>>2]|0;d=c[240581]|0;c[240581]=d+2;f=e[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]|0;d=c[962260+(f>>>12<<2)>>2]|0;if((f&2048|0)==0){g=d<<16>>16}else{g=d}d=(f<<24>>24)+a+g|0;g=d>>>16&255;a=c[957128+(g*20|0)>>2]|0;if((a|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]|0}else{h=fl[a&255](d&16777215)|0}a=h<<1|h>>>15;f=a&65535;i=c[957136+(g*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(g*20|0)>>2]|0)+(d&65535)>>1]=a&65535;j=f>>>8;c[240591]=j;c[240592]=f;k=h>>>7;c[240594]=k;c[240593]=0;return}else{fj[i&511](d&16777215,f);j=f>>>8;c[240591]=j;c[240592]=f;k=h>>>7;c[240594]=k;c[240593]=0;return}}function aHS(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[240581]|0;c[240581]=a+2;d=b[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;a=d>>>16&255;f=c[957128+(a*20|0)>>2]|0;if((f|0)==0){g=e[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]|0}else{g=fl[f&255](d&16777215)|0}f=g<<1|g>>>15;h=f&65535;i=c[957136+(a*20|0)>>2]|0;if((i|0)==0){b[(c[957120+(a*20|0)>>2]|0)+(d&65535)>>1]=f&65535;j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240593]=0;return}else{fj[i&511](d&16777215,h);j=h>>>8;c[240591]=j;c[240592]=h;k=g>>>7;c[240594]=k;c[240593]=0;return}}function aHT(){return 1}function aHU(a){a=a|0;c[222036]=a;return}function aHV(a){a=a|0;return}function aHW(a){a=a|0;c[3579458]=a;return}function aHX(a){a=a|0;c[423054]=a;return}function aHY(a){a=a|0;c[423052]=a;return}function aHZ(a,b){a=a|0;b=b|0;return}function aH_(){return 1036288}function aH$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a>>31&4;e=d|24;f=(a|0)>-1;g=f?a:-a|0;a=b<<16>>16;h=b<<16>>16>-1;b=h?a:-a|0;if((g>>16|0)>=(b|0)){i=e+8|0;j=i<<1;k=c[240563]|0;l=k+j|0;c[240563]=l;return}a=(g|0)/(b|0)|0;b=e+220|0;do{if(h){if(f){m=e+216|0;break}else{m=d|248;break}}else{m=b}}while(0);b=(a&2|0)==0?m+4|0:m;m=(a&4|0)==0?b+4|0:b;b=(a&8|0)==0?m+4|0:m;m=(a&16|0)==0?b+4|0:b;b=(a&32|0)==0?m+4|0:m;m=(a&64|0)==0?b+4|0:b;b=(a&128|0)==0?m+4|0:m;m=(a&256|0)==0?b+4|0:b;b=(a&512|0)==0?m+4|0:m;m=(a&1024|0)==0?b+4|0:b;b=(a&2048|0)==0?m+4|0:m;m=(a&4096|0)==0?b+4|0:b;b=(a&8192|0)==0?m+4|0:m;m=(a&16384|0)==0?b+4|0:b;i=(a&32768|0)==0?m+4|0:m;j=i<<1;k=c[240563]|0;l=k+j|0;c[240563]=l;return}function aH0(b){b=b|0;c[b>>2]=726120;c[b+4>>2]=724688;c[b+8>>2]=723656;a[b+13|0]=0;a[b+12|0]=1;return}function aH1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[240581]|0;c[240581]=a+4;d=e[(c[957120+((a>>>16&255)*20|0)>>2]|0)+(a&65535)>>1]|0;f=a+2|0;a=e[(c[957120+((f>>>16&255)*20|0)>>2]|0)+(f&65535)>>1]|0;f=a|d<<16;g=d&255;d=c[957128+(g*20|0)>>2]|0;if((d|0)==0){h=e[(c[957120+(g*20|0)>>2]|0)+a>>1]|0}else{h=fl[d&255](f&16777215)|0}d=h<<1|h>>>15;i=d&65535;j=c[957136+(g*20|0)>>2]|0;if((j|0)==0){b[(c[957120+(g*20|0)>>2]|0)+a>>1]=d&65535;k=i>>>8;c[240591]=k;c[240592]=i;l=h>>>7;c[240594]=l;c[240593]=0;return}else{fj[j&511](f&16777215,i);k=i>>>8;c[240591]=k;c[240592]=i;l=h>>>7;c[240594]=l;c[240593]=0;return}}function aH2(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[240589]|0;f=d<<11|c[240588]|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;c[240588]=0;c[962328+(d<<2)>>2]=c[240580];c[240589]=4;d=(c[240581]|0)-2|0;g=(c[240586]|0)-4|0;c[240580]=g;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[240580]|0)+2|0;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;d=(c[240580]|0)-2|0;c[240580]=d;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;f=c[239282]|0;if((f|0)==0){d=c[239280]|0;h=e[d+46>>1]|0|(e[d+44>>1]|0)<<16;c[240581]=h;i=c[240587]|0;j=537288+i|0;k=a[j]|0;l=k&255;m=16-l|0;n=c[240563]|0;o=m+n|0;c[240563]=o;return}else{d=(fl[f&255](44)|0)<<16;h=fl[c[239282]&255](46)|0|d;c[240581]=h;i=c[240587]|0;j=537288+i|0;k=a[j]|0;l=k&255;m=16-l|0;n=c[240563]|0;o=m+n|0;c[240563]=o;return}}function aH3(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[240589]|0;f=d<<11|c[240588]|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;c[240588]=0;c[962328+(d<<2)>>2]=c[240580];c[240589]=4;d=c[240581]|0;g=(c[240586]|0)-4|0;c[240580]=g;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[240580]|0)+2|0;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;d=(c[240580]|0)-2|0;c[240580]=d;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;f=a<<2;d=a>>>14&255;g=957128+(d*20|0)|0;h=c[g>>2]|0;if((h|0)==0){i=c[957120+(d*20|0)>>2]|0;d=f&65532;j=e[i+(d|2)>>1]|0|(e[i+d>>1]|0)<<16;c[240581]=j;k=536264+(a<<1)|0;l=b[k>>1]|0;m=l&65535;n=c[240563]|0;o=n+m|0;c[240563]=o;return}else{d=f&16777212;f=(fl[h&255](d)|0)<<16;j=fl[c[g>>2]&255](d|2)|0|f;c[240581]=j;k=536264+(a<<1)|0;l=b[k>>1]|0;m=l&65535;n=c[240563]|0;o=n+m|0;c[240563]=o;return}}function aH4(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[240589]|0;f=d<<11|c[240588]|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1;c[240588]=0;c[962328+(d<<2)>>2]=c[240580];c[240589]=4;d=(c[240581]|0)-2|0;g=(c[240586]|0)-4|0;c[240580]=g;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d>>>16&65535;g=(c[240580]|0)+2|0;b[(c[957120+((g>>>16&255)*20|0)>>2]|0)+(g&65535)>>1]=d&65535;d=(c[240580]|0)-2|0;c[240580]=d;b[(c[957120+((d>>>16&255)*20|0)>>2]|0)+(d&65535)>>1]=f&65535;f=c[239282]|0;if((f|0)==0){d=c[239280]|0;h=e[d+34>>1]|0|(e[d+32>>1]|0)<<16;c[240581]=h;i=c[240587]|0;j=537288+i|0;k=a[j]|0;l=k&255;m=136-l|0;n=c[240563]|0;o=m+n|0;c[240563]=o;return}else{d=(fl[f&255](32)|0)<<16;h=fl[c[239282]&255](34)|0|d;c[240581]=h;i=c[240587]|0;j=537288+i|0;k=a[j]|0;l=k&255;m=136-l|0;n=c[240563]|0;o=m+n|0;c[240563]=o;return}}function aH5(a){a=a|0;c[3118408]=a;fA[a&63](16,6536)|0;return}function aH6(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=i;i=i+65600|0;h=g|0;j=g+65536|0;aIy(j|0,668664,64)|0;k=c9(b|0,697480)|0;do{if((cP(b|0,14585968)|0)==0){l=42835}else{if((cP(b|0,14586480)|0)==0){l=42835;break}if((cP(b|0,14586224)|0)==0){l=42835}}}while(0);if((l|0)==42835){bQ(j|0,64,695480,(m=i,i=i+8|0,c[m>>2]=b,m)|0)|0;i=m}if((k|0)==0){l=c[p>>2]|0;ei(l|0,693376,(m=i,i=i+8|0,c[m>>2]=j,m)|0)|0;i=m;n=0;i=g;return n|0}ec(h|0,65536,1,k|0)|0;ev(k|0,0,2)|0;h=cf(k|0)|0;ev(k|0,0,0)|0;if((h|0)>(e|0)){aS(k|0)|0;e=c[p>>2]|0;a5(691240,27,1,e|0)|0;n=0;i=g;return n|0}ci(j|0,730416,(m=i,i=i+8|0,c[m>>2]=h,m)|0)|0;i=m;ei(c[p>>2]|0,728128,(m=i,i=i+8|0,c[m>>2]=j,m)|0)|0;i=m;if((f|0)!=0){m=b+((aIu(b|0)|0)-3)|0;a[f]=a[m]|0;a[f+1|0]=a[m+1|0]|0;a[f+2|0]=a[m+2|0]|0;a[f+3|0]=0}if((h|0)>65536){f=h-65537&-65536;m=d;b=h;while(1){ec(m|0,65536,1,k|0)|0;j=b-65536|0;if((j|0)>65536){m=m+65536|0;b=j}else{break}}o=d+(f+65536)|0;q=h-65536-f|0}else{o=d;q=h}ec(o|0,q|0,1,k|0)|0;aS(k|0)|0;n=h;i=g;return n|0}function aH7(a){a=a|0;var b=0;b=a;c[b>>2]=c[494726];c[b+4>>2]=c[494727];c[b+8>>2]=c[494728];c[b+12>>2]=c[494729];c[b+16>>2]=c[494730];c[b+20>>2]=c[494731];c[b+24>>2]=c[494732];c[b+28>>2]=c[494733];c[b+32>>2]=c[494734];c[b+36>>2]=c[494735];return}function aH8(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((f|0)!=1036288){g=0;return g|0}aIy(e|0,724496,16)|0;f=a[937424]|0;h=(f&-127)<<24>>24==-128;i=e+16|0;if(h){aIy(i|0,756920,65536)|0;j=e+65552|0;aIy(j|0,736800,8192)|0;a[e+73744|0]=a[736792]|0;j=e+73745|0;x=c[186760]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;k=73749}else{aIy(i|0,756920,8192)|0;k=8208}i=e+k|0;aIy(i|0,1692184,16)|0;i=e+(k+16)|0;aIy(i|0,956096,1024)|0;i=e+(k+1040)|0;aIy(i|0,822600,65536)|0;i=e+(k+66576)|0;aIy(i|0,12474e3,128)|0;i=e+(k+66704)|0;aIy(i|0,822464,128)|0;i=e+(k+66832)|0;aIy(i|0,962712,32)|0;i=e+(k+66864)|0;x=b[7158924]|0;a[i]=x&255;x=x>>8;a[i+1|0]=x&255;i=e+(k+66866)|0;x=b[7158920]|0;a[i]=x&255;x=x>>8;a[i+1|0]=x&255;a[e+(k+66868)|0]=a[12474208]|0;a[e+(k+66869)|0]=a[968008]|0;i=e+(k+66870)|0;x=b[468728]|0;a[i]=x&255;x=x>>8;a[i+1|0]=x&255;i=e+(k+66872)|0;x=b[6236980]|0;a[i]=x&255;x=x>>8;a[i+1|0]=x&255;a[e+(k+66874)|0]=a[1692344]|0;a[e+(k+66875)|0]=a[888136]|0;i=e+(k+66876)|0;x=c[3118496]|0;a[i]=x&255;x=x>>8;a[i+1|0]=x&255;x=x>>8;a[i+2|0]=x&255;x=x>>8;a[i+3|0]=x&255;a[e+(k+66880)|0]=a[12473968]|0;i=e+(k+66881)|0;x=b[6236988]|0;a[i]=x&255;x=x>>8;a[i+1|0]=x&255;i=e+(k+66883)|0;x=c[3118616]|0;a[i]=x&255;x=x>>8;a[i+1|0]=x&255;x=x>>8;a[i+2|0]=x&255;x=x>>8;a[i+3|0]=x&255;i=k+66887|0;j=e+i|0;if(h){aIy(j|0,747592,3336)|0;l=k+66889|0;m=0;n=3336;while(1){a[e+(n+i)|0]=((c[747592+(m*360|0)>>2]|0)-749796|0)>>>7&255;o=n|2;a[e+(o+i)|0]=((c[747668+(m*360|0)>>2]|0)-749796|0)>>>7&255;a[e+(l+o)|0]=((c[747744+(m*360|0)>>2]|0)-749796|0)>>>7&255;a[e+((n|6)+i)|0]=((c[747820+(m*360|0)>>2]|0)-749796|0)>>>7&255;o=m+1|0;if((o|0)<6){m=o;n=n+8|0}else{p=3384;break}}}else{aIy(j|0,750928,5984)|0;p=5984}j=e+(p+i)|0;aIy(j|0,14582176,184)|0;j=e+(k+67071+p)|0;x=c[494744]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=k+67075+p|0;if(h){p=e+j|0;x=c[291651]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+4)|0;x=c[291652]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+8)|0;x=c[291653]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+12)|0;x=c[291654]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+16)|0;x=c[291655]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+20)|0;x=c[291656]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+24)|0;x=c[291657]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+28)|0;x=c[291658]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+32)|0;x=c[291659]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+36)|0;x=c[291660]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+40)|0;x=c[291661]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+44)|0;x=c[291662]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+48)|0;x=c[291663]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+52)|0;x=c[291664]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+56)|0;x=c[291665]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+60)|0;x=c[291666]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+64)|0;x=c[291667]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+68)|0;x=(c[291675]<<11|c[291674]|c[291681]|(c[291676]|0)>>>4&16|(c[291677]|0)>>>4&8|((c[291678]|0)==0)<<2|(c[291679]|0)>>>6&2|(c[291680]|0)>>>8&1)&65535;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;p=e+(j+70)|0;x=(c[291675]|0)!=0?c[291668]|0:c[291666]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+74)|0;x=(c[291675]|0)!=0?c[291666]|0:c[291672]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+78)|0;x=c[291649]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+82)|0;x=c[291682]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;p=e+(j+86)|0;x=c[291683]|0;a[p]=x&255;x=x>>8;a[p+1|0]=x&255;x=x>>8;a[p+2|0]=x&255;x=x>>8;a[p+3|0]=x&255;q=j+90|0}else{q=j}j=e+q|0;aIy(j|0,14318648,76)|0;j=q+76|0;if(f<<24>>24!=-124){if(h){r=0}else{h=c[235938]|0;f=e+j|0;x=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[f]=x&255;x=x>>8;a[f+1|0]=x&255;x=x>>8;a[f+2|0]=x&255;x=x>>8;a[f+3|0]=x&255;g=1;return g|0}do{f=c[1161464+(r*20|0)>>2]|0;if((f|0)==(c[234374]|0)){a[e+(r+j)|0]=-1}else{a[e+(r+j)|0]=(f-1987672|0)>>>16&255}r=r+1|0;}while((r|0)<64);r=e+(q+140)|0;x=c[3118362]|0;a[r]=x&255;x=x>>8;a[r+1|0]=x&255;x=x>>8;a[r+2|0]=x&255;x=x>>8;a[r+3|0]=x&255;r=c[234362]|0;if((r|0)==0){g=1;return g|0}f=e+(q+144)|0;h=r|0;aIy(f|0,h|0,2048)|0;h=e+(q+2192)|0;f=r+131072|0;aIy(h|0,f|0,131072)|0;f=e+(q+133264)|0;h=r+262144|0;aIy(f|0,h|0,1280)|0;g=1;return g|0}h=e+j|0;x=558121811;a[h]=x&255;x=x>>8;a[h+1|0]=x&255;x=x>>8;a[h+2|0]=x&255;x=x>>8;a[h+3|0]=x&255;h=q+80|0;j=e+h|0;aIy(j|0,11629664,512)|0;j=e+(q+592)|0;x=c[2907544]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+596)|0;x=c[2907546]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;a[e+(q+600)|0]=a[11630188]|0;a[e+(q+601)|0]=a[11630189]|0;j=e+(q+602)|0;x=c[2907548]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+606)|0;x=c[2907549]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+610)|0;x=c[2907550]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;a[e+(q+614)|0]=a[11630212]|0;a[e+(q+615)|0]=a[11630213]|0;j=e+(q+616)|0;x=b[5815107]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;j=e+(q+618)|0;x=c[2907554]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+622)|0;x=(c[2907551]|0)-11359328|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+626)|0;x=(c[2907552]|0)-11359328|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+630)|0;f=c[2989674]|0;do{if((f|0)==194){s=1}else{if((f|0)==34){s=2;break}if((f|0)==74){s=3;break}if((f|0)==196){s=4;break}s=(f|0)==42?5:0}}while(0);aIy(j|0,11958668,18768)|0;a[e+(q+19398)|0]=s;s=e+(q+19399)|0;x=c[2994359]|0;a[s]=x&255;x=x>>8;a[s+1|0]=x&255;x=x>>8;a[s+2|0]=x&255;x=x>>8;a[s+3|0]=x&255;s=e+(q+19403)|0;x=c[2994360]|0;a[s]=x&255;x=x>>8;a[s+1|0]=x&255;x=x>>8;a[s+2|0]=x&255;x=x>>8;a[s+3|0]=x&255;s=e+(q+19407)|0;x=c[2994362]|0;a[s]=x&255;x=x>>8;a[s+1|0]=x&255;x=x>>8;a[s+2|0]=x&255;x=x>>8;a[s+3|0]=x&255;s=e+(q+19411)|0;x=c[2994363]|0;a[s]=x&255;x=x>>8;a[s+1|0]=x&255;x=x>>8;a[s+2|0]=x&255;x=x>>8;a[s+3|0]=x&255;s=e+(q+19415)|0;x=c[2994364]|0;a[s]=x&255;x=x>>8;a[s+1|0]=x&255;x=x>>8;a[s+2|0]=x&255;x=x>>8;a[s+3|0]=x&255;s=e+(q+19419)|0;x=c[2994365]|0;a[s]=x&255;x=x>>8;a[s+1|0]=x&255;x=x>>8;a[s+2|0]=x&255;x=x>>8;a[s+3|0]=x&255;a[e+(q+19423)|0]=a[11977464]|0;s=e+(q+19424)|0;j=((c[2994803]|0)-11979219|0)>>>12&255;aIy(s|0,11979080,128)|0;s=e+(q+19552)|0;x=c[2994802]|0;a[s]=x&255;x=x>>8;a[s+1|0]=x&255;x=x>>8;a[s+2|0]=x&255;x=x>>8;a[s+3|0]=x&255;a[e+(q+19556)|0]=j;a[e+(q+19557)|0]=a[11979216]|0;a[e+(q+19558)|0]=a[11979217]|0;a[e+(q+19559)|0]=a[11979218]|0;j=e+(q+19560)|0;aIy(j|0,11979219,65536)|0;j=e+(q+85096)|0;aIy(j|0,10572896,524288)|0;j=e+(q+609384)|0;if((a[11629666]&4)==0){aIy(j|0,11359328,262144)|0}else{aIy(j|0,11097184,262144)|0}j=e+(q+871528)|0;aIy(j|0,1166584,12)|0;j=e+(q+871540)|0;aIy(j|0,962240,12)|0;j=e+(q+871552)|0;x=b[(c[290366]|0)+114>>1]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;j=e+(q+871554)|0;x=c[240563]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871558)|0;x=c[240596]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871562)|0;x=c[240597]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871566)|0;x=c[240565]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871570)|0;x=c[240566]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871574)|0;x=c[240567]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871578)|0;x=c[240568]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871582)|0;x=c[240569]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871586)|0;x=c[240570]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871590)|0;x=c[240571]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871594)|0;x=c[240572]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871598)|0;x=c[240573]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871602)|0;x=c[240574]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871606)|0;x=c[240575]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871610)|0;x=c[240576]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871614)|0;x=c[240577]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871618)|0;x=c[240578]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871622)|0;x=c[240579]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871626)|0;x=c[240580]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871630)|0;x=c[240581]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871634)|0;x=(c[240589]<<11|c[240588]|c[240595]|(c[240590]|0)>>>4&16|(c[240591]|0)>>>4&8|((c[240592]|0)==0)<<2|(c[240593]|0)>>>6&2|(c[240594]|0)>>>8&1)&65535;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;j=e+(q+871636)|0;x=(c[240589]|0)!=0?c[240582]|0:c[240580]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=e+(q+871640)|0;x=(c[240589]|0)!=0?c[240580]|0:c[240586]|0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;if((a[10441816]|0)==0){g=1;return g|0}else{t=0}do{j=c[1161464+(t*20|0)>>2]|0;if((j|0)==(c[234374]|0)){a[e+(h+(t+871564))|0]=-1}else{a[e+(h+(t+871564))|0]=(j-1987672|0)>>>16&255}t=t+1|0;}while((t|0)<64);t=e+(q+871708)|0;x=c[3118362]|0;a[t]=x&255;x=x>>8;a[t+1|0]=x&255;x=x>>8;a[t+2|0]=x&255;x=x>>8;a[t+3|0]=x&255;t=c[234362]|0;if((t|0)==0){g=1;return g|0}h=e+(q+871712)|0;j=t|0;aIy(h|0,j|0,2048)|0;j=e+(q+873760)|0;h=t+131072|0;aIy(j|0,h|0,131072)|0;h=e+(q+1004832)|0;q=t+262144|0;aIy(h|0,q|0,1280)|0;g=1;return g|0}function aH9(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=i;i=i+64|0;j=h|0;k=h+32|0;l=h+56|0;if((g|0)!=1036288){m=0;i=h;return m|0}g=k|0;n=l|0;aIy(g|0,f|0,16)|0;a[k+16|0]=0;if((aID(g|0,724496,11)|0)!=0){m=1;i=h;return m|0}if((a[k+11|0]|0)<49){m=1;i=h;return m|0}if((a[k+13|0]|0)<55){m=1;i=h;return m|0}if((a[k+15|0]|0)<49){m=1;i=h;return m|0}ky();c[291327]=150;c[291328]=110;c[291329]=216;c[291330]=264;c[186632]=108;c[186633]=116;c[291367]=150;c[291368]=110;c[291369]=216;c[291370]=264;c[186648]=108;c[186649]=116;c[291407]=150;c[291408]=110;c[291409]=216;c[291410]=264;c[186664]=108;c[186665]=116;c[291447]=150;c[291448]=110;c[291449]=216;c[291450]=264;c[186680]=108;c[186681]=116;k=a[937424]|0;g=f+16|0;if((k&-127)<<24>>24==-128){aIy(756920,g|0,65536)|0;o=f+65552|0;aIy(736800,o|0,8192)|0;o=a[f+73744|0]|0;a[736792]=o;p=f+73745|0;c[186760]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;if(o<<24>>24==3){c[291167]=2;c[291168]=206;c[291169]=22;c[291170]=26;o=f+73749|0;aIy(1692184,o|0,16)|0}else{c[291167]=100;c[291168]=92;c[291169]=278;c[291170]=84;o=f+73749|0;aIy(1692184,o|0,16)|0}q=a[9808]|a[12474172]&1|32;r=73765}else{aIy(756920,g|0,8192)|0;g=f+8208|0;aIy(1692184,g|0,16)|0;q=(d[9808]|0)>>>1|-128;r=8224}a[1692184]=q;q=f+r|0;g=j|0;aIy(956096,q|0,1024)|0;q=f+(r|1024)|0;aIy(822600,q|0,65536)|0;q=f+(r+66560)|0;aIy(12474e3,q|0,128)|0;q=f+(r+66688)|0;aIy(822464,q|0,128)|0;q=f+(r+66816)|0;aIy(g|0,q|0,32)|0;L52271:do{if(k<<24>>24>-1){if((k&255)>16){q=0;while(1){a[968008]=1;b[7158920]=d[j+q|0]|0;jU(q|128);q=q+1|0;if((q|0)>=16){break L52271}}}a[968008]=1;b[7158920]=d[g]|0;jV(128);a[968008]=1;b[7158920]=d[j+1|0]|0;jV(129);q=a[j+2|0]|0;o=q&255;b[7158920]=o;a[12474208]=2;b[7158924]=o|512;a[968008]=0;p=c[3579678]|0;s=a[962713]|0;a[962714]=q;b[484136]=o<<10&-8192;o=b[444104]|0;q=o&65535;t=c[3446841]|0;do{if((q|0)<(t|0)){if((s&64)==0){u=p;v=s;y=o;z=t;break}if(((c[290364]|0)+860|0)>>>0<p>>>0){u=p;v=s;y=o;z=t;break}kv(q);u=c[3579678]|0;v=a[962713]|0;y=b[444104]|0;z=c[3446841]|0}else{u=p;v=s;y=o;z=t}}while(0);t=a[j+3|0]|0;b[7158920]=t&255;a[12474208]=2;o=t&255;b[7158924]=(o|768)&1023;a[968008]=0;a[962715]=t;b[484128]=((a[962724]&1)==0?-2048:-4096)&(o<<10&65535);o=y&65535;do{if((o|0)<(z|0)){if((v&64)==0){A=u;B=v;C=y;D=z;break}if(((c[290364]|0)+860|0)>>>0<u>>>0){A=u;B=v;C=y;D=z;break}kv(o);A=c[3579678]|0;B=a[962713]|0;C=b[444104]|0;D=c[3446841]|0}else{A=u;B=v;C=y;D=z}}while(0);o=a[j+4|0]|0;b[7158920]=o&255;a[12474208]=2;t=o&255;b[7158924]=(t|1024)&1279;a[968008]=0;a[962716]=o;b[484132]=t<<13&65535;t=C&65535;do{if((t|0)<(D|0)){if((B&64)==0){E=A;break}if(((c[290364]|0)+860|0)>>>0<A>>>0){E=A;break}kv(t);E=c[3579678]|0}else{E=A}}while(0);t=a[j+5|0]|0;a[962717]=t;b[478036]=b[478040]&(t&255)<<9;a[962718]=a[j+6|0]|0;t=a[j+7|0]|0;b[7158920]=t&255;a[12474208]=2;o=t&255;b[7158924]=(o|1792)&2047;a[968008]=0;jT(7,o,E)}else{o=0;do{jT(o,d[j+o|0]|0,0);o=o+1|0;}while((o|0)<32)}}while(0);j=f+(r+66848)|0;b[7158924]=(w=d[j]|d[j+1|0]<<8,w<<16>>16);j=f+(r+66850)|0;b[7158920]=(w=d[j]|d[j+1|0]<<8,w<<16>>16);j=a[f+(r+66852)|0]|0;a[12474208]=j;a[968008]=a[f+(r+66853)|0]|0;E=f+(r+66854)|0;A=(w=d[E]|d[E+1|0]<<8,w<<16>>16);b[468728]=A;E=f+(r+66856)|0;b[6236980]=(w=d[E]|d[E+1|0]<<8,w<<16>>16);a[1692344]=a[f+(r+66858)|0]|0;a[888136]=a[f+(r+66859)|0]|0;E=f+(r+66860)|0;c[3118496]=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24;a[12473968]=a[f+(r+66864)|0]|0;E=f+(r+66865)|0;b[6236988]=(w=d[E]|d[E+1|0]<<8,w<<16>>16);E=f+(r+66867)|0;c[3118616]=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24;E=a[962724]|0;c[496912]=((E&1)!=0?190:214)<<((j&15)>>>0<3);j=a[937424]|0;if(j<<24>>24<0){b[468728]=d[888176]|A&-2}if((a[962713]&4)==0){b[7158912]=512;A=0;do{j7(A,e[12474e3+(A<<1)>>1]|0);A=A+1|0;}while((A|0)<32);j7(64,e[12474e3+(d[12736648]<<1&30|32)>>1]|0);F=512}else{b[7158912]=2048;A=e[12474e3+(d[12736648]<<1)>>1]|0;B=(a[962712]&4)==0;D=B?A&73:A;A=(E&8)==0;if(A){E=b[965448+(D<<1)>>1]|0;b[483748]=E;b[483812]=E;G=E}else{b[483748]=b[966472+(D<<1)>>1]|0;b[483812]=b[965448+(D<<1)>>1]|0;G=b[964424+(D<<1)>>1]|0}b[483876]=G;G=1;while(1){D=e[12474e3+(G<<1)>>1]|0;E=B?D&73:D;if(A){D=b[965448+(E<<1)>>1]|0;b[967496+(G<<1)>>1]=D;b[967496+((G|64)<<1)>>1]=D;b[967496+((G|128)<<1)>>1]=D}else{b[967496+(G<<1)>>1]=b[966472+(E<<1)>>1]|0;b[967496+((G|64)<<1)>>1]=b[965448+(E<<1)>>1]|0;b[967496+((G|128)<<1)>>1]=b[964424+(E<<1)>>1]|0}E=G+1|0;if((E|0)<64){G=E}else{F=2048;break}}}aIv(14315776,-1|0,F|0);G=0;do{b[14311680+(G<<1)>>1]=G&65535;G=G+1|0;}while((G|0)<(F|0));F=r+66871|0;G=f+F|0;A=(j&-127)<<24>>24==-128;if(A){aIy(747592,G|0,3336)|0;B=0;E=3336;while(1){D=E|2;c[747592+(B*360|0)>>2]=749796+((a[f+(F+E)|0]&7)<<7);c[747668+(B*360|0)>>2]=749796+((a[f+(F+D)|0]&7)<<7);c[747744+(B*360|0)>>2]=749796+((a[f+(F+(D+2))|0]&7)<<7);c[747820+(B*360|0)>>2]=749796+((a[f+(F+(E|6))|0]&7)<<7);D=B+1|0;if((D|0)<6){B=D;E=E+8|0}else{break}}switch(d[747896]|0){case 0:{c[186977]=12474480;c[186979]=1161352;c[186978]=12474472;c[186981]=1166832;break};case 1:{c[186977]=1161352;c[186979]=1161352;c[186978]=12474472;c[186981]=1166832;break};case 2:{c[186977]=12474472;c[186979]=1161352;c[186978]=12474472;c[186981]=1166832;break};case 3:{c[186977]=12474480;c[186979]=1161352;c[186978]=12474472;c[186981]=12474472;break};case 4:{c[186977]=12474480;c[186979]=968040;c[186978]=12474472;c[186981]=1161352;break};case 5:{c[186977]=0;c[186979]=968040;c[186978]=968040;c[186981]=1166832;break};case 6:{c[186977]=12474480;c[186979]=968040;c[186978]=968040;c[186981]=1161352;break};case 7:{c[186977]=968040;c[186979]=968040;c[186978]=968040;c[186981]=1161352;break};default:{}}c[186980]=968040;switch(d[748256]|0){case 0:{c[187067]=12474480;c[187069]=1161352;c[187068]=12474472;c[187071]=1166832;break};case 1:{c[187067]=1161352;c[187069]=1161352;c[187068]=12474472;c[187071]=1166832;break};case 2:{c[187067]=12474472;c[187069]=1161352;c[187068]=12474472;c[187071]=1166832;break};case 3:{c[187067]=12474480;c[187069]=1161352;c[187068]=12474472;c[187071]=12474472;break};case 4:{c[187067]=12474480;c[187069]=968044;c[187068]=12474472;c[187071]=1161352;break};case 5:{c[187067]=0;c[187069]=968044;c[187068]=968044;c[187071]=1166832;break};case 6:{c[187067]=12474480;c[187069]=968044;c[187068]=968044;c[187071]=1161352;break};case 7:{c[187067]=968044;c[187069]=968044;c[187068]=968044;c[187071]=1161352;break};default:{}}c[187070]=968044;switch(d[748616]|0){case 0:{c[187157]=12474480;c[187159]=1161352;c[187158]=12474472;c[187161]=1166832;break};case 1:{c[187157]=1161352;c[187159]=1161352;c[187158]=12474472;c[187161]=1166832;break};case 2:{c[187157]=12474472;c[187159]=1161352;c[187158]=12474472;c[187161]=1166832;break};case 3:{c[187157]=12474480;c[187159]=1161352;c[187158]=12474472;c[187161]=12474472;break};case 4:{c[187157]=12474480;c[187159]=968048;c[187158]=12474472;c[187161]=1161352;break};case 5:{c[187157]=0;c[187159]=968048;c[187158]=968048;c[187161]=1166832;break};case 6:{c[187157]=12474480;c[187159]=968048;c[187158]=968048;c[187161]=1161352;break};case 7:{c[187157]=968048;c[187159]=968048;c[187158]=968048;c[187161]=1161352;break};default:{}}c[187160]=968048;switch(d[748976]|0){case 3:{c[187247]=12474480;c[187249]=1161352;c[187248]=12474472;c[187251]=12474472;break};case 4:{c[187247]=12474480;c[187249]=968052;c[187248]=12474472;c[187251]=1161352;break};case 5:{c[187247]=0;c[187249]=968052;c[187248]=968052;c[187251]=1166832;break};case 6:{c[187247]=12474480;c[187249]=968052;c[187248]=968052;c[187251]=1161352;break};case 7:{c[187247]=968052;c[187249]=968052;c[187248]=968052;c[187251]=1161352;break};case 0:{c[187247]=12474480;c[187249]=1161352;c[187248]=12474472;c[187251]=1166832;break};case 1:{c[187247]=1161352;c[187249]=1161352;c[187248]=12474472;c[187251]=1166832;break};case 2:{c[187247]=12474472;c[187249]=1161352;c[187248]=12474472;c[187251]=1166832;break};default:{}}c[187250]=968052;switch(d[749336]|0){case 0:{c[187337]=12474480;c[187339]=1161352;c[187338]=12474472;c[187341]=1166832;break};case 1:{c[187337]=1161352;c[187339]=1161352;c[187338]=12474472;c[187341]=1166832;break};case 2:{c[187337]=12474472;c[187339]=1161352;c[187338]=12474472;c[187341]=1166832;break};case 3:{c[187337]=12474480;c[187339]=1161352;c[187338]=12474472;c[187341]=12474472;break};case 4:{c[187337]=12474480;c[187339]=968056;c[187338]=12474472;c[187341]=1161352;break};case 5:{c[187337]=0;c[187339]=968056;c[187338]=968056;c[187341]=1166832;break};case 6:{c[187337]=12474480;c[187339]=968056;c[187338]=968056;c[187341]=1161352;break};case 7:{c[187337]=968056;c[187339]=968056;c[187338]=968056;c[187341]=1161352;break};default:{}}c[187340]=968056;switch(d[749696]|0){case 0:{c[187427]=12474480;c[187429]=1161352;c[187428]=12474472;c[187431]=1166832;break};case 1:{c[187427]=1161352;c[187429]=1161352;c[187428]=12474472;c[187431]=1166832;break};case 2:{c[187427]=12474472;c[187429]=1161352;c[187428]=12474472;c[187431]=1166832;break};case 3:{c[187427]=12474480;c[187429]=1161352;c[187428]=12474472;c[187431]=12474472;break};case 4:{c[187427]=12474480;c[187429]=968060;c[187428]=12474472;c[187431]=1161352;break};case 5:{c[187427]=0;c[187429]=968060;c[187428]=968060;c[187431]=1166832;break};case 6:{c[187427]=12474480;c[187429]=968060;c[187428]=968060;c[187431]=1161352;break};case 7:{c[187427]=968060;c[187429]=968060;c[187428]=968060;c[187431]=1161352;break};default:{}}c[187430]=968060;on(a[12474147]|0);H=3384}else{aIy(750928,G|0,5984)|0;H=5984}G=f+(H+F)|0;aIy(14582176,G|0,184)|0;G=f+(r+67055+H)|0;F=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;c[494744]=F;c[494748]=F;F=r+67059+H|0;H=c[235925]|0;r=c[235926]|0;if(A){c[3184682]=H;c[3184676]=r;c[3645544]=100;c[3645545]=100;c[3645546]=100;c[3645547]=100;c[3645548]=100;c[3645549]=100;c[3645550]=100;c[3645551]=100;c[3645552]=9;c[3645553]=16;ou(0,b[6237075]|0,d[12474146]|0,255);A=f+F|0;c[291651]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+4)|0;c[291652]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+8)|0;c[291653]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+12)|0;c[291654]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+16)|0;c[291655]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+20)|0;c[291656]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+24)|0;c[291657]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+28)|0;c[291658]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+32)|0;c[291659]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+36)|0;c[291660]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+40)|0;c[291661]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+44)|0;c[291662]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+48)|0;c[291663]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+52)|0;c[291664]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+56)|0;c[291665]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+60)|0;G=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;c[291666]=G;A=f+(F+64)|0;c[291667]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=f+(F+68)|0;E=(w=d[A]|d[A+1|0]<<8,w<<16>>16)&65535;c[291674]=E&32768;c[291681]=E&1792;A=E<<4;c[291676]=A&256;c[291677]=A&128;c[291678]=E>>>2&1^1;c[291679]=E<<6&128;c[291680]=E<<8&256;A=E>>>11&4;c[1166672+(c[291675]<<2)>>2]=G;c[291675]=A;c[291666]=c[1166672+(A<<2)>>2];ID();A=f+(F+70)|0;G=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;A=F+74|0;if((c[291675]|0)==0){c[291666]=G;E=f+A|0;c[291672]=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24}else{c[291668]=G;G=f+A|0;c[291666]=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24}G=f+(F+78)|0;c[291649]=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24;G=f+(F+82)|0;c[291682]=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24;G=f+(F+86)|0;c[291683]=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24;I=F+90|0;J=a[937424]|0}else{G=(j&255)>16;c[3184682]=H;c[3184676]=r;c[3645544]=100;c[3645545]=100;c[3645546]=100;c[3645547]=100;c[3645548]=100;c[3645549]=100;c[3645550]=100;c[3645551]=100;c[3645552]=G?9:6;c[3645553]=G?16:15;ou(0,b[6237075]|0,d[12474146]|0,d[1692190]|0);I=F;J=j}j=f+I|0;aIy(14318648,j|0,72)|0;j=I+76|0;c[3579680]=202;if(J<<24>>24!=-124){F=f+j|0;if((J&-127)<<24>>24==-128){nd(F)|0;m=1;i=h;return m|0}else{J=F;F=c[235938]|0;x=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;a[F]=x&255;x=x>>8;a[F+1|0]=x&255;x=x>>8;a[F+2|0]=x&255;x=x>>8;a[F+3|0]=x&255;nj(~a[1692198]);m=1;i=h;return m|0}}F=f+j|0;c[l>>2]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;a[l+4|0]=0;if((aID(n|0,727848,4)|0)!=0){m=1;i=h;return m|0}n=f+(I+80)|0;aIy(11629664,n|0,512)|0;n=f+(I+592)|0;c[2907544]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=f+(I+596)|0;c[2907546]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;a[11630188]=a[f+(I+600)|0]|0;a[11630189]=a[f+(I+601)|0]|0;n=f+(I+602)|0;c[2907548]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=f+(I+606)|0;c[2907549]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=f+(I+610)|0;c[2907550]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;a[11630212]=a[f+(I+614)|0]|0;a[11630213]=a[f+(I+615)|0]|0;n=f+(I+616)|0;b[5815107]=(w=d[n]|d[n+1|0]<<8,w<<16>>16);n=f+(I+618)|0;c[2907554]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=f+(I+622)|0;c[2907551]=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24)+11359328;n=f+(I+626)|0;c[2907552]=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24)+11359328;n=f+(I+630)|0;aIy(11958668,n|0,18768)|0;switch(d[f+(I+19398)|0]|0){case 1:{c[2989674]=194;break};case 2:{c[2989674]=34;break};case 3:{c[2989674]=74;break};case 4:{c[2989674]=196;break};case 5:{c[2989674]=42;break};default:{c[2989674]=0}}n=f+(I+19399)|0;c[2994359]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=f+(I+19403)|0;c[2994360]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=f+(I+19407)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[2994362]=l;n=f+(I+19411)|0;F=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[2994363]=F;n=f+(I+19415)|0;c[2994364]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=f+(I+19419)|0;c[2994365]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;a[11977464]=a[f+(I+19423)|0]|0;n=c[11977484+(l<<4)>>2]|0;j=(F|0)<(n|0)?n:F;do{if((l|0)==0){F=c[2994369]|0;if((F|0)==0){break}n=ab(e[5988733]|0,j)|0;ev(F|0,n|0,0)|0}else{n=c[11977476+(l<<4)>>2]|0;if((n|0)==0){break}F=(j*2352|0)-(c[11977480+(l<<4)>>2]|0)|0;ev(n|0,F|0,0)|0}}while(0);l=f+(I+19424)|0;aIy(11979080,l|0,128)|0;l=f+(I+19552)|0;c[2994802]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[2994803]=(d[f+(I+19556)|0]<<12&61440)+11979219;a[11979216]=a[f+(I+19557)|0]|0;a[11979217]=a[f+(I+19558)|0]|0;a[11979218]=a[f+(I+19559)|0]|0;l=f+(I+19560)|0;aIy(11979219,l|0,65536)|0;l=f+(I+85096)|0;aIy(10572896,l|0,524288)|0;l=a[11629666]|0;j=(l&255)<<11&393216;F=d[10441816]|0;c[1161464+((F+2|0)*20|0)>>2]=j+10572896;c[1161464+((F+3|0)*20|0)>>2]=j+10638432;j=f+(I+609384)|0;do{if((l&4)==0){aIy(11359328,j|0,262144)|0;n=F+32|0;J=F+36|0;if(n>>>0<J>>>0){G=n;do{c[1161464+(G*20|0)>>2]=(G<<16&196608)+11359328;aIv(1161468+(G*20|0)|0,0,16);c[744992+(G<<3)>>2]=0;c[744996+(G<<3)>>2]=0;G=G+1|0;}while((G|0)<(J|0))}aIv(957284,0,16);aIv(957304,0,16);aIv(957324,0,16);aIv(957344,0,16);c[239341]=166;c[239342]=58;c[239343]=164;c[239344]=224;c[239346]=166;c[239347]=58;c[239348]=164;c[239349]=224}else{aIy(11097184,j|0,262144)|0;J=F+32|0;G=F+34|0;n=J>>>0<G>>>0;if((l&1)==0){if(n){r=J;do{c[1161464+(r*20|0)>>2]=(r<<16&65536)+11097184;r=r+1|0;}while((r|0)<(G|0))}r=F+36|0;H=G;do{c[1161468+(H*20|0)>>2]=124;c[1161472+(H*20|0)>>2]=122;c[1161476+(H*20|0)>>2]=220;c[1161480+(H*20|0)>>2]=182;c[744992+(H<<3)>>2]=124;c[744996+(H<<3)>>2]=220;H=H+1|0;}while((H|0)<(r|0));c[239321]=78;c[239322]=14;c[239323]=314;c[239324]=150;c[239326]=78;c[239327]=14;c[239328]=314;c[239329]=150;c[239331]=78;c[239332]=14;c[239333]=314;c[239334]=150;c[239336]=78;c[239337]=14;c[239338]=314;c[239339]=150;c[239340]=11228256;aIv(957364,0,16);c[239345]=11293792;aIv(957384,0,16);break}else{if(n){r=J;do{c[1161464+(r*20|0)>>2]=(r<<16&65536)+11228256;r=r+1|0;}while((r|0)<(G|0))}r=F+36|0;J=G;do{c[1161468+(J*20|0)>>2]=24;c[1161472+(J*20|0)>>2]=12;c[1161476+(J*20|0)>>2]=162;c[1161480+(J*20|0)>>2]=134;c[744992+(J<<3)>>2]=24;c[744996+(J<<3)>>2]=162;J=J+1|0;}while((J|0)<(r|0));c[239321]=40;c[239322]=10;c[239323]=172;c[239324]=76;c[239326]=40;c[239327]=10;c[239328]=172;c[239329]=76;c[239331]=40;c[239332]=10;c[239333]=172;c[239334]=76;c[239336]=40;c[239337]=10;c[239338]=172;c[239339]=76;c[239340]=11097184;aIv(957364,0,16);c[239345]=11162720;aIv(957384,0,16);break}}}while(0);F=f+(I+871528)|0;aIy(1166584,F|0,12)|0;F=f+(I+871540)|0;aIy(962240,F|0,12)|0;F=f+(I+871552)|0;b[(c[290366]|0)+114>>1]=(w=d[F]|d[F+1|0]<<8,w<<16>>16);F=f+(I+871554)|0;c[240563]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871558)|0;c[240596]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871562)|0;c[240597]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871566)|0;c[240565]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871570)|0;c[240566]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871574)|0;c[240567]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871578)|0;c[240568]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871582)|0;c[240569]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871586)|0;c[240570]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871590)|0;c[240571]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871594)|0;c[240572]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871598)|0;c[240573]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871602)|0;c[240574]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871606)|0;c[240575]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871610)|0;c[240576]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871614)|0;c[240577]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871618)|0;c[240578]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871622)|0;c[240579]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871626)|0;l=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;c[240580]=l;F=f+(I+871630)|0;c[240581]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24;F=f+(I+871634)|0;j=(w=d[F]|d[F+1|0]<<8,w<<16>>16)&65535;c[240588]=j&32768;c[240595]=j&1792;F=j<<4;c[240590]=F&256;c[240591]=F&128;c[240592]=j>>>2&1^1;c[240593]=j<<6&128;c[240594]=j<<8&256;F=j>>>11&4;c[962328+(c[240589]<<2)>>2]=l;c[240589]=F;c[240580]=c[962328+(F<<2)>>2];ahk();F=f+(I+871636)|0;l=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;if((c[240589]|0)==0){c[240580]=l;F=f+(I+871640)|0;c[240586]=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24}else{c[240582]=l;l=f+(I+871640)|0;c[240580]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24}if((a[10441816]|0)==0){m=1;i=h;return m|0}nd(f+(I+871644)|0)|0;m=1;i=h;return m|0}function aIa(){return}function aIb(a,b,c){a=a|0;b=b|0;c=c|0;return}function aIc(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0.0,Z=0,_=0,ac=0.0,ad=0.0,ae=0.0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0;f=i;i=i+16400|0;g=f|0;j=f+16384|0;k=f+16392|0;l=e|0;aIE(1819696,c[l>>2]|0,1023)|0;a[1820719]=0;e=ck(1819696,47)|0;do{if((e|0)==0){m=ck(1819696,92)|0;if((m|0)!=0){n=m;o=43055;break}a[1819696]=0}else{n=e;o=43055}}while(0);if((o|0)==43055){a[n]=0}n=fA[c[3118408]&63](9,k)|0;e=c[k>>2]|0;if(n&(e|0)!=0){q=e}else{e=c[p>>2]|0;ei(e|0,722208,(r=i,i=i+8|0,c[r>>2]=1819696,r)|0)|0;i=r;c[k>>2]=1819696;q=1819696}bQ(14586480,256,720904,(r=i,i=i+16|0,c[r>>2]=q,c[r+8>>2]=47,r)|0)|0;i=r;bQ(14585968,256,719872,(r=i,i=i+16|0,c[r>>2]=c[k>>2],c[r+8>>2]=47,r)|0)|0;i=r;bQ(14586224,256,718816,(r=i,i=i+16|0,c[r>>2]=c[k>>2],c[r+8>>2]=47,r)|0)|0;i=r;bQ(14585712,256,717896,(r=i,i=i+16|0,c[r>>2]=c[k>>2],c[r+8>>2]=47,r)|0)|0;i=r;bQ(14585200,256,716912,(r=i,i=i+16|0,c[r>>2]=c[k>>2],c[r+8>>2]=47,r)|0)|0;i=r;bQ(14585456,256,715616,(r=i,i=i+16|0,c[r>>2]=c[k>>2],c[r+8>>2]=47,r)|0)|0;i=r;bQ(14586736,256,714056,(r=i,i=i+16|0,c[r>>2]=c[k>>2],c[r+8>>2]=47,r)|0)|0;i=r;ei(c[p>>2]|0,712560,(r=i,i=i+8|0,c[r>>2]=14586480,r)|0)|0;i=r;ei(c[p>>2]|0,711392,(r=i,i=i+8|0,c[r>>2]=14585968,r)|0)|0;i=r;ei(c[p>>2]|0,710864,(r=i,i=i+8|0,c[r>>2]=14586224,r)|0)|0;i=r;ei(c[p>>2]|0,710056,(r=i,i=i+8|0,c[r>>2]=14585712,r)|0)|0;i=r;ei(c[p>>2]|0,709424,(r=i,i=i+8|0,c[r>>2]=14585200,r)|0)|0;i=r;ei(c[p>>2]|0,709008,(r=i,i=i+8|0,c[r>>2]=14585456,r)|0)|0;i=r;ei(c[p>>2]|0,708600,(r=i,i=i+8|0,c[r>>2]=14586736,r)|0)|0;i=r;bQ(14584176,1024,1819696,(r=i,i=i+1|0,i=i+7>>3<<3,c[r>>2]=0,r)|0)|0;i=r;aIy(12474128,702544,16)|0;b[6237075]=150;b[6237076]=100;a[12474144]=1;a[12474146]=1;a[12474145]=0;b[6237077]=-26215;b[6237078]=880;b[6237079]=5e3;b[6237080]=1;b[6237081]=1;b[6237082]=1;a[12474147]=14;a[12474148]=2;a[12474149]=0;aIv(12474166,0,5);a[12474171]=1;aIv(12474172,0,7);aIv(13787336,0,44);c[3446835]=1024;c[3446836]=512;c[3446837]=2048;c[3446834]=12738760;aIv(13787352,0,16);r=c[l>>2]|0;if((a[937424]|0)==-124&(a[11977464]|0)==5){l=mb(r,11958700)|0;if((a[10441816]|0)==0){kN(11958700)}if((l|0)==0){o=43063}else{s=l}}else{o=43063}L52468:do{if((o|0)==43063){a[11977464]=0;l=j;k=j;nD();mP(0);a[14317872]=0;if((c[3118359]|0)>>>0>8388608){c[2994361]=0}q=mb(r,1987672)|0;if((q|0)<0){s=0;break}do{if((q|0)>0){a[937424]=-124;t=q}else{e=aH6(r,1987672,10485760,l)|0;if((e|0)==0){a[937440]=a[937440]&-113;s=0;break L52468}do{if((e|0)>8388608){a[937440]=a[937440]&-17}else{if((e|0)<=4194304){break}a[937440]=a[937440]&-97}}while(0);c[j>>2]=c[j>>2]&-538976289;do{if((aID(730504,l|0,3)|0)==0){a[937424]=33;u=e;v=33}else{n=k+1|0;if((aID(728256,n|0,2)|0)==0){a[937424]=64;u=e;v=64;break}if((aID(726232,n|0,2)|0)==0){a[937424]=16;u=e;v=16;break}a[937424]=-128;if((aID(724728,l|0,3)|0)==0){n=e-1|0;if((n|0)>4){m=4;do{a[1987672+(m-4)|0]=a[1987672+m|0]^64;m=m+1|0;}while((m|0)<(n|0))}w=e-5|0}else{w=e}if((aID(1987928,723728,16)|0)==0){if((w|0)>0){y=0}else{u=w;v=-128;break}}else{if((aID(1987928,722304,12)|0)==0&(w|0)>0){y=0}else{u=w;v=-128;break}}while(1){n=1987672+y|0;m=a[n]|0;z=1987672+(y|1)|0;a[n]=a[z]|0;a[z]=m;m=y+2|0;if((m|0)<(w|0)){y=m}else{u=w;v=-128;break}}}}while(0);if((aID(1987928,720944,4)|0)==0){t=u;break}if(!((((u|0)/512|0)&1|0)!=0&(u&511|0)==0)){t=u;break}e=u-512|0;aIy(1987672,1988184,e)|0;if(v<<24>>24!=-128){t=e;break}m=(e|0)/16384|0;if((e|0)<=16383){t=e;break}z=g|0;n=0;while(1){A=n<<14;B=1987672+A|0;aIy(z|0,B|0,16384)|0;B=0;do{C=B<<1;a[1987672+(C+A)|0]=a[g+(B+8192)|0]|0;a[1987672+((C|1)+A)|0]=a[g+B|0]|0;B=B+1|0;}while((B|0)<8192);B=n+1|0;if((B|0)<(m|0)){n=B}else{t=e;break}}}}while(0);c[3118359]=t;kN(1987672);l=a[937424]|0;L52517:do{if(l<<24>>24==-124){k=a[1988195]|0;if((k|0)==122){a[9808]=-128;D=-128;break}else if((k|0)==100){a[9808]=-64;D=-64;break}else{a[9808]=0;D=0;break}}else{if(l<<24>>24>=0){k=c[3118359]|0;if((k|0)==0){E=0}else{q=k;k=1987672;e=-1;while(1){n=q-1|0;m=d[k]|0;z=c[684280+(((m^e)&15)<<2)>>2]^e>>>4;G=z>>>4^c[684280+((z&15^m>>>4)<<2)>>2];if((n|0)==0){break}else{q=n;k=k+1|0;e=G}}E=~G}if((a[12474148]|0)==0){H=0;o=43138}else{if((E|0)==1738413686|(E|0)==583838139){I=0}else{H=0;o=43138}}do{if((o|0)==43138){while(1){o=0;if((H|0)>=211){o=43141;break}if((c[672536+(H*12|0)>>2]|0)==(E|0)){o=43140;break}else{H=H+1|0;o=43138}}if((o|0)==43140){I=a[672545+(H*12|0)|0]|0;break}else if((o|0)==43141){I=l<<24>>24==17?0:-128;break}}}while(0);a[9808]=I;D=I;break}L52537:do{if((aID(962664,706136,3)|0)==0){o=43121}else{if((aID(962664,705784,3)|0)==0){o=43121;break}L52540:do{if((aID(962664,705424,3)|0)!=0){if((aID(962664,705032,3)|0)==0){break}do{if((aID(962664,704680,3)|0)!=0){if((aID(962664,704376,3)|0)==0){break}e=(c5(a[962664]|0)|0)<<24;k=e>>24;do{if((k|0)==74){J=1}else if((k|0)==69){J=8}else if((k|0)==75){J=1}else if((k|0)==85){J=4}else{if((e|0)<268435456){J=k;break}if((e-788529153|0)>>>0<184549375){J=k-48|0;break}else{J=(e-1073741825|0)>>>0<117440511?k-55|0:0;break}}}while(0);k=(c5(a[962665]|0)|0)<<24;e=k>>24;do{if((e|0)==75){K=J|1}else if((e|0)==69){K=J|8}else if((e|0)==74){K=J|1}else if((e|0)==85){K=J|4}else{if((k|0)<268435456){K=e|J;break}if((k-788529153|0)>>>0<184549375){K=e-48|J;break}if((k-1073741825|0)>>>0>=117440511){K=J;break}K=e-55|J}}while(0);e=(c5(a[962666]|0)|0)<<24;k=e>>24;do{if((k|0)==75){L=K|1}else if((k|0)==69){L=K|8}else if((k|0)==74){L=K|1}else if((k|0)==85){L=K|4}else{if((e|0)<268435456){L=k|K;break}if((e-788529153|0)>>>0<184549375){L=k-48|K;break}if((e-1073741825|0)>>>0>=117440511){L=K;break}L=k-55|K}}while(0);k=(c5(a[962667]|0)|0)<<24;e=k>>24;do{if((e|0)==75){M=L|1}else if((e|0)==69){M=L|8}else if((e|0)==74){M=L|1}else if((e|0)==85){M=L|4}else{if((k|0)<268435456){M=e|L;break}if((k-788529153|0)>>>0<184549375){M=e-48|L;break}if((k-1073741825|0)>>>0>=117440511){M=L;break}M=e-55|L}}while(0);if((M&4|0)!=0){break}if((M&1|0)!=0){break L52540}if((M&8|0)!=0){o=43121;break L52537}if((M&2|0)==0){a[9808]=-128;N=-128;break L52537}else{a[9808]=64;N=64;break L52537}}}while(0);a[9808]=-128;N=-128;break L52537}}while(0);a[9808]=0;N=0}}while(0);if((o|0)==43121){a[9808]=-64;N=-64}e=(bx(962636,703920)|0)!=0;do{if(!(e&(b[481325]|0)==3969)){if((bx(962636,703336)|0)!=0){break}if((bx(962636,702568)|0)!=0){break}if((bx(962636,702304)|0)!=0){break}if((b[481326]|0)!=21294){D=N;break L52517}if((bx(962636,702072)|0)==0){D=N;break L52517}a[9808]=0;D=0;break L52517}}while(0);a[9808]=-64;D=-64}}while(0);l=a[12474167]|0;if((l<<24>>24|0)==1){a[9808]=-128;O=-128}else if((l<<24>>24|0)==2){a[9808]=-64;O=-64}else if((l<<24>>24|0)==3){a[9808]=0;O=0}else if((l<<24>>24|0)==4){a[9808]=64;O=64}else{O=D}l=(O&255)>>>6&1;a[888176]=l;c[234358]=l<<24>>24!=0?53203424:53693175;l=a[12474169]|0;if((l<<24>>24|0)==1){a[888176]=0}else if((l<<24>>24|0)==2){a[888176]=1}l=a[12474168]|0;if((l<<24>>24|0)==1){c[234358]=53693175}else if((l<<24>>24|0)==2){c[234358]=53203424}l=a[937424]|0;do{if((l<<24>>24|0)==(-128|0)){if((c[3118359]|0)==0){break}else{R=0}do{e=1987672+R|0;k=a[e]|0;q=1987672+(R|1)|0;a[e]=a[q]|0;a[q]=k;R=R+2|0;}while(R>>>0<(c[3118359]|0)>>>0)}else if((l<<24>>24|0)==(-124|0)){if((kO()|0)!=0){a[10441816]=0;break}if((c[2994361]|0)!=0){k=c[2994368]|0;if((k|0)>0){q=0;e=k;while(1){k=11977476+(q<<4)|0;n=c[k>>2]|0;if((n|0)==0){S=q;T=e}else{aS(n|0)|0;n=c[2994368]|0;S=(c[11977476+(q+1<<4)>>2]|0)==(c[k>>2]|0)?n:q;T=n}n=S+1|0;if((n|0)<(T|0)){q=n;e=T}else{break}}}c[2994361]=0}aIv(11977466,0,1610);s=0;break L52468}}while(0);L52656:do{if((bx(962496,719928)|0)==0){if((bx(962632,718864)|0)!=0){a[937424]=-124;a[10441816]=0;aIy(10441824,1987672,131072)|0;a[937440]=a[937440]&-32|(d[9808]|0)>>>4|16;o=43210;break}do{if((bx(962532,717944)|0)==0){if((bx(962532,716936)|0)!=0){o=43206;break}l=(bx(962636,730248)|0)!=0;e=a[12474166]|0;if(!(l&e<<24>>24==0)){V=e;break L52656}}else{o=43206}}while(0);if((o|0)==43206){e=a[12474166]|0;if(e<<24>>24!=0){V=e;break}}a[937424]=-124;if((kO()|0)==0){a[937424]=-128;o=43210;break}else{a[10441816]=64;e=r+((aIu(r|0)|0)-4)|0;x=1869834542;a[e]=x&255;x=x>>8;a[e+1|0]=x&255;x=x>>8;a[e+2|0]=x&255;x=x>>8;a[e+3|0]=x&255;mb(r,11958700)|0;o=43210;break}}else{a[937424]=-126;o=43210}}while(0);if((o|0)==43210){V=a[12474166]|0}do{if((V<<24>>24|0)==(-128|0)){if((a[937424]|0)<0){break}a[937424]=-127}else if((V<<24>>24|0)==64){if((a[937424]|0)==64){break}a[937424]=65}else if((V<<24>>24|0)!=0){a[937424]=V}}while(0);e=c[2784]|0;l=(e|0)==-1;if(!l){a[1692304]=e&255}e=c[2782]|0;q=(e|0)==-1;if(q){W=a[1692296]|0}else{n=e&255;a[1692296]=n;W=n}c[423058]=W<<24>>24==3?64:0;c[423056]=0;if((bx(962582,712680)|0)!=0){if(l){c[2784]=d[1692304]|0}if(q){c[2782]=W&255}a[1692304]=1;a[1692296]=3;c[423058]=82;c[423056]=0;s=1;break}if((bx(962582,711536)|0)!=0){if(l){c[2784]=d[1692304]|0}if(q){c[2782]=W&255}a[1692304]=1;a[1692296]=3;c[423058]=133;c[423056]=-8;s=1;break}if((bx(962582,710960)|0)!=0){if(l){c[2784]=d[1692304]|0}if(q){c[2782]=W&255}a[1692304]=1;a[1692296]=3;c[423058]=68;c[423056]=-24;s=1;break}if((bx(962582,710144)|0)!=0){if(l){c[2784]=d[1692304]|0}if(q){c[2782]=W&255}a[1692304]=1;a[1692296]=3;c[423058]=64;c[423056]=-8;s=1;break}if((bx(962582,709464)|0)!=0){if(l){c[2784]=d[1692304]|0}if(q){c[2782]=W&255}a[1692304]=1;a[1692296]=3;c[423058]=61;c[423056]=0;s=1;break}if((bx(962582,709048)|0)!=0){if(l){c[2784]=d[1692304]|0}if(q){c[2782]=W&255}a[1692304]=1;a[1692296]=3;c[423058]=70;c[423056]=18;s=1;break}if((bx(962582,708640)|0)!=0){if(l){c[2784]=d[1692304]|0}if(q){c[2782]=W&255}a[1692304]=1;a[1692296]=3;c[423058]=49;c[423056]=0;s=1;break}if((bx(962582,708256)|0)!=0){if(l){c[2784]=d[1692304]|0}if(q){c[2782]=W&255}a[1692304]=1;a[1692296]=3;c[423058]=60;c[423056]=30;s=1;break}if((bx(962582,707640)|0)==0){if((bx(962582,706960)|0)==0){s=1;break}}if(l){c[2784]=d[1692304]|0}if(q){c[2782]=W&255}a[1692304]=1;a[1692296]=4;c[423058]=(bx(962582,706504)|0)!=0?24:0;c[423056]=0;s=1}}while(0);if((s|0)<=0){X=0;i=f;return X|0}s=d[937424]|0;if((s|0)==128|(s|0)==132){a[12474181]=1;a[12474184]=1;a[12474187]=1;a[12474190]=1;a[12474193]=1;a[12474196]=1;a[12474199]=1;a[12474202]=1;a[1692304]=1;a[1692296]=1}else if((s|0)==64|(s|0)==32){a[1692304]=7;a[1692296]=7}Y=+((c[234358]|0)>>>0>>>0);s=c[235925]|0;if((s|0)!=0){aIq(s)}c[235925]=0;s=c[235926]|0;if((s|0)!=0){aIq(s)}c[235926]=0;s=c[235927]|0;if((s|0)!=0){aIq(s)}c[235927]=0;s=c[235928]|0;if((s|0)!=0){aIq(s)}c[235928]=0;s=c[235929]|0;if((s|0)!=0){aIq(s)}c[235929]=0;s=c[235930]|0;if((s|0)!=0){aIq(s)}aIv(943680,0,48);c[235920]=44100;h[117961]=0.0;s=aIp(17736)|0;if((s|0)!=0){W=s;c[W>>2]=0;c[W+4>>2]=1;c[s+16>>2]=4410;W=s+8|0;c[W>>2]=-2147483648;c[W+4>>2]=0;aIv(s+20|0,0,17716)}c[235925]=s;s=aIp(17736)|0;W=s;L52798:do{if((s|0)==0){c[235926]=W;V=c[235925]|0;if((V|0)==0){Z=W}else{aIq(V);Z=c[235926]|0}c[235925]=0;if((Z|0)==0){o=43302}else{_=Z;o=43301}}else{V=s;c[V>>2]=0;c[V+4>>2]=1;c[s+16>>2]=4410;V=s+8|0;c[V>>2]=-2147483648;c[V+4>>2]=0;aIv(s+20|0,0,17716);c[235926]=W;V=c[235925]|0;if((V|0)==0){c[235925]=0;_=W;o=43301;break}ac=198608743567038870000.0/Y;r=~~ac>>>0;T=+Q(ac)>=1.0?ac>0.0?(ag(+P(ac/4294967296.0),4294967295.0)|0)>>>0:~~+aa((ac- +(~~ac>>>0))/4294967296.0)>>>0:0;S=V|0;V=aIF(+(r>>>0)+ +(T>>>0)*4294967296.0<ac|0,0,r,T)|0;T=F;c[S>>2]=V;c[S+4>>2]=T;S=c[235926]|0;c[S>>2]=V;c[S+4>>2]=T;T=c[235926]|0;S=a[937424]|0;V=(S&255)>16;c[3184682]=c[235925];c[3184676]=T;c[3645544]=100;c[3645545]=100;c[3645546]=100;c[3645547]=100;c[3645548]=100;c[3645549]=100;c[3645550]=100;c[3645551]=100;c[3645552]=V?9:6;c[3645553]=V?16:15;do{if(S<<24>>24==-124){V=aIp(17736)|0;if((V|0)!=0){T=V;c[T>>2]=0;c[T+4>>2]=1;c[V+16>>2]=4410;T=V+8|0;c[T>>2]=-2147483648;c[T+4>>2]=0;aIv(V+20|0,0,17716)}c[235927]=V;V=aIp(17736)|0;if((V|0)!=0){T=V;c[T>>2]=0;c[T+4>>2]=1;c[V+16>>2]=4410;T=V+8|0;c[T>>2]=-2147483648;c[T+4>>2]=0;aIv(V+20|0,0,17716)}c[235928]=V;V=aIp(17736)|0;if((V|0)!=0){T=V;c[T>>2]=0;c[T+4>>2]=1;c[V+16>>2]=4410;T=V+8|0;c[T>>2]=-2147483648;c[T+4>>2]=0;aIv(V+20|0,0,17716)}c[235929]=V;V=aIp(17736)|0;if((V|0)!=0){T=V;c[T>>2]=0;c[T+4>>2]=1;c[V+16>>2]=4410;T=V+8|0;c[T>>2]=-2147483648;c[T+4>>2]=0;aIv(V+20|0,0,17716)}c[235930]=V;T=c[235927]|0;r=c[235928]|0;if((T|0)!=0&(r|0)!=0&(c[235929]|0)!=0&(V|0)!=0){ac=+h[117961];if(ac!=0.0){ad=ac*((a[888176]|0)!=0?996592.0:834208.0)}else{ad=5.0e7}c[3184684]=T;c[3184678]=r;ac=ad/1536.0;ae=+(c[235920]|0)*4503599627370496.0/ac;V=~~ae>>>0;R=+Q(ae)>=1.0?ae>0.0?(ag(+P(ae/4294967296.0),4294967295.0)|0)>>>0:~~+aa((ae- +(~~ae>>>0))/4294967296.0)>>>0:0;O=T|0;T=aIF(+(V>>>0)+ +(R>>>0)*4294967296.0<ae|0,0,V,R)|0;c[O>>2]=T;c[O+4>>2]=F;ae=+(c[235920]|0)*4503599627370496.0/ac;O=~~ae>>>0;T=+Q(ae)>=1.0?ae>0.0?(ag(+P(ae/4294967296.0),4294967295.0)|0)>>>0:~~+aa((ae- +(~~ae>>>0))/4294967296.0)>>>0:0;R=r|0;r=aIF(+(O>>>0)+ +(T>>>0)*4294967296.0<ae|0,0,O,T)|0;c[R>>2]=r;c[R+4>>2]=F;R=c[235929]|0;r=c[235930]|0;c[3184686]=R;c[3184680]=r;ae=+(c[235920]|0)*4503599627370496.0/44100.0;T=~~ae>>>0;O=+Q(ae)>=1.0?ae>0.0?(ag(+P(ae/4294967296.0),4294967295.0)|0)>>>0:~~+aa((ae- +(~~ae>>>0))/4294967296.0)>>>0:0;V=R|0;R=aIF(+(T>>>0)+ +(O>>>0)*4294967296.0<ae|0,0,T,O)|0;c[V>>2]=R;c[V+4>>2]=F;ae=+(c[235920]|0)*4503599627370496.0/44100.0;V=~~ae>>>0;R=+Q(ae)>=1.0?ae>0.0?(ag(+P(ae/4294967296.0),4294967295.0)|0)>>>0:~~+aa((ae- +(~~ae>>>0))/4294967296.0)>>>0:0;O=r|0;r=aIF(+(V>>>0)+ +(R>>>0)*4294967296.0<ae|0,0,V,R)|0;c[O>>2]=r;c[O+4>>2]=F;break}O=c[235925]|0;if((O|0)!=0){aIq(O)}c[235925]=0;O=c[235926]|0;if((O|0)!=0){aIq(O)}c[235926]=0;O=c[235927]|0;if((O|0)!=0){aIq(O)}c[235927]=0;O=c[235928]|0;if((O|0)!=0){aIq(O)}c[235928]=0;O=c[235929]|0;if((O|0)!=0){aIq(O)}c[235929]=0;O=c[235930]|0;if((O|0)!=0){aIq(O)}c[235930]=0;af=0;ah=14450848;ai=14516384;aj=14319776;ak=14385312;break L52798}}while(0);c[235924]=1;kx();af=0;ah=14450848;ai=14516384;aj=14319776;ak=14385312}}while(0);if((o|0)==43301){aIq(_);o=43302}if((o|0)==43302){c[235926]=0;o=c[235927]|0;if((o|0)!=0){aIq(o)}c[235927]=0;o=c[235928]|0;if((o|0)!=0){aIq(o)}c[235928]=0;o=c[235929]|0;if((o|0)!=0){aIq(o)}c[235929]=0;o=c[235930]|0;if((o|0)!=0){aIq(o)}c[235930]=0;af=0;ah=14450848;ai=14516384;aj=14319776;ak=14385312}while(1){o=af&15;_=af^128;W=ak+256|0;s=0;Z=ah;S=ai;O=aj;r=ak;while(1){R=s-af|0;V=(s|0)!=0;T=s&128;D=s&40;N=((V?T:64)|D)&255;M=s&15;L=M>>>0<o>>>0;K=N|16;J=(s|0)<(af|0)|0;I=(L?K:N)|J;a[Z]=((R^s)&128&(R^_)|0)==0?I:I|4;I=R-1|0;R=M>>>0>o>>>0;M=(s|0)>(af|0)|0;H=((R?N:K)|M)^1;a[S]=((I^s)&128&(I^_)|0)==0?H:H|4;H=af-s|0;I=((V?T|2:66)|D)&255;D=I|16;T=(R?D:I)|M;M=(s^af)&128;a[O]=(M&(H^af)|0)==0?T:T|4;T=(L?I:D)|J^1;a[r]=((H+255^af)&M|0)==0?T:T|4;T=s+1|0;if((T|0)<256){s=T;Z=Z+1|0;S=S+1|0;O=O+1|0;r=r+1|0}else{break}}r=af+1|0;if((r|0)<256){af=r;ah=ah+256|0;ai=ai+256|0;aj=aj+256|0;ak=W}else{al=0;break}}do{ak=al&128;aj=(al|0)!=0;ai=al&40;ah=(aj?ak:64)|ai;af=ah&255;a[14581920+al|0]=af;a[14318752+al|0]=((aj?ak:68)|ai)&255;a[14319008+al|0]=(((al>>>5)+(al&1)+(al>>>6)+(al>>>3)+(al>>>4)+(al>>>1)+(al>>>2)+(ak>>>7)<<2&4|ah)^4)&255;ah=(al|0)==128?af|4:af;ak=al&15;a[14319264+al|0]=(ak|0)==0?ah|16:ah;ah=af|((al|0)==127?6:2);a[14319520+al|0]=(ak|0)==15?ah|16:ah;al=al+1|0;}while((al|0)<256);aIv(14318648,0,72);c[3579680]=202;b[7159338]=0;b[7159336]=0;b[7159326]=0;b[7159334]=0;b[7159332]=0;b[7159330]=0;b[7159328]=0;a[14318656]=64;c[3118612]=685504;c[3118610]=686528;c[3118608]=686016;c[3118606]=684992;c[3118604]=684480;al=a[937424]|0;L52870:do{if((al&-127)<<24>>24==-128){c[291688]=d[12474171]|0;ah=128;do{c[1161464+(ah*20|0)>>2]=756920;c[1161468+(ah*20|0)>>2]=198;c[1161472+(ah*20|0)>>2]=50;c[1161476+(ah*20|0)>>2]=178;c[1161480+(ah*20|0)>>2]=166;c[744992+(ah<<3)>>2]=96;c[744996+(ah<<3)>>2]=54;ah=ah+1|0;}while((ah|0)<224);c[291327]=150;c[291328]=110;c[291329]=216;c[291330]=264;c[186632]=108;c[186633]=116;c[291367]=150;c[291368]=110;c[291369]=216;c[291370]=264;c[186648]=108;c[186649]=116;c[291407]=150;c[291408]=110;c[291409]=216;c[291410]=264;c[186664]=108;c[186665]=116;c[291447]=150;c[291448]=110;c[291449]=216;c[291450]=264;c[186680]=108;c[186681]=116;ah=224;do{c[1161464+(ah*20|0)>>2]=756920;aIv(1161468+(ah*20|0)|0,0,16);c[744992+(ah<<3)>>2]=158;c[744996+(ah<<3)>>2]=0;ah=ah+1|0;}while((ah|0)<256);do{if(al<<24>>24==-126){c[291007]=144;c[291008]=56;c[291009]=278;c[291010]=84;c[291172]=100;c[291173]=92;c[291174]=278;c[291175]=84}else{c[291172]=138;c[291173]=132;c[291174]=140;c[291175]=250;c[186570]=194;c[186571]=170;ah=0;do{c[747336+(ah<<2)>>2]=736800+(ah<<10&7168);ah=ah+1|0;}while((ah|0)<64);c[186764]=62;c[186832]=44;c[186762]=80;c[186830]=210;if(al<<24>>24!=-124){break}ah=a[10441816]|0;W=ah<<24>>24==0;ak=W?6:0;a[10441817]=ak;do{if(W){aIv(937480,0,20);aIv(1987672,0,8454144);c[2610455]=(1<<(ak&255)+13)-1;a[10441818]=1;af=64;while(1){c[1161464+(af*20|0)>>2]=0;c[1161468+(af*20|0)>>2]=152;c[1161472+(af*20|0)>>2]=28;c[1161476+(af*20|0)>>2]=278;c[1161480+(af*20|0)>>2]=84;c[744992+(af<<3)>>2]=152;c[744996+(af<<3)>>2]=268;ai=af+1|0;if((ai|0)<96){af=ai}else{am=96;break}}while(1){c[1161464+(am*20|0)>>2]=0;c[1161468+(am*20|0)>>2]=168;c[1161472+(am*20|0)>>2]=74;c[1161476+(am*20|0)>>2]=284;c[1161480+(am*20|0)>>2]=196;c[744992+(am<<3)>>2]=168;c[744996+(am<<3)>>2]=284;af=am+1|0;if((af|0)<112){am=af}else{an=112;break}}do{c[1161464+(an*20|0)>>2]=0;c[1161468+(an*20|0)>>2]=80;c[1161472+(an*20|0)>>2]=20;c[1161476+(an*20|0)>>2]=232;c[1161480+(an*20|0)>>2]=112;c[744992+(an<<3)>>2]=80;c[744996+(an<<3)>>2]=232;an=an+1|0;}while((an|0)<128)}else{mU();if((a[10441816]|0)==0){ao=0}else{break}do{af=ao+64|0;c[1161464+(af*20|0)>>2]=c[1161464+(ao*20|0)>>2];c[1161468+(af*20|0)>>2]=c[1161468+(ao*20|0)>>2];c[1161472+(af*20|0)>>2]=c[1161472+(ao*20|0)>>2];c[1161476+(af*20|0)>>2]=c[1161476+(ao*20|0)>>2];c[1161480+(af*20|0)>>2]=c[1161480+(ao*20|0)>>2];c[744992+(af<<3)>>2]=c[744992+(ao<<3)>>2];c[744996+(af<<3)>>2]=c[744996+(ao<<3)>>2];ao=ao+1|0;}while((ao|0)<64)}}while(0);ak=ah&255;W=ak+32|0;af=ak;do{ai=af<<16&65536;if((af&2|0)==0){c[1161464+(af*20|0)>>2]=ai+10441824;c[1161468+(af*20|0)>>2]=0;c[1161472+(af*20|0)>>2]=0;c[1161476+(af*20|0)>>2]=278;c[1161480+(af*20|0)>>2]=84;c[744992+(af<<3)>>2]=0;c[744996+(af<<3)>>2]=268}else{c[1161464+(af*20|0)>>2]=ai+10572896;aIv(1161468+(af*20|0)|0,0,16);c[744992+(af<<3)>>2]=0;c[744996+(af<<3)>>2]=0}af=af+1|0;}while((af|0)<(W|0));af=ak+64|0;ah=W;while(1){c[1161464+(ah*20|0)>>2]=(ah<<16&196608)+11359328;aIv(1161468+(ah*20|0)|0,0,16);c[744992+(ah<<3)>>2]=0;c[744996+(ah<<3)>>2]=0;ai=ah+1|0;if((ai|0)<(af|0)){ah=ai}else{ap=0;break}}do{c[957120+(ap*20|0)>>2]=(ap<<16)+10572896;c[957124+(ap*20|0)>>2]=0;c[957128+(ap*20|0)>>2]=0;ah=(ap|0)<2;c[957132+(ap*20|0)>>2]=ah?322:0;c[957136+(ap*20|0)>>2]=ah?128:0;ap=ap+1|0;}while((ap|0)<8);c[239320]=11359328;aIv(957284,0,16);c[239325]=11424864;aIv(957304,0,16);c[239330]=11490400;aIv(957324,0,16);c[239335]=11555936;aIv(957344,0,16);ah=12;do{c[957120+(ah*20|0)>>2]=(ah<<16&196608)+11359328;c[957124+(ah*20|0)>>2]=166;c[957128+(ah*20|0)>>2]=58;c[957132+(ah*20|0)>>2]=164;c[957136+(ah*20|0)>>2]=224;ah=ah+1|0;}while((ah|0)<253);c[240545]=0;c[240546]=68;c[240547]=36;c[240548]=312;c[240549]=50;c[240550]=0;c[240551]=68;c[240552]=36;c[240553]=312;c[240554]=50;c[240555]=0;c[240556]=98;c[240557]=32;c[240558]=286;c[240559]=294;aIv(11630192,0,347244);ah=0;while(1){b[11630220+(ah<<1)>>1]=(ah>>>3<<11|ah<<8&1792|ah>>>8<<2&252)&65535;af=ah+1|0;if((af|0)<16384){ah=af}else{aq=16384;break}}while(1){b[11630220+(aq<<1)>>1]=(aq>>>7<<2&252|aq<<8&1792|aq>>>3<<11&30720)&65535;ah=aq+1|0;if((ah|0)<24576){aq=ah}else{ar=24576;break}}while(1){b[11630220+(ar<<1)>>1]=(ar<<8&1792|ar>>>6<<2&252|ar>>>3<<11&14336|32768)&65535;ah=ar+1|0;if((ah|0)<28672){ar=ah}else{as=28672;break}}while(1){b[11630220+(as<<1)>>1]=(as<<8&1792|as>>>5<<2&252|as>>>3<<11&6144|49152)&65535;ah=as+1|0;if((ah|0)<30720){as=ah}else{at=30720;break}}while(1){b[11630220+(at<<1)>>1]=(at>>>3<<11|at<<8&1792|at>>>5<<2&252|57344)&65535;ah=at+1|0;if((ah|0)<32768){at=ah}else{au=0;break}}while(1){ah=au&15;af=au&240;W=(af|0)!=0;ak=au&255;if((ah|0)==0){if(W){ai=0;do{a[11695756+(au<<8)+ai|0]=ai&255;aj=ai&15;a[11761292+(au<<8)+ai|0]=(aj|af)&255;a[11826828+(au<<8)+ai|0]=(((aj|0)!=0?ai:au)&15|((ai&240|0)!=0?ai:au)&240)&255;a[11892364+(au<<8)+ai|0]=ak;ai=ai+1|0;}while((ai|0)<256)}else{ai=0;do{af=ai&255;a[11695756+(au<<8)+ai|0]=af;a[11761292+(au<<8)+ai|0]=af;a[11826828+(au<<8)+ai|0]=(((ai&15|0)!=0?ai:au)&15|((ai&240|0)!=0?ai:au)&240)&255;a[11892364+(au<<8)+ai|0]=ak;ai=ai+1|0;}while((ai|0)<256)}}else{if(W){ai=0;do{a[11695756+(au<<8)+ai|0]=ai&255;a[11761292+(au<<8)+ai|0]=ak;a[11826828+(au<<8)+ai|0]=(((ai&15|0)!=0?ai:au)&15|((ai&240|0)!=0?ai:au)&240)&255;a[11892364+(au<<8)+ai|0]=ak;ai=ai+1|0;}while((ai|0)<256)}else{ai=0;do{a[11695756+(au<<8)+ai|0]=ai&255;W=ai&240;a[11761292+(au<<8)+ai|0]=(W|ah)&255;a[11826828+(au<<8)+ai|0]=(((ai&15|0)!=0?ai:au)&15|((W|0)!=0?ai:au)&240)&255;a[11892364+(au<<8)+ai|0]=ak;ai=ai+1|0;}while((ai|0)<256)}}ai=au+1|0;if((ai|0)<256){au=ai}else{av=0;break}}while(1){ai=av>>>2&2|1;ak=av>>>6;ah=av>>>4;if((av&4|0)==0){aw=ai&ah&255}else{aw=ai&(ah^255)&255}if((av&2|0)==0){ax=aw;ay=ai&ak&255}else{ax=(aw&255^ai)&255;ay=ai&(ak^255)&255}if((av&1|0)==0){az=ax;aA=ay}else{az=(ay&255^ai)&255;aA=ax}a[av+11958412|0]=(ab(az&255,ai+1|0)|0)+(aA&255)&255;ai=av+1|0;if((ai|0)<256){av=ai}else{aB=0;break}}do{ai=aB>>>6&7;ak=aB>>>3&7;ah=(aB&4|0)==0?ak:ak^7;if((aB&2|0)==0){aC=ah;aD=ai}else{aC=ah^7;aD=ai^7}ai=(aB&1|0)==0;a[aB+11957900|0]=((ai?aD:aC)<<3)+(ai?aC:aD^7)&255;aB=aB+1|0;}while((aB|0)<512);aIv(10572896,0,1056768);break L52870}}while(0);mU()}else{nh();switch(d[937424]|0){case 129:{c[186762]=158;c[186830]=6;break L52870;break};case 64:case 65:{nh();c[186762]=154;c[186830]=112;break L52870;break};case 32:case 33:{c[186762]=126;c[186830]=192;break L52870;break};case 17:{c[186762]=174;c[186830]=180;break L52870;break};case 16:{c[186762]=92;c[186830]=164;break L52870;break};default:{break L52870}}}}while(0);a[1692288]=-1;b[846136]=0;a[1692289]=-1;b[846137]=0;a[1692290]=-1;b[846138]=0;a[1692291]=-1;b[846139]=0;a[1692292]=-1;b[846140]=0;a[1692293]=-1;b[846141]=0;a[1692294]=-1;b[846142]=0;a[1692295]=-1;b[846143]=0;aB=a[937424]|0;do{if(aB<<24>>24==-126){a[1692288]=7}else{if((a[12473444]&2)!=0){a[1692288]=8;break}switch(d[1692304]|0){case 7:{a[1692288]=2;aE=1;break};case 1:{a[1692288]=a[12474181]|0;aE=1;break};case 2:{a[1692288]=3;aE=1;break};case 6:{a[1692288]=10;aE=1;break};case 5:{a[1692288]=9;aE=1;break};case 8:{a[1692288]=4;aE=1;break};case 9:{a[1692288]=5;aE=1;break};case 10:{a[1692288]=6;aE=1;break};case 12:{a[1692288]=a[12474181]|0;a[1692289]=a[12474184]|0;a[1692290]=a[12474187]|0;a[1692291]=a[12474190]|0;aE=4;break};case 11:{a[1692288]=a[12474181]|0;a[1692289]=a[12474184]|0;a[1692290]=a[12474187]|0;a[1692291]=a[12474190]|0;l2(0);aE=4;break};default:{aE=0}}switch(d[1692296]|0){case 7:{a[1692292]=2;aF=aE+1|0;break};case 1:{a[1692292]=a[12474181+(aE*3|0)|0]|0;aF=aE+1|0;break};case 2:{a[1692292]=3;aF=aE+1|0;break};case 6:{a[1692292]=10;aF=aE+1|0;break};case 5:{a[1692292]=9;aF=aE+1|0;break};case 3:{a[1692292]=4;aF=aE+1|0;break};case 4:{a[1692292]=4;a[1692293]=4;aF=aE|2;break};case 11:{a[1692292]=a[12474181+(aE*3|0)|0]|0;a[1692293]=a[12474181+((aE+1|0)*3|0)|0]|0;aD=aE|2;a[1692294]=a[12474181+(aD*3|0)|0]|0;aC=aD+1|0;if(aC>>>0<8){a[1692295]=a[12474181+(aC*3|0)|0]|0;aG=aD+2|0}else{aG=aC}l2(1);aF=aG;break};case 8:{a[1692292]=4;aF=aE+1|0;break};case 9:{a[1692292]=5;aF=aE+1|0;break};case 10:{a[1692292]=6;aF=aE+1|0;break};default:{aF=aE}}if(!((a[12473444]&4)!=0&(aF|0)<8)){break}a[1692293]=a[12474181+(aF*3|0)|0]|0;aC=aF+1|0;if((aC|0)>=8){break}a[1692294]=a[12474181+(aC*3|0)|0]|0}}while(0);switch(d[1692304]|0){case 7:{c[241062]=328;c[241063]=66;break};case 1:{c[241062]=234;c[241063]=66;break};case 2:{c[241062]=18;c[241063]=10;break};case 6:{c[241062]=184;c[241063]=36;break};case 5:{c[241062]=192;c[241063]=46;break};case 12:{c[241062]=136;c[241063]=56;break};case 11:{c[241062]=132;c[241063]=78;break};case 8:{c[241062]=328;c[241063]=96;break};case 9:{c[241062]=318;c[241063]=58;break};case 10:{c[241062]=72;c[241063]=12;break};default:{c[241062]=328;c[241063]=68}}switch(d[1692296]|0){case 7:{c[241064]=328;c[241065]=32;break};case 1:{c[241064]=270;c[241065]=32;break};case 2:{c[241064]=18;c[241065]=10;break};case 5:{c[241064]=262;c[241065]=42;break};case 6:{c[241064]=330;c[241065]=88;break};case 3:{c[241064]=328;c[241065]=80;break};case 4:{c[241064]=248;c[241065]=38;break};case 12:{c[241064]=98;c[241065]=100;break};case 11:{c[241064]=238;c[241065]=76;break};case 8:{c[241064]=328;c[241065]=20;break};case 9:{c[241064]=66;c[241065]=18;break};case 10:{c[241064]=288;c[241065]=44;break};default:{c[241064]=328;c[241065]=68}}c[241066]=328;c[241067]=68;b[780032]=(a[888176]|0)!=0?313:262;aF=(aB&-127)<<24>>24==-128;c[239016]=aF?52:164;c[239014]=aF?152:164;aB=0;while(1){aE=aB<<8;aG=aB&127;aC=aB&64;aD=(aC|0)==0;av=(aB&15|0)!=0;aA=aB&63;az=aB&255;ax=aB>>>1&64;ay=ax|aA;aw=ax+64|aA;au=(aB&32|0)==0;at=(aB&128|0)!=0;as=0;do{ar=as|aE;aq=as&127;ap=as&64;ao=as&15;an=(ap|0)==0;do{if(an){if(aD){aH=(ao|0)!=0?aq:aG;break}else{aH=av?aG:aq;break}}else{aH=(ao|0)!=0?aq:aG}}while(0);am=ar&65535;a[1166840+am|0]=(aH&15|0)==0?0:aH&255;al=as&63;ai=(ao|0)==0;ah=ai|at;if(ah){aI=az}else{if((ap|0)!=0|aD){aJ=al}else{aJ=av?aA:al}aI=(aJ&15|0)==0?-128:(aJ|128)&255}a[1232376+am|0]=aI;do{if(an){if(aD){aK=(ao|0)!=0?aq:aG;break}else{aK=av?aG:aq;break}}else{aK=(ao|0)!=0?aq:aG}}while(0);aq=aK|(ap|aC)<<1;a[1297912+am|0]=((aK&15|0)==0?aq&128:aq)&255;if(ai){aL=az}else{aq=at?aB:as;aL=(((aq&15|0)==0?64:127)&aq|128)&255}a[1363448+am|0]=aL;aq=ap|ax;do{if(an){if(aD){if(ai){aM=ay;break}if((as&62|0)==62){aM=(as&1|0)==0?aw:aA;break}if((al|0)==46|(al|0)==30|(al|0)==14){aM=al|64;break}else{aM=aq|al;break}}else{if(av|ai){aM=ay;break}if((as&62|0)==62){aM=(as&1|0)==0?aw:aA;break}if((al|0)==46|(al|0)==30|(al|0)==14){aM=al|64;break}else{aM=aq|al;break}}}else{if(ai){aM=ay;break}if((as&62|0)==62){aM=(as&1|0)==0?aw:aA;break}if((al|0)==46|(al|0)==30|(al|0)==14){aM=al|64;break}else{aM=aq|al;break}}}while(0);a[1428984+am|0]=((aM&15|0)==0?aM&192:aM)&255;al=ao|16;if(ah){aN=az}else{if(au){aO=al}else{aO=av?aA:al}aN=(aO|128)&255}a[1494520+am|0]=aN;as=as+1|0;}while((as|0)<256);as=aB+1|0;if((as|0)<256){aB=as}else{aP=0;break}}while(1){aB=aP&7;aN=aP>>>3&7;aO=aP>>>6&7;b[966472+(aP<<1)>>1]=(aN<<7|aB<<12|aO<<1|aN>>>2<<5)&65535;b[965448+(aP<<1)>>1]=(aB>>>2<<11|aB<<13|aN<<8|aO<<2|aO>>>2|aN>>>1<<5)&65535;aM=aB+7|0;aB=aN+7|0;aN=aO+7|0;b[964424+(aP<<1)>>1]=(aM>>>3<<11|aM<<12|aB<<7|aN<<1|aN>>>3|aB>>>2<<5)&65535;aB=aP+1|0;if((aB|0)<512){aP=aB}else{aQ=0;break}}while(1){aP=aQ&3;aB=aQ>>>2&3;aN=aQ>>>4&3;b[964296+(aQ<<1)>>1]=(aB<<5|aP>>>1<<11|aN>>>1|(aP<<2|aP)<<12|(aB<<2|aB)<<7|(aN<<2|aN)<<1)&65535;aN=aQ+1|0;if((aN|0)<64){aQ=aN}else{aR=0;break}}while(1){aQ=aR&3;aN=aR>>>2&3;aB=aR>>>4&3;aP=aR>>>6&3;if(aN>>>0>aB>>>0|aQ>>>0>aP>>>0){a[968280+aR|0]=-1}else{a[968280+aR|0]=(ab((aR&256|0)==0?aQ:aP-aQ|0,aB+1|0)|0)+((aR&512|0)==0?aN:aB-aN|0)&255}aN=aR+1|0;if((aN|0)<1024){aR=aN}else{aT=0;break}}do{aR=aT>>>5&4|aT&64|aT<<5&1024|aT<<10&16384|aT<<15&262144|aT<<20&4194304|aT<<25&67108864|aT<<30&1073741824;aN=0;do{c[12474504+((aN<<8|aT)<<2)>>2]=aR|aN<<31|aN>>>4&8|aN<<1&128|aN<<6&2048|aN<<11&32768|aN<<16&524288|aN<<21&8388608|aN<<26&134217728;aN=aN+1|0;}while((aN|0)<256);aT=aT+1|0;}while((aT|0)<256);if(aF){aIv(747592,0,3336);aF=0;while(1){aT=aF+1|0;aN=~~+P(+(65536.0/+dj(+(+(aT|0)*.03125*.125))));aR=(aN>>>4&1)+(aN>>5)|0;aN=aR<<2;aB=aF<<1;c[910760+(aB<<2)>>2]=aN;aQ=aB|1;c[910760+(aQ<<2)>>2]=-aN;aN=aR<<1;c[910760+(aB+512<<2)>>2]=aN;c[910760+(aQ+512<<2)>>2]=-aN;c[910760+(aB+1024<<2)>>2]=aR;c[910760+(aQ+1024<<2)>>2]=-aR;aN=aR>>1;c[910760+(aB+1536<<2)>>2]=aN;c[910760+(aQ+1536<<2)>>2]=-aN;aN=aR>>2;c[910760+(aB+2048<<2)>>2]=aN;c[910760+(aQ+2048<<2)>>2]=-aN;aN=aR>>3;c[910760+(aB+2560<<2)>>2]=aN;c[910760+(aQ+2560<<2)>>2]=-aN;aN=aR>>4;c[910760+(aB+3072<<2)>>2]=aN;c[910760+(aQ+3072<<2)>>2]=-aN;aN=aR>>5;c[910760+(aB+3584<<2)>>2]=aN;c[910760+(aQ+3584<<2)>>2]=-aN;aN=aR>>6;c[910760+(aB+4096<<2)>>2]=aN;c[910760+(aQ+4096<<2)>>2]=-aN;aN=aR>>7;c[910760+(aB+4608<<2)>>2]=aN;c[910760+(aQ+4608<<2)>>2]=-aN;aN=aR>>8;c[910760+(aB+5120<<2)>>2]=aN;c[910760+(aQ+5120<<2)>>2]=-aN;aN=aR>>9;c[910760+(aB+5632<<2)>>2]=aN;c[910760+(aQ+5632<<2)>>2]=-aN;aN=aR>>10;c[910760+(aB+6144<<2)>>2]=aN;c[910760+(aQ+6144<<2)>>2]=-aN;if((aT|0)<256){aF=aT}else{aU=0;break}}while(1){ad=+U(+(+(aU<<1|1|0)*3.141592653589793*.0009765625));aF=~~(+$(+((ad>0.0?1.0:-1.0)/ad))*8.0/.6931471805599453*32.0*2.0);c[951960+(aU<<2)>>2]=(aF<<1&2)+aF&-2|ad<0.0;aF=aU+1|0;if((aF|0)<1024){aU=aF}else{aV=0;break}}while(1){aU=aV<<5;aF=aV+48|0;aT=aV+40|0;aN=aV+32|0;aQ=aV+24|0;aB=aV+16|0;aR=aV+8|0;aP=0;aM=0;while(1){aO=(aM<<8)+aU|0;aL=(aM&2|0)==0;aK=(aM&4|0)==0;aI=(aM&8|0)==0;aJ=(aM&16|0)==0;aH=(aM&32|0)==0;as=(aM&64|0)==0;if((aM&1|0)==0){aA=0;av=0;while(1){if(aL){aW=0}else{aW=a[668824+(aR<<3)+av|0]|0}if(aK){aX=aW}else{aX=(a[668824+(aB<<3)+av|0]|0)+aW&255}if(aI){aY=aX}else{aY=(a[668824+(aQ<<3)+av|0]|0)+aX&255}if(aJ){aZ=aY}else{aZ=(a[668824+(aN<<3)+av|0]|0)+aY&255}if(aH){a_=aZ}else{a_=(a[668824+(aT<<3)+av|0]|0)+aZ&255}if(as){a$=a_}else{a$=(a[668824+(aF<<3)+av|0]|0)+a_&255}au=a$&255;az=av+aO|0;c[1561112+(az<<2)>>2]=au;aw=(av^7)+aO|0;c[1561112+(aw+8<<2)>>2]=au;ay=-au|0;c[1561112+(az+16<<2)>>2]=ay;c[1561112+(aw+24<<2)>>2]=ay;ay=aA+1&255;if((ay&255)<8){aA=ay;av=ay&255}else{break}}}else{av=0;aA=0;while(1){am=a[668824+(aV<<3)+aA|0]|0;if(aL){a0=am}else{a0=(a[668824+(aR<<3)+aA|0]|0)+am&255}if(aK){a1=a0}else{a1=(a[668824+(aB<<3)+aA|0]|0)+a0&255}if(aI){a2=a1}else{a2=(a[668824+(aQ<<3)+aA|0]|0)+a1&255}if(aJ){a3=a2}else{a3=(a[668824+(aN<<3)+aA|0]|0)+a2&255}if(aH){a4=a3}else{a4=(a[668824+(aT<<3)+aA|0]|0)+a3&255}if(as){a5=a4}else{a5=(a[668824+(aF<<3)+aA|0]|0)+a4&255}am=a5&255;ah=aA+aO|0;c[1561112+(ah<<2)>>2]=am;ao=(aA^7)+aO|0;c[1561112+(ao+8<<2)>>2]=am;ay=-am|0;c[1561112+(ah+16<<2)>>2]=ay;c[1561112+(ao+24<<2)>>2]=ay;ay=av+1&255;if((ay&255)<8){av=ay;aA=ay&255}else{break}}}aA=aP+1&255;if(aA<<24>>24>-1){aP=aA;aM=aA&255}else{break}}aM=aV+1|0;if((aM|0)<8){aV=aM}else{a6=0;break}}while(1){aV=d[675976+a6|0]|0;c[749796+(a6<<2)>>2]=aV;c[750308+(a6<<2)>>2]=-aV;aV=a6+1|0;if((aV|0)<32){a6=aV}else{a7=0;break}}while(1){a6=d[a7+676008|0]|0;c[749924+(a7<<2)>>2]=a6;c[750436+(a7<<2)>>2]=-a6;a6=a7+1|0;if((a6|0)<32){a7=a6}else{a8=0;break}}while(1){a7=d[a8+676040|0]|0;c[750052+(a8<<2)>>2]=a7;c[750564+(a8<<2)>>2]=-a7;a7=a8+1|0;if((a7|0)<32){a8=a7}else{a9=0;break}}do{a8=d[a9+676072|0]|0;c[750180+(a9<<2)>>2]=a8;c[750692+(a9<<2)>>2]=-a8;a9=a9+1|0;}while((a9|0)<32);on(a[12474147]|0);ba=1008;bb=240;bc=118;bd=6656}else{a9=0;while(1){a8=a9+1|0;a7=~~+P(+(65536.0/+dj(+(+(a8|0)*.03125*.125))));a6=(a7>>>4&1)+(a7>>5)|0;a7=a9<<1;c[888232+(a7<<2)>>2]=a6;aV=a7|1;c[888232+(aV<<2)>>2]=-a6;a5=a6>>1;c[888232+(a7+512<<2)>>2]=a5;c[888232+(aV+512<<2)>>2]=-a5;a5=a6>>2;c[888232+(a7+1024<<2)>>2]=a5;c[888232+(aV+1024<<2)>>2]=-a5;a5=a6>>3;c[888232+(a7+1536<<2)>>2]=a5;c[888232+(aV+1536<<2)>>2]=-a5;a5=a6>>4;c[888232+(a7+2048<<2)>>2]=a5;c[888232+(aV+2048<<2)>>2]=-a5;a5=a6>>5;c[888232+(a7+2560<<2)>>2]=a5;c[888232+(aV+2560<<2)>>2]=-a5;a5=a6>>6;c[888232+(a7+3072<<2)>>2]=a5;c[888232+(aV+3072<<2)>>2]=-a5;a5=a6>>7;c[888232+(a7+3584<<2)>>2]=a5;c[888232+(aV+3584<<2)>>2]=-a5;a5=a6>>8;c[888232+(a7+4096<<2)>>2]=a5;c[888232+(aV+4096<<2)>>2]=-a5;a5=a6>>9;c[888232+(a7+4608<<2)>>2]=a5;c[888232+(aV+4608<<2)>>2]=-a5;a5=a6>>10;c[888232+(a7+5120<<2)>>2]=a5;c[888232+(aV+5120<<2)>>2]=-a5;if((a8|0)<256){a9=a8}else{be=0;break}}do{ad=+U(+(+(be<<1|1|0)*3.141592653589793*.0009765625));a9=~~(+$(+((ad>0.0?1.0:-1.0)/ad))*8.0/.6931471805599453*32.0*2.0);a8=(a9<<1&2)+a9&-2|ad<0.0;c[943768+(be<<2)>>2]=a8;c[943768+(be+1024<<2)>>2]=(be&512|0)==0?a8:5632;be=be+1|0;}while((be|0)<1024);aIv(750928,0,5984);be=0;do{c[752796+(be<<2)>>2]=~~(+(be|0)*64.0*64.0);be=be+1|0;}while((be|0)<1024);c[188155]=262144;c[188157]=16384;c[188160]=65536;c[188151]=65536;c[188152]=65536;ba=1080;bb=28;bc=2;bd=3230}c[3579686]=bd;c[3579684]=bc;c[3579682]=bb;c[494746]=ba;ou(0,b[6237075]|0,d[12474146]|0,255);ky();do{if((a[937424]|0)==-124){ba=d[9808]|0;if((ba|0)==0){bf=c9(14585456,697480)|0}else if((ba|0)==192){bf=c9(14585712,697480)|0}else if((ba|0)==128){bf=c9(14585200,697480)|0}else{break}if((bf|0)==0){a[11629663]=0}else{ec(11621472,8192,1,bf|0)|0;aS(bf|0)|0;ba=8192;bb=11621472;bc=-1;while(1){bd=ba-1|0;be=d[bb]|0;a8=c[684280+(((be^bc)&15)<<2)>>2]^bc>>>4;bg=a8>>>4^c[684280+((a8&15^be>>>4)<<2)>>2];if((bd|0)==0){break}else{ba=bd;bb=bb+1|0;bc=bg}}c[3118624]=~bg}if((aID(11629632,687072,32)|0)!=0){aIv(11621472,0,8128);a[687062]=0;a[687060]=0;a[687058]=0;a[687056]=0;a[687063]=125;a[687061]=125;a[687059]=125;a[687057]=125;aIy(11629600,687040,64)|0;c[3118624]=0}if((a[10441817]|0)==0){break}bc=c9(14586736,697480)|0;bb=c[2610455]|0;if((bc|0)==0){bh=bb}else{ba=bb+1|0;if((ba|0)>65536){bd=bb-65536|0;be=ba;a8=0;while(1){ec(1987672+a8|0,65536,1,bc|0)|0;a9=be-65536|0;if((a9|0)>65536){be=a9;a8=a8+65536|0}else{break}}a8=bd&-65536;bi=bb-65535-a8|0;bj=a8+65536|0}else{bi=ba;bj=0}if((bi|0)!=0){a8=1987672+bj|0;ec(a8|0,bi|0,1,bc|0)|0}aS(bc|0)|0;a8=c[2610455]|0;be=a8+1|0;if((be|0)==0){bk=0}else{a9=be;be=1987672;a5=-1;while(1){aV=a9-1|0;a7=d[be]|0;a6=c[684280+(((a7^a5)&15)<<2)>>2]^a5>>>4;bl=a6>>>4^c[684280+((a6&15^a7>>>4)<<2)>>2];if((aV|0)==0){break}else{a9=aV;be=be+1|0;a5=bl}}bk=~bl}c[3118622]=bk;bh=a8}if((aID(1987672+(bh-31)|0,687072,32)|0)==0){break}aIv(1987672,0,bh+1|0);a5=c[2610455]|0;be=(a5+1|0)>>>6;a9=(be+65533|0)>>>8&255;a[687062]=a9;a[687060]=a9;a[687058]=a9;a[687056]=a9;a9=be+253&255;a[687063]=a9;a[687061]=a9;a[687059]=a9;a[687057]=a9;a9=1987672+(a5-63)|0;aIy(a9|0,687040,64)|0}}while(0);aIh();aIi();X=1;i=f;return X|0}function aId(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function aIe(){return(a[888176]|0)!=0|0}function aIf(b){b=b|0;return((a[937481]|0)!=0&(b|0)==0?c[234374]|0:0)|0}function aIg(b){b=b|0;var c=0;if((a[937481]|0)==0){c=0;return c|0}c=(b|0)==0?65536:0;return c|0}function aIh(){var b=0,d=0,e=0,f=0.0;if((a[937424]&-127)<<24>>24==-128){kz();kz();kz();kz();kz();kz();kz();kz();kz();kz()}else{kC();kC();kC();kC();kC();kC();kC();kC();kC();kC()}c[205614]=(c[3446838]<<1)+(c[3446840]|0);c[222038]=(c[3446839]<<1)+(c[3446841]|0);ky();do{if((a[12474176]|0)==0){b=c[205614]|0}else{d=c[205614]|0;if((a[937424]|0)<0){e=(((d-3|0)/4|0)<<3)+8|0;c[205614]=e;b=e;break}else{e=(((d|0)/3|0)*7|0)+7|0;c[205614]=e;b=e;break}}}while(0);e=c[222038]|0;f=(a[888176]|0)==0?59.92274340431231:49.7014591857706;c[494726]=b;c[494727]=e;c[494728]=1024;c[494729]=512;g[494730]=1.3333333730697632;h[247366]=f;h[247367]=44100.0;return}function aIi(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+8|0;d=b|0;e=d;f=d;c[d>>2]=0;c[d+4>>2]=0;g=d;c[g>>2]=712952;do{if(fA[c[3118408]&63](15,f)|0){d=c[e+4>>2]|0;if((cP(d|0,706944)|0)==0){a[12474176]=0;h=1;break}if((cP(d|0,706488)|0)==0){a[12474176]=1;oh(c[235932]|0,2200);og(c[290362]|0,11416);h=1;break}if((cP(d|0,706120)|0)==0){a[12474176]=1;oh(c[235932]|0,2288);og(c[290362]|0,1161360);h=1;break}if((cP(d|0,705776)|0)==0){a[12474176]=1;oh(c[235932]|0,1952);og(c[290362]|0,11192);h=1;break}if((cP(d|0,705416)|0)!=0){h=1;break}a[12474176]=1;oh(c[235932]|0,2040);og(c[290362]|0,11280);h=1}else{h=0}}while(0);c[g>>2]=713824;if(fA[c[3118408]&63](15,f)|0){d=a[12474175]|0;j=c[e+4>>2]|0;do{if((cP(j|0,705024)|0)==0){a[12474175]=0;k=0}else{if((cP(j|0,704672)|0)==0){a[12474175]=1;k=1;break}if((cP(j|0,704368)|0)==0){a[12474175]=2;k=2;break}if((cP(j|0,703912)|0)!=0){k=d;break}a[12474175]=3;k=3}}while(0);l=h|d<<24>>24!=k<<24>>24}else{l=h}c[g>>2]=702528;do{if(fA[c[3118408]&63](15,f)|0){g=a[12474177]|0;h=c[e+4>>2]|0;do{if((cP(h|0,706944)|0)==0){a[12474177]=0;m=0}else{if((cP(h|0,703328)|0)!=0){m=g;break}a[12474177]=1;m=1}}while(0);if(l|g<<24>>24!=m<<24>>24){break}i=b;return}else{if(l){break}i=b;return}}while(0);aIh();i=b;return}function aIj(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[937424]|0)==-124){b=8192;e=11621472;f=-1}else{return}while(1){g=b-1|0;h=d[e]|0;i=c[684280+(((h^f)&15)<<2)>>2]^f>>>4;j=i>>>4^c[684280+((i&15^h>>>4)<<2)>>2];if((g|0)==0){break}else{b=g;e=e+1|0;f=j}}do{if((c[3118624]|0)!=(~j|0)){if((aID(11629632,687072,32)|0)!=0){break}f=d[9808]|0;if((f|0)==128){k=c9(14585200,707632)|0}else if((f|0)==0){k=c9(14585456,707632)|0}else if((f|0)==192){k=c9(14585712,707632)|0}else{return}if((k|0)==0){break}a5(11621472,8192,1,k|0)|0;aS(k|0)|0;f=8192;e=11621472;b=-1;while(1){g=f-1|0;h=d[e]|0;i=c[684280+(((h^b)&15)<<2)>>2]^b>>>4;l=i>>>4^c[684280+((i&15^h>>>4)<<2)>>2];if((g|0)==0){break}else{f=g;e=e+1|0;b=l}}c[3118624]=~l}}while(0);if((a[10441817]|0)==0){return}l=c[2610455]|0;k=l+1|0;if((k|0)==0){m=0}else{j=k;k=1987672;b=-1;while(1){e=j-1|0;f=d[k]|0;g=c[684280+(((f^b)&15)<<2)>>2]^b>>>4;n=g>>>4^c[684280+((g&15^f>>>4)<<2)>>2];if((e|0)==0){break}else{j=e;k=k+1|0;b=n}}m=~n}if((c[3118622]|0)==(m|0)){return}if((aID(1987672+(l-31)|0,687072,32)|0)!=0){return}l=c9(14586736,707632)|0;if((l|0)==0){return}m=c[2610455]|0;n=m+1|0;if((n|0)>65536){b=m-65536|0;k=n;j=0;while(1){a5(1987672+j|0,65536,1,l|0)|0;e=k-65536|0;if((e|0)>65536){k=e;j=j+65536|0}else{break}}j=b&-65536;o=m-65535-j|0;p=j+65536|0}else{o=n;p=0}if((o|0)!=0){n=1987672+p|0;a5(n|0,o|0,1,l|0)|0}aS(l|0)|0;l=(c[2610455]|0)+1|0;if((l|0)==0){q=0}else{o=l;l=1987672;n=-1;while(1){p=o-1|0;j=d[l]|0;m=c[684280+(((j^n)&15)<<2)>>2]^n>>>4;r=m>>>4^c[684280+((m&15^j>>>4)<<2)>>2];if((p|0)==0){break}else{o=p;l=l+1|0;n=r}}q=~r}c[3118622]=q;return}function aIk(){var a=0,b=0,d=0,e=0;a=i;i=i+16|0;b=a|0;d=a+8|0;e=aIp(688128)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}aIv(e|0,0,688128)}}while(0);c[235932]=e;e=aIp(65536)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}aIv(e|0,0,65536)}}while(0);c[290362]=e;c[b>>2]=1;fA[c[3118408]&63](8,b)|0;c[d>>2]=2;if(!(fA[c[3118408]&63](10,d)|0)){i=a;return}a5(708192,62,1,c[p>>2]|0)|0;i=a;return}function aIl(){var a=0,b=0,d=0,e=0,f=0;a=c[235925]|0;if((a|0)!=0){aIq(a)}c[235925]=0;a=c[235926]|0;if((a|0)!=0){aIq(a)}c[235926]=0;a=c[235927]|0;if((a|0)!=0){aIq(a)}c[235927]=0;a=c[235928]|0;if((a|0)!=0){aIq(a)}c[235928]=0;a=c[235929]|0;if((a|0)!=0){aIq(a)}c[235929]=0;a=c[235930]|0;if((a|0)==0){c[235930]=0;b=c[290362]|0;d=b;aIq(d);e=c[235932]|0;f=e;aIq(f);return}aIq(a);c[235930]=0;b=c[290362]|0;d=b;aIq(d);e=c[235932]|0;f=e;aIq(f);return}function aIm(){ky();return}function aIn(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[423054]|0;if((e|0)==0){return}fG[e&16383]();e=d[1692304]|0;do{if((e|0)==7|(e|0)==1){if((a[1692288]|0)==-1){break}else{f=0;g=0}while(1){if((fE[c[423052]&15](0,1,0,c[689448+(f<<3)>>2]|0)|0)<<16>>16==0){h=g}else{h=c[689452+(f<<3)>>2]|g}i=f+1|0;if(i>>>0<12){f=i;g=h}else{break}}b[846136]=h&65535}}while(0);h=d[1692296]|0;do{if((h|0)==7|(h|0)==1){if((a[1692292]|0)==-1){break}else{j=0;k=0}while(1){if((fE[c[423052]&15](1,1,0,c[689448+(j<<3)>>2]|0)|0)<<16>>16==0){l=k}else{l=c[689452+(j<<3)>>2]|k}b[846140]=l&65535;g=j+1|0;if(g>>>0<12){j=g;k=l}else{break}}}}while(0);if((a[12473444]&4)==0){return}else{m=0;n=0}while(1){if((fE[c[423052]&15](2,1,0,c[689448+(m<<3)>>2]|0)|0)<<16>>16==0){o=n}else{o=c[689452+(m<<3)>>2]|n}b[846141]=o&65535;l=m+1|0;if(l>>>0<12){m=l;n=o}else{p=0;q=0;break}}while(1){if((fE[c[423052]&15](3,1,0,c[689448+(p<<3)>>2]|0)|0)<<16>>16==0){r=q}else{r=c[689452+(p<<3)>>2]|q}b[846142]=r&65535;o=p+1|0;if(o>>>0<12){p=o;q=r}else{break}}return}function aIo(){var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0.0,ap=0.0,aq=0.0,ar=0.0,as=0.0,at=0.0,au=0.0,av=0.0,aw=0.0,ax=0.0,ay=0.0,az=0.0,aA=0.0,aB=0.0,aC=0.0,aD=0.0,aE=0.0,aF=0.0,aG=0,aH=0;f=i;i=i+8|0;g=f|0;a[g]=0;j=a[937424]|0;do{if(j<<24>>24==-124){k=d[962722]|0;c[290364]=0;c[2907544]=0;b[444104]=(b[780032]|0)-1&65535;c[496910]=0;c[496914]=0;lO();l=c[3446844]|0;m=a[1692200]|0;if((l&2|0)==0){n=m}else{o=a[962724]|0;p=(o&255)>>>1&1;a[1692200]=p;do{if(m<<24>>24==p<<24>>24){c[3446844]=l&-3;q=a[962713]|0}else{r=(o&6)==6;a[1692312]=r&1;a[968080]=1;c[3446844]=5;s=a[962713]|0;if((s&4)==0){q=s;break}t=(a[962723]&4)!=0;if(r){c[240676]=t?252:146;c[240674]=(o&8)!=0?30:32;q=s;break}else{c[240676]=t?198:106;c[240674]=(o&8)!=0?86:90;q=s;break}}}while(0);l=q&255;if((l&4|0)==0){c[3446841]=192;u=ab(-(a[12474175]&1)&24,(d[888176]|0)+1|0)|0}else{m=l<<1&16|224;c[3446841]=m;u=240-m+((d[888176]|0)*48|0)>>1&-(a[12474175]&1)}c[3446839]=u;c[3446840]=(o&255)<<6&64|256;n=p}m=b[468728]&-795|512;b[468728]=m;l=a[968080]^1;a[968080]=l;if(n<<24>>24!=0){b[468728]=(l&255)<<4|m}if((c[3118496]|0)!=0){jW(0)}if((c[3446839]|0)>0){m=e[444104]|0;l=c[3446838]|0;aIv(1560072+(32-l)|0,64,(c[3446840]|0)+(l<<1)|0);kw(m)}if((a[962713]&64)!=0){fi[c[242004]&255](-1)}mQ(3420);if((a[736792]|0)==1){oy(3420)}else{c[3579678]=3420}m=(c[290364]|0)+3420|0;c[290364]=m;l=0;s=k;t=m;while(1){b[444104]=l&65535;lO();m=s-1|0;do{if((m|0)<0){r=d[962722]|0;a[1692344]=16;if((a[962712]&16)==0){v=r;break}c[291682]=c[291682]|1024;v=r}else{v=m}}while(0);if((c[3118496]|0)!=0){jW(t)}kv(l);mQ((c[290364]|0)+3420|0);m=c[290364]|0;r=m+3420|0;if((a[736792]|0)==1){oy(r);w=c[290364]|0}else{c[3579678]=r;w=m}x=w+3420|0;c[290364]=x;y=l+1|0;z=c[3446841]|0;if((y|0)<(z|0)){l=y;s=v;t=x}else{break}}b[444104]=y&65535;b[468728]=b[468728]|8;t=c[3446839]|0;s=(e[780032]|0)-t|0;k=t+z|0;t=c[3446840]|0;if(!((t|0)==(c[3446842]|0)&(z|0)==(c[3446843]|0))){c[3446842]=t;c[3446843]=z;c[3446844]=c[3446844]|1}lO();do{if((v-1|0)<0){a[1692344]=16;if((a[962712]&16)==0){break}c[291682]=c[291682]|1024}}while(0);if((c[3118496]|0)!=0){jW(x)}if((y|0)<(k|0)){t=c[3446838]|0;aIv(1560072+(32-t)|0,64,(c[3446840]|0)+(t<<1)|0);kw(y)}aIn();IE((c[290364]|0)+588|0);b[468728]=b[468728]|128;IE((c[290364]|0)+788|0);t=(c[290364]|0)+788|0;if((a[736792]|0)==1){oy(t)}else{c[3579678]=t}a[888136]=32;if((a[962713]&32)!=0){c[291682]=1536}a[14318709]=1;mQ((c[290364]|0)+3420|0);t=c[290364]|0;p=t+3420|0;if((a[736792]|0)==1){oy(p);A=c[290364]|0}else{c[3579678]=p;A=t}t=A+3420|0;c[290364]=t;p=l+2|0;o=1;m=t;while(1){b[444104]=p&65535;lO();if(!((p|0)>=(k|0)&(p|0)<(s|0))){t=c[3446838]|0;aIv(1560072+(32-t)|0,64,(c[3446840]|0)+(t<<1)|0);kw(p)}if((o|0)==0){B=m}else{IE(m+788|0);t=c[290364]|0;r=t+788|0;if((a[736792]|0)==1){oy(r);C=c[290364]|0}else{c[3579678]=r;C=t}a[14318709]=0;B=C}mQ(B+3420|0);t=c[290364]|0;r=t+3420|0;if((a[736792]|0)==1){oy(r);D=c[290364]|0}else{c[3579678]=r;D=t}E=D+3420|0;c[290364]=E;t=p+1|0;if((t|0)<((e[780032]|0)-1|0)){p=t;o=0;m=E}else{break}}m=c[2907544]|0;o=c[2907545]|0;p=((m-o|0)>>>0)/1536|0;b[5814838]=(e[5814838]|0)+p&4095;c[2907545]=o-m+(p*1536|0);c[240563]=(c[240563]|0)-m;c[2907548]=(c[2907548]|0)-m;c[291647]=0;c[240561]=0;c[3579678]=(c[3579678]|0)-E;c[291649]=(c[291649]|0)-E}else{if((j&-127)<<24>>24==-128){kz();break}else{kC();break}}}while(0);if((a[12474176]|0)==0){G=(c[3446838]<<1)+(c[3446840]|0)|0}else{G=c[205614]|0}fH[c[222036]&63](c[3446834]|0,G,(c[3446839]<<1)+(c[3446841]|0)|0,c[3446837]|0);G=c[290364]|0;j=c[3645589]|0;if(j>>>0<G>>>0){ov(G);E=c[3645589]|0;D=G-E+239|0;B=E-((D>>>0)%240|0)+D|0;c[3645589]=B;H=B}else{H=j}c[3645589]=H-G;c[3645565]=(c[3645565]|0)-G;c[3645566]=(c[3645566]|0)-G;c[3645567]=(c[3645567]|0)-G;c[3645568]=(c[3645568]|0)-G;H=c[494748]|0;if(H>>>0<G>>>0){j=c[494746]|0;B=((G-1-H+j|0)>>>0)/(j>>>0)|0;fj[c[3579684]&511](c[494738]|0,B);c[494738]=(c[494738]|0)+(B<<1<<2);j=ab(c[494746]|0,B)|0;c[494748]=(c[494748]|0)+j}j=b[6237076]|0;B=c[494744]|0;H=c[494742]|0;D=c[494740]|0;E=c[494746]|0;if((a[12474144]|0)==0){C=1979e3;A=D;y=H;x=B;while(1){v=(ab(c[C>>2]|0,j)|0)/100|0;z=v-y|0;w=c[235925]|0;n=x;u=0;q=w|0;m=aIP(c[q>>2]|0,c[q+4>>2]|0,n,u)|0;q=w+8|0;aIF(m,F,c[q>>2]|0,c[q+4>>2]|0)|0;q=F;m=w+24|0;w=q>>>20|0<<12;p=ab((q>>>5|0<<27)&32767,z)|0;q=m+(w+7<<2)|0;c[q>>2]=(c[q>>2]|0)+(z<<15)-p;z=m+(w+8<<2)|0;c[z>>2]=p+(c[z>>2]|0);z=(ab(c[C+4>>2]|0,j)|0)/100|0;p=z-A|0;w=c[235926]|0;m=w|0;q=aIP(c[m>>2]|0,c[m+4>>2]|0,n,u)|0;u=w+8|0;aIF(q,F,c[u>>2]|0,c[u+4>>2]|0)|0;u=F;q=w+24|0;w=u>>>20|0<<12;n=ab((u>>>5|0<<27)&32767,p)|0;u=q+(w+7<<2)|0;c[u>>2]=(c[u>>2]|0)+(p<<15)-n;p=q+(w+8<<2)|0;c[p>>2]=n+(c[p>>2]|0);p=E+x|0;if(p>>>0<G>>>0){C=C+8|0;A=z;y=v;x=p}else{I=z;J=v;K=p;break}}}else{x=1979e3;y=D;D=H;H=B;while(1){B=(ab(c[x>>2]|0,j)|0)/100|0;ow(c[235925]|0,H,B-D|0);A=(ab(c[x+4>>2]|0,j)|0)/100|0;ow(c[235926]|0,H,A-y|0);C=E+H|0;if(C>>>0<G>>>0){x=x+8|0;y=A;D=B;H=C}else{I=A;J=B;K=C;break}}}c[494738]=1979e3;c[494742]=J;c[494740]=I;I=K-G|0;c[494744]=I;c[494748]=I;I=c[235925]|0;K=G;G=0;J=I|0;H=aIP(c[J>>2]|0,c[J+4>>2]|0,K,G)|0;J=I+8|0;I=aIF(c[J>>2]|0,c[J+4>>2]|0,H,F)|0;c[J>>2]=I;c[J+4>>2]=F;J=c[235926]|0;I=J|0;H=aIP(c[I>>2]|0,c[I+4>>2]|0,K,G)|0;G=J+8|0;J=aIF(c[G>>2]|0,c[G+4>>2]|0,H,F)|0;c[G>>2]=J;c[G+4>>2]=F;G=c[235925]|0;J=(c[G+12>>2]|0)>>>20|0<<12;H=0>>>20|0<<12;K=J;if((a[937424]|0)==-124){I=c[3184684]|0;D=0<<20|0>>>12;y=J<<20|0>>>12;x=I+8|0;E=c[x>>2]|0;j=c[x+4>>2]|0;do{if(!(y>>>0<j>>>0|y>>>0==j>>>0&D>>>0<E>>>0)){x=I|0;C=c[x>>2]|0;B=c[x+4>>2]|0;x=aIF(D,y,-1,-1)|0;A=aIG(x,F,E,j)|0;x=aIF(A,F,C,B)|0;A=aIQ(x,F,C,B)|0;B=A;if((B|0)==0){break}mt(B)}}while(0);c[3011189]=0;j=b[5989538]|0;E=b[5989539]|0;I=c[3184686]|0;B=I+8|0;A=c[B>>2]|0;C=c[B+4>>2]|0;if(y>>>0<C>>>0|y>>>0==C>>>0&D>>>0<A>>>0){L=0}else{B=I|0;x=c[B>>2]|0;p=c[B+4>>2]|0;B=aIF(D,y,-1,-1)|0;y=aIG(B,F,A,C)|0;A=aIF(y,F,x,p)|0;y=aIQ(A,F,x,p)|0;L=y}do{if((a[11629719]|0)==0){y=c[11977476+(c[2994362]<<4)>>2]|0;if((y|0)==0){M=43816;break}p=c[2994365]|0;x=(e[5814858]|0)>>>4;A=L<<2;ec(11958700,1,A|0,y|0)|0;y=c[3184686]|0;L53521:do{if((L|0)==0){N=j;O=E;P=p;Q=y}else{A=y|0;B=y+8|0;D=y+24|0;v=c[3184680]|0;z=v|0;n=v+8|0;w=v+24|0;v=0;q=E;u=j;m=p;o=11958700;while(1){s=m&2044;k=(s|0)!=0?s:m&3;s=(ab(b[o>>1]|0,k)|0)/1024|0;l=s-(u<<16>>16)|0;t=s&65535;s=v;r=0;R=aIP(c[A>>2]|0,c[A+4>>2]|0,s,r)|0;aIF(R,F,c[B>>2]|0,c[B+4>>2]|0)|0;R=F;S=R>>>20|0<<12;T=ab((R>>>5|0<<27)&32767,l)|0;R=D+(S+7<<2)|0;c[R>>2]=(c[R>>2]|0)+(l<<15)-T;l=D+(S+8<<2)|0;c[l>>2]=T+(c[l>>2]|0);l=(ab(b[o+2>>1]|0,k)|0)/1024|0;k=l-(q<<16>>16)|0;T=o+4|0;S=l&65535;l=aIP(c[z>>2]|0,c[z+4>>2]|0,s,r)|0;aIF(l,F,c[n>>2]|0,c[n+4>>2]|0)|0;l=F;r=l>>>20|0<<12;s=ab((l>>>5|0<<27)&32767,k)|0;l=w+(r+7<<2)|0;c[l>>2]=(c[l>>2]|0)+(k<<15)-s;k=w+(r+8<<2)|0;c[k>>2]=s+(c[k>>2]|0);do{if((m|0)<(x|0)){U=m+1|0}else{if((m|0)>(x|0)){U=m-1|0;break}else{if((m|0)==0){N=t;O=S;P=0;Q=y;break L53521}else{U=m;break}}}}while(0);k=v+1|0;if(k>>>0<L>>>0){v=k;q=S;u=t;m=U;o=T}else{N=t;O=S;P=U;Q=y;break}}}}while(0);c[2994365]=P;V=O;W=N;X=Q}else{M=43816}}while(0);do{if((M|0)==43816){if(j<<16>>16!=0){Q=-(j<<16>>16)|0;N=I+24|0;O=C>>>20|0<<12;P=ab((C>>>5|0<<27)&32767,Q)|0;U=N+(O+7<<2)|0;c[U>>2]=(c[U>>2]|0)+(Q<<15)-P;Q=N+(O+8<<2)|0;c[Q>>2]=P+(c[Q>>2]|0)}if(E<<16>>16==0){V=0;W=0;X=I;break}Q=c[3184680]|0;P=-(E<<16>>16)|0;O=c[Q+12>>2]|0;N=Q+24|0;Q=O>>>20|0<<12;U=ab((O>>>5|0<<27)&32767,P)|0;O=N+(Q+7<<2)|0;c[O>>2]=(c[O>>2]|0)+(P<<15)-U;P=N+(Q+8<<2)|0;c[P>>2]=U+(c[P>>2]|0);V=0;W=0;X=I}}while(0);b[5989538]=W;b[5989539]=V;V=L;L=0;W=X|0;I=aIP(c[W>>2]|0,c[W+4>>2]|0,V,L)|0;W=X+8|0;X=aIF(c[W>>2]|0,c[W+4>>2]|0,I,F)|0;c[W>>2]=X;c[W+4>>2]=F;W=c[3184680]|0;X=W|0;I=aIP(c[X>>2]|0,c[X+4>>2]|0,V,L)|0;L=W+8|0;W=aIF(c[L>>2]|0,c[L+4>>2]|0,I,F)|0;c[L>>2]=W;c[L+4>>2]=F;Y=c[235925]|0}else{Y=G}G=Y+24|0;L=G;W=L+(K<<2)|0;I=Y+20|0;V=c[I>>2]|0;X=937544;E=L;while(1){C=V>>15;j=E+4|0;M=(c[E>>2]|0)+V|0;if((C|0)>32767){Z=32767}else{Z=(C|0)<-32768?-32768:C}b[X>>1]=Z&65535;_=M-(Z<<6)|0;if((j|0)==(W|0)){break}else{V=_;X=X+4|0;E=j}}c[I>>2]=_;_=Y+8|0;Y=c[_>>2]|0;I=c[_+4>>2]|0;E=aIG(18,0,J,H)|0;H=F;X=aIF(I>>>20|0<<12,0>>>20|0<<12,E,H)|0;V=X;X=0<<20|0>>>12;Z=J<<20|0>>>12;j=aIG(Y,I,X,Z)|0;c[_>>2]=j;c[_+4>>2]=F;aIC(G|0,W|0,V<<2|0);W=J<<2|0>>>30;aIv(L+(V<<2)|0,0,W|0);V=c[235926]|0;L=V+24|0;J=L;G=J+(K<<2)|0;_=V+20|0;j=c[_>>2]|0;I=937546;Y=J;while(1){M=j>>15;C=Y+4|0;P=(c[Y>>2]|0)+j|0;if((M|0)>32767){$=32767}else{$=(M|0)<-32768?-32768:M}b[I>>1]=$&65535;aa=P-($<<6)|0;if((C|0)==(G|0)){break}else{j=aa;I=I+4|0;Y=C}}c[_>>2]=aa;aa=V+8|0;V=c[aa>>2]|0;_=c[aa+4>>2]|0;Y=aIF(_>>>20|0<<12,0>>>20|0<<12,E,H)|0;I=Y;Y=aIG(V,_,X,Z)|0;c[aa>>2]=Y;c[aa+4>>2]=F;aIC(L|0,G|0,I<<2|0);aIv(J+(I<<2)|0,0,W|0);if((a[937424]|0)==-124){I=c[235927]|0;J=I+24|0;G=J;L=G+(K<<2)|0;aa=I+20|0;Y=c[aa>>2]|0;_=937544;V=G;while(1){j=Y>>15;$=V+4|0;ac=(c[V>>2]|0)+Y-(j<<6)|0;C=(b[_>>1]|0)+j|0;if((C|0)>32767){ad=32767}else{ad=(C|0)<-32768?-32768:C&65535}b[_>>1]=ad;if(($|0)==(L|0)){break}else{Y=ac;_=_+4|0;V=$}}c[aa>>2]=ac;ac=I+8|0;I=c[ac>>2]|0;aa=c[ac+4>>2]|0;V=aIF(aa>>>20|0<<12,0>>>20|0<<12,E,H)|0;_=V;V=aIG(I,aa,X,Z)|0;c[ac>>2]=V;c[ac+4>>2]=F;aIC(J|0,L|0,_<<2|0);aIv(G+(_<<2)|0,0,W|0);_=c[235928]|0;G=_+24|0;L=G;J=L+(K<<2)|0;ac=_+20|0;V=c[ac>>2]|0;aa=937546;I=L;while(1){Y=V>>15;ad=I+4|0;ae=(c[I>>2]|0)+V-(Y<<6)|0;$=(b[aa>>1]|0)+Y|0;if(($|0)>32767){af=32767}else{af=($|0)<-32768?-32768:$&65535}b[aa>>1]=af;if((ad|0)==(J|0)){break}else{V=ae;aa=aa+4|0;I=ad}}c[ac>>2]=ae;ae=_+8|0;_=c[ae>>2]|0;ac=c[ae+4>>2]|0;I=aIF(ac>>>20|0<<12,0>>>20|0<<12,E,H)|0;aa=I;I=aIG(_,ac,X,Z)|0;c[ae>>2]=I;c[ae+4>>2]=F;aIC(G|0,J|0,aa<<2|0);aIv(L+(aa<<2)|0,0,W|0);aa=c[235929]|0;L=aa+24|0;J=L;G=J+(K<<2)|0;ae=aa+20|0;I=c[ae>>2]|0;ac=937544;_=J;while(1){V=I>>15;af=_+4|0;ag=(c[_>>2]|0)+I-(V<<6)|0;ad=(b[ac>>1]|0)+V|0;if((ad|0)>32767){ah=32767}else{ah=(ad|0)<-32768?-32768:ad&65535}b[ac>>1]=ah;if((af|0)==(G|0)){break}else{I=ag;ac=ac+4|0;_=af}}c[ae>>2]=ag;ag=aa+8|0;aa=c[ag>>2]|0;ae=c[ag+4>>2]|0;_=aIF(ae>>>20|0<<12,0>>>20|0<<12,E,H)|0;ac=_;_=aIG(aa,ae,X,Z)|0;c[ag>>2]=_;c[ag+4>>2]=F;aIC(L|0,G|0,ac<<2|0);aIv(J+(ac<<2)|0,0,W|0);ac=c[235930]|0;J=ac+24|0;G=J;L=G+(K<<2)|0;ag=ac+20|0;_=c[ag>>2]|0;ae=937546;aa=G;while(1){I=_>>15;ah=aa+4|0;ai=(c[aa>>2]|0)+_-(I<<6)|0;af=(b[ae>>1]|0)+I|0;if((af|0)>32767){aj=32767}else{aj=(af|0)<-32768?-32768:af&65535}b[ae>>1]=aj;if((ah|0)==(L|0)){break}else{_=ai;ae=ae+4|0;aa=ah}}c[ag>>2]=ai;ai=ac+8|0;ac=c[ai>>2]|0;ag=c[ai+4>>2]|0;aa=aIF(ag>>>20|0<<12,0>>>20|0<<12,E,H)|0;H=aa;aa=aIG(ac,ag,X,Z)|0;c[ai>>2]=aa;c[ai+4>>2]=F;aIC(J|0,L|0,H<<2|0);aIv(G+(H<<2)|0,0,W|0)}W=a[12474145]|0;do{if(W<<24>>24!=0){H=W&255;if((H&1|0)!=0){G=b[6237077]|0;L=65536-G|0;J=K;ai=937544;aa=b[481244]|0;Z=b[780028]|0;while(1){X=ab(Z,G)|0;ag=(ab(b[ai>>1]|0,L)|0)+X|0;X=ab(aa,G)|0;ac=ai+2|0;E=ag>>16;ag=(ab(b[ac>>1]|0,L)|0)+X>>16;ak=E&65535;b[ai>>1]=ak;al=ag&65535;b[ac>>1]=al;ac=J-1|0;if((ac|0)==0){break}else{J=ac;ai=ai+4|0;aa=ag;Z=E}}b[780028]=ak;b[481244]=al;break}if((H&2|0)==0){break}else{am=K;an=937544}while(1){ao=+h[1559188];ap=+(b[an>>1]|0);aq=+h[1559189];ar=aq+(ao*(ap-aq)+2.3283064370807974e-10);h[1559189]=ar;aq=+h[1559190];as=aq+ao*(ar-aq);h[1559190]=as;aq=+h[1559191];at=aq+ao*(as-aq);h[1559191]=at;aq=+h[1559192];au=aq+ao*(at-aq);h[1559192]=au;aq=+h[1559193];av=+h[1559194];aw=av+(aq*(ap-av)+2.3283064370807974e-10);h[1559194]=aw;av=+h[1559195];ax=av+aq*(aw-av);h[1559195]=ax;av=+h[1559196];ay=av+aq*(ax-av);h[1559196]=ay;av=+h[1559197];az=av+aq*(ay-av);h[1559197]=az;av=+h[1559200]-az;aA=+h[1559201];aB=+h[1559202];aC=+h[1559203];aD=+h[1559199];h[1559200]=aD;aE=+h[1559198];h[1559199]=aE;h[1559198]=ap;Z=~~(aC*av+(aA*au+aB*(ap-(au+av))));aa=an+2|0;av=+(b[aa>>1]|0);aF=ar+(ao*(av-ar)+2.3283064370807974e-10);h[1559189]=aF;ar=as+ao*(aF-as);h[1559190]=ar;as=at+ao*(ar-at);h[1559191]=as;at=au+ao*(as-au);h[1559192]=at;au=aw+(aq*(av-aw)+2.3283064370807974e-10);h[1559194]=au;aw=ax+aq*(au-ax);h[1559195]=aw;ax=ay+aq*(aw-ay);h[1559196]=ax;ay=az+aq*(ax-az);h[1559197]=ay;az=aD-ay;h[1559200]=aE;h[1559199]=ap;h[1559198]=av;ai=~~(aC*az+(aA*at+aB*(av-(at+az))));if((Z|0)>32767){aG=32767}else{aG=(Z|0)<-32768?-32768:Z&65535}if((ai|0)>32767){aH=32767}else{aH=(ai|0)<-32768?-32768:ai&65535}b[an>>1]=aG;b[aa>>1]=aH;aa=am-1|0;if((aa|0)==0){break}else{am=aa;an=an+4|0}}}}while(0);if((a[12474149]|0)!=0){an=K;am=937544;while(1){aH=am+2|0;aG=(((b[aH>>1]|0)+(b[am>>1]|0)|0)/2|0)&65535;b[am>>1]=aG;b[aH>>1]=aG;aG=an-1|0;if((aG|0)==0){break}else{an=aG;am=am+4|0}}}fA[c[3579458]&63](937544,K)|0;if(!(fA[c[3118408]&63](17,g)|0)){i=f;return}if((a[g]&1)==0){i=f;return}aIi();i=f;return}function aIp(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;do{if(a>>>0<245){if(a>>>0<11){b=16}else{b=a+11&-8}d=b>>>3;e=c[3579488]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=14317992+(h<<2)|0;j=14317992+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[3579488]=e&~(1<<g)}else{if(l>>>0<(c[3579492]|0)>>>0){b7();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{b7();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(b>>>0<=(c[3579490]|0)>>>0){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=14317992+(p<<2)|0;m=14317992+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[3579488]=e&~(1<<r)}else{if(l>>>0<(c[3579492]|0)>>>0){b7();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{b7();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[3579490]|0;if((l|0)!=0){q=c[3579493]|0;d=l>>>3;l=d<<1;f=14317992+(l<<2)|0;k=c[3579488]|0;h=1<<d;do{if((k&h|0)==0){c[3579488]=k|h;s=f;t=14317992+(l+2<<2)|0}else{d=14317992+(l+2<<2)|0;g=c[d>>2]|0;if(g>>>0>=(c[3579492]|0)>>>0){s=g;t=d;break}b7();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[3579490]=m;c[3579493]=e;n=i;return n|0}l=c[3579489]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[14318256+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[3579492]|0;if(r>>>0<i>>>0){b7();return 0}e=r+b|0;m=e;if(r>>>0>=e>>>0){b7();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){b7();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){b7();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){b7();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{b7();return 0}}}while(0);L53686:do{if((e|0)!=0){f=d+28|0;i=14318256+(c[f>>2]<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[3579489]=c[3579489]&~(1<<c[f>>2]);break L53686}else{if(e>>>0<(c[3579492]|0)>>>0){b7();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break L53686}}}while(0);if(v>>>0<(c[3579492]|0)>>>0){b7();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[3579490]|0;if((f|0)!=0){e=c[3579493]|0;i=f>>>3;f=i<<1;q=14317992+(f<<2)|0;k=c[3579488]|0;g=1<<i;do{if((k&g|0)==0){c[3579488]=k|g;y=q;z=14317992+(f+2<<2)|0}else{i=14317992+(f+2<<2)|0;l=c[i>>2]|0;if(l>>>0>=(c[3579492]|0)>>>0){y=l;z=i;break}b7();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[3579490]=p;c[3579493]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231){o=-1;break}f=a+11|0;g=f&-8;k=c[3579489]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[14318256+(A<<2)>>2]|0;L53734:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break L53734}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=(i|-i)&k;if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[14318256+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(J>>>0>=((c[3579490]|0)-g|0)>>>0){o=g;break}q=K;m=c[3579492]|0;if(q>>>0<m>>>0){b7();return 0}p=q+g|0;k=p;if(q>>>0>=p>>>0){b7();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){b7();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){b7();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){b7();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{b7();return 0}}}while(0);L53784:do{if((e|0)!=0){i=K+28|0;m=14318256+(c[i>>2]<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[3579489]=c[3579489]&~(1<<c[i>>2]);break L53784}else{if(e>>>0<(c[3579492]|0)>>>0){b7();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break L53784}}}while(0);if(L>>>0<(c[3579492]|0)>>>0){b7();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256){e=i<<1;m=14317992+(e<<2)|0;r=c[3579488]|0;j=1<<i;do{if((r&j|0)==0){c[3579488]=r|j;O=m;P=14317992+(e+2<<2)|0}else{i=14317992+(e+2<<2)|0;d=c[i>>2]|0;if(d>>>0>=(c[3579492]|0)>>>0){O=d;P=i;break}b7();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=14318256+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[3579489]|0;l=1<<Q;if((m&l|0)==0){c[3579489]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=44017;break}else{l=l<<1;m=j}}if((T|0)==44017){if(S>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[3579492]|0;if(m>>>0<i>>>0){b7();return 0}if(j>>>0<i>>>0){b7();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[3579490]|0;if(o>>>0<=K>>>0){S=K-o|0;J=c[3579493]|0;if(S>>>0>15){R=J;c[3579493]=R+o;c[3579490]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[3579490]=0;c[3579493]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[3579491]|0;if(o>>>0<J>>>0){S=J-o|0;c[3579491]=S;J=c[3579494]|0;K=J;c[3579494]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[242326]|0)==0){J=aP(8)|0;if((J-1&J|0)==0){c[242328]=J;c[242327]=J;c[242329]=-1;c[242330]=-1;c[242331]=0;c[3579599]=0;c[242326]=(eM(0)|0)&-16^1431655768;break}else{b7();return 0}}}while(0);J=o+48|0;S=c[242328]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(S>>>0<=o>>>0){n=0;return n|0}O=c[3579598]|0;do{if((O|0)!=0){P=c[3579596]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);L53876:do{if((c[3579599]&4|0)==0){O=c[3579494]|0;L53878:do{if((O|0)==0){T=44047}else{L=O;P=14318400;while(1){U=P|0;M=c[U>>2]|0;if(M>>>0<=L>>>0){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=44047;break L53878}else{P=M}}if((P|0)==0){T=44047;break}L=R-(c[3579491]|0)&Q;if(L>>>0>=2147483647){W=0;break}m=d1(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=44056}}while(0);do{if((T|0)==44047){O=d1(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[242327]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[3579596]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647)){W=0;break}m=c[3579598]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=d1($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=44056}}while(0);L53898:do{if((T|0)==44056){m=-_|0;if((X|0)!=-1){aa=Y;ab=X;T=44067;break L53876}do{if((Z|0)!=-1&_>>>0<2147483647&_>>>0<J>>>0){g=c[242328]|0;O=K-_+g&-g;if(O>>>0>=2147483647){ac=_;break}if((d1(O|0)|0)==-1){d1(m|0)|0;W=Y;break L53898}else{ac=O+_|0;break}}else{ac=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ac;ab=Z;T=44067;break L53876}}}while(0);c[3579599]=c[3579599]|4;ad=W;T=44064}else{ad=0;T=44064}}while(0);do{if((T|0)==44064){if(S>>>0>=2147483647){break}W=d1(S|0)|0;Z=d1(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ac=Z-W|0;Z=ac>>>0>(o+40|0)>>>0;Y=Z?W:-1;if((Y|0)!=-1){aa=Z?ac:ad;ab=Y;T=44067}}}while(0);do{if((T|0)==44067){ad=(c[3579596]|0)+aa|0;c[3579596]=ad;if(ad>>>0>(c[3579597]|0)>>>0){c[3579597]=ad}ad=c[3579494]|0;L53918:do{if((ad|0)==0){S=c[3579492]|0;if((S|0)==0|ab>>>0<S>>>0){c[3579492]=ab}c[3579600]=ab;c[3579601]=aa;c[3579603]=0;c[3579497]=c[242326];c[3579496]=-1;S=0;do{Y=S<<1;ac=14317992+(Y<<2)|0;c[14317992+(Y+3<<2)>>2]=ac;c[14317992+(Y+2<<2)>>2]=ac;S=S+1|0;}while(S>>>0<32);S=ab+8|0;if((S&7|0)==0){ae=0}else{ae=-S&7}S=aa-40-ae|0;c[3579494]=ab+ae;c[3579491]=S;c[ab+(ae+4)>>2]=S|1;c[ab+(aa-36)>>2]=40;c[3579495]=c[242330]}else{S=14318400;while(1){af=c[S>>2]|0;ag=S+4|0;ah=c[ag>>2]|0;if((ab|0)==(af+ah|0)){T=44079;break}ac=c[S+8>>2]|0;if((ac|0)==0){break}else{S=ac}}do{if((T|0)==44079){if((c[S+12>>2]&8|0)!=0){break}ac=ad;if(!(ac>>>0>=af>>>0&ac>>>0<ab>>>0)){break}c[ag>>2]=ah+aa;ac=c[3579494]|0;Y=(c[3579491]|0)+aa|0;Z=ac;W=ac+8|0;if((W&7|0)==0){ai=0}else{ai=-W&7}W=Y-ai|0;c[3579494]=Z+ai;c[3579491]=W;c[Z+(ai+4)>>2]=W|1;c[Z+(Y+4)>>2]=40;c[3579495]=c[242330];break L53918}}while(0);if(ab>>>0<(c[3579492]|0)>>>0){c[3579492]=ab}S=ab+aa|0;Y=14318400;while(1){aj=Y|0;if((c[aj>>2]|0)==(S|0)){T=44089;break}Z=c[Y+8>>2]|0;if((Z|0)==0){break}else{Y=Z}}do{if((T|0)==44089){if((c[Y+12>>2]&8|0)!=0){break}c[aj>>2]=ab;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ab+8|0;if((S&7|0)==0){ak=0}else{ak=-S&7}S=ab+(aa+8)|0;if((S&7|0)==0){al=0}else{al=-S&7}S=ab+(al+aa)|0;Z=S;W=ak+o|0;ac=ab+W|0;_=ac;K=S-(ab+ak)-o|0;c[ab+(ak+4)>>2]=o|3;do{if((Z|0)==(c[3579494]|0)){J=(c[3579491]|0)+K|0;c[3579491]=J;c[3579494]=_;c[ab+(W+4)>>2]=J|1}else{if((Z|0)==(c[3579493]|0)){J=(c[3579490]|0)+K|0;c[3579490]=J;c[3579493]=_;c[ab+(W+4)>>2]=J|1;c[ab+(J+W)>>2]=J;break}J=aa+4|0;X=c[ab+(al+J)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;L53963:do{if(X>>>0<256){U=c[ab+((al|8)+aa)>>2]|0;Q=c[ab+(aa+12+al)>>2]|0;R=14317992+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[3579492]|0)>>>0){b7();return 0}if((c[U+12>>2]|0)==(Z|0)){break}b7();return 0}}while(0);if((Q|0)==(U|0)){c[3579488]=c[3579488]&~(1<<V);break}do{if((Q|0)==(R|0)){am=Q+8|0}else{if(Q>>>0<(c[3579492]|0)>>>0){b7();return 0}m=Q+8|0;if((c[m>>2]|0)==(Z|0)){am=m;break}b7();return 0}}while(0);c[U+12>>2]=Q;c[am>>2]=U}else{R=S;m=c[ab+((al|24)+aa)>>2]|0;P=c[ab+(aa+12+al)>>2]|0;do{if((P|0)==(R|0)){O=al|16;g=ab+(O+J)|0;L=c[g>>2]|0;if((L|0)==0){e=ab+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){an=0;break}else{ao=O;ap=e}}else{ao=L;ap=g}while(1){g=ao+20|0;L=c[g>>2]|0;if((L|0)!=0){ao=L;ap=g;continue}g=ao+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{ao=L;ap=g}}if(ap>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[ap>>2]=0;an=ao;break}}else{g=c[ab+((al|8)+aa)>>2]|0;if(g>>>0<(c[3579492]|0)>>>0){b7();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){b7();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;an=P;break}else{b7();return 0}}}while(0);if((m|0)==0){break}P=ab+(aa+28+al)|0;U=14318256+(c[P>>2]<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=an;if((an|0)!=0){break}c[3579489]=c[3579489]&~(1<<c[P>>2]);break L53963}else{if(m>>>0<(c[3579492]|0)>>>0){b7();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=an}else{c[m+20>>2]=an}if((an|0)==0){break L53963}}}while(0);if(an>>>0<(c[3579492]|0)>>>0){b7();return 0}c[an+24>>2]=m;R=al|16;P=c[ab+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[an+16>>2]=P;c[P+24>>2]=an;break}}}while(0);P=c[ab+(R+J)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[an+20>>2]=P;c[P+24>>2]=an;break}}}while(0);aq=ab+(($|al)+aa)|0;ar=$+K|0}else{aq=Z;ar=K}J=aq+4|0;c[J>>2]=c[J>>2]&-2;c[ab+(W+4)>>2]=ar|1;c[ab+(ar+W)>>2]=ar;J=ar>>>3;if(ar>>>0<256){V=J<<1;X=14317992+(V<<2)|0;P=c[3579488]|0;m=1<<J;do{if((P&m|0)==0){c[3579488]=P|m;as=X;at=14317992+(V+2<<2)|0}else{J=14317992+(V+2<<2)|0;U=c[J>>2]|0;if(U>>>0>=(c[3579492]|0)>>>0){as=U;at=J;break}b7();return 0}}while(0);c[at>>2]=_;c[as+12>>2]=_;c[ab+(W+8)>>2]=as;c[ab+(W+12)>>2]=X;break}V=ac;m=ar>>>8;do{if((m|0)==0){au=0}else{if(ar>>>0>16777215){au=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;au=ar>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=14318256+(au<<2)|0;c[ab+(W+28)>>2]=au;c[ab+(W+20)>>2]=0;c[ab+(W+16)>>2]=0;X=c[3579489]|0;Q=1<<au;if((X&Q|0)==0){c[3579489]=X|Q;c[m>>2]=V;c[ab+(W+24)>>2]=m;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}if((au|0)==31){av=0}else{av=25-(au>>>1)|0}Q=ar<<av;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ar|0)){break}aw=X+16+(Q>>>31<<2)|0;m=c[aw>>2]|0;if((m|0)==0){T=44162;break}else{Q=Q<<1;X=m}}if((T|0)==44162){if(aw>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[aw>>2]=V;c[ab+(W+24)>>2]=X;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[3579492]|0;if(X>>>0<$>>>0){b7();return 0}if(m>>>0<$>>>0){b7();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ab+(W+8)>>2]=m;c[ab+(W+12)>>2]=X;c[ab+(W+24)>>2]=0;break}}}while(0);n=ab+(ak|8)|0;return n|0}}while(0);Y=ad;W=14318400;while(1){ax=c[W>>2]|0;if(ax>>>0<=Y>>>0){ay=c[W+4>>2]|0;az=ax+ay|0;if(az>>>0>Y>>>0){break}}W=c[W+8>>2]|0}W=ax+(ay-39)|0;if((W&7|0)==0){aA=0}else{aA=-W&7}W=ax+(ay-47+aA)|0;ac=W>>>0<(ad+16|0)>>>0?Y:W;W=ac+8|0;_=ab+8|0;if((_&7|0)==0){aB=0}else{aB=-_&7}_=aa-40-aB|0;c[3579494]=ab+aB;c[3579491]=_;c[ab+(aB+4)>>2]=_|1;c[ab+(aa-36)>>2]=40;c[3579495]=c[242330];c[ac+4>>2]=27;c[W>>2]=c[3579600];c[W+4>>2]=c[14318404>>2];c[W+8>>2]=c[14318408>>2];c[W+12>>2]=c[14318412>>2];c[3579600]=ab;c[3579601]=aa;c[3579603]=0;c[3579602]=W;W=ac+28|0;c[W>>2]=7;if((ac+32|0)>>>0<az>>>0){_=W;while(1){W=_+4|0;c[W>>2]=7;if((_+8|0)>>>0<az>>>0){_=W}else{break}}}if((ac|0)==(Y|0)){break}_=ac-ad|0;W=Y+(_+4)|0;c[W>>2]=c[W>>2]&-2;c[ad+4>>2]=_|1;c[Y+_>>2]=_;W=_>>>3;if(_>>>0<256){K=W<<1;Z=14317992+(K<<2)|0;S=c[3579488]|0;m=1<<W;do{if((S&m|0)==0){c[3579488]=S|m;aC=Z;aD=14317992+(K+2<<2)|0}else{W=14317992+(K+2<<2)|0;Q=c[W>>2]|0;if(Q>>>0>=(c[3579492]|0)>>>0){aC=Q;aD=W;break}b7();return 0}}while(0);c[aD>>2]=ad;c[aC+12>>2]=ad;c[ad+8>>2]=aC;c[ad+12>>2]=Z;break}K=ad;m=_>>>8;do{if((m|0)==0){aE=0}else{if(_>>>0>16777215){aE=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;ac=(Y+520192|0)>>>16&4;W=Y<<ac;Y=(W+245760|0)>>>16&2;Q=14-(ac|S|Y)+(W<<Y>>>15)|0;aE=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=14318256+(aE<<2)|0;c[ad+28>>2]=aE;c[ad+20>>2]=0;c[ad+16>>2]=0;Z=c[3579489]|0;Q=1<<aE;if((Z&Q|0)==0){c[3579489]=Z|Q;c[m>>2]=K;c[ad+24>>2]=m;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}if((aE|0)==31){aF=0}else{aF=25-(aE>>>1)|0}Q=_<<aF;Z=c[m>>2]|0;while(1){if((c[Z+4>>2]&-8|0)==(_|0)){break}aG=Z+16+(Q>>>31<<2)|0;m=c[aG>>2]|0;if((m|0)==0){T=44197;break}else{Q=Q<<1;Z=m}}if((T|0)==44197){if(aG>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[aG>>2]=K;c[ad+24>>2]=Z;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}}Q=Z+8|0;_=c[Q>>2]|0;m=c[3579492]|0;if(Z>>>0<m>>>0){b7();return 0}if(_>>>0<m>>>0){b7();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[ad+8>>2]=_;c[ad+12>>2]=Z;c[ad+24>>2]=0;break}}}while(0);ad=c[3579491]|0;if(ad>>>0<=o>>>0){break}_=ad-o|0;c[3579491]=_;ad=c[3579494]|0;Q=ad;c[3579494]=Q+o;c[Q+(o+4)>>2]=_|1;c[ad+4>>2]=o|3;n=ad+8|0;return n|0}}while(0);c[(dX()|0)>>2]=12;n=0;return n|0}function aIq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[3579492]|0;if(b>>>0<e>>>0){b7()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){b7()}h=f&-8;i=a+(h-8)|0;j=i;L54135:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){b7()}if((n|0)==(c[3579493]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[3579490]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=14317992+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){b7()}if((c[k+12>>2]|0)==(n|0)){break}b7()}}while(0);if((s|0)==(k|0)){c[3579488]=c[3579488]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){b7()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}b7()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){b7()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){b7()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){b7()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{b7()}}}while(0);if((p|0)==0){q=n;r=o;break}v=a+(l+28)|0;m=14318256+(c[v>>2]<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[3579489]=c[3579489]&~(1<<c[v>>2]);q=n;r=o;break L54135}else{if(p>>>0<(c[3579492]|0)>>>0){b7()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break L54135}}}while(0);if(A>>>0<(c[3579492]|0)>>>0){b7()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[3579492]|0)>>>0){b7()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[3579492]|0)>>>0){b7()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(d>>>0>=i>>>0){b7()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){b7()}do{if((e&2|0)==0){if((j|0)==(c[3579494]|0)){B=(c[3579491]|0)+r|0;c[3579491]=B;c[3579494]=q;c[q+4>>2]=B|1;if((q|0)!=(c[3579493]|0)){return}c[3579493]=0;c[3579490]=0;return}if((j|0)==(c[3579493]|0)){B=(c[3579490]|0)+r|0;c[3579490]=B;c[3579493]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;L54237:do{if(e>>>0<256){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=14317992+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[3579492]|0)>>>0){b7()}if((c[u+12>>2]|0)==(j|0)){break}b7()}}while(0);if((g|0)==(u|0)){c[3579488]=c[3579488]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[3579492]|0)>>>0){b7()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}b7()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[3579492]|0)>>>0){b7()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[3579492]|0)>>>0){b7()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){b7()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{b7()}}}while(0);if((f|0)==0){break}t=a+(h+20)|0;u=14318256+(c[t>>2]<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[3579489]=c[3579489]&~(1<<c[t>>2]);break L54237}else{if(f>>>0<(c[3579492]|0)>>>0){b7()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break L54237}}}while(0);if(E>>>0<(c[3579492]|0)>>>0){b7()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[3579492]|0)>>>0){b7()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[3579492]|0)>>>0){b7()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[3579493]|0)){H=B;break}c[3579490]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256){d=r<<1;e=14317992+(d<<2)|0;A=c[3579488]|0;E=1<<r;do{if((A&E|0)==0){c[3579488]=A|E;I=e;J=14317992+(d+2<<2)|0}else{r=14317992+(d+2<<2)|0;h=c[r>>2]|0;if(h>>>0>=(c[3579492]|0)>>>0){I=h;J=r;break}b7()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=14318256+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[3579489]|0;d=1<<K;do{if((r&d|0)==0){c[3579489]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=44374;break}else{A=A<<1;J=E}}if((N|0)==44374){if(M>>>0<(c[3579492]|0)>>>0){b7()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[3579492]|0;if(J>>>0<E>>>0){b7()}if(B>>>0<E>>>0){b7()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[3579496]|0)-1|0;c[3579496]=q;if((q|0)==0){O=14318408}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[3579496]=-1;return}function aIr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((a|0)==0){d=aIp(b)|0;return d|0}if(b>>>0>4294967231){c[(dX()|0)>>2]=12;d=0;return d|0}if(b>>>0<11){e=16}else{e=b+11&-8}f=a-8|0;g=a-4|0;h=c[g>>2]|0;i=h&-8;j=i-8|0;k=a+j|0;l=k;m=c[3579492]|0;if(f>>>0<m>>>0){b7();return 0}n=h&3;if(!((n|0)!=1&(j|0)>-8)){b7();return 0}j=i|4;o=a+(j-8)|0;p=c[o>>2]|0;if((p&1|0)==0){b7();return 0}L54373:do{if((n|0)==0){if(e>>>0<256|i>>>0<(e|4)>>>0){break}if((i-e|0)>>>0>c[242328]<<1>>>0|(f|0)==0){break}else{d=a}return d|0}else{do{if(i>>>0<e>>>0){if((l|0)==(c[3579494]|0)){q=(c[3579491]|0)+i|0;if(q>>>0<=e>>>0){break L54373}r=q-e|0;c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=r|1;c[3579494]=a+(e-8);c[3579491]=r;break}if((l|0)==(c[3579493]|0)){r=(c[3579490]|0)+i|0;if(r>>>0<e>>>0){break L54373}q=r-e|0;if(q>>>0>15){c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=q|1;c[a+(r-8)>>2]=q;s=a+(r-4)|0;c[s>>2]=c[s>>2]&-2;t=a+(e-8)|0;u=q}else{c[g>>2]=h&1|r|2;q=a+(r-4)|0;c[q>>2]=c[q>>2]|1;t=0;u=0}c[3579490]=u;c[3579493]=t;break}if((p&2|0)!=0){break L54373}q=(p&-8)+i|0;if(q>>>0<e>>>0){break L54373}r=q-e|0;s=p>>>3;L54397:do{if(p>>>0<256){v=c[a+i>>2]|0;w=c[a+j>>2]|0;x=14317992+(s<<1<<2)|0;do{if((v|0)!=(x|0)){if(v>>>0<m>>>0){b7();return 0}if((c[v+12>>2]|0)==(l|0)){break}b7();return 0}}while(0);if((w|0)==(v|0)){c[3579488]=c[3579488]&~(1<<s);break}do{if((w|0)==(x|0)){y=w+8|0}else{if(w>>>0<m>>>0){b7();return 0}z=w+8|0;if((c[z>>2]|0)==(l|0)){y=z;break}b7();return 0}}while(0);c[v+12>>2]=w;c[y>>2]=v}else{x=k;z=c[a+(i+16)>>2]|0;A=c[a+j>>2]|0;do{if((A|0)==(x|0)){B=a+(i+12)|0;C=c[B>>2]|0;if((C|0)==0){D=a+(i+8)|0;E=c[D>>2]|0;if((E|0)==0){F=0;break}else{G=E;H=D}}else{G=C;H=B}while(1){B=G+20|0;C=c[B>>2]|0;if((C|0)!=0){G=C;H=B;continue}B=G+16|0;C=c[B>>2]|0;if((C|0)==0){break}else{G=C;H=B}}if(H>>>0<m>>>0){b7();return 0}else{c[H>>2]=0;F=G;break}}else{B=c[a+i>>2]|0;if(B>>>0<m>>>0){b7();return 0}C=B+12|0;if((c[C>>2]|0)!=(x|0)){b7();return 0}D=A+8|0;if((c[D>>2]|0)==(x|0)){c[C>>2]=A;c[D>>2]=B;F=A;break}else{b7();return 0}}}while(0);if((z|0)==0){break}A=a+(i+20)|0;v=14318256+(c[A>>2]<<2)|0;do{if((x|0)==(c[v>>2]|0)){c[v>>2]=F;if((F|0)!=0){break}c[3579489]=c[3579489]&~(1<<c[A>>2]);break L54397}else{if(z>>>0<(c[3579492]|0)>>>0){b7();return 0}w=z+16|0;if((c[w>>2]|0)==(x|0)){c[w>>2]=F}else{c[z+20>>2]=F}if((F|0)==0){break L54397}}}while(0);if(F>>>0<(c[3579492]|0)>>>0){b7();return 0}c[F+24>>2]=z;x=c[a+(i+8)>>2]|0;do{if((x|0)!=0){if(x>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[F+16>>2]=x;c[x+24>>2]=F;break}}}while(0);x=c[a+(i+12)>>2]|0;if((x|0)==0){break}if(x>>>0<(c[3579492]|0)>>>0){b7();return 0}else{c[F+20>>2]=x;c[x+24>>2]=F;break}}}while(0);if(r>>>0>=16){c[g>>2]=c[g>>2]&1|e|2;c[a+((e|4)-8)>>2]=r|3;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;aIs(a+(e-8)|0,r);break}c[g>>2]=q|c[g>>2]&1|2;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;d=a;return d|0}else{s=i-e|0;if(s>>>0<=15){break}c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=s|3;c[o>>2]=c[o>>2]|1;aIs(a+(e-8)|0,s);d=a;return d|0}}while(0);if((f|0)==0){break}else{d=a}return d|0}}while(0);f=aIp(b)|0;if((f|0)==0){d=0;return d|0}e=c[g>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;e=g>>>0<b>>>0?g:b;aIy(f|0,a|0,e)|0;aIq(a);d=f;return d|0}function aIs(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;L54479:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[3579492]|0;if(i>>>0<l>>>0){b7()}if((j|0)==(c[3579493]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[3579490]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=14317992+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){b7()}if((c[p+12>>2]|0)==(j|0)){break}b7()}}while(0);if((q|0)==(p|0)){c[3579488]=c[3579488]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){b7()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}b7()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){b7()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){b7()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){b7()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{b7()}}}while(0);if((m|0)==0){n=j;o=k;break}t=d+(28-h)|0;l=14318256+(c[t>>2]<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[3579489]=c[3579489]&~(1<<c[t>>2]);n=j;o=k;break L54479}else{if(m>>>0<(c[3579492]|0)>>>0){b7()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break L54479}}}while(0);if(y>>>0<(c[3579492]|0)>>>0){b7()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[3579492]|0)>>>0){b7()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[3579492]|0)>>>0){b7()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[3579492]|0;if(e>>>0<a>>>0){b7()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[3579494]|0)){A=(c[3579491]|0)+o|0;c[3579491]=A;c[3579494]=n;c[n+4>>2]=A|1;if((n|0)!=(c[3579493]|0)){return}c[3579493]=0;c[3579490]=0;return}if((f|0)==(c[3579493]|0)){A=(c[3579490]|0)+o|0;c[3579490]=A;c[3579493]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;L54578:do{if(z>>>0<256){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=14317992+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){b7()}if((c[g+12>>2]|0)==(f|0)){break}b7()}}while(0);if((t|0)==(g|0)){c[3579488]=c[3579488]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){b7()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}b7()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){b7()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){b7()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){b7()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{b7()}}}while(0);if((m|0)==0){break}l=d+(b+28)|0;g=14318256+(c[l>>2]<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[3579489]=c[3579489]&~(1<<c[l>>2]);break L54578}else{if(m>>>0<(c[3579492]|0)>>>0){b7()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break L54578}}}while(0);if(C>>>0<(c[3579492]|0)>>>0){b7()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[3579492]|0)>>>0){b7()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[3579492]|0)>>>0){b7()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[3579493]|0)){F=A;break}c[3579490]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256){z=o<<1;y=14317992+(z<<2)|0;C=c[3579488]|0;b=1<<o;do{if((C&b|0)==0){c[3579488]=C|b;G=y;H=14317992+(z+2<<2)|0}else{o=14317992+(z+2<<2)|0;d=c[o>>2]|0;if(d>>>0>=(c[3579492]|0)>>>0){G=d;H=o;break}b7()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=14318256+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[3579489]|0;z=1<<I;if((o&z|0)==0){c[3579489]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=44640;break}else{I=I<<1;J=G}}if((L|0)==44640){if(K>>>0<(c[3579492]|0)>>>0){b7()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[3579492]|0;if(J>>>0<I>>>0){b7()}if(L>>>0<I>>>0){b7()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function aIt(b){b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0.0,x=0.0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0,L=0,M=0.0,N=0.0,O=0.0;d=b;while(1){e=d+1|0;if((bf(a[d]|0)|0)==0){break}else{d=e}}b=a[d]|0;if((b<<24>>24|0)==43){f=e;g=0}else if((b<<24>>24|0)==45){f=e;g=1}else{f=d;g=0}d=-1;e=0;b=f;while(1){i=a[b]|0;if(((i<<24>>24)-48|0)>>>0<10){j=d}else{if(i<<24>>24!=46|(d|0)>-1){break}else{j=e}}d=j;e=e+1|0;b=b+1|0}j=b+(-e|0)|0;f=(d|0)<0;k=((f^1)<<31>>31)+e|0;l=(k|0)>18;m=(l?-18:-k|0)+(f?e:d)|0;d=l?18:k;do{if((d|0)==0){n=0.0}else{if((d|0)>9){k=j;l=d;e=0;while(1){f=a[k]|0;o=k+1|0;if(f<<24>>24==46){p=a[o]|0;q=k+2|0}else{p=f;q=o}r=(e*10|0)-48+(p<<24>>24)|0;o=l-1|0;if((o|0)>9){k=q;l=o;e=r}else{break}}s=+(r|0)*1.0e9;t=9;u=q;v=44688}else{if((d|0)>0){s=0.0;t=d;u=j;v=44688}else{w=0.0;x=0.0}}if((v|0)==44688){e=u;l=t;k=0;while(1){o=a[e]|0;f=e+1|0;if(o<<24>>24==46){y=a[f]|0;z=e+2|0}else{y=o;z=f}A=(k*10|0)-48+(y<<24>>24)|0;f=l-1|0;if((f|0)>0){e=z;l=f;k=A}else{break}}w=+(A|0);x=s}B=x+w;do{if((i<<24>>24|0)==69|(i<<24>>24|0)==101){k=b+1|0;l=a[k]|0;if((l<<24>>24|0)==45){C=b+2|0;D=1}else if((l<<24>>24|0)==43){C=b+2|0;D=0}else{C=k;D=0}k=a[C]|0;if(((k<<24>>24)-48|0)>>>0<10){E=C;F=0;G=k}else{H=0;I=D;break}while(1){k=(G<<24>>24)-48+(F*10|0)|0;l=E+1|0;e=a[l]|0;if(((e<<24>>24)-48|0)>>>0<10){E=l;F=k;G=e}else{H=k;I=D;break}}}else{H=0;I=0}}while(0);k=m+((I|0)==0?H:-H|0)|0;e=(k|0)<0?-k|0:k;if((e|0)>511){c[(dX()|0)>>2]=34;J=1.0;K=10624;L=511;v=44705}else{if((e|0)==0){M=1.0}else{J=1.0;K=10624;L=e;v=44705}}if((v|0)==44705){while(1){v=0;if((L&1|0)==0){N=J}else{N=J*+h[K>>3]}e=L>>1;if((e|0)==0){M=N;break}else{J=N;K=K+8|0;L=e;v=44705}}}if((k|0)>-1){n=B*M;break}else{n=B/M;break}}}while(0);if((g|0)==0){O=n;return+O}O=-0.0-n;return+O}function aIu(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function aIv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+e|0;if((e|0)>=20){d=d&255;e=b&3;g=d|d<<8|d<<16|d<<24;h=f&~3;if(e){e=b+4-e|0;while((b|0)<(e|0)){a[b]=d;b=b+1|0}}while((b|0)<(h|0)){c[b>>2]=g;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}}function aIw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;u=u+1|0;c[a>>2]=u;while((e|0)<40){if((c[d+(e<<2)>>2]|0)==0){c[d+(e<<2)>>2]=u;c[d+((e<<2)+4)>>2]=b;c[d+((e<<2)+8)>>2]=0;return 0}e=e+2|0}cK(116);cK(111);cK(111);cK(32);cK(109);cK(97);cK(110);cK(121);cK(32);cK(115);cK(101);cK(116);cK(106);cK(109);cK(112);cK(115);cK(32);cK(105);cK(110);cK(32);cK(97);cK(32);cK(102);cK(117);cK(110);cK(99);cK(116);cK(105);cK(111);cK(110);cK(32);cK(99);cK(97);cK(108);cK(108);cK(44);cK(32);cK(98);cK(117);cK(105);cK(108);cK(100);cK(32);cK(119);cK(105);cK(116);cK(104);cK(32);cK(97);cK(32);cK(104);cK(105);cK(103);cK(104);cK(101);cK(114);cK(32);cK(118);cK(97);cK(108);cK(117);cK(101);cK(32);cK(102);cK(111);cK(114);cK(32);cK(77);cK(65);cK(88);cK(95);cK(83);cK(69);cK(84);cK(74);cK(77);cK(80);cK(83);cK(10);ac(0);return 0}function aIx(a,b){a=a|0;b=b|0;var d=0,e=0;while((d|0)<20){e=c[b+(d<<2)>>2]|0;if((e|0)==0)break;if((e|0)==(a|0)){return c[b+((d<<2)+4)>>2]|0}d=d+2|0}return 0}function aIy(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function aIz(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function aIA(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;while(e>>>0<d>>>0){f=aIz(a[b+e|0]|0)|0;g=aIz(a[c+e|0]|0)|0;if((f|0)==(g|0)&(f|0)==0)return 0;if((f|0)==0)return-1;if((g|0)==0)return 1;if((f|0)==(g|0)){e=e+1|0;continue}else{return(f>>>0>g>>>0?1:-1)|0}}return 0}function aIB(a,b){a=a|0;b=b|0;return aIA(a,b,-1)|0}function aIC(b,c,d){b=b|0;c=c|0;d=d|0;if((c|0)<(b|0)&(b|0)<(c+d|0)){c=c+d|0;b=b+d|0;while((d|0)>0){b=b-1|0;c=c-1|0;d=d-1|0;a[b]=a[c]|0}}else{aIy(b,c,d)|0}}function aID(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;while((e|0)<(c|0)){f=d[a+e|0]|0;g=d[b+e|0]|0;if((f|0)!=(g|0))return((f|0)>(g|0)?1:-1)|0;e=e+1|0}return 0}function aIE(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;while((e|0)<(d|0)){a[b+e|0]=f?0:a[c+e|0]|0;f=f?1:(a[c+e|0]|0)==0;e=e+1|0}return b|0}function aIF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(F=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function aIG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(F=e,a-c>>>0|0)|0}function aIH(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}F=a<<c-32;return 0}function aII(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}F=0;return b>>>c-32|0}function aIJ(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}F=(b|0)<0?-1:0;return b>>c-32|0}function aIK(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function aIL(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function aIM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ab(d,c)|0;f=a>>>16;a=(e>>>16)+(ab(d,f)|0)|0;d=b>>>16;b=ab(d,c)|0;return(F=(a>>>16)+(ab(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function aIN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=aIG(e^a,f^b,e,f)|0;b=F;a=g^e;e=h^f;f=aIG((aIS(i,b,aIG(g^c,h^d,g,h)|0,F,0)|0)^a,F^e,a,e)|0;return(F=F,f)|0}function aIO(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=aIG(h^a,j^b,h,j)|0;b=F;a=aIG(k^d,l^e,k,l)|0;aIS(m,b,a,F,g)|0;a=aIG(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=F;i=f;return(F=j,a)|0}function aIP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=aIM(e,a)|0;f=F;return(F=(ab(b,a)|0)+(ab(d,e)|0)+f|f&0,c|0|0)|0}function aIQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=aIS(a,b,c,d,0)|0;return(F=F,e)|0}function aIR(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;aIS(a,b,d,e,g)|0;i=f;return(F=c[g+4>>2]|0,c[g>>2]|0)|0}function aIS(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(F=n,o)|0}else{if(!m){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(F=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(F=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(F=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((aIL(l|0)|0)>>>0);return(F=n,o)|0}p=(aIK(l|0)|0)-(aIK(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(F=n,o)|0}else{if(!m){r=(aIK(l|0)|0)-(aIK(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(F=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(aIK(j|0)|0)+33-(aIK(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(F=n,o)|0}else{p=aIL(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(F=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;G=0;H=0}else{g=d|0|0;d=k|e&0;e=aIF(g,d,-1,-1)|0;k=F;i=w;w=v;v=u;u=t;t=s;s=0;while(1){I=w>>>31|i<<1;J=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;aIG(e,k,j,a)|0;b=F;h=b>>31|((b|0)<0?-1:0)<<1;K=h&1;L=aIG(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=F;b=t-1|0;if((b|0)==0){break}else{i=I;w=J;v=M;u=L;t=b;s=K}}B=I;C=J;D=M;E=L;G=0;H=K}K=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(K|0)>>>31|(B|C)<<1|(C<<1|K>>>31)&0|G;o=(K<<1|0>>>31)&-2|H;return(F=n,o)|0}function aIT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;di(a|0,b|0,c|0,d|0,e|0)}function aIU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;eC(a|0,b|0,c|0,d|0,e|0)}function aIV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dy(a|0,b|0,c|0,d|0,e|0)}function aIW(a,b){a=a|0;b=+b;bE(a|0,+b)}function aIX(a){a=a|0;bs(a|0)}function aIY(a){a=a|0;c3(a|0)}function aIZ(a){a=a|0;eW(a|0)}function aI_(a){a=a|0;cS(a|0)}function aI$(a){a=a|0;e3(a|0)}function aI0(a){a=a|0;cO(a|0)}function aI1(a){a=a|0;bB(a|0)}function aI2(a){a=a|0;bn(a|0)}function aI3(a){a=a|0;e4(a|0)}function aI4(a){a=a|0;bP(a|0)}function aI5(a){a=a|0;d6(a|0)}function aI6(a){a=a|0;dl(a|0)}function aI7(a){a=a|0;cg(a|0)}function aI8(a){a=a|0;eq(a|0)}function aI9(a){a=a|0;bp(a|0)}function aJa(a){a=a|0;be(a|0)}function aJb(a){a=a|0;eb(a|0)}function aJc(a){a=a|0;cM(a|0)}function aJd(a){a=a|0;c2(a|0)}function aJe(a){a=a|0;dr(a|0)}function aJf(a){a=a|0;dg(a|0)}function aJg(a){a=a|0;fd(a|0)}function aJh(a){a=a|0;by(a|0)}function aJi(a){a=a|0;a9(a|0)}function aJj(a){a=a|0;ch(a|0)}function aJk(a,b){a=a|0;b=b|0;dY(a|0,b|0)}function aJl(a,b){a=a|0;b=b|0;cQ(a|0,b|0)}function aJm(a,b){a=a|0;b=b|0;bA(a|0,b|0)}function aJn(a,b){a=a|0;b=b|0;aZ(a|0,b|0)}function aJo(a,b){a=a|0;b=b|0;dP(a|0,b|0)}function aJp(a,b){a=a|0;b=b|0;eJ(a|0,b|0)}function aJq(a,b){a=a|0;b=b|0;eB(a|0,b|0)}function aJr(a,b){a=a|0;b=b|0;d4(a|0,b|0)}function aJs(a,b){a=a|0;b=b|0;c7(a|0,b|0)}function aJt(a,b){a=a|0;b=b|0;bh(a|0,b|0)}function aJu(a,b){a=a|0;b=b|0;bO(a|0,b|0)}function aJv(a,b){a=a|0;b=b|0;c1(a|0,b|0)}function aJw(a,b){a=a|0;b=b|0;bY(a|0,b|0)}function aJx(a,b){a=a|0;b=b|0;ez(a|0,b|0)}function aJy(a,b){a=a|0;b=b|0;b2(a|0,b|0)}function aJz(a,b){a=a|0;b=b|0;dT(a|0,b|0)}function aJA(a,b){a=a|0;b=b|0;cU(a|0,b|0)}function aJB(a,b){a=a|0;b=b|0;cZ(a|0,b|0)}function aJC(a,b){a=a|0;b=b|0;cH(a|0,b|0)}function aJD(a,b){a=a|0;b=b|0;e9(a|0,b|0)}function aJE(a,b){a=a|0;b=b|0;e6(a|0,b|0)}function aJF(a,b){a=a|0;b=b|0;fe(a|0,b|0)}function aJG(a,b){a=a|0;b=b|0;e5(a|0,b|0)}function aJH(a,b){a=a|0;b=b|0;cl(a|0,b|0)}function aJI(a,b){a=a|0;b=b|0;b9(a|0,b|0)}function aJJ(a,b){a=a|0;b=b|0;bI(a|0,b|0)}function aJK(a,b){a=a|0;b=b|0;dw(a|0,b|0)}function aJL(a,b){a=a|0;b=b|0;cx(a|0,b|0)}function aJM(a,b){a=a|0;b=b|0;bX(a|0,b|0)}function aJN(a,b){a=a|0;b=b|0;bL(a|0,b|0)}function aJO(a,b){a=a|0;b=b|0;dO(a|0,b|0)}function aJP(a,b){a=a|0;b=b|0;eF(a|0,b|0)}function aJQ(a,b){a=a|0;b=b|0;fb(a|0,b|0)}function aJR(a){a=a|0;return bJ(a|0)|0}function aJS(a){a=a|0;return dH(a|0)|0}function aJT(a){a=a|0;return cK(a|0)|0}function aJU(a){a=a|0;return eg(a|0)|0}function aJV(a){a=a|0;return cc(a|0)|0}function aJW(a){a=a|0;return d$(a|0)|0}function aJX(a){a=a|0;return b3(a|0)|0}function aJY(a){a=a|0;return a4(a|0)|0}function aJZ(a){a=a|0;return a_(a|0)|0}function aJ_(a){a=a|0;return dh(a|0)|0}function aJ$(a){a=a|0;return bw(a|0)|0}function aJ0(a){a=a|0;return aS(a|0)|0}function aJ1(a){a=a|0;return dv(a|0)|0}function aJ2(a){a=a|0;return cp(a|0)|0}function aJ3(a){a=a|0;return co(a|0)|0}function aJ4(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;dx(a|0,+b,+c,+d,+e)}function aJ5(a,b,c){a=a|0;b=b|0;c=c|0;return bM(a|0,b|0,c|0)|0}function aJ6(a,b,c){a=a|0;b=b|0;c=c|0;return a2(a|0,b|0,c|0)|0}function aJ7(a,b,c){a=a|0;b=b|0;c=c|0;return aX(a|0,b|0,c|0)|0}function aJ8(a,b,c){a=a|0;b=b|0;c=c|0;return ee(a|0,b|0,c|0)|0}function aJ9(a,b,c){a=a|0;b=b|0;c=c|0;return cT(a|0,b|0,c|0)|0}function aKa(a,b,c){a=a|0;b=b|0;c=c|0;return ei(a|0,b|0,c|0)|0}function aKb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;bW(a|0,b|0,c|0,d|0,e|0,f|0)}function aKc(a){a=+a;return+bK(+a)}function aKd(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ea(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function aKe(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;d8(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function aKf(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;bD(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function aKg(a,b){a=a|0;b=b|0;return c9(a|0,b|0)|0}function aKh(a,b){a=a|0;b=b|0;return dG(a|0,b|0)|0}function aKi(a,b){a=a|0;b=b|0;return cP(a|0,b|0)|0}function aKj(a,b){a=a|0;b=b|0;return c6(a|0,b|0)|0}function aKk(a,b){a=a|0;b=b|0;return eI(a|0,b|0)|0}function aKl(){return+bb()}function aKm(){return dK()|0}function aKn(){return eG()|0}function aKo(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return a5(a|0,b|0,c|0,d|0)|0}function aKp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return bQ(a|0,b|0,c|0,d|0)|0}function aKq(a,b,c){a=a|0;b=b|0;c=c|0;bu(a|0,b|0,c|0)}function aKr(a,b,c){a=a|0;b=b|0;c=c|0;dN(a|0,b|0,c|0)}function aKs(a,b,c){a=a|0;b=b|0;c=c|0;eN(a|0,b|0,c|0)}function aKt(a,b,c){a=a|0;b=b|0;c=c|0;cI(a|0,b|0,c|0)}function aKu(a,b,c){a=a|0;b=b|0;c=c|0;aV(a|0,b|0,c|0)}function aKv(a,b,c){a=a|0;b=b|0;c=c|0;du(a|0,b|0,c|0)}function aKw(a,b,c){a=a|0;b=b|0;c=c|0;b6(a|0,b|0,c|0)}function aKx(a,b,c){a=a|0;b=b|0;c=c|0;bd(a|0,b|0,c|0)}function aKy(a,b,c){a=a|0;b=b|0;c=c|0;dt(a|0,b|0,c|0)}function aKz(a,b,c){a=a|0;b=b|0;c=c|0;db(a|0,b|0,c|0)}function aKA(a,b,c){a=a|0;b=b|0;c=c|0;aU(a|0,b|0,c|0)}function aKB(a,b,c){a=a|0;b=b|0;c=c|0;cL(a|0,b|0,c|0)}function aKC(a,b,c){a=a|0;b=b|0;c=c|0;dL(a|0,b|0,c|0)}function aKD(a,b,c){a=a|0;b=b|0;c=c|0;cV(a|0,b|0,c|0)}function aKE(a,b,c){a=a|0;b=b|0;c=c|0;ex(a|0,b|0,c|0)}function aKF(a,b,c){a=a|0;b=b|0;c=c|0;eS(a|0,b|0,c|0)}function aKG(a,b,c){a=a|0;b=b|0;c=c|0;bG(a|0,b|0,c|0)}function aKH(a,b,c){a=a|0;b=b|0;c=c|0;cv(a|0,b|0,c|0)}function aKI(a,b,c){a=a|0;b=b|0;c=c|0;dR(a|0,b|0,c|0)}function aKJ(a,b,c){a=a|0;b=b|0;c=c|0;e2(a|0,b|0,c|0)}function aKK(a,b,c){a=a|0;b=b|0;c=c|0;bT(a|0,b|0,c|0)}function aKL(a,b,c){a=a|0;b=b|0;c=c|0;dM(a|0,b|0,c|0)}function aKM(a,b,c){a=a|0;b=b|0;c=c|0;ba(a|0,b|0,c|0)}function aKN(a,b,c){a=a|0;b=b|0;c=c|0;bR(a|0,b|0,c|0)}function aKO(a,b,c){a=a|0;b=b|0;c=c|0;cb(a|0,b|0,c|0)}function aKP(a,b,c){a=a|0;b=b|0;c=c|0;a0(a|0,b|0,c|0)}function aKQ(a,b,c){a=a|0;b=b|0;c=c|0;bq(a|0,b|0,c|0)}function aKR(a,b,c){a=a|0;b=b|0;c=c|0;e0(a|0,b|0,c|0)}function aKS(a,b,c){a=a|0;b=b|0;c=c|0;br(a|0,b|0,c|0)}function aKT(){cw()}function aKU(){eA()}function aKV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dz(a|0,b|0,c|0,d|0)}function aKW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eV(a|0,b|0,c|0,d|0)}function aKX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ep(a|0,b|0,c|0,d|0)}function aKY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eK(a|0,b|0,c|0,d|0)}function aKZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bU(a|0,b|0,c|0,d|0)}function aK_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ef(a|0,b|0,c|0,d|0)}function aK$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dE(a|0,b|0,c|0,d|0)}function aK0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dF(a|0,b|0,c|0,d|0)}function aK1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cY(a|0,b|0,c|0,d|0)}function aK2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;aO(a|0,b|0,c|0,d|0)}function aK3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dU(a|0,b|0,c|0,d|0)}function aK4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dC(a|0,b|0,c|0,d|0)}function aK5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d5(a|0,b|0,c|0,d|0)}function aK6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cA(a|0,b|0,c|0,d|0)}function aK7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ed(a|0,b|0,c|0,d|0)}function aK8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b1(a|0,b|0,c|0,d|0)}function aK9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cB(a|0,b|0,c|0,d|0)}function aLa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dQ(a|0,b|0,c|0,d|0)}function aLb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cn(a|0,b|0,c|0,d|0)}function aLc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;er(a|0,b|0,c|0,d|0)}function aLd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cj(a|0,b|0,c|0,d|0)}function aLe(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bk(a|0,b|0,c|0,d|0)}function aLf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d9(a|0,b|0,c|0,d|0)}function aLg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ej(a|0,b|0,c|0,d|0)}function aLh(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;bj(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function aLi(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;df(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function aLj(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;cz(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function aLk(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;dS(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function aLl(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eu(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function aLm(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eX(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function aLn(a,b,c){a=a|0;b=+b;c=+c;dn(a|0,+b,+c)}function aLo(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;cu(a|0,+b,+c,+d)}function aLp(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return ff[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0)|0}function aLq(a,b,c){a=a|0;b=b|0;c=+c;fg[a&7](b|0,+c)}function aLr(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;fh[a&15](b|0,c|0,d|0,e|0,f|0)}function aLs(a,b){a=a|0;b=b|0;fi[a&255](b|0)}function aLt(a,b,c){a=a|0;b=b|0;c=c|0;fj[a&511](b|0,c|0)}function aLu(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return fk[a&15](b|0,c|0,d|0,e|0,f|0,g|0)|0}function aLv(a,b){a=a|0;b=b|0;return fl[a&255](b|0)|0}function aLw(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;fm[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)}function aLx(a,b,c,d,e,f){a=a|0;b=b|0;c=+c;d=+d;e=+e;f=+f;fn[a&7](b|0,+c,+d,+e,+f)}function aLy(a,b){a=a|0;b=+b;return fo[a&3](+b)|0}function aLz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fp[a&63](b|0,c|0,d|0)|0}function aLA(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;fq[a&3](b|0,c|0,d|0,e|0,f|0,+g)}function aLB(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;fr[a&7](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function aLC(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=+d;e=+e;fs[a&3](b|0,+c,+d,+e)}function aLD(a,b,c){a=a|0;b=b|0;c=c|0;return+ft[a&3](b|0,c|0)}function aLE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;return fu[a&3](b|0,c|0,+d)|0}function aLF(a,b,c,d){a=a|0;b=b|0;c=+c;d=+d;fv[a&3](b|0,+c,+d)}function aLG(a,b,c){a=a|0;b=b|0;c=+c;return fw[a&3](b|0,+c)|0}function aLH(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;fx[a&7](b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function aLI(a,b){a=a|0;b=+b;return+fy[a&3](+b)}function aLJ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;fz[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)}function aLK(a,b,c){a=a|0;b=b|0;c=c|0;return fA[a&63](b|0,c|0)|0}function aLL(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;fB[a&31](b|0,c|0,d|0,e|0,f|0,g|0)}function aLM(a){a=a|0;return+fC[a&3]()}function aLN(a){a=a|0;return fD[a&127]()|0}function aLO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fE[a&15](b|0,c|0,d|0,e|0)|0}function aLP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fF[a&127](b|0,c|0,d|0)}function aLQ(a){a=a|0;fG[a&16383]()}function aLR(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;fH[a&63](b|0,c|0,d|0,e|0)}function aLS(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ac(0);return 0}function aLT(a,b){a=a|0;b=+b;ac(1)}function aLU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ac(2)}function aLV(a){a=a|0;ac(3)}function aLW(a,b){a=a|0;b=b|0;ac(4)}function aLX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ac(5);return 0}function aLY(a){a=a|0;ac(6);return 0}function aLZ(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;ac(7)}function aL_(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;ac(8)}function aL$(a){a=+a;ac(9);return 0}function aL0(a,b,c){a=a|0;b=b|0;c=c|0;ac(10);return 0}function aL1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;ac(11)}function aL2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ac(12)}function aL3(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;ac(13)}function aL4(a,b){a=a|0;b=b|0;ac(14);return 0.0}function aL5(a,b,c){a=a|0;b=b|0;c=+c;ac(15);return 0}function aL6(a,b,c){a=a|0;b=+b;c=+c;ac(16)}function aL7(a,b){a=a|0;b=+b;ac(17);return 0}function aL8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ac(18)}function aL9(a){a=+a;ac(19);return 0.0}function aMa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ac(20)}function aMb(a,b){a=a|0;b=b|0;ac(21);return 0}function aMc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ac(22)}function aMd(){ac(23);return 0.0}function aMe(){ac(24);return 0}function aMf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ac(25);return 0}function aMg(a,b,c){a=a|0;b=b|0;c=c|0;ac(26)}function aMh(){ac(27)}function aMi(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ac(28)}
// EMSCRIPTEN_END_FUNCS
var ff=[aLS,aLS,jf,aLS];var fg=[aLT,aLT,i_,aLT,aIW,aLT,aLT,aLT];var fh=[aLU,aLU,jo,aLU,aIT,aLU,aIU,aLU,aIV,aLU,aLU,aLU,aLU,aLU,aLU,aLU];var fi=[aLV,aLV,aIX,aLV,hF,aLV,aIY,aLV,gf,aLV,is,aLV,j1,aLV,aIZ,aLV,aHV,aLV,aI_,aLV,hv,aLV,i8,aLV,aI$,aLV,jP,aLV,aI0,aLV,ku,aLV,km,aLV,mz,aLV,aI1,aLV,gp,aLV,ig,aLV,mx,aLV,hi,aLV,hB,aLV,g0,aLV,aI2,aLV,Iw,aLV,jx,aLV,nU,aLV,aI3,aLV,g$,aLV,hM,aLV,g_,aLV,aI4,aLV,nP,aLV,aHY,aLV,aI5,aLV,mc,aLV,nZ,aLV,n_,aLV,n$,aLV,n1,aLV,nX,aLV,ko,aLV,j4,aLV,kl,aLV,nY,aLV,j0,aLV,ks,aLV,kn,aLV,jR,aLV,iO,aLV,jS,aLV,aI6,aLV,j6,aLV,kr,aLV,gN,aLV,jM,aLV,nV,aLV,gZ,aLV,aI7,aLV,iV,aLV,jb,aLV,jZ,aLV,aI8,aLV,aHW,aLV,aI9,aLV,kq,aLV,kk,aLV,kt,aLV,j5,aLV,aH5,aLV,he,aLV,j3,aLV,aJa,aLV,aH0,aLV,IC,aLV,g1,aLV,aJb,aLV,aJc,aLV,nW,aLV,hu,aLV,oB,aLV,aJd,aLV,aH7,aLV,hh,aLV,aJe,aLV,aHU,aLV,aHX,aLV,n0,aLV,aJf,aLV,aJg,aLV,hq,aLV,kp,aLV,io,aLV,aJh,aLV,aJi,aLV,mu,aLV,mw,aLV,aIq,aLV,jQ,aLV,aJj,aLV,gO,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV,aLV];var fj=[aLW,aLW,os,aLW,iR,aLW,jc,aLW,aJk,aLW,jp,aLW,m0,aLW,mS,aLW,aJl,aLW,lD,aLW,m2,aLW,kR,aLW,aJm,aLW,kS,aLW,or,aLW,aJn,aLW,aJo,aLW,iI,aLW,aJp,aLW,gl,aLW,aJq,aLW,jz,aLW,aJr,aLW,ny,aLW,aJs,aLW,mI,aLW,nq,aLW,ld,aLW,aJt,aLW,ie,aLW,kd,aLW,k4,aLW,aJu,aLW,lH,aLW,i3,aLW,i$,aLW,lQ,aLW,nx,aLW,mf,aLW,nz,aLW,k2,aLW,iH,aLW,kG,aLW,hr,aLW,j9,aLW,ka,aLW,lh,aLW,nA,aLW,aJv,aLW,lu,aLW,iS,aLW,im,aLW,aJw,aLW,kg,aLW,aJx,aLW,no,aLW,l1,aLW,nF,aLW,ly,aLW,om,aLW,aJy,aLW,aJz,aLW,nM,aLW,k9,aLW,mC,aLW,nL,aLW,lS,aLW,mo,aLW,lw,aLW,m1,aLW,kV,aLW,m5,aLW,lA,aLW,ki,aLW,gY,aLW,mg,aLW,nt,aLW,k7,aLW,aJA,aLW,k5,aLW,aJB,aLW,ms,aLW,mA,aLW,kI,aLW,kc,aLW,lk,aLW,mj,aLW,lf,aLW,nw,aLW,kH,aLW,aJC,aLW,mn,aLW,lo,aLW,ng,aLW,aJD,aLW,aJE,aLW,lW,aLW,n8,aLW,l8,aLW,kh,aLW,aJF,aLW,jh,aLW,iK,aLW,kf,aLW,nm,aLW,i2,aLW,j8,aLW,m7,aLW,k$,aLW,kb,aLW,mr,aLW,aJG,aLW,mB,aLW,mW,aLW,iq,aLW,m$,aLW,l0,aLW,ls,aLW,aHZ,aLW,lT,aLW,ol,aLW,gj,aLW,aJH,aLW,iZ,aLW,lC,aLW,kW,aLW,kj,aLW,gI,aLW,mN,aLW,aJI,aLW,mX,aLW,lX,aLW,k0,aLW,aJJ,aLW,lb,aLW,lt,aLW,mO,aLW,aJK,aLW,aJL,aLW,kF,aLW,ne,aLW,aJM,aLW,l7,aLW,mL,aLW,lR,aLW,aJN,aLW,aJO,aLW,mM,aLW,na,aLW,nE,aLW,hL,aLW,nc,aLW,np,aLW,aJP,aLW,mY,aLW,mR,aLW,mH,aLW,mk,aLW,mZ,aLW,lG,aLW,nn,aLW,mv,aLW,ke,aLW,aJQ,aLW,kA,aLW,lp,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW,aLW];var fk=[aLX,aLX,hs,aLX,hx,aLX,iG,aLX,hy,aLX,hw,aLX,aLX,aLX,aLX,aLX];var fl=[aLY,aLY,kP,aLY,ip,aLY,k6,aLY,nr,aLY,md,aLY,mm,aLY,me,aLY,aJR,aLY,aIu,aLY,l$,aLY,nu,aLY,mq,aLY,g3,aLY,lZ,aLY,m3,aLY,mK,aLY,aJS,aLY,mG,aLY,aJT,aLY,mh,aLY,hO,aLY,k1,aLY,oa,aLY,aJU,aLY,kM,aLY,m9,aLY,aJV,aLY,kY,aLY,mE,aLY,aIg,aLY,iJ,aLY,hJ,aLY,je,aLY,mF,aLY,m_,aLY,nH,aLY,l6,aLY,nJ,aLY,mi,aLY,l_,aLY,jr,aLY,aJW,aLY,hK,aLY,ik,aLY,hD,aLY,kK,aLY,gr,aLY,lc,aLY,mJ,aLY,kJ,aLY,ha,aLY,hN,aLY,mT,aLY,lx,aLY,k_,aLY,k8,aLY,m4,aLY,ns,aLY,aJX,aLY,mV,aLY,ml,aLY,mp,aLY,m6,aLY,aJY,aLY,n9,aLY,kU,aLY,il,aLY,m8,aLY,kT,aLY,aJZ,aLY,nB,aLY,kX,aLY,nf,aLY,aIc,aLY,kZ,aLY,lY,aLY,aJ_,aLY,jq,aLY,la,aLY,nl,aLY,aIf,aLY,li,aLY,mD,aLY,l5,aLY,aJ$,aLY,aIp,aLY,aJ0,aLY,nK,aLY,nI,aLY,lg,aLY,jB,aLY,gU,aLY,aJ1,aLY,hz,aLY,gF,aLY,le,aLY,lj,aLY,hb,aLY,kL,aLY,aJ2,aLY,jK,aLY,jA,aLY,kQ,aLY,nv,aLY,k3,aLY,gt,aLY,lz,aLY,jv,aLY,iM,aLY,nb,aLY,iL,aLY,aJ3,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY,aLY];var fm=[aLZ,aLZ,jw,aLZ];var fn=[aL_,aL_,iX,aL_,iY,aL_,aJ4,aL_];var fo=[aL$,aL$,ir,aL$];var fp=[aL0,aL0,aJ5,aL0,jm,aL0,iF,aL0,aJ6,aL0,hH,aL0,ii,aL0,ij,aL0,aJ7,aL0,iN,aL0,aId,aL0,aJ8,aL0,aJ9,aL0,jg,aL0,gy,aL0,g6,aL0,aKa,aL0,hI,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0,aL0];var fq=[aL1,aL1,i0,aL1];var fr=[aL2,aL2,aLh,aL2,aLi,aL2,aLj,aL2];var fs=[aL3,aL3,aLo,aL3];var ft=[aL4,aL4,jj,aL4];var fu=[aL5,aL5,i9,aL5];var fv=[aL6,aL6,aLn,aL6];var fw=[aL7,aL7,ic,aL7];var fx=[aL8,aL8,aLk,aL8,aLl,aL8,aLm,aL8];var fy=[aL9,aL9,aKc,aL9];var fz=[aMa,aMa,aKd,aMa,aKe,aMa,h4,aMa,aKf,aMa,aMa,aMa,aMa,aMa,aMa,aMa];var fA=[aMb,aMb,aKg,aMb,gw,aMb,iU,aMb,aKh,aMb,f$,aMb,aKi,aMb,g8,aMb,go,aMb,gP,aMb,aIB,aMb,ht,aMb,aKj,aMb,aH9,aMb,aKk,aMb,hl,aMb,gv,aMb,gW,aMb,gT,aMb,f3,aMb,aIr,aMb,iT,aMb,ju,aMb,aH8,aMb,g9,aMb,aMb,aMb,aMb,aMb,aMb,aMb,aMb,aMb,aMb,aMb,aMb,aMb,aMb,aMb];var fB=[aMc,aMc,hT,aMc,hW,aMc,hU,aMc,hV,aMc,h2,aMc,hS,aMc,hY,aMc,h_,aMc,aKb,aMc,hX,aMc,h$,aMc,hZ,aMc,aMc,aMc,aMc,aMc,aMc,aMc];var fC=[aMd,aMd,aKl,aMd];var fD=[aMe,aMe,aIe,aMe,jL,aMe,jN,aMe,j$,aMe,lN,aMe,lI,aMe,n2,aMe,g5,aMe,lF,aMe,lL,aMe,n6,aMe,of,aMe,oc,aMe,od,aMe,aKm,aMe,lr,aMe,aKn,aMe,lm,aMe,lM,aMe,aHT,aMe,lV,aMe,lP,aMe,lU,aMe,aH_,aMe,g7,aMe,h7,aMe,gX,aMe,lv,aMe,lE,aMe,n5,aMe,gE,aMe,ji,aMe,lq,aMe,kB,aMe,ob,aMe,n3,aMe,j_,aMe,l4,aMe,l3,aMe,lB,aMe,jk,aMe,oe,aMe,n7,aMe,ln,aMe,hp,aMe,nQ,aMe,jt,aMe,lK,aMe,jy,aMe,ll,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe,aMe];var fE=[aMf,aMf,gm,aMf,aKo,aMf,aKp,aMf,i4,aMf,aMf,aMf,aMf,aMf,aMf,aMf];var fF=[aMg,aMg,aKq,aMg,aKr,aMg,aKs,aMg,aKt,aMg,aIb,aMg,aKu,aMg,aKv,aMg,gB,aMg,aKw,aMg,aKx,aMg,hd,aMg,aKy,aMg,id,aMg,aKz,aMg,hC,aMg,aKA,aMg,aKB,aMg,aKC,aMg,aKD,aMg,aKE,aMg,aKF,aMg,gS,aMg,h3,aMg,aKG,aMg,aKH,aMg,iW,aMg,aKI,aMg,aKJ,aMg,aKK,aMg,gH,aMg,aKL,aMg,ja,aMg,aKM,aMg,aKN,aMg,i1,aMg,aKO,aMg,aKP,aMg,aKQ,aMg,aIC,aMg,h0,aMg,aKR,aMg,aKS,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg,aMg];var fG=[aMh,aMh,aaz,aMh,aln,aMh,asj,aMh,auX,aMh,aoA,aMh,ak$,aMh,_s,aMh,akd,aMh,ajl,aMh,adn,aMh,Zw,aMh,xA,aMh,aay,aMh,xC,aMh,xD,aMh,xE,aMh,xF,aMh,xG,aMh,xH,aMh,aHC,aMh,I7,aMh,aA_,aMh,aoR,aMh,aF$,aMh,anZ,aMh,aat,aMh,UU,aMh,amI,aMh,aGD,aMh,av1,aMh,ayA,aMh,Pi,aMh,alA,aMh,Z6,aMh,Ot,aMh,Lk,aMh,act,aMh,awl,aMh,xL,aMh,xM,aMh,xN,aMh,xO,aMh,xP,aMh,az9,aMh,P7,aMh,alc,aMh,P6,aMh,S7,aMh,Qj,aMh,Kx,aMh,amm,aMh,xI,aMh,V3,aMh,V$,aMh,xJ,aMh,_b,aMh,X9,aMh,ato,aMh,au6,aMh,P4,aMh,akX,aMh,aHO,aMh,aGu,aMh,akp,aMh,Zd,aMh,ag6,aMh,aHl,aMh,V2,aMh,__,aMh,afF,aMh,acV,aMh,aqc,aMh,QO,aMh,axb,aMh,ahH,aMh,Qx,aMh,KK,aMh,RE,aMh,asW,aMh,aB5,aMh,PE,aMh,aAr,aMh,xB,aMh,aEZ,aMh,ZN,aMh,aGr,aMh,ahs,aMh,Ag,aMh,aj5,aMh,Ae,aMh,Af,aMh,Ac,aMh,Ad,aMh,aq2,aMh,Ab,aMh,ah6,aMh,VZ,aMh,Ds,aMh,Az,aMh,J2,aMh,RJ,aMh,wJ,aMh,IF,aMh,aEH,aMh,auO,aMh,aB$,aMh,Rm,aMh,api,aMh,IW,aMh,PK,aMh,aju,aMh,PL,aMh,anF,aMh,al0,aMh,anI,aMh,axc,aMh,PV,aMh,Kk,aMh,Z7,aMh,asF,aMh,avN,aMh,avx,aMh,ai0,aMh,ahu,aMh,auf,aMh,aB8,aMh,Rd,aMh,WH,aMh,ai$,aMh,Ph,aMh,Ia,aMh,aG3,aMh,P8,aMh,aub,aMh,Qg,aMh,z7,aMh,z8,aMh,z5,aMh,M4,aMh,Qf,aMh,z4,aMh,z1,aMh,z2,aMh,ald,aMh,at1,aMh,Jy,aMh,z9,aMh,ahD,aMh,azv,aMh,H1,aMh,IL,aMh,tc,aMh,tx,aMh,tI,aMh,JF,aMh,ar2,aMh,ty,aMh,afc,aMh,ag7,aMh,ae6,aMh,zs,aMh,zt,aMh,Ll,aMh,abT,aMh,oP,aMh,JG,aMh,abS,aMh,zn,aMh,zk,aMh,zl,aMh,zq,aMh,ad3,aMh,zo,aMh,zp,aMh,aaB,aMh,amP,aMh,amy,aMh,ajO,aMh,aeZ,aMh,ab3,aMh,ao6,aMh,aiY,aMh,acf,aMh,TQ,aMh,atf,aMh,Kg,aMh,aCc,aMh,VR,aMh,Nb,aMh,al5,aMh,ace,aMh,ai1,aMh,Lb,aMh,ao_,aMh,KZ,aMh,aqN,aMh,o5,aMh,o6,aMh,pl,aMh,azR,aMh,o7,aMh,aCF,aMh,$3,aMh,pa,aMh,aE9,aMh,zw,aMh,zu,aMh,zz,aMh,acx,aMh,zx,aMh,zy,aMh,Pc,aMh,aiP,aMh,OS,aMh,UM,aMh,acN,aMh,aad,aMh,ta,aMh,tq,aMh,tr,aMh,tu,aMh,tv,aMh,ts,aMh,tt,aMh,O5,aMh,R7,aMh,alR,aMh,WA,aMh,WC,aMh,aeu,aMh,sj,aMh,asO,aMh,aw8,aMh,afx,aMh,aGf,aMh,Uk,aMh,u2,aMh,av8,aMh,arP,aMh,ag_,aMh,ahK,aMh,apC,aMh,DU,aMh,aiz,aMh,IO,aMh,aeA,aMh,aep,aMh,aas,aMh,aps,aMh,aeq,aMh,afA,aMh,azP,aMh,afo,aMh,Iq,aMh,Ip,aMh,Io,aMh,adA,aMh,In,aMh,Im,aMh,ac6,aMh,Ik,aMh,Ij,aMh,Ii,aMh,Jm,aMh,ai5,aMh,Sn,aMh,alG,aMh,pI,aMh,ayE,aMh,anW,aMh,Jo,aMh,Kb,aMh,AK,aMh,_i,aMh,Sh,aMh,$c,aMh,aCe,aMh,Mj,aMh,Qb,aMh,ag4,aMh,IB,aMh,_c,aMh,ap6,aMh,awc,aMh,M_,aMh,aaS,aMh,Xy,aMh,atu,aMh,aFS,aMh,aGb,aMh,aaR,aMh,On,aMh,azF,aMh,aeF,aMh,auV,aMh,aHJ,aMh,aug,aMh,aeG,aMh,_1,aMh,LR,aMh,aeE,aMh,KS,aMh,arv,aMh,aj6,aMh,sd,aMh,aBe,aMh,S6,aMh,aaO,aMh,atm,aMh,Px,aMh,aaG,aMh,Pm,aMh,x$,aMh,OA,aMh,wX,aMh,Pn,aMh,YQ,aMh,x1,aMh,$I,aMh,aFc,aMh,Re,aMh,aAX,aMh,avf,aMh,w0,aMh,ayu,aMh,$z,aMh,aCu,aMh,auC,aMh,U$,aMh,abp,aMh,ajn,aMh,asw,aMh,Mo,aMh,aiM,aMh,aGE,aMh,az0,aMh,az_,aMh,aFK,aMh,MY,aMh,aB2,aMh,ad4,aMh,Xx,aMh,M8,aMh,aij,aMh,arJ,aMh,Xu,aMh,Pd,aMh,Yh,aMh,aAb,aMh,M7,aMh,L0,aMh,auT,aMh,xY,aMh,ajZ,aMh,agd,aMh,aCy,aMh,xS,aMh,xR,aMh,aCh,aMh,xX,aMh,axi,aMh,aDt,aMh,xU,aMh,aif,aMh,ap5,aMh,aAD,aMh,abA,aMh,$y,aMh,aqG,aMh,abM,aMh,aG0,aMh,amJ,aMh,Ce,aMh,UD,aMh,aGZ,aMh,awb,aMh,aHy,aMh,anp,aMh,aCP,aMh,ajs,aMh,ab_,aMh,aBh,aMh,ZD,aMh,aHD,aMh,RT,aMh,_C,aMh,Tn,aMh,abb,aMh,akb,aMh,Yu,aMh,asb,aMh,am7,aMh,$Q,aMh,ss,aMh,aIj,aMh,ax_,aMh,aEN,aMh,_S,aMh,ask,aMh,auw,aMh,aDb,aMh,sf,aMh,aw7,aMh,aj4,aMh,ash,aMh,acy,aMh,avJ,aMh,aoo,aMh,aeb,aMh,Nt,aMh,aFp,aMh,aEI,aMh,aoW,aMh,Ly,aMh,px,aMh,aGS,aMh,afG,aMh,apF,aMh,Vo,aMh,aqH,aMh,ah$,aMh,aip,aMh,D_,aMh,Vn,aMh,aho,aMh,aqh,aMh,aeQ,aMh,UI,aMh,att,aMh,UT,aMh,Mc,aMh,aeB,aMh,axf,aMh,aeC,aMh,aHa,aMh,al7,aMh,ayb,aMh,awe,aMh,Qr,aMh,Sb,aMh,Qa,aMh,EA,aMh,Lo,aMh,hc,aMh,Tb,aMh,as7,aMh,P9,aMh,ao2,aMh,aga,aMh,KY,aMh,aA1,aMh,apq,aMh,AT,aMh,AV,aMh,zK,aMh,asu,aMh,zL,aMh,asx,aMh,yL,aMh,S1,aMh,KW,aMh,LG,aMh,akg,aMh,afY,aMh,Jx,aMh,Lm,aMh,aDP,aMh,PM,aMh,aaP,aMh,Xs,aMh,aw6,aMh,abJ,aMh,Jz,aMh,abR,aMh,auy,aMh,zS,aMh,aDy,aMh,avS,aMh,zT,aMh,aqs,aMh,abQ,aMh,zQ,aMh,zP,aMh,axM,aMh,zW,aMh,zV,aMh,DH,aMh,aq_,aMh,amj,aMh,LH,aMh,zJ,aMh,zI,aMh,VF,aMh,zF,aMh,zE,aMh,zH,aMh,zG,aMh,zB,aMh,zD,aMh,zC,aMh,z$,aMh,arR,aMh,z0,aMh,U2,aMh,$K,aMh,zY,aMh,$F,aMh,acC,aMh,az$,aMh,alJ,aMh,aeS,aMh,Y9,aMh,Qy,aMh,aEJ,aMh,gc,aMh,JN,aMh,aFl,aMh,agC,aMh,aAZ,aMh,ajU,aMh,aqP,aMh,awJ,aMh,aaX,aMh,Qk,aMh,Yc,aMh,qg,aMh,qw,aMh,pp,aMh,po,aMh,apI,aMh,pn,aMh,H$,aMh,tg,aMh,tC,aMh,ax6,aMh,MU,aMh,ahj,aMh,amd,aMh,tA,aMh,te,aMh,tJ,aMh,tL,aMh,Yb,aMh,tf,aMh,tM,aMh,amu,aMh,aoX,aMh,WG,aMh,aDj,aMh,NM,aMh,ayt,aMh,avb,aMh,gn,aMh,sq,aMh,ay7,aMh,avj,aMh,apR,aMh,tN,aMh,tD,aMh,Kq,aMh,tF,aMh,PC,aMh,J9,aMh,ti,aMh,Ke,aMh,GN,aMh,GO,aMh,arT,aMh,WR,aMh,Rh,aMh,GI,aMh,qe,aMh,qj,aMh,qi,aMh,MJ,aMh,qd,aMh,qx,aMh,GL,aMh,ID,aMh,_D,aMh,R8,aMh,arf,aMh,avY,aMh,asc,aMh,aaW,aMh,aiu,aMh,RP,aMh,aGJ,aMh,aHr,aMh,aaV,aMh,akH,aMh,axT,aMh,f5,aMh,aqE,aMh,akY,aMh,ayx,aMh,adg,aMh,atR,aMh,arq,aMh,ahJ,aMh,aAs,aMh,St,aMh,_W,aMh,alb,aMh,Jh,aMh,adh,aMh,_n,aMh,apL,aMh,_6,aMh,alO,aMh,Sp,aMh,alz,aMh,Em,aMh,El,aMh,Ek,aMh,Eq,aMh,Ep,aMh,Eo,aMh,En,aMh,aHN,aMh,Es,aMh,aAN,aMh,Q$,aMh,arS,aMh,Kt,aMh,aIm,aMh,avv,aMh,Yw,aMh,apX,aMh,alv,aMh,aA$,aMh,avg,aMh,iQ,aMh,anY,aMh,Ht,aMh,aqX,aMh,Yn,aMh,aDg,aMh,Uz,aMh,aqi,aMh,ann,aMh,Z1,aMh,aDi,aMh,Ev,aMh,Et,aMh,aHt,aMh,Ey,aMh,amZ,aMh,Ew,aMh,awO,aMh,OU,aMh,ayO,aMh,asr,aMh,avB,aMh,aqW,aMh,acO,aMh,PP,aMh,alr,aMh,ax4,aMh,aDX,aMh,aCN,aMh,aiC,aMh,Ki,aMh,$A,aMh,aC5,aMh,art,aMh,IM,aMh,awh,aMh,yd,aMh,Np,aMh,yb,aMh,aw3,aMh,aeI,aMh,Nx,aMh,x4,aMh,Y$,aMh,ajM,aMh,azb,aMh,aGT,aMh,aqM,aMh,aio,aMh,ang,aMh,ar_,aMh,adf,aMh,Yl,aMh,aot,aMh,Z2,aMh,yj,aMh,aEt,aMh,aAm,aMh,yi,aMh,yf,aMh,yg,aMh,aAC,aMh,am$,aMh,yE,aMh,akc,aMh,amB,aMh,Zp,aMh,axH,aMh,adb,aMh,SL,aMh,EJ,aMh,T1,aMh,aCE,aMh,aqm,aMh,auW,aMh,yB,aMh,aBb,aMh,SH,aMh,asB,aMh,auU,aMh,wS,aMh,EM,aMh,aCD,aMh,akq,aMh,GT,aMh,SJ,aMh,ap8,aMh,Tr,aMh,as8,aMh,alV,aMh,adN,aMh,ads,aMh,afC,aMh,adI,aMh,adO,aMh,MQ,aMh,ao0,aMh,av3,aMh,awQ,aMh,AH,aMh,AI,aMh,akP,aMh,aaC,aMh,AL,aMh,AM,aMh,ays,aMh,Ok,aMh,ay2,aMh,aA6,aMh,aEW,aMh,QU,aMh,Ol,aMh,Z3,aMh,aDK,aMh,Q_,aMh,_7,aMh,alI,aMh,aCX,aMh,UX,aMh,atj,aMh,aEP,aMh,Xf,aMh,agS,aMh,add,aMh,atH,aMh,agM,aMh,apE,aMh,ZR,aMh,YF,aMh,abC,aMh,al8,aMh,axA,aMh,azp,aMh,ZF,aMh,au2,aMh,RK,aMh,ao5,aMh,ak7,aMh,aqY,aMh,Ax,aMh,S8,aMh,axj,aMh,AA,aMh,XX,aMh,AD,aMh,AE,aMh,aol,aMh,AG,aMh,axG,aMh,V_,aMh,au7,aMh,arA,aMh,agT,aMh,ajk,aMh,aCs,aMh,rb,aMh,auH,aMh,sy,aMh,afv,aMh,am0,aMh,sS,aMh,azE,aMh,sw,aMh,pF,aMh,pG,aMh,pE,aMh,aj3,aMh,SS,aMh,pH,aMh,qz,aMh,Co,aMh,aGm,aMh,Vt,aMh,akr,aMh,Lz,aMh,K4,aMh,aCm,aMh,as$,aMh,atk,aMh,as2,aMh,asA,aMh,anV,aMh,z6,aMh,YR,aMh,asa,aMh,aDo,aMh,aAn,aMh,Ls,aMh,LA,aMh,Rz,aMh,CJ,aMh,st,aMh,su,aMh,sv,aMh,sg,aMh,sa,aMh,aqB,aMh,apY,aMh,aCf,aMh,py,aMh,pz,aMh,pq,aMh,aE4,aMh,qy,aMh,ad6,aMh,pA,aMh,pB,aMh,ale,aMh,JD,aMh,We,aMh,_N,aMh,Qe,aMh,_T,aMh,Qd,aMh,aA9,aMh,avq,aMh,IT,aMh,YN,aMh,YP,aMh,als,aMh,ahT,aMh,av_,aMh,axo,aMh,apD,aMh,Ri,aMh,aqg,aMh,axD,aMh,alL,aMh,XY,aMh,f6,aMh,acn,aMh,sR,aMh,avz,aMh,alF,aMh,D$,aMh,ahU,aMh,apo,aMh,sx,aMh,akC,aMh,aco,aMh,aBd,aMh,ach,aMh,apJ,aMh,W6,aMh,ah9,aMh,auM,aMh,aaA,aMh,aal,aMh,asm,aMh,BK,aMh,WS,aMh,aam,aMh,ajt,aMh,asU,aMh,akA,aMh,acu,aMh,SY,aMh,acH,aMh,adS,aMh,J4,aMh,apt,aMh,axR,aMh,ahw,aMh,akL,aMh,Mv,aMh,ajP,aMh,td,aMh,I4,aMh,vo,aMh,abY,aMh,aDc,aMh,avG,aMh,WZ,aMh,ME,aMh,aEA,aMh,Mw,aMh,aGN,aMh,afl,aMh,aog,aMh,aAl,aMh,pm,aMh,Jw,aMh,XH,aMh,MW,aMh,pc,aMh,aki,aMh,Jv,aMh,afd,aMh,azs,aMh,asd,aMh,yu,aMh,yw,aMh,yv,aMh,yy,aMh,yx,aMh,Q0,aMh,yz,aMh,Z0,aMh,XP,aMh,yK,aMh,aAM,aMh,zm,aMh,axd,aMh,aj7,aMh,ati,aMh,ZO,aMh,aEu,aMh,aw$,aMh,arM,aMh,aa6,aMh,asS,aMh,ahZ,aMh,vk,aMh,acX,aMh,alN,aMh,aea,aMh,OC,aMh,aBN,aMh,Oy,aMh,adD,aMh,aul,aMh,aCH,aMh,adF,aMh,ab2,aMh,atp,aMh,ah7,aMh,aiF,aMh,si,aMh,arZ,aMh,avs,aMh,aj$,aMh,La,aMh,ab0,aMh,aeY,aMh,aoC,aMh,yk,aMh,yn,aMh,Yi,aMh,aDM,aMh,aCv,aMh,yr,aMh,yq,aMh,yt,aMh,ys,aMh,arH,aMh,apw,aMh,ajI,aMh,ayB,aMh,O7,aMh,YX,aMh,Wy,aMh,aAw,aMh,apH,aMh,ZA,aMh,aG4,aMh,u6,aMh,Lr,aMh,az2,aMh,alT,aMh,Py,aMh,agm,aMh,Zz,aMh,Pz,aMh,aqt,aMh,PJ,aMh,aGd,aMh,VE,aMh,an6,aMh,aFU,aMh,aj2,aMh,VI,aMh,u5,aMh,VP,aMh,azf,aMh,Tk,aMh,Td,aMh,OY,aMh,Tl,aMh,aEQ,aMh,at8,aMh,atB,aMh,adJ,aMh,Ql,aMh,$6,aMh,aFi,aMh,ayK,aMh,$U,aMh,aDk,aMh,Qm,aMh,R1,aMh,$T,aMh,apB,aMh,M5,aMh,arK,aMh,$b,aMh,aqx,aMh,aF3,aMh,awk,aMh,Og,aMh,aoy,aMh,QW,aMh,Oe,aMh,SG,aMh,$S,aMh,adC,aMh,_2,aMh,atP,aMh,ajr,aMh,abl,aMh,agO,aMh,Nn,aMh,agN,aMh,abn,aMh,aGP,aMh,anK,aMh,T0,aMh,tO,aMh,avX,aMh,akM,aMh,VU,aMh,Oc,aMh,X$,aMh,alZ,aMh,r0,aMh,Jg,aMh,aDm,aMh,aqZ,aMh,aui,aMh,Kr,aMh,RO,aMh,Mz,aMh,Q5,aMh,aHn,aMh,r_,aMh,am3,aMh,at$,aMh,afw,aMh,u9,aMh,$_,aMh,adl,aMh,adk,aMh,aFD,aMh,JA,aMh,Nu,aMh,Wx,aMh,aox,aMh,aDr,aMh,aae,aMh,an8,aMh,U5,aMh,JJ,aMh,aFd,aMh,LS,aMh,atv,aMh,aD9,aMh,o8,aMh,ak3,aMh,azu,aMh,ag5,aMh,ahO,aMh,o9,aMh,ahf,aMh,YZ,aMh,Li,aMh,aFH,aMh,ayR,aMh,Lq,aMh,zv,aMh,arj,aMh,aEo,aMh,afe,aMh,Aq,aMh,oN,aMh,atW,aMh,An,aMh,ah8,aMh,Al,aMh,ahe,aMh,Aj,aMh,aqz,aMh,Ah,aMh,QJ,aMh,K_,aMh,awr,aMh,ap9,aMh,ap4,aMh,aAi,aMh,K$,aMh,ax0,aMh,amO,aMh,aiD,aMh,_K,aMh,MM,aMh,ajh,aMh,Mx,aMh,axZ,aMh,IY,aMh,Pr,aMh,Aw,aMh,Av,aMh,Au,aMh,At,aMh,azY,aMh,Ar,aMh,aEq,aMh,asN,aMh,acB,aMh,IR,aMh,ML,aMh,aAO,aMh,IZ,aMh,auN,aMh,pQ,aMh,pP,aMh,sA,aMh,arF,aMh,s6,aMh,MA,aMh,tk,aMh,tj,aMh,pK,aMh,pJ,aMh,s7,aMh,ps,aMh,aur,aMh,pM,aMh,pO,aMh,qA,aMh,Hi,aMh,tH,aMh,Hj,aMh,apS,aMh,arC,aMh,Hf,aMh,Hg,aMh,Hh,aMh,N4,aMh,aj8,aMh,asg,aMh,YI,aMh,amg,aMh,aeD,aMh,aDn,aMh,arQ,aMh,apT,aMh,aD_,aMh,alM,aMh,aqI,aMh,g2,aMh,ai6,aMh,adY,aMh,VG,aMh,ad2,aMh,Ha,aMh,Hb,aMh,H2,aMh,Hc,aMh,G6,aMh,G7,aMh,G8,aMh,G9,aMh,NL,aMh,J8,aMh,Ww,aMh,auc,aMh,He,aMh,tn,aMh,s8,aMh,aE8,aMh,BV,aMh,aj0,aMh,s9,aMh,tp,aMh,aoV,aMh,pR,aMh,pS,aMh,ZU,aMh,qB,aMh,al_,aMh,aC4,aMh,aAh,aMh,ab8,aMh,R$,aMh,amW,aMh,aHQ,aMh,Oz,aMh,abF,aMh,arE,aMh,Z$,aMh,LC,aMh,MF,aMh,Yv,aMh,I0,aMh,MG,aMh,VW,aMh,LF,aMh,au4,aMh,anO,aMh,aF1,aMh,Mi,aMh,Q4,aMh,Ra,aMh,azJ,aMh,gL,aMh,amS,aMh,MN,aMh,Q9,aMh,atc,aMh,auQ,aMh,aHG,aMh,axu,aMh,aC1,aMh,aqv,aMh,Ni,aMh,T9,aMh,azZ,aMh,aDU,aMh,RM,aMh,aak,aMh,auI,aMh,ZL,aMh,K2,aMh,ar5,aMh,iP,aMh,aqr,aMh,$8,aMh,aAa,aMh,alx,aMh,IN,aMh,am8,aMh,agr,aMh,RY,aMh,aD$,aMh,R6,aMh,axC,aMh,L7,aMh,XC,aMh,aCW,aMh,Zo,aMh,abH,aMh,Zg,aMh,axY,aMh,aFk,aMh,yl,aMh,arU,aMh,Ub,aMh,ajB,aMh,atK,aMh,auZ,aMh,any,aMh,apK,aMh,ay$,aMh,aFV,aMh,aCR,aMh,Vz,aMh,aEd,aMh,yp,aMh,Zt,aMh,Pk,aMh,yo,aMh,aiv,aMh,ahI,aMh,aDv,aMh,UL,aMh,akh,aMh,UG,aMh,axz,aMh,LQ,aMh,wE,aMh,wF,aMh,UK,aMh,aA8,aMh,aka,aMh,wB,aMh,wC,aMh,ac4,aMh,aw5,aMh,amt,aMh,ac3,aMh,wI,aMh,aof,aMh,as6,aMh,Tg,aMh,aE_,aMh,avl,aMh,Vj,aMh,OX,aMh,aHf,aMh,acv,aMh,aq3,aMh,aa9,aMh,Te,aMh,TF,aMh,aG1,aMh,Sr,aMh,OW,aMh,awE,aMh,awY,aMh,ayG,aMh,QT,aMh,Me,aMh,TE,aMh,amc,aMh,QS,aMh,wN,aMh,wO,aMh,wP,aMh,wK,aMh,wL,aMh,wM,aMh,P$,aMh,GP,aMh,ara,aMh,aDq,aMh,Xp,aMh,aEp,aMh,Tf,aMh,ae1,aMh,aby,aMh,anA,aMh,U8,aMh,ayP,aMh,Mr,aMh,aDB,aMh,aFA,aMh,aDY,aMh,aoG,aMh,JU,aMh,ak6,aMh,Mm,aMh,aFL,aMh,U3,aMh,aks,aMh,auS,aMh,al3,aMh,PU,aMh,azB,aMh,aq1,aMh,aFQ,aMh,aDS,aMh,aiy,aMh,as1,aMh,aed,aMh,av4,aMh,auY,aMh,IA,aMh,aEk,aMh,aiT,aMh,aFE,aMh,aEO,aMh,R9,aMh,acS,aMh,ame,aMh,acM,aMh,aik,aMh,ahy,aMh,aEb,aMh,arD,aMh,Cl,aMh,ar0,aMh,JQ,aMh,Cz,aMh,ac$,aMh,js,aMh,ay4,aMh,aDV,aMh,aB4,aMh,aes,aMh,JP,aMh,My,aMh,_P,aMh,aFC,aMh,_M,aMh,MO,aMh,al$,aMh,axU,aMh,Ob,aMh,aoI,aMh,KR,aMh,Jq,aMh,aGs,aMh,ant,aMh,arr,aMh,Mg,aMh,aGy,aMh,aCq,aMh,_Q,aMh,arO,aMh,Mh,aMh,aAd,aMh,ZP,aMh,Ku,aMh,aaM,aMh,auj,aMh,$0,aMh,aaF,aMh,Cx,aMh,$L,aMh,ae0,aMh,avC,aMh,aaN,aMh,Cd,aMh,adq,aMh,Cs,aMh,NR,aMh,OB,aMh,Ck,aMh,Cj,aMh,Cv,aMh,MP,aMh,asp,aMh,_q,aMh,adv,aMh,ak4,aMh,VS,aMh,RX,aMh,VC,aMh,aHe,aMh,avI,aMh,N$,aMh,arw,aMh,aDO,aMh,rz,aMh,re,aMh,qN,aMh,aem,aMh,ahX,aMh,rc,aMh,agv,aMh,asi,aMh,amh,aMh,acQ,aMh,arG,aMh,To,aMh,azT,aMh,aqq,aMh,Tq,aMh,ajc,aMh,S_,aMh,anJ,aMh,apc,aMh,aF_,aMh,aB1,aMh,ad_,aMh,adZ,aMh,axQ,aMh,asQ,aMh,ail,aMh,alP,aMh,aq4,aMh,Su,aMh,Pj,aMh,akx,aMh,agJ,aMh,Zb,aMh,aCb,aMh,ath,aMh,aiI,aMh,aGv,aMh,awu,aMh,amz,aMh,ajA,aMh,TB,aMh,aDI,aMh,ai8,aMh,ajC,aMh,Ue,aMh,Ka,aMh,q7,aMh,q6,aMh,q8,aMh,ry,aMh,q3,aMh,Zi,aMh,q5,aMh,q4,aMh,TC,aMh,afO,aMh,ra,aMh,Tv,aMh,aws,aMh,aav,aMh,GX,aMh,GW,aMh,agU,aMh,GU,aMh,G_,aMh,JS,aMh,GZ,aMh,aAU,aMh,Mn,aMh,G$,aMh,agV,aMh,GC,aMh,GD,aMh,akZ,aMh,GF,aMh,GE,aMh,HZ,aMh,YH,aMh,aHm,aMh,aow,aMh,ahC,aMh,apM,aMh,at6,aMh,aAv,aMh,awd,aMh,anl,aMh,pu,aMh,pZ,aMh,qC,aMh,p_,aMh,pV,aMh,OR,aMh,pX,aMh,pY,aMh,_w,aMh,alH,aMh,p$,aMh,p0,aMh,amo,aMh,Gu,aMh,Gv,aMh,Gs,aMh,Iu,aMh,HY,aMh,Gy,aMh,Gw,aMh,Gx,aMh,It,aMh,Gz,aMh,GA,aMh,aaD,aMh,aiH,aMh,Is,aMh,G3,aMh,G2,aMh,G1,aMh,Ir,aMh,ats,aMh,G4,aMh,aw1,aMh,aF0,aMh,pv,aMh,qD,aMh,p4,aMh,p1,aMh,p2,aMh,p3,aMh,aFR,aMh,ag3,aMh,agA,aMh,aGn,aMh,NH,aMh,akf,aMh,aCo,aMh,agz,aMh,w3,aMh,w2,aMh,w1,aMh,ZJ,aMh,$q,aMh,Rf,aMh,s1,aMh,$r,aMh,aaI,aMh,Rp,aMh,adK,aMh,aFf,aMh,ap_,aMh,aD0,aMh,ark,aMh,T8,aMh,Nh,aMh,ax3,aMh,aja,aMh,WY,aMh,ajE,aMh,Ns,aMh,Na,aMh,afP,aMh,Nq,aMh,op,aMh,aj1,aMh,Wl,aMh,avR,aMh,au0,aMh,atQ,aMh,ajv,aMh,afq,aMh,Vy,aMh,_O,aMh,L5,aMh,L4,aMh,TW,aMh,aFw,aMh,$a,aMh,TD,aMh,TV,aMh,abK,aMh,wV,aMh,wU,aMh,wT,aMh,awR,aMh,wR,aMh,XD,aMh,wZ,aMh,wY,aMh,oG,aMh,aom,aMh,ajo,aMh,aym,aMh,aFz,aMh,aba,aMh,aBk,aMh,asR,aMh,acm,aMh,adz,aMh,aCt,aMh,Ro,aMh,B1,aMh,adP,aMh,asy,aMh,apr,aMh,tb,aMh,avc,aMh,azj,aMh,L6,aMh,X8,aMh,Xe,aMh,Y_,aMh,aHS,aMh,Tp,aMh,Rg,aMh,azg,aMh,ap0,aMh,aji,aMh,Jc,aMh,awD,aMh,Rl,aMh,avD,aMh,Je,aMh,tP,aMh,QV,aMh,UW,aMh,Zu,aMh,azn,aMh,awA,aMh,Y5,aMh,aq7,aMh,ah2,aMh,XL,aMh,XN,aMh,P0,aMh,aG5,aMh,ab5,aMh,ar1,aMh,$n,aMh,aFT,aMh,DR,aMh,Kd,aMh,agg,aMh,axh,aMh,KT,aMh,aCk,aMh,aBL,aMh,avh,aMh,$o,aMh,aEE,aMh,$g,aMh,az8,aMh,am5,aMh,ada,aMh,VM,aMh,azz,aMh,au$,aMh,KD,aMh,_X,aMh,aut,aMh,Yg,aMh,RG,aMh,alU,aMh,abc,aMh,RF,aMh,Lj,aMh,JE,aMh,Ye,aMh,Za,aMh,aiW,aMh,alf,aMh,aFY,aMh,aD7,aMh,aE6,aMh,Y8,aMh,alp,aMh,Wu,aMh,OT,aMh,aiq,aMh,aib,aMh,Km,aMh,aF9,aMh,ago,aMh,aer,aMh,gM,aMh,aex,aMh,awn,aMh,X2,aMh,KL,aMh,BL,aMh,X3,aMh,Th,aMh,Kn,aMh,BH,aMh,BG,aMh,BI,aMh,AP,aMh,BJ,aMh,AR,aMh,AO,aMh,AN,aMh,abf,aMh,Tu,aMh,S9,aMh,aAF,aMh,aAY,aMh,Lt,aMh,aoK,aMh,ahV,aMh,asv,aMh,x3,aMh,aum,aMh,apP,aMh,WO,aMh,Tt,aMh,alj,aMh,WP,aMh,ar9,aMh,akW,aMh,aCB,aMh,NW,aMh,ayI,aMh,aoB,aMh,aG7,aMh,afW,aMh,apn,aMh,akT,aMh,AS,aMh,BM,aMh,BN,aMh,Oi,aMh,ad8,aMh,Nz,aMh,NX,aMh,Lw,aMh,aww,aMh,NP,aMh,Xn,aMh,aDh,aMh,adV,aMh,jd,aMh,aEf,aMh,K6,aMh,Mu,aMh,W8,aMh,oT,aMh,alB,aMh,abD,aMh,abE,aMh,Om,aMh,acj,aMh,p7,aMh,afk,aMh,pw,aMh,qL,aMh,ZV,aMh,aCx,aMh,WF,aMh,rf,aMh,rg,aMh,rh,aMh,ri,aMh,rj,aMh,rk,aMh,rA,aMh,rl,aMh,rm,aMh,rn,aMh,atT,aMh,amq,aMh,aiX,aMh,aDd,aMh,ayL,aMh,KO,aMh,ajG,aMh,YC,aMh,atw,aMh,YA,aMh,aHP,aMh,Jb,aMh,amG,aMh,aGO,aMh,Uc,aMh,abd,aMh,apj,aMh,aBB,aMh,ayd,aMh,Fx,aMh,T3,aMh,aeN,aMh,rp,aMh,rq,aMh,rr,aMh,rB,aMh,rs,aMh,ahq,aMh,LL,aMh,Jj,aMh,LV,aMh,K0,aMh,ay1,aMh,qG,aMh,aFN,aMh,qE,aMh,qK,aMh,Vv,aMh,qJ,aMh,LU,aMh,ak1,aMh,p6,aMh,p5,aMh,aG9,aMh,atO,aMh,auD,aMh,avA,aMh,Ge,aMh,Gh,aMh,Gg,aMh,Gj,aMh,Gi,aMh,aor,aMh,HW,aMh,Gm,aMh,Yp,aMh,aBU,aMh,Yd,aMh,arh,aMh,TJ,aMh,aGK,aMh,ade,aMh,Yo,aMh,L$,aMh,axP,aMh,NT,aMh,azA,aMh,acJ,aMh,se,aMh,Ow,aMh,azh,aMh,ah5,aMh,azK,aMh,alE,aMh,Kw,aMh,aBF,aMh,Z4,aMh,Eb,aMh,IK,aMh,aGc,aMh,wz,aMh,aDT,aMh,wy,aMh,wr,aMh,wm,aMh,asV,aMh,wq,aMh,ab9,aMh,sh,aMh,VJ,aMh,aru,aMh,ao8,aMh,acR,aMh,auz,aMh,xo,aMh,VB,aMh,anv,aMh,aFs,aMh,acT,aMh,Gn,aMh,Gp,aMh,Go,aMh,HX,aMh,Gq,aMh,Gr,aMh,ayM,aMh,aBg,aMh,akt,aMh,LN,aMh,wv,aMh,aye,aMh,wu,aMh,wo,aMh,wl,aMh,atb,aMh,ws,aMh,anq,aMh,aF5,aMh,auG,aMh,SR,aMh,Zk,aMh,ww,aMh,wn,aMh,aoM,aMh,aHx,aMh,hf,aMh,axX,aMh,aCY,aMh,ahE,aMh,O0,aMh,aHq,aMh,YS,aMh,afL,aMh,afN,aMh,anQ,aMh,aFo,aMh,xc,aMh,aCd,aMh,OM,aMh,aBa,aMh,w6,aMh,aGi,aMh,w4,aMh,JL,aMh,NQ,aMh,aix,aMh,ahb,aMh,w9,aMh,$H,aMh,ahM,aMh,ais,aMh,ay9,aMh,atI,aMh,ane,aMh,ave,aMh,Ul,aMh,qH,aMh,Pe,aMh,aB9,aMh,ajT,aMh,aFF,aMh,qF,aMh,amv,aMh,ac_,aMh,aC0,aMh,aiS,aMh,L8,aMh,azl,aMh,CY,aMh,Ma,aMh,afp,aMh,Um,aMh,Rx,aMh,Ug,aMh,aEB,aMh,XS,aMh,av$,aMh,WB,aMh,aAR,aMh,alk,aMh,qI,aMh,apl,aMh,arB,aMh,Wp,aMh,xg,aMh,XR,aMh,MS,aMh,xj,aMh,anU,aMh,xh,aMh,asG,aMh,aGg,aMh,abs,aMh,ami,aMh,awM,aMh,abk,aMh,Js,aMh,arL,aMh,apa,aMh,xZ,aMh,aFu,aMh,ax7,aMh,azL,aMh,atg,aMh,abr,aMh,aAK,aMh,ado,aMh,LB,aMh,Zs,aMh,Ze,aMh,aqp,aMh,LK,aMh,Ve,aMh,ak5,aMh,aax,aMh,Sj,aMh,xT,aMh,Ty,aMh,Va,aMh,Y7,aMh,LJ,aMh,E0,aMh,MC,aMh,ap$,aMh,JI,aMh,xQ,aMh,Ys,aMh,Gk,aMh,al1,aMh,Fu,aMh,xW,aMh,CR,aMh,BU,aMh,awS,aMh,xV,aMh,CQ,aMh,Cq,aMh,$4,aMh,A4,aMh,aA2,aMh,Pg,aMh,avH,aMh,aoq,aMh,arx,aMh,Ti,aMh,Ap,aMh,aml,aMh,Ym,aMh,Ao,aMh,Oh,aMh,aDe,aMh,KC,aMh,Am,aMh,agc,aMh,agq,aMh,Cp,aMh,aEL,aMh,BS,aMh,BT,aMh,CK,aMh,CL,aMh,Ch,aMh,CM,aMh,Ak,aMh,aIa,aMh,CO,aMh,CP,aMh,V1,aMh,u4,aMh,Ai,aMh,ak_,aMh,ahA,aMh,aqf,aMh,$X,aMh,aqb,aMh,aie,aMh,vA,aMh,atd,aMh,axt,aMh,PF,aMh,aoj,aMh,amY,aMh,$5,aMh,aiG,aMh,SO,aMh,awB,aMh,Cf,aMh,aou,aMh,$j,aMh,PG,aMh,PA,aMh,ZG,aMh,aiQ,aMh,alY,aMh,Nr,aMh,abI,aMh,anu,aMh,O$,aMh,ac0,aMh,rH,aMh,rU,aMh,rT,aMh,rS,aMh,rG,aMh,O9,aMh,N1,aMh,atE,aMh,amr,aMh,alt,aMh,N3,aMh,Qo,aMh,O4,aMh,apZ,aMh,aGG,aMh,asl,aMh,yP,aMh,aFv,aMh,ayW,aMh,S2,aMh,ajF,aMh,ahQ,aMh,ake,aMh,ay8,aMh,azc,aMh,am6,aMh,aEj,aMh,abP,aMh,Bd,aMh,aos,aMh,aHv,aMh,arg,aMh,af4,aMh,_o,aMh,aeP,aMh,Zr,aMh,aBT,aMh,anm,aMh,rP,aMh,rF,aMh,rO,aMh,aH2,aMh,ru,aMh,rt,aMh,rD,aMh,avZ,aMh,aBz,aMh,aC9,aMh,L1,aMh,awa,aMh,ai4,aMh,aqe,aMh,aAx,aMh,aq$,aMh,aeJ,aMh,aBJ,aMh,abe,aMh,LW,aMh,aqj,aMh,L2,aMh,VT,aMh,Wg,aMh,aFx,aMh,afM,aMh,afK,aMh,KG,aMh,arY,aMh,aih,aMh,anj,aMh,azt,aMh,awI,aMh,qs,aMh,qM,aMh,qq,aMh,V7,aMh,arV,aMh,qm,aMh,qn,aMh,qk,aMh,PQ,aMh,SD,aMh,aEK,aMh,ai9,aMh,Zc,aMh,Sz,aMh,aDL,aMh,aBQ,aMh,aac,aMh,SW,aMh,vT,aMh,acI,aMh,aAQ,aMh,aBt,aMh,Sx,aMh,aoE,aMh,asH,aMh,Sy,aMh,ayH,aMh,acL,aMh,ajQ,aMh,yM,aMh,acF,aMh,axv,aMh,aiL,aMh,axe,aMh,qO,aMh,rv,aMh,Zj,aMh,qv,aMh,R5,aMh,apA,aMh,af$,aMh,af6,aMh,ad$,aMh,aHc,aMh,IU,aMh,MI,aMh,XT,aMh,JT,aMh,H5,aMh,amw,aMh,J$,aMh,ve,aMh,ahG,aMh,As,aMh,avO,aMh,Wf,aMh,aiR,aMh,aDN,aMh,xz,aMh,Kv,aMh,_L,aMh,J_,aMh,xv,aMh,ac8,aMh,WN,aMh,aD5,aMh,Wr,aMh,vB,aMh,aob,aMh,W4,aMh,afy,aMh,aAy,aMh,FY,aMh,FX,aMh,Rt,aMh,FV,aMh,FW,aMh,Mp,aMh,aDp,aMh,aw0,aMh,arl,aMh,WM,aMh,ac7,aMh,afH,aMh,Ru,aMh,Sq,aMh,Ml,aMh,Sw,aMh,xs,aMh,azw,aMh,auK,aMh,xp,aMh,apx,aMh,xr,aMh,aBM,aMh,xl,aMh,xk,aMh,xn,aMh,xm,aMh,aef,aMh,Mk,aMh,avo,aMh,ahx,aMh,aw4,aMh,Sv,aMh,Gb,aMh,FR,aMh,FP,aMh,FQ,aMh,aBR,aMh,P5,aMh,FL,aMh,aB_,aMh,PW,aMh,XZ,aMh,S3,aMh,PX,aMh,avP,aMh,FT,aMh,ag2,aMh,Uy,aMh,aBw,aMh,anx,aMh,UE,aMh,Fk,aMh,Sa,aMh,Tw,aMh,aCl,aMh,sT,aMh,aEl,aMh,aky,aMh,QN,aMh,Zm,aMh,Tx,aMh,Dt,aMh,Ee,aMh,aiO,aMh,QI,aMh,QD,aMh,ZM,aMh,aAk,aMh,alS,aMh,ZK,aMh,ama,aMh,Vb,aMh,aBi,aMh,adr,aMh,abt,aMh,azV,aMh,avw,aMh,akn,aMh,Vc,aMh,$B,aMh,au8,aMh,akl,aMh,Eh,aMh,OL,aMh,pL,aMh,afz,aMh,Nl,aMh,aFj,aMh,aGV,aMh,ahY,aMh,tm,aMh,J3,aMh,abB,aMh,wt,aMh,aoU,aMh,Wk,aMh,aa_,aMh,ZE,aMh,asM,aMh,JR,aMh,Un,aMh,Wj,aMh,ZC,aMh,au9,aMh,an$,aMh,arW,aMh,C2,aMh,wk,aMh,aD8,aMh,H3,aMh,asq,aMh,aBo,aMh,agu,aMh,axF,aMh,arm,aMh,Xv,aMh,aje,aMh,Xo,aMh,K7,aMh,aEC,aMh,Xw,aMh,Mb,aMh,ayh,aMh,zr,aMh,TN,aMh,ae4,aMh,aGt,aMh,agy,aMh,aeU,aMh,agE,aMh,aHB,aMh,aig,aMh,ak9,aMh,aci,aMh,$k,aMh,GV,aMh,TK,aMh,apV,aMh,I1,aMh,ae3,aMh,agD,aMh,CC,aMh,alC,aMh,CB,aMh,CA,aMh,CE,aMh,BQ,aMh,CD,aMh,Cn,aMh,akR,aMh,CG,aMh,CF,aMh,Tz,aMh,aGL,aMh,PB,aMh,aEX,aMh,avQ,aMh,alq,aMh,avi,aMh,ad9,aMh,W_,aMh,NF,aMh,WU,aMh,axl,aMh,N8,aMh,N0,aMh,Jp,aMh,aBX,aMh,ND,aMh,aCw,aMh,aCT,aMh,Yk,aMh,aqd,aMh,aCp,aMh,Iz,aMh,N7,aMh,amL,aMh,aiK,aMh,aqO,aMh,aiE,aMh,UV,aMh,ak2,aMh,am_,aMh,Ts,aMh,aAe,aMh,$G,aMh,YD,aMh,$f,aMh,H0,aMh,CH,aMh,Cg,aMh,abh,aMh,Vm,aMh,CI,aMh,apN,aMh,aAV,aMh,aqa,aMh,ZQ,aMh,Uw,aMh,azC,aMh,NS,aMh,aoh,aMh,apm,aMh,agY,aMh,H7,aMh,aso,aMh,xd,aMh,agZ,aMh,Pv,aMh,Ux,aMh,B9,aMh,X0,aMh,Up,aMh,afZ,aMh,hg,aMh,af9,aMh,rx,aMh,q0,aMh,abm,aMh,q1,aMh,qZ,aMh,q$,aMh,q_,aMh,acw,aMh,rE,aMh,LX,aMh,w7,aMh,rI,aMh,rY,aMh,rW,aMh,rX,aMh,rJ,aMh,r$,aMh,rZ,aMh,avn,aMh,SF,aMh,afu,aMh,aB0,aMh,SB,aMh,an0,aMh,xa,aMh,ahW,aMh,aft,aMh,afE,aMh,O3,aMh,aBG,aMh,aES,aMh,aBu,aMh,V8,aMh,aGU,aMh,Wa,aMh,aqS,aMh,SE,aMh,Z8,aMh,avp,aMh,WT,aMh,amH,aMh,aqC,aMh,r1,aMh,r2,aMh,awv,aMh,rK,aMh,r4,aMh,P2,aMh,r3,aMh,rL,aMh,aud,aMh,agI,aMh,qX,aMh,qV,aMh,qU,aMh,qW,aMh,qR,aMh,QM,aMh,qT,aMh,qS,aMh,_4,aMh,axm,aMh,Xr,aMh,Sf,aMh,aBO,aMh,$u,aMh,amn,aMh,Ya,aMh,PY,aMh,_5,aMh,_G,aMh,aAJ,aMh,ars,aMh,$v,aMh,T_,aMh,$p,aMh,SN,aMh,aEa,aMh,SP,aMh,aGz,aMh,ajx,aMh,JW,aMh,Sg,aMh,anB,aMh,ael,aMh,aE2,aMh,aek,aMh,Hy,aMh,ayZ,aMh,anc,aMh,ah0,aMh,age,aMh,agh,aMh,v6,aMh,v7,aMh,v8,aMh,vU,aMh,aDR,aMh,asL,aMh,azH,aMh,xK,aMh,am1,aMh,aAu,aMh,hj,aMh,aHi,aMh,aGH,aMh,Hd,aMh,Dz,aMh,awW,aMh,VN,aMh,amD,aMh,ayY,aMh,OG,aMh,aFe,aMh,ans,aMh,are,aMh,ayD,aMh,Wh,aMh,vR,aMh,v1,aMh,v2,aMh,v3,aMh,vS,aMh,v4,aMh,v5,aMh,vN,aMh,aod,aMh,akJ,aMh,adX,aMh,J7,aMh,_p,aMh,ayq,aMh,VQ,aMh,adU,aMh,Lp,aMh,aBp,aMh,RU,aMh,anz,aMh,ajX,aMh,azU,aMh,aCJ,aMh,aE0,aMh,to,aMh,adB,aMh,TZ,aMh,W2,aMh,T2,aMh,as5,aMh,app,aMh,ayj,aMh,ahB,aMh,M$,aMh,apG,aMh,FC,aMh,FB,aMh,FD,aMh,F9,aMh,Fy,aMh,Rc,aMh,FA,aMh,_r,aMh,acg,aMh,p9,aMh,FF,aMh,am2,aMh,Q3,aMh,azk,aMh,ani,aMh,MD,aMh,ahR,aMh,awC,aMh,aFZ,aMh,_Y,aMh,pU,aMh,Ji,aMh,Ne,aMh,Rr,aMh,aqR,aMh,ab1,aMh,aEG,aMh,Rq,aMh,aBH,aMh,RB,aMh,p8,aMh,aCj,aMh,atU,aMh,az1,aMh,amA,aMh,am4,aMh,awZ,aMh,Mf,aMh,av9,aMh,aHk,aMh,ahr,aMh,aya,aMh,avE,aMh,$h,aMh,ZX,aMh,aoL,aMh,Yy,aMh,Wq,aMh,Yq,aMh,Wi,aMh,Wn,aMh,FJ,aMh,aqD,aMh,FG,aMh,FI,aMh,FH,aMh,ary,aMh,TH,aMh,aCQ,aMh,alu,aMh,aGq,aMh,aDD,aMh,ab7,aMh,aA0,aMh,apg,aMh,_u,aMh,QA,aMh,av7,aMh,RD,aMh,Ny,aMh,atA,aMh,aet,aMh,XK,aMh,au5,aMh,RN,aMh,Fa,aMh,QB,aMh,Ur,aMh,aBc,aMh,alK,aMh,Nv,aMh,Y0,aMh,aus,aMh,aoQ,aMh,azr,aMh,aHj,aMh,as4,aMh,tw,aMh,NU,aMh,Op,aMh,ajd,aMh,aaZ,aMh,C3,aMh,Y1,aMh,C1,aMh,aqu,aMh,C$,aMh,Rj,aMh,C_,aMh,awH,aMh,Qc,aMh,XU,aMh,XW,aMh,TR,aMh,_H,aMh,afV,aMh,afI,aMh,aAq,aMh,UR,aMh,$e,aMh,tG,aMh,ae7,aMh,X6,aMh,CZ,aMh,CW,aMh,CX,aMh,CU,aMh,CV,aMh,CS,aMh,CT,aMh,Ca,aMh,Cb,aMh,as_,aMh,aAg,aMh,Jk,aMh,acE,aMh,ayU,aMh,ae_,aMh,KJ,aMh,anC,aMh,ae8,aMh,as9,aMh,alW,aMh,MZ,aMh,axy,aMh,WQ,aMh,$$,aMh,abW,aMh,xf,aMh,Yx,aMh,aBZ,aMh,ayw,aMh,DD,aMh,ae$,aMh,aBY,aMh,amf,aMh,aeK,aMh,$P,aMh,asJ,aMh,xe,aMh,awU,aMh,DF,aMh,aEs,aMh,zR,aMh,sm,aMh,aAW,aMh,sF,aMh,sc,aMh,sn,aMh,sG,aMh,RC,aMh,Wo,aMh,awX,aMh,ah3,aMh,N9,aMh,K9,aMh,aaE,aMh,QQ,aMh,ajq,aMh,zO,aMh,xi,aMh,acZ,aMh,ayf,aMh,YG,aMh,Vp,aMh,avU,aMh,ar6,aMh,abg,aMh,NA,aMh,axx,aMh,amx,aMh,YL,aMh,M9,aMh,QY,aMh,z_,aMh,Yz,aMh,_t,aMh,aeo,aMh,aoJ,aMh,ard,aMh,Lc,aMh,sb,aMh,anM,aMh,aqU,aMh,LO,aMh,YB,aMh,tU,aMh,amb,aMh,axL,aMh,r6,aMh,r5,aMh,acr,aMh,rM,aMh,_9,aMh,sB,aMh,LM,aMh,aCL,aMh,Ja,aMh,aar,aMh,aaf,aMh,aGh,aMh,XI,aMh,$d,aMh,Zl,aMh,aBV,aMh,XJ,aMh,an_,aMh,auo,aMh,PS,aMh,A2,aMh,SX,aMh,SM,aMh,U0,aMh,pd,aMh,AW,aMh,AX,aMh,AY,aMh,AZ,aMh,A_,aMh,abj,aMh,I9,aMh,au_,aMh,Pl,aMh,Sm,aMh,an2,aMh,g4,aMh,aE5,aMh,Pb,aMh,ST,aMh,az3,aMh,aoc,aMh,V4,aMh,aH1,aMh,asz,aMh,af3,aMh,aFy,aMh,TY,aMh,aAo,aMh,ahl,aMh,akQ,aMh,aoS,aMh,Rv,aMh,acc,aMh,azd,aMh,ayT,aMh,axs,aMh,anb,aMh,U1,aMh,NO,aMh,awV,aMh,atx,aMh,aDz,aMh,ajy,aMh,aii,aMh,aqL,aMh,JC,aMh,ay3,aMh,Kl,aMh,w$,aMh,Ov,aMh,NN,aMh,NE,aMh,amC,aMh,aBA,aMh,A5,aMh,NB,aMh,A7,aMh,A8,aMh,adQ,aMh,ar4,aMh,C6,aMh,$2,aMh,aqV,aMh,C5,aMh,Di,aMh,Dj,aMh,Dg,aMh,Dh,aMh,aGQ,aMh,Of,aMh,gK,aMh,Dk,aMh,Dl,aMh,aAH,aMh,w_,aMh,awz,aMh,T$,aMh,akI,aMh,atJ,aMh,ON,aMh,ayv,aMh,IS,aMh,OO,aMh,_v,aMh,ahn,aMh,akz,aMh,O1,aMh,acl,aMh,wg,aMh,aiw,aMh,vW,aMh,we,aMh,wd,aMh,wc,aMh,vV,aMh,wb,aMh,No,aMh,asZ,aMh,apO,aMh,apk,aMh,HQ,aMh,HR,aMh,HV,aMh,HS,aMh,Q7,aMh,Jd,aMh,$V,aMh,Ui,aMh,ana,aMh,acD,aMh,ajf,aMh,Uh,aMh,aEz,aMh,Db,aMh,Lu,aMh,C9,aMh,Da,aMh,Dn,aMh,C8,aMh,$7,aMh,zX,aMh,aFh,aMh,anG,aMh,aIl,aMh,HF,aMh,IP,aMh,MH,aMh,awq,aMh,ro,aMh,zZ,aMh,HU,aMh,ajp,aMh,HM,aMh,anT,aMh,WV,aMh,axW,aMh,UF,aMh,aAt,aMh,Vf,aMh,aDH,aMh,aE$,aMh,ano,aMh,aFq,aMh,auh,aMh,vY,aMh,wi,aMh,adu,aMh,vP,aMh,vX,aMh,IG,aMh,aHK,aMh,JX,aMh,aD3,aMh,Pf,aMh,adm,aMh,ar$,aMh,acz,aMh,aew,aMh,aqk,aMh,acA,aMh,Zf,aMh,av2,aMh,ad7,aMh,aGI,aMh,I2,aMh,ahz,aMh,adp,aMh,at4,aMh,QF,aMh,wx,aMh,Qz,aMh,aC3,aMh,ak0,aMh,pN,aMh,ank,aMh,ain,aMh,$i,aMh,V0,aMh,K5,aMh,QE,aMh,Jf,aMh,adj,aMh,ah_,aMh,axq,aMh,XM,aMh,Pu,aMh,azS,aMh,agl,aMh,acs,aMh,aa8,aMh,_8,aMh,aa7,aMh,r7,aMh,Jr,aMh,aAA,aMh,OV,aMh,ao3,aMh,aG8,aMh,aCI,aMh,au1,aMh,sC,aMh,auv,aMh,avK,aMh,aB7,aMh,acU,aMh,sD,aMh,ayn,aMh,Ix,aMh,sl,aMh,akK,aMh,aim,aMh,Tc,aMh,au3,aMh,abU,aMh,anw,aMh,AU,aMh,Y3,aMh,ZH,aMh,LE,aMh,X4,aMh,aeO,aMh,Qu,aMh,aHM,aMh,auk,aMh,aHR,aMh,aCM,aMh,M6,aMh,ai3,aMh,qc,aMh,B_,aMh,oO,aMh,B0,aMh,BX,aMh,BW,aMh,BZ,aMh,BY,aMh,auR,aMh,avV,aMh,aCK,aMh,QG,aMh,GR,aMh,QR,aMh,aqA,aMh,aql,aMh,asf,aMh,Ci,aMh,aGC,aMh,aCG,aMh,aEF,aMh,asX,aMh,at0,aMh,an3,aMh,aiU,aMh,anN,aMh,apW,aMh,aqT,aMh,Pw,aMh,aaw,aMh,GS,aMh,aun,aMh,avM,aMh,af0,aMh,Vg,aMh,BR,aMh,I8,aMh,aGx,aMh,afT,aMh,afQ,aMh,aCA,aMh,T6,aMh,_3,aMh,Se,aMh,aE1,aMh,EQ,aMh,B8,aMh,B7,aMh,aHo,aMh,B4,aMh,amU,aMh,B6,aMh,B5,aMh,QP,aMh,VK,aMh,atD,aMh,pe,aMh,N_,aMh,VY,aMh,aEe,aMh,IH,aMh,asT,aMh,Nf,aMh,tB,aMh,agH,aMh,axE,aMh,ayr,aMh,aA3,aMh,VX,aMh,WE,aMh,ata,aMh,agG,aMh,sK,aMh,sL,aMh,sp,aMh,sM,aMh,sI,aMh,sJ,aMh,so,aMh,r8,aMh,axJ,aMh,XA,aMh,sN,aMh,Ez,aMh,tK,aMh,awG,aMh,TP,aMh,ayV,aMh,R4,aMh,Bm,aMh,Bl,aMh,Bk,aMh,VA,aMh,Bp,aMh,Bo,aMh,Bn,aMh,_y,aMh,zM,aMh,aaU,aMh,axk,aMh,RR,aMh,aCa,aMh,RS,aMh,Zv,aMh,_A,aMh,ax9,aMh,PD,aMh,aBP,aMh,aIk,aMh,aty,aMh,axB,aMh,ayS,aMh,ayk,aMh,aCg,aMh,Bj,aMh,Bi,aMh,aoY,aMh,Bc,aMh,Bb,aMh,Ba,aMh,Bh,aMh,Bg,aMh,Bf,aMh,Be,aMh,sP,aMh,sr,aMh,sQ,aMh,Rw,aMh,r9,aMh,sO,aMh,aq9,aMh,adt,aMh,atz,aMh,all,aMh,KV,aMh,TG,aMh,anD,aMh,JK,aMh,awg,aMh,K1,aMh,A$,aMh,Rn,aMh,aFn,aMh,ag1,aMh,A0,aMh,NG,aMh,abL,aMh,ayF,aMh,aa2,aMh,aBC,aMh,VL,aMh,al4,aMh,aAp,aMh,axr,aMh,Wt,aMh,V9,aMh,Ws,aMh,UA,aMh,Uo,aMh,UB,aMh,azq,aMh,vr,aMh,vs,aMh,V5,aMh,vq,aMh,vu,aMh,vt,aMh,vD,aMh,Rs,aMh,RZ,aMh,Ry,aMh,asD,aMh,CN,aMh,ax2,aMh,Z5,aMh,Wd,aMh,aw9,aMh,ady,aMh,LZ,aMh,UN,aMh,azW,aMh,aHg,aMh,Kj,aMh,an5,aMh,av0,aMh,afR,aMh,afU,aMh,aAE,aMh,ajN,aMh,TS,aMh,ae9,aMh,vp,aMh,HO,aMh,Vs,aMh,vj,aMh,tz,aMh,vh,aMh,vi,aMh,vC,aMh,vn,aMh,vl,aMh,vm,aMh,Wc,aMh,MV,aMh,ait,aMh,wA,aMh,anL,aMh,TT,aMh,xt,aMh,TL,aMh,awK,aMh,acP,aMh,adT,aMh,ao9,aMh,U7,aMh,anE,aMh,_Z,aMh,wD,aMh,KH,aMh,$l,aMh,Xc,aMh,aro,aMh,Iv,aMh,azQ,aMh,aux,aMh,aGe,aMh,Yt,aMh,axa,aMh,avL,aMh,aBx,aMh,ad5,aMh,Ld,aMh,aee,aMh,aGA,aMh,F5,aMh,F4,aMh,F3,aMh,Gd,aMh,Xt,aMh,F1,aMh,F0,aMh,QK,aMh,F_,aMh,FZ,aMh,ah1,aMh,PO,aMh,anR,aMh,acp,aMh,ok,aMh,PN,aMh,JY,aMh,gg,aMh,Pt,aMh,auL,aMh,C7,aMh,$Z,aMh,MX,aMh,W0,aMh,Ua,aMh,Lh,aMh,Nj,aMh,QL,aMh,aup,aMh,W1,aMh,Nc,aMh,T4,aMh,aiJ,aMh,Nk,aMh,Lg,aMh,_a,aMh,arb,aMh,ac5,aMh,akk,aMh,ZB,aMh,Y2,aMh,_e,aMh,Mt,aMh,JV,aMh,MK,aMh,ym,aMh,aFP,aMh,Md,aMh,aEh,aMh,th,aMh,aDE,aMh,aa5,aMh,az6,aMh,aza,aMh,Yr,aMh,ayi,aMh,HE,aMh,HT,aMh,HD,aMh,HC,aMh,HB,aMh,HA,aMh,_d,aMh,awt,aMh,avk,aMh,amK,aMh,PH,aMh,aAT,aMh,an4,aMh,aFt,aMh,Oj,aMh,Vl,aMh,X5,aMh,Nm,aMh,aeV,aMh,GJ,aMh,aA7,aMh,aeX,aMh,GG,aMh,aGW,aMh,awf,aMh,Xg,aMh,Qh,aMh,akF,aMh,agQ,aMh,at2,aMh,qh,aMh,qY,aMh,aHh,aMh,Q1,aMh,GM,aMh,adx,aMh,aER,aMh,aa4,aMh,ahL,aMh,GK,aMh,ayo,aMh,Xh,aMh,pC,aMh,agj,aMh,agn,aMh,ar3,aMh,aqy,aMh,IJ,aMh,RI,aMh,aiV,aMh,ZS,aMh,aBW,aMh,akE,aMh,ayg,aMh,aHI,aMh,asP,aMh,anH,aMh,Kf,aMh,L3,aMh,aaY,aMh,atV,aMh,at7,aMh,aD1,aMh,awy,aMh,azM,aMh,aan,aMh,M3,aMh,alm,aMh,abi,aMh,aHF,aMh,aaJ,aMh,aoZ,aMh,abu,aMh,al9,aMh,ajJ,aMh,aez,aMh,_g,aMh,aAc,aMh,Xj,aMh,_B,aMh,aKT,aMh,Vw,aMh,apb,aMh,aaQ,aMh,aF4,aMh,o0,aMh,aFr,aMh,aei,aMh,v$,aMh,as0,aMh,Vq,aMh,Ou,aMh,Vx,aMh,aoF,aMh,Us,aMh,I_,aMh,ahS,aMh,apQ,aMh,aAf,aMh,Uq,aMh,adR,aMh,Ei,aMh,agB,aMh,tl,aMh,W9,aMh,aku,aMh,axg,aMh,ay5,aMh,zU,aMh,avt,aMh,_E,aMh,O_,aMh,aE7,aMh,Zn,aMh,JO,aMh,_R,aMh,_x,aMh,aaT,aMh,atC,aMh,_F,aMh,ak8,aMh,and,aMh,f8,aMh,A6,aMh,Qp,aMh,VH,aMh,aD6,aMh,aFM,aMh,adM,aMh,axp,aMh,axN,aMh,aDG,aMh,A9,aMh,rV,aMh,PI,aMh,J5,aMh,$R,aMh,abo,aMh,aFG,aMh,ug,aMh,tT,aMh,uQ,aMh,ue,aMh,uf,aMh,auJ,aMh,ud,aMh,aGj,aMh,aai,aMh,C4,aMh,$J,aMh,Ko,aMh,apu,aMh,apf,aMh,_k,aMh,$W,aMh,EO,aMh,atN,aMh,s$,aMh,_l,aMh,ayC,aMh,Sc,aMh,WI,aMh,By,aMh,Bz,aMh,Bw,aMh,Bx,aMh,Bu,aMh,Bv,aMh,Bs,aMh,Bt,aMh,Bq,aMh,Br,aMh,aF7,aMh,af7,aMh,aC7,aMh,uv,aMh,uw,aMh,aHd,aMh,aa$,aMh,us,aMh,ut,aMh,uZ,aMh,uu,aMh,uo,aMh,up,aMh,uq,aMh,ur,aMh,XO,aMh,afm,aMh,I6,aMh,aAG,aMh,NI,aMh,agW,aMh,uP,aMh,ua,aMh,tS,aMh,t9,aMh,t7,aMh,t8,aMh,t5,aMh,t6,aMh,akv,aMh,aff,aMh,I5,aMh,afn,aMh,uc,aMh,atG,aMh,aDZ,aMh,MB,aMh,uA,aMh,u_,aMh,uB,aMh,ux,aMh,uy,aMh,uz,aMh,akU,aMh,BF,aMh,_h,aMh,Xz,aMh,BE,aMh,BB,aMh,BC,aMh,BA,aMh,atr,aMh,DA,aMh,DB,aMh,DC,aMh,axn,aMh,DE,aMh,aE3,aMh,DG,aMh,acW,aMh,DI,aMh,anP,aMh,abX,aMh,as3,aMh,ET,aMh,auu,aMh,ass,aMh,X7,aMh,AQ,aMh,arz,aMh,aEM,aMh,aC8,aMh,vK,aMh,vJ,aMh,ac9,aMh,aGM,aMh,vF,aMh,vE,aMh,vw,aMh,vv,aMh,vH,aMh,vG,aMh,vI,aMh,vx,aMh,OQ,aMh,aFX,aMh,R_,aMh,EX,aMh,EY,aMh,air,aMh,EW,aMh,E_,aMh,EZ,aMh,Fe,aMh,Zy,aMh,aqF,aMh,$s,aMh,ahP,aMh,DJ,aMh,DK,aMh,SK,aMh,DM,aMh,DN,aMh,DO,aMh,U9,aMh,aaj,aMh,u7,aMh,WW,aMh,PT,aMh,EU,aMh,EV,aMh,awT,aMh,vO,aMh,aiB,aMh,EP,aMh,Ms,aMh,EN,aMh,aDf,aMh,Fd,aMh,WX,aMh,ER,aMh,ES,aMh,wf,aMh,an9,aMh,TX,aMh,ajH,aMh,aph,aMh,af_,aMh,vy,aMh,Vd,aMh,vM,aMh,vL,aMh,vQ,aMh,vZ,aMh,v_,aMh,JZ,aMh,arN,aMh,aeR,aMh,aD2,aMh,abz,aMh,X_,aMh,abv,aMh,KM,aMh,abw,aMh,KN,aMh,qb,aMh,av5,aMh,Kz,aMh,WD,aMh,aGF,aMh,wa,aMh,Ex,aMh,auq,aMh,asY,aMh,akG,aMh,aEc,aMh,agb,aMh,avm,aMh,HP,aMh,va,aMh,Cr,aMh,aFW,aMh,aKU,aMh,Ej,aMh,aAB,aMh,ahv,aMh,KE,aMh,awi,aMh,T7,aMh,OJ,aMh,atl,aMh,Xl,aMh,YY,aMh,_0,aMh,ax8,aMh,_U,aMh,adw,aMh,GQ,aMh,alh,aMh,W3,aMh,N5,aMh,azD,aMh,acY,aMh,ala,aMh,_$,aMh,adG,aMh,aCC,aMh,aHH,aMh,an7,aMh,Er,aMh,ac1,aMh,S0,aMh,axK,aMh,v9,aMh,awF,aMh,Cc,aMh,aAP,aMh,Ay,aMh,Uj,aMh,azG,aMh,Y4,aMh,ajg,aMh,Rb,aMh,aid,aMh,QX,aMh,aoz,aMh,aGa,aMh,ari,aMh,af1,aMh,oQ,aMh,atL,aMh,ajK,aMh,Ga,aMh,$x,aMh,amQ,aMh,aon,aMh,ag9,aMh,agP,aMh,Uu,aMh,ahm,aMh,aeM,aMh,YV,aMh,ajS,aMh,LP,aMh,XG,aMh,wp,aMh,aBD,aMh,w5,aMh,aoO,aMh,aDQ,aMh,ao7,aMh,ayp,aMh,rR,aMh,pg,aMh,aB3,aMh,AB,aMh,rQ,aMh,axS,aMh,alQ,aMh,ams,aMh,akV,aMh,YO,aMh,VO,aMh,aao,aMh,aFJ,aMh,aHL,aMh,ap2,aMh,awo,aMh,rN,aMh,pf,aMh,at3,aMh,AC,aMh,Tj,aMh,auE,aMh,IX,aMh,Cy,aMh,aAS,aMh,aBv,aMh,xb,aMh,rC,aMh,aCr,aMh,Ut,aMh,aBI,aMh,awN,aMh,aej,aMh,UP,aMh,Oa,aMh,Cm,aMh,al6,aMh,Dm,aMh,WK,aMh,avy,aMh,ajm,aMh,aeL,aMh,YW,aMh,ajb,aMh,w8,aMh,aag,aMh,aah,aMh,BP,aMh,acq,aMh,alg,aMh,Pp,aMh,J6,aMh,XV,aMh,u1,aMh,sk,aMh,uL,aMh,auF,aMh,u3,aMh,akO,aMh,aoP,aMh,aF6,aMh,az7,aMh,aBK,aMh,akN,aMh,anf,aMh,$Y,aMh,Kp,aMh,aDC,aMh,Kh,aMh,V6,aMh,AF,aMh,UQ,aMh,Eu,aMh,awx,aMh,UO,aMh,KP,aMh,HH,aMh,XB,aMh,ajD,aMh,G5,aMh,OE,aMh,ap3,aMh,KQ,aMh,aBf,aMh,aCS,aMh,aca,aMh,adL,aMh,Qn,aMh,aq8,aMh,afr,aMh,ay6,aMh,aic,aMh,aqw,aMh,OD,aMh,apv,aMh,afg,aMh,qp,aMh,aly,aMh,HL,aMh,aiN,aMh,afh,aMh,auB,aMh,aau,aMh,uK,aMh,uJ,aMh,Os,aMh,HN,aMh,uF,aMh,uE,aMh,Wb,aMh,uC,aMh,uI,aMh,u$,aMh,uH,aMh,uG,aMh,Ih,aMh,aqQ,aMh,Ig,aMh,ase,aMh,Ie,aMh,If,aMh,UC,aMh,abx,aMh,RA,aMh,aDA,aMh,uW,aMh,DZ,aMh,uX,aMh,un,aMh,ajW,aMh,uR,aMh,uU,aMh,uT,aMh,Dy,aMh,Dx,aMh,Dw,aMh,ui,aMh,apz,aMh,Du,aMh,ao$,aMh,awm,aMh,A3,aMh,tY,aMh,uM,aMh,F2,aMh,D1,aMh,ab6,aMh,Id,aMh,qa,aMh,aF2,aMh,alD,aMh,aiZ,aMh,Y6,aMh,Xq,aMh,ape,aMh,tV,aMh,ayJ,aMh,uY,aMh,um,aMh,Q2,aMh,amT,aMh,uj,aMh,aBs,aMh,ul,aMh,uk,aMh,Df,aMh,De,aMh,Dd,aMh,Dc,aMh,Dr,aMh,Dq,aMh,Dp,aMh,Do,aMh,Iy,aMh,R0,aMh,H8,aMh,H9,aMh,H6,aMh,Wz,aMh,ZI,aMh,Hz,aMh,amN,aMh,aEy,aMh,O2,aMh,R2,aMh,IQ,aMh,Ib,aMh,Ic,aMh,ql,aMh,LI,aMh,NY,aMh,oM,aMh,H_,aMh,Xk,aMh,arn,aMh,aFB,aMh,_z,aMh,aFI,aMh,F$,aMh,ai_,aMh,OZ,aMh,Qw,aMh,aA4,aMh,azm,aMh,Qs,aMh,aDF,aMh,adE,aMh,Jt,aMh,Jl,aMh,aAI,aMh,Ju,aMh,ar7,aMh,ax5,aMh,aEi,aMh,aC$,aMh,EH,aMh,EG,aMh,$M,aMh,aia,aMh,Nw,aMh,KA,aMh,aEw,aMh,yN,aMh,yO,aMh,EC,aMh,EB,aMh,EE,aMh,ED,aMh,EF,aMh,Fb,aMh,J0,aMh,aGp,aMh,ag0,aMh,Yj,aMh,azX,aMh,vz,aMh,aIo,aMh,Zx,aMh,ag$,aMh,aBr,aMh,arp,aMh,aFa,aMh,qr,aMh,aBl,aMh,aEV,aMh,sE,aMh,Ky,aMh,Vi,aMh,aEg,aMh,Ks,aMh,aCi,aMh,afb,aMh,awP,aMh,aj9,aMh,_V,aMh,apU,aMh,Ss,aMh,qo,aMh,KB,aMh,Q8,aMh,aeH,aMh,aap,aMh,amF,aMh,aAz,aMh,Yf,aMh,Mq,aMh,aEn,aMh,apd,aMh,yI,aMh,yJ,aMh,y$,aMh,EI,aMh,yF,aMh,yG,aMh,yH,aMh,yA,aMh,EL,aMh,yC,aMh,yD,aMh,pb,aMh,azN,aMh,aHp,aMh,PZ,aMh,yc,aMh,DL,aMh,avu,aMh,P_,aMh,aB6,aMh,OP,aMh,jn,aMh,M1,aMh,ya,aMh,_m,aMh,adi,aMh,ae5,aMh,x8,aMh,JB,aMh,x9,aMh,atF,aMh,x6,aMh,aED,aMh,aDs,aMh,x7,aMh,amV,aMh,DP,aMh,x5,aMh,DS,aMh,aht,aMh,aBy,aMh,M2,aMh,SV,aMh,avT,aMh,aec,aMh,ast,aMh,avF,aMh,YT,aMh,aaL,aMh,aCn,aMh,at9,aMh,DT,aMh,aoi,aMh,XF,aMh,av6,aMh,DW,aMh,ag8,aMh,Cu,aMh,afD,aMh,ad1,aMh,amX,aMh,ZY,aMh,aqJ,aMh,acd,aMh,Ct,aMh,UJ,aMh,Zq,aMh,aGk,aMh,BO,aMh,sz,aMh,anr,aMh,T5,aMh,aEv,aMh,ZZ,aMh,UY,aMh,ay0,aMh,UZ,aMh,al2,aMh,TM,aMh,aBq,aMh,aDx,aMh,HG,aMh,aDW,aMh,YU,aMh,TO,aMh,Lv,aMh,aiA,aMh,ad0,aMh,aaH,aMh,alw,aMh,aCz,aMh,QC,aMh,ahF,aMh,qf,aMh,agx,aMh,SA,aMh,YE,aMh,agL,aMh,ajL,aMh,agF,aMh,azi,aMh,agK,aMh,ayc,aMh,Lf,aMh,ai2,aMh,Po,aMh,ajY,aMh,akS,aMh,Vh,aMh,LY,aMh,agw,aMh,II,aMh,HI,aMh,Vk,aMh,Zh,aMh,ZW,aMh,RV,aMh,LD,aMh,amM,aMh,aab,aMh,RW,aMh,IV,aMh,RQ,aMh,zN,aMh,aCU,aMh,asn,aMh,ap1,aMh,K3,aMh,amE,aMh,KI,aMh,HJ,aMh,aEm,aMh,abZ,aMh,SQ,aMh,ajz,aMh,aoe,aMh,qQ,aMh,qP,aMh,I3,aMh,aC6,aMh,TA,aMh,HK,aMh,s2,aMh,s3,aMh,s4,aMh,ags,aMh,s5,aMh,qu,aMh,aeW,aMh,aDu,aMh,aEx,aMh,Kc,aMh,oW,aMh,oX,aMh,oF,aMh,oV,aMh,pi,aMh,ap7,aMh,qt,aMh,_J,aMh,GH,aMh,akD,aMh,agt,aMh,az4,aMh,MT,aMh,abG,aMh,Q6,aMh,akw,aMh,asC,aMh,afa,aMh,ZT,aMh,agi,aMh,Qt,aMh,VV,aMh,ate,aMh,aG_,aMh,yh,aMh,oU,aMh,oD,aMh,oS,aMh,agp,aMh,ph,aMh,oC,aMh,oz,aMh,oR,aMh,KU,aMh,N2,aMh,oA,aMh,oE,aMh,sU,aMh,sW,aMh,sX,aMh,sY,aMh,sZ,aMh,s_,aMh,M0,aMh,wj,aMh,s0,aMh,sV,aMh,ye,aMh,q9,aMh,S4,aMh,wW,aMh,af8,aMh,$O,aMh,aBj,aMh,$E,aMh,OH,aMh,Qv,aMh,arI,aMh,O6,aMh,adc,aMh,aAj,aMh,Ln,aMh,SC,aMh,Pq,aMh,afs,aMh,$N,aMh,aBE,aMh,atM,aMh,Fv,aMh,F8,aMh,Fw,aMh,Ec,aMh,Fs,aMh,Ft,aMh,azO,aMh,D5,aMh,D6,aMh,D3,aMh,D4,aMh,D9,aMh,Ea,aMh,D7,aMh,D8,aMh,Hp,aMh,Ho,aMh,Hq,aMh,H4,aMh,Hl,aMh,Hk,aMh,Hn,aMh,Hm,aMh,vc,aMh,vb,aMh,Hs,aMh,Hr,aMh,aF8,aMh,sH,aMh,L_,aMh,ahN,aMh,aHA,aMh,TU,aMh,alo,aMh,aBn,aMh,wh,aMh,TI,aMh,aoD,aMh,ava,aMh,vf,aMh,Hw,aMh,vd,aMh,Hx,aMh,Z9,aMh,u0,aMh,Hv,aMh,Hu,aMh,aa0,aMh,akm,aMh,aBS,aMh,aa1,aMh,Fn,aMh,Fo,aMh,F7,aMh,Fp,aMh,Fj,aMh,Sd,aMh,Fl,aMh,Fm,aMh,PR,aMh,Ef,aMh,Il,aMh,Ed,aMh,Fq,aMh,Fr,aMh,Eg,aMh,NZ,aMh,OK,aMh,aoa,aMh,afS,aMh,JM,aMh,W5,aMh,aD4,aMh,Gf,aMh,rw,aMh,P3,aMh,VD,aMh,SU,aMh,aeT,aMh,Ff,aMh,aAL,aMh,UH,aMh,P1,aMh,Wm,aMh,adH,aMh,NC,aMh,ay_,aMh,xy,aMh,wQ,aMh,awj,aMh,aHw,aMh,xx,aMh,Vu,aMh,afJ,aMh,agf,aMh,af5,aMh,azx,aMh,K8,aMh,E6,aMh,Xa,aMh,xu,aMh,ako,aMh,NK,aMh,Wv,aMh,aaq,aMh,aGR,aMh,anS,aMh,ajw,aMh,xw,aMh,yZ,aMh,yY,aMh,yX,aMh,yW,aMh,yV,aMh,yU,aMh,yT,aMh,yS,aMh,yR,aMh,yQ,aMh,aeg,aMh,U6,aMh,aue,aMh,OI,aMh,rd,aMh,atS,aMh,ahp,aMh,ax1,aMh,ub,aMh,Xd,aMh,aq0,aMh,J1,aMh,u8,aMh,aGl,aMh,$m,aMh,Xi,aMh,asE,aMh,az5,aMh,aeh,aMh,D0,aMh,aok,aMh,aDl,aMh,ac2,aMh,_I,aMh,aHu,aMh,Or,aMh,ayy,aMh,y3,aMh,y2,aMh,y1,aMh,y0,aMh,KF,aMh,y_,aMh,zA,aMh,aoT,aMh,pt,aMh,RL,aMh,W$,aMh,asK,aMh,aG6,aMh,Gt,aMh,pD,aMh,aua,aMh,aBm,aMh,aGX,aMh,am9,aMh,Z_,aMh,x0,aMh,X1,aMh,auP,aMh,aw_,aMh,aGo,aMh,aev,aMh,ajj,aMh,aDa,aMh,ajR,aMh,atn,aMh,atY,aMh,Ta,aMh,BD,aMh,NJ,aMh,aHs,aMh,pT,aMh,awL,aMh,aj_,aMh,Gc,aMh,Ps,aMh,RH,aMh,S5,aMh,FK,aMh,aaK,aMh,akB,aMh,Tm,aMh,x_,aMh,aey,aMh,aGY,aMh,$C,aMh,FU,aMh,aDw,aMh,$D,aMh,$w,aMh,avW,aMh,L9,aMh,Nd,aMh,C0,aMh,ayQ,aMh,amp,aMh,ai7,aMh,afj,aMh,aFO,aMh,aC2,aMh,avd,aMh,aoN,aMh,aop,aMh,afi,aMh,aa3,aMh,aFb,aMh,YK,aMh,NV,aMh,aqK,aMh,aGB,aMh,Gl,aMh,aHb,aMh,Qi,aMh,Rk,aMh,Jn,aMh,o1,aMh,Lx,aMh,axV,aMh,auA,aMh,ae2,aMh,_j,aMh,anh,aMh,pr,aMh,pW,aMh,aqn,aMh,Le,aMh,at5,aMh,amR,aMh,aoH,aMh,Fi,aMh,z3,aMh,WL,aMh,WJ,aMh,adW,aMh,Ng,aMh,atZ,aMh,atX,aMh,at_,aMh,zj,aMh,zi,aMh,zh,aMh,zg,aMh,zf,aMh,ze,aMh,Si,aMh,x2,aMh,aq6,aMh,W7,aMh,q2,aMh,LT,aMh,xq,aMh,Vr,aMh,Cw,aMh,Pa,aMh,Ud,aMh,aw2,aMh,N6,aMh,I$,aMh,afX,aMh,AJ,aMh,axO,aMh,Qq,aMh,aEU,aMh,B3,aMh,uD,aMh,B2,aMh,zb,aMh,za,aMh,y9,aMh,y8,aMh,y7,aMh,y6,aMh,y5,aMh,y4,aMh,JH,aMh,S$,aMh,zd,aMh,zc,aMh,KX,aMh,B$,aMh,tE,aMh,ayz,aMh,atq,aMh,aov,aMh,o$,aMh,o_,aMh,oI,aMh,ayl,aMh,oZ,aMh,oY,aMh,oH,aMh,pj,aMh,aHE,aMh,QZ,aMh,oJ,aMh,US,aMh,acG,aMh,abV,aMh,Sl,aMh,acb,aMh,ax$,aMh,t0,aMh,t$,aMh,t_,aMh,uN,aMh,tZ,aMh,aG2,aMh,tX,aMh,tQ,aMh,tW,aMh,D2,aMh,jl,aMh,aze,aMh,Xb,aMh,Uv,aMh,QH,aMh,anX,aMh,GY,aMh,EK,aMh,axI,aMh,aET,aMh,$9,aMh,aHz,aMh,agX,aMh,So,aMh,alX,aMh,aaa,aMh,G0,aMh,SZ,aMh,DY,aMh,DX,aMh,vg,aMh,Od,aMh,ah4,aMh,DQ,aMh,t4,aMh,uO,aMh,t3,aMh,t2,aMh,tR,aMh,t1,aMh,DV,aMh,o4,aMh,o3,aMh,YM,aMh,oL,aMh,pk,aMh,aqo,aMh,o2,aMh,oK,aMh,FN,aMh,U4,aMh,awp,aMh,azy,aMh,Uf,aMh,FO,aMh,Fz,aMh,aen,aMh,uV,aMh,agk,aMh,Fc,aMh,wG,aMh,FM,aMh,apy,aMh,aCO,aMh,GB,aMh,arX,aMh,avr,aMh,U_,aMh,uS,aMh,aq5,aMh,SI,aMh,aEY,aMh,A1,aMh,v0,aMh,azo,aMh,O8,aMh,aFm,aMh,wH,aMh,XE,aMh,E2,aMh,E1,aMh,E$,aMh,E5,aMh,FS,aMh,E4,aMh,E3,aMh,ar8,aMh,E7,aMh,MR,aMh,ayX,aMh,Oo,aMh,af2,aMh,Sk,aMh,ab$,aMh,amk,aMh,aFg,aMh,Dv,aMh,aC_,aMh,abO,aMh,abN,aMh,uh,aMh,arc,aMh,$1,aMh,aCZ,aMh,aG$,aMh,axw,aMh,aCV,aMh,aA5,aMh,XQ,aMh,afB,aMh,$t,aMh,Fg,aMh,E9,aMh,E8,aMh,ayN,aMh,aEr,aMh,F6,aMh,Fh,aMh,an1,aMh,akj,aMh,R3,aMh,ao4,aMh,ao1,aMh,acK,aMh,FE,aMh,abq,aMh,ack,aMh,ajV,aMh,azI,aMh,ab4,aMh,agR,aMh,Ox,aMh,Xm,aMh,_f,aMh,Aa,aMh,OF,aMh,f_,aMh,Oq,aMh,aDJ,aMh,YJ,aMh,aGw,aMh,asI,aMh,ali,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh,aMh];var fH=[aMi,aMi,aKV,aMi,aKW,aMi,aKX,aMi,aKY,aMi,aKZ,aMi,aK_,aMi,aK$,aMi,aK0,aMi,aK1,aMi,aK2,aMi,aK3,aMi,aK4,aMi,aK5,aMi,f2,aMi,aK6,aMi,aK7,aMi,aK8,aMi,aK9,aMi,aLa,aMi,aLb,aMi,aLc,aMi,aLd,aMi,aLe,aMi,aLf,aMi,aLg,aMi,aMi,aMi,aMi,aMi,aMi,aMi,aMi,aMi,aMi,aMi,aMi,aMi];return{_testSetjmp:aIx,_saveSetjmp:aIw,_free:aIq,_main:fZ,_memcmp:aID,_strncpy:aIE,_memmove:aIC,_tolower:aIz,_strncasecmp:aIA,_memset:aIv,_malloc:aIp,_memcpy:aIy,_strcasecmp:aIB,_strlen:aIu,_realloc:aIr,runPostSets:fY,stackAlloc:fI,stackSave:fJ,stackRestore:fK,setThrew:fL,setTempRet0:fO,setTempRet1:fP,setTempRet2:fQ,setTempRet3:fR,setTempRet4:fS,setTempRet5:fT,setTempRet6:fU,setTempRet7:fV,setTempRet8:fW,setTempRet9:fX,dynCall_iiiiiiii:aLp,dynCall_vif:aLq,dynCall_viiiii:aLr,dynCall_vi:aLs,dynCall_vii:aLt,dynCall_iiiiiii:aLu,dynCall_ii:aLv,dynCall_viiiiiiiiiii:aLw,dynCall_viffff:aLx,dynCall_if:aLy,dynCall_iiii:aLz,dynCall_viiiiif:aLA,dynCall_viiiiiiii:aLB,dynCall_vifff:aLC,dynCall_fii:aLD,dynCall_iiif:aLE,dynCall_viff:aLF,dynCall_iif:aLG,dynCall_viiiiiii:aLH,dynCall_ff:aLI,dynCall_viiiiiiiii:aLJ,dynCall_iii:aLK,dynCall_viiiiii:aLL,dynCall_f:aLM,dynCall_i:aLN,dynCall_iiiii:aLO,dynCall_viii:aLP,dynCall_v:aLQ,dynCall_viiii:aLR}})
// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_vif": invoke_vif, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_ii": invoke_ii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_viffff": invoke_viffff, "invoke_if": invoke_if, "invoke_iiii": invoke_iiii, "invoke_viiiiif": invoke_viiiiif, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_vifff": invoke_vifff, "invoke_fii": invoke_fii, "invoke_iiif": invoke_iiif, "invoke_viff": invoke_viff, "invoke_iif": invoke_iif, "invoke_viiiiiii": invoke_viiiiiii, "invoke_ff": invoke_ff, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_iii": invoke_iii, "invoke_viiiiii": invoke_viiiiii, "invoke_f": invoke_f, "invoke_i": invoke_i, "invoke_iiiii": invoke_iiiii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_RWebInputDestroy": _RWebInputDestroy, "_RWebAudioStop": _RWebAudioStop, "_glClearColor": _glClearColor, "_sysconf": _sysconf, "_rand": _rand, "__scanString": __scanString, "_fclose": _fclose, "_RWebAudioInit": _RWebAudioInit, "_glGetVertexAttribPointerv": _glGetVertexAttribPointerv, "_glGetRenderbufferParameteriv": _glGetRenderbufferParameteriv, "_eglDestroySurface": _eglDestroySurface, "_strtoul": _strtoul, "_strtoull": _strtoull, "_glBindTexture": _glBindTexture, "_fflush": _fflush, "_exp": _exp, "_glGetUniformiv": _glGetUniformiv, "_fabsf": _fabsf, "_strtol": _strtol, "_fputc": _fputc, "_glGetString": _glGetString, "_fwrite": _fwrite, "_gluUnProject": _gluUnProject, "_send": _send, "_fputs": _fputs, "_glLineWidth": _glLineWidth, "_glUniform2fv": _glUniform2fv, "_emscripten_get_now": _emscripten_get_now, "_eglCreateContext": _eglCreateContext, "_glBindAttribLocation": _glBindAttribLocation, "_glCompileShader": _glCompileShader, "_isspace": _isspace, "_localtime": _localtime, "_glDeleteTextures": _glDeleteTextures, "_eglBindAPI": _eglBindAPI, "_glCompressedTexImage2D": _glCompressedTexImage2D, "_glStencilFuncSeparate": _glStencilFuncSeparate, "_read": _read, "_RWebAudioBufferSize": _RWebAudioBufferSize, "_glDeleteShader": _glDeleteShader, "_RWebInputInit": _RWebInputInit, "_glClearDepthf": _glClearDepthf, "_glUniform4iv": _glUniform4iv, "_glGetTexParameteriv": _glGetTexParameteriv, "_glClearStencil": _glClearStencil, "_glLoadIdentity": _glLoadIdentity, "_glUniform1fv": _glUniform1fv, "_llvm_pow_f64": _llvm_pow_f64, "_glIsShader": _glIsShader, "_strstr": _strstr, "_glSampleCoverage": _glSampleCoverage, "_fsync": _fsync, "_glGenTextures": _glGenTextures, "_glDepthFunc": _glDepthFunc, "_remove": _remove, "_glCompressedTexSubImage2D": _glCompressedTexSubImage2D, "_glUniform1f": _glUniform1f, "_opendir": _opendir, "_glGetTexParameterfv": _glGetTexParameterfv, "_RWebAudioWrite": _RWebAudioWrite, "_glStencilMaskSeparate": _glStencilMaskSeparate, "_glCreateShader": _glCreateShader, "_round": _round, "_glUniform1i": _glUniform1i, "_strncmp": _strncmp, "_cosf": _cosf, "_glDeleteRenderbuffers": _glDeleteRenderbuffers, "_glLinkProgram": _glLinkProgram, "_snprintf": _snprintf, "_glUniform2i": _glUniform2i, "_fgetc": _fgetc, "_glStencilFunc": _glStencilFunc, "_glShaderSource": _glShaderSource, "_readdir": _readdir, "_glVertexAttribPointer": _glVertexAttribPointer, "_glHint": _glHint, "_glBindBuffer": _glBindBuffer, "_glVertexPointer": _glVertexPointer, "_fgets": _fgets, "_close": _close, "_getgid": _getgid, "_glGetAttachedShaders": _glGetAttachedShaders, "_glBindFramebuffer": _glBindFramebuffer, "_glIsFramebuffer": _glIsFramebuffer, "_strchr": _strchr, "_llvm_bswap_i16": _llvm_bswap_i16, "_glUniform4fv": _glUniform4fv, "_abort": _abort, "___setErrNo": ___setErrNo, "_glDeleteFramebuffers": _glDeleteFramebuffers, "_eglTerminate": _eglTerminate, "_glGetVertexAttribfv": _glGetVertexAttribfv, "_glIsBuffer": _glIsBuffer, "_emscripten_GetProcAddress": _emscripten_GetProcAddress, "_eglGetProcAddress": _eglGetProcAddress, "_ftell": _ftell, "_glDeleteProgram": _glDeleteProgram, "_exit": _exit, "_sprintf": _sprintf, "_glRenderbufferStorage": _glRenderbufferStorage, "_strrchr": _strrchr, "_glAttachShader": _glAttachShader, "_RWebInputPoll": _RWebInputPoll, "_glUniform3i": _glUniform3i, "_glIsProgram": _glIsProgram, "_glCheckFramebufferStatus": _glCheckFramebufferStatus, "__isLeapYear": __isLeapYear, "_gluProject": _gluProject, "_llvm_uadd_with_overflow_i32": _llvm_uadd_with_overflow_i32, "_localtime_r": _localtime_r, "_glUniform3f": _glUniform3f, "_glGetBufferParameteriv": _glGetBufferParameteriv, "_glFlush": _glFlush, "_glBlendEquationSeparate": _glBlendEquationSeparate, "_emscripten_get_canvas_size": _emscripten_get_canvas_size, "_glCopyTexImage2D": _glCopyTexImage2D, "_glDrawElements": _glDrawElements, "_glColorMask": _glColorMask, "_sinf": _sinf, "_gluLookAt": _gluLookAt, "_eglInitialize": _eglInitialize, "_recv": _recv, "__parseInt64": __parseInt64, "_glVertexAttrib1fv": _glVertexAttrib1fv, "_glUniform2iv": _glUniform2iv, "_cos": _cos, "_putchar": _putchar, "_glUniform1iv": _glUniform1iv, "_glActiveTexture": _glActiveTexture, "_glMatrixMode": _glMatrixMode, "_glBlendEquation": _glBlendEquation, "_strcmp": _strcmp, "_glVertexAttrib1f": _glVertexAttrib1f, "_RWebAudioWriteAvail": _RWebAudioWriteAvail, "_glGenerateMipmap": _glGenerateMipmap, "_memchr": _memchr, "_glDetachShader": _glDetachShader, "_glGetShaderiv": _glGetShaderiv, "__exit": __exit, "_strftime": _strftime, "_glVertexAttrib3f": _glVertexAttrib3f, "_glGenRenderbuffers": _glGenRenderbuffers, "_tzset": _tzset, "_RWebAudioSampleRate": _RWebAudioSampleRate, "_glGetShaderPrecisionFormat": _glGetShaderPrecisionFormat, "_glVertexAttrib4fv": _glVertexAttrib4fv, "_glDepthMask": _glDepthMask, "_glDisableVertexAttribArray": _glDisableVertexAttribArray, "_glBegin": _glBegin, "_toupper": _toupper, "_printf": _printf, "_glBindRenderbuffer": _glBindRenderbuffer, "_pread": _pread, "_fopen": _fopen, "_open": _open, "_glDrawArrays": _glDrawArrays, "_usleep": _usleep, "_llvm_pow_f32": _llvm_pow_f32, "__arraySum": __arraySum, "_glCopyTexSubImage2D": _glCopyTexSubImage2D, "_glDisable": _glDisable, "_puts": _puts, "_glUniform4i": _glUniform4i, "_exp2": _exp2, "_nanosleep": _nanosleep, "_glClear": _glClear, "_qsort": _qsort, "_glUniform2f": _glUniform2f, "_eglDestroyContext": _eglDestroyContext, "_isalpha": _isalpha, "_glEnableVertexAttribArray": _glEnableVertexAttribArray, "_rmdir": _rmdir, "_glUniform3fv": _glUniform3fv, "_glStencilOp": _glStencilOp, "_strdup": _strdup, "_glDepthRange": _glDepthRange, "_glUniform4f": _glUniform4f, "_glFramebufferTexture2D": _glFramebufferTexture2D, "_glUniformMatrix2fv": _glUniformMatrix2fv, "_glGenVertexArrays": _glGenVertexArrays, "_eglMakeCurrent": _eglMakeCurrent, "_glUniformMatrix3fv": _glUniformMatrix3fv, "_glutCreateWindow": _glutCreateWindow, "_glBufferData": _glBufferData, "_glBlendColor": _glBlendColor, "_glGetUniformLocation": _glGetUniformLocation, "_glIsEnabled": _glIsEnabled, "__formatString": __formatString, "_getenv": _getenv, "_glGetError": _glGetError, "_glGetVertexAttribiv": _glGetVertexAttribiv, "_glTexParameteriv": _glTexParameteriv, "_glGetProgramiv": _glGetProgramiv, "_glVertexAttrib3fv": _glVertexAttrib3fv, "_glGetFloatv": _glGetFloatv, "_glBufferSubData": _glBufferSubData, "_glUniform3iv": _glUniform3iv, "_glReadPixels": _glReadPixels, "_glGenFramebuffers": _glGenFramebuffers, "_glFramebufferRenderbuffer": _glFramebufferRenderbuffer, "_emscripten_procAddressTable": _emscripten_procAddressTable, "_ceil": _ceil, "___errno_location": ___errno_location, "_glGetIntegerv": _glGetIntegerv, "_RWebAudioFree": _RWebAudioFree, "_llvm_lifetime_start": _llvm_lifetime_start, "_glIsRenderbuffer": _glIsRenderbuffer, "_llvm_bswap_i32": _llvm_bswap_i32, "_sbrk": _sbrk, "__parseInt": __parseInt, "_RWebAudioSetNonblockState": _RWebAudioSetNonblockState, "_glVertexAttrib2fv": _glVertexAttrib2fv, "_glGetFramebufferAttachmentParameteriv": _glGetFramebufferAttachmentParameteriv, "_glUseProgram": _glUseProgram, "_sscanf": _sscanf, "_glTexImage2D": _glTexImage2D, "_glGetProgramInfoLog": _glGetProgramInfoLog, "_glTexSubImage2D": _glTexSubImage2D, "_glStencilMask": _glStencilMask, "_fread": _fread, "_glStencilOpSeparate": _glStencilOpSeparate, "_strtok_r": _strtok_r, "_glGetShaderInfoLog": _glGetShaderInfoLog, "_glIsTexture": _glIsTexture, "_eglCreateWindowSurface": _eglCreateWindowSurface, "_fprintf": _fprintf, "_glGetShaderSource": _glGetShaderSource, "_gluPerspective": _gluPerspective, "_eglChooseConfig": _eglChooseConfig, "___buildEnvironment": ___buildEnvironment, "_feof": _feof, "__addDays": __addDays, "_glScissor": _glScissor, "_glEnable": _glEnable, "_glBlendFuncSeparate": _glBlendFuncSeparate, "_floor": _floor, "__reallyNegative": __reallyNegative, "_glGetActiveAttrib": _glGetActiveAttrib, "_fseek": _fseek, "_sqrt": _sqrt, "_glTexParameterfv": _glTexParameterfv, "_write": _write, "_glGenBuffers": _glGenBuffers, "_glFinish": _glFinish, "_glGetAttribLocation": _glGetAttribLocation, "_glVertexAttrib4f": _glVertexAttrib4f, "_rewind": _rewind, "_sin": _sin, "_glBlendFunc": _glBlendFunc, "_glCreateProgram": _glCreateProgram, "_realpath": _realpath, "_stat": _stat, "_longjmp": _longjmp, "_glViewport": _glViewport, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_time": _time, "_glVertexAttrib2f": _glVertexAttrib2f, "_closedir": _closedir, "_isgraph": _isgraph, "_readlink": _readlink, "_log": _log, "_glGetUniformfv": _glGetUniformfv, "_unlink": _unlink, "_gluOrtho2D": _gluOrtho2D, "_glUniformMatrix4fv": _glUniformMatrix4fv, "_glClearDepth": _glClearDepth, "_glGetActiveUniform": _glGetActiveUniform, "_glutDestroyWindow": _glutDestroyWindow, "_pwrite": _pwrite, "__isFloat": __isFloat, "_fabs": _fabs, "_glTexParameterf": _glTexParameterf, "_RWebAudioStart": _RWebAudioStart, "_glTexParameteri": _glTexParameteri, "_glFrontFace": _glFrontFace, "_glCullFace": _glCullFace, "_glDepthRangef": _glDepthRangef, "_glDeleteBuffers": _glDeleteBuffers, "_eglGetDisplay": _eglGetDisplay, "_emscripten_set_canvas_size": _emscripten_set_canvas_size, "_glGetBooleanv": _glGetBooleanv, "_eglQuerySurface": _eglQuerySurface, "_glPixelStorei": _glPixelStorei, "_readdir_r": _readdir_r, "_glValidateProgram": _glValidateProgram, "_glPolygonOffset": _glPolygonOffset, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stdout": _stdout, "_stderr": _stderr }, buffer);
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var _strncpy = Module["_strncpy"] = asm["_strncpy"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _strncasecmp = Module["_strncasecmp"] = asm["_strncasecmp"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strcasecmp = Module["_strcasecmp"] = asm["_strcasecmp"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_vif = Module["dynCall_vif"] = asm["dynCall_vif"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_viffff = Module["dynCall_viffff"] = asm["dynCall_viffff"];
var dynCall_if = Module["dynCall_if"] = asm["dynCall_if"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiiif = Module["dynCall_viiiiif"] = asm["dynCall_viiiiif"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_vifff = Module["dynCall_vifff"] = asm["dynCall_vifff"];
var dynCall_fii = Module["dynCall_fii"] = asm["dynCall_fii"];
var dynCall_iiif = Module["dynCall_iiif"] = asm["dynCall_iiif"];
var dynCall_viff = Module["dynCall_viff"] = asm["dynCall_viff"];
var dynCall_iif = Module["dynCall_iif"] = asm["dynCall_iif"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_ff = Module["dynCall_ff"] = asm["dynCall_ff"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_f = Module["dynCall_f"] = asm["dynCall_f"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };
// TODO: strip out parts of this we do not need
//======= begin closure i64 code =======
// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */
var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };
  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.
    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };
  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.
  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};
  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };
  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };
  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };
  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };
  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.
  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;
  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);
  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);
  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };
  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };
  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (this.isZero()) {
      return '0';
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }
    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };
  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };
  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };
  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };
  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };
  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };
  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };
  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };
  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };
  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };
  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };
  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);
      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };
  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };
  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };
  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };
  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };
  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };
  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };
  //======= begin jsbn =======
  var navigator = { appName: 'Modern Browser' }; // polyfill a little
  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/
  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */
  // Basic JavaScript BN library - subset useful for RSA encryption.
  // Bits per digit
  var dbits;
  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);
  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }
  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }
  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.
  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;
  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }
  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }
  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }
  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }
  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }
  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }
  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }
  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }
  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }
  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }
  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }
  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }
  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }
  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }
  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }
  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }
  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }
  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }
  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }
  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }
  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }
  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }
  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }
  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }
  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }
  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  // jsbn2 stuff
  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }
  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }
  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }
  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }
  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }
  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  //======= end jsbn =======
  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();
//======= end closure i64 code =======
// === Auto-generated postamble setup entry stuff ===
function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;
var initialStackTop;
var preloadStartTime = null;
Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
    Module.printErr('preload time: ' + (Date.now() - preloadStartTime) + ' ms');
  }
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);
  initialStackTop = STACKTOP;
  try {
    var ret = Module['_main'](argc, argv, 0);
    // if we're not running an evented main loop, it's time to exit
    if (!Module['noExitRuntime']) {
      exit(ret);
    }
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      throw e;
    }
  }
}
function run(args) {
  args = args || Module['arguments'];
  if (preloadStartTime === null) preloadStartTime = Date.now();
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }
  preRun();
  if (runDependencies > 0) {
    // a preRun added a dependency, run will be called later
    return;
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    calledRun = true;
    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }
    postRun();
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;
function exit(status) {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;
  // exit the runtime
  exitRuntime();
  // throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;
function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }
  ABORT = true;
  EXITSTATUS = 1;
  throw 'abort() at ' + (new Error().stack);
}
Module['abort'] = Module.abort = abort;
// {{PRE_RUN_ADDITIONS}}
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run();
// {{POST_RUN_ADDITIONS}}
// {{MODULE_ADDITIONS}}
