// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = eval('(function() { try { return Module || {} } catch(e) { return {} } })()');
// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function(filename) { return Module['read'](filename, true) };
  Module['load'] = function(f) {
    globalEval(read(f));
  };
  Module['arguments'] = process['argv'].slice(2);
  module.exports = Module;
}
else if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function() { throw 'no read() available (jsc?)' };
  }
  Module['readBinary'] = function(f) {
    return read(f, 'binary');
  };
  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  this['Module'] = Module;
}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  if (ENVIRONMENT_IS_WEB) {
    Module['print'] = function(x) {
      console.log(x);
    };
    Module['printErr'] = function(x) {
      console.log(x);
    };
    this['Module'] = Module;
  } else if (ENVIRONMENT_IS_WORKER) {
    // We can do very little here...
    var TRY_USE_DUMP = false;
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];
// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (type == 'i64' || type == 'double' || vararg) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    var index = 0;
    type.flatIndexes = type.fields.map(function(field) {
      index++;
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        if (field[1] === '0') {
          // this is [0 x something]. When inside another structure like here, it must be at the end,
          // and it adds no size
          // XXX this happens in java-nbody for example... assert(index === type.fields.length, 'zero-length in the middle!');
          size = 0;
          alignSize = type.alignSize || QUANTUM_SIZE;
        } else {
          size = Types.types[field].flatSize;
          alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
        }
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2 + 2*i;
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;
      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }
      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          Math.floor((codePoint - 0x10000) / 0x400) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+7)>>3)<<3); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+7)>>3)<<3); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = ((((DYNAMICTOP)+7)>>3)<<3); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>(0))))+((+(((high)>>>(0))))*(+(4294967296)))) : ((+(((low)>>>(0))))+((+(((high)|(0))))*(+(4294967296))))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = Module['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value, or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 67108864;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited
var runtimeInitialized = false;
function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}
function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;
function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;
function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;
function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;
function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math['imul']) Math['imul'] = function(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledInit = false, calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
function loadMemoryInitializer(filename) {
  function applyData(data) {
    HEAPU8.set(data, STATIC_BASE);
  }
  // always do this asynchronously, to keep shell and web as similar as possible
  addOnPreRun(function() {
    if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
      applyData(Module['readBinary'](filename));
    } else {
      Browser.asyncLoad(filename, function(data) {
        applyData(data);
      }, function(data) {
        throw 'could not load memory initializer ' + filename;
      });
    }
  });
}
// === Body ===
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 683096;
var _stdout;
var _stdin;
var _stderr;
/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } },{ func: function() { __GLOBAL__I_a() } });
var ___fsmu8;
var ___dso_handle;
var __ZTVN10__cxxabiv120__si_class_type_infoE;
var __ZTVN10__cxxabiv117__class_type_infoE;
var _stdout = _stdout=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stdin = _stdin=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stderr = _stderr=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
__ZTVN10__cxxabiv120__si_class_type_infoE=allocate([0,0,0,0,248,241,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
__ZTVN10__cxxabiv117__class_type_infoE=allocate([0,0,0,0,8,242,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,54,0,0,0,10,0,0,0,56,0,0,0,14,0,0,0,108,0,0,0,26,0,0,0,18,1,0,0,112,141,0,0,52,0,0,0,2,0,0,0,8,0,0,0,150,0,0,0,30,0,0,0,186,0,0,0,124,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,160,171,4,0,96,180,4,0,1,1,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,0,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,13,0,0,0,15,0,0,0,17,0,0,0,19,0,0,0,23,0,0,0,27,0,0,0,31,0,0,0,35,0,0,0,43,0,0,0,51,0,0,0,59,0,0,0,67,0,0,0,83,0,0,0,99,0,0,0,115,0,0,0,131,0,0,0,163,0,0,0,195,0,0,0,227,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,13,0,0,0,17,0,0,0,25,0,0,0,33,0,0,0,49,0,0,0,65,0,0,0,97,0,0,0,129,0,0,0,193,0,0,0,1,1,0,0,129,1,0,0,1,2,0,0,1,3,0,0,1,4,0,0,1,6,0,0,1,8,0,0,1,12,0,0,1,16,0,0,1,24,0,0,1,32,0,0,1,48,0,0,1,64,0,0,1,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,96,223,0,0,0,0,0,0,64,223,0,0,1,0,0,0,24,108,0,0,2,0,0,0,184,106,0,0,3,0,0,0,40,105,0,0,4,0,0,0,136,103,0,0,5,0,0,0,80,102,0,0,6,0,0,0,176,100,0,0,7,0,0,0,104,223,0,0,8,0,0,0,72,223,0,0,9,0,0,0,88,223,0,0,10,0,0,0,136,43,0,0,11,0,0,0,224,91,0,0,12,0,0,0,200,90,0,0,13,0,0,0,240,89,0,0,14,0,0,0,176,88,0,0,15,0,0,0,208,87,0,0,16,0,0,0,192,86,0,0,17,0,0,0,40,86,0,0,18,0,0,0,224,83,0,0,19,0,0,0,104,81,0,0,20,0,0,0,232,79,0,0,21,0,0,0,48,78,0,0,22,0,0,0,136,77,0,0,23,0,0,0,64,77,0,0,24,0,0,0,240,76,0,0,25,0,0,0,88,76,0,0,26,0,0,0,168,75,0,0,27,0,0,0,56,75,0,0,28,0,0,0,96,74,0,0,29,0,0,0,184,72,0,0,30,0,0,0,248,71,0,0,31,0,0,0,72,71,0,0,32,0,0,0,128,70,0,0,33,0,0,0,232,69,0,0,34,0,0,0,40,69,0,0,35,0,0,0,96,68,0,0,36,0,0,0,96,67,0,0,37,0,0,0,152,66,0,0,38,0,0,0,208,65,0,0,39,0,0,0,24,64,0,0,40,0,0,0,40,63,0,0,41,0,0,0,32,62,0,0,42,0,0,0,56,61,0,0,43,0,0,0,184,60,0,0,44,0,0,0,40,60,0,0,45,0,0,0,160,59,0,0,46,0,0,0,224,58,0,0,47,0,0,0,32,58,0,0,48,0,0,0,128,57,0,0,49,0,0,0,136,55,0,0,50,0,0,0,168,54,0,0,51,0,0,0,96,53,0,0,52,0,0,0,184,52,0,0,53,0,0,0,32,52,0,0,54,0,0,0,136,51,0,0,55,0,0,0,2,0,0,0,194,0,0,0,90,0,0,0,168,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,111,114,109,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,56,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,55,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,2,0,0,0,1,1,0,0,4,1,0,0,4,2,0,0,4,3,0,0,4,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,3,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,160,171,4,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,9,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,144,158,0,0,144,94,8,0,48,188,0,0,152,94,8,0,216,139,0,0,80,94,8,0,192,111,0,0,32,94,8,0,16,94,0,0,64,94,8,0,240,81,0,0,0,94,8,0,240,72,0,0,120,94,8,0,96,64,0,0,16,94,8,0,208,55,0,0,8,94,8,0,48,47,0,0,192,94,8,0,120,203,0,0,208,94,8,0,224,193,0,0,200,94,8,0,32,185,0,0,136,94,8,0,112,179,0,0,216,94,8,0,80,175,0,0,160,94,8,0,216,169,0,0,128,94,8,0,152,164,0,0,72,94,8,0,184,160,0,0,176,94,8,0,168,156,0,0,168,94,8,0,64,153,0,0,184,94,8,0,104,149,0,0,112,94,8,0,160,144,0,0,24,94,8,0,8,137,0,0,40,94,8,0,224,131,0,0,56,94,8,0,200,127,0,0,104,94,8,0,144,125,0,0,48,94,8,0,144,122,0,0,96,94,8,0,0,120,0,0,88,94,8,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,72,170,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,136,169,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,200,168,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,216,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,136,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,32,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,168,166,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,120,166,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,64,166,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,240,165,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,224,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,80,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,8,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,120,163,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,240,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,200,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,144,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,88,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,40,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,224,161,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,232,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,112,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,224,159,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,80,159,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,32,159,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,72,170,0,0,122,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,136,169,0,0,97,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,200,168,0,0,47,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,216,167,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,136,167,0,0,17,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,32,167,0,0,18,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,168,166,0,0,20,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,120,166,0,0,19,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,64,166,0,0,120,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,240,165,0,0,115,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,224,164,0,0,113,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,80,164,0,0,119,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,8,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,120,163,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,240,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,200,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,144,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,88,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,40,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,224,161,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,232,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,112,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,224,159,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,80,159,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,32,159,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,25,0,0,0,0,159,0,0,32,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,26,0,0,0,200,158,0,0,108,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,27,0,0,0,8,172,0,0,29,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,28,0,0,0,128,172,0,0,27,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,29,0,0,0,40,158,0,0,102,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,30,0,0,0,24,157,0,0,27,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,31,0,0,0,128,156,0,0,32,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,32,0,0,0,56,156,0,0,31,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,33,0,0,0,48,203,0,0,114,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,34,0,0,0,80,155,0,0,111,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,35,0,0,0,32,155,0,0,112,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,36,0,0,0,216,154,0,0,107,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,37,0,0,0,160,154,0,0,104,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,38,0,0,0,104,154,0,0,109,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,39,0,0,0,32,154,0,0,110,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,40,0,0,0,160,153,0,0,121,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,41,0,0,0,240,152,0,0,116,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,42,0,0,0,144,152,0,0,117,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,43,0,0,0,240,151,0,0,33,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,44,0,0,0,176,151,0,0,99,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,45,0,0,0,144,42,0,0,34,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,46,0,0,0,96,151,0,0,105,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,47,0,0,0,72,151,0,0,101,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,48,0,0,0,0,151,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,49,0,0,0,200,150,0,0,14,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,50,0,0,0,200,149,0,0,13,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,51,0,0,0,80,149,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,52,0,0,0,232,148,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,53,0,0,0,72,148,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,54,0,0,0,24,196,0,0,36,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,55,0,0,0,208,147,0,0,26,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,37,0,0,0,20,1,0,0,39,0,0,0,19,1,0,0,38,0,0,0,17,1,0,0,40,0,0,0,18,1,0,0,13,0,0,0,13,0,0,0,9,0,0,0,9,0,0,0,45,0,0,0,21,1,0,0,46,0,0,0,127,0,0,0,16,0,0,0,47,1,0,0,16,0,0,0,48,1,0,0,17,0,0,0,50,1,0,0,35,0,0,0,23,1,0,0,36,0,0,0,22,1,0,0,34,0,0,0,25,1,0,0,33,0,0,0,24,1,0,0,18,0,0,0,52,1,0,0,32,0,0,0,32,0,0,0,27,0,0,0,27,0,0,0,8,0,0,0,8,0,0,0,13,0,0,0,15,1,0,0,107,0,0,0,14,1,0,0,109,0,0,0,13,1,0,0,106,0,0,0,12,1,0,0,111,0,0,0,11,1,0,0,192,0,0,0,96,0,0,0,19,0,0,0,19,0,0,0,96,0,0,0,0,1,0,0,97,0,0,0,1,1,0,0,98,0,0,0,2,1,0,0,99,0,0,0,3,1,0,0,100,0,0,0,4,1,0,0,101,0,0,0,5,1,0,0,102,0,0,0,6,1,0,0,103,0,0,0,7,1,0,0,104,0,0,0,8,1,0,0,105,0,0,0,9,1,0,0,48,0,0,0,48,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,50,0,0,0,51,0,0,0,51,0,0,0,52,0,0,0,52,0,0,0,53,0,0,0,53,0,0,0,54,0,0,0,54,0,0,0,55,0,0,0,55,0,0,0,56,0,0,0,56,0,0,0,57,0,0,0,57,0,0,0,112,0,0,0,26,1,0,0,113,0,0,0,27,1,0,0,114,0,0,0,28,1,0,0,115,0,0,0,29,1,0,0,116,0,0,0,30,1,0,0,117,0,0,0,31,1,0,0,118,0,0,0,32,1,0,0,119,0,0,0,33,1,0,0,120,0,0,0,34,1,0,0,121,0,0,0,35,1,0,0,122,0,0,0,36,1,0,0,123,0,0,0,37,1,0,0,65,0,0,0,97,0,0,0,66,0,0,0,98,0,0,0,67,0,0,0,99,0,0,0,68,0,0,0,100,0,0,0,69,0,0,0,101,0,0,0,70,0,0,0,102,0,0,0,71,0,0,0,103,0,0,0,72,0,0,0,104,0,0,0,73,0,0,0,105,0,0,0,74,0,0,0,106,0,0,0,75,0,0,0,107,0,0,0,76,0,0,0,108,0,0,0,77,0,0,0,109,0,0,0,78,0,0,0,110,0,0,0,79,0,0,0,111,0,0,0,80,0,0,0,112,0,0,0,81,0,0,0,113,0,0,0,82,0,0,0,114,0,0,0,83,0,0,0,115,0,0,0,84,0,0,0,116,0,0,0,85,0,0,0,117,0,0,0,86,0,0,0,118,0,0,0,87,0,0,0,119,0,0,0,88,0,0,0,120,0,0,0,89,0,0,0,121,0,0,0,90,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,184,162,0,0,240,158,0,0,8,181,0,0,152,181,0,0,192,147,0,0,96,141,0,0,104,134,0,0,232,129,0,0,72,126,0,0,16,124,0,0,64,122,0,0,216,108,0,0,16,180,0,0,48,179,0,0,208,178,0,0,136,178,0,0,0,0,0,0,0,0,36,64,0,0,0,0,0,0,89,64,0,0,0,0,0,136,195,64,0,0,0,0,132,215,151,65,0,128,224,55,121,195,65,67,23,110,5,181,181,184,147,70,245,249,63,233,3,79,56,77,50,29,48,249,72,119,130,90,60,191,115,127,221,79,21,117,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,137,80,78,71,13,10,26,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,171,4,0,96,180,4,0,32,189,4,0,224,197,4,0,160,206,4,0,96,215,4,0,32,224,4,0,224,232,4,0,14,0,0,0,248,0,0,0,2,0,0,0,4,0,0,0,28,0,0,0,0,0,0,0,200,201,0,0,12,0,0,0,80,102,0,0,20,1,0,0,176,100,0,0,19,1,0,0,40,105,0,0,17,1,0,0,136,103,0,0,18,1,0,0,200,191,0,0,13,0,0,0,104,190,0,0,15,1,0,0,136,197,0,0,9,0,0,0,16,189,0,0,21,1,0,0,40,188,0,0,127,0,0,0,88,187,0,0,23,1,0,0,216,186,0,0,22,1,0,0,104,186,0,0,47,1,0,0,248,184,0,0,48,1,0,0,104,184,0,0,50,1,0,0,16,183,0,0,52,1,0,0,32,193,0,0,32,0,0,0,56,182,0,0,27,0,0,0,192,181,0,0,14,1,0,0,88,181,0,0,13,1,0,0,232,180,0,0,14,1,0,0,184,180,0,0,13,1,0,0,136,180,0,0,26,1,0,0,80,179,0,0,27,1,0,0,224,178,0,0,28,1,0,0,152,178,0,0,29,1,0,0,96,178,0,0,30,1,0,0,48,178,0,0,31,1,0,0,128,177,0,0,32,1,0,0,64,177,0,0,33,1,0,0,16,177,0,0,34,1,0,0,208,176,0,0,35,1,0,0,136,176,0,0,36,1,0,0,32,175,0,0,37,1,0,0,160,174,0,0,48,0,0,0,32,174,0,0,49,0,0,0,192,173,0,0,50,0,0,0,80,173,0,0,51,0,0,0,160,172,0,0,52,0,0,0,80,172,0,0,53,0,0,0,176,171,0,0,54,0,0,0,88,171,0,0,55,0,0,0,0,171,0,0,56,0,0,0,208,169,0,0,57,0,0,0,80,169,0,0,24,1,0,0,80,168,0,0,25,1,0,0,208,167,0,0,0,1,0,0,128,167,0,0,1,1,0,0,200,166,0,0,2,1,0,0,192,166,0,0,3,1,0,0,144,166,0,0,4,1,0,0,88,166,0,0,5,1,0,0,16,166,0,0,6,1,0,0,216,165,0,0,7,1,0,0,112,164,0,0,8,1,0,0,32,164,0,0,9,1,0,0,104,46,0,0,46,0,0,0,48,163,0,0,45,1,0,0,224,162,0,0,44,1,0,0,88,86,0,0,8,0,0,0,120,162,0,0,12,1,0,0,56,162,0,0,11,1,0,0,240,161,0,0,60,1,0,0,184,161,0,0,46,1,0,0,96,195,0,0,96,0,0,0,248,159,0,0,96,0,0,0,144,159,0,0,19,0,0,0,56,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,96,223,0,0,224,117,0,0,0,0,0,0,1,0,0,0,0,0,0,0,64,223,0,0,48,87,0,0,1,0,0,0,1,0,0,0,0,0,0,0,24,108,0,0,112,67,0,0,2,0,0,0,1,0,0,0,0,0,0,0,184,106,0,0,80,50,0,0,3,0,0,0,1,0,0,0,0,0,0,0,40,105,0,0,40,199,0,0,4,0,0,0,1,0,0,0,0,0,0,0,136,103,0,0,240,180,0,0,5,0,0,0,1,0,0,0,0,0,0,0,80,102,0,0,248,171,0,0,6,0,0,0,1,0,0,0,0,0,0,0,176,100,0,0,104,162,0,0,7,0,0,0,1,0,0,0,0,0,0,0,104,223,0,0,168,154,0,0,8,0,0,0,1,0,0,0,0,0,0,0,72,223,0,0,80,147,0,0,9,0,0,0,1,0,0,0,0,0,0,0,88,223,0,0,168,133,0,0,10,0,0,0,1,0,0,0,0,0,0,0,136,43,0,0,32,126,0,0,11,0,0,0,1,0,0,0,0,0,0,0,224,91,0,0,168,120,0,0,12,0,0,0,1,0,0,0,0,0,0,0,200,90,0,0,168,117,0,0,13,0,0,0,1,0,0,0,0,0,0,0,240,89,0,0,0,115,0,0,14,0,0,0,1,0,0,0,0,0,0,0,176,88,0,0,168,109,0,0,15,0,0,0,1,0,0,0,0,0,0,0,208,87,0,0,192,106,0,0,16,0,0,0,1,0,0,0,0,0,0,0,192,86,0,0,168,103,0,0,17,0,0,0,1,0,0,0,0,0,0,0,40,86,0,0,240,100,0,0,18,0,0,0,1,0,0,0,0,0,0,0,224,83,0,0,224,97,0,0,19,0,0,0,1,0,0,0,0,0,0,0,104,81,0,0,232,92,0,0,20,0,0,0,1,0,0,0,0,0,0,0,232,79,0,0,16,91,0,0,21,0,0,0,1,0,0,0,0,0,0,0,48,78,0,0,216,88,0,0,22,0,0,0,1,0,0,0,0,0,0,0,136,77,0,0,216,86,0,0,23,0,0,0,1,0,0,0,0,0,0,0,64,77,0,0,208,84,0,0,24,0,0,0,1,0,0,0,1,0,0,0,240,76,0,0,0,80,0,0,25,0,0,0,1,0,0,0,2,0,0,0,88,76,0,0,192,77,0,0,26,0,0,0,1,0,0,0,1,0,0,0,168,75,0,0,16,77,0,0,27,0,0,0,1,0,0,0,1,0,0,0,56,75,0,0,208,75,0,0,28,0,0,0,1,0,0,0,2,0,0,0,96,74,0,0,224,74,0,0,29,0,0,0,1,0,0,0,2,0,0,0,184,72,0,0,48,169,0,0,30,0,0,0,1,0,0,0,2,0,0,0,248,71,0,0,184,70,0,0,31,0,0,0,1,0,0,0,2,0,0,0,72,71,0,0,80,69,0,0,32,0,0,0,1,0,0,0,1,0,0,0,128,70,0,0,48,203,0,0,33,0,0,0,1,0,0,0,2,0,0,0,232,69,0,0,8,66,0,0,34,0,0,0,1,0,0,0,2,0,0,0,40,69,0,0,104,63,0,0,35,0,0,0,1,0,0,0,2,0,0,0,96,68,0,0,96,61,0,0,36,0,0,0,1,0,0,0,2,0,0,0,96,67,0,0,72,60,0,0,37,0,0,0,1,0,0,0,2,0,0,0,152,66,0,0,16,59,0,0,38,0,0,0,1,0,0,0,2,0,0,0,208,65,0,0,200,57,0,0,39,0,0,0,1,0,0,0,2,0,0,0,24,64,0,0,208,54,0,0,40,0,0,0,1,0,0,0,2,0,0,0,40,63,0,0,224,52,0,0,41,0,0,0,1,0,0,0,2,0,0,0,32,62,0,0,168,51,0,0,42,0,0,0,1,0,0,0,2,0,0,0,56,61,0,0,40,50,0,0,43,0,0,0,1,0,0,0,2,0,0,0,184,60,0,0,232,48,0,0,44,0,0,0,1,0,0,0,2,0,0,0,40,60,0,0,16,46,0,0,45,0,0,0,1,0,0,0,2,0,0,0,160,59,0,0,200,44,0,0,46,0,0,0,1,0,0,0,2,0,0,0,224,58,0,0,192,43,0,0,47,0,0,0,1,0,0,0,2,0,0,0,32,58,0,0,224,42,0,0,48,0,0,0,1,0,0,0,2,0,0,0,128,57,0,0,184,205,0,0,49,0,0,0,1,0,0,0,2,0,0,0,136,55,0,0,200,202,0,0,50,0,0,0,1,0,0,0,2,0,0,0,168,54,0,0,184,201,0,0,51,0,0,0,1,0,0,0,2,0,0,0,96,53,0,0,72,200,0,0,52,0,0,0,1,0,0,0,2,0,0,0,184,52,0,0,112,198,0,0,53,0,0,0,1,0,0,0,2,0,0,0,32,52,0,0,24,196,0,0,54,0,0,0,1,0,0,0,1,0,0,0,136,51,0,0,136,192,0,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,92,8,0,168,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,184,0,0,0,6,0,0,0,64,161,0,0,0,0,0,0,88,0,0,0,28,0,0,0,154,0,0,0,226,0,0,0,6,0,0,0,8,0,0,0,68,0,0,0,86,0,0,0,0,0,0,0,84,0,0,0,14,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,2,0,0,0,116,0,0,0,16,0,0,0,2,0,0,0,34,0,0,0,16,0,0,0,44,0,0,0,216,0,0,0,106,0,0,0,176,0,0,0,98,0,0,0,24,0,0,0,2,0,0,0,152,48,0,0,2,0,0,0,56,48,0,0,0,0,0,0,36,48,0,0,8,0,0,0,35,48,0,0,8,0,0,0,34,48,0,0,8,0,0,0,33,48,0,0,8,0,0,0,51,48,0,0,4,0,0,0,56,48,0,0,0,0,0,0,28,0,0,0,54,0,0,0,4,0,0,0,120,0,0,0,30,0,0,0,52,0,0,0,2,0,0,0,28,0,0,0,6,0,0,0,2,0,0,0,26,0,0,0,42,0,0,0,26,0,0,0,228,0,0,0,104,0,0,0,2,0,0,0,0,0,0,0,136,160,0,0,0,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,192,0,0,24,52,0,0,184,178,0,0,0,0,0,0,0,0,0,0,100,16,183,29,200,32,110,59,172,48,217,38,144,65,220,118,244,81,107,107,88,97,178,77,60,113,5,80,32,131,184,237,68,147,15,240,232,163,214,214,140,179,97,203,176,194,100,155,212,210,211,134,120,226,10,160,28,242,189,189,0,0,0,0,255,0,0,0,85,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,160,111,0,0,2,0,0,0,8,94,0,0,3,0,0,0,232,81,0,0,5,0,0,0,232,72,0,0,4,0,0,0,160,171,4,0,96,180,4,0,32,189,4,0,224,197,4,0,160,206,4,0,96,215,4,0,32,224,4,0,224,232,4,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,106,0,0,0,134,0,0,0,90,1,0,0,2,0,0,0,208,175,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,16,66,8,32,0,0,74,41,0,0,0,0,0,0,168,175,212,87,0,0,128,248,226,232,35,0,0,0,136,170,168,138,0,0,192,164,100,82,116,0,0,132,16,0,0,0,0,0,136,8,33,132,32,8,0,130,32,132,16,34,2,0,0,144,234,42,1,0,0,0,16,242,9,1,0,0,0,0,0,0,32,2,0,0,0,240,1,0,0,0,0,0,0,0,32,0,0,16,34,68,136,16,1,0,192,197,88,99,116,0,0,128,24,66,8,113,0,0,192,69,200,68,248,0,0,192,69,200,96,116,0,0,0,49,149,62,66,0,0,224,135,240,96,116,0,0,128,137,240,98,116,0,0,224,67,132,8,17,0,0,192,197,232,98,116,0,0,192,197,232,33,50,0,0,0,0,2,0,1,0,0,0,0,2,0,17,0,0,0,64,54,24,4,0,0,0,128,15,62,0,0,0,0,4,131,77,0,0,0,192,69,136,8,32,0,0,192,135,214,122,240,0,0,128,16,165,92,140,0,0,224,197,248,98,124,0,0,192,197,16,66,116,0,0,224,164,24,99,58,0,0,224,135,240,66,248,0,0,224,135,240,66,8,0,0,192,197,144,99,244,0,0,32,198,248,99,140,0,0,192,17,66,8,113,0,0,128,67,8,33,124,0,0,32,166,50,74,138,0,0,32,132,16,66,248,0,0,32,198,189,107,141,0,0,96,206,90,107,206,0,0,192,197,24,99,116,0,0,224,197,248,66,8,0,0,192,197,24,99,246,0,0,224,197,248,98,140,0,0,192,197,224,96,116,0,0,224,19,66,8,33,0,0,32,198,24,99,116,0,0,32,198,168,20,33,0,0,32,214,90,149,82,0,0,32,70,69,84,140,0,0,32,198,232,8,33,0,0,224,67,68,68,248,0,0,78,8,33,132,16,14,0,33,8,65,8,66,16,0,14,33,132,16,66,14,0,128,168,8,0,0,0,0,0,0,0,0,0,31,0,128,32,0,0,0,0,0,0,0,7,125,244,0,0,33,132,23,99,124,0,0,0,0,31,66,240,0,0,16,66,31,99,244,0,0,0,0,23,127,240,0,0,92,136,39,132,16,0,0,0,0,23,99,244,208,1,33,132,23,99,140,0,0,128,0,67,8,33,0,0,0,1,134,16,66,232,0,66,8,169,140,146,0,0,134,16,66,8,33,0,0,0,128,85,107,173,0,0,0,128,23,99,140,0,0,0,0,23,99,116,0,0,0,128,23,99,124,33,0,0,0,31,99,244,16,2,0,128,54,67,8,0,0,0,0,31,28,124,0,0,64,8,39,132,224,0,0,0,128,24,99,244,0,0,0,128,24,149,34,0,0,0,128,88,171,82,0,0,0,128,168,136,138,0,0,0,128,24,99,244,208,1,0,128,143,136,248,0,0,136,16,34,8,33,8,0,132,16,66,8,33,4,0,130,16,130,8,33,2,0,0,0,96,50,0,0,0,0,0,0,0,0,0,0,63,132,16,66,8,225,3,0,0,0,0,0,0,0,0,0,0,0,64,4,0,152,16,71,8,33,68,0,0,0,0,0,80,10,0,0,0,0,0,168,0,0,132,124,66,8,33,4,0,132,124,242,9,33,4,0,68,1,0,0,0,0,0,0,72,69,84,2,0,0,138,0,31,62,124,0,0,0,0,68,4,65,0,0,192,166,148,83,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,32,0,0,0,0,0,8,17,0,0,0,0,0,74,81,0,0,0,0,0,148,42,0,0,0,0,0,0,0,192,24,0,0,0,0,0,0,62,0,0,0,0,0,0,62,0,0,0,0,0,64,21,0,0,0,0,128,175,149,2,0,0,138,0,31,28,124,0,0,0,0,130,32,34,0,0,0,0,155,114,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,10,196,24,29,33,0,0,0,0,0,0,0,0,0,128,0,66,8,33,0,0,0,32,174,20,71,0,0,152,16,79,68,248,0,0,0,4,47,165,15,0,0,32,70,71,62,33,0,0,132,16,2,8,33,4,0,152,16,23,163,35,100,0,64,1,0,0,0,0,0,192,135,86,90,240,0,0,4,49,197,0,0,0,0,0,0,34,147,36,0,0,0,0,224,33,132,0,0,0,0,0,0,0,0,0,192,135,84,74,240,0,0,224,3,0,0,0,0,0,128,56,2,0,0,0,0,0,16,242,9,249,0,0,6,17,225,0,0,0,0,6,25,100,0,0,0,0,136,0,0,0,0,0,0,0,0,41,165,116,34,0,192,223,107,41,165,148,2,0,0,64,0,0,0,0,0,0,0,0,96,136,0,196,16,226,0,0,0,0,68,41,2,0,0,0,0,0,128,36,137,76,0,0,48,166,68,168,22,1,0,48,166,68,137,148,1,0,81,46,85,168,22,1,0,128,0,130,96,116,0,0,130,0,226,92,140,0,0,68,0,226,92,140,0,0,68,1,226,92,140,0,0,84,1,226,92,140,0,0,64,1,226,92,140,0,0,196,17,226,92,140,0,0,128,59,231,83,202,0,0,192,197,16,66,116,68,0,130,128,31,94,248,0,0,68,128,31,94,248,0,0,68,129,31,94,248,0,0,64,129,31,94,248,0,0,130,0,71,8,113,0,0,68,0,71,8,113,0,0,68,1,71,8,113,0,0,64,1,71,8,113,0,0,192,73,241,132,116,0,0,84,129,89,107,206,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,84,1,23,99,116,0,0,64,1,23,99,116,0,0,0,68,69,84,4,0,0,0,48,169,173,108,0,0,130,128,24,99,116,0,0,68,128,24,99,116,0,0,68,129,24,99,116,0,0,64,129,24,99,116,0,0,136,196,24,29,33,0,0,64,8,39,165,19,2,0,192,73,233,164,116,1,0,130,0,7,125,244,0,0,68,0,7,125,244,0,0,68,1,7,125,244,0,0,84,1,7,125,244,0,0,64,1,7,125,244,0,0,196,17,7,125,244,0,0,0,0,139,124,178,0,0,0,0,31,66,240,68,0,130,0,23,127,240,0,0,68,0,23,127,240,0,0,68,1,23,127,240,0,0,64,1,23,127,240,0,0,130,0,67,8,33,0,0,68,0,67,8,33,0,0,68,1,67,8,33,0,0,64,1,67,8,33,0,0,192,34,232,99,116,0,0,84,129,23,99,140,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,170,0,23,99,116,0,0,64,1,23,99,116,0,0,0,16,240,1,1,0,0,0,48,169,173,108,0,0,130,128,24,99,244,0,0,68,128,24,99,244,0,0,68,129,24,99,244,0,0,64,129,24,99,244,0,0,68,128,24,99,244,208,1,32,132,23,99,124,33,0,64,129,24,99,244,208,1,48,155,0,0,232,154,0,0,192,154,0,0,120,154,0,0,48,154,0,0,248,153,0,0,8,153,0,0,160,152,0,0,16,0,0,0,46,0,0,0,92,0,0,0,162,0,0,0].concat([54,0,0,0,76,0,0,0,8,0,0,0,168,191,0,0,10,0,0,0,28,0,0,0,50,0,0,0,10,0,0,0,236,0,0,0,100,0,0,0,174,0,0,0,152,0,0,0,126,0,0,0,112,174,0,0,0,0,0,0,0,0,0,0,248,39,0,0,32,40,0,0,52,58,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,169,170,63,49,54,58,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,142,227,63,49,54,58,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,205,204,204,63,49,54,58,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,137,136,136,63,67,111,110,102,105,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,113,117,97,114,101,32,112,105,120,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,111,114,101,32,112,114,111,118,105,100,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,117,115,116,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,110,112,117,116,95,100,101,98,117,103,95,101,110,97,98,108,101,0,0,0,0,0,0,74,117,108,0,0,0,0,0,77,117,116,101,32,65,117,100,105,111,0,0,0,0,0,0,115,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,109,111,118,105,101,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,69,110,97,98,108,101,32,104,111,116,107,101,121,115,0,0,105,110,112,117,116,95,100,117,116,121,95,99,121,99,108,101,0,0,0,0,0,0,0,0,74,117,110,0,0,0,0,0,37,100,0,0,0,0,0,0,68,105,115,107,32,73,109,97,103,101,32,65,112,112,101,110,100,0,0,0,0,0,0,0,115,99,97,108,101,95,121,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,117,110,109,117,116,101,32,97,117,100,105,111,46,10,0,0,0,57,48,0,0,0,0,0,0,105,110,112,117,116,95,116,117,114,98,111,95,112,101,114,105,111,100,0,0,0,0,0,0,114,0,0,0,0,0,0,0,65,112,114,0,0,0,0,0,68,105,115,107,32,73,110,100,101,120,0,0,0,0,0,0,115,99,97,108,101,95,120,0,65,117,100,105,111,32,117,110,109,117,116,101,100,46,0,0,83,108,111,119,32,109,111,116,105,111,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,82,79,84,65,84,73,79,78,58,32,37,117,10,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,115,105,122,101,0,0,0,0,0,0,0,77,97,114,0,0,0,0,0,69,115,116,105,109,97,116,101,100,32,77,111,110,105,116,111,114,32,70,80,83,0,0,0,115,99,97,108,101,0,0,0,65,117,100,105,111,32,109,117,116,101,100,46,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,112,97,116,104,0,0,0,0,0,0,0,70,101,98,0,0,0,0,0,67,114,111,112,32,79,118,101,114,115,99,97,110,32,40,114,101,108,111,97,100,41,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,88,77,76,58,32,73,110,118,97,108,105,100,32,112,114,111,112,101,114,116,121,32,102,111,114,32,102,105,108,116,101,114,46,10,0,0,86,111,108,117,109,101,58,32,37,46,49,102,32,100,66,0,78,101,116,112,108,97,121,32,102,108,105,112,32,112,108,97,121,101,114,115,0,0,0,0,115,116,100,105,110,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,61,61,61,10,0,74,97,110,0,0,0,0,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,89,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,76,73,78,69,65,82,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,100,106,117,115,116,105,110,103,32,97,115,112,101,99,116,32,114,97,116,105,111,32,116,111,32,37,46,50,102,10,0,0,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,112,111,114,116,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,45,37,109,37,100,45,37,72,37,77,37,83,46,0,0,68,101,99,101,109,98,101,114,0,0,0,0,0,0,0,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,88,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,78,69,65,82,69,83,84,46,10,0,0,0,0,0,0,65,117,100,105,111,32,109,117,116,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,112,101,114,105,111,100,0,0,78,111,118,101,109,98,101,114,0,0,0,0,0,0,0,0,86,83,121,110,99,32,83,119,97,112,32,73,110,116,101,114,118,97,108,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,76,85,84,32,102,105,108,116,101,114,32,116,121,112,101,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,98,32,109,111,117,115,101,32,115,116,97,116,101,58,32,37,115,46,10,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,108,111,99,97,108,101,32,102,111,114,32,115,116,97,110,100,97,114,100,32,105,110,112,117,116,0,0,0,91,104,97,110,100,121,93,32,72,76,69,95,66,73,79,83,95,73,110,105,116,13,10,0,103,108,67,111,112,121,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,105,110,32,118,101,99,52,32,99,111,108,111,114,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,72,87,32,114,101,110,100,101,114,32,70,66,79,32,35,37,117,44,32,101,114,114,111,114,58,32,48,120,37,117,46,10,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,108,111,97,100,0,0,0,0,0,115,116,121,108,101,0,0,0,79,99,116,111,98,101,114,0,66,108,97,99,107,32,70,114,97,109,101,32,73,110,115,101,114,116,105,111,110,0,0,0,111,118,101,114,108,97,121,37,117,95,110,97,109,101,0,0,110,101,97,114,101,115,116,0,60,33,45,45,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,117,109,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,0,0,0,0,68,83,80,32,99,111,110,102,105,103,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,115,97,118,101,0,0,0,0,0,83,101,112,116,101,109,98,101,114,0,0,0,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,32,70,114,97,109,101,115,0,0,0,0,108,105,110,101,97,114,0,0,82,101,116,114,111,65,114,99,104,58,32,85,110,112,97,117,115,101,100,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,105,110,100,101,120,0,0,0,0,65,117,103,117,115,116,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,102,105,108,101,110,97,109,101,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,97,117,115,101,100,46,10,0,0,0,0,0,84,97,107,101,32,115,99,114,101,101,110,115,104,111,116,0,98,108,111,99,107,95,115,114,97,109,95,111,118,101,114,119,114,105,116,101,0,0,0,0,83,116,97,114,116,32,98,117,116,116,111,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,77,111,118,105,101,32,102,111,114,109,97,116,32,115,101,101,109,115,32,116,111,32,104,97,118,101,32,97,32,100,105,102,102,101,114,101,110,116,32,115,101,114,105,97,108,105,122,101,114,32,118,101,114,115,105,111,110,46,32,87,105,108,108,32,109,111,115,116,32,108,105,107,101,108,121,32,102,97,105,108,46,10,0,0,74,117,108,121,0,0,0,0,86,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,73,68,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,82,101,97,99,104,101,100,32,101,110,100,32,111,102,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,0,0,0,91,104,97,110,100,121,93,114,111,109,32,110,111,116,32,102,111,117,110,100,32,37,115,10,0,0,0,0,0,0,0,0,99,104,101,97,116,95,115,101,116,116,105,110,103,115,95,112,97,116,104,0,0,0,0,0,74,117,110,101,0,0,0,0,82,111,116,97,116,105,111,110,0,0,0,0,0,0,0,0,102,105,108,116,101,114,0,0,109,101,110,117,95,116,111,103,103,108,101,0,0,0,0,0,82,101,119,105,110,100,105,110,103,46,0,0,0,0,0,0,67,104,101,97,116,32,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,77,69,83,83,65,71,69,58,32,37,115,10,0,0,0,0,0,99,104,101,97,116,95,100,97,116,97,98,97,115,101,95,112,97,116,104,0,0,0,0,0,77,97,121,0,0,0,0,0,84,111,103,103,108,101,32,70,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,103,114,97,98,95,109,111,117,115,101,95,116,111,103,103,108,101,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,46,0,0,0,0,97,117,116,111,115,97,118,101,95,105,110,116,101,114,118,97,108,0,0,0,0,0,0,0,65,112,114,105,108,0,0,0,67,117,115,116,111,109,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,84,111,111,32,109,97,110,121,32,116,101,120,116,117,114,101,32,105,109,97,103,101,115,46,32,73,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,100,105,115,107,95,110,101,120,116,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,32,114,101,119,105,110,100,46,0,0,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,45,0,0,0,112,97,117,115,101,95,110,111,110,97,99,116,105,118,101,0,77,97,114,99,104,0,0,0,65,115,112,101,99,116,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,65,77,32,97,100,100,114,101,115,115,32,115,112,101,99,105,102,105,99,101,100,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,100,105,115,107,95,101,106,101,99,116,95,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,10,0,0,0,0,0,0,0,37,115,32,124,124,32,70,80,83,58,32,37,54,46,49,102,32,124,124,32,70,114,97,109,101,115,58,32,37,100,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,117,100,105,111,32,114,97,116,101,32,99,111,110,116,114,111,108,32,119,97,115,32,100,101,115,105,114,101,100,44,32,98,117,116,32,100,114,105,118,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,101,101,100,101,100,32,102,101,97,116,117,114,101,115,46,10,0,0,0,0,0,0,0,102,97,115,116,102,111,114,119,97,114,100,95,114,97,116,105,111,0,0,0,0,0,0,0,102,105,108,101,95,112,97,116,104,46,99,0,0,0,0,0,70,101,98,114,117,97,114,121,0,0,0,0,0,0,0,0,73,110,116,101,103,101,114,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,105,110,112,117,116,32,115,108,111,116,32,102,111,114,32,105,109,112,111,114,116,46,10,0,0,0,0,111,118,101,114,108,97,121,95,110,101,120,116,0,0,0,0,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,43,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,115,108,111,119,109,111,116,105,111,110,95,114,97,116,105,111,0,0,0,0,0,0,0,0,74,97,110,117,97,114,121,0,83,104,97,100,101,114,32,79,112,116,105,111,110,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,118,111,108,117,109,101,95,100,111,119,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,103,108,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,79,69,83,95,112,97,99,107,101,100,95,100,101,112,116,104,95,115,116,101,110,99,105,108,0,0,0,0,0,0,0,0,114,101,119,105,110,100,95,103,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,71,76,83,76,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,83,99,97,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,110,102,105,103,32,107,101,121,58,32,37,115,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,111,114,32,73,68,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,118,111,108,117,109,101,95,117,112,0,0,0,0,0,0,0,61,34,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,80,114,101,118,105,111,117,115,32,115,104,97,100,101,114,0,114,101,119,105,110,100,95,98,117,102,102,101,114,95,115,105,122,101,0,0,0,0,0,0,68,0,0,0,101,0,0,0,99,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,70,105,108,116,101,114,0,0,0,0,0,0,0,101,113,117,97,108,0,0,0,101,110,97,98,108,101,95,104,111,116,107,101,121,0,0,0,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,97,118,101,32,115,116,97,116,101,115,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,114,101,119,105,110,100,95,101,110,97,98,108,101,0,0,0,78,0,0,0,111,0,0,0,118,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,0,0,0,0,0,0,109,97,115,107,0,0,0,0,115,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,0,0,78,101,120,116,32,115,104,97,100,101,114,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,115,99,97,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,115,116,97,116,101,32,102,114,111,109,32,109,111,118,105,101,46,10,0,0,0,79,0,0,0,99,0,0,0,116,0,0,0,0,0,0,0,83,104,97,100,101,114,32,80,97,115,115,101,115,0,0,0,105,110,112,117,116,95,115,108,111,116,0,0,0,0,0,0,110,101,116,112,108,97,121,95,102,108,105,112,95,112,108,97,121,101,114,115,0,0,0,0,37,115,46,98,115,118,0,0,108,121,110,120,98,111,111,116,46,105,109,103,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,111,112,97,99,105,116,121,0,0,0,83,0,0,0,101,0,0,0,112,0,0,0,0,0,0,0,98,97,115,105,99,95,115,116,114,105,110,103,0,0,0,0,76,111,97,100,32,83,104,97,100,101,114,32,80,114,101,115,101,116,0,0,0,0,0,0,119,114,97,109,0,0,0,0,97,117,100,105,111,95,109,117,116,101,0,0,0,0,0,0,37,115,37,117,46,98,115,118,0,0,0,0,0,0,0,0,82,101,115,101,116,32,103,97,109,101,0,0,0,0,0,0,46,114,101,116,114,111,97,114,99,104,45,99,111,114,101,45,111,112,116,105,111,110,115,46,99,102,103,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,0,0,0,65,0,0,0,117,0,0,0,103,0,0,0,0,0,0,0,68,101,102,97,117,108,116,32,70,105,108,116,101,114,0,0,115,101,109,97,110,116,105,99,0,0,0,0,0,0,0,0,100,115,112,95,99,111,110,102,105,103,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,0,111,118,101,114,108,97,121,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,74,0,0,0,117,0,0,0,108,0,0,0,0,0,0,0,65,112,112,108,121,32,83,104,97,100,101,114,32,67,104,97,110,103,101,115,0,0,0,0,105,100,0,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,70,114,97,109,101,97,100,118,97,110,99,101,0,0,0,0,114,103,117,105,95,98,114,111,119,115,101,114,95,100,105,114,101,99,116,111,114,121,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,101,110,100,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,74,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,37,115,32,40,37,100,44,32,37,100,32,58,32,37,52,117,120,37,52,117,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,111,111,32,109,97,110,121,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,115,32,46,46,46,10,0,0,0,0,0,99,104,101,97,116,95,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,108,121,32,115,104,97,100,101,114,46,10,0,0,0,0,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,110,32,101,120,105,115,116,105,110,103,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,77,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,83,101,116,32,66,111,116,116,111,109,45,82,105,103,104,116,32,67,111,114,110,101,114,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,80,121,116,104,111,110,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,109,105,110,117,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,0,80,97,117,115,101,32,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,100,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,0,0,0,0,65,0,0,0,112,0,0,0,114,0,0,0,0,0,0,0,83,101,116,32,85,112,112,101,114,45,76,101,102,116,32,67,111,114,110,101,114,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,108,97,110,103,117,97,103,101,32,105,115,32,110,111,116,32,80,121,116,104,111,110,46,10,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,112,108,117,115,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,58,32,34,37,115,34,46,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,83,110,97,112,115,104,111,116,46,10,0,0,0,0,0,0,103,108,84,101,120,73,109,97,103,101,51,68,79,69,83,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,116,97,116,101,32,116,114,97,99,107,101,114,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,77,97,120,32,116,101,120,116,117,114,101,32,115,105,122,101,58,32,37,100,32,112,120,44,32,114,101,110,100,101,114,98,117,102,102,101,114,32,115,105,122,101,58,32,37,117,32,112,120,46,10,0,0,0,0,99,111,114,101,95,111,112,116,105,111,110,115,95,112,97,116,104,0,0,0,0,0,0,0,78,47,65,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,66,105,116,32,100,101,112,116,104,32,111,102,32,84,71,65,32,105,109,97,103,101,32,105,115,32,119,114,111,110,103,46,32,79,110,108,121,32,51,50,45,98,105,116,32,97,110,100,32,50,52,45,98,105,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,0,0,0,0,37,115,32,40,37,52,117,120,37,52,117,44,32,37,117,32,120,32,37,117,32,115,99,97,108,101,41,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,111,118,101,114,108,97,121,0,0,0,0,0,0,0,99,108,97,115,115,0,0,0,115,104,97,100,101,114,95,112,114,101,118,0,0,0,0,0,32,10,9,12,11,13,0,0,82,101,116,114,111,65,114,99,104,58,32,9,9,37,115,10,0,0,0,0,0,0,0,0,46,99,103,112,0,0,0,0,77,111,118,105,101,32,114,101,99,111,114,100,32,116,111,103,103,108,101,0,0,0,0,0,108,105,98,114,101,116,114,111,95,112,97,116,104,0,0,0,70,0,0,0,101,0,0,0,98,0,0,0,0,0,0,0,91,99,111,117,108,100,32,110,111,116,32,115,101,116,32,82,71,66,53,54,53,93,10,0,83,101,116,32,115,99,97,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,97,108,114,101,97,100,121,32,105,109,112,111,114,116,101,100,46,10,0,0,115,104,97,100,101,114,95,110,101,120,116,0,0,0,0,0,46,99,103,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,117,115,101,115,32,116,104,114,101,97,100,101,100,32,97,117,100,105,111,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,0,105,110,112,117,116,95,106,111,121,112,97,100,95,100,114,105,118,101,114,0,0,0,0,0,74,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,67,71,80,32,102,97,105,108,101,100,46,10,0,0,63,63,63,0,0,0,0,0,114,101,115,101,116,0,0,0,46,115,104,97,100,101,114,0,83,101,108,101,99,116,32,98,117,116,116,111,110,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,82,67,51,50,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,82,79,77,32,102,105,108,101,32,97,110,100,32,115,97,118,101,100,32,82,79,77,32,99,104,101,99,107,115,117,109,32,105,110,32,114,101,112,108,97,121,32,102,105,108,101,32,104,101,97,100,101,114,59,32,114,101,112,108,97,121,32,104,105,103,104,108,121,32,108,105,107,101,108,121,32,116,111,32,100,101,115,121,110,99,32,111,110,32,112,108,97,121,98,97,99,107,46,10,0,68,0,0,0,101,0,0,0,99,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,78,47,65,32,40,115,116,111,99,107,41,0,0,0,0,0,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,0,102,114,97,109,101,95,97,100,118,97,110,99,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,111,116,32,105,110,118,97,108,105,100,32,100,105,115,107,32,105,110,100,101,120,32,102,114,111,109,32,108,105,98,114,101,116,114,111,46,10,0,0,0,0,0,37,115,37,99,37,115,0,0,97,117,100,105,111,95,100,115,112,95,112,108,117,103,105,110,0,0,0,0,0,0,0,0,78,0,0,0,111,0,0,0,118,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,0,114,101,112,101,97,116,0,0,112,97,117,115,101,95,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,66,83,82,77,58,32,37,115,10,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,45,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,86,65,82,73,65,66,76,69,83,46,10,0,0,0,0,0,0,97,117,100,105,111,95,100,114,105,118,101,114,0,0,0,0,104,111,119,97,114,100,46,111,0,0,0,0,0,0,0,0,79,0,0,0,99,0,0,0,116,0,0,0,111,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,37,115,32,40,37,115,41,0,99,108,97,109,112,95,116,111,95,101,100,103,101,0,0,0,109,111,118,105,101,95,114,101,99,111,114,100,95,116,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,83,82,77,58,32,37,115,10,0,0,0,0,118,105,100,101,111,95,103,108,95,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,83,0,0,0,101,0,0,0,112,0,0,0,116,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,60,85,115,101,32,116,104,105,115,32,100,105,114,101,99,116,111,114,121,62,0,0,0,0,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,0,114,101,119,105,110,100,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,83,117,102,97,109,105,32,116,117,114,98,111,32,65,47,66,32,82,65,77,46,10,0,0,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,43,0,0,0,0,0,0,0,0,118,105,100,101,111,95,100,114,105,118,101,114,0,0,0,0,37,48,50,120,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,101,110,100,105,110,103,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,0,65,0,0,0,117,0,0,0,103,0,0,0,117,0,0,0,115,0,0,0,116,0,0,0,0,0,0,0,0,0,0,0,37,115,124,122,105,112,0,0,97,98,115,111,108,117,116,101,0,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,100,101,99,114,101,97,115,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,83,82,77,58,32,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,114,101,115,97,109,112,108,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,97,117,100,105,111,95,118,111,108,117,109,101,0,0,0,0,74,0,0,0,117,0,0,0,108,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,99,102,103,0,0,0,0,0,118,105,101,119,112,111,114,116,0,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,105,110,99,114,101,97,115,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,32,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,32,98,117,102,102,101,114,46,10,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,95,100,101,108,116,97,0,0,0,0,0,0,0,0,74,0,0,0,117,0,0,0,110,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,99,103,124,103,108,115,108,0,115,111,117,114,99,101,0,0,101,120,105,116,95,101,109,117,108,97,116,111,114,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,66,83,88,32,40,80,41,82,65,77,46,10,0,0,80,76,84,69,0,0,0,0,103,108,71,101,116,66,117,102,102,101,114,80,111,105,110,116,101,114,118,79,69,83,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,76,85,84,115,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,32,72,87,32,114,101,110,100,101,114,32,40,37,117,32,120,32,37,117,41,46,10,0,0,0,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,84,71,65,32,112,105,120,101,108,115,46,10,0,0,0,0,115,104,97,100,101,114,0,0,67,77,105,107,105,101,58,58,80,111,107,101,40,41,32,45,32,87,114,105,116,101,32,116,111,32,77,84,69,83,84,50,0,0,0,0,0,0,0,0,99,103,112,124,103,108,115,108,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,111,118,101,114,108,97,121,32,99,97,108,108,101,100,58,32,34,37,115,34,46,10,0,0,0,0,115,99,97,108,101,95,37,115,37,117,0,0,0,0,0,0,116,111,103,103,108,101,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,67,104,101,97,116,58,32,35,37,117,32,91,37,115,93,58,32,37,115,0,0,0,0,0,60,47,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,80,111,115,115,105,98,108,101,32,118,97,108,117,101,115,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,71,97,109,101,98,111,121,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,116,111,103,103,108,101,0,0,0,0,0,0,0,97,117,100,105,111,95,115,121,110,99,0,0,0,0,0,0,65,0,0,0,112,0,0,0,114,0,0,0,105,0,0,0,108,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,95,37,115,37,117,0,115,97,118,101,95,115,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,84,67,58,32,37,115,10,0,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,0,0,0,0,0,97,117,100,105,111,95,108,97,116,101,110,99,121,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,99,0,0,0,104,0,0,0,0,0,0,0,37,99,32,37,45,42,46,42,115,32,37,45,42,115,0,0,108,111,97,100,95,115,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,37,115,10,0,0,0,0,0,83,97,118,101,32,115,116,97,116,101,0,0,0,0,0,0,97,117,100,105,111,95,100,101,118,105,99,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,118,105,101,32,102,105,108,101,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,66,83,86,49,32,102,105,108,101,46,10,0,0,0,0,0,0,70,0,0,0,101,0,0,0,98,0,0,0,114,0,0,0,117,0,0,0,97,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,104,111,108,100,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,114,101,103,117,108,97,114,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,108,110,120,0,0,0,0,0,97,117,100,105,111,95,98,108,111,99,107,95,102,114,97,109,101,115,0,0,0,0,0,0,74,0,0,0,97,0,0,0,110,0,0,0,117,0,0,0,97,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,37,117,0,0,0,0,0,116,111,103,103,108,101,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,102,97,105,108,101,100,0,0,76,111,97,100,32,115,116,97,116,101,0,0,0,0,0,0,97,117,100,105,111,95,111,117,116,95,114,97,116,101,0,0,76,83,83,50,0,0,0,0,63,0,0,0,0,0,0,0,114,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,115,117,99,99,101,101,100,101,100,0,0,0,0,0,0,0,97,117,100,105,111,95,101,110,97,98,108,101,0,0,0,0,80,77,0,0,0,0,0,0,85,110,107,110,111,119,110,0,112,121,116,104,111,110,0,0,114,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,117,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,32,37,115,46,10,0,70,97,115,116,32,102,111,114,119,97,114,100,32,104,111,108,100,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,37,117,95,106,111,121,112,97,100,95,105,110,100,101,120,0,0,0,0,0,44,0,0,0,0,0,0,0,65,77,0,0,0,0,0,0,83,117,112,101,114,83,99,111,112,101,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,95,112,114,101,118,105,111,117,115,0,0,0,0,0,114,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,46,97,117,116,111,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,110,101,116,112,108,97,121,95,99,108,105,101,110,116,95,115,119,97,112,95,105,110,112,117,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,100,105,114,101,99,116,111,114,121,58,32,34,37,115,34,10,0,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,0,74,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,99,97,112,116,117,114,101,95,112,114,101,118,105,111,117,115,0,0,0,0,0,0,0,0,114,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,45,118,0,0,0,0,0,0,70,97,115,116,32,102,111,114])
.concat([119,97,114,100,32,116,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,105,110,112,117,116,95,97,120,105,115,95,116,104,114,101,115,104,111,108,100,0,0,0,0,80,0,0,0,77,0,0,0,0,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,74,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,95,99,111,117,110,116,0,0,0,0,0,0,0,0,108,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,45,99,0,0,0,0,0,0,67,77,101,109,77,97,112,58,58,67,111,110,116,101,120,116,83,97,118,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,105,108,101,32,67,82,67,32,100,105,102,102,101,114,115,32,102,114,111,109,32,90,73,80,32,67,82,67,46,32,70,105,108,101,58,32,48,120,37,120,44,32,90,73,80,58,32,48,120,37,120,46,10,0,0,0,0,0,0,73,69,78,68,0,0,0,0,103,108,85,110,109,97,112,66,117,102,102,101,114,79,69,83,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,83,76,32,115,116,111,99,107,32,112,114,111,103,114,97,109,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,37,117,32,116,101,120,116,117,114,101,115,46,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,101,100,32,84,71,65,58,32,40,37,117,120,37,117,32,64,32,37,117,32,98,112,112,41,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,0,0,0,65,0,0,0,77,0,0,0,0,0,0,0,0,0,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,0,0,0,77,111,117,115,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,111,108,118,101,32,110,101,120,116,32,116,97,114,103,101,116,115,46,10,0,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,0,0,0,0,0,0,108,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,110,121,32,99,104,101,97,116,115,32,105,110,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,82,117,110,116,105,109,101,32,65,108,101,114,116,32,45,32,83,121,115,116,101,109,32,72,97,108,116,101,100,10,67,77,105,107,105,101,58,58,80,111,107,101,40,83,89,83,67,84,76,49,41,32,45,32,76,121,110,120,32,112,111,119,101,114,32,100,111,119,110,32,111,99,99,117,114,101,100,32,97,116,32,80,67,61,36,37,48,52,120,46,10,82,101,115,101,116,116,105,110,103,32,115,121,115,116,101,109,46,0,0,0,0,93,93,62,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,67,117,114,114,101,110,116,32,118,97,108,117,101,58,32,37,115,10,0,0,45,83,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,100,105,114,0,0,0,0,0,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,66,79,32,116,101,120,116,117,114,101,115,32,101,120,99,101,101,100,101,100,32,109,97,120,105,109,117,109,32,115,105,122,101,32,111,102,32,71,80,85,32,40,37,117,120,37,117,41,46,32,82,101,115,105,122,105,110,103,32,116,111,32,102,105,116,46,10,0,0,0,0,0,0,0,0,77,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,99,97,112,116,117,114,101,0,108,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,45,115,0,0,0,0,0,0,118,105,100,101,111,95,103,112,117,95,115,99,114,101,101,110,115,104,111,116,0,0,0,0,98,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,66,79,32,112,97,115,115,32,35,37,100,32,105,115,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,46,10,0,0,0,0,0,74,111,121,112,97,100,32,119,47,32,65,110,97,108,111,103,0,0,0,0,0,0,0,0,37,115,95,101,113,117,97,108,0,0,0,0,0,0,0,0,108,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,45,45,109,101,110,117,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,85,78,83,85,80,80,79,82,84,69,68,32,40,35,37,117,41,46,10,0,0,118,105,100,101,111,95,103,112,117,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,89,32,98,117,116,116,111,110,32,40,108,101,102,116,41,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,109,111,118,105,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,32,101,120,116,101,110,115,105,111,110,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,0,0,74,111,121,112,97,100,0,0,37,115,95,109,97,115,107,0,116,117,114,98,111,0,0,0,82,101,116,114,111,65,114,99,104,58,32,78,111,32,82,79,77,44,32,115,116,97,114,116,105,110,103,32,100,117,109,109,121,32,99,111,114,101,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,46,10,0,0,0,0,0,118,105,100,101,111,95,112,111,115,116,95,102,105,108,116,101,114,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,48,46,57,53,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,104,97,100,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,0,0,0,0,0,0,0,0,78,111,110,101,0,0,0,0,37,115,95,105,110,112,117,116,95,115,108,111,116,0,0,0,114,51,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,82,79,77,58,32,37,115,46,10,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,95,69,83,67,65,80,69,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,37,115,10,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,99,111,108,111,114,0,0,0,0,0,46,98,114,97,109,0,0,0,76,89,78,88,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,118,101,114,115,105,111,110,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,117,112,32,102,114,97,109,101,32,98,117,102,102,101,114,32,111,98,106,101,99,116,115,46,32,77,117,108,116,105,45,112,97,115,115,32,115,104,97,100,105,110,103,32,119,105,108,108,32,110,111,116,32,119,111,114,107,46,10,0,0,37,115,95,119,114,97,109,0,108,51,0,0,0,0,0,0,114,101,116,114,111,97,114,99,104,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,83,69,84,95,76,73,66,82,69,84,82,79,95,80,65,84,72,46,10,0,0,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,104,101,105,103,104,116,0,0,46,97,114,97,109,0,0,0,35,118,101,114,115,105,111,110,32,37,117,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,0,0,0,78,47,65,32,40,112,111,114,116,32,35,37,117,41,0,0,37,115,95,115,101,109,97,110,116,105,99,0,0,0,0,0,114,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,70,82,65,77,69,95,84,73,77,69,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,119,105,100,116,104,0,0,0,115,101,116,116,105,110,103,115,46,99,0,0,0,0,0,0,46,112,114,97,109,0,0,0,35,118,101,114,115,105,111,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,35,37,100,0,0,0,0,0,49,0,0,0,0,0,0,0,108,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,109,111,118,105,110,103,32,116,101,109,112,111,97,114,121,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,110,111,0,0,0,0,0,0,100,114,105,118,101,114,46,99,0,0,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,121,0,0,0,0,0,0,0,46,114,116,99,0,0,0,0,46,46,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,98,105,110,100,32,65,80,73,32,37,115,32,116,111,32,99,111,110,116,101,120,116,32,37,115,46,10,0,0,0,0,0,0,37,46,50,102,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,65,77,32,119,105,108,108,32,110,111,116,32,98,101,32,115,97,118,101,100,46,10,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,0,121,101,115,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,120,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,105,110,107,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,0,0,0,0,0,79,112,101,110,71,76,32,69,83,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,107,105,112,112,105,110,103,32,83,82,65,77,32,108,111,97,100,46,10,0,60,42,42,32,82,69,83,84,79,82,69,68,32,42,42,62,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,97,110,121,32,82,79,77,83,32,116,104,97,116,32,109,97,116,99,104,101,100,32,118,97,108,105,100,32,101,120,116,101,110,115,105,111,110,115,32,102,111,114,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,73,68,65,84,0,0,0,0,103,108,77,97,112,66,117,102,102,101,114,79,69,83,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,99,111,110,116,101,120,116,32,105,115,32,117,115,101,100,44,32,98,117,116,32,115,104,97,100,101,114,32,105,115,32,110,111,116,32,109,111,100,101,114,110,46,32,67,97,110,110,111,116,32,117,115,101,32,105,116,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,68,105,109,101,110,115,105,111,110,115,58,32,37,117,120,37,117,10,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,83,85,80,80,79,82,84,95,78,79,95,71,65,77,69,58,32,37,115,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,109,117,108,116,105,112,97,115,115,32,115,104,97,100,101,114,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,68,73,83,75,32,65,80,80,69,78,68,32,37,115,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,71,65,32,105,109,97,103,101,32,105,115,32,110,111,116,32,117,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,46,46,46,32,67,97,110,110,111,116,32,114,101,99,111,118,101,114,32,115,97,118,101,32,102,105,108,101,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,88,77,76,32,115,104,97,100,101,114,58,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,105,110,103,32,71,76,83,76,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,46,10,51,50,45,98,105,116,32,112,97,116,104,32,119,105,108,108,32,114,101,113,117,105,114,101,32,99,111,110,118,101,114,115,105,111,110,46,10,0,0,0,60,82,79,77,32,100,105,114,62,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,103,114,97,98,32,99,104,101,97,116,115,46,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,0,0,60,33,91,67,68,65,84,65,91,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,75,101,121,58,32,37,115,10,0,0,0,0,67,77,105,107,105,101,58,58,83,101,116,83,99,114,101,101,110,65,116,116,114,105,98,117,116,101,115,40,41,32,45,32,85,110,114,101,99,111,103,110,105,115,101,100,32,100,105,115,112,108,97,121,32,102,111,114,109,97,116,0,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,10,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,117,110,107,110,111,119,110,32,99,111,110,116,101,120,116,46,10,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,120,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,99,99,101,101,100,101,100,32,105,110,32,115,97,118,105,110,103,32,82,65,77,32,100,97,116,97,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,89,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,32,102,111,117,110,100,32,102,111,114,32,71,76,69,83,46,10,0,0,0,0,60,100,101,102,97,117,108,116,62,0,0,0,0,0,0,0,105,109,112,111,114,116,115,0,61,61,61,32,66,117,105,108,100,32,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,32,99,111,110,116,101,120,116,44,32,98,117,116,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,79,112,101,110,71,76,69,83,50,46,32,67,97,110,110,111,116,32,117,115,101,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,99,97,108,101,0,0,0,0,0,0,0,0,102,105,110,100,95,97,117,100,105,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,37,89,45,37,109,45,37,100,45,37,72,45,37,77,45,37,83,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,108,111,99,97,108,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,0,0,0,91,68,105,115,112,108,97,121,83,101,116,65,116,116,114,105,98,117,116,101,115,32,50,93,10,0,0,0,0,0,0,0,35,100,101,102,105,110,101,32,70,82,65,71,77,69,78,84,10,0,0,0,0,0,0,0,66,71,82,65,56,56,56,56,0,0,0,0,0,0,0,0,37,46,51,102,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,95,99,108,97,115,115,0,0,0,0,0,114,105,103,104,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,116,97,108,32,101,114,114,111,114,32,114,101,99,101,105,118,101,100,32,105,110,58,32,34,37,115,34,10,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,69,83,50,32,99,111,110,116,101,120,116,46,10,0,0,0,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,101,110,97,98,108,101,0,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,97,117,100,105,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,37,115,47,82,101,116,114,111,65,114,99,104,45,114,101,99,111,118,101,114,121,45,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,112,108,97,121,98,97,99,107,46,10,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,104,97,100,101,114,44,32,102,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,0,0,0,108,101,102,116,0,0,0,0,90,73,80,124,122,105,112,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,110,111,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,105,122,101,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,97,117,100,105,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,104,97,110,100,121,0,0,0,37,0,0,0,73,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,0,0,37,46,51,102,32,72,122,32,40,37,46,49,102,37,37,32,100,101,118,44,32,37,117,32,115,97,109,112,108,101,115,41,0,0,0,0,0,0,0,0,37,115,95,119,114,97,112,95,109,111,100,101,0,0,0,0,100,111,119,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,58,32,37,115,32,37,115,0,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,72,87,95,82,69,78,68,69,82,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,86,65,82,73,65,66,76,69,32,37,115,58,10,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,112,97,116,104,0,102,105,110,100,95,118,105,100,101,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,79,77,32,105,115,32,117,115,101,100,44,32,98,117,116,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,104,105,115,46,10,0,0,37,73,58,37,77,58,37,83,32,37,112,0,0,0,0,0,66,83,57,51,0,0,0,0,35,100,101,102,105,110,101,32,86,69,82,84,69,88,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,118,97,108,105,100,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,32,67,111,110,116,105,110,117,105,110,103,32,119,105,116,104,111,117,116,32,115,104,97,100,101,114,115,46,10,0,0,0,0,0,0,0,37,46,49,102,120,0,0,0,37,115,95,108,105,110,101,97,114,0,0,0,0,0,0,0,117,112,0,0,0,0,0,0,83,101,116,116,105,110,103,32,114,101,102,114,101,115,104,32,114,97,116,101,32,116,111,58,32,37,46,51,102,32,72,122,46,0,0,0,0,0,0,0,118,48,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,68,73,83,75,95,67,79,78,84,82,79,76,95,73,78,84,69,82,70,65,67,69,46,10,0,118,105,100,101,111,95,97,108,108,111,119,95,114,111,116,97,116,101,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,118,105,100,101,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,32,105,110,32,34,37,115,34,10,0,0,0,0,0,0,0,0,37,0,0,0,97,0,0,0,32,0,0,0,37,0,0,0,98,0,0,0,32,0,0,0,37,0,0,0,100,0,0,0,32,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,89,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,118,101,114,116,101,120,32,115,104,97,100,101,114,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,10,0,0,0,0,116,101,120,116,117,114,101,115,0,0,0,0,0,0,0,0,115,116,97,114,116,0,0,0,84,117,114,98,111,32,101,110,97,98,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,75,69,89,66,79,65,82,68,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,101,110,97,98,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,118,105,100,101,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,116,99,104,32,37,115,58,32,69,114,114,111,114,32,35,37,117,10,0,0,0,0,0,37,97,32,37,98,32,37,100,32,37,72,58,37,77,58,37,83,32,37,89,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,71,76,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,78,111,116,32,108,111,97,100,105,110,103,32,97,110,121,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,115,101,108,101,99,116,0,0,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,82,101,116,114,111,80,97,100,44,32,80,108,97,121,101,114,32,37,117,44,32,66,117,116,116,111,110,32,34,37,115,34,32,61,62,32,34,37,115,34,10,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,0,0,0,0,102,105,110,100,95,105,110,112,117,116,95,100,114,105,118,101,114,40,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,112,97,116,99,104,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,40,37,115,41,46,10,0,0,0,0,0,0,82,0,0,0,0,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,71,76,83,76,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,110,32,115,112,101,99,105,102,105,101,100,32,71,76,32,101,114,114,111,114,46,10,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,37,117,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,100,105,115,107,32,37,117,32,111,102,32,37,117,46,0,0,0,0,82,51,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,73,78,80,85,84,95,68,69,83,67,82,73,80,84,79,82,83,58,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,68,105,100,110,39,116,32,114,101,97,100,32,119,104,111,108,101,32,102,105,108,101,46,10,0,0,0,0,118,105,100,101,111,95,114,101,102,114,101,115,104,95,114,97,116,101,0,0,0,0,0,0,9,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,112,97,116,99,104,101,100,32,82,79,77,32,46,46,46,10,0,0,0,0,0,67,83,117,115,105,101,58,58,76,105,110,101,73,110,105,116,40,41,32,79,117,116,32,111,102,32,98,111,117,110,100,115,32,40,118,111,102,102,41,0,115,116,100,58,58,98,97,100,95,97,108,108,111,99,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,79,117,116,32,111,102,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,119,114,97,112,95,109,111,100,101,37,117,0,0,0,0,0,82,101,109,111,118,101,100,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,60,42,42,32,73,77,65,71,69,32,42,42,62,0,0,0,82,101,116,114,111,65,114,99,104,58,32,79,70,70,83,69,84,58,32,37,117,44,32,67,83,73,90,69,58,32,37,117,44,32,83,73,90,69,58,32,37,117,46,10,0,0,0,0,73,72,68,82,0,0,0,0,67,82,111,109,58,58,67,111,110,116,101,120,116,83,97,118,101,0,0,0,0,0,0,0,103,108,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,83,116,111,99,107,32,71,76,83,76,32,115,104,97,100,101,114,115,32,119,105,108,108,32,98,101,32,117,115,101,100,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,65,116,116,101,109,112,116,101,100,32,116,111,32,114,101,45,105,110,105,116,105,97,108,105,122,101,32,100,114,105,118,101,114,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,67,97,110,110,111,116,32,102,105,110,100,32,115,104,97,100,101,114,32,99,111,114,101,32,102,111,114,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,0,0,0,67,79,82,69,32,83,69,76,69,67,84,73,79,78,32,37,115,0,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,95,97,117,116,111,0,99,103,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,65,118,97,105,108,97,98,108,101,32,105,110,112,117,116,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,37,115,32,102,105,108,101,32,105,110,32,34,37,115,34,44,32,97,116,116,101,109,112,116,105,110,103,32,116,111,32,112,97,116,99,104,32,46,46,46,10,0,0,0,0,0,0,37,0,0,0,109,0,0,0,47,0,0,0,37,0,0,0,100,0,0,0,47,0,0,0,37,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,111,112,101,114,97,116,105,111,110,46,10,0,0,0,0,79,70,70,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,111,118,101,114,108,97,121,115,32,118,97,114,105,97,98,108,101,32,110,111,116,32,100,101,102,105,110,101,100,32,105,110,32,99,111,110,102,105,103,46,10,0,0,102,105,108,116,101,114,95,108,105,110,101,97,114,37,117,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,115,97,116,117,114,97,116,101,95,112,99,116,0,0,0,115,104,97,50,53,54,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,105,109,97,103,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,60,47,37,115,62,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,68,101,115,99,114,105,112,116,105,111,110,58,32,37,115,10,0,0,0,0,83,101,116,116,105,110,103,32,100,105,115,107,32,37,117,32,111,102,32,37,117,32,105,110,32,116,114,97,121,46,0,0,76,51,32,98,117,116,116,111,110,32,40,108,101,102,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,0,97,115,112,101,99,116,95,114,97,116,105,111,95,105,110,100,101,120,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,105,110,112,117,116,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,32,118,97,108,105,100,32,82,79,77,32,112,97,116,99,104,46,10,0,0,0,0,0,114,117,98,121,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,79,78,0,0,0,0,0,0,115,104,97,100,101,114,37,117,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,65,110,97,108,111,103,32,104,105,116,98,111,120,32,116,121,112,101,32,109,117,115,116,32,98,101,32,34,114,97,100,105,97,108,34,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,37,115,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,32,46,46,46,10,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,32,97,117,100,105,111,32,105,110,112,117,116,32,114,97,116,101,32,116,111,58,32,37,46,50,102,32,72,122,46,10,0,0,0,73,80,83,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,101,110,117,109,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,88,77,76,32,115,104,97,100,101,114,32,46,46,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,72,105,116,98,111,120,32,116,121,112,101,32,40,37,115,41,32,105,115,32,105,110,118,97,108,105,100,46,32,85,115,101,32,34,114,97,100,105,97,108,34,32,111,114,32,34,114,101,99,116,34,46,10,0,0,0,99,108,111,115,101,0,0,0,82,50,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,118,105,100,101,111,95,99,114,111,112,95,111,118,101,114,115,99,97,110,0,0,0,0,0,66,32,98,117,116,116,111,110,32,40,100,111,119,110,41,0,37,117,58,37,117,32,40,49,58,49,32,80,65,82,41,0,82,101,116,114,111,65,114,99,104,58,32,71,97,109,101,32,70,80,83,32,62,32,77,111,110,105,116,111,114,32,70,80,83,46,32,67,97,110,110,111,116,32,114,101,108,121,32,111,110,32,86,83,121,110,99,46,10,0,0,0,0,0,0,0,66,80,83,0,0,0,0,0,102,0,0,0,97,0,0,0,108,0,0,0,115,0,0,0,101,0,0,0,0,0,0,0,91,68,105,115,112,108,97,121,83,101,116,65,116,116,114,105,98,117,116,101,115,32,49,93,10,0,0,0,0,0,0,0,84,101,120,116,117,114,101,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,76,111,97,100,101,100,32,37,117,32,112,114,111,103,114,97,109,40,115,41,46,10,0,0,0,78,101,97,114,101,115,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,110,111,114,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,105,110,32,88,77,76,32,102,105,108,101,46,10,0,0,0,0,0,0,114,101,99,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,97,100,106,117,115,116,101,100,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,116,111,32,37,117,32,77,105,66,10,0,0,0,0,0,101,106,101,99,116,0,0,0,118,105,100,101,111,95,115,99,97,108,101,95,105,110,116,101,103,101,114,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,84,105,109,105,110,103,115,32,100,101,118,105,97,116,101,32,116,111,111,32,109,117,99,104,46,32,87,105,108,108,32,110,111,116,32,97,100,106,117,115,116,46,32,40,68,105,115,112,108,97,121,32,61,32,37,46,50,102,32,72,122,44,32,71,97,109,101,32,61,32,37,46,50,102,32,72,122,41,10,0,0,0,0,0,0,85,80,83,0,0,0,0,0,102,97,108,115,101,0,0,0,68,105,115,112,108,97,121,32,114,111,116,97,116,105,111,110,59,32,78,111,110,101,124,57,48,124,50,52,48,0,0,0,103,108,71,101,116,80,111,105])
.concat([110,116,101,114,118,0,0,0,37,115,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,105,110,105,116,32,102,97,105,108,101,100,46,10,0,76,105,110,101,97,114,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,114,97,100,105,97,108,0,0,70,97,105,108,101,100,32,116,111,32,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,76,50,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,67,65,78,95,68,85,80,69,58,32,116,114,117,101,10,0,0,118,105,100,101,111,95,102,111,114,99,101,95,97,115,112,101,99,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,117,100,105,111,32,98,97,99,107,101,110,100,32,102,97,105,108,101,100,32,116,111,32,119,114,105,116,101,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,115,111,117,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,109,111,117,110,116,32,111,102,32,116,105,109,101,32,115,112,101,110,116,32,99,108,111,115,101,32,116,111,32,117,110,100,101,114,114,117,110,58,32,37,46,50,102,32,37,37,46,32,67,108,111,115,101,32,116,111,32,98,108,111,99,107,105,110,103,58,32,37,46,50,102,32,37,37,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,115,99,111,112,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,101,118,101,114,97,108,32,112,97,116,99,104,101,115,32,97,114,101,32,101,120,112,108,105,99,105,116,108,121,32,100,101,102,105,110,101,100,44,32,105,103,110,111,114,105,110,103,32,97,108,108,32,46,46,46,10,0,0,0,76,0,0,0,0,0,0,0,116,0,0,0,114,0,0,0,117,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,77,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,103,108,71,101,116,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,80,114,101,118,37,117,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,10,0,0,37,115,0,0,0,0,0,0,115,99,114,105,112,116,0,0,73,110,118,97,108,105,100,32,67,97,114,116,46,10,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,110,101,120,116,95,116,97,114,103,101,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,115,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,67,108,111,115,101,100,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,109,111,117,115,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,115,99,111,110,110,101,99,116,105,110,103,32,100,101,118,105,99,101,32,102,114,111,109,32,112,111,114,116,32,37,117,46,10,0,0,88,32,40,117,112,41,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,99,111,110,102,105,103,32,102,105,108,101,46,32,85,115,105,110,103,32,115,121,115,116,101,109,32,100,101,102,97,117,108,116,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,99,111,110,102,105,103,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,118,105,100,101,111,95,115,109,111,111,116,104,0,0,0,0,46,99,102,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,97,117,100,105,111,32,98,117,102,102,101,114,32,115,97,116,117,114,97,116,105,111,110,58,32,37,46,50,102,32,37,37,44,32,115,116,97,110,100,97,114,100,32,100,101,118,105,97,116,105,111,110,32,40,112,101,114,99,101,110,116,97,103,101,32,112,111,105,110,116,115,41,58,32,37,46,50,102,32,37,37,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,82,67,51,50,58,32,48,120,37,120,44,32,83,72,65,50,53,54,58,32,37,115,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,103,108,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,0,0,0,80,114,101,118,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,114,115,105,111,110,58,32,37,115,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,111,114,116,32,118,97,108,117,101,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,46,120,109,108,0,0,0,0,46,105,112,115,0,0,0,0,69,106,101,99,116,101,100,0,46,98,112,115,0,0,0,0,82,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,46,117,112,115,0,0,0,0,65,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,102,97,109,105,32,84,117,114,98,111,32,83,82,65,77,32,112,97,116,104,115,32,119,105,108,108,32,98,101,32,105,110,102,101,114,114,101,100,32,102,114,111,109,32,116,104,101,105,114,32,114,101,115,112,101,99,116,105,118,101,32,112,97,116,104,115,32,116,111,32,97,118,111,105,100,32,99,111,110,102,108,105,99,116,115,46,10,0,0,0,118,105,100,101,111,95,116,104,114,101,97,100,101,100,0,0,46,112,115,114,109,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,115,104,97,100,101,114,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,103,97,109,101,46,10,0,0,0,0,0,0,9,45,68,47,45,45,100,101,116,97,99,104,58,32,68,101,116,97,99,104,32,82,101,116,114,111,65,114,99,104,32,102,114,111,109,32,116,104,101,32,114,117,110,110,105,110,103,32,99,111,110,115,111,108,101,46,32,78,111,116,32,114,101,108,101,118,97,110,116,32,102,111,114,32,97,108,108,32,112,108,97,116,102,111,114,109,115,46,10,0,0,0,0,0,0,0,67,54,53,67,48,50,58,58,85,112,100,97,116,101,40,41,32,45,32,73,108,108,101,103,97,108,32,111,112,99,111,100,101,32,40,37,48,50,120,41,32,97,116,32,80,67,61,36,37,48,52,120,46,0,0,0,103,108,71,101,116,79,98,106,101,99,116,76,97,98,101,108,0,0,0,0,0,0,0,0,80,97,115,115,37,117,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,110,100,111,114,58,32,37,115,44,32,82,101,110,100,101,114,101,114,58,32,37,115,46,10,0,0,0,0,0,102,114,111,110,116,101,110,100,47,109,101,110,117,47,46,46,47,46,46,47,103,102,120,47,46,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,105,109,112,111,114,116,0,0,82,101,116,114,111,65,114,99,104,58,32,91,67,111,110,102,105,103,93,58,32,81,117,101,114,121,105,110,103,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,97,110,97,108,111,103,95,114,105,103,104,116,0,0,0,0,9,45,88,47,45,45,120,109,108,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,116,111,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,46,0,0,0,0,9,45,45,110,111,45,112,97,116,99,104,58,32,68,105,115,97,98,108,101,115,32,97,108,108,32,102,111,114,109,115,32,111,102,32,114,111,109,32,112,97,116,99,104,105,110,103,46,0,0,0,0,0,0,0,0,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,0,0,9,45,45,105,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,73,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,9,45,45,98,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,66,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,9,45,85,47,45,45,117,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,85,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,0,9,45,118,47,45,45,118,101,114,98,111,115,101,58,32,86,101,114,98,111,115,101,32,108,111,103,103,105,110,103,46,0,9,9,68,111,32,110,111,116,101,32,116,104,97,116,32,110,111,108,111,97,100,45,115,97,118,101,32,105,109,112,108,105,101,115,32,116,104,97,116,32,115,97,118,101,32,102,105,108,101,115,32,119,105,108,108,32,98,101,32,100,101,108,101,116,101,100,32,97,110,100,32,111,118,101,114,119,114,105,116,116,101,110,46,0,0,0,0,0,118,105,100,101,111,95,115,119,97,112,95,105,110,116,101,114,118,97,108,0,0,0,0,0,32,10,9,12,13,11,0,0,9,9,123,110,111,44,125,108,111,97,100,45,123,110,111,44,125,115,97,118,101,32,100,101,115,99,114,105,98,101,115,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,108,111,97,100,101,100,44,32,97,110,100,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,115,97,118,101,100,46,0,0,115,104,97,100,101,114,124,99,103,124,99,103,112,124,103,108,115,108,124,103,108,115,108,112,0,0,0,0,0,0,0,0,9,45,77,47,45,45,115,114,97,109,45,109,111,100,101,58,32,84,97,107,101,115,32,97,110,32,97,114,103,117,109,101,110,116,32,116,101,108,108,105,110,103,32,104,111,119,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,104,97,110,100,108,101,100,32,105,110,32,116,104,101,32,115,101,115,115,105,111,110,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,0,0,9,45,82,47,45,45,98,115,118,114,101,99,111,114,100,58,32,83,116,97,114,116,32,114,101,99,111,114,100,105,110,103,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,32,102,114,111,109,32,116,104,101,32,98,101,103,105,110,110,105,110,103,46,0,0,0,103,108,79,98,106,101,99,116,76,97,98,101,108,0,0,0,80,97,115,115,80,114,101,118,37,117,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,101,116,101,99,116,105,110,103,32,115,99,114,101,101,110,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,46,10,0,0,48,46,57,46,57,46,51,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,101,120,116,117,114,101,32,105,109,97,103,101,32,102,97,105,108,101,100,32,116,111,32,108,111,97,100,46,10,0,0,0,0,0,97,110,97,108,111,103,95,108,101,102,116,0,0,0,0,0,9,45,80,47,45,45,98,115,118,112,108,97,121,58,32,80,108,97,121,98,97,99,107,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,46,0,0,0,0,0,0,0,9,45,52,47,45,45,109,117,108,116,105,116,97,112,58,32,67,111,110,110,101,99,116,32,97,32,83,78,69,83,32,109,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,65,112,112,101,110,100,101,100,32,100,105,115,107,58,32,37,115,0,0,0,0,0,0,0,9,45,74,47,45,45,106,117,115,116,105,102,105,101,114,115,58,32,68,97,105,115,121,32,99,104,97,105,110,32,116,119,111,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,115,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,76,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,0,9,45,106,47,45,45,106,117,115,116,105,102,105,101,114,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,9,45,112,47,45,45,115,99,111,112,101,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,83,117,112,101,114,83,99,111,112,101,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,9,45,109,47,45,45,109,111,117,115,101,58,32,67,111,110,110,101,99,116,32,97,32,109,111,117,115,101,32,105,110,116,111,32,112,111,114,116,32,111,102,32,116,104,101,32,100,101,118,105,99,101,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,0,0,0,9,45,65,47,45,45,100,117,97,108,97,110,97,108,111,103,58,32,67,111,110,110,101,99,116,32,97,32,68,117,97,108,65,110,97,108,111,103,32,99,111,110,116,114,111,108,108,101,114,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,118,105,100,101,111,95,98,108,97,99,107,95,102,114,97,109,101,95,105,110,115,101,114,116,105,111,110,0,0,0,0,0,34,0,0,0,0,0,0,0,9,45,78,47,45,45,110,111,100,101,118,105,99,101,58,32,68,105,115,99,111,110,110,101,99,116,115,32,99,111,110,116,114,111,108,108,101,114,32,100,101,118,105,99,101,32,99,111,110,110,101,99,116,101,100,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,48,82,71,66,49,53,53,53,32,112,105,120,101,108,32,102,111,114,109,97,116,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,97,110,100,32,119,105,108,108,32,98,101,32,115,108,111,119,101,114,46,32,70,111,114,32,49,53,47,49,54,45,98,105,116,44,32,82,71,66,53,54,53,32,102,111,114,109,97,116,32,105,115,32,112,114,101,102,101,114,114,101,100,46,10,0,0,0,0,0,0,0,0,9,45,45,115,117,102,97,109,105,66,58,32,80,97,116,104,32,116,111,32,66,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,108,111,97,100,105,110,103,32,115,107,105,112,112,101,100,46,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,119,105,108,108,32,108,111,97,100,32,105,116,32,111,110,32,105,116,115,32,111,119,110,46,10,0,0,0,0,0,0,0,0,9,45,45,115,117,102,97,109,105,65,58,32,80,97,116,104,32,116,111,32,65,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,32,76,111,97,100,32,83,117,102,97,109,105,32,98,97,115,101,32,99,97,114,116,32,97,115,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,103,108,80,111,112,68,101,98,117,103,71,114,111,117,112,0,79,114,105,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,10,0,0,0,0,0,0,0,0,37,115,32,45,32,37,115,32,37,115,0,0,0,0,0,0,46,0,0,0,0,0,0,0,46,46,46,0,0,0,0,0,116,101,120,116,117,114,101,0,67,83,117,115,105,101,58,80,97,105,110,116,83,112,114,105,116,101,115,40,41,58,32,83,105,110,103,108,101,32,100,114,97,119,32,115,112,114,105,116,101,32,108,105,109,105,116,32,101,120,99,101,101,100,101,100,32,40,62,52,48,57,54,41,46,32,84,104,101,32,83,67,66,32,105,115,32,109,111,115,116,32,108,105,107,101,108,121,32,108,111,111,112,101,100,32,98,97,99,107,32,111,110,32,105,116,115,101,108,102,46,32,82,101,115,101,116,47,69,120,105,116,32,105,115,32,114,101,99,111,109,109,101,110,100,101,100,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,79,118,101,114,108,97,121,32,100,101,115,99,32,105,115,32,105,110,118,97,108,105,100,46,32,82,101,113,117,105,114,101,115,32,97,116,32,108,101,97,115,116,32,54,32,116,111,107,101,110,115,46,10,0,0,0,9,45,66,47,45,45,98,115,120,115,108,111,116,58,32,80,97,116,104,32,116,111,32,66,83,88,32,115,108,111,116,116,101,100,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,9,45,98,47,45,45,98,115,120,58,32,80,97,116,104,32,116,111,32,66,83,88,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,82,101,115,101,116,46,0,0,9,45,103,47,45,45,103,97,109,101,98,111,121,58,32,80,97,116,104,32,116,111,32,71,97,109,101,98,111,121,32,82,79,77,46,32,76,111,97,100,32,83,117,112,101,114,71,97,109,101,66,111,121,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,67,67,97,114,116,58,58,67,111,110,116,101,120,116,83,97,118,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,90,73,80,32,101,120,116,114,97,99,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,108,105,110,101,58,32,37,100,46,10,0,0,0,0,0,0,0,0,115,116,100,58,58,98,97,100,95,99,97,115,116,0,0,0,9,9,77,117,108,116,105,112,108,101,32,99,111,110,102,105,103,115,32,97,114,101,32,100,101,108,105,109,105,116,101,100,32,98,121,32,39,44,39,46,0,0,0,0,0,0,0,0,103,108,71,101,116,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,71,76,83,76,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,46,46,46,10,0,0,0,70,65,75,69,32,76,89,78,88,66,79,79,84,46,73,77,71,32,45,32,67,65,82,84,82,73,68,71,69,83,32,87,73,76,76,32,78,79,84,32,87,79,82,75,10,10,80,76,69,65,83,69,32,82,69,65,68,32,84,72,69,32,65,67,67,79,77,80,65,78,89,73,78,71,32,82,69,65,68,77,69,46,84,88,84,32,70,73,76,69,10,10,40,68,111,32,110,111,116,32,101,109,97,105,108,32,116,104,101,32,97,117,116,104,111,114,32,97,115,107,105,110,103,32,102,111,114,32,116,104,105,115,32,105,109,97,103,101,41,10,0,0,0,0,9,45,45,97,112,112,101,110,100,99,111,110,102,105,103,58,32,69,120,116,114,97,32,99,111,110,102,105,103,32,102,105,108,101,115,32,97,114,101,32,108,111,97,100,101,100,32,105,110,44,32,97,110,100,32,116,97,107,101,32,112,114,105,111,114,105,116,121,32,111,118,101,114,32,99,111,110,102,105,103,32,115,101,108,101,99,116,101,100,32,105,110,32,45,99,32,40,111,114,32,100,101,102,97,117,108,116,41,46,0,0,0,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,0,103,108,0,0,0,0,0,0,37,115,10,37,115,10,37,115,10,0,0,0,0,0,0,0,9,45,99,47,45,45,99,111,110,102,105,103,58,32,80,97,116,104,32,102,111,114,32,99,111,110,102,105,103,32,102,105,108,101,46,10,9,9,66,121,32,100,101,102,97,117,108,116,32,108,111,111,107,115,32,102,111,114,32,99,111,110,102,105,103,32,105,110,32,36,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,36,72,79,77,69,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,97,110,100,32,36,72,79,77,69,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,46,0,0,0,0,0,9,45,83,47,45,45,115,97,118,101,115,116,97,116,101,58,32,80,97,116,104,32,116,111,32,117,115,101,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,115,46,32,73,102,32,110,111,116,32,115,101,108,101,99,116,101,100,44,32,42,46,115,116,97,116,101,32,119,105,108,108,32,98,101,32,97,115,115,117,109,101,100,46,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,46,10,0,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,95,102,114,97,109,101,115,0,0,82,101,116,114,111,65,114,99,104,58,32,83,73,78,67,32,112,97,114,97,109,115,32,40,37,117,32,112,104,97,115,101,32,98,105,116,115,44,32,37,117,32,116,97,112,115,41,46,10,0,0,0,0,0,0,0,33,33,33,32,35,105,110,99,108,117,100,101,32,100,101,112,116,104,32,101,120,99,101,101,100,101,100,32,102,111,114,32,99,111,110,102,105,103,46,32,77,105,103,104,116,32,98,101,32,97,32,99,121,99,108,101,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,80,78,71,93,58,32,85,115,105,110,103,32,82,80,78,71,32,108,111,97,100,101,114,46,10,0,0,9,45,102,47,45,45,102,117,108,108,115,99,114,101,101,110,58,32,83,116,97,114,116,32,82,101,116,114,111,65,114,99,104,32,105,110,32,102,117,108,108,115,99,114,101,101,110,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,99,111,110,102,105,103,32,115,101,116,116,105,110,103,115,46,0,0,105,111,115,95,98,97,115,101,58,58,99,108,101,97,114,0,9,45,115,47,45,45,115,97,118,101,58,32,80,97,116,104,32,102,111,114,32,115,97,118,101,32,102,105,108,101,32,40,42,46,115,114,109,41,46,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,101,101,100,32,116,111,32,100,101,102,105,110,101,32,97,116,32,108,101,97,115,116,32,49,32,115,104,97,100,101,114,46,10,0,9,45,45,102,101,97,116,117,114,101,115,58,32,80,114,105,110,116,115,32,97,118,97,105,108,97,98,108,101,32,102,101,97,116,117,114,101,115,32,99,111,109,112,105,108,101,100,32,105,110,116,111,32,82,101,116,114,111,65,114,99,104,46,0,103,108,80,117,115,104,68,101,98,117,103,71,114,111,117,112,0,0,0,0,0,0,0,0,70,114,97,109,101,68,105,114,101,99,116,105,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,99,114,101,97,116,105,110,103,32,70,66,79,32,116,101,120,116,117,114,101,32,35,37,100,58,32,37,117,120,37,117,10,0,0,0,71,65,77,69,32,40,37,115,41,32,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,71,85,73,93,58,32,79,112,101,110,105,110,103,32,104,105,115,116,111,114,121,58,32,37,115,46,10,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,88,77,76,32,115,104,97,100,101,114,32,97,116,116,114,105,98,117,116,101,115,32,100,111,32,110,111,116,32,99,111,109,112,108,121,32,119,105,116,104,32,115,112,101,99,105,102,105,99,97,116,105,111,110,115,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,111,118,101,114,108,97,121,32,100,101,115,99,46,10,0,0,99,97,114,116,114,105,100,103,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,9,9,73,102,32,110,111,32,97,114,103,117,109,101,110,116,115,32,97,114,101,32,112,97,115,115,101,100,32,116,111,32,82,101,116,114,111,65,114,99,104,44,32,105,116,32,105,115,32,101,113,117,105,118,97,108,101,110,116,32,116,111,32,117,115,105,110,103,32,45,45,109,101,110,117,32,97,115,32,111,110,108,121,32,97,114,103,117,109,101,110,116,46,0,0,0,47,62,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,114,101,32,111,112,116,105,111,110,58,10,0,0,0,0,0,0,0,0,9,45,45,109,101,110,117,58,32,68,111,32,110,111,116,32,114,101,113,117,105,114,101,32,82,79,77,32,111,114,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,116,111,32,98,101,32,108,111,97,100,101,100,44,32,115,116,97,114,116,115,32,100,105,114,101,99,116,108,121,32,105,110,32,109,101,110,117,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,115,101,116,116,105,110,103,32,103,97,109,101,46,10,0,0,0,0,0,9,45,104,47,45,45,104,101,108,112,58,32,83,104,111,119,32,116,104,105,115,32,104,101,108,112,32,109,101,115,115,97,103,101,46,0,0,0,0,0,88,32,98,117,116,116,111,110,32,40,116,111,112,41,0,0,85,115,97,103,101,58,32,114,101,116,114,111,97,114,99,104,32,91,114,111,109,32,102,105,108,101,93,32,91,111,112,116,105,111,110,115,46,46,46,93,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,114,111,110,116,101,110,100,32,102,111,114,32,108,105,98,114,101,116,114,111,32,45,45,32,118,48,46,57,46,57,46,51,32,45,45,0,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,0,77,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,83,99,114,105,112,116,32,115,117,112,112,111,114,116,32,105,110,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,68,105,115,107,32,83,119,97,112,32,78,101,120,116,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,0,105,110,99,108,117,100,101,32,0,0,0,0,0,0,0,0,80,121,116,104,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,109,111,110,105,116,111,114,32,72,122,58,32,37,46,54,102,32,72,122,46,32,40,37,46,51,102,32,37,37,32,102,114,97,109,101,32,116,105,109,101,32,100,101,118,105,97,116,105,111,110,44,32,98,97,115,101,100,32,111,110,32,37,117,32,108,97,115,116,32,115,97,109,112,108,101,115,41,46,10,0,0,0,0,0,0,68,105,115,107,32,69,106,101,99,116,32,84,111,103,103,108,101,0,0,0,0,0,0,0,37,112,0,0,0,0,0,0,80,101,101,114,45,116,111,45,112,101,101,114,32,110,101,116,112,108,97,121,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,46,10,0,0,78,101,120,116,32,79,118,101,114,108,97,121,0,0,0,0,78,101,116,112,108,97,121,0,103,108,71,101,116,68,101,98,117,103,77,101,115,115,97,103,101,76,111,103,0,0,0,0,70,114,97,109,101,67,111,117,110,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,105,110,105,116,32,70,66,79,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,86,111,108,117,109,101,32,68,111,119,110,0,0,0,0,0,78,111,32,67,111,114,101,0,46,114,101,116,114,111,97,114,99,104,45,103,97,109,101,45,104,105,115,116,111,114,121,46,116,120,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,100,101,114,110,32,71,76,83,76,32,119,97,115,32,99,104,111,115,101,110,32,97,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,119,97,115,32,110,111,116,32,112,114,111,118,105,100,101,100,46,32,84,104,105,115,32,105,115,32,97,110,32,101,114,114,111,114,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,107,101,121,58,32,37,115,46,10,0,0,0,84,84,70,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,119,105,116,104,32,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,85,112,0,0,0,0,0,0,0,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,69,110,97,98,108,101,32,72,111,116,107,101,121,0,0,0,79,110,45,116,104,101,45,102,108,121,32,114,101,99,111,114,100,105,110,103,32,111,102,32,103,97,109,101,112,108,97,121,32,119,105,116,104,32,108,105,98,97,118,99,111,100,101,99,0,0,0,0,0,0,0,0,83,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,70,70,109,112,101,103,0,0,78,101,116,112,108,97,121,32,70,108,105,112,32,80,108,97,121,101,114,115,0,0,0,0,68,121,110,97,109,105,99,32,114,117,110,45,116,105,109,101,32,108,111,97,100,105,110,103,32,111,102,32,108,105,98,114,101,116,114,111,32,108,105,98,114,97,114,121,0,0,0,0,68,121,110,97,109,105,99,0,68,83,80,32,67,111,110,102,105,103,0,0,0,0,0,0,79,112,101,110,71,76,32,114,101,110,100,101,114,45,116,111,45,116,101,120,116,117,114,101,32,40,109,117,108,116,105,45,112,97,115,115,32,115,104,97,100,101,114,115,41,0,0,0,83,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,118,105,100,101,111,95,118,115,121,110,99,0,0,0,0,0,70,66,79,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,111,101,115,32,110,111,116,32,104,97,118,101,32,101,110,111,117,103,104,32,115,97,109,112,108,101,115,32,102,111,114,32,109,111,110,105,116,111,114,32,114,101,102,114,101,115,104,32,114,97,116,101,32,101,115,116,105,109,97,116,105,111,110,46,32,82,101,113,117,105,114,101,115,32,116,111,32,114,117,110,32,102,111,114,32,97,116,32,108,101,97,115,116,32,37,117,32,102,114,97,109,101,115,46,10,0,0,0,67,104,101,97,116,32,84,111,103,103,108,101,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,56,0,0,0,83,68,76,95,105,109,97,103,101,32,105,109,97,103,101,32,108,111,97,100,105,110,103,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,67,104,101,97,116,32,73,110,100,101,120,32,77,105,110,117,115,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,55,0,0,0,83,68,76,95,105,109,97,103,101,0,0,0,0,0,0,0,67,83,117,115,105,101,58,58,67,111,110,116,101,120,116,83,97,118,101,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,97,108,108,98,97,99,107,0,0,84,101,120,116,117,114,101,83,105,122,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,69,71,76,32,105,109,97,103,101,46,10,0,67,104,101,97,116,32,73,110,100,101,120,32,80,108,117,115,0,0,0,0,0,0,0,0,83,89,83,84,69,77,32,68,73,82,32,37,115,0,0,0,102,114,97,103,109,101,110,116,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,0,0,0,0,0,0,0,0,43,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,54,0,0,0,108,105,98,120,109,108,50,32,88,77,76,32,112,97,114,115,105,110,103,0,0,0,0,0,80,114,101,118,105,111,117,115,32,83,104,97,100,101,114,0,105,110,112,117,116,95,112,108,97,121,101,114,53,0,0,0,108,105,98,120,109,108,50,0,83,97,118,101,32,115,116,97,116,101,47,109,111,118,105,101,32,115,108,111,116,58,32,37,117,0,0,0,0,0,0,0,78,101,120,116,32,83,104,97,100,101,114,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,52,0,0,0,67,103,32,112,105,120,101,108,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,0,82,101,115,101,116,0,0,0,65,32,98,117,116,116,111,110,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,51,0,0,0,67,103,0,0,0,0,0,0,70,114,97,109,101,32,65,100,118,97,110,99,101,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,50,0,0,0,69,120,116,101,114,110,97,108,32,102,105,108,116,101,114,32,97,110,100,32,112,108,117,103,105,110,32,115,117,112,112,111,114,116,0,0,0,0,0,0,80,97,117,115,101,32,84,111,103,103,108,101,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,49,0,0,0,69,120,116,101,114,110,97,108,0,0,0,0,0,0,0,0,77,111,118,105,101,32,82,101,99,111,114,100,32,84,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,111,117,110,100,32,105,110,118,97,108,105,100,32,104,97,116,32,105,110,32,99,111,110,102,105,103,33,10,0,0,0,0,0,0,0,79,112,101,110,65,76,0,0,118,105,100,101,111,95,100,105,115,97,98,108,101,95,99,111,109,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,80,78,71,32,101,110,99,111,100,101,47,100,101,99,111,100,101,32,97,110,100,32,46,122,105,112,32,101,120,116,114,97,99,116,105,111,110,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,110,105,116,111,114,32,70,80,83,32,101,115,116,105,109,97,116,105,111,110,32,105,115,32,100,105,115,97,98,108,101,100,32,102,111,114,32,116,104,114,101,97,100,101,100,32,118,105,100,101,111,46,10,0,0,0,0,0,0,83,116,97,116,101,32,83,108,111,116,32,77,105,110,117,115,0,0,0,0,0,0,0,0,122,108,105,98,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,82,79,77,32,116,121,112,101,46,10,0,83,116,97,116,101,32,83,108,111,116,32,80,108,117,115,0,105,110,112,117,116,95,100,114,105,118,101,114,0,0,0,0,88,65,117,100,105,111,50,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,73,110,115,101,114,116,0,0,0,0,79,117,116,112,117,116,83,105,122,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,34,37,115,34,32,102,111,114,32,114,101,99,111,114,100,105,110,103,46,10,0,0,0,0,0,111,110,0,0,0,0,0,0,81,117,105,116,32,75,101,121,0,0,0,0,0,0,0,0,79,86,69,82,76,65,89,32,68,73,82,32,37,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,109,101,110,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,104,97,100,101,114,32,115,111,117,114,99,101,32,102,105,108,101,32,119,97,115,32,112,114,111,118,105,100,101,100,44,32,98,117,116,32,102,97,105,108,101,100,32,116,111,32,114,101,97,100,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,100,101,115,99,115,32,102,111,114,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,99,111,100,101,0,0,0,0,68,105,114,101,99,116,83,111,117,110,100,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,84,111,103,103,108,101,0,0,0,0,0,0,0,80,117,108,115,101,65,117,100,105,111,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,0,0,0,37,115,95,37,115,95,97,120,105,115,0,0,0,0,0,0,82,111,97,114,65,117,100,105,111,0,0,0,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,84,101,120,116,117,114,101,50,68,79,69,83,0,0,0,0,37,115,95,37,115,95,98,116,110,0,0,0,0,0,0,0,82,83,111,117,110,100,0,0,70,97,115,116,32,70,111,114,119,97,114,100,32,72,111,108,100,0,0,0,0,0,0,0,105,110,112,117,116,0,0,0,74,97,99,107,0,0,0,0,89,32,40,108,101,102,116,41,0,0,0,0,0,0,0,0,70,97,115,116,32,70,111,114,119,97,114,100,0,0,0,0,37,115,95,37,115,0,0,0,79,83,83,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,45,0,0,0,0,0,0,0,0,110,117,108,0,0,0,0,0,97,117,100,105,111,32,100,114,105,118,101,114,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,43,0,0,0,0,0,0,0,0,118,105,100,101,111,95,109,111,110,105,116,111,114,95,105,110,100,101,120,0,0,0,0,0,40,105,110,99,108,117,100,101,100,41,0,0,0,0,0,0,112,97,117,115,101,0,0,0,65,76,83,65,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,45,0,0,0,0,0,0,0,0,98,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0])
.concat([103,108,115,108,0,0,0,0,88,86,105,100,101,111,32,111,117,116,112,117,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,101,120,116,114,97,99,116,32,82,79,77,32,102,114,111,109,32,122,105,112,112,101,100,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,67,0,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,43,0,0,0,0,0,0,0,0,101,109,115,99,114,105,112,116,101,110,0,0,0,0,0,0,88,86,105,100,101,111,0,0,67,77,105,107,105,101,58,58,67,111,110,116,101,120,116,83,97,118,101,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,111,110,116,114,111,108,0,0,0,73,110,112,117,116,83,105,122,101,0,0,0,0,0,0,0,111,102,102,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,45,0,83,65,86,69,70,73,76,69,32,68,73,82,32,37,115,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,102,97,105,108,101,100,46,10,0,0,0,0,71,76,32,114,97,115,116,101,114,0,0,0,0,0,0,0,115,114,99,0,0,0,0,0,104,97,110,100,121,95,114,111,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,100,101,115,99,115,46,10,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,115,99,114,111,108,108,95,108,111,99,107,0,0,0,0,0,79,112,101,110,86,71,32,111,117,116,112,117,116,32,115,117,112,112,111,114,116,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,43,0,112,114,105,110,116,95,115,99,114,101,101,110,0,0,0,0,79,112,101,110,86,71,0,0,83,97,118,101,100,32,115,116,97,116,101,32,116,111,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,45,0,100,105,118,105,100,101,0,0,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,43,0,82,105,103,104,116,32,68,45,112,97,100,0,0,0,0,0,109,117,108,116,105,112,108,121,0,0,0,0,0,0,0,0,69,71,76,0,0,0,0,0,84,117,114,98,111,32,69,110,97,98,108,101,0,0,0,0,75,77,83,47,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,66,32,40,98,111,116,116,111,109,41,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,51,32,66,117,116,116,111,110,0,0,0,0,0,0,110,117,109,108,111,99,107,0,75,77,83,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,51,32,66,117,116,116,111,110,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,114,101,97,116,105,110,103,32,70,66,79,32,37,100,32,64,32,37,117,120,37,117,10,0,0,0,0,0,99,97,112,115,108,111,99,107,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,79,86,69,82,83,67,65,78,58,32,37,117,10,0,0,0,0,79,112,101,110,71,76,32,100,114,105,118,101,114,0,0,0,82,101,116,114,111,80,97,100,32,82,50,32,66,117,116,116,111,110,0,0,0,0,0,0,118,105,100,101,111,95,119,105,110,100,111,119,101,100,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,32,37,115,10,0,0,0,79,112,101,110,71,76,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,105,110,105,116,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,50,32,66,117,116,116,111,110,0,0,0,0,0,0,107,101,121,112,97,100,57,0,84,104,114,101,97,100,105,110,103,32,115,117,112,112,111,114,116,0,0,0,0,0,0,0,122,105,112,0,0,0,0,0,66,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,32,66,117,116,116,111,110,0,0,0,0,0,0,0,118,101,99,116,111,114,0,0,107,101,121,112,97,100,56,0,84,104,114,101,97,100,115,0,67,54,53,48,50,58,58,67,111,110,116,101,120,116,83,97,118,101,0,0,0,0,0,0,103,108,73,115,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,0,0,76,85,84,84,101,120,67,111,111,114,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,32,86,83,121,110,99,32,61,62,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,32,66,117,116,116,111,110,0,0,0,0,0,0,0,83,65,86,69,83,84,65,84,69,32,68,73,82,32,37,115,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,37,115,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,104,97,118,101,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,105,110,32,97,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,110,117,109,98,101,114,32,111,102,32,100,101,115,99,115,32,102,114,111,109,32,99,111,110,102,105,103,32,107,101,121,58,32,37,115,46,10,0,0,0,0,99,104,101,97,116,0,0,0,107,101,121,112,97,100,55,0,83,68,76,32,100,114,105,118,101,114,115,0,0,0,0,0,82,101,116,114,111,80,97,100,32,88,32,66,117,116,116,111,110,0,0,0,0,0,0,0,114,98,0,0,0,0,0,0,107,101,121,112,97,100,54,0,83,68,76,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,0,82,101,116,114,111,80,97,100,32,65,32,66,117,116,116,111,110,0,0,0,0,0,0,0,107,101,121,112,97,100,53,0,9,37,115,58,10,9,9,37,115,58,32,37,115,10,0,0,37,102,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,107,101,121,112,97,100,52,0,70,101,97,116,117,114,101,115,58,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,107,101,121,112,97,100,51,0,107,101,121,112,97,100,50,0,78,111,116,32,97,32,114,101,99,111,103,110,105,115,101,100,32,76,83,83,32,102,105,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,88,82,71,66,56,56,56,56,46,10,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,45,45,109,101,110,117,32,119,97,115,32,117,115,101,100,44,32,98,117,116,32,82,79,77,32,102,105,108,101,32,119,97,115,32,112,97,115,115,101,100,32,97,115,32,119,101,108,108,46,10,0,107,101,121,112,97,100,49,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,114,103,117,109,101,110,116,115,46,10,0,0,107,101,121,112,97,100,48,0,82,101,116,114,111,80,97,100,32,83,116,97,114,116,32,66,117,116,116,111,110,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,32,105,110,32,45,45,115,114,97,109,45,109,111,100,101,46,10,0,0,112,97,103,101,100,111,119,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,112,104,105,99,115,32,100,114,105,118,101,114,32,100,105,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,97,110,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,112,105,99,107,32,97,32,115,117,105,116,97,98,108,101,32,100,114,105,118,101,114,46,10,0,0,0,82,101,116,114,111,80,97,100,32,83,101,108,101,99,116,32,66,117,116,116,111,110,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,114,101,115,111,108,118,101,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,33,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,81,117,105,116,32,82,101,116,114,111,65,114,99,104,0,0,108,111,97,100,45,115,97,118,101,0,0,0,0,0,0,0,112,97,103,101,117,112,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,116,111,32,34,37,115,34,46,10,0,65,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,89,32,66,117,116,116,111,110,0,0,0,0,0,0,0,82,101,115,116,97,114,116,32,82,101,116,114,111,65,114,99,104,0,0,0,0,0,0,0,37,46,48,76,102,0,0,0,108,111,97,100,45,110,111,115,97,118,101,0,0,0,0,0,110,117,109,57,0,0,0,0,103,108,71,101,110,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,0,0,0,67,111,108,111,114,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,51,50,45,98,105,116,32,70,66,79,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,49,54,45,98,105,116,46,10,0,0,0,0,82,101,116,114,111,80,97,100,32,66,32,66,117,116,116,111,110,0,0,0,0,0,0,0,83,72,65,68,69,82,32,68,73,82,32,37,115,0,0,0,82,101,116,114,111,65,114,99,104,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,115,117,99,99,101,101,100,101,100,46,10,0,0,0,118,101,114,116,101,120,0,0,82,101,115,116,97,114,116,32,71,97,109,101,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,115,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,99,104,101,97,116,32,102,111,114,32,103,97,109,101,58,32,34,37,115,34,10,0,0,110,111,108,111,97,100,45,115,97,118,101,0,0,0,0,0,110,117,109,56,0,0,0,0,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,0,82,101,115,117,109,101,32,71,97,109,101,0,0,0,0,0,110,111,108,111,97,100,45,110,111,115,97,118,101,0,0,0,76,111,97,100,101,100,32,115,116,97,116,101,32,102,114,111,109,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,110,117,109,55,0,0,0,0,84,97,107,101,32,83,99,114,101,101,110,115,104,111,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,115,99,111,110,110,101,99,116,32,100,101,118,105,99,101,32,102,114,111,109,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,110,117,109,54,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,0,0,0,0,0,0,0,76,101,102,116,32,68,45,112,97,100,0,0,0,0,0,0,76,111,97,100,32,83,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,109,111,117,115,101,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,110,117,109,53,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,58,32,37,115,46,10,0,0,0,83,97,118,101,32,83,116,97,116,101,0,0,0,0,0,0,112,97,114,115,101,95,105,110,112,117,116,40,41,0,0,0,110,117,109,52,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,82,71,66,53,54,53,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,46,10,0,0,0,0,0,68,105,115,107,32,79,112,116,105,111,110,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,0,110,117,109,51,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,114,111,109,58,32,37,115,46,10,0,0,0,0,83,101,116,116,105,110,103,115,0,0,0,0,0,0,0,0,104,115,58,102,118,83,58,109,58,112,52,106,74,65,58,103,58,98,58,99,58,66,58,89,58,90,58,85,58,68,78,58,88,58,80,58,82,58,77,58,0,0,0,0,0,0,0,0,110,117,109,50,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,121,0,0,0,0,0,0,35,105,110,99,108,117,100,101,32,34,37,115,34,10,0,0,80,97,116,104,32,79,112,116,105,111,110,115,0,0,0,0,102,101,97,116,117,114,101,115,0,0,0,0,0,0,0,0,110,117,109,49,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,111,112,101,110,32,118,105,100,101,111,32,100,114,105,118,101,114,32,46,46,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,47,101,116,99,0,0,0,0,110,117,108,108,0,0,0,0,47,112,114,111,99,47,37,117,47,37,115,0,0,0,0,0,73,110,112,117,116,32,79,112,116,105,111,110,115,0,0,0,100,101,116,97,99,104,0,0,110,117,109,48,0,0,0,0,115,105,110,99,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,114,101,99,111,118,101,114,32,46,46,46,10,0,0,37,115,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,0,65,117,100,105,111,32,79,112,116,105,111,110,115,0,0,0,109,111,110,101,121,95,103,101,116,32,101,114,114,111,114,0,120,109,108,0,0,0,0,0,102,49,50,0,0,0,0,0,91,104,97,110,100,121,93,78,111,116,32,97,32,114,101,99,111,103,110,105,115,101,100,32,76,83,83,32,102,105,108,101,10,0,0,0,0,0,0,0,103,108,68,101,108,101,116,101,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,86,101,114,116,101,120,67,111,111,114,100,0,0,0,0,0,46,116,103,97,0,0,0,0,65,82,77,95,97,114,103,98,56,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,111,107,105,110,103,32,102,111,114,32,99,111,110,102,105,103,32,105,110,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,66,82,79,87,83,69,82,32,68,73,82,32,37,115,0,0,98,105,116,109,97,112,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,76,101,103,97,99,121,32,115,104,97,100,101,114,115,32,97,114,101,32,100,101,112,114,101,99,97,116,101,100,46,10,0,0,0,0,0,0,0,86,105,100,101,111,32,79,112,116,105,111,110,115,0,0,0,111,118,101,114,108,97,121,37,117,95,102,117,108,108,95,115,99,114,101,101,110,0,0,0,110,97,109,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,110,111,45,112,97,116,99,104,0,0,0,0,0,0,0,0,102,49,49,0,0,0,0,0,37,115,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,67,111,114,101,32,79,112,116,105,111,110,115,0,0,0,0,105,112,115,0,0,0,0,0,102,49,48,0,0,0,0,0,37,115,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,76,111,97,100,32,71,97,109,101,0,0,0,0,0,0,0,98,112,115,0,0,0,0,0,102,57,0,0,0,0,0,0,72,79,77,69,0,0,0,0,76,111,97,100,32,71,97,109,101,32,40,72,105,115,116,111,114,121,41,0,0,0,0,0,117,112,115,0,0,0,0,0,102,56,0,0,0,0,0,0,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,0,48,0,0,0,0,0,0,0,114,103,117,105,46,99,103,112,0,0,0,0,0,0,0,0,115,114,97,109,45,109,111,100,101,0,0,0,0,0,0,0,102,55,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,48,82,71,66,49,53,53,53,46,10,0,91,104,97,110,100,121,93,76,83,83,32,83,110,97,112,115,104,111,116,32,67,82,67,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,108,111,97,100,101,100,32,99,97,114,116,114,105,100,103,101,32,105,109,97,103,101,44,32,97,98,111,114,116,105,110,103,32,108,111,97,100,46,10,0,0,0,0,0,0,114,103,117,105,46,103,108,115,108,112,0,0,0,0,0,0,98,115,118,114,101,99,111,114,100,0,0,0,0,0,0,0,102,54,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,46,46,46,10,0,98,115,118,112,108,97,121,0,102,53,0,0,0,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,120,0,0,0,0,0,0,83,97,116,0,0,0,0,0,82,51,0,0,0,0,0,0,115,117,102,97,109,105,66,0,102,52,0,0,0,0,0,0,105,110,105,116,95,118,105,100,101,111,95,105,110,112,117,116,40,41,0,0,0,0,0,0,112,97,116,104,47,97,46,111,117,116,0,0,0,0,0,0,70,114,105,0,0,0,0,0,76,51,0,0,0,0,0,0,115,117,102,97,109,105,65,0,102,51,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,83,82,65,77,46,10,0,0,0,0,0,0,84,104,117,0,0,0,0,0,105,111,115,116,114,101,97,109,0,0,0,0,0,0,0,0,82,50,0,0,0,0,0,0,37,76,102,0,0,0,0,0,109,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,102,50,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,97,114,116,46,10,0,0,3,3,11,0,0,0,0,0,103,108,66,105,110,100,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,84,101,120,67,111,111,114,100,0,0,0,0,0,0,0,0,79,69,83,95,114,103,98,56,95,114,103,98,97,56,0,0,79,86,69,82,76,65,89,32,37,115,0,0,0,0,0,0,73,78,70,79,32,45,32,76,111,97,100,105,110,103,32,37,115,32,46,46,46,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,114,101,112,111,114,116,115,32,97,32,71,76,69,83,50,32,115,116,121,108,101,32,115,104,97,100,101,114,46,10,0,0,87,101,100,0,0,0,0,0,76,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,114,101,99,116,32,34,37,115,34,32,105,110,116,111,32,97,116,32,108,101,97,115,116,32,102,111,117,114,32,116,111,107,101,110,115,46,10,0,0,0,115,99,97,108,101,95,121,37,117,0,0,0,0,0,0,0,98,115,120,115,108,111,116,0,102,49,0,0,0,0,0,0,84,117,101,0,0,0,0,0,115,99,97,108,101,95,120,37,117,0,0,0,0,0,0,0,98,115,120,0,0,0,0,0,37,115,37,117,0,0,0,0,107,112,95,109,105,110,117,115,0,0,0,0,0,0,0,0,77,111,110,0,0,0,0,0,115,99,97,108,101,37,117,0,115,97,118,101,115,116,97,116,101,0,0,0,0,0,0,0,107,112,95,112,108,117,115,0,68,111,119,110,32,68,45,112,97,100,0,0,0,0,0,0,83,117,110,0,0,0,0,0,83,101,108,101,99,116,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,116,116,114,105,98,117,116,101,46,10,0,0,0,0,0,0,0,0,115,104,97,100,101,114,115,0,100,117,97,108,97,110,97,108,111,103,0,0,0,0,0,0,115,117,98,116,114,97,99,116,0,0,0,0,0,0,0,0,79,117,116,32,88,32,61,32,37,100,32,61,62,32,73,110,32,88,32,61,32,37,100,10,0,0,0,0,0,0,0,0,83,97,116,117,114,100,97,121,0,0,0,0,0,0,0,0,83,116,97,114,116,0,0,0,115,99,97,108,101,95,116,121,112,101,95,121,37,117,0,0,106,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,97,100,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,89,83,84,69,77,95,68,73,82,69,67,84,79,82,89,58,32,34,37,115,34,46,10,0,0,0,0,0,105,110,112,117,116,95,100,101,118,105,99,101,95,112,37,117,0,0,0,0,0,0,0,0,70,114,105,100,97,121,0,0,115,99,97,108,101,95,116,121,112,101,95,120,37,117,0,0,106,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,101,115,99,97,112,101,0,0,105,110,112,117,116,95,100,112,97,100,95,101,109,117,108,97,116,105,111,110,95,112,37,117,0,0,0,0,0,0,0,0,84,104,117,114,115,100,97,121,0,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,37,117,0,0,0,0,115,99,111,112,101,0,0,0,99,117,115,116,111,109,95,98,103,109,95,101,110,97,98,108,101,0,0,0,0,0,0,0,118,105,100,101,111,95,121,115,99,97,108,101,0,0,0,0,87,101,100,110,101,115,100,97,121,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,112,97,114,115,101,32,115,104,97,100,101,114,32,115,111,117,114,99,101,32,40,37,115,41,46,10,0,0,0,0,0,0,0,0,110,111,100,101,118,105,99,101,0,0,0,0,0,0,0,0,97,108,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,112,105,120,101,108,32,99,111,110,118,101,114,116,101,114,46,10,0,0,0,115,99,114,101,101,110,95,111,114,105,101,110,116,97,116,105,111,110,0,0,0,0,0,0,109,111,117,115,101,0,0,0,84,117,101,115,100,97,121,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,73,110,118,97,108,105,100,32,119,114,97,112,112,105,110,103,32,116,121,112,101,32,37,115,46,32,86,97,108,105,100,32,111,110,101,115,32,97,114,101,58,32,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,32,40,100,101,102,97,117,108,116,41,44,32,99,108,97,109,112,95,116,111,95,101,100,103,101,44,32,114,101,112,101,97,116,32,97,110,100,32,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,100,101,102,97,117,108,116,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,32,82,101,119,105,110,100,105,110,103,32,119,105,108,108,32,98,101,32,100,105,115,97,98,108,101,100,46,10,0,0,99,116,114,108,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,66,108,111,99,107,105,110,103,32,83,82,65,77,32,111,118,101,114,119,114,105,116,101,46,10,0,0,0,0,77,111,110,100,97,121,0,0,82,105,103,104,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,112,97,116,104,32,116,111,32,116,101,120,116,117,114,101,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,97,112,112,101,110,100,99,111,110,102,105,103,0,0,0,0,115,104,105,102,116,0,0,0,67,83,121,115,116,101,109,58,58,67,111,110,116,101,120,116,83,97,118,101,0,0,0,0,2,3,7,0,0,0,0,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,51,68,79,69,83,0,0,0,0,0,0,0,77,86,80,77,97,116,114,105,120,0,0,0,0,0,0,0,100,111,101,115,110,39,116,32,101,120,105,115,116,0,0,0,115,116,97,116,101,95,115,108,111,116,0,0,0,0,0,0,37,115,46,122,105,112,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,117,110,105,102,111,114,109,32,97,110,100,32,97,116,116,114,105,98,32,112,114,101,102,105,120,58,32,37,115,10,0,0,0,83,117,110,100,97,121,0,0,76,101,102,116,0,0,0,0,44,32,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,97,100,100,114,101,115,115,32,97,115,115,105,103,110,101,100,32,116,111,32,115,101,109,97,110,116,105,99,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,32,116,111,32,34,37,115,34,46,32,67,104,101,99,107,32,112,101,114,109,105,115,115,105,111,110,115,46,10,0,0,0,0,63,62,10,0,0,0,0,0,99,111,110,102,105,103,0,0,114,115,104,105,102,116,0,0,115,111,117,110,100,95,109,111,100,101,0,0,0,0,0,0,68,111,119,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,46,10,0,103,97,109,101,98,111,121,0,82,101,116,114,111,65,114,99,104,58,32,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,104,111,109,101,0,0,0,0,99,117,114,114,101,110,116,95,114,101,115,111,108,117,116,105,111,110,95,105,100,0,0,0,58,32,0,0,0,0,0,0,83,0,0,0,97,0,0,0,116,0,0,0,0,0,0,0,85,112,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,46,10,0,0,118,101,114,98,111,115,101,0,101,110,100,0,0,0,0,0,60,78,111,32,99,97,114,116,32,108,111,97,100,101,100,62,0,0,0,0,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,91,82,80,78,71,93,58,32,69,114,114,111,114,32,105,110,32,108,105,110,101,32,37,100,46,10,0,0,0,0,0,0,70,0,0,0,114,0,0,0,105,0,0,0,0,0,0,0,68,80,97,100,32,69,109,117,108,97,116,105,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,101,120,116,101,114,110,97,108,32,115,111,117,114,99,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,37,115,37,99,104,97,110,100,121,46,116,109,112,0,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,100,101,108,0,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,79,69,83,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,103,108,115,108,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,37,115,10,0,0,84,0,0,0,104,0,0,0,117,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,105,110,105,116,32,102,111,110,116,32,114,101,110,100,101,114,101,114,46,10,0,0,0,0,0,0,0,68,101,118,105,99,101,32,84,121,112,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,115,97,118,101,0,0,0,0,105,110,115,101,114,116,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,80,69,82,70,79,82,77,65,78,67,69,95,76,69,86,69,76,58,32,37,117,46,10,0,0,0,0,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,70,66,79,32,116,97,114,103,101,116,115,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,70,66,79,46,10,0,0,87,0,0,0,101,0,0,0,100,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,82,79,77,46,10,0,0,0,68,101,118,105,99,101,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,104,101,108,112,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,0,0,0,84,0,0,0,117,0,0,0,101,0,0,0,0,0,0,0,80,108,97,121,101,114,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,109,101,110,117,0,0,0,0,107,112,95,101,110,116,101,114,0,0,0,0,0,0,0,0,105,110,102,111,95,109,115,103,95,101,110,97,98,108,101,0,118,105,100,101,111,95,120,115,99,97,108,101,0,0,0,0,99,103,112,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,118,101,114,108,97,121,32,105,110,116,101,114,102,97,99,101,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,118,105,100,101,111,32,100,114,105,118,101,114,46,10,0,82,101,116,114,111,65,114,99,104,58,32,83,105,110,99,32,114,101,115,97,109,112,108,101,114,32,91,67,93,10,0,0,77,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,67,82,97,109,58,58,67,111,110,116,101,120,116,83,97,118,101,0,0,0,0,0,0,0,46,112,110,103,0,0,0,0,79,118,101,114,108,97,121,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,121,32,97,116,116,114,58,32,37,117,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,114,119,101,98,97,117,100,105,111,0,0,0,0,0,0,0,83,101,112,32,49,51,32,50,48,49,51,0,0,0,0,0,101,110,116,101,114,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,102,117,108,108,115,99,114,101,101,110,10,0,0,116,114,105,112,108,101,95,98,117,102,102,101,114,105,110,103,95,101,110,97,98,108,101,0,101,120,101,0,0,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,105,111,115,116,114,101,97,109,95,99,97,116,101,103,111,114,121,32,101,114,114,111,114,0,0,0,0,0,83,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,79,118,101,114,108,97,121,32,79,112,97,99,105,116,121,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,120,32,97,116,116,114,58,32,37,117,10,0,66,117,105,108,116,58,32,37,115,10,0,0,0,0,0,0,82,71,85,73,32,109,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,34,115,104,97,100,101,114,115,34,32,112,97,114,97,109,46,10,0,0,0,0,0,0,79,117,116,32,89,32,61,32,37,100,32,61,62,32,73,110,32,89,32,61,32,37,100,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,115,112,97,99,101,0,0,0,103,97,109,109,97,95,99,111,114,114,101,99,116,105,111,110,0,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,79,118,101,114,108,97,121,32,80,114,101,115,101,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,32,97,116,116,114,58,32,37,117,10,0,0,0,52,46,50,46,49,32,67,111,109,112,97,116,105,98,108,101,32,67,108,97,110,103,32,51,46,50,32,40,116,97,103,115,47,82,69,76,69,65,83,69,95,51,50,47,102,105,110,97,108,41,0,0,0,0,0,0,76,83,83,51,0,0,0,0,5,5,4,0,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,101,120,105,115,116,115,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,77,69,78,85,32,37,115,0,37,117,120,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,99,111,110,102,105,103,32,102,105,108,101,58,32,37,115,46,10,0,0,0,116,105,108,100,101,0,0,0,112,114,101,102,105,120,0,0,70,0,0,0,114,0,0,0,105,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,83,121,115,116,101,109,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,114,101,99,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,37,117,59,0,0,0,0,0,60,63,120,109,108,0,0,0,100,97,116,97,98,97,115,101,0,0,0,0,0,0,0,0,67,108,97,110,103,47,76,76,86,77,32,40,37,115,41,32,37,117,45,98,105,116,10,0,71,114,97,98,32,109,111,117,115,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,99,111,109,112,97,116,47,99,111,109,112,97,116,46,99,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,99,111,110,102,105,103,46,32,65,115,115,117,109,105,110,103,32,115,121,115,116,101,109,32,100,105,114,101,99,116,111,114,121,32,105,115,32,115,97,109,101,32,102,111,108,100,101,114,32,97,115,32,103,97,109,101,58,32,34,37,115,34,46,10,0,0,0,0,0,84,0,0,0,104,0,0,0,117,0,0,0,114,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,79,118,101,114,108,97,121,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,10,67,111,109,112,105,108,101,114,58,32,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,73,110,105,116,105,110,103,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,119,105,116,104,32,115,105,122,101,58,32,37,117,32,77,66,10,0,0,0,0,0,0,98,109,112,0,0,0,0,0,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,116,97,98,0,0,0,0,0,87,0,0,0,101,0,0,0,100,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,83,97,118,101,102,105,108,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,97,32,100,105,102,102,101,114,101,110,116,32,118,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,116,104,97,110,32,116,104,105,115,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,68,105,115,107,32,110,101,120,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,85,115,105,110,103,32,82,88,77,76,32,97,115,32,100,114,111,112,32,105,110,32,102,111,114,32,108,105,98,120,109,108,50,46,32,66,101,104,97,118,105,111,114,32,109,105,103,104,116,32,98,101,32,118,101,114,121,32,98,117,103,103,121,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,85,112,32,68,45,112,97,100,0,0,0,0,0,0,0,0,37,117,0,0,0,0,0,0,84,0,0,0,117,0,0,0,101,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,102,114,97,109,101,32,99,111,117,110,116,32,109,111,100,32,97,116,116,114,58,32,37,117,10,0,0,0,0,0,0,0,0,50,52,48,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,65,80,73,58,32,37,117,10,0,0,0,0,46,115,116,97,116,101,0,0,77,0,0,0,111,0,0,0,110,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,68])
.concat([105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,65,80,73,58,32,37,117,10,0,68,105,115,107,32,101,106,101,99,116,32,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,72,85,84,68,79,87,78,46,10,0,0,0,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,83,0,0,0,117,0,0,0,110,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,66,114,111,119,115,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,108,97,115,116,32,115,116,97,116,101,32,115,108,111,116,58,32,35,37,117,10,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,0,68,101,98,117,103,32,73,110,102,111,32,77,101,115,115,97,103,101,115,0,0,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,0,59,32,0,0,0,0,0,0,65,117,116,111,45,108,111,97,100,105,110,103,32,115,97,118,101,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,32,37,115,46,0,0,0,0,79,118,101,114,108,97,121,32,110,101,120,116,0,0,0,0,114,119,101,98,105,110,112,117,116,0,0,0,0,0,0,0,46,115,114,109,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,101,110,100,32,61,61,61,10,0,0,0,0,0,37,120,0,0,0,0,0,0,68,101,99,0,0,0,0,0,67,111,110,102,105,103,32,83,97,118,101,32,79,110,32,69,120,105,116,0,0,0,0,0,111,117,116,115,99,97,108,101,95,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,97,117,116,111,32,115,97,118,101,115,116,97,116,101,32,105,110,58,32,37,115,10,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,37,117,120,37,117,10,0,0,0,0,0,0,0,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,46,37,115,0,0,0,0,0,78,111,118,0,0,0,0,0,82,101,119,105,110,100,32,71,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,111,117,116,115,99,97,108,101,95,120,0,0,0,0,0,0,86,111,108,117,109,101,32,45,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,0,99,111,110,102,105,103,95,115,97,118,101,95,111,110,95,101,120,105,116,0,0,0,0,0,79,99,116,0,0,0,0,0,82,101,119,105,110,100,0,0,111,117,116,115,99,97,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,10,0,0,0,0,119,98,0,0,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,81,117,101,114,121,105,110,103,32,71,76,32,101,120,116,101,110,115,105,111,110,58,32,37,115,32,61,62,32,37,115,10,0,0,0,0,0,106,111,121,112,97,100,95,97,117,116,111,99,111,110,102,105,103,95,100,105,114,0,0,0,83,72,65,68,69,82,32,37,115,0,0,0,0,0,0,0,71,76,69,83,50,0,0,0,83,101,112,0,0,0,0,0,78,111,32,111,112,116,105,111,110,115,32,97,118,97,105,108,97,98,108,101,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,115,105,122,101,95,121,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,115,97,118,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,46,10,0,0,0,45,45,62,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,43,0,0,0,0,0,0,0,0,105,110,112,117,116,95,97,117,116,111,100,101,116,101,99,116,95,101,110,97,98,108,101,0,65,117,103,0,0,0,0,0,82,97,116,101,32,67,111,110,116,114,111,108,32,68,101,108,116,97,0,0,0,0,0,0,115,105,122,101,95,120,0,0,105,110,105,116,95,109,111,118,105,101,40,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,101,114,102,111,114,109,32,105,110,105,116,105,97,108,32,115,101,114,105,97,108,105,122,97,116,105,111,110,32,102,111,114,32,114,101,119,105,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,32,71,80,85,32,114,101,110,100,101,114,105,110,103,32,105,115,32,117,115,101,100,32,97,110,100,32,114,101,97,100,95,118,105,101,119,112,111,114,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,0,0,0,0,0,0,37,0,0,0,89,0,0,0,45,0,0,0,37,0,0,0,109,0,0,0,45,0,0,0,37,0,0,0,100,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,0,0,0,0,37,0,0,0,73,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,112,0,0,0,0,0,0,0,37,0,0,0,109,0,0,0,47,0,0,0,37,0,0,0,100,0,0,0,47,0,0,0,37,0,0,0,121,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,37,72,58,37,77,58,37,83,37,72,58,37,77,0,0,0,37,73,58,37,77,58,37,83,32,37,112,0,0,0,0,0,37,89,45,37,109,45,37,100,37,109,47,37,100,47,37,121,37,72,58,37,77,58,37,83,37,0,0,0,0,0,0,0,37,112,0,0,0,0,0,0,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,128,10,144,4,142,139,253,24,232,142,135,253,162,2,142,0,0,0,0,0,0,0,0,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,82,64,0,0,0,0,128,136,213,64,88,161,0,0,224,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,235,0,0,240,0,0,0,200,0,0,0,180,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,0,0,60,1,0,0,6,1,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,236,0,0,122,0,0,0,156,1,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,236,0,0,162,0,0,0,10,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,236,0,0,162,0,0,0,26,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,236,0,0,10,1,0,0,142,0,0,0,74,0,0,0,2,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,236,0,0,112,1,0,0,34,1,0,0,74,0,0,0,4,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,236,0,0,4,1,0,0,36,1,0,0,74,0,0,0,12,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,236,0,0,148,1,0,0,230,0,0,0,74,0,0,0,10,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,237,0,0,144,1,0,0,156,0,0,0,74,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,237,0,0,2,1,0,0,190,0,0,0,74,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,237,0,0,58,0,0,0,192,0,0,0,74,0,0,0,214,0,0,0,4,0,0,0,36,0,0,0,8,0,0,0,20,0,0,0,62,0,0,0,8,0,0,0,248,255,255,255,136,237,0,0,34,0,0,0,16,0,0,0,50,0,0,0,20,0,0,0,6,0,0,0,48,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,237,0,0,44,1,0,0,140,0,0,0,74,0,0,0,32,0,0,0,6,0,0,0,66,0,0,0,30,0,0,0,18,0,0,0,2,0,0,0,10,0,0,0,248,255,255,255,176,237,0,0,130,0,0,0,186,0,0,0,208,0,0,0,224,0,0,0,202,0,0,0,70,0,0,0,86,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,237,0,0,134,0,0,0,40,1,0,0,74,0,0,0,78,0,0,0,64,0,0,0,22,0,0,0,100,0,0,0,138,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,237,0,0,172,0,0,0,116,0,0,0,74,0,0,0,66,0,0,0,156,0,0,0,24,0,0,0,144,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,237,0,0,136,1,0,0,4,0,0,0,74,0,0,0,42,0,0,0,8,0,0,0,158,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,238,0,0,70,0,0,0,8,0,0,0,74,0,0,0,70,0,0,0,20,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,238,0,0,96,1,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,238,0,0,40,0,0,0,228,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,238,0,0,80,0,0,0,16,1,0,0,74,0,0,0,46,0,0,0,12,0,0,0,14,0,0,0,10,0,0,0,12,0,0,0,4,0,0,0,2,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,238,0,0,168,0,0,0,24,0,0,0,74,0,0,0,40,0,0,0,44,0,0,0,40,0,0,0,42,0,0,0,38,0,0,0,10,0,0,0,8,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,238,0,0,60,0,0,0,30,0,0,0,74,0,0,0,54,0,0,0,52,0,0,0,44,0,0,0,46,0,0,0,34,0,0,0,50,0,0,0,42,0,0,0,60,0,0,0,58,0,0,0,56,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,238,0,0,46,1,0,0,6,0,0,0,74,0,0,0,82,0,0,0,76,0,0,0,70,0,0,0,72,0,0,0,64,0,0,0,74,0,0,0,68,0,0,0,32,0,0,0,80,0,0,0,78,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,238,0,0,128,0,0,0,154,0,0,0,74,0,0,0,16,0,0,0,56,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,238,0,0,38,0,0,0,20,1,0,0,74,0,0,0,22,0,0,0,66,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,238,0,0,110,1,0,0,220,0,0,0,74,0,0,0,14,0,0,0,4,0,0,0,24,0,0,0,24,0,0,0,112,0,0,0,4,0,0,0,230,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,239,0,0,92,1,0,0,106,0,0,0,74,0,0,0,2,0,0,0,8,0,0,0,14,0,0,0,188,0,0,0,178,0,0,0,12,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,239,0,0,92,1,0,0,222,0,0,0,74,0,0,0,16,0,0,0,6,0,0,0,2,0,0,0,232,0,0,0,198,0,0,0,10,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,239,0,0,92,1,0,0,250,0,0,0,74,0,0,0,10,0,0,0,12,0,0,0,20,0,0,0,54,0,0,0,140,0,0,0,6,0,0,0,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,239,0,0,92,1,0,0,48,0,0,0,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,239,0,0,92,0,0,0,212,0,0,0,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,239,0,0,92,1,0,0,136,0,0,0,74,0,0,0,38,0,0,0,4,0,0,0,10,0,0,0,18,0,0,0,38,0,0,0,56,0,0,0,70,0,0,0,8,0,0,0,16,0,0,0,16,0,0,0,22,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,239,0,0,154,1,0,0,52,0,0,0,74,0,0,0,6,0,0,0,6,0,0,0,58,0,0,0,68,0,0,0,26,0,0,0,12,0,0,0,48,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,239,0,0,210,0,0,0,102,1,0,0,142,0,0,0,82,0,0,0,62,0,0,0,64,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,239,0,0,92,1,0,0,144,0,0,0,74,0,0,0,10,0,0,0,12,0,0,0,20,0,0,0,54,0,0,0,140,0,0,0,6,0,0,0,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,92,1,0,0,122,1,0,0,74,0,0,0,10,0,0,0,12,0,0,0,20,0,0,0,54,0,0,0,140,0,0,0,6,0,0,0,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,240,0,0,216,0,0,0,116,1,0,0,66,0,0,0,40,0,0,0,24,0,0,0,46,0,0,0,164,0,0,0,182,0,0,0,60,0,0,0,46,0,0,0,42,0,0,0,20,0,0,0,76,0,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,240,0,0,62,1,0,0,100,0,0,0,156,0,0,0,72,0,0,0,52,0,0,0,30,0,0,0,82,0,0,0,160,0,0,0,34,0,0,0,12,0,0,0,18,0,0,0,106,0,0,0,32,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,40,240,0,0,254,0,0,0,22,1,0,0,148,255,255,255,148,255,255,255,40,240,0,0,166,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,88,240,0,0,66,0,0,0,82,1,0,0,252,255,255,255,252,255,255,255,88,240,0,0,236,0,0,0,214,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,112,240,0,0,98,1,0,0,118,1,0,0,252,255,255,255,252,255,255,255,112,240,0,0,188,0,0,0,68,1,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,136,240,0,0,148,0,0,0,158,1,0,0,248,255,255,255,248,255,255,255,136,240,0,0,94,1,0,0,114,1,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,160,240,0,0,182,0,0,0,76,1,0,0,248,255,255,255,248,255,255,255,160,240,0,0,72,0,0,0,82,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,240,0,0,88,1,0,0,112,0,0,0,114,0,0,0,12,0,0,0,18,0,0,0,54,0,0,0,76,0,0,0,160,0,0,0,34,0,0,0,170,0,0,0,18,0,0,0,54,0,0,0,32,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,240,0,0,74,1,0,0,26,1,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,240,0,0,138,1,0,0,30,1,0,0,42,0,0,0,40,0,0,0,24,0,0,0,46,0,0,0,94,0,0,0,182,0,0,0,60,0,0,0,46,0,0,0,42,0,0,0,20,0,0,0,76,0,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,241,0,0,252,0,0,0,78,1,0,0,92,0,0,0,72,0,0,0,52,0,0,0,30,0,0,0,166,0,0,0,160,0,0,0,34,0,0,0,12,0,0,0,18,0,0,0,106,0,0,0,32,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,241,0,0,104,1,0,0,234,0,0,0,74,0,0,0,128,0,0,0,212,0,0,0,126,0,0,0,190,0,0,0,14,0,0,0,80,0,0,0,84,0,0,0,58,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,241,0,0,180,0,0,0,88,0,0,0,74,0,0,0,196,0,0,0,206,0,0,0,162,0,0,0,176,0,0,0,178,0,0,0,64,0,0,0,200,0,0,0,140,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,241,0,0,108,1,0,0,196,0,0,0,74,0,0,0,22,0,0,0,106,0,0,0,130,0,0,0,118,0,0,0,34,0,0,0,142,0,0,0,172,0,0,0,146,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,241,0,0,130,0,0,0,14,1,0,0,74,0,0,0,184,0,0,0,190,0,0,0,78,0,0,0,170,0,0,0,68,0,0,0,48,0,0,0,144,0,0,0,168,0,0,0,164,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,241,0,0,58,1,0,0,22,0,0,0,148,0,0,0,40,0,0,0,24,0,0,0,46,0,0,0,164,0,0,0,182,0,0,0,60,0,0,0,138,0,0,0,152,0,0,0,32,0,0,0,76,0,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,241,0,0,18,0,0,0,100,1,0,0,160,0,0,0,72,0,0,0,52,0,0,0,30,0,0,0,82,0,0,0,160,0,0,0,34,0,0,0,26,0,0,0,234,0,0,0,8,0,0,0,32,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,241,0,0,142,1,0,0,64,1,0,0,110,0,0,0,244,0,0,0,18,0,0,0,30,0,0,0,14,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,242,0,0,70,1,0,0,140,1,0,0,146,1,0,0,74,0,0,0,90,0,0,0,104,0,0,0,52,0,0,0,60,0,0,0,46,0,0,0,72,0,0,0,10,0,0,0,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,242,0,0,106,1,0,0,20,0,0,0,64,0,0,0,84,0,0,0,114,0,0,0,50,0,0,0,112,0,0,0,4,0,0,0,48,0,0,0,132,0,0,0,58,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,242,0,0,42,1,0,0,134,1,0,0,32,0,0,0,84,0,0,0,100,0,0,0,52,0,0,0,60,0,0,0,4,0,0,0,48,0,0,0,132,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,242,0,0,178,0,0,0,14,0,0,0,86,0,0,0,84,0,0,0,74,0,0,0,110,0,0,0,56,0,0,0,4,0,0,0,48,0,0,0,132,0,0,0,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,242,0,0,176,0,0,0,124,0,0,0,56,1,0,0,84,0,0,0,110,0,0,0,22,0,0,0,34,0,0,0,4,0,0,0,48,0,0,0,60,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,242,0,0,126,0,0,0,104,0,0,0,54,1,0,0,84,0,0,0,102,0,0,0,108,0,0,0,64,0,0,0,4,0,0,0,48,0,0,0,132,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,242,0,0,48,1,0,0,80,1,0,0,102,0,0,0,84,0,0,0,40,0,0,0,70,0,0,0,80,0,0,0,4,0,0,0,48,0,0,0,132,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,120,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,83,116,57,116,121,112,101,95,105,110,102,111,0,0,0,0,83,116,57,101,120,99,101,112,116,105,111,110,0,0,0,0,83,116,57,98,97,100,95,97,108,108,111,99,0,0,0,0,83,116,56,98,97,100,95,99,97,115,116,0,0,0,0,0,83,116,49,51,114,117,110,116,105,109,101,95,101,114,114,111,114,0,0,0,0,0,0,0,83,116,49,50,108,101,110,103,116,104,95,101,114,114,111,114,0,0,0,0,0,0,0,0,83,116,49,49,108,111,103,105,99,95,101,114,114,111,114,0,78,83,116,51,95,95,49,57,116,105,109,101,95,98,97,115,101,69,0,0,0,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,98,97,115,105,99,95,105,111,115,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,57,98,97,115,105,99,95,105,111,115,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,112,117,116,73,119,69,69,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,112,117,116,73,99,69,69,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,103,101,116,73,119,69,69,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,103,101,116,73,99,69,69,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,110,117,109,112,117,110,99,116,73,119,69,69,0,0,0,0,78,83,116,51,95,95,49,56,110,117,109,112,117,110,99,116,73,99,69,69,0,0,0,0,78,83,116,51,95,95,49,56,109,101,115,115,97,103,101,115,73,119,69,69,0,0,0,0,78,83,116,51,95,95,49,56,109,101,115,115,97,103,101,115,73,99,69,69,0,0,0,0,78,83,116,51,95,95,49,56,105,111,115,95,98,97,115,101,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,56,105,111,115,95,98,97,115,101,55,102,97,105,108,117,114,101,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,108,108,97,116,101,73,119,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,108,108,97,116,101,73,99,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,119,99,49,48,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,99,99,49,48,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,68,115,99,49,48,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,68,105,99,49,48,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,54,108,111,99,97,108,101,53,102,97,99,101,116,69,0,0,0,78,83,116,51,95,95,49,54,108,111,99,97,108,101,53,95,95,105,109,112,69,0,0,0,78,83,116,51,95,95,49,53,99,116,121,112,101,73,119,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,53,99,116,121,112,101,73,99,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,50,48,95,95,116,105,109,101,95,103,101,116,95,99,95,115,116,111,114,97,103,101,73,119,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,50,48,95,95,116,105,109,101,95,103,101,116,95,99,95,115,116,111,114,97,103,101,73,99,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,57,95,95,105,111,115,116,114,101,97,109,95,99,97,116,101,103,111,114,121,69,0,0,0,78,83,116,51,95,95,49,49,55,95,95,119,105,100,101,110,95,102,114,111,109,95,117,116,102,56,73,76,106,51,50,69,69,69,0,0,0,0,0,0,78,83,116,51,95,95,49,49,54,95,95,110,97,114,114,111,119,95,116,111,95,117,116,102,56,73,76,106,51,50,69,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,53,98,97,115,105,99,95,115,116,114,101,97,109,98,117,102,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,53,98,97,115,105,99,95,115,116,114,101,97,109,98,117,102,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,101,114,114,111,114,95,99,97,116,101,103,111,114,121,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,98,97,115,105,99,95,105,102,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,78,83,116,51,95,95,49,49,52,95,95,115,104,97,114,101,100,95,99,111,117,110,116,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,95,95,110,117,109,95,112,117,116,95,98,97,115,101,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,95,95,110,117,109,95,103,101,116,95,98,97,115,101,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,51,109,101,115,115,97,103,101,115,95,98,97,115,101,69,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,111,115,116,114,101,97,109,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,111,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,105,115,116,114,101,97,109,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,105,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,102,105,108,101,98,117,102,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,78,83,116,51,95,95,49,49,50,115,121,115,116,101,109,95,101,114,114,111,114,69,0,0,78,83,116,51,95,95,49,49,50,99,111,100,101,99,118,116,95,98,97,115,101,69,0,0,78,83,116,51,95,95,49,49,50,95,95,100,111,95,109,101,115,115,97,103,101,69,0,0,78,83,116,51,95,95,49,49,49,95,95,115,116,100,111,117,116,98,117,102,73,119,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,115,116,100,111,117,116,98,117,102,73,99,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,112,117,116,73,119,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,112,117,116,73,99,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,103,101,116,73,119,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,103,101,116,73,99,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,119,76,98,49,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,119,76,98,48,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,99,76,98,49,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,99,76,98,48,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,95,98,97,115,101,69,0,0,0,0,78,83,116,51,95,95,49,49,48,99,116,121,112,101,95,98,97,115,101,69,0,0,0,0,78,83,116,51,95,95,49,49,48,95,95,116,105,109,101,95,112,117,116,69,0,0,0,0,78,83,116,51,95,95,49,49,48,95,95,115,116,100,105,110,98,117,102,73,119,69,69,0,78,83,116,51,95,95,49,49,48,95,95,115,116,100,105,110,98,117,102,73,99,69,69,0,78,49,48,95,95,99,120,120,97,98,105,118,49,50,49,95,95,118,109,105,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,50,48,95,95,115,105,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,55,95,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,54,95,95,115,104,105,109,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,0,0,0,0,57,67,76,121,110,120,66,97,115,101,0,0,0,0,0,0,55,67,83,121,115,116,101,109,0,0,0,0,0,0,0,0,55,67,77,101,109,77,97,112,0,0,0,0,0,0,0,0,54,67,83,117,115,105,101,0,54,67,77,105,107,105,101,0,53,67,67,97,114,116,0,0,52,67,82,111,109,0,0,0,52,67,82,97,109,0,0,0,49,49,67,83,121,115,116,101,109,66,97,115,101,0,0,0,0,0,0,0,112,223,0,0,0,0,0,0,128,223,0,0,0,0,0,0,144,223,0,0,232,235,0,0,0,0,0,0,0,0,0,0,160,223,0,0,232,235,0,0,0,0,0,0,0,0,0,0,176,223,0,0,232,235,0,0,0,0,0,0,0,0,0,0,200,223,0,0,48,236,0,0,0,0,0,0,0,0,0,0,224,223,0,0,232,235,0,0,0,0,0,0,0,0,0,0,240,223,0,0,88,221,0,0,8,224,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,16,241,0,0,0,0,0,0,88,221,0,0,80,224,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,24,241,0,0,0,0,0,0,88,221,0,0,152,224,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,32,241,0,0,0,0,0,0,88,221,0,0,224,224,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,40,241,0,0,0,0,0,0,0,0,0,0,40,225,0,0,56,238,0,0,0,0,0,0,0,0,0,0,88,225,0,0,56,238,0,0,0,0,0,0,88,221,0,0,136,225,0,0,0,0,0,0,1,0,0,0,64,240,0,0,0,0,0,0,88,221,0,0,160,225,0,0,0,0,0,0,1,0,0,0,64,240,0,0,0,0,0,0,88,221,0,0,184,225,0,0,0,0,0,0,1,0,0,0,72,240,0,0,0,0,0,0,88,221,0,0,208,225,0,0,0,0,0,0,1,0,0,0,72,240,0,0,0,0,0,0,88,221,0,0,232,225,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,192,241,0,0,0,8,0,0,88,221,0,0,48,226,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,192,241,0,0,0,8,0,0,88,221,0,0,120,226,0,0,0,0,0,0,3,0,0,0,112,239,0,0,2,0,0,0,64,236,0,0,2,0,0,0,208,239,0,0,0,8,0,0,88,221,0,0,192,226,0,0,0,0,0,0,3,0,0,0,112,239,0,0,2,0,0,0,64,236,0,0,2,0,0,0,216,239,0,0,0,8,0,0,0,0,0,0,8,227,0,0,112,239,0,0,0,0,0,0,0,0,0,0,32,227,0,0,112,239,0,0,0,0,0,0,88,221,0,0,56,227,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,80,240,0,0,2,0,0,0,88,221,0,0,80,227,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,80,240,0,0,2,0,0,0,0,0,0,0,104,227,0,0,0,0,0,0,128,227,0,0,200,240,0,0,0,0,0,0,88,221,0,0,160,227,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,232,236,0,0,0,0,0,0,88,221,0,0,232,227,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,0,237,0,0,0,0,0,0,88,221,0,0,48,228,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,24,237,0,0,0,0,0,0,88,221,0,0,120,228,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,48,237,0,0,0,0,0,0,0,0,0,0,192,228,0,0,112,239,0,0,0,0,0,0,0,0,0,0,216,228,0,0,112,239,0,0,0,0,0,0,88,221,0,0,240,228,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,216,240,0,0,2,0,0,0,88,221,0,0,24,229,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,216,240,0,0,2,0,0,0,88,221,0,0,64,229,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,216,240,0,0,2,0,0,0,88,221,0,0,104,229,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,216,240,0,0,2,0,0,0,0,0,0,0,144,229,0,0,56,240,0,0,0,0,0,0,0,0,0,0,168,229,0,0,112,239,0,0,0,0,0,0,88,221,0,0,192,229,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,184,241,0,0,2,0,0,0,88,221,0,0,216,229,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,184,241,0,0,2,0,0,0,0,0,0,0,240,229,0,0,0,0,0,0,24,230,0,0,0,0,0,0,64,230,0,0,224,240,0,0,0,0,0,0,0,0,0,0,96,230,0,0,80,239,0,0,0,0,0,0,0,0,0,0,136,230,0,0])
.concat([80,239,0,0,0,0,0,0,0,0,0,0,176,230,0,0,0,0,0,0,232,230,0,0,0,0,0,0,32,231,0,0,0,0,0,0,64,231,0,0,160,240,0,0,0,0,0,0,0,0,0,0,112,231,0,0,0,0,0,0,144,231,0,0,0,0,0,0,176,231,0,0,0,0,0,0,208,231,0,0,88,221,0,0,232,231,0,0,0,0,0,0,1,0,0,0,200,236,0,0,3,244,255,255,88,221,0,0,24,232,0,0,0,0,0,0,1,0,0,0,216,236,0,0,3,244,255,255,88,221,0,0,72,232,0,0,0,0,0,0,1,0,0,0,200,236,0,0,3,244,255,255,88,221,0,0,120,232,0,0,0,0,0,0,1,0,0,0,216,236,0,0,3,244,255,255,0,0,0,0,168,232,0,0,24,240,0,0,0,0,0,0,0,0,0,0,216,232,0,0,16,236,0,0,0,0,0,0,0,0,0,0,240,232,0,0,0,0,0,0,8,233,0,0,32,240,0,0,0,0,0,0,0,0,0,0,32,233,0,0,16,240,0,0,0,0,0,0,0,0,0,0,64,233,0,0,24,240,0,0,0,0,0,0,0,0,0,0,96,233,0,0,0,0,0,0,128,233,0,0,0,0,0,0,160,233,0,0,0,0,0,0,192,233,0,0,88,221,0,0,224,233,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,176,241,0,0,2,0,0,0,88,221,0,0,0,234,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,176,241,0,0,2,0,0,0,88,221,0,0,32,234,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,176,241,0,0,2,0,0,0,88,221,0,0,64,234,0,0,0,0,0,0,2,0,0,0,112,239,0,0,2,0,0,0,176,241,0,0,2,0,0,0,0,0,0,0,96,234,0,0,0,0,0,0,120,234,0,0,0,0,0,0,144,234,0,0,0,0,0,0,168,234,0,0,16,240,0,0,0,0,0,0,0,0,0,0,192,234,0,0,24,240,0,0,0,0,0,0,0,0,0,0,216,234,0,0,8,242,0,0,0,0,0,0,0,0,0,0,0,235,0,0,8,242,0,0,0,0,0,0,0,0,0,0,40,235,0,0,24,242,0,0,0,0,0,0,0,0,0,0,80,235,0,0,224,235,0,0,0,0,0,0,0,0,0,0,120,235,0,0,0,0,0,0,136,235,0,0,160,242,0,0,0,0,0,0,0,0,0,0,152,235,0,0,40,242,0,0,0,0,0,0,0,0,0,0,168,235,0,0,40,242,0,0,0,0,0,0,0,0,0,0,176,235,0,0,40,242,0,0,0,0,0,0,0,0,0,0,184,235,0,0,40,242,0,0,0,0,0,0,0,0,0,0,192,235,0,0,40,242,0,0,0,0,0,0,0,0,0,0,200,235,0,0,40,242,0,0,0,0,0,0,0,0,0,0,208,235,0,0,108,0,0,0,0,0,0,0,160,240,0,0,182,0,0,0,76,1,0,0,148,255,255,255,148,255,255,255,160,240,0,0,72,0,0,0,82,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,48,49,50,51,52,53,54,55,56,57,97,98,99,100,101,102,65,66,67,68,69,70,120,88,43,45,112,80,105,73,110,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,181,163,148,40,6,216,162,38,149,215,113,178,60,253,86,28,74,25,182,163,176,38,0,54,90,48,110,60,77,99,56,27,212,28,19,100,137,54,76,242,186,42,88,244,254,225,253,172,126,121,0,0,0,0,0,8,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,7,0,0,0,64,0,0,0,6,0,0,0,128,0,0,0,4,0,0,0,16,0,0,0,5,0,0,0,32,0,0,0,10,0,0,0,8,0,0,0,11,0,0,0,4,0,0,0,3,0,0,0,0,1,0,0,8,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,7,0,0,0,128,0,0,0,6,0,0,0,64,0,0,0,4,0,0,0,32,0,0,0,5,0,0,0,16,0,0,0,10,0,0,0,8,0,0,0,11,0,0,0,4,0,0,0,3,0,0,0,0,1,0,0,8,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,7,0,0,0,32,0,0,0,6,0,0,0,16,0,0,0,4,0,0,0,64,0,0,0,5,0,0,0,128,0,0,0,10,0,0,0,8,0,0,0,11,0,0,0,4,0,0,0,3,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,47,138,66,145,68,55,113,207,251,192,181,165,219,181,233,91,194,86,57,241,17,241,89,164,130,63,146,213,94,28,171,152,170,7,216,1,91,131,18,190,133,49,36,195,125,12,85,116,93,190,114,254,177,222,128,167,6,220,155,116,241,155,193,193,105,155,228,134,71,190,239,198,157,193,15,204,161,12,36,111,44,233,45,170,132,116,74,220,169,176,92,218,136,249,118,82,81,62,152,109,198,49,168,200,39,3,176,199,127,89,191,243,11,224,198,71,145,167,213,81,99,202,6,103,41,41,20,133,10,183,39,56,33,27,46,252,109,44,77,19,13,56,83,84,115,10,101,187,10,106,118,46,201,194,129,133,44,114,146,161,232,191,162,75,102,26,168,112,139,75,194,163,81,108,199,25,232,146,209,36,6,153,214,133,53,14,244,112,160,106,16,22,193,164,25,8,108,55,30,76,119,72,39,181,188,176,52,179,12,28,57,74,170,216,78,79,202,156,91,243,111,46,104,238,130,143,116,111,99,165,120,20,120,200,132,8,2,199,140,250,255,190,144,235,108,80,164,247,163,249,190,242,120,113,198,103,230,9,106,133,174,103,187,114,243,110,60,58,245,79,165,127,82,14,81,140,104,5,155,171,217,131,31,25,205,224,91])
, "i8", ALLOC_NONE, Runtime.GLOBAL_BASE)
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
  function _emscripten_set_canvas_size(width, height) {
      Browser.setCanvasSize(width, height);
    }
  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
      Module['noExitRuntime'] = true;
      Browser.mainLoop.runner = function() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        if (Module['preMainLoop']) {
          Module['preMainLoop']();
        }
        Runtime.dynCall('v', func);
        if (Module['postMainLoop']) {
          Module['postMainLoop']();
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        }
      } else {
        Browser.mainLoop.scheduler = function() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        }
      }
      Browser.mainLoop.scheduler();
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:35,EIDRM:36,ECHRNG:37,EL2NSYNC:38,EL3HLT:39,EL3RST:40,ELNRNG:41,EUNATCH:42,ENOCSI:43,EL2HLT:44,EDEADLK:45,ENOLCK:46,EBADE:50,EBADR:51,EXFULL:52,ENOANO:53,EBADRQC:54,EBADSLT:55,EDEADLOCK:56,EBFONT:57,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:74,EDOTDOT:76,EBADMSG:77,ENOTUNIQ:80,EBADFD:81,EREMCHG:82,ELIBACC:83,ELIBBAD:84,ELIBSCN:85,ELIBMAX:86,ELIBEXEC:87,ENOSYS:88,ENOTEMPTY:90,ENAMETOOLONG:91,ELOOP:92,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:106,EPROTOTYPE:107,ENOTSOCK:108,ENOPROTOOPT:109,ESHUTDOWN:110,ECONNREFUSED:111,EADDRINUSE:112,ECONNABORTED:113,ENETUNREACH:114,ENETDOWN:115,ETIMEDOUT:116,EHOSTDOWN:117,EHOSTUNREACH:118,EINPROGRESS:119,EALREADY:120,EDESTADDRREQ:121,EMSGSIZE:122,EPROTONOSUPPORT:123,ESOCKTNOSUPPORT:124,EADDRNOTAVAIL:125,ENETRESET:126,EISCONN:127,ENOTCONN:128,ETOOMANYREFS:129,EUSERS:131,EDQUOT:132,ESTALE:133,ENOTSUP:134,ENOMEDIUM:135,EILSEQ:138,EOVERFLOW:139,ECANCELED:140,ENOTRECOVERABLE:141,EOWNERDEAD:142,ESTRPIPE:143};
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"No message of desired type",36:"Identifier removed",37:"Channel number out of range",38:"Level 2 not synchronized",39:"Level 3 halted",40:"Level 3 reset",41:"Link number out of range",42:"Protocol driver not attached",43:"No CSI structure available",44:"Level 2 halted",45:"Deadlock condition",46:"No record locks available",50:"Invalid exchange",51:"Invalid request descriptor",52:"Exchange full",53:"No anode",54:"Invalid request code",55:"Invalid slot",56:"File locking deadlock error",57:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",74:"Multihop attempted",76:"Cross mount point (not really error)",77:"Trying to read unreadable message",80:"Given log. name not unique",81:"f.d. invalid for this operation",82:"Remote address changed",83:"Can   access a needed shared lib",84:"Accessing a corrupted shared lib",85:".lib section in a.out corrupted",86:"Attempting to link in too many libs",87:"Attempting to exec a shared library",88:"Function not implemented",90:"Directory not empty",91:"File or path name too long",92:"Too many symbolic links",95:"Operation not supported on transport endpoint",96:"Protocol family not supported",104:"Connection reset by peer",105:"No buffer space available",106:"Address family not supported by protocol family",107:"Protocol wrong type for socket",108:"Socket operation on non-socket",109:"Protocol not available",110:"Can't send after socket shutdown",111:"Connection refused",112:"Address already in use",113:"Connection aborted",114:"Network is unreachable",115:"Network interface is not configured",116:"Connection timed out",117:"Host is down",118:"Host is unreachable",119:"Connection already in progress",120:"Socket already connected",121:"Destination address required",122:"Message too long",123:"Unknown protocol",124:"Socket type not supported",125:"Address not available",126:"Connection reset by network",127:"Socket is already connected",128:"Socket is not connected",129:"Too many references",131:"Too many users",132:"Quota exceeded",133:"Stale file handle",134:"Not supported",135:"No medium (in tape drive)",138:"Illegal byte sequence",139:"Value too large for defined data type",140:"Operation canceled",141:"State not recoverable",142:"Previous owner died",143:"Streams pipe error"};
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value
      return value;
    }
  var VFS=undefined;
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path, ext) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var f = PATH.splitPath(path)[2];
        if (ext && f.substr(-1 * ext.length) === ext) {
          f = f.substr(0, f.length - ext.length);
        }
        return f;
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.filter(function(p, index) {
          if (typeof p !== 'string') {
            throw new TypeError('Arguments to path.join must be strings');
          }
          return p;
        }).join('/'));
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            continue;
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  var MEMFS={CONTENT_OWNING:1,CONTENT_FLEXIBLE:2,CONTENT_FIXED:3,ensureFlexible:function (node) {
        if (node.contentMode !== MEMFS.CONTENT_FLEXIBLE) {
          var contents = node.contents;
          node.contents = Array.prototype.slice.call(contents);
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        }
      },mount:function (mount) {
        return MEMFS.create_node(null, '/', 0040000 | 0777, 0);
      },create_node:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            lookup: MEMFS.node_ops.lookup,
            mknod: MEMFS.node_ops.mknod,
            mknod: MEMFS.node_ops.mknod,
            rename: MEMFS.node_ops.rename,
            unlink: MEMFS.node_ops.unlink,
            rmdir: MEMFS.node_ops.rmdir,
            readdir: MEMFS.node_ops.readdir,
            symlink: MEMFS.node_ops.symlink
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek
          };
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek,
            read: MEMFS.stream_ops.read,
            write: MEMFS.stream_ops.write,
            allocate: MEMFS.stream_ops.allocate,
            mmap: MEMFS.stream_ops.mmap
          };
          node.contents = [];
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            readlink: MEMFS.node_ops.readlink
          };
          node.stream_ops = {};
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = FS.chrdev_stream_ops;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.contents.length;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.ensureFlexible(node);
            var contents = node.contents;
            if (attr.size < contents.length) contents.length = attr.size;
            else while (attr.size > contents.length) contents.push(0);
          }
        },lookup:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.create_node(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.create_node(parent, newname, 0777 | 0120000, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          var node = stream.node;
          node.timestamp = Date.now();
          var contents = node.contents;
          if (length && contents.length === 0 && position === 0 && buffer.subarray) {
            // just replace it with the new data
            assert(buffer.length);
            if (canOwn && buffer.buffer === HEAP8.buffer && offset === 0) {
              node.contents = buffer; // this is a subarray of the heap, and we can own it
              node.contentMode = MEMFS.CONTENT_OWNING;
            } else {
              node.contents = new Uint8Array(buffer.subarray(offset, offset+length));
              node.contentMode = MEMFS.CONTENT_FIXED;
            }
            return length;
          }
          MEMFS.ensureFlexible(node);
          var contents = node.contents;
          while (contents.length < position) contents.push(0);
          for (var i = 0; i < length; i++) {
            contents[position + i] = buffer[offset + i];
          }
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.contents.length;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.ensureFlexible(stream.node);
          var contents = stream.node.contents;
          var limit = offset + length;
          while (limit > contents.length) contents.push(0);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 0x02) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < contents.length) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);var FS={root:null,nodes:[null],devices:[null],streams:[null],nextInode:1,name_table:null,currentPath:"/",initialized:false,ignorePermissions:true,ErrnoError:function ErrnoError(errno) {
          this.errno = errno;
          for (var key in ERRNO_CODES) {
            if (ERRNO_CODES[key] === errno) {
              this.code = key;
              break;
            }
          }
          this.message = ERRNO_MESSAGES[errno];
        },handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + new Error().stack;
        return ___setErrNo(e.errno);
      },hashName:function (parentid, name) {
        var hash = 0;
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.name_table.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.name_table[hash];
        FS.name_table[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.name_table[hash] === node) {
          FS.name_table[hash] = node.name_next;
        } else {
          var current = FS.name_table[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.name_table[hash]; node; node = node.name_next) {
          if (node.parent.id === parent.id && node.name === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        var node = {
          id: FS.nextInode++,
          name: name,
          mode: mode,
          node_ops: {},
          stream_ops: {},
          rdev: rdev,
          parent: null,
          mount: null
        };
        if (!parent) {
          parent = node;  // root node sets parent to itself
        }
        node.parent = parent;
        node.mount = parent.mount;
        // compatibility
        var readMode = 292 | 73;
        var writeMode = 146;
        // NOTE we must use Object.defineProperties instead of individual calls to
        // Object.defineProperty in order to make closure compiler happy
        Object.defineProperties(node, {
          read: {
            get: function() { return (node.mode & readMode) === readMode; },
            set: function(val) { val ? node.mode |= readMode : node.mode &= ~readMode; }
          },
          write: {
            get: function() { return (node.mode & writeMode) === writeMode; },
            set: function(val) { val ? node.mode |= writeMode : node.mode &= ~writeMode; }
          },
          isFolder: {
            get: function() { return FS.isDir(node.mode); },
          },
          isDevice: {
            get: function() { return FS.isChrdev(node.mode); },
          },
        });
        FS.hashAddNode(node);
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return node.mounted;
      },isFile:function (mode) {
        return (mode & 0170000) === 0100000;
      },isDir:function (mode) {
        return (mode & 0170000) === 0040000;
      },isLink:function (mode) {
        return (mode & 0170000) === 0120000;
      },isChrdev:function (mode) {
        return (mode & 0170000) === 0020000;
      },isBlkdev:function (mode) {
        return (mode & 0170000) === 0060000;
      },isFIFO:function (mode) {
        return (mode & 0170000) === 0010000;
      },isSocket:function (mode) {
        return (mode & 0140000) === 0140000;
      },cwd:function () {
        return FS.currentPath;
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.currentPath, path);
        opts = opts || { recurse_count: 0 };
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
        // start at the root
        var current = FS.root;
        var current_path = '/';
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join(current_path, parts[i]);
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            current = current.mount.root;
          }
          // follow symlinks
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            return path ? PATH.join(node.mount.mountpoint, path) : node.mount.mountpoint;
          }
          path = path ? PATH.join(node.name, path) : node.name;
          node = node.parent;
        }
      },flagModes:{"r":0,"rs":8192,"r+":2,"w":1537,"wx":3585,"xw":3585,"w+":1538,"wx+":3586,"xw+":3586,"a":521,"ax":2569,"xa":2569,"a+":522,"ax+":2570,"xa+":2570},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 3;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 1024)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        return FS.nodePermissions(dir, 'x');
      },mayMknod:function (mode) {
        switch (mode & 0170000) {
          case 0100000:
          case 0020000:
          case 0060000:
          case 0010000:
          case 0140000:
            return 0;
          default:
            return ERRNO_CODES.EINVAL;
        }
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.currentPath) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 3) !== 0 ||  // opening for write
              (flags & 1024)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 1;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        // compatibility
        Object.defineProperties(stream, {
          object: {
            get: function() { return stream.node; },
            set: function(val) { stream.node = val; }
          },
          isRead: {
            get: function() { return (stream.flags & 3) !== 1; }
          },
          isWrite: {
            get: function() { return (stream.flags & 3) !== 0; }
          },
          isAppend: {
            get: function() { return (stream.flags & 8); }
          }
        });
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join(parent, part);
          try {
            FS.mkdir(current, 0777);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(path, mode | 146);
          var stream = FS.open(path, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(path, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
              if (!hasByteServing) chunkSize = datalength;
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp', 0777);
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev', 0777);
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', 0666, FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', 0666, FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', 0666, FS.makedev(6, 0));
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm', 0777);
        FS.mkdir('/dev/shm/tmp', 0777);
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=stdin.fd;
        assert(stdin.fd === 1, 'invalid handle for stdin (' + stdin.fd + ')');
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=stdout.fd;
        assert(stdout.fd === 2, 'invalid handle for stdout (' + stdout.fd + ')');
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=stderr.fd;
        assert(stderr.fd === 3, 'invalid handle for stderr (' + stderr.fd + ')');
      },staticInit:function () {
        FS.name_table = new Array(4096);
        FS.root = FS.createNode(null, '/', 0040000 | 0777, 0);
        FS.mount(MEMFS, {}, '/');
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },mount:function (type, opts, mountpoint) {
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          root: null
        };
        var lookup;
        if (mountpoint) {
          lookup = FS.lookupPath(mountpoint, { follow: false });
        }
        // create a root node for the fs
        var root = type.mount(mount);
        root.mount = mount;
        mount.root = root;
        // assign the mount info to the mountpoint's node
        if (lookup) {
          lookup.node.mount = mount;
          lookup.node.mounted = true;
          // compatibility update FS.root if we mount to /
          if (mountpoint === '/') {
            FS.root = mount.root;
          }
        }
        return root;
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode &= 4095;
        mode |= 0100000;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode &= 511 | 0001000;
        mode |= 0040000;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        mode |= 0020000;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
      },readlink:function (path) {
        var lookup = FS.lookupPath(path, { follow: false });
        var link = lookup.node;
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        path = PATH.normalize(path);
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 0666 : mode;
        if ((flags & 512)) {
          mode = (mode & 4095) | 0100000;
        } else {
          mode = 0;
        }
        var node;
        try {
          var lookup = FS.lookupPath(path, {
            follow: !(flags & 0200000)
          });
          node = lookup.node;
          path = lookup.path;
        } catch (e) {
          // ignore
        }
        // perhaps we need to create the node
        if ((flags & 512)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 2048)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~1024;
        }
        // check permissions
        var err = FS.mayOpen(node, flags);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // do truncation if necessary
        if ((flags & 1024)) {
          FS.truncate(node, 0);
        }
        // register the stream with the filesystem
        var stream = FS.createStream({
          path: path,
          node: node,
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        if (stream.flags & 8) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.errnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      }};function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module.print('exit(' + status + ') called');
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }
  var SOCKFS={mount:function (mount) {
        return FS.createNode(null, '/', 0040000 | 0777, 0);
      },nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 0140000, 0);
        node.sock = sock;
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              var url = 'ws://' + addr + ':' + port;
              // the node ws library API is slightly different than the browser's
              var opts = ENVIRONMENT_IS_NODE ? {} : ['binary'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
          var handleOpen = function () {
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
          var handleMessage = function(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
          };
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('error', function() {
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onmessage = function(event) {
              handleMessage(event.data);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (0 /* XXX missing C define POLLRDNORM */ | 1) : 0;
          }
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (0 /* XXX missing C define POLLRDNORM */ | 1);
          }
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 2;
          }
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 1:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODS.EOPNOTSUPP);
          }
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
              // push to queue for accept to pick up
              sock.pending.push(newsock);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
            }
          });
          sock.server.on('closed', function() {
            sock.server = null;
          });
          sock.server.on('error', function() {
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  Module["_strlen"] = _strlen;
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (flagAlwaysSigned) {
                if (currArg < 0) {
                  prefix = '-' + prefix;
                } else {
                  prefix = '+' + prefix;
                }
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (flagAlwaysSigned && currArg >= 0) {
                  argText = '+' + argText;
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }
  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i32=_memset;
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    } 
  Module["_saveSetjmp"] = _saveSetjmp;
  Module["_testSetjmp"] = _testSetjmp;var _setjmp=undefined;
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _remove(path) {
      // int remove(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/remove.html
      var ret = _unlink(path);
      if (ret == -1) ret = _rmdir(path);
      return ret;
    }
  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }
  var ___timespec_struct_layout={__size__:8,tv_sec:0,tv_nsec:4};function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_sec))>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_nsec))>>2)];
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_sec))>>2)]=0
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_nsec))>>2)]=0
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }
  function _strrchr(ptr, chr) {
      var ptr2 = ptr + _strlen(ptr);
      do {
        if (HEAP8[(ptr2)] == chr) return ptr2;
        ptr2--;
      } while (ptr2 >= ptr);
      return 0;
    }
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  var _llvm_pow_f32=Math.pow;
  function _round(x) {
      return (x < 0) ? -Math.round(-x) : Math.round(x);
    }var _roundf=_round;
  function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }
  function _isspace(chr) {
      return (chr == 32) || (chr >= 9 && chr <= 13);
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm["setTempRet0"]((tempDouble=ret,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)),ret>>>0)|0);
      }
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }
  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function _llvm_lifetime_start() {}
  function _llvm_lifetime_end() {}
  var _llvm_memset_p0i8_i64=_memset;
  var ___dirent_struct_layout={__size__:1040,d_ino:0,d_name:4,d_off:1028,d_reclen:1032,d_type:1036};function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStream(stream);
      stream.eof = false;
      return 0;
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStream(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }
  function _rewind(stream) {
      // void rewind(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rewind.html
      _fseek(stream, 0, 0);  // SEEK_SET.
      var streamObj = FS.getStream(stream);
      if (streamObj) streamObj.error = false;
    }
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStream(stream);
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)|0)]=streamObj.ungotten.pop()
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(stream, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return Math.floor(bytesRead / size);
    }
  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      stream = FS.getStream(stream);
      return Number(stream && stream.eof);
    }
  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }function _fgets(s, n, stream) {
      // char *fgets(char *restrict s, int n, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgets.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return 0;
      if (streamObj.error || streamObj.eof) return 0;
      var byte_;
      for (var i = 0; i < n - 1 && byte_ != 10; i++) {
        byte_ = _fgetc(stream);
        if (byte_ == -1) {
          if (streamObj.error || (streamObj.eof && i == 0)) return 0;
          else if (streamObj.eof) break;
        }
        HEAP8[(((s)+(i))|0)]=byte_
      }
      HEAP8[(((s)+(i))|0)]=0
      return s;
    }
  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }
  Module["_tolower"] = _tolower; 
  Module["_strncasecmp"] = _strncasecmp; 
  Module["_strcasecmp"] = _strcasecmp;
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'root';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/emscripten';
        ENV['LANG'] = 'en_US.UTF-8';
        ENV['_'] = './this.program';
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        for (var j = 0; j < line.length; j++) {
          HEAP8[(((poolPtr)+(j))|0)]=line.charCodeAt(j);
        }
        HEAP8[(((poolPtr)+(j))|0)]=0;
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  var ___tm_struct_layout={__size__:44,tm_sec:0,tm_min:4,tm_hour:8,tm_mday:12,tm_mon:16,tm_year:20,tm_wday:24,tm_yday:28,tm_isdst:32,tm_gmtoff:36,tm_zone:40};
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
      var date = {
        tm_sec: HEAP32[(((tm)+(___tm_struct_layout.tm_sec))>>2)],
        tm_min: HEAP32[(((tm)+(___tm_struct_layout.tm_min))>>2)],
        tm_hour: HEAP32[(((tm)+(___tm_struct_layout.tm_hour))>>2)],
        tm_mday: HEAP32[(((tm)+(___tm_struct_layout.tm_mday))>>2)],
        tm_mon: HEAP32[(((tm)+(___tm_struct_layout.tm_mon))>>2)],
        tm_year: HEAP32[(((tm)+(___tm_struct_layout.tm_year))>>2)],
        tm_wday: HEAP32[(((tm)+(___tm_struct_layout.tm_wday))>>2)],
        tm_yday: HEAP32[(((tm)+(___tm_struct_layout.tm_yday))>>2)],
        tm_isdst: HEAP32[(((tm)+(___tm_struct_layout.tm_isdst))>>2)]
      };
      var pattern = Pointer_stringify(format);
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S',                 // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
      var leadingSomething = function(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
      var leadingNulls = function(value, digits) {
        return leadingSomething(value, digits, '0');
      };
      var compareByDay = function(date1, date2) {
        var sgn = function(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
      var getFirstWeekStartDate = function(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
      var getWeekBasedYear = function(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls(Math.floor(year/100),2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ),
          // or by no characters if no timezone is determinable. 
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich). 
          // If tm_isdst is zero, the standard time offset is used. 
          // If tm_isdst is greater than zero, the daylight savings time offset is used. 
          // If tm_isdst is negative, no characters are returned. 
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%Z': function(date) {
          // Replaced by the timezone name or abbreviation, or by no bytes if no timezone information exists. [ tm_isdst]
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }
  var ___tm_current=allocate(4*26, "i8", ALLOC_STATIC);
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);
  var __tzname=allocate(8, "i32*", ALLOC_STATIC);
  var __daylight=allocate(1, "i32*", ALLOC_STATIC);
  var __timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
      HEAP32[((__timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((__daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset())
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((__tzname)>>2)]=winterNamePtr
      HEAP32[(((__tzname)+(4))>>2)]=summerNamePtr
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var offsets = ___tm_struct_layout;
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getDay()
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=start.getTimezoneOffset() * 60
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=dst
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezone
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }
  function _strtok_r(s, delim, lasts) {
      var skip_leading_delim = 1;
      var spanp;
      var c, sc;
      var tok;
      if (s == 0 && (s = getValue(lasts, 'i8*')) == 0) {
        return 0;
      }
      cont: while (1) {
        c = getValue(s++, 'i8');
        for (spanp = delim; (sc = getValue(spanp++, 'i8')) != 0;) {
          if (c == sc) {
            if (skip_leading_delim) {
              continue cont;
            } else {
              setValue(lasts, s, 'i8*');
              setValue(s - 1, 0, 'i8');
              return s - 1;
            }
          }
        }
        break;
      }
      if (c == 0) {
        setValue(lasts, 0, 'i8*');
        return 0;
      }
      tok = s - 1;
      for (;;) {
        c = getValue(s++, 'i8');
        spanp = delim;
        do {
          if ((sc = getValue(spanp++, 'i8')) == c) {
            if (c == 0) {
              s = 0;
            } else {
              setValue(s - 1, 0, 'i8');
            }
            setValue(lasts, s, 'i8*');
            return tok;
          }
        } while (sc != 0);
      }
      abort('strtok_r error!');
    }
  function _qsort(base, num, size, cmp) {
      if (num == 0 || size == 0) return;
      // forward calls to the JavaScript sort method
      // first, sort the items logically
      var keys = [];
      for (var i = 0; i < num; i++) keys.push(i);
      keys.sort(function(a, b) {
        return Module['dynCall_iii'](cmp, base+a*size, base+b*size);
      });
      // apply the sort
      var temp = _malloc(num*size);
      _memcpy(temp, base, num*size);
      for (var i = 0; i < num; i++) {
        if (keys[i] == i) continue; // already in place
        _memcpy(base+i*size, temp+keys[i]*size, size);
      }
      _free(temp);
    }
  function _opendir(dirname) {
      // DIR *opendir(const char *dirname);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/opendir.html
      // NOTE: Calculating absolute path redundantly since we need to associate it
      //       with the opened stream.
      var path = Pointer_stringify(dirname);
      if (!path) {
        ___setErrNo(ERRNO_CODES.ENOENT);
        return 0;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return 0;
      }
      if (!FS.isDir(node.mode)) {
        ___setErrNo(ERRNO_CODES.ENOTDIR);
        return 0;
      }
      var err = _open(dirname, 0, allocate([0, 0, 0, 0], 'i32', ALLOC_STACK));
      // open returns 0 on failure, not -1
      return err === -1 ? 0 : err;
    }
  function _readdir_r(dirp, entry, result) {
      // int readdir_r(DIR *dirp, struct dirent *entry, struct dirent **result);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        return ___setErrNo(ERRNO_CODES.EBADF);
      }
      var entries;
      try {
        entries = FS.readdir(stream.path);
      } catch (e) {
        return FS.handleFSError(e);
      }
      if (stream.position < 0 || stream.position >= entries.length) {
        HEAP32[((result)>>2)]=0
        return 0;
      }
      var id;
      var type;
      var name = entries[stream.position];
      var offset = stream.position + 1;
      if (!name.indexOf('.')) {
        id = 1;
        type = 4;
      } else {
        var child = FS.lookupNode(stream.node, name);
        id = child.id;
        type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
               FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
               FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
               8;                             // DT_REG, regular file.
      }
      HEAP32[(((entry)+(___dirent_struct_layout.d_ino))>>2)]=id
      HEAP32[(((entry)+(___dirent_struct_layout.d_off))>>2)]=offset
      HEAP32[(((entry)+(___dirent_struct_layout.d_reclen))>>2)]=name.length + 1
      for (var i = 0; i < name.length; i++) {
        HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=name.charCodeAt(i)
      }
      HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=0
      HEAP8[(((entry)+(___dirent_struct_layout.d_type))|0)]=type
      HEAP32[((result)>>2)]=entry
      stream.position++;
      return 0;
    }function _readdir(dirp) {
      // struct dirent *readdir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // TODO Is it supposed to be safe to execute multiple readdirs?
      if (!_readdir.entry) _readdir.entry = _malloc(___dirent_struct_layout.__size__);
      if (!_readdir.result) _readdir.result = _malloc(4);
      var err = _readdir_r(dirp, _readdir.entry, _readdir.result);
      if (err) {
        ___setErrNo(err);
        return 0;
      }
      return HEAP32[((_readdir.result)>>2)];
    }
  function _closedir(dirp) {
      // int closedir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/closedir.html
      return _close(dirp);
    }
  var ___stat_struct_layout={__size__:68,st_dev:0,st_ino:4,st_mode:8,st_nlink:12,st_uid:16,st_gid:20,st_rdev:24,st_size:28,st_atime:32,st_spare1:36,st_mtime:40,st_spare2:44,st_ctime:48,st_spare3:52,st_blksize:56,st_blocks:60,st_spare4:64};function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[(((buf)+(___stat_struct_layout.st_dev))>>2)]=stat.dev;
        HEAP32[(((buf)+(___stat_struct_layout.st_ino))>>2)]=stat.ino
        HEAP32[(((buf)+(___stat_struct_layout.st_mode))>>2)]=stat.mode
        HEAP32[(((buf)+(___stat_struct_layout.st_nlink))>>2)]=stat.nlink
        HEAP32[(((buf)+(___stat_struct_layout.st_uid))>>2)]=stat.uid
        HEAP32[(((buf)+(___stat_struct_layout.st_gid))>>2)]=stat.gid
        HEAP32[(((buf)+(___stat_struct_layout.st_rdev))>>2)]=stat.rdev
        HEAP32[(((buf)+(___stat_struct_layout.st_size))>>2)]=stat.size
        HEAP32[(((buf)+(___stat_struct_layout.st_atime))>>2)]=Math.floor(stat.atime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_mtime))>>2)]=Math.floor(stat.mtime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_ctime))>>2)]=Math.floor(stat.ctime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_blksize))>>2)]=4096
        HEAP32[(((buf)+(___stat_struct_layout.st_blocks))>>2)]=stat.blocks
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _realpath(file_name, resolved_name) {
      // char *realpath(const char *restrict file_name, char *restrict resolved_name);
      // http://pubs.opengroup.org/onlinepubs/009604499/functions/realpath.html
      var absolute = FS.analyzePath(Pointer_stringify(file_name));
      if (absolute.error) {
        ___setErrNo(absolute.error);
        return 0;
      } else {
        var size = Math.min(4095, absolute.path.length);  // PATH_MAX - 1.
        for (var i = 0; i < size; i++) {
          HEAP8[(((resolved_name)+(i))|0)]=absolute.path.charCodeAt(i)
        }
        HEAP8[(((resolved_name)+(size))|0)]=0
        return resolved_name;
      }
    }
  function _getgid() {
      // gid_t getgid(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/getgid.html
      // We have just one process/group/user, all with ID 0.
      return 0;
    }var _getpid=_getgid;
  function _readlink(path, buf, bufsize) {
      // ssize_t readlink(const char *restrict path, char *restrict buf, size_t bufsize);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/readlink.html
      path = Pointer_stringify(path);
      var str;
      try {
        str = FS.readlink(path);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      str = str.slice(0, Math.max(0, bufsize - 1));
      writeStringToMemory(str, buf, true);
      return str.length;
    }
  var _sqrt=Math.sqrt;
  var _fabs=Math.abs;
  function ___errno_location() {
      return ___errno_state;
    }var ___errno=___errno_location;
  function __parseInt64(str, endptr, base, min, max, unsign) {
      var isNegative = false;
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      if (HEAP8[(str)] == 45) {
        str++;
        isNegative = true;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var ok = false;
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            ok = true; // we saw an initial zero, perhaps the entire thing is just "0"
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      start = str;
      // Get digits.
      var chr;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          str++;
          ok = true;
        }
      }
      if (!ok) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return ((asm["setTempRet0"](0),0)|0);
      }
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      try {
        var numberString = isNegative ? '-'+Pointer_stringify(start, str - start) : Pointer_stringify(start, str - start);
        i64Math.fromString(numberString, finalBase, min, max, unsign);
      } catch(e) {
        ___setErrNo(ERRNO_CODES.ERANGE); // not quite correct
      }
      return ((asm["setTempRet0"](((HEAP32[(((tempDoublePtr)+(4))>>2)])|0)),((HEAP32[((tempDoublePtr)>>2)])|0))|0);
    }function _strtoull(str, endptr, base) {
      return __parseInt64(str, endptr, base, 0, '18446744073709551615', true);  // ULONG_MAX.
    }
  var _getc=_fgetc;
  function _isgraph(chr) {
      return 0x20 < chr && chr < 0x7F;
    }
  function _llvm_bswap_i32(x) {
      return ((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24);
    }
  function _isalpha(chr) {
      return (chr >= 97 && chr <= 122) ||
             (chr >= 65 && chr <= 90);
    }
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', {
              alpha: false
            });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var x, y;
          if (event.type == 'touchstart' ||
              event.type == 'touchend' ||
              event.type == 'touchmove') {
            var t = event.touches.item(0);
            if (t) {
              x = t.pageX - (window.scrollX + rect.left);
              y = t.pageY - (window.scrollY + rect.top);
            } else {
              return;
            }
          } else {
            x = event.pageX - (window.scrollX + rect.left);
            y = event.pageY - (window.scrollY + rect.top);
          }
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};var RI={temp:null,contexts:[],eventHandler:function (event) {
           var i;
           switch (event.type) {
              case 'mousemove':
                 var x = event['movementX'] || event['mozMovementX'] || event['webkitMovementX'];
                 var y = event['movementY'] || event['mozMovementY'] || event['webkitMovementY'];
                 for (i = 0; i < RI.contexts.length; i++) {
                    var oldX = HEAP32[(((RI.contexts[i].state)+(32))>>2)];
                    var oldY = HEAP32[(((RI.contexts[i].state)+(36))>>2)];
                    x += oldX;
                    y += oldY;
                    HEAP32[(((RI.contexts[i].state)+(32))>>2)]=x;
                    HEAP32[(((RI.contexts[i].state)+(36))>>2)]=y;
                 }
                 break;
              case 'mouseup':
              case 'mousedown':
                 var value;
                 var offset;
                 if (event.button === 0) offset = 40;
                 else if (event.button === 2) offset = 41;
                 else break;
                 if (event.type === 'mouseup') value = 0;
                 else value = 1;
                 for (i = 0; i < RI.contexts.length; i++) {
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 break;
              case 'keyup':
              case 'keydown':
                 var key = event.keyCode;
                 var offset = key >> 3;
                 var bit = 1 << (key & 7);
                 if (offset >= 32) throw 'key code error! bad code: ' + key;
                 for (i = 0; i < RI.contexts.length; i++) {
                    var value = HEAP8[(((RI.contexts[i].state)+(offset))|0)];
                    if (event.type === 'keyup') value &= ~bit;
                    else value |= bit;
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 event.preventDefault();
                 break;
              case 'blur':
              case 'visibilitychange':
                 for (i = 0; i < RI.contexts.length; i++) {
                    _memset(RI.contexts[i].state, 0, 42);
                 }
                 break;
           }
        }};function _RWebInputDestroy(context) {
        if (context === RI.contexts.length) {
           RI.contexts.pop();
           if (RI.contexts.length === 0) {
              document.removeEventListener('keyup', RI.eventHandler, false);
              document.removeEventListener('keydown', RI.eventHandler, false);
              document.removeEventListener('mousemove', RI.eventHandler, false);
              document.removeEventListener('mouseup', RI.eventHandler, false);
              document.removeEventListener('mousedown', RI.eventHandler, false);
              document.removeEventListener('blur', RI.eventHandler, false);
              document.removeEventListener('onvisbilitychange', RI.eventHandler, false);
           }
        }
     }
  function _RWebInputPoll(context) {
        context -= 1;
        var state = RI.contexts[context].state;
        _memcpy(RI.temp, state, 42);
        // reset mouse movements
        HEAP32[(((RI.contexts[context].state)+(32))>>2)]=0;
        HEAP32[(((RI.contexts[context].state)+(36))>>2)]=0;
        return RI.temp;
     }
  function _RWebInputInit(latency) {
        if (RI.contexts.length === 0) {
           document.addEventListener('keyup', RI.eventHandler, false);
           document.addEventListener('keydown', RI.eventHandler, false);
           document.addEventListener('mousemove', RI.eventHandler, false);
           document.addEventListener('mouseup', RI.eventHandler, false);
           document.addEventListener('mousedown', RI.eventHandler, false);
           document.addEventListener('blur', RI.eventHandler, false);
           document.addEventListener('onvisbilitychange', RI.eventHandler, false);
        }
        if (RI.temp === null) RI.temp = _malloc(42);
        var s = _malloc(42);
        _memset(s, 0, 42);
        RI.contexts.push({
           state: s
        });
        return RI.contexts.length;
     }
  function _strstr(ptr1, ptr2) {
      var check = 0, start;
      do {
        if (!check) {
          start = ptr1;
          check = ptr2;
        }
        var curr1 = HEAP8[((ptr1++)|0)];
        var curr2 = HEAP8[((check++)|0)];
        if (curr2 == 0) return start;
        if (curr2 != curr1) {
          // rewind to one character after start, to find ez in eeez
          ptr1 = start + 1;
          check = 0;
        }
      } while (curr1);
      return 0;
    }
  Module["_memmove"] = _memmove;var _llvm_memmove_p0i8_p0i8_i32=_memmove;
  Module["_memcmp"] = _memcmp;
  var RA={BUFFER_SIZE:256,context:null,buffers:[],numBuffers:0,bufIndex:0,bufOffset:0,startTime:0,nonblock:false,currentTimeWorkaround:false,setStartTime:function () {
           if (RA.context.currentTime) {
              RA.startTime = window['performance']['now']() - RA.context.currentTime * 1000;
              var time1 = RA.context.currentTime;
              _usleep(50);
              if (time1 === RA.context.currentTime) {
                 RA.currentTimeWorkaround = true;
                 if (RA.startTime === 0) throw 'startTime is 0';
              }
              Module["resumeMainLoop"]();
           } else window['setTimeout'](RA.setStartTime, 0);
        },getCurrentPerfTime:function () {
           if (!RA.currentTimeWorkaround) return RA.context.currentTime;
           else if (RA.startTime) return (window['performance']['now']() - RA.startTime) / 1000;
           else throw 'getCurrentPerfTime() called before start time set';
        },process:function (queueBuffers) {
           var currentTime = RA.getCurrentPerfTime();
           for (var i = 0; i < RA.bufIndex; i++) {
              if (RA.buffers[i].endTime < currentTime) {
                 var buf = RA.buffers.splice(i, 1);
                 RA.buffers[RA.numBuffers - 1] = buf[0];
                 i--;
                 RA.bufIndex--;
              }
           }
        },fillBuffer:function (buf, samples) {
           var count = 0;
           var leftBuffer = RA.buffers[RA.bufIndex].getChannelData(0);
           var rightBuffer = RA.buffers[RA.bufIndex].getChannelData(1);
           while (samples && RA.bufOffset !== RA.BUFFER_SIZE) {
              leftBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8))>>2)];
              rightBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8 + 4))>>2)];
              RA.bufOffset++;
              count++;
              samples--;
           }
           return count;
        },queueAudio:function () {
           var index = RA.bufIndex;
           var startTime;
           if (RA.bufIndex) startTime = RA.buffers[RA.bufIndex - 1].endTime;
           else startTime = RA.context.currentTime;
           RA.buffers[index].endTime = startTime + RA.buffers[index].duration;
           var bufferSource = RA.context.createBufferSource();
           bufferSource.buffer = RA.buffers[index];
           bufferSource.connect(RA.context.destination);
           bufferSource.start(startTime);
           RA.bufIndex++;
           RA.bufOffset = 0;
        },block:function () {
           do {
              RA.process();
           } while (RA.bufIndex === RA.numBuffers - 1);
        }};function _RWebAudioBufferSize() {
        return RA.numBuffers * RA.BUFFER_SIZE + RA.BUFFER_SIZE;
     }
  function _RWebAudioWriteAvail() {
        RA.process();
        return ((RA.numBuffers - RA.bufIndex) * RA.BUFFER_SIZE - RA.bufOffset) * 8;
     }
  function _RWebAudioFree() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return;
     }
  function _RWebAudioSetNonblockState(state) {
        RA.nonblock = state;
     }
  function _RWebAudioStart() {
        return true;
     }
  function _RWebAudioStop() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return true;
     }
  function _RWebAudioWrite(buf, size) {
        RA.process();
        var samples = size / 8;
        var count = 0;
        while (samples) {
           var fill = RA.fillBuffer(buf, samples);
           samples -= fill;
           count += fill;
           buf += fill * 8;
           if (RA.bufOffset === RA.BUFFER_SIZE) {
              if (RA.bufIndex === RA.numBuffers - 1) {
                 if (RA.nonblock) break;
                 else RA.block();
              }
              RA.queueAudio();
           }
        }
        return count * 8;
     }
  function _RWebAudioInit(latency) {
        var ac = window['AudioContext'] || window['webkitAudioContext'];
        if (!ac) return 0;
        RA.context = new ac();
        RA.numBuffers = ((latency * RA.context.sampleRate) / (1000 * RA.BUFFER_SIZE))|0;
        if (RA.numBuffers < 2) RA.numBuffers = 2;
        for (var i = 0; i < RA.numBuffers; i++) RA.buffers[i] = RA.context.createBuffer(2, RA.BUFFER_SIZE, RA.context.sampleRate);
        RA.nonblock = false;
        RA.startTime = 0;
        // chrome hack to get currentTime running
        RA.context.createGain();
        window['setTimeout'](RA.setStartTime, 0);
        Module["pauseMainLoop"]();
        return 1;
     }
  function _RWebAudioSampleRate() {
        return RA.context.sampleRate;
     }
  var _fabsf=Math.abs;
  var _sin=Math.sin;
  var _ceil=Math.ceil;
  function _emscripten_get_now() {
      if (!_emscripten_get_now.actual) {
        if (ENVIRONMENT_IS_NODE) {
            _emscripten_get_now.actual = function() {
              var t = process['hrtime']();
              return t[0] * 1e3 + t[1] / 1e6;
            }
        } else if (typeof dateNow !== 'undefined') {
          _emscripten_get_now.actual = dateNow;
        } else if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
          _emscripten_get_now.actual = function() { return window['performance']['now'](); };
        } else {
          _emscripten_get_now.actual = Date.now;
        }
      }
      return _emscripten_get_now.actual();
    }
  function _llvm_uadd_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm["setTempRet0"](x+y > 4294967295),(x+y)>>>0)|0);
    }
  var GL={counter:1,buffers:[],programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],currArrayBuffer:0,currElementArrayBuffer:0,byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],uniformTable:{},packAlignment:4,unpackAlignment:4,init:function () {
        Browser.moduleContextCreatedCallbacks.push(GL.initExtensions);
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:16,miniTempBuffer:null,miniTempBufferViews:[0],MAX_TEMP_BUFFER_SIZE:2097152,tempBufferIndexLookup:null,tempVertexBuffers:null,tempIndexBuffers:null,tempQuadIndexBuffer:null,generateTempBuffers:function (quads) {
        GL.tempBufferIndexLookup = new Uint8Array(GL.MAX_TEMP_BUFFER_SIZE+1);
        GL.tempVertexBuffers = [];
        GL.tempIndexBuffers = [];
        var last = -1, curr = -1;
        var size = 1;
        for (var i = 0; i <= GL.MAX_TEMP_BUFFER_SIZE; i++) {
          if (i > size) {
            size <<= 1;
          }
          if (size != last) {
            curr++;
            GL.tempVertexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, GL.tempVertexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, null);
            GL.tempIndexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempIndexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
            last = size;
          }
          GL.tempBufferIndexLookup[i] = curr;
        }
        if (quads) {
          // GL_QUAD indexes can be precalculated
          GL.tempQuadIndexBuffer = Module.ctx.createBuffer();
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempQuadIndexBuffer);
          var numIndexes = GL.MAX_TEMP_BUFFER_SIZE >> 1;
          var quadIndexes = new Uint16Array(numIndexes);
          var i = 0, v = 0;
          while (1) {
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+1;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+3;
            if (i >= numIndexes) break;
            v += 4;
          }
          Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, quadIndexes, Module.ctx.STATIC_DRAW);
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
        }
      },findToken:function (source, token) {
        function isIdentChar(ch) {
          if (ch >= 48 && ch <= 57) // 0-9
            return true;
          if (ch >= 65 && ch <= 90) // A-Z
            return true;
          if (ch >= 97 && ch <= 122) // a-z
            return true;
          return false;
        }
        var i = -1;
        do {
          i = source.indexOf(token, i + 1);
          if (i < 0) {
            break;
          }
          if (i > 0 && isIdentChar(source[i - 1])) {
            continue;
          }
          i += token.length;
          if (i < source.length - 1 && isIdentChar(source[i + 1])) {
            continue;
          }
          return true;
        } while (true);
        return false;
      },getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        // Let's see if we need to enable the standard derivatives extension
        type = Module.ctx.getShaderParameter(GL.shaders[shader], 0x8B4F /* GL_SHADER_TYPE */);
        if (type == 0x8B30 /* GL_FRAGMENT_SHADER */) {
          if (GL.findToken(source, "dFdx") ||
              GL.findToken(source, "dFdy") ||
              GL.findToken(source, "fwidth")) {
            source = "#extension GL_OES_standard_derivatives : enable\n" + source;
            var extension = Module.ctx.getExtension("OES_standard_derivatives");
          }
        }
        return source;
      },computeImageSize:function (width, height, sizePerPixel, alignment) {
        function roundedToNextMultipleOf(x, y) {
          return Math.floor((x + y - 1) / y) * y
        }
        var plainRowSize = width * sizePerPixel;
        var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
        return (height <= 0) ? 0 :
                 ((height - 1) * alignedRowSize + plainRowSize);
      },getTexPixelData:function (type, format, width, height, pixels, internalFormat) {
        var sizePerPixel;
        switch (type) {
          case 0x1401 /* GL_UNSIGNED_BYTE */:
            switch (format) {
              case 0x1906 /* GL_ALPHA */:
              case 0x1909 /* GL_LUMINANCE */:
                sizePerPixel = 1;
                break;
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4;
                break;
              case 0x190A /* GL_LUMINANCE_ALPHA */:
                sizePerPixel = 2;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            break;
          case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
          case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
          case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
            sizePerPixel = 2;
            break;
          case 0x1406 /* GL_FLOAT */:
            assert(GL.floatExt, 'Must have OES_texture_float to use float textures');
            switch (format) {
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3*4;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4*4;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            internalFormat = Module.ctx.RGBA;
            break;
          default:
            throw 'Invalid type (' + type + ')';
        }
        var bytes = GL.computeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
        if (type == 0x1401 /* GL_UNSIGNED_BYTE */) {
          pixels = HEAPU8.subarray((pixels),(pixels+bytes));
        } else if (type == 0x1406 /* GL_FLOAT */) {
          pixels = HEAPF32.subarray((pixels)>>2,(pixels+bytes)>>2);
        } else {
          pixels = HEAPU16.subarray((pixels)>>1,(pixels+bytes)>>1);
        }
        return {
          pixels: pixels,
          internalFormat: internalFormat
        }
      },initExtensions:function () {
        if (GL.initExtensions.done) return;
        GL.initExtensions.done = true;
        if (!Module.useWebGL) return; // an app might link both gl and 2d backends
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }
        GL.maxVertexAttribs = Module.ctx.getParameter(Module.ctx.MAX_VERTEX_ATTRIBS);
        GL.compressionExt = Module.ctx.getExtension('WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('MOZ_WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('WEBKIT_WEBGL_compressed_texture_s3tc');
        GL.anisotropicExt = Module.ctx.getExtension('EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('MOZ_EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('WEBKIT_EXT_texture_filter_anisotropic');
        GL.floatExt = Module.ctx.getExtension('OES_texture_float');
        GL.elementIndexUintExt = Module.ctx.getExtension('OES_element_index_uint');
        GL.standardDerivativesExt = Module.ctx.getExtension('OES_standard_derivatives');
      }};function _glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        Module.ctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }
  function _glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        Module.ctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }
  function _glViewport(x0, x1, x2, x3) { Module.ctx.viewport(x0, x1, x2, x3) }
  function _glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.textures);
        var texture = Module.ctx.createTexture();
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }
  function _glBindTexture(target, texture) {
      Module.ctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }
  function _glTexParameteri(x0, x1, x2) { Module.ctx.texParameteri(x0, x1, x2) }
  function _glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      Module.ctx.pixelStorei(pname, param);
    }
  function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, internalFormat);
        pixels = data.pixels;
        internalFormat = data.internalFormat;
      } else {
        pixels = null;
      }
      Module.ctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels);
    }
  function _glBindFramebuffer(target, framebuffer) {
      Module.ctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
    }
  function _glReadPixels(x, y, width, height, format, type, pixels) {
      assert(type == 0x1401 /* GL_UNSIGNED_BYTE */);
      var sizePerPixel;
      switch (format) {
        case 0x1907 /* GL_RGB */:
          sizePerPixel = 3;
          break;
        case 0x1908 /* GL_RGBA */:
          sizePerPixel = 4;
          break;
        default: throw 'unsupported glReadPixels format';
      }
      var totalSize = width*height*sizePerPixel;
      Module.ctx.readPixels(x, y, width, height, format, type, HEAPU8.subarray(pixels, pixels + totalSize));
    }
  function _glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        Module.ctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }
  function _glGetIntegerv(name_, p) {
      switch(name_) { // Handle a few trivial GLES values
        case 0x8DFA: // GL_SHADER_COMPILER
          HEAP32[((p)>>2)]=1;
          return;
        case 0x8DF9: // GL_NUM_SHADER_BINARY_FORMATS
          HEAP32[((p)>>2)]=0;
          return;
        case 0x86A2: // GL_NUM_COMPRESSED_TEXTURE_FORMATS
          // WebGL doesn't have GL_NUM_COMPRESSED_TEXTURE_FORMATS (it's obsolete since GL_COMPRESSED_TEXTURE_FORMATS returns a JS array that can be queried for length),
          // so implement it ourselves to allow C++ GLES2 code get the length.
          var formats = Module.ctx.getParameter(0x86A3 /*GL_COMPRESSED_TEXTURE_FORMATS*/);
          HEAP32[((p)>>2)]=formats.length;
          return;
      }
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAP8[(p)]=result ? 1 : 0;
          break;
        case "string":
          throw 'Native code calling glGetIntegerv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP32[((p)>>2)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetIntegerv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var id = GL.getNewId(GL.framebuffers);
        var framebuffer = Module.ctx.createFramebuffer();
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }
  function _glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.renderbuffers);
        var renderbuffer = Module.ctx.createRenderbuffer();
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }
  function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      Module.ctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }
  function _glBindRenderbuffer(target, renderbuffer) {
      Module.ctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }
  function _glRenderbufferStorage(x0, x1, x2, x3) { Module.ctx.renderbufferStorage(x0, x1, x2, x3) }
  function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      Module.ctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }
  function _glCheckFramebufferStatus(x0) { return Module.ctx.checkFramebufferStatus(x0) }
  function _glGetString(name_) {
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x1F02 /* GL_VERSION */:
          return allocate(intArrayFromString(Module.ctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
        case 0x1F03 /* GL_EXTENSIONS */:
          return allocate(intArrayFromString(Module.ctx.getSupportedExtensions().join(' ')), 'i8', ALLOC_NORMAL);
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          return allocate(intArrayFromString('OpenGL ES GLSL 1.00 (WebGL)'), 'i8', ALLOC_NORMAL);
        default:
          throw 'Failure: Invalid glGetString value: ' + name_;
      }
    }
  function _glDisable(x0) { Module.ctx.disable(x0) }
  function _glBlendFunc(x0, x1) { Module.ctx.blendFunc(x0, x1) }
  function _glClearColor(x0, x1, x2, x3) { Module.ctx.clearColor(x0, x1, x2, x3) }
  function _glClear(x0) { Module.ctx.clear(x0) }
  function _glDrawArrays(mode, first, count) {
      Module.ctx.drawArrays(mode, first, count);
    }
  function _glEnable(x0) { Module.ctx.enable(x0) }
  function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, -1);
        pixels = data.pixels;
      } else {
        pixels = null;
      }
      Module.ctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels);
    }
  function _glGetError() { return Module.ctx.getError() }
  var _cosf=Math.cos;
  var _sinf=Math.sin;
  function _glGetFloatv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAPF32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAPF32[((p)>>2)]=result ? 1.0 : 0.0;
          break;
        case "string":
            HEAPF32[((p)>>2)]=0;
        case "object":
          if (result === null) {
            throw 'Native code calling glGetFloatv(' + name_ + ') and it returns null';
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAPF32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetFloatv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGetBooleanv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP8[(p)]=result != 0;
          break;
        case "boolean":
          HEAP8[(p)]=result != 0;
          break;
        case "string":
          throw 'Native code calling glGetBooleanv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP8[(p)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP8[(((p)+(i))|0)]=result[i] != 0;
            }
          } else if (result instanceof WebGLBuffer ||
                     result instanceof WebGLProgram ||
                     result instanceof WebGLFramebuffer ||
                     result instanceof WebGLRenderbuffer ||
                     result instanceof WebGLTexture) {
            HEAP8[(p)]=1; // non-zero ID is always 1!
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
            throw 'Unknown object returned from WebGL getParameter';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data);
    }
  function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, data);
    }
  function _glGetTexParameterfv(target, pname, params) {
      HEAPF32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glGetTexParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      Module.ctx.texParameterf(target, pname, param);
    }
  function _glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      Module.ctx.texParameteri(target, pname, param);
    }
  function _glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return Module.ctx.isTexture(texture);
    }
  function _glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.buffers);
        var buffer = Module.ctx.createBuffer();
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }
  function _glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
        Module.ctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }
  function _glGetBufferParameteriv(target, value, data) {
      HEAP32[((data)>>2)]=Module.ctx.getBufferParameter(target, value);
    }
  function _glBufferData(target, size, data, usage) {
      switch (usage) { // fix usages, WebGL only has *_DRAW
        case 0x88E1: // GL_STREAM_READ
        case 0x88E2: // GL_STREAM_COPY
          usage = 0x88E0; // GL_STREAM_DRAW
          break;
        case 0x88E5: // GL_STATIC_READ
        case 0x88E6: // GL_STATIC_COPY
          usage = 0x88E4; // GL_STATIC_DRAW
          break;
        case 0x88E9: // GL_DYNAMIC_READ
        case 0x88EA: // GL_DYNAMIC_COPY
          usage = 0x88E8; // GL_DYNAMIC_DRAW
          break;
      }
      Module.ctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
    }
  function _glBufferSubData(target, offset, size, data) {
      Module.ctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }
  function _glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return Module.ctx.isBuffer(b);
    }
  function _glGetRenderbufferParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.ctx.getRenderbufferParameter(target, pname);
    }
  function _glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return Module.ctx.isRenderbuffer(rb);
    }
  function _glGetUniformfv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformiv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
      var ptable = GL.uniformTable[program];
      if (!ptable) ptable = GL.uniformTable[program] = {};
      var id = ptable[name];
      if (id) return id;
      var loc = Module.ctx.getUniformLocation(GL.programs[program], name);
      if (!loc) return -1;
      id = GL.getNewId(GL.uniforms);
      GL.uniforms[id] = loc;
      ptable[name] = id;
      return id;
    }
  function _glGetVertexAttribfv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribiv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribPointerv(index, pname, pointer) {
      HEAP32[((pointer)>>2)]=Module.ctx.getVertexAttribOffset(index, pname);
    }
  function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveUniform(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glUniform1f(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1f(location, v0);
    }
  function _glUniform2f(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2f(location, v0, v1);
    }
  function _glUniform3f(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3f(location, v0, v1, v2);
    }
  function _glUniform4f(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4f(location, v0, v1, v2, v3);
    }
  function _glUniform1i(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1i(location, v0);
    }
  function _glUniform2i(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2i(location, v0, v1);
    }
  function _glUniform3i(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3i(location, v0, v1, v2);
    }
  function _glUniform4i(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4i(location, v0, v1, v2, v3);
    }
  function _glUniform1iv(location, count, value) {
      location = GL.uniforms[location];
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform1iv(location, value);
    }
  function _glUniform2iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 2;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform2iv(location, value);
    }
  function _glUniform3iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 3;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform3iv(location, value);
    }
  function _glUniform4iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 4;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform4iv(location, value);
    }
  function _glUniform1fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[0];
        view[0] = HEAPF32[((value)>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      Module.ctx.uniform1fv(location, view);
    }
  function _glUniform2fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[1];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      Module.ctx.uniform2fv(location, view);
    }
  function _glUniform3fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[2];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      Module.ctx.uniform3fv(location, view);
    }
  function _glUniform4fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[3];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
        view[3] = HEAPF32[(((value)+(12))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniform4fv(location, view);
    }
  function _glUniformMatrix2fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[3];
        for (var i = 0; i < 4; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniformMatrix2fv(location, transpose, view);
    }
  function _glUniformMatrix3fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[8];
        for (var i = 0; i < 9; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      Module.ctx.uniformMatrix3fv(location, transpose, view);
    }
  function _glUniformMatrix4fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[15];
        for (var i = 0; i < 16; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      Module.ctx.uniformMatrix4fv(location, transpose, view);
    }
  function _glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
      if (target == Module.ctx.ARRAY_BUFFER) {
        GL.currArrayBuffer = buffer;
      } else if (target == Module.ctx.ELEMENT_ARRAY_BUFFER) {
        GL.currElementArrayBuffer = buffer;
      }
      Module.ctx.bindBuffer(target, bufferObj);
    }
  function _glVertexAttrib1fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+4)>>2);
      Module.ctx.vertexAttrib1fv(index, v);
    }
  function _glVertexAttrib2fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+8)>>2);
      Module.ctx.vertexAttrib2fv(index, v);
    }
  function _glVertexAttrib3fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+12)>>2);
      Module.ctx.vertexAttrib3fv(index, v);
    }
  function _glVertexAttrib4fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+16)>>2);
      Module.ctx.vertexAttrib4fv(index, v);
    }
  function _glGetAttribLocation(program, name) {
      program = GL.programs[program];
      name = Pointer_stringify(name);
      return Module.ctx.getAttribLocation(program, name);
    }
  function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveAttrib(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = Module.ctx.createShader(shaderType);
      return id;
    }
  function _glDeleteShader(shader) {
      Module.ctx.deleteShader(GL.shaders[shader]);
      GL.shaders[shader] = null;
    }
  function _glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = Module.ctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        assert(id !== -1, 'shader not bound to local id');
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }
  function _glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
      Module.ctx.shaderSource(GL.shaders[shader], source);
    }
  function _glGetShaderSource(shader, bufSize, length, source) {
      var result = Module.ctx.getShaderSource(GL.shaders[shader]);
      result = result.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(result, source);
      if (length) {
        HEAP32[((length)>>2)]=result.length;
      }
    }
  function _glCompileShader(shader) {
      Module.ctx.compileShader(GL.shaders[shader]);
    }
  function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = Module.ctx.getShaderInfoLog(GL.shaders[shader]);
      // Work around a bug in Chromium which causes getShaderInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glGetShaderiv(shader, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getShaderInfoLog(GL.shaders[shader]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }
  function _glGetProgramiv(program, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getProgramInfoLog(GL.programs[program]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getProgramParameter(GL.programs[program], pname);
      }
    }
  function _glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return Module.ctx.isShader(s);
    }
  function _glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = Module.ctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }
  function _glDeleteProgram(program) {
      var program = GL.programs[program];
      Module.ctx.deleteProgram(program);
      program.name = 0;
      GL.programs[program] = null;
      GL.uniformTable[program] = null;
    }
  function _glAttachShader(program, shader) {
      Module.ctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glDetachShader(program, shader) {
      Module.ctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = Module.ctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }
  function _glLinkProgram(program) {
      Module.ctx.linkProgram(GL.programs[program]);
      GL.uniformTable[program] = {}; // uniforms no longer keep the same names after linking
    }
  function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = Module.ctx.getProgramInfoLog(GL.programs[program]);
      // Work around a bug in Chromium which causes getProgramInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glUseProgram(program) {
      Module.ctx.useProgram(program ? GL.programs[program] : null);
    }
  function _glValidateProgram(program) {
      Module.ctx.validateProgram(GL.programs[program]);
    }
  function _glIsProgram(program) {
      var program = GL.programs[program];
      if (!program) return 0;
      return Module.ctx.isProgram(program);
    }
  function _glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      Module.ctx.bindAttribLocation(GL.programs[program], index, name);
    }
  function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = Module.ctx.getFramebufferAttachmentParameter(target, attachment, pname);
      HEAP32[((params)>>2)]=params;
    }
  function _glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return Module.ctx.isFramebuffer(fb);
    }
  function _glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glGenVertexArrays(){ throw 'Legacy GL function (glGenVertexArrays) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glBegin(){ throw 'Legacy GL function (glBegin) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _gluPerspective(fov, aspect, near, far) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix[GL.immediate.currentMatrix] =
        GL.immediate.matrix.lib.mat4.perspective(fov, aspect, near, far,
                                                 GL.immediate.matrix[GL.immediate.currentMatrix]);
    }
  function _gluLookAt(ex, ey, ez, cx, cy, cz, ux, uy, uz) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix.lib.mat4.lookAt(GL.immediate.matrix[GL.immediate.currentMatrix], [ex, ey, ez],
          [cx, cy, cz], [ux, uy, uz]);
    }
  function _gluProject(objX, objY, objZ, model, proj, view, winX, winY, winZ) {
      // The algorithm for this functions comes from Mesa
      var inVec = new Float32Array(4);
      var outVec = new Float32Array(4);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((model)>>3,(model+128)>>3),
          [objX, objY, objZ, 1.0], outVec);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          outVec, inVec);
      if (inVec[3] == 0.0) {
        return 0 /* GL_FALSE */;
      }
      inVec[0] /= inVec[3];
      inVec[1] /= inVec[3];
      inVec[2] /= inVec[3];
      // Map x, y and z to range 0-1 */
      inVec[0] = inVec[0] * 0.5 + 0.5;
      inVec[1] = inVec[1] * 0.5 + 0.5;
      inVec[2] = inVec[2] * 0.5 + 0.5;
      // Map x, y to viewport
      inVec[0] = inVec[0] * HEAP32[(((view)+(8))>>2)] + HEAP32[((view)>>2)];
      inVec[1] = inVec[1] * HEAP32[(((view)+(12))>>2)] + HEAP32[(((view)+(4))>>2)];
      HEAPF64[((winX)>>3)]=inVec[0];
      HEAPF64[((winY)>>3)]=inVec[1];
      HEAPF64[((winZ)>>3)]=inVec[2];
      return 1 /* GL_TRUE */;
    }
  function _gluUnProject(winX, winY, winZ, model, proj, view, objX, objY, objZ) {
      var result = GL.immediate.matrix.lib.mat4.unproject([winX, winY, winZ],
          HEAPF64.subarray((model)>>3,(model+128)>>3),
          HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          HEAP32.subarray((view)>>2,(view+16)>>2));
      if (result === null) {
        return 0 /* GL_FALSE */;
      }
      HEAPF64[((objX)>>3)]=result[0];
      HEAPF64[((objY)>>3)]=result[1];
      HEAPF64[((objZ)>>3)]=result[2];
      return 1 /* GL_TRUE */;
    }
  function _gluOrtho2D(left, right, bottom, top) {
      _glOrtho(left, right, bottom, top, -1, 1);
    }
  function _glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      Module.ctx.vertexAttribPointer(index, size, type, normalized, stride, ptr);
    }
  function _glEnableVertexAttribArray(index) {
      Module.ctx.enableVertexAttribArray(index);
    }
  function _glDisableVertexAttribArray(index) {
      Module.ctx.disableVertexAttribArray(index);
    }
  function _glDrawElements(mode, count, type, indices) {
      Module.ctx.drawElements(mode, count, type, indices);
    }
  function _glFinish() { Module.ctx.finish() }
  function _glFlush() { Module.ctx.flush() }
  function _glClearDepth(x0) { Module.ctx.clearDepth(x0) }
  function _glClearDepthf(x0) { Module.ctx.clearDepth(x0) }
  function _glDepthFunc(x0) { Module.ctx.depthFunc(x0) }
  function _glFrontFace(x0) { Module.ctx.frontFace(x0) }
  function _glCullFace(x0) { Module.ctx.cullFace(x0) }
  function _glLineWidth(x0) { Module.ctx.lineWidth(x0) }
  function _glClearStencil(x0) { Module.ctx.clearStencil(x0) }
  function _glDepthMask(x0) { Module.ctx.depthMask(x0) }
  function _glStencilMask(x0) { Module.ctx.stencilMask(x0) }
  function _glGenerateMipmap(x0) { Module.ctx.generateMipmap(x0) }
  function _glActiveTexture(x0) { Module.ctx.activeTexture(x0) }
  function _glBlendEquation(x0) { Module.ctx.blendEquation(x0) }
  function _glSampleCoverage(x0) { Module.ctx.sampleCoverage(x0) }
  function _glIsEnabled(x0) { return Module.ctx.isEnabled(x0) }
  function _glBlendEquationSeparate(x0, x1) { Module.ctx.blendEquationSeparate(x0, x1) }
  function _glDepthRange(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glDepthRangef(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glStencilMaskSeparate(x0, x1) { Module.ctx.stencilMaskSeparate(x0, x1) }
  function _glHint(x0, x1) { Module.ctx.hint(x0, x1) }
  function _glPolygonOffset(x0, x1) { Module.ctx.polygonOffset(x0, x1) }
  function _glVertexAttrib1f(x0, x1) { Module.ctx.vertexAttrib1f(x0, x1) }
  function _glTexParameterf(x0, x1, x2) { Module.ctx.texParameterf(x0, x1, x2) }
  function _glVertexAttrib2f(x0, x1, x2) { Module.ctx.vertexAttrib2f(x0, x1, x2) }
  function _glStencilFunc(x0, x1, x2) { Module.ctx.stencilFunc(x0, x1, x2) }
  function _glStencilOp(x0, x1, x2) { Module.ctx.stencilOp(x0, x1, x2) }
  function _glScissor(x0, x1, x2, x3) { Module.ctx.scissor(x0, x1, x2, x3) }
  function _glVertexAttrib3f(x0, x1, x2, x3) { Module.ctx.vertexAttrib3f(x0, x1, x2, x3) }
  function _glColorMask(x0, x1, x2, x3) { Module.ctx.colorMask(x0, x1, x2, x3) }
  function _glBlendFuncSeparate(x0, x1, x2, x3) { Module.ctx.blendFuncSeparate(x0, x1, x2, x3) }
  function _glBlendColor(x0, x1, x2, x3) { Module.ctx.blendColor(x0, x1, x2, x3) }
  function _glStencilFuncSeparate(x0, x1, x2, x3) { Module.ctx.stencilFuncSeparate(x0, x1, x2, x3) }
  function _glStencilOpSeparate(x0, x1, x2, x3) { Module.ctx.stencilOpSeparate(x0, x1, x2, x3) }
  function _glVertexAttrib4f(x0, x1, x2, x3, x4) { Module.ctx.vertexAttrib4f(x0, x1, x2, x3, x4) }
  function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }
  function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }function _emscripten_procAddressTable(name) {
  switch(name) {
  case "glPixelStorei": return 192; break;
  case "glGetString": return 146; break;
  case "glGetIntegerv": return 72; break;
  case "glGetFloatv": return 90; break;
  case "glGetBooleanv": return 112; break;
  case "glGenTextures": return 70; break;
  case "glDeleteTextures": return 122; break;
  case "glCompressedTexImage2D": return 2; break;
  case "glCompressedTexSubImage2D": return 4; break;
  case "glTexImage2D": return 12; break;
  case "glTexSubImage2D": return 6; break;
  case "glReadPixels": return 22; break;
  case "glBindTexture": return 88; break;
  case "glGetTexParameterfv": return 98; break;
  case "glGetTexParameteriv": return 12; break;
  case "glTexParameterfv": return 58; break;
  case "glTexParameteriv": return 2; break;
  case "glIsTexture": return 210; break;
  case "glGenBuffers": return 110; break;
  case "glDeleteBuffers": return 32; break;
  case "glGetBufferParameteriv": return 100; break;
  case "glBufferData": return 50; break;
  case "glBufferSubData": return 18; break;
  case "glIsBuffer": return 134; break;
  case "glGenRenderbuffers": return 188; break;
  case "glDeleteRenderbuffers": return 152; break;
  case "glBindRenderbuffer": return 120; break;
  case "glGetRenderbufferParameteriv": return 66; break;
  case "glIsRenderbuffer": return 222; break;
  case "glGetUniformfv": return 62; break;
  case "glGetUniformiv": return 32; break;
  case "glGetUniformLocation": return 72; break;
  case "glGetVertexAttribfv": return 54; break;
  case "glGetVertexAttribiv": return 56; break;
  case "glGetVertexAttribPointerv": return 18; break;
  case "glGetActiveUniform": return 26; break;
  case "glUniform1f": return 4; break;
  case "glUniform2f": return 2; break;
  case "glUniform3f": return 2; break;
  case "glUniform4f": return 6; break;
  case "glUniform1i": return 180; break;
  case "glUniform2i": return 10; break;
  case "glUniform3i": return 22; break;
  case "glUniform4i": return 12; break;
  case "glUniform1iv": return 24; break;
  case "glUniform2iv": return 30; break;
  case "glUniform3iv": return 26; break;
  case "glUniform4iv": return 42; break;
  case "glUniform1fv": return 28; break;
  case "glUniform2fv": return 48; break;
  case "glUniform3fv": return 102; break;
  case "glUniform4fv": return 38; break;
  case "glUniformMatrix2fv": return 2; break;
  case "glUniformMatrix3fv": return 14; break;
  case "glUniformMatrix4fv": return 4; break;
  case "glBindBuffer": return 46; break;
  case "glVertexAttrib1fv": return 108; break;
  case "glVertexAttrib2fv": return 116; break;
  case "glVertexAttrib3fv": return 182; break;
  case "glVertexAttrib4fv": return 30; break;
  case "glGetAttribLocation": return 104; break;
  case "glGetActiveAttrib": return 24; break;
  case "glCreateShader": return 132; break;
  case "glDeleteShader": return 380; break;
  case "glGetAttachedShaders": return 52; break;
  case "glShaderSource": return 40; break;
  case "glGetShaderSource": return 38; break;
  case "glCompileShader": return 376; break;
  case "glGetShaderInfoLog": return 60; break;
  case "glGetShaderiv": return 36; break;
  case "glGetProgramiv": return 34; break;
  case "glIsShader": return 136; break;
  case "glCreateProgram": return 18; break;
  case "glDeleteProgram": return 44; break;
  case "glAttachShader": return 20; break;
  case "glDetachShader": return 136; break;
  case "glLinkProgram": return 96; break;
  case "glGetProgramInfoLog": return 64; break;
  case "glUseProgram": return 118; break;
  case "glValidateProgram": return 246; break;
  case "glIsProgram": return 218; break;
  case "glBindAttribLocation": return 40; break;
  case "glBindFramebuffer": return 74; break;
  case "glGenFramebuffers": return 76; break;
  case "glDeleteFramebuffers": return 82; break;
  case "glFramebufferRenderbuffer": return 6; break;
  case "glFramebufferTexture2D": return 10; break;
  case "glGetFramebufferAttachmentParameteriv": return 44; break;
  case "glIsFramebuffer": return 122; break;
  case "glVertexAttribPointer": return 32; break;
  case "glEnableVertexAttribArray": return 84; break;
  case "glDisableVertexAttribArray": return 12; break;
  case "glDrawArrays": return 14; break;
  case "glDrawElements": return 16; break;
  case "glGetError": return 4; break;
  case "glFinish": return 12; break;
  case "glFlush": return 58; break;
  case "glClearDepth": return 108; break;
  case "glClearDepthf": return 284; break;
  case "glDepthFunc": return 342; break;
  case "glEnable": return 256; break;
  case "glDisable": return 218; break;
  case "glFrontFace": return 186; break;
  case "glCullFace": return 62; break;
  case "glClear": return 98; break;
  case "glLineWidth": return 328; break;
  case "glClearStencil": return 2; break;
  case "glDepthMask": return 36; break;
  case "glStencilMask": return 416; break;
  case "glCheckFramebufferStatus": return 90; break;
  case "glGenerateMipmap": return 146; break;
  case "glActiveTexture": return 78; break;
  case "glBlendEquation": return 224; break;
  case "glSampleCoverage": return 294; break;
  case "glIsEnabled": return 150; break;
  case "glBlendFunc": return 102; break;
  case "glBlendEquationSeparate": return 38; break;
  case "glDepthRange": return 172; break;
  case "glDepthRangef": return 94; break;
  case "glStencilMaskSeparate": return 18; break;
  case "glHint": return 62; break;
  case "glPolygonOffset": return 50; break;
  case "glVertexAttrib1f": return 40; break;
  case "glTexParameteri": return 80; break;
  case "glTexParameterf": return 44; break;
  case "glVertexAttrib2f": return 90; break;
  case "glStencilFunc": return 46; break;
  case "glStencilOp": return 88; break;
  case "glViewport": return 10; break;
  case "glClearColor": return 12; break;
  case "glScissor": return 48; break;
  case "glVertexAttrib3f": return 62; break;
  case "glColorMask": return 58; break;
  case "glRenderbufferStorage": return 32; break;
  case "glBlendFuncSeparate": return 28; break;
  case "glBlendColor": return 34; break;
  case "glStencilFuncSeparate": return 36; break;
  case "glStencilOpSeparate": return 20; break;
  case "glVertexAttrib4f": return 2; break;
  case "glCopyTexImage2D": return 18; break;
  case "glCopyTexSubImage2D": return 8; break;
  }
  return 0;
  }function _emscripten_GetProcAddress(name) {
    name = name.replace('EXT', '').replace('ARB', '');
    switch(name) { // misc renamings
      case 'glCreateProgramObject': name = 'glCreateProgram'; break;
      case 'glUseProgramObject': name = 'glUseProgram'; break;
      case 'glCreateShaderObject': name = 'glCreateShader'; break;
      case 'glAttachObject': name = 'glAttachShader'; break;
      case 'glDetachObject': name = 'glDetachShader'; break;
    }
    var ret = _emscripten_procAddressTable(name);
    if (!ret) Module.printErr('WARNING: getProcAddress failed for ' + name);
    return ret;
  }function _eglGetProcAddress(name_) {
      return _emscripten_GetProcAddress(Pointer_stringify(name_));
    }
  function _emscripten_get_canvas_size(width, height, isFullscreen) {
      var canvas = Module['canvas'];
      HEAP32[((width)>>2)]=canvas.width;
      HEAP32[((height)>>2)]=canvas.height;
      HEAP32[((isFullscreen)>>2)]=Browser.isFullScreen ? 1 : 0;
    }
  var EGL={eglErrorCode:12288,setErrorCode:function (code) {
        EGL.eglErrorCode = code;
      },chooseConfig:function (display, attribList, config, config_size, numConfigs) { 
        if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
          EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
          return 0;
        }
        // TODO: read attribList.
        if ((!config || !config_size) && !numConfigs) {
          EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
          return 0;
        }
        if (numConfigs) {
          HEAP32[((numConfigs)>>2)]=1; // Total number of supported configs: 1.
        }
        if (config && config_size > 0) {
          HEAP32[((config)>>2)]=62002; 
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      }};function _eglBindAPI(api) {
      if (api == 0x30A0 /* EGL_OPENGL_ES_API */) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } else { // if (api == 0x30A1 /* EGL_OPENVG_API */ || api == 0x30A2 /* EGL_OPENGL_API */) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
    }
  function _eglMakeCurrent(display, draw, read, context) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      if (read != 62006 || draw != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _glutDestroyWindow(name) {
      Module.ctx = Browser.destroyContext(Module['canvas'], true, true);
      return 1;
    }function _eglDestroyContext(display, context) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglDestroySurface(display, surface) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0; 
      }
      if (surface != 62006 /* Magic ID for the only EGLSurface supported by Emscripten */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 1;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglTerminate(display) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      // TODO: Tear down EGL here. Currently a no-op since we don't need to actually do anything here for the browser.
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglGetDisplay(nativeDisplayType) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      // Note: As a 'conformant' implementation of EGL, we would prefer to init here only if the user
      //       calls this function with EGL_DEFAULT_DISPLAY. Other display IDs would be preferred to be unsupported
      //       and EGL_NO_DISPLAY returned. Uncomment the following code lines to do this.
      // Instead, an alternative route has been preferred, namely that the Emscripten EGL implementation
      // "emulates" X11, and eglGetDisplay is expected to accept/receive a pointer to an X11 Display object.
      // Therefore, be lax and allow anything to be passed in, and return the magic handle to our default EGLDisplay object.
  //    if (nativeDisplayType == 0 /* EGL_DEFAULT_DISPLAY */) {
          return 62000; // Magic ID for Emscripten 'default display'
  //    }
  //    else
  //      return 0; // EGL_NO_DISPLAY
    }
  function _eglInitialize(display, majorVersion, minorVersion) {
      if (display == 62000 /* Magic ID for Emscripten 'default display' */) {
        if (majorVersion) {
          HEAP32[((majorVersion)>>2)]=1; // Advertise EGL Major version: '1'
        }
        if (minorVersion) {
          HEAP32[((minorVersion)>>2)]=4; // Advertise EGL Minor version: '4'
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } 
      else {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
    }
  function _eglChooseConfig(display, attrib_list, configs, config_size, numConfigs) { 
      return EGL.chooseConfig(display, attrib_list, configs, config_size, numConfigs);
    }
  function _glutCreateWindow(name) {
      Module.ctx = Browser.createContext(Module['canvas'], true, true);
      return Module.ctx ? 1 /* a new GLUT window ID for the created context */ : 0 /* failure */;
    }function _eglCreateContext(display, config, hmm, contextAttribs) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      EGL.windowID = _glutCreateWindow();
      if (EGL.windowID != 0) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 62004; // Magic ID for Emscripten EGLContext
      } else {
        EGL.setErrorCode(0x3009 /* EGL_BAD_MATCH */); // By the EGL 1.4 spec, an implementation that does not support GLES2 (WebGL in this case), this error code is set.
        return 0; /* EGL_NO_CONTEXT */
      }
    }
  function _eglCreateWindowSurface(display, config, win, attrib_list) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      // TODO: Examine attrib_list! Parameters that can be present there are:
      // - EGL_RENDER_BUFFER (must be EGL_BACK_BUFFER)
      // - EGL_VG_COLORSPACE (can't be set)
      // - EGL_VG_ALPHA_FORMAT (can't be set)
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 62006; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglQuerySurface(display, surface, attribute, value) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (surface != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
      case 0x3028: // EGL_CONFIG_ID
        HEAP32[((value)>>2)]=62002;
          return 1;
      case 0x3058: // EGL_LARGEST_PBUFFER
        // Odd EGL API: If surface is not a pbuffer surface, 'value' should not be written to. It's not specified as an error, so true should(?) be returned.
        // Existing Android implementation seems to do so at least.
        return 1;
      case 0x3057: // EGL_WIDTH
        HEAP32[((value)>>2)]=Module.canvas.width;
        return 1;
      case 0x3056: // EGL_HEIGHT
        HEAP32[((value)>>2)]=Module.canvas.height;
        return 1;
      case 0x3090: // EGL_HORIZONTAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3091: // EGL_VERTICAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3092: // EGL_PIXEL_ASPECT_RATIO
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3086: // EGL_RENDER_BUFFER
        // The main surface is bound to the visible canvas window - it's always backbuffered. 
        // Alternative to EGL_BACK_BUFFER would be EGL_SINGLE_BUFFER.
        HEAP32[((value)>>2)]=0x3084; 
        return 1;
      case 0x3099: // EGL_MULTISAMPLE_RESOLVE
        HEAP32[((value)>>2)]=0x309A; 
        return 1;
      case 0x3093: // EGL_SWAP_BEHAVIOR
        // The two possibilities are EGL_BUFFER_PRESERVED and EGL_BUFFER_DESTROYED. Slightly unsure which is the
        // case for browser environment, but advertise the 'weaker' behavior to be sure.
        HEAP32[((value)>>2)]=0x3095;
        return 1;
      case 0x3080: // EGL_TEXTURE_FORMAT
      case 0x3081: // EGL_TEXTURE_TARGET
      case 0x3082: // EGL_MIPMAP_TEXTURE
      case 0x3083: // EGL_MIPMAP_LEVEL
        // This is a window surface, not a pbuffer surface. Spec:
        // "Querying EGL_TEXTURE_FORMAT, EGL_TEXTURE_TARGET, EGL_MIPMAP_TEXTURE, or EGL_MIPMAP_LEVEL for a non-pbuffer surface is not an error, but value is not modified."
        // So pass-through.
        return 1;
      default:
        EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
        return 0;
      }
    }
  function ___gxx_personality_v0() {
    }
  Module["_strncpy"] = _strncpy;
  Module["_strcpy"] = _strcpy;
  function __ZSt9terminatev() {
      _exit(-1234);
    }
  function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }
  Module["_strcat"] = _strcat;
  function _llvm_trap() {
      throw 'trap! ' + new Error().stack;
    }
  function __ZSt18uncaught_exceptionv() { // std::uncaught_exception()
      return !!__ZSt18uncaught_exceptionv.uncaught_exception;
    }function ___cxa_begin_catch(ptr) {
      __ZSt18uncaught_exceptionv.uncaught_exception--;
      return ptr;
    }
  function _llvm_eh_exception() {
      return HEAP32[((_llvm_eh_exception.buf)>>2)];
    }
  function ___cxa_free_exception(ptr) {
      try {
        return _free(ptr);
      } catch(e) { // XXX FIXME
      }
    }function ___cxa_end_catch() {
      if (___cxa_end_catch.rethrown) {
        ___cxa_end_catch.rethrown = false;
        return;
      }
      // Clear state flag.
      asm['setThrew'](0);
      // Clear type.
      HEAP32[(((_llvm_eh_exception.buf)+(4))>>2)]=0
      // Call destructor if one is registered then clear it.
      var ptr = HEAP32[((_llvm_eh_exception.buf)>>2)];
      var destructor = HEAP32[(((_llvm_eh_exception.buf)+(8))>>2)];
      if (destructor) {
        Runtime.dynCall('vi', destructor, [ptr]);
        HEAP32[(((_llvm_eh_exception.buf)+(8))>>2)]=0
      }
      // Free ptr if it isn't null.
      if (ptr) {
        ___cxa_free_exception(ptr);
        HEAP32[((_llvm_eh_exception.buf)>>2)]=0
      }
    }
  function ___cxa_allocate_exception(size) {
      return _malloc(size);
    }
  function ___cxa_is_number_type(type) {
      var isNumber = false;
      try { if (type == __ZTIi) isNumber = true } catch(e){}
      try { if (type == __ZTIj) isNumber = true } catch(e){}
      try { if (type == __ZTIl) isNumber = true } catch(e){}
      try { if (type == __ZTIm) isNumber = true } catch(e){}
      try { if (type == __ZTIx) isNumber = true } catch(e){}
      try { if (type == __ZTIy) isNumber = true } catch(e){}
      try { if (type == __ZTIf) isNumber = true } catch(e){}
      try { if (type == __ZTId) isNumber = true } catch(e){}
      try { if (type == __ZTIe) isNumber = true } catch(e){}
      try { if (type == __ZTIc) isNumber = true } catch(e){}
      try { if (type == __ZTIa) isNumber = true } catch(e){}
      try { if (type == __ZTIh) isNumber = true } catch(e){}
      try { if (type == __ZTIs) isNumber = true } catch(e){}
      try { if (type == __ZTIt) isNumber = true } catch(e){}
      return isNumber;
    }function ___cxa_does_inherit(definiteType, possibilityType, possibility) {
      if (possibility == 0) return false;
      if (possibilityType == 0 || possibilityType == definiteType)
        return true;
      var possibility_type_info;
      if (___cxa_is_number_type(possibilityType)) {
        possibility_type_info = possibilityType;
      } else {
        var possibility_type_infoAddr = HEAP32[((possibilityType)>>2)] - 8;
        possibility_type_info = HEAP32[((possibility_type_infoAddr)>>2)];
      }
      switch (possibility_type_info) {
      case 0: // possibility is a pointer
        // See if definite type is a pointer
        var definite_type_infoAddr = HEAP32[((definiteType)>>2)] - 8;
        var definite_type_info = HEAP32[((definite_type_infoAddr)>>2)];
        if (definite_type_info == 0) {
          // Also a pointer; compare base types of pointers
          var defPointerBaseAddr = definiteType+8;
          var defPointerBaseType = HEAP32[((defPointerBaseAddr)>>2)];
          var possPointerBaseAddr = possibilityType+8;
          var possPointerBaseType = HEAP32[((possPointerBaseAddr)>>2)];
          return ___cxa_does_inherit(defPointerBaseType, possPointerBaseType, possibility);
        } else
          return false; // one pointer and one non-pointer
      case 1: // class with no base class
        return false;
      case 2: // class with base class
        var parentTypeAddr = possibilityType + 8;
        var parentType = HEAP32[((parentTypeAddr)>>2)];
        return ___cxa_does_inherit(definiteType, parentType, possibility);
      default:
        return false; // some unencountered type
      }
    }
  function ___resumeException(ptr) {
      if (HEAP32[((_llvm_eh_exception.buf)>>2)] == 0) HEAP32[((_llvm_eh_exception.buf)>>2)]=ptr;
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";;
    }function ___cxa_find_matching_catch(thrown, throwntype) {
      if (thrown == -1) thrown = HEAP32[((_llvm_eh_exception.buf)>>2)];
      if (throwntype == -1) throwntype = HEAP32[(((_llvm_eh_exception.buf)+(4))>>2)];
      var typeArray = Array.prototype.slice.call(arguments, 2);
      // If throwntype is a pointer, this means a pointer has been
      // thrown. When a pointer is thrown, actually what's thrown
      // is a pointer to the pointer. We'll dereference it.
      if (throwntype != 0 && !___cxa_is_number_type(throwntype)) {
        var throwntypeInfoAddr= HEAP32[((throwntype)>>2)] - 8;
        var throwntypeInfo= HEAP32[((throwntypeInfoAddr)>>2)];
        if (throwntypeInfo == 0)
          thrown = HEAP32[((thrown)>>2)];
      }
      // The different catch blocks are denoted by different types.
      // Due to inheritance, those types may not precisely match the
      // type of the thrown object. Find one which matches, and
      // return the type of the catch block which should be called.
      for (var i = 0; i < typeArray.length; i++) {
        if (___cxa_does_inherit(typeArray[i], throwntype, thrown))
          return ((asm["setTempRet0"](typeArray[i]),thrown)|0);
      }
      // Shouldn't happen unless we have bogus data in typeArray
      // or encounter a type for which emscripten doesn't have suitable
      // typeinfo defined. Best-efforts match just in case.
      return ((asm["setTempRet0"](throwntype),thrown)|0);
    }function ___cxa_throw(ptr, type, destructor) {
      if (!___cxa_throw.initialized) {
        try {
          HEAP32[((__ZTVN10__cxxabiv119__pointer_type_infoE)>>2)]=0; // Workaround for libcxxabi integration bug
        } catch(e){}
        try {
          HEAP32[((__ZTVN10__cxxabiv117__class_type_infoE)>>2)]=1; // Workaround for libcxxabi integration bug
        } catch(e){}
        try {
          HEAP32[((__ZTVN10__cxxabiv120__si_class_type_infoE)>>2)]=2; // Workaround for libcxxabi integration bug
        } catch(e){}
        ___cxa_throw.initialized = true;
      }
      HEAP32[((_llvm_eh_exception.buf)>>2)]=ptr
      HEAP32[(((_llvm_eh_exception.buf)+(4))>>2)]=type
      HEAP32[(((_llvm_eh_exception.buf)+(8))>>2)]=destructor
      if (!("uncaught_exception" in __ZSt18uncaught_exceptionv)) {
        __ZSt18uncaught_exceptionv.uncaught_exception = 1;
      } else {
        __ZSt18uncaught_exceptionv.uncaught_exception++;
      }
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";;
    }
  var _fseeko=_fseek;
  var _ftello=_ftell;
  function ___cxa_call_unexpected(exception) {
      Module.printErr('Unexpected exception thrown, this is not properly supported - aborting');
      ABORT = true;
      throw exception;
    }
  function _pthread_mutex_lock() {}
  function _pthread_mutex_unlock() {}
  function ___cxa_guard_acquire(variable) {
      if (!HEAP8[(variable)]) { // ignore SAFE_HEAP stuff because llvm mixes i64 and i8 here
        HEAP8[(variable)]=1;
        return 1;
      }
      return 0;
    }
  function ___cxa_guard_release() {}
  function _pthread_cond_broadcast() {
      return 0;
    }
  function _pthread_cond_wait() {
      return 0;
    }
  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }var ___cxa_atexit=_atexit;
  function _ungetc(c, stream) {
      // int ungetc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ungetc.html
      stream = FS.getStream(stream);
      if (!stream) {
        return -1;
      }
      if (c === -1) {
        // do nothing for EOF character
        return c;
      }
      c = unSign(c & 0xFF);
      stream.ungotten.push(c);
      stream.eof = false;
      return c;
    }
  function _strerror_r(errnum, strerrbuf, buflen) {
      if (errnum in ERRNO_MESSAGES) {
        if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
          return ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          var msg = ERRNO_MESSAGES[errnum];
          for (var i = 0; i < msg.length; i++) {
            HEAP8[(((strerrbuf)+(i))|0)]=msg.charCodeAt(i)
          }
          HEAP8[(((strerrbuf)+(i))|0)]=0
          return 0;
        }
      } else {
        return ___setErrNo(ERRNO_CODES.EINVAL);
      }
    }function _strerror(errnum) {
      if (!_strerror.buffer) _strerror.buffer = _malloc(256);
      _strerror_r(errnum, _strerror.buffer, 256);
      return _strerror.buffer;
    }
  function _abort() {
      Module['abort']();
    }
  function ___cxa_rethrow() {
      ___cxa_end_catch.rethrown = true;
      throw HEAP32[((_llvm_eh_exception.buf)>>2)] + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";;
    }
  function _memchr(ptr, chr, num) {
      chr = unSign(chr);
      for (var i = 0; i < num; i++) {
        if (HEAP8[(ptr)] == chr) return ptr;
        ptr++;
      }
      return 0;
    }
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
        case 10: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
  function ___cxa_guard_abort() {}
  function _isxdigit(chr) {
      return (chr >= 48 && chr <= 57) ||
             (chr >= 97 && chr <= 102) ||
             (chr >= 65 && chr <= 70);
    }var _isxdigit_l=_isxdigit;
  function _isdigit(chr) {
      return chr >= 48 && chr <= 57;
    }var _isdigit_l=_isdigit;
  function __isFloat(text) {
      return !!(/^[+-]?[0-9]*\.?[0-9]+([eE][+-]?[0-9]+)?$/.exec(text));
    }function __scanString(format, get, unget, varargs) {
      if (!__scanString.whiteSpace) {
        __scanString.whiteSpace = {};
        __scanString.whiteSpace[32] = 1;
        __scanString.whiteSpace[9] = 1;
        __scanString.whiteSpace[10] = 1;
        __scanString.whiteSpace[11] = 1;
        __scanString.whiteSpace[12] = 1;
        __scanString.whiteSpace[13] = 1;
        __scanString.whiteSpace[' '] = 1;
        __scanString.whiteSpace['\t'] = 1;
        __scanString.whiteSpace['\n'] = 1;
        __scanString.whiteSpace['\v'] = 1;
        __scanString.whiteSpace['\f'] = 1;
        __scanString.whiteSpace['\r'] = 1;
      }
      // Supports %x, %4x, %d.%d, %lld, %s, %f, %lf.
      // TODO: Support all format specifiers.
      format = Pointer_stringify(format);
      var soFar = 0;
      if (format.indexOf('%n') >= 0) {
        // need to track soFar
        var _get = get;
        get = function() {
          soFar++;
          return _get();
        }
        var _unget = unget;
        unget = function() {
          soFar--;
          return _unget();
        }
      }
      var formatIndex = 0;
      var argsi = 0;
      var fields = 0;
      var argIndex = 0;
      var next;
      mainLoop:
      for (var formatIndex = 0; formatIndex < format.length;) {
        if (format[formatIndex] === '%' && format[formatIndex+1] == 'n') {
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          HEAP32[((argPtr)>>2)]=soFar;
          formatIndex += 2;
          continue;
        }
        if (format[formatIndex] === '%') {
          var nextC = format.indexOf('c', formatIndex+1);
          if (nextC > 0) {
            var maxx = 1;
            if (nextC > formatIndex+1) {
              var sub = format.substring(formatIndex+1, nextC)
              maxx = parseInt(sub);
              if (maxx != sub) maxx = 0;
            }
            if (maxx) {
              var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
              argIndex += Runtime.getAlignSize('void*', null, true);
              fields++;
              for (var i = 0; i < maxx; i++) {
                next = get();
                HEAP8[((argPtr++)|0)]=next;
              }
              formatIndex += nextC - formatIndex + 1;
              continue;
            }
          }
        }
        // remove whitespace
        while (1) {
          next = get();
          if (next == 0) return fields;
          if (!(next in __scanString.whiteSpace)) break;
        }
        unget();
        if (format[formatIndex] === '%') {
          formatIndex++;
          var suppressAssignment = false;
          if (format[formatIndex] == '*') {
            suppressAssignment = true;
            formatIndex++;
          }
          var maxSpecifierStart = formatIndex;
          while (format[formatIndex].charCodeAt(0) >= 48 &&
                 format[formatIndex].charCodeAt(0) <= 57) {
            formatIndex++;
          }
          var max_;
          if (formatIndex != maxSpecifierStart) {
            max_ = parseInt(format.slice(maxSpecifierStart, formatIndex), 10);
          }
          var long_ = false;
          var half = false;
          var longLong = false;
          if (format[formatIndex] == 'l') {
            long_ = true;
            formatIndex++;
            if (format[formatIndex] == 'l') {
              longLong = true;
              formatIndex++;
            }
          } else if (format[formatIndex] == 'h') {
            half = true;
            formatIndex++;
          }
          var type = format[formatIndex];
          formatIndex++;
          var curr = 0;
          var buffer = [];
          // Read characters according to the format. floats are trickier, they may be in an unfloat state in the middle, then be a valid float later
          if (type == 'f' || type == 'e' || type == 'g' ||
              type == 'F' || type == 'E' || type == 'G') {
            var last = 0;
            next = get();
            while (next > 0) {
              buffer.push(String.fromCharCode(next));
              if (__isFloat(buffer.join(''))) {
                last = buffer.length;
              }
              next = get();
            }
            for (var i = 0; i < buffer.length - last + 1; i++) {
              unget();
            }
            buffer.length = last;
          } else {
            next = get();
            var first = true;
            while ((curr < max_ || isNaN(max_)) && next > 0) {
              if (!(next in __scanString.whiteSpace) && // stop on whitespace
                  (type == 's' ||
                   ((type === 'd' || type == 'u' || type == 'i') && ((next >= 48 && next <= 57) ||
                                                                     (first && next == 45))) ||
                   ((type === 'x' || type === 'X') && (next >= 48 && next <= 57 ||
                                     next >= 97 && next <= 102 ||
                                     next >= 65 && next <= 70))) &&
                  (formatIndex >= format.length || next !== format[formatIndex].charCodeAt(0))) { // Stop when we read something that is coming up
                buffer.push(String.fromCharCode(next));
                next = get();
                curr++;
                first = false;
              } else {
                break;
              }
            }
            unget();
          }
          if (buffer.length === 0) return 0;  // Failure.
          if (suppressAssignment) continue;
          var text = buffer.join('');
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          switch (type) {
            case 'd': case 'u': case 'i':
              if (half) {
                HEAP16[((argPtr)>>1)]=parseInt(text, 10);
              } else if (longLong) {
                (tempI64 = [parseInt(text, 10)>>>0,(tempDouble=parseInt(text, 10),(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)],HEAP32[((argPtr)>>2)]=tempI64[0],HEAP32[(((argPtr)+(4))>>2)]=tempI64[1]);
              } else {
                HEAP32[((argPtr)>>2)]=parseInt(text, 10);
              }
              break;
            case 'X':
            case 'x':
              HEAP32[((argPtr)>>2)]=parseInt(text, 16)
              break;
            case 'F':
            case 'f':
            case 'E':
            case 'e':
            case 'G':
            case 'g':
            case 'E':
              // fallthrough intended
              if (long_) {
                HEAPF64[((argPtr)>>3)]=parseFloat(text)
              } else {
                HEAPF32[((argPtr)>>2)]=parseFloat(text)
              }
              break;
            case 's':
              var array = intArrayFromString(text);
              for (var j = 0; j < array.length; j++) {
                HEAP8[(((argPtr)+(j))|0)]=array[j]
              }
              break;
          }
          fields++;
        } else if (format[formatIndex] in __scanString.whiteSpace) {
          next = get();
          while (next in __scanString.whiteSpace) {
            if (next <= 0) break mainLoop;  // End of input.
            next = get();
          }
          unget(next);
          formatIndex++;
        } else {
          // Not a specifier.
          next = get();
          if (format[formatIndex].charCodeAt(0) !== next) {
            unget(next);
            break mainLoop;
          }
          formatIndex++;
        }
      }
      return fields;
    }function _sscanf(s, format, varargs) {
      // int sscanf(const char *restrict s, const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var index = 0;
      var get = function() { return HEAP8[(((s)+(index++))|0)]; };
      var unget = function() { index--; };
      return __scanString(format, get, unget, varargs);
    }
  function __Z7catopenPKci() { throw 'catopen not implemented' }
  function __Z7catgetsP8_nl_catdiiPKc() { throw 'catgets not implemented' }
  function __Z8catcloseP8_nl_catd() { throw 'catclose not implemented' }
  function _newlocale(mask, locale, base) {
      return 0;
    }
  function _freelocale(locale) {}
  function ___ctype_b_loc() {
      // http://refspecs.freestandards.org/LSB_3.0.0/LSB-Core-generic/LSB-Core-generic/baselib---ctype-b-loc.html
      var me = ___ctype_b_loc;
      if (!me.ret) {
        var values = [
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2,2,8195,8194,8194,8194,8194,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,24577,49156,49156,49156,
          49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,55304,55304,55304,55304,55304,55304,55304,55304,
          55304,55304,49156,49156,49156,49156,49156,49156,49156,54536,54536,54536,54536,54536,54536,50440,50440,50440,50440,50440,
          50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,49156,49156,49156,49156,49156,
          49156,54792,54792,54792,54792,54792,54792,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,
          50696,50696,50696,50696,50696,50696,50696,49156,49156,49156,49156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
        ];
        var i16size = 2;
        var arr = _malloc(values.length * i16size);
        for (var i = 0; i < values.length; i++) {
          HEAP16[(((arr)+(i * i16size))>>1)]=values[i]
        }
        me.ret = allocate([arr + 128 * i16size], 'i16*', ALLOC_NORMAL);
      }
      return me.ret;
    }
  function ___ctype_tolower_loc() {
      // http://refspecs.freestandards.org/LSB_3.1.1/LSB-Core-generic/LSB-Core-generic/libutil---ctype-tolower-loc.html
      var me = ___ctype_tolower_loc;
      if (!me.ret) {
        var values = [
          128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,
          158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,
          188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,
          218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,
          248,249,250,251,252,253,254,-1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,
          33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,97,98,99,100,101,102,103,
          104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,91,92,93,94,95,96,97,98,99,100,101,102,103,
          104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,
          134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,
          164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,
          194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,
          224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,
          254,255
        ];
        var i32size = 4;
        var arr = _malloc(values.length * i32size);
        for (var i = 0; i < values.length; i++) {
          HEAP32[(((arr)+(i * i32size))>>2)]=values[i]
        }
        me.ret = allocate([arr + 128 * i32size], 'i32*', ALLOC_NORMAL);
      }
      return me.ret;
    }
  function ___ctype_toupper_loc() {
      // http://refspecs.freestandards.org/LSB_3.1.1/LSB-Core-generic/LSB-Core-generic/libutil---ctype-toupper-loc.html
      var me = ___ctype_toupper_loc;
      if (!me.ret) {
        var values = [
          128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,
          158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,
          188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,
          218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,
          248,249,250,251,252,253,254,-1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,
          33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,
          73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,
          81,82,83,84,85,86,87,88,89,90,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,
          145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,
          175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,
          205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,
          235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255
        ];
        var i32size = 4;
        var arr = _malloc(values.length * i32size);
        for (var i = 0; i < values.length; i++) {
          HEAP32[(((arr)+(i * i32size))>>2)]=values[i]
        }
        me.ret = allocate([arr + 128 * i32size], 'i32*', ALLOC_NORMAL);
      }
      return me.ret;
    }
  var _strftime_l=_strftime;
  var _strtoull_l=_strtoull;
  function _strtoll(str, endptr, base) {
      return __parseInt64(str, endptr, base, '-9223372036854775808', '9223372036854775807');  // LLONG_MIN, LLONG_MAX.
    }var _strtoll_l=_strtoll;
  function _uselocale(locale) {
      return 0;
    }
  function ___locale_mb_cur_max() { throw '__locale_mb_cur_max not implemented' }
  var _llvm_va_start=undefined;
  function _asprintf(s, format, varargs) {
      return _sprintf(-s, format, varargs);
    }function _vasprintf(s, format, va_arg) {
      return _asprintf(s, format, HEAP32[((va_arg)>>2)]);
    }
  function _llvm_va_end() {}
  function _vsnprintf(s, n, format, va_arg) {
      return _snprintf(s, n, format, HEAP32[((va_arg)>>2)]);
    }
  function _vsscanf(s, format, va_arg) {
      return _sscanf(s, format, HEAP32[((va_arg)>>2)]);
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }
  function _llvm_bswap_i16(x) {
      return ((x&0xff)<<8) | ((x>>8)&0xff);
    }
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
___buildEnvironment(ENV);
Module["requestFullScreen"] = function(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function() { Browser.getUserMedia() }
GL.init()
_llvm_eh_exception.buf = allocate(12, "void*", ALLOC_STATIC);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true; // seal the static portion of memory
STACK_MAX = STACK_BASE + 5242880;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
assert(DYNAMIC_BASE < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);
var Math_min = Math.min;
function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vif(index,a1,a2) {
  try {
    Module["dynCall_vif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viffff(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viffff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_if(index,a1) {
  try {
    return Module["dynCall_if"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiif(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiif"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viff(index,a1,a2,a3) {
  try {
    Module["dynCall_viff"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vifff(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_vifff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_fii(index,a1,a2) {
  try {
    return Module["dynCall_fii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiif(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iif(index,a1,a2) {
  try {
    return Module["dynCall_iif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ff(index,a1) {
  try {
    return Module["dynCall_ff"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiif(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiif"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_f(index) {
  try {
    return Module["dynCall_f"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    return Module["dynCall_iiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env.__ZTVN10__cxxabiv117__class_type_infoE|0;var p=env.___fsmu8|0;var q=env._stdout|0;var r=env.___dso_handle|0;var s=env._stdin|0;var t=env._stderr|0;var u=env.__ZTVN10__cxxabiv120__si_class_type_infoE|0;var v=+env.NaN;var w=+env.Infinity;var x=0;var y=0;var z=0;var A=0;var B=0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0.0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=0;var Q=0;var R=0;var S=0;var T=0;var U=global.Math.floor;var V=global.Math.abs;var W=global.Math.sqrt;var X=global.Math.pow;var Y=global.Math.cos;var Z=global.Math.sin;var _=global.Math.tan;var $=global.Math.acos;var aa=global.Math.asin;var ab=global.Math.atan;var ac=global.Math.atan2;var ad=global.Math.exp;var ae=global.Math.log;var af=global.Math.ceil;var ag=global.Math.imul;var ah=env.abort;var ai=env.assert;var aj=env.asmPrintInt;var ak=env.asmPrintFloat;var al=env.min;var am=env.invoke_iiiiiiii;var an=env.invoke_vif;var ao=env.invoke_viiiii;var ap=env.invoke_vi;var aq=env.invoke_vii;var ar=env.invoke_iiiiiii;var as=env.invoke_ii;var at=env.invoke_viiiiiiiiiii;var au=env.invoke_viffff;var av=env.invoke_if;var aw=env.invoke_iiiiii;var ax=env.invoke_iiii;var ay=env.invoke_viiiiif;var az=env.invoke_viff;var aA=env.invoke_vifff;var aB=env.invoke_fii;var aC=env.invoke_iiif;var aD=env.invoke_viiiiiiii;var aE=env.invoke_iif;var aF=env.invoke_viiiiiii;var aG=env.invoke_ff;var aH=env.invoke_viiiiiiiii;var aI=env.invoke_viiiiiif;var aJ=env.invoke_iii;var aK=env.invoke_viiiiii;var aL=env.invoke_f;var aM=env.invoke_i;var aN=env.invoke_iiiii;var aO=env.invoke_viii;var aP=env.invoke_v;var aQ=env.invoke_iiiiiiiii;var aR=env.invoke_viiii;var aS=env._llvm_lifetime_end;var aT=env._lseek;var aU=env._RWebInputDestroy;var aV=env._RWebAudioStop;var aW=env._glClearColor;var aX=env._sysconf;var aY=env.__scanString;var aZ=env._pthread_mutex_unlock;var a_=env._fclose;var a$=env._RWebAudioInit;var a0=env._glGetVertexAttribPointerv;var a1=env._pthread_mutex_lock;var a2=env._glGetRenderbufferParameteriv;var a3=env._eglDestroySurface;var a4=env._strtoul;var a5=env._strtoull;var a6=env._glBindTexture;var a7=env._fflush;var a8=env._isxdigit;var a9=env._glGetUniformiv;var ba=env._fabsf;var bb=env._strtol;var bc=env._fputc;var bd=env._glGetString;var be=env._fwrite;var bf=env._gluUnProject;var bg=env._send;var bh=env._fputs;var bi=env._glLineWidth;var bj=env._glUniform2fv;var bk=env._emscripten_get_now;var bl=env._asprintf;var bm=env._eglCreateContext;var bn=env._glBindAttribLocation;var bo=env._glCompileShader;var bp=env._isspace;var bq=env._localtime;var br=env._glDeleteTextures;var bs=env._eglBindAPI;var bt=env._glCompressedTexImage2D;var bu=env._sbrk;var bv=env._glStencilFuncSeparate;var bw=env._read;var bx=env._RWebAudioBufferSize;var by=env._glDeleteShader;var bz=env._RWebInputInit;var bA=env._glClearDepthf;var bB=env._glUniform4iv;var bC=env._glGetTexParameteriv;var bD=env._glClearStencil;var bE=env._glLoadIdentity;var bF=env._glUniform1fv;var bG=env.___cxa_guard_abort;var bH=env._glIsShader;var bI=env.__Z7catopenPKci;var bJ=env._strstr;var bK=env._glSampleCoverage;var bL=env._fsync;var bM=env._glGenTextures;var bN=env._newlocale;var bO=env._glDepthFunc;var bP=env._remove;var bQ=env._glCompressedTexSubImage2D;var bR=env._pthread_cond_wait;var bS=env._glUniform1f;var bT=env._opendir;var bU=env.___resumeException;var bV=env._glGetTexParameterfv;var bW=env._RWebAudioWrite;var bX=env._glStencilMaskSeparate;var bY=env._glCreateShader;var bZ=env._round;var b_=env._glUniform1i;var b$=env.___cxa_end_catch;var b0=env._strncmp;var b1=env._cosf;var b2=env._vsscanf;var b3=env._glDeleteRenderbuffers;var b4=env._glLinkProgram;var b5=env._snprintf;var b6=env._glUniform2i;var b7=env._fgetc;var b8=env._glStencilFunc;var b9=env._strerror_r;var ca=env._glShaderSource;var cb=env._readdir;var cc=env._glVertexAttribPointer;var cd=env._glHint;var ce=env._glBindBuffer;var cf=env._glVertexPointer;var cg=env._fgets;var ch=env._close;var ci=env._getgid;var cj=env._glGetAttachedShaders;var ck=env._glBindFramebuffer;var cl=env._glIsFramebuffer;var cm=env._strchr;var cn=env._llvm_bswap_i16;var co=env._glUniform4fv;var cp=env._abort;var cq=env.___setErrNo;var cr=env._glDeleteFramebuffers;var cs=env._eglTerminate;var ct=env._glGetVertexAttribfv;var cu=env._glIsBuffer;var cv=env._emscripten_GetProcAddress;var cw=env._eglGetProcAddress;var cx=env._ftell;var cy=env._glDeleteProgram;var cz=env._exit;var cA=env._sprintf;var cB=env._glRenderbufferStorage;var cC=env.___ctype_b_loc;var cD=env._strrchr;var cE=env._freelocale;var cF=env._glAttachShader;var cG=env._RWebInputPoll;var cH=env._glUniform3i;var cI=env._glIsProgram;var cJ=env._glCheckFramebufferStatus;var cK=env.__isLeapYear;var cL=env._gluProject;var cM=env.___cxa_find_matching_catch;var cN=env._llvm_uadd_with_overflow_i32;var cO=env._localtime_r;var cP=env._glUniform3f;var cQ=env.___cxa_guard_acquire;var cR=env._glGetBufferParameteriv;var cS=env._glFlush;var cT=env._glBlendEquationSeparate;var cU=env._emscripten_get_canvas_size;var cV=env._glCopyTexImage2D;var cW=env._glDrawElements;var cX=env._glColorMask;var cY=env._sinf;var cZ=env._gluLookAt;var c_=env._eglInitialize;var c$=env._recv;var c0=env.__parseInt64;var c1=env._glVertexAttrib1fv;var c2=env._glUniform2iv;var c3=env.__ZSt18uncaught_exceptionv;var c4=env._putchar;var c5=env._glUniform1iv;var c6=env.___cxa_call_unexpected;var c7=env._glActiveTexture;var c8=env._glMatrixMode;var c9=env._glBlendEquation;var da=env._strcmp;var db=env._glVertexAttrib1f;var dc=env._RWebAudioWriteAvail;var dd=env._glGenerateMipmap;var de=env._memchr;var df=env._glDetachShader;var dg=env._glGetShaderiv;var dh=env.__exit;var di=env._strftime;var dj=env._glVertexAttrib3f;var dk=env._glGenRenderbuffers;var dl=env._tzset;var dm=env._RWebAudioSampleRate;var dn=env._glGetShaderPrecisionFormat;var dp=env._glVertexAttrib4fv;var dq=env.___cxa_throw;var dr=env._glDepthMask;var ds=env._glDisableVertexAttribArray;var dt=env._glBegin;var du=env._llvm_eh_exception;var dv=env._printf;var dw=env._glBindRenderbuffer;var dx=env._pread;var dy=env.___locale_mb_cur_max;var dz=env._fopen;var dA=env._open;var dB=env._glDrawArrays;var dC=env._usleep;var dD=env._llvm_pow_f32;var dE=env.__arraySum;var dF=env._glCopyTexSubImage2D;var dG=env._glDisable;var dH=env._puts;var dI=env._glUniform4i;var dJ=env._nanosleep;var dK=env._glClear;var dL=env._qsort;var dM=env._glUniform2f;var dN=env._eglDestroyContext;var dO=env._isalpha;var dP=env._glEnableVertexAttribArray;var dQ=env._rmdir;var dR=env._glUniform3fv;var dS=env._glStencilOp;var dT=env._strdup;var dU=env._glDepthRange;var dV=env.___cxa_free_exception;var dW=env._glUniform4f;var dX=env._glFramebufferTexture2D;var dY=env._glUniformMatrix2fv;var dZ=env._glGenVertexArrays;var d_=env._eglMakeCurrent;var d$=env._glUniformMatrix3fv;var d0=env._glutCreateWindow;var d1=env._glBufferData;var d2=env._glBlendColor;var d3=env._glGetUniformLocation;var d4=env._glIsEnabled;var d5=env.__formatString;var d6=env._pthread_cond_broadcast;var d7=env.__Z8catcloseP8_nl_catd;var d8=env._getenv;var d9=env.___cxa_does_inherit;var ea=env._glGetError;var eb=env._glGetVertexAttribiv;var ec=env._glTexParameteriv;var ed=env._glGetProgramiv;var ee=env._llvm_trap;var ef=env._glVertexAttrib3fv;var eg=env._glGetFloatv;var eh=env._glBufferSubData;var ei=env._glUniform3iv;var ej=env._glReadPixels;var ek=env._glGenFramebuffers;var el=env._glFramebufferRenderbuffer;var em=env._emscripten_procAddressTable;var en=env._atexit;var eo=env._ceil;var ep=env.___errno_location;var eq=env._strerror;var er=env._glGetIntegerv;var es=env._RWebAudioFree;var et=env._llvm_lifetime_start;var eu=env._glIsRenderbuffer;var ev=env._llvm_bswap_i32;var ew=env._vsnprintf;var ex=env.__parseInt;var ey=env.___cxa_guard_release;var ez=env._ungetc;var eA=env._RWebAudioSetNonblockState;var eB=env._glVertexAttrib2fv;var eC=env._uselocale;var eD=env._glGetFramebufferAttachmentParameteriv;var eE=env._glUseProgram;var eF=env._sscanf;var eG=env._glTexImage2D;var eH=env._glGetProgramInfoLog;var eI=env._glTexSubImage2D;var eJ=env._glStencilMask;var eK=env._fread;var eL=env._glStencilOpSeparate;var eM=env._strtok_r;var eN=env._glGetShaderInfoLog;var eO=env._glIsTexture;var eP=env._eglCreateWindowSurface;var eQ=env._fprintf;var eR=env._glGetShaderSource;var eS=env._gluPerspective;var eT=env._strtoll;var eU=env._isdigit;var eV=env._eglChooseConfig;var eW=env.___buildEnvironment;var eX=env._feof;var eY=env.__addDays;var eZ=env.___cxa_rethrow;var e_=env._glScissor;var e$=env._glEnable;var e0=env._glBlendFuncSeparate;var e1=env.__reallyNegative;var e2=env._glGetActiveAttrib;var e3=env._fseek;var e4=env._sqrt;var e5=env._glTexParameterfv;var e6=env._write;var e7=env._glGenBuffers;var e8=env._glFinish;var e9=env._glGetAttribLocation;var fa=env._glVertexAttrib4f;var fb=env._rewind;var fc=env.___cxa_allocate_exception;var fd=env._sin;var fe=env._glBlendFunc;var ff=env._glCreateProgram;var fg=env._realpath;var fh=env._stat;var fi=env._longjmp;var fj=env._vasprintf;var fk=env._glViewport;var fl=env._emscripten_set_main_loop;var fm=env._time;var fn=env.___ctype_toupper_loc;var fo=env.___cxa_begin_catch;var fp=env._glVertexAttrib2f;var fq=env._closedir;var fr=env._isgraph;var fs=env._readlink;var ft=env.___ctype_tolower_loc;var fu=env._glGetUniformfv;var fv=env._llvm_va_end;var fw=env._unlink;var fx=env._gluOrtho2D;var fy=env._glUniformMatrix4fv;var fz=env._glClearDepth;var fA=env._glGetActiveUniform;var fB=env._glutDestroyWindow;var fC=env._pwrite;var fD=env.__isFloat;var fE=env._fabs;var fF=env._glTexParameterf;var fG=env.__ZSt9terminatev;var fH=env._RWebAudioStart;var fI=env._glTexParameteri;var fJ=env._glFrontFace;var fK=env._glCullFace;var fL=env._glDepthRangef;var fM=env._glDeleteBuffers;var fN=env._eglGetDisplay;var fO=env._emscripten_set_canvas_size;var fP=env.___cxa_is_number_type;var fQ=env._glGetBooleanv;var fR=env._eglQuerySurface;var fS=env._glPixelStorei;var fT=env._readdir_r;var fU=env._glValidateProgram;var fV=env._glPolygonOffset;var fW=env.__Z7catgetsP8_nl_catdiiPKc;var fX=env.___gxx_personality_v0;
// EMSCRIPTEN_START_FUNCS
function gs(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7>>3<<3;return b|0}function gt(){return i|0}function gu(a){a=a|0;i=a}function gv(a,b){a=a|0;b=b|0;if((x|0)==0){x=a;y=b}}function gw(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function gx(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function gy(a){a=a|0;K=a}function gz(a){a=a|0;L=a}function gA(a){a=a|0;M=a}function gB(a){a=a|0;N=a}function gC(a){a=a|0;O=a}function gD(a){a=a|0;P=a}function gE(a){a=a|0;Q=a}function gF(a){a=a|0;R=a}function gG(a){a=a|0;S=a}function gH(a){a=a|0;T=a}function gI(){c[u+8>>2]=398;c[u+12>>2]=288;c[u+16>>2]=110;c[u+20>>2]=244;c[u+24>>2]=18;c[u+28>>2]=14;c[u+32>>2]=8;c[u+36>>2]=24;c[o+8>>2]=398;c[o+12>>2]=388;c[o+16>>2]=110;c[o+20>>2]=244;c[o+24>>2]=18;c[o+28>>2]=48;c[o+32>>2]=4;c[o+36>>2]=42;c[15096]=o+8;c[15098]=o+8;c[15100]=u+8;c[15104]=u+8;c[15108]=u+8;c[15112]=u+8;c[15116]=u+8;c[15120]=o+8;c[15154]=u+8;c[15158]=u+8;c[15222]=u+8;c[15226]=u+8;c[15246]=o+8;c[15248]=u+8;c[15284]=u+8;c[15288]=u+8;c[15324]=u+8;c[15328]=u+8;c[15348]=o+8;c[15350]=o+8;c[15352]=u+8;c[15356]=u+8;c[15360]=u+8;c[15364]=o+8;c[15366]=o+8;c[15368]=o+8;c[15370]=u+8;c[15374]=o+8;c[15376]=o+8;c[15378]=o+8;c[15380]=o+8;c[15406]=u+8;c[15410]=u+8;c[15414]=o+8;c[15416]=u+8;c[15420]=u+8;c[15424]=u+8;c[15428]=o+8;c[15430]=o+8;c[15432]=o+8;c[15434]=o+8;c[15468]=o+8;c[15470]=o+8;c[15472]=o+8;c[15474]=u+8;c[15478]=u+8;c[15482]=u+8;c[15486]=u+8;c[15490]=u+8;c[15494]=u+8;c[15498]=o+8;c[15500]=u+8;c[15504]=u+8;c[15508]=u+8;c[15512]=u+8;c[15516]=u+8;c[15520]=u+8;c[15524]=u+8;c[15528]=o+8}function gJ(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+20480|0;f=e|0;h=e+12288|0;fO(800,600);s_(281176,0,102392);j=c[135158]|0;if((j|0)!=0){a_(j|0)|0}s_(383584,0,158128);a[383586]=1;a[383585]=1;c[96930]=0;c[95897]=1;c[95898]=1;c[95899]=1;c[95900]=1;c[95901]=1;c[95902]=1;c[95903]=1;c[95904]=1;gU();j=g1(b,d)|0;if((j|0)!=0){k=j;i=e;return k|0}j=e+16384|0;d=sR(113728)|0;b=(d|0)==0;do{if(!b){if((c[d-4>>2]&3|0)==0){break}s_(d|0,0,113728)}}while(0);l=d;c[d+28>>2]=64360;c[d+32>>2]=640;c[d+4152>>2]=8408;m=4096;n=d+54|0;o=379465;while(1){p=m-1|0;if((p|0)==0){q=10;break}r=a[o]|0;a[n]=r;if(r<<24>>24==0){break}else{m=p;n=n+1|0;o=o+1|0}}do{if((q|0)==10){a[n]=0;if((a[o]|0)==0){break}else{s=o}do{s=s+1|0;}while((a[s]|0)!=0)}}while(0);s=sR(12)|0;o=(s|0)==0;do{if(!o){if((c[s-4>>2]&3|0)==0){break}s_(s|0,0,12)}}while(0);c[d+40>>2]=s;n=sR(12)|0;do{if((n|0)!=0){if((c[n-4>>2]&3|0)==0){break}s_(n|0,0,12)}}while(0);c[d+44>>2]=n;if(!o){o=s+8|0;n=s+4|0;m=c[n>>2]|0;if((c[o>>2]|0)>>>0<m>>>0){u=s}else{p=(m<<1)+2|0;c[n>>2]=p;n=s;c[n>>2]=sT(c[n>>2]|0,p*12|0)|0;u=n}n=dT(547872)|0;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)>>2]=n;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=4;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1}c[d+48>>2]=0;je(l);o=c[136866]|0;do{if((o|0)==0){v=1.3333333730697632}else{if(!((c[135145]|0)==0|(c[135146]|0)==0)){v=1.3333333730697632;break}f0[c[(c[136863]|0)+44>>2]&255](o,540572);v=+((c[135145]|0)>>>0>>>0)/+((c[135146]|0)>>>0>>>0)}}while(0);g[2715]=v;c[15704]=l;if(b){b=c[135158]|0;l=(b|0)!=0?b:c[t>>2]|0;be(40248,48,1,l|0)|0;l=c[135158]|0;b=(l|0)!=0?l:c[t>>2]|0;a7(b|0)|0;if((a[540637]&1)==0){b=c[135158]|0;l=(b|0)!=0?b:c[t>>2]|0;eQ(l|0,33848,(w=i,i=i+16|0,c[w>>2]=32792,c[w+8>>2]=832,w)|0)|0;i=w;l=c[135158]|0;b=(l|0)!=0?l:c[t>>2]|0;a7(b|0)|0;cz(2);return 0}else{a[540639]=109;a[540640]=101;a[540641]=110;a[540642]=117;a[540643]=95;a[540644]=105;a[540645]=110;a[540646]=105;a[540647]=116;a[540648]=40;a[540649]=41;a[540650]=0;fi(541664,1);return 0}}s_(d|0,0,17);a[d+36|0]=1;c[d+113708>>2]=0;b=d+4160|0;s_(b|0,0,16);c[b>>2]=26328;c[d+4164>>2]=22608;a[d+4172|0]=1;c[d+4168>>2]=19608;a[d+4173|0]=0;b=h|0;h=cD(281292,46)|0;l=(h|0)==0?547872:h+1|0;L44:do{if((da(l|0,48240)|0)==0){q=32}else{if((da(l|0,48792)|0)==0){q=32;break}do{if((da(l|0,40968)|0)!=0){if((da(l|0,28888)|0)==0){break}h=(a[289493]|0)!=0?289493:375332;hj(b,h,45584);o=hz(b,0)|0;if((o|0)==0){hj(b,h,45408);h=hz(b,0)|0;if((h|0)==0){break L44}else{x=h}}else{x=o}o=d+4180|0;if(iU(x,o)|0){iY(o,b)}hx(x);break L44}}while(0);o=4096;h=d+4256|0;u=281292;while(1){n=o-1|0;if((n|0)==0){q=41;break}p=a[u]|0;a[h]=p;if(p<<24>>24==0){break}else{o=n;h=h+1|0;u=u+1|0}}do{if((q|0)==41){a[h]=0;if((a[u]|0)==0){break}else{y=u}do{y=y+1|0;}while((a[y]|0)!=0)}}while(0);c[d+4252>>2]=1}}while(0);do{if((q|0)==32){y=hz(281292,0)|0;if((y|0)==0){break}x=d+4180|0;if(iU(y,x)|0){iY(x,281292)}hx(y)}}while(0);if((a[404114]|0)!=0){L74:do{if((a[354848]|0)==0){ht(j,404114,38368)}else{d=4096;y=j;x=354848;while(1){l=d-1|0;if((l|0)==0){break}u=a[x]|0;a[y]=u;if(u<<24>>24==0){break L74}else{d=l;y=y+1|0;x=x+1|0}}a[y]=0;if((a[x]|0)==0){break}else{z=x}do{z=z+1|0;}while((a[z]|0)!=0)}}while(0);if((a[383584]&1)!=0){z=c[135158]|0;x=(z|0)!=0?z:c[t>>2]|0;eQ(x|0,37128,(w=i,i=i+8|0,c[w>>2]=j,w)|0)|0;i=w;x=c[135158]|0;z=(x|0)!=0?x:c[t>>2]|0;a7(z|0)|0}z=c[89736]|0;x=sR(16)|0;do{if((x|0)==0){A=0}else{if((c[x-4>>2]&3|0)!=0){s_(x|0,0,16)}y=x;do{if((z|0)==0){B=0}else{d=z*12|0;if(z>>>0<=65535){B=d;break}B=((d>>>0)/(z>>>0)|0|0)==12?d:-1}}while(0);d=sR(B)|0;if((d|0)==0){c[x>>2]=0;jl(y);A=0;break}if((c[d-4>>2]&3|0)==0){l=x;c[l>>2]=d;C=l}else{s_(d|0,0,B|0);l=x;c[l>>2]=d;C=l}l=x+8|0;c[l>>2]=z;d=f|0;u=dz(j|0,11144)|0;if((u|0)!=0){h=x+4|0;c[h>>2]=0;L104:do{if((c[l>>2]|0)!=0){o=f+4096|0;n=f+8192|0;do{a[d]=0;if((cg(d|0,4096,u|0)|0)==0){break L104}p=cD(d|0,10)|0;if((p|0)!=0){a[p]=0}a[o]=0;if((cg(o|0,4096,u|0)|0)==0){break L104}p=cD(o|0,10)|0;if((p|0)!=0){a[p]=0}a[n]=0;if((cg(n|0,4096,u|0)|0)==0){break L104}p=cD(n|0,10)|0;if((p|0)!=0){a[p]=0}p=c[h>>2]|0;s=c[C>>2]|0;if((a[o]|0)==0){break L104}if((a[n]|0)==0){break L104}if((a[d]|0)!=0){c[s+(p*12|0)>>2]=dT(d|0)|0}c[s+(p*12|0)+4>>2]=dT(o|0)|0;c[s+(p*12|0)+8>>2]=dT(n|0)|0;p=(c[h>>2]|0)+1|0;c[h>>2]=p;}while(p>>>0<(c[l>>2]|0)>>>0)}}while(0);a_(u|0)|0}c[x+12>>2]=dT(j|0)|0;A=y}}while(0);c[(c[15704]|0)+113712>>2]=A}v=+bk()*1.0e3;A=+V(v)>=1.0?v>0.0?(al(+U(v/4294967296.0),4294967295.0)|0)>>>0:~~+af((v- +(~~v>>>0))/4294967296.0)>>>0:0;x=(c[15704]|0)+113720|0;c[x>>2]=~~v>>>0;c[x+4>>2]=A;A=540624;x=c[A+4>>2]|0;C=540624;c[C>>2]=c[A>>2]|1;c[C+4>>2]=x;do{if((a[541709]&1)==0){L131:do{if((a[383620]&1)==0){x=4096;C=j;A=420498;while(1){f=x-1|0;if((f|0)==0){break}z=a[A]|0;a[C]=z;if(z<<24>>24==0){break L131}else{x=f;C=C+1|0;A=A+1|0}}a[C]=0;if((a[A]|0)==0){break}else{D=A}do{D=D+1|0;}while((a[D]|0)!=0)}else{b5(j|0,4096,47472,(w=i,i=i+8|0,c[w>>2]=416402,w)|0)|0;i=w}}while(0);L140:do{if((a[j]|0)!=0){y=4096;u=b;A=j;while(1){C=y-1|0;if((C|0)==0){q=99;break}x=a[A]|0;a[u]=x;if(x<<24>>24==0){break}else{y=C;u=u+1|0;A=A+1|0}}do{if((q|0)==99){a[u]=0;if((a[A]|0)==0){break}else{E=A}do{E=E+1|0;}while((a[E]|0)!=0)}}while(0);if((fg(b|0,j|0)|0)==0){F=4096;G=j;H=b}else{break}while(1){A=F-1|0;if((A|0)==0){break}u=a[H]|0;a[G]=u;if(u<<24>>24==0){break L140}else{F=A;G=G+1|0;H=H+1|0}}a[G]=0;if((a[H]|0)==0){break}else{I=H}do{I=I+1|0;}while((a[I]|0)!=0)}}while(0);A=c[(c[15704]|0)+113712>>2]|0;if((A|0)==0){break}jk(A,(a[j]|0)!=0?j:0,c[119468]|0)}}while(0);fl(60,((a[281264]&1)!=0?0:2147483647)|0,1);k=0;i=e;return k|0}function gK(){var b=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,ag=0,ah=0,ai=0,aj=0,ak=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=i;i=i+8664|0;e=b|0;f=b+8|0;j=b+136|0;k=b+264|0;l=b+4360|0;m=b+8456|0;n=b+8464|0;o=b+8592|0;p=b+8656|0;if((a[477936]&1)!=0){a[477936]=0;q=c[15704]|0;if((a[q+4156|0]&1)!=0){sS(c[q+4152>>2]|0)}r=c[q+40>>2]|0;s=r+8|0;u=r|0;v=c[u>>2]|0;if((c[s>>2]|0)==0){w=v}else{x=0;y=v;while(1){sS(c[y+(x*12|0)>>2]|0);v=x+1|0;z=c[u>>2]|0;if(v>>>0<(c[s>>2]|0)>>>0){x=v;y=z}else{w=z;break}}}sS(w);sS(r);r=c[q+44>>2]|0;q=r+8|0;w=r|0;y=c[w>>2]|0;if((c[q>>2]|0)==0){A=y}else{x=0;s=y;while(1){sS(c[s+(x*12|0)>>2]|0);y=x+1|0;u=c[w>>2]|0;if(y>>>0<(c[q>>2]|0)>>>0){x=y;s=u}else{A=u;break}}}sS(A);sS(r);jl(c[(c[15704]|0)+113712>>2]|0);sS(c[15704]|0);L173:do{if(!((a[540638]&1)==0|(a[404114]|0)==0)){r=o|0;A=hz(404114,0)|0;do{if((A|0)==0){s=sR(20)|0;if((s|0)==0){break L173}if((c[s-4>>2]&3|0)==0){B=s;break}else{s_(s|0,0,20);B=s;break}}else{B=A}}while(0);if((a[383584]&1)!=0){A=c[135158]|0;s=(A|0)!=0?A:c[t>>2]|0;eQ(s|0,49904,(C=i,i=i+8|0,c[C>>2]=404114,C)|0)|0;i=C;s=c[135158]|0;A=(s|0)!=0?s:c[t>>2]|0;a7(A|0)|0}hC(B,16928,358948);hC(B,13280,363044);hC(B,15016,(a[379428]&1)!=0?51224:30680);A=c[94859]|0;s=n|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,14536,s);hC(B,27776,281292);hC(B,27392,(a[285388]&1)!=0?51224:30680);D=+g[70320];b5(s|0,128,42608,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hC(B,29848,s);D=+g[70310];b5(s|0,128,42608,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hC(B,48776,s);D=+g[70311];b5(s|0,128,42608,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hC(B,46752,s);hC(B,30152,(a[281278]&1)!=0?51224:30680);hC(B,30552,(a[281285]&1)!=0?51224:30680);hC(B,31880,(a[281276]&1)!=0?51224:30680);D=+g[72372];b5(s|0,128,42608,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hC(B,28200,s);hC(B,38912,(a[281264]&1)!=0?51224:30680);hC(B,37976,(a[281265]&1)!=0?51224:30680);A=c[70318]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,36552,s);hC(B,34616,(a[281266]&1)!=0?51224:30680);A=c[70317]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,33392,s);A=c[70322]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,29472,s);hC(B,19424,297772);hC(B,18808,(a[305969]&1)!=0?51224:30680);D=+g[76493];b5(s|0,128,42608,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hC(B,18544,s);if((a[375332]|0)==0){hC(B,50544,21104)}else{hC(B,50544,375332)}if((a[453266]|0)==0){hC(B,51832,21104)}else{hC(B,51832,453266)}if((a[457362]|0)==0){hC(B,51328,21104)}else{hC(B,51328,457362)}if((a[289493]|0)==0){hC(B,21736,21104)}else{hC(B,21736,289493)}if((a[379465]|0)==0){hC(B,15728,21104)}else{hC(B,15728,379465)}if((a[461458]|0)==0){hC(B,15600,21104)}else{hC(B,15600,461458)}hC(B,15480,342552);D=+g[86662];b5(s|0,128,42608,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hC(B,15312,s);D=+g[86663];b5(s|0,128,42608,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hC(B,15136,s);hC(B,49448,(c[135150]|0)!=0?51224:30680);A=540624;if((c[A>>2]&16384|0)==0&(c[A+4>>2]&0|0)==0){hC(B,49136,30680)}else{hC(B,49136,51224)}A=540624;if((c[A>>2]&128|0)==0&(c[A+4>>2]&0|0)==0){hC(B,48760,30680)}else{hC(B,48760,51224)}A=540624;if((c[A>>2]&65536|0)==0&(c[A+4>>2]&0|0)==0){hC(B,48648,30680)}else{hC(B,48648,51224)}A=540624;if((c[A>>2]&32768|0)==0&(c[A+4>>2]&0|0)==0){hC(B,48456,30680)}else{hC(B,48456,51224)}A=d[540604]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,48216,s);A=d[540605]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,47992,s);A=c[135137]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,47840,s);A=c[135145]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,23384,s);A=c[135146]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,23104,s);A=c[135143]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,23816,s);A=c[135144]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,23600,s);D=+g[74422];b5(s|0,128,42608,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;hC(B,26248,s);hC(B,51984,(a[540638]&1)!=0?51224:30680);A=c[135152]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,47728,s);A=c[119462]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,47456,s);A=a[482713]&1;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,15400,s);A=c[135149]|0;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;hC(B,46928,s);A=540624;if((c[A>>2]&524288|0)==0&(c[A+4>>2]&0|0)==0){hC(B,46728,30680);E=0}else{hC(B,46728,51224);E=0}while(1){A=E+1|0;b5(r|0,64,46656,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=c[342508+(E<<2)>>2],C)|0)|0;i=C;hC(B,r,s);b5(r|0,64,46584,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=c[341964+(E<<2)>>2],C)|0)|0;i=C;hC(B,r,s);b5(r|0,64,19928,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;b5(s|0,128,11024,(C=i,i=i+8|0,c[C>>2]=c[341932+(E<<2)>>2],C)|0)|0;i=C;hC(B,r,s);if(A>>>0<8){E=A}else{break}}hD(B,404114)|0;hx(B)}}while(0);if((a[540636]&1)!=0){g4()}B=c[133027]|0;if((B|0)!=0){E=B+4|0;n=c[E>>2]|0;o=B|0;if(n>>>0>1){s=1;r=n;while(1){n=c[(c[o>>2]|0)+(s<<2)>>2]|0;if((n|0)==0){F=r}else{sS(c[n+8>>2]|0);sS(c[(c[o>>2]|0)+(s<<2)>>2]|0);c[(c[o>>2]|0)+(s<<2)>>2]=0;F=c[E>>2]|0}n=s+1|0;if(n>>>0<F>>>0){s=n;r=F}else{break}}}c[E>>2]=1;E=B+12|0;sS(c[E>>2]|0);c[E>>2]=0;sS(c[o>>2]|0);sS(B);c[133027]=0}s_(281176,0,102392);B=c[135158]|0;if((B|0)==0){s_(383584,0,158128);a[383586]=1;a[383585]=1;c[96930]=0;c[95897]=1;c[95898]=1;c[95899]=1;c[95900]=1;c[95901]=1;c[95902]=1;c[95903]=1;c[95904]=1;cz(0)}a_(B|0)|0;s_(383584,0,158128);a[383586]=1;a[383585]=1;c[96930]=0;c[95897]=1;c[95898]=1;c[95899]=1;c[95900]=1;c[95901]=1;c[95902]=1;c[95903]=1;c[95904]=1;cz(0)}B=540624;o=c[B>>2]|0;E=c[B+4>>2]|0;if(a[6072]|0){if(!((o&32|0)==0&(E&0|0)==0)){B=c[15704]|0;a[B+52|0]=1;F=540624;r=c[F+4>>2]|0;s=540624;c[s>>2]=c[F>>2]&-33;c[s+4>>2]=r;r=B|0;B=c[r+4>>2]|0;c[r>>2]=c[r>>2]|256;c[r+4>>2]=B}gR();if((c[136908]|0)!=0){do{if((a[547479]&1)==0){B=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,51)|0;r=547640;if((c[r>>2]&0|B&1|0)==0&(c[r+4>>2]&524288|0)==0){G=0;break}if((a[64120]&1)!=0){G=1;break}r=c[136908]|0;B=r+28|0;s=c[B>>2]|0;F=r+20|0;c[F>>2]=s;n=c[r+12>>2]|0;A=r+16|0;c[A>>2]=n+(s*136|0);x=r+4|0;q=c[(c[x>>2]|0)+4>>2]|0;w=r|0;u=c[w>>2]|0;y=c[n+(s*136|0)+8>>2]|0;z=c[n+(s*136|0)+12>>2]|0;v=c[n+(s*136|0)+16>>2]|0;gn[q&31](u,y,z,v)|0;v=c[A>>2]|0;f4[c[(c[x>>2]|0)+12>>2]&7](c[w>>2]|0,+g[v+24>>2],+g[v+28>>2],+g[v+32>>2],+g[v+36>>2]);f0[c[(c[x>>2]|0)+16>>2]&255](c[w>>2]|0,(a[(c[A>>2]|0)+68|0]&1)!=0);a[r+9|0]=1;c[B>>2]=(((c[F>>2]|0)+1|0)>>>0)%((c[r+24>>2]|0)>>>0)|0;G=1}else{G=0}}while(0);a[64120]=G}if((a[547479]&1)==0){G=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,30)|0;r=547640;if((c[r>>2]&1073741824|G&1|0)==0&(c[r+4>>2]&0|0)==0){H=184}else{H=185}}else{H=184}do{if((H|0)==184){if(f2[c[(c[136863]|0)+12>>2]&255](c[136866]|0)|0){I=0;J=0;L=0}else{H=185;break}do{r=c[1480+(L<<2)>>2]|0;if((f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,1544,0,1,0,r)|0)<<16>>16==0){M=0;N=0}else{G=tc(1,0,c[1480+((L|1)<<2)>>2]|0)|0;F=K;M=F;N=G}G=547640;F=c[G>>2]|0;B=c[G+4>>2]|0;G=tc(1,0,r|0)|0;r=K;if((F&G|0)==0&(B&r|0)==0){O=0;P=0}else{r=tc(1,0,c[1480+((L|1)<<2)>>2]|0)|0;B=K;O=B;P=r}J=N|J|P;I=M|I|O;L=L+2|0;}while(L>>>0<16);if((a[547479]&1)==0){r=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,55)|0;B=547640;G=(c[B>>2]&0|r&1|0)!=0|(c[B+4>>2]&8388608|0)!=0;Q=G?0:0;R=G?256:0}else{Q=0;R=0}G=R|J;B=Q|I;r=c[15704]|0;F=r|0;A=B&~c[F+4>>2];w=r+8|0;c[w>>2]=G&~c[F>>2];c[w+4>>2]=A;do{if((J&15|0)==0&(I&0|0)==0){a[r+16|0]=0;H=200}else{A=((G>>>8|B<<24)&1^1)&255;a[r+16|0]=A;if((A&1)==0){H=200;break}if(!(a[6088]|0)){a[6088]=1;c[r+20>>2]=a[6080]|0?6:12;c[r+24>>2]=0;S=1;T=0;break}A=c[r+24>>2]|0;if(A>>>0<(c[r+20>>2]|0)>>>0){S=1;T=A;break}a[6088]=0;c[w>>2]=G;c[w+4>>2]=B;S=1;T=A}}while(0);if((H|0)==200){a[6088]=0;S=0;T=c[r+24>>2]|0}a[6080]=S;c[r+24>>2]=T+1;c[F>>2]=G;c[F+4>>2]=B;w=jf(r)|0;A=c[136914]|0;do{if((A|0)!=0){x=c[A+24>>2]|0;if((x|0)==0){break}go[x&127](c[136866]|0,(a[(c[15704]|0)+36|0]&1)!=0,0)}}while(0);gN();D=+bk()*1.0e3;A=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;r=(c[15704]|0)+113720|0;B=tb(~~D>>>0,A,c[r>>2]|0,c[r+4>>2]|0)|0;r=ti(B,K,1e3,0)|0;B=K;D=750.0/+g[72372];A=tb(~~D>>>0,+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0,r,B)|0;B=K;r=0;if((B|0)>(r|0)|(B|0)==(r|0)&A>>>0>0>>>0){r=A;A=m;c[m>>2]=0;c[m+4>>2]=0;c[m>>2]=(r>>>0)/1e3|0;c[A+4>>2]=((r>>>0)%1e3|0)*1e6|0;dJ(A|0,0)|0}D=+bk()*1.0e3;A=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;r=c[15704]|0;B=r+113720|0;c[B>>2]=~~D>>>0;c[B+4>>2]=A;A=c[136914]|0;do{if((A|0)==0){W=r}else{B=c[A+24>>2]|0;if((B|0)==0){W=r;break}go[B&127](c[136866]|0,0,0);W=c[15704]|0}}while(0);r=W+8|0;do{if((c[r>>2]&256|0)==0&(c[r+4>>2]&0|0)==0){X=0}else{if((a[540636]&1)==0){X=0;break}if((a[541709]&1)!=0){X=0;break}A=540624;B=c[A+4>>2]|0;F=540624;c[F>>2]=c[A>>2]|65;c[F+4>>2]=B;X=-1}}while(0);r=540624;B=c[r>>2]|0;F=c[r+4>>2]|0;if(!((B&64|0)==0&(F&0|0)==0)){r=540624;c[r>>2]=B&-65;c[r+4>>2]=F|0}do{if((X|0)<0){F=c[W+40>>2]|0;r=c[F+8>>2]|0;if((r|0)==0){Y=0;Z=W;_=F;$=0}else{B=c[(c[F>>2]|0)+((r-1|0)*12|0)+4>>2]|0;if((B|0)==4){break}else{Y=B;Z=W;_=F;$=r}}while(1){r=Z+48|0;F=_+8|0;if(($|0)!=0){B=$-1|0;c[F>>2]=B;sS(c[(c[_>>2]|0)+(B*12|0)>>2]|0)}if((r|0)!=0){c[r>>2]=c[(c[_>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]}F=c[15704]|0;r=c[F+40>>2]|0;B=c[r+8>>2]|0;if((B|0)==0){aa=Y}else{aa=c[(c[r>>2]|0)+((B-1|0)*12|0)+4>>2]|0}if((aa|0)==4){break}else{Y=aa;Z=F;_=r;$=B}}}}while(0);if((X|w|0)!=0){break}i=b;return}}while(0);if((H|0)==185){X=540624;$=c[X+4>>2]|0;_=540624;c[_>>2]=c[X>>2]|1;c[_+4>>2]=$}a[6072]=0;$=(a[547480]&1)!=0;_=c[136866]|0;if((a[383586]&1)!=0&(_|0)!=0){if((a[281264]&1)==0){H=229}else{if((a[477949]&1)==0){ab=$}else{H=229}}if((H|0)==229){ab=1}f0[c[(c[136863]|0)+8>>2]&255](_,ab)}ab=c[136865]|0;if((a[383585]&1)!=0&(ab|0)!=0){f0[c[(c[136862]|0)+16>>2]&255](ab,(a[301872]&1)==0|$);ac=c[136865]|0}else{ac=ab}c[120672]=$?c[120673]|0:c[120674]|0;do{if((ac|0)!=0){if(f2[c[(c[136862]|0)+12>>2]&255](ac)|0){break}$=c[135158]|0;ab=($|0)!=0?$:c[t>>2]|0;be(12432,81,1,ab|0)|0;ab=c[135158]|0;$=(ab|0)!=0?ab:c[t>>2]|0;a7($|0)|0;a[383585]=0}}while(0);ac=540624;$=c[ac+4>>2]|0;ab=540624;c[ab>>2]=c[ac>>2]&-5;c[ab+4>>2]=$;i=b;return}if((o&2|0)==0&(E&0|0)==0){if((o&1|0)==0&(E&0|0)==0){if((o&4|0)==0&(E&0|0)==0){a[477936]=1;i=b;return}$=540624;c[$>>2]=o|32;c[$+4>>2]=E;f0[c[(c[136863]|0)+8>>2]&255](c[136866]|0,0);$=c[136865]|0;if(($|0)!=0){ab=c[(c[136862]|0)+8>>2]|0;f2[ab&255]($)|0}a[6072]=1;i=b;return}do{if((a[540335]&1)==0){H=295}else{if((a[540336]&1)!=0){H=295;break}if((a[547479]&1)==0){$=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,30)|0;ab=547640;if(!((c[ab>>2]&1073741824|$&1|0)==0&(c[ab+4>>2]&0|0)==0)){break}}if(!(f2[c[(c[136863]|0)+12>>2]&255](c[136866]|0)|0)){break}g2();gR();ab=p;c[p>>2]=0;c[p+4>>2]=0;c[p>>2]=0;c[ab+4>>2]=1e7;dJ(ab|0,0)|0;i=b;return}}while(0);L367:do{if((H|0)==295){if((a[547479]&1)==0){p=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,30)|0;ab=547640;if(!((c[ab>>2]&1073741824|p&1|0)==0&(c[ab+4>>2]&0|0)==0)){break}}if(!(f2[c[(c[136863]|0)+12>>2]&255](c[136866]|0)|0)){break}do{if((a[547479]&1)==0){ab=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,55)|0;p=547640;if((c[p>>2]&0|ab&1|0)==0&(c[p+4>>2]&8388608|0)==0){H=301;break}ad=a[8376]|0;H=303}else{H=301}}while(0);do{if((H|0)==301){if((a[541709]&1)==0){ae=0;break}w=a[8376]|0;if((w&1)==0){ad=w;H=303}else{ae=0}}}while(0);do{if((H|0)==303){if((ad&1)!=0){ae=1;break}w=540624;p=c[w+4>>2]|0;ab=540624;c[ab>>2]=c[w>>2]|4;c[ab+4>>2]=p;a[8376]=1;p=482656;c[p>>2]=0;c[p+4>>2]=0;break L367}}while(0);a[8376]=ae;if((a[532112]&1)!=0){a[532112]=0;break}g2();p=c[133033]|0;if((p|0)!=0){ab=cx(c[p>>2]|0)|0;c[(c[p+12>>2]|0)+(c[p+20>>2]<<2)>>2]=ab}if((c[120660]|0)!=0){D=+bk()*1.0e3;ab=~~D>>>0;p=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;do{if((a[540335]&1)==0){w=(a[547480]&1)!=0;$=482656;ac=c[$>>2]|0;_=c[$+4>>2]|0;$=(ac|0)==0&(_|0)==0|w;X=482648;Z=c[X>>2]|0;aa=c[X+4>>2]|0;X=tb(ab,p,ac,_)|0;_=$?Z:X;X=$?aa:K;if(w){ag=X;ah=_;ai=0;aj=0;break}if((a[540337]&1)==0){ag=X;ah=_;ai=p;aj=ab;break}D=(+(_>>>0)+ +(X|0)*4294967296.0)/+g[94860];ag=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;ah=~~D>>>0;ai=p;aj=ab}else{X=482648;ag=c[X+4>>2]|0;ah=c[X>>2]|0;ai=0;aj=0}}while(0);ab=482656;c[ab>>2]=aj;c[ab+4>>2]=ai;f0[c[120660]&255](ah,ag)}gp[c[16054]&63]();do{if(+g[94861]>=0.0){D=+bk()*1.0e3;ab=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;p=477864;X=477856;_=c[X>>2]|0;w=c[X+4>>2]|0;X=tb(c[p>>2]|0,c[p+4>>2]|0,~~D>>>0,ab)|0;ab=ta(X,K,_,w)|0;w=K;_=0;if((w|0)>(_|0)|(w|0)==(_|0)&ab>>>0>999>>>0){_=ti(ab,w,1e3,0)|0;w=_;_=e;c[e>>2]=0;c[e+4>>2]=0;c[e>>2]=(w>>>0)/1e3|0;c[_+4>>2]=((w>>>0)%1e3|0)*1e6|0;dJ(_|0,0)|0;_=477856;w=477864;ab=ta(c[w>>2]|0,c[w+4>>2]|0,c[_>>2]|0,c[_+4>>2]|0)|0;_=477864;c[_>>2]=ab;c[_+4>>2]=K;break}else{D=+bk()*1.0e3;_=+V(D)>=1.0?D>0.0?(al(+U(D/4294967296.0),4294967295.0)|0)>>>0:~~+af((D- +(~~D>>>0))/4294967296.0)>>>0:0;ab=477864;c[ab>>2]=~~D>>>0;c[ab+4>>2]=_;break}}}while(0);_=c[133033]|0;if((_|0)==0){i=b;return}ab=_+20|0;c[ab>>2]=(c[ab>>2]|0)+1&c[_+16>>2];ab=_+33|0;a[_+32|0]=a[ab]&1^1;a[ab]=0;i=b;return}}while(0);e=540624;ag=c[e+4>>2]|0;ah=540624;c[ah>>2]=c[e>>2]&-2;c[ah+4>>2]=ag;i=b;return}ag=k|0;k=l|0;L411:do{if((a[420498]|0)==0){l=c[15704]|0;if((a[l+4176|0]&1)==0){ak=l}else{H=248}}else{if((o&128|0)==0&(E&0|0)==0){H=248;break}hr(ag,420498,4096);b5(k|0,4096,46008,(C=i,i=i+8|0,c[C>>2]=ag,C)|0)|0;i=C;l=c[133027]|0;ah=l+4|0;if((c[ah>>2]|0)>>>0>=(c[l+8>>2]|0)>>>0){H=248;break}e=sR(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}s_(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=1;ai=dT(k|0)|0;aj=c[ah>>2]|0;c[e+8>>2]=ai;ai=l|0;c[(c[ai>>2]|0)+(aj<<2)>>2]=e;aj=c[ah>>2]|0;c[ah>>2]=aj+1;if(aj>>>0>1){am=aj}else{H=248;break}while(1){aj=am>>>1;ae=c[ai>>2]|0;ad=ae+(aj<<2)|0;ab=c[ad>>2]|0;_=c[ae+(am<<2)>>2]|0;if((c[_+4>>2]|0)>>>0<=(c[ab+4>>2]|0)>>>0){H=248;break L411}c[ad>>2]=_;c[(c[ai>>2]|0)+(am<<2)>>2]=ab;if(am>>>0>3){am=aj}else{H=248;break}}}}while(0);do{if((H|0)==248){am=c[15704]|0;E=c[am+4160>>2]|0;o=c[am+113712>>2]|0;if((o|0)==0){ak=am;break}jk(o,(a[420498]|0)!=0?420498:0,(E|0)==0?547872:E);ak=c[15704]|0}}while(0);s_(ak|0,0,17);a[ak+53|0]=1;jf(ak)|0;ak=c[136914]|0;do{if((ak|0)!=0){H=c[ak+24>>2]|0;if((H|0)==0){break}go[H&127](c[136866]|0,(a[(c[15704]|0)+36|0]&1)!=0,0)}}while(0);if((c[136863]|0)!=0){gN()}ak=c[136914]|0;do{if((ak|0)!=0){H=c[ak+24>>2]|0;if((H|0)==0){break}go[H&127](c[136866]|0,0,0)}}while(0);if((a[540636]&1)!=0){g4()}ak=a[383584]&1;H=(a[404114]|0)!=0;E=H?404114:0;o=(a[453266]|0)!=0;am=o?453266:0;ai=(a[457362]|0)!=0;ah=ai?457362:0;e=(a[420498]|0)!=0;l=e?420498:0;aj=(c[15704]|0)+4176|0;ab=a[aj]&1;a[aj]=0;aj=f;_=j;if((a[540636]&1)!=0){g4()}s_(aj|0,0,128);ad=f|0;c[ad>>2]=dT(23032)|0;do{if(ab<<24>>24==0){ae=(a[383584]&1)!=0;if(e){if(ae){w=c[135158]|0;X=(w|0)!=0?w:c[t>>2]|0;eQ(X|0,22712,(C=i,i=i+8|0,c[C>>2]=l,C)|0)|0;i=C;X=c[135158]|0;w=(X|0)!=0?X:c[t>>2]|0;a7(w|0)|0}c[f+4>>2]=dT(l|0)|0;an=2;break}else{if(ae){ae=c[135158]|0;w=(ae|0)!=0?ae:c[t>>2]|0;be(22488,40,1,w|0)|0;w=c[135158]|0;ae=(w|0)!=0?w:c[t>>2]|0;a7(ae|0)|0}c[f+4>>2]=dT(22224)|0;an=2;break}}else{an=1}}while(0);if(o){c[f+(an<<2)>>2]=dT(22072)|0;c[f+(an+1<<2)>>2]=dT(am|0)|0;ao=an+2|0}else{ao=an}if(ai){c[f+(ao<<2)>>2]=dT(21704)|0;c[f+(ao+1<<2)>>2]=dT(ah|0)|0;ap=ao+2|0}else{ap=ao}if(H){c[f+(ap<<2)>>2]=dT(20856)|0;c[f+(ap+1<<2)>>2]=dT(E|0)|0;aq=ap+2|0}else{aq=ap}if(ak<<24>>24==0){ar=aq}else{c[f+(aq<<2)>>2]=dT(20472)|0;ar=aq+1|0}s1(_|0,aj|0,128)|0;aj=g1(ar,ad)|0;ad=0;do{sS(c[j+(ad<<2)>>2]|0);ad=ad+1|0;}while(ad>>>0<32);if((aj|0)==0){if((a[383584]&1)!=0){aj=c[135158]|0;ad=(aj|0)!=0?aj:c[t>>2]|0;be(43632,45,1,ad|0)|0;ad=c[135158]|0;aj=(ad|0)!=0?ad:c[t>>2]|0;a7(aj|0)|0}aj=540624;ad=c[aj+4>>2]|0|0;j=540624;c[j>>2]=c[aj>>2]&-4|1;c[j+4>>2]=ad;i=b;return}hr(ag,420498,4096);b5(k|0,4096,42256,(C=i,i=i+8|0,c[C>>2]=ag,C)|0)|0;i=C;C=c[133027]|0;ag=C+4|0;L478:do{if((c[ag>>2]|0)>>>0<(c[C+8>>2]|0)>>>0){ad=sR(12)|0;do{if((ad|0)!=0){if((c[ad-4>>2]&3|0)==0){break}s_(ad|0,0,12)}}while(0);c[ad+4>>2]=1;c[ad>>2]=90;j=dT(k|0)|0;aj=c[ag>>2]|0;c[ad+8>>2]=j;j=C|0;c[(c[j>>2]|0)+(aj<<2)>>2]=ad;aj=c[ag>>2]|0;c[ag>>2]=aj+1;if(aj>>>0>1){as=aj}else{break}while(1){aj=as>>>1;ar=c[j>>2]|0;_=ar+(aj<<2)|0;aq=c[_>>2]|0;f=c[ar+(as<<2)>>2]|0;if((c[f+4>>2]|0)>>>0<=(c[aq+4>>2]|0)>>>0){break L478}c[_>>2]=f;c[(c[j>>2]|0)+(as<<2)>>2]=aq;if(as>>>0>3){as=aj}else{break}}}}while(0);a[(c[15704]|0)+53|0]=1;as=c[135158]|0;be(41224,52,1,((as|0)!=0?as:c[t>>2]|0)|0)|0;as=c[135158]|0;a7(((as|0)!=0?as:c[t>>2]|0)|0)|0;i=b;return}function gL(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=d<<1;if((e|0)==0){return d|0}else{f=0}do{g=b[a+(f<<1)>>1]|0;h=(c[120682]|0)-1|0;c[120682]=h;b[(c[120681]|0)+(h<<1)>>1]=g;f=f+1|0;}while(f>>>0<e>>>0);return d|0}function gM(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+24|0;d=b|0;if((a[371236]|0)==0){i=b;return}do{if((a[297719]&1)!=0|(c[120649]|0)!=0){e=c[136863]|0;if((c[e+48>>2]|0)==0){f=360;break}g=e+44|0;if((c[g>>2]|0)==0){f=360;break}s_(d|0,0,24);f0[c[g>>2]&255](c[136866]|0,d);g=d+8|0;e=c[g>>2]|0;if((e|0)==0){f=365;break}h=d+12|0;j=c[h>>2]|0;if((j|0)==0){f=365;break}k=sR(ag(e*3|0,j)|0)|0;if((k|0)==0){f=365;break}if(gj[c[(c[136863]|0)+48>>2]&127](c[136866]|0,k)|0){j=c[g>>2]|0;g=iq(k,j,c[h>>2]|0,j*3|0,1)|0;sS(k);if(g){f=363;break}else{f=365;break}}else{sS(k);f=365;break}}else{f=360}}while(0);do{if((f|0)==360){d=c[135094]|0;k=d;if((k|0)==(-1|0)|(k|0)==0){k=c[135158]|0;g=(k|0)!=0?k:c[t>>2]|0;be(52840,103,1,g|0)|0;g=c[135158]|0;k=(g|0)!=0?g:c[t>>2]|0;a7(k|0)|0;f=365;break}else{k=c[135095]|0;g=c[135096]|0;j=c[135097]|0;if(iq(d+(ag(g-1|0,j)|0)|0,k,g,-j|0,0)|0){f=363;break}else{f=365;break}}}}while(0);do{if((f|0)==363){if((a[383584]&1)==0){l=38632;break}j=c[135158]|0;g=(j|0)!=0?j:c[t>>2]|0;be(47800,30,1,g|0)|0;g=c[135158]|0;j=(g|0)!=0?g:c[t>>2]|0;a7(j|0)|0;l=38632}else if((f|0)==365){j=c[135158]|0;be(29792,50,1,((j|0)!=0?j:c[t>>2]|0)|0)|0;j=c[135158]|0;a7(((j|0)!=0?j:c[t>>2]|0)|0)|0;l=25416}}while(0);j=c[133027]|0;g=j+4|0;k=c[g>>2]|0;if(k>>>0>1){d=j|0;h=1;e=k;while(1){k=c[(c[d>>2]|0)+(h<<2)>>2]|0;if((k|0)==0){m=e}else{sS(c[k+8>>2]|0);sS(c[(c[d>>2]|0)+(h<<2)>>2]|0);c[(c[d>>2]|0)+(h<<2)>>2]=0;m=c[g>>2]|0}k=h+1|0;if(k>>>0<m>>>0){h=k;e=m}else{break}}}c[g>>2]=1;g=j+12|0;sS(c[g>>2]|0);c[g>>2]=0;g=c[133027]|0;j=g+4|0;m=(c[j>>2]|0)>>>0<(c[g+8>>2]|0)>>>0;if((a[540335]&1)!=0){L529:do{if(m){e=sR(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}s_(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=1;h=dT(l|0)|0;d=c[j>>2]|0;c[e+8>>2]=h;h=g|0;c[(c[h>>2]|0)+(d<<2)>>2]=e;d=c[j>>2]|0;c[j>>2]=d+1;if(d>>>0>1){n=d}else{break}while(1){d=n>>>1;k=c[h>>2]|0;o=k+(d<<2)|0;p=c[o>>2]|0;q=c[k+(n<<2)>>2]|0;if((c[q+4>>2]|0)>>>0<=(c[p+4>>2]|0)>>>0){break L529}c[o>>2]=q;c[(c[h>>2]|0)+(n<<2)>>2]=p;if(n>>>0>3){n=d}else{break}}}}while(0);gN();i=b;return}if(!m){i=b;return}m=sR(12)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}s_(m|0,0,12)}}while(0);c[m+4>>2]=1;c[m>>2]=180;n=dT(l|0)|0;l=c[j>>2]|0;c[m+8>>2]=n;n=g|0;c[(c[n>>2]|0)+(l<<2)>>2]=m;m=c[j>>2]|0;c[j>>2]=m+1;if(m>>>0>1){r=m}else{i=b;return}while(1){m=r>>>1;j=c[n>>2]|0;l=j+(m<<2)|0;g=c[l>>2]|0;h=c[j+(r<<2)>>2]|0;if((c[h+4>>2]|0)>>>0<=(c[g+4>>2]|0)>>>0){f=389;break}c[l>>2]=h;c[(c[n>>2]|0)+(r<<2)>>2]=g;if(r>>>0>3){r=m}else{f=390;break}}if((f|0)==389){i=b;return}else if((f|0)==390){i=b;return}}function gN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[135094]|0;d=(b|0)==-1?0:b;b=c[135095]|0;e=c[135096]|0;f=c[135097]|0;if((a[383586]&1)==0){return}c[135094]=d;c[135095]=b;c[135096]=e;c[135097]=f;do{if((c[119486]|0)==0){g=d;if((g|0)==(-1|0)|(g|0)==0){h=d;i=f;break}c[136874]=b;c[136875]=e;c[136877]=b;c[136878]=e;c[136876]=f;c[136879]=b<<1;iP(547496,c[136906]|0,d);h=c[136906]|0;i=c[136879]|0}else{h=d;i=f}}while(0);f=h4(c[133027]|0)|0;c[136915]=f;if(f1[c[(c[136863]|0)+4>>2]&15](c[136866]|0,h,b,e,i,f)|0){return}a[383586]=0;return}function gO(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[383586]&1)==0){return}c[135094]=b;c[135095]=d;c[135096]=e;c[135097]=f;do{if((c[119486]|0)==0){g=b;if((g|0)==(-1|0)|(g|0)==0){h=b;i=f;break}c[136874]=d;c[136875]=e;c[136877]=d;c[136878]=e;c[136876]=f;c[136879]=d<<1;iP(547496,c[136906]|0,b);h=c[136906]|0;i=c[136879]|0}else{h=b;i=f}}while(0);f=h4(c[133027]|0)|0;c[136915]=f;if(f1[c[(c[136863]|0)+4>>2]&15](c[136866]|0,h,d,e,i,f)|0){return}a[383586]=0;return}function gP(b,c){b=b|0;c=c|0;var d=0,e=0;d=c>>>0>1024?1024:c;if(gQ(b,d<<1)|0){e=a[383585]&1}else{e=0}a[383585]=e;return d|0}function gQ(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0.0,q=0,r=0;f=i;i=i+24|0;j=f|0;if((a[540335]&1)!=0){k=1;i=f;return k|0}if((a[482713]&1)!=0){k=1;i=f;return k|0}if((a[383585]&1)==0){k=0;i=f;return k|0}s_(j|0,0,24);l=c[120670]|0;m=+g[120692]*30517578125.0e-15;if((e|0)==0){n=l}else{o=0;do{g[l+(o<<2)>>2]=m*+(b[d+(o<<1)>>1]|0);o=o+1|0;}while(o>>>0<e>>>0);n=c[120670]|0}c[j>>2]=n;c[j+8>>2]=e>>>1;c[j+4>>2]=c[120679];if((a[482748]&1)==0){p=+h[60338]}else{e=f2[c[(c[136862]|0)+32>>2]&255](c[136865]|0)|0;n=515544;o=c[n>>2]|0;d=ta(o,c[n+4>>2]|0,1,0)|0;n=515544;c[n>>2]=d;c[n+4>>2]=K;c[482776+((o&8191)<<2)>>2]=e;o=(c[120690]|0)>>>1;m=+h[60344]*(+(e-o|0)/+(o|0)*+g[76493]+1.0);h[60338]=m;p=m}o=j+16|0;h[o>>3]=p;if((a[540337]&1)!=0){h[o>>3]=p*+g[94860]}f0[c[(c[120669]|0)+4>>2]&255](c[120668]|0,j);o=c[120679]|0;e=c[j+12>>2]|0;if((a[482712]&1)!=0){if((f7[c[(c[136862]|0)+4>>2]&127](c[136865]|0,o,e<<3)|0)>=0){k=1;i=f;return k|0}j=c[135158]|0;n=(j|0)!=0?j:c[t>>2]|0;be(30984,81,1,n|0)|0;n=c[135158]|0;j=(n|0)!=0?n:c[t>>2]|0;a7(j|0)|0;k=0;i=f;return k|0}j=c[120680]|0;n=e<<1;if((n|0)==0){q=j}else{d=0;do{l=~~(+g[o+(d<<2)>>2]*32768.0);if((l|0)>32767){r=32767}else{r=(l|0)<-32768?-32768:l&65535}b[j+(d<<1)>>1]=r;d=d+1|0;}while(d>>>0<n>>>0);q=c[120680]|0}if((f7[c[(c[136862]|0)+4>>2]&127](c[136865]|0,q,e<<2)|0)>=0){k=1;i=f;return k|0}e=c[135158]|0;be(30984,81,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[135158]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;k=0;i=f;return k|0}function gR(){var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0,S=0.0,T=0,U=0,W=0.0,X=0.0;d=i;i=i+16|0;e=d|0;f$[c[(c[136864]|0)+4>>2]&511](c[136867]|0);f=c[136908]|0;if((f|0)==0){i=d;return}h=e;s_(547640,0,16);j=(a[(c[f+16>>2]|0)+68|0]&1)!=0?65542:6;if((f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,0,0,j,0,2)|0)<<16>>16==0){a[(c[136908]|0)+9|0]=0;i=d;return}f=e|0;k=e+8|0;l=e+10|0;m=e+12|0;n=e+14|0;o=0;do{p=f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,0,0,j,o,0)|0;q=f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,0,0,j,o,1)|0;r=c[136908]|0;s_(h|0,0,16);L635:do{if((a[r+8|0]&1)==0){a[r+9|0]=0;s=0;t=0}else{u=c[r+16>>2]|0;v=(+((p<<16>>16)+32767|0)/65535.0- +g[u+24>>2])/+g[u+32>>2];w=(+((q<<16>>16)+32767|0)/65535.0- +g[u+28>>2])/+g[u+36>>2];x=u+4|0;y=c[x>>2]|0;do{if((y|0)==0){z=r+9|0}else{A=r+28|0;B=0;C=y;while(1){D=u|0;E=c[D>>2]|0;F=E+(B*104|0)|0;G=c[E+(B*104|0)+8>>2]|0;do{if((G|0)==1){H=+g[F>>2];I=+V(+(v-H));J=+g[E+(B*104|0)+12>>2];if(I>J){K=C;break}I=+g[E+(B*104|0)+4>>2];L=+V(+(w-I));M=+g[E+(B*104|0)+16>>2];if(L>M){K=C}else{N=H;O=J;P=I;Q=M;R=458}}else if((G|0)==0){M=+g[F>>2];I=+g[E+(B*104|0)+12>>2];J=(v-M)/I;H=+g[E+(B*104|0)+4>>2];L=+g[E+(B*104|0)+16>>2];S=(w-H)/L;if(J*J+S*S>1.0){K=C}else{N=M;O=I;P=H;Q=L;R=458}}else{K=C}}while(0);do{if((R|0)==458){R=0;F=c[E+(B*104|0)+20>>2]|0;if((F|0)==0){G=E+(B*104|0)+24|0;T=c[G>>2]|0;U=c[G+4>>2]|0;G=c[f+4>>2]|U;c[f>>2]=c[f>>2]|T;c[f+4>>2]=G;if((T&0|0)==0&(U&524288|0)==0){K=C;break}c[A>>2]=c[(c[D>>2]|0)+(B*104|0)+36>>2];K=c[x>>2]|0;break}L=+g[E+(B*104|0)+32>>2];H=(v-N)/O/L;I=(w-P)/Q/L;if(+V(+H)>1.0){W=H>0.0?1.0:-1.0}else{W=H}if(+V(+I)>1.0){X=I>0.0?1.0:-1.0}else{X=I}U=(F|0)==2?2:0;b[e+8+(U<<1)>>1]=~~(W*32767.0);b[e+8+((U|1)<<1)>>1]=~~(X*32767.0);K=C}}while(0);E=B+1|0;if(E>>>0<K>>>0){B=E;C=K}else{break}}C=c[f>>2]|0;B=c[f+4>>2]|0;A=r+9|0;if((C|0)==0&(B|0)==0){z=A;break}if((a[A]&1)==0){s=B;t=C;break L635}s_(h|0,0,16);s=0;t=0;break L635}}while(0);a[z]=0;s=0;t=0}}while(0);r=547640;q=c[r+4>>2]|s;p=547640;c[p>>2]=c[r>>2]|t;c[p+4>>2]=q;if((b[273824]|0)==0){b[273824]=b[k>>1]|0}if((b[273825]|0)==0){b[273825]=b[l>>1]|0}if((b[273826]|0)==0){b[273826]=b[m>>1]|0}if((b[273827]|0)==0){b[273827]=b[n>>1]|0}o=o+1|0;}while((f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,0,0,j,o,2)|0)<<16>>16!=0);i=d;return}function gS(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;if((a[379428]&1)==0|(c[133029]|0)!=0){i=b;return}if((c[120641]|0)!=0){d=c[135158]|0;e=(d|0)!=0?d:c[t>>2]|0;be(17072,76,1,e|0)|0;e=c[135158]|0;d=(e|0)!=0?e:c[t>>2]|0;a7(d|0)|0;i=b;return}d=gm[c[16050]&31]()|0;c[133031]=d;if((d|0)==0){e=c[135158]|0;f=(e|0)!=0?e:c[t>>2]|0;be(14928,85,1,f|0)|0;f=c[135158]|0;e=(f|0)!=0?f:c[t>>2]|0;a7(e|0)|0;i=b;return}e=d+3|0;f=e&-4;g=sR(f)|0;if((g|0)==0){c[133030]=0;h=c[135158]|0;j=(h|0)!=0?h:c[t>>2]|0;be(12632,66,1,j|0)|0;j=c[135158]|0;h=(j|0)!=0?j:c[t>>2]|0;a7(h|0)|0;i=b;return}if((c[g-4>>2]&3|0)!=0){s_(g|0,0,f|0)}c[133030]=g;if(!(gj[c[16052]&127](g,d)|0)){d=c[135158]|0;g=(d|0)!=0?d:c[t>>2]|0;be(52760,73,1,g|0)|0;g=c[135158]|0;d=(g|0)!=0?g:c[t>>2]|0;a7(d|0)|0;sS(c[133030]|0);c[133030]=0;i=b;return}if((a[383584]&1)!=0){d=c[135158]|0;g=(d|0)!=0?d:c[t>>2]|0;d=((c[94858]|0)>>>0)/1e6|0;eQ(g|0,50480,(k=i,i=i+8|0,c[k>>2]=d,k)|0)|0;i=k;d=c[135158]|0;g=(d|0)!=0?d:c[t>>2]|0;a7(g|0)|0}g=c[94858]|0;d=c[133030]|0;L704:do{if(f<<2>>>0<g>>>0){h=sR(32)|0;if((h|0)==0){l=514;break}if((c[h-4>>2]&3|0)!=0){s_(h|0,0,32)}j=h;c[h+16>>2]=1;m=e>>>2;c[h+24>>2]=m;n=g-1|0;o=n>>>1|n;n=o>>>2|o;o=n>>>4|n;n=o>>>8|o;o=(n>>>16|n)+1|0;n=o>>>1;p=(o-g|0)>>>0<(g-n|0)>>>0?o:n;n=p>>>3;c[h+4>>2]=n;c[h+8>>2]=n-1;if((a[383584]&1)!=0){o=c[135158]|0;q=(o|0)!=0?o:c[t>>2]|0;o=p>>>23<<3;eQ(q|0,30488,(k=i,i=i+8|0,c[k>>2]=o,k)|0)|0;i=k;o=c[135158]|0;q=(o|0)!=0?o:c[t>>2]|0;a7(q|0)|0}q=n<<3;n=sR(q)|0;do{if((n|0)==0){c[h>>2]=0;r=h+12|0}else{if((c[n-4>>2]&3|0)==0){c[h>>2]=n}else{s_(n|0,0,q|0);c[h>>2]=n}o=m<<2;p=sR(o)|0;if((p|0)==0){s=h+12|0;c[s>>2]=0;r=s;break}if((c[p-4>>2]&3|0)==0){c[h+12>>2]=p;s1(p|0,d|0,f)|0;c[133029]=j;if((h|0)==0){break L704}i=b;return}else{s_(p|0,0,o|0);c[h+12>>2]=p;s1(p|0,d|0,f)|0;c[133029]=j;i=b;return}}}while(0);sS(n);sS(c[r>>2]|0);sS(h);l=514}else{l=514}}while(0);if((l|0)==514){c[133029]=0}l=c[135158]|0;be(47128,78,1,((l|0)!=0?l:c[t>>2]|0)|0)|0;l=c[135158]|0;a7(((l|0)!=0?l:c[t>>2]|0)|0)|0;i=b;return}function gT(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;a=i;i=i+4608|0;b=c[119462]|0;d=a|0;if((b|0)==0){b5(d|0,4096,31448,(e=i,i=i+8|0,c[e>>2]=445074,e)|0)|0;i=e}else{b5(d|0,4096,46256,(e=i,i=i+16|0,c[e>>2]=445074,c[e+8>>2]=b,e)|0)|0;i=e}b=a+4096|0;if(hb(d)|0){f=c[119462]|0;b5(b|0,512,43832,(e=i,i=i+8|0,c[e>>2]=f,e)|0)|0;i=e}else{b5(b|0,512,42528,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e}e=c[133027]|0;d=e+4|0;f=c[d>>2]|0;if(f>>>0>1){g=e|0;h=1;j=f;while(1){f=c[(c[g>>2]|0)+(h<<2)>>2]|0;if((f|0)==0){k=j}else{sS(c[f+8>>2]|0);sS(c[(c[g>>2]|0)+(h<<2)>>2]|0);c[(c[g>>2]|0)+(h<<2)>>2]=0;k=c[d>>2]|0}f=h+1|0;if(f>>>0<k>>>0){h=f;j=k}else{break}}}c[d>>2]=1;d=e+12|0;sS(c[d>>2]|0);c[d>>2]=0;d=c[133027]|0;e=d+4|0;if((c[e>>2]|0)>>>0>=(c[d+8>>2]|0)>>>0){i=a;return}k=sR(12)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}s_(k|0,0,12)}}while(0);c[k+4>>2]=2;c[k>>2]=180;j=dT(b|0)|0;b=c[e>>2]|0;c[k+8>>2]=j;j=d|0;c[(c[j>>2]|0)+(b<<2)>>2]=k;k=c[e>>2]|0;c[e>>2]=k+1;if(k>>>0>1){l=k}else{i=a;return}while(1){k=l>>>1;e=c[j>>2]|0;b=e+(k<<2)|0;d=c[b>>2]|0;h=c[e+(l<<2)>>2]|0;if((c[h+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){m=547;break}c[b>>2]=h;c[(c[j>>2]|0)+(l<<2)>>2]=d;if(l>>>0>3){l=k}else{m=548;break}}if((m|0)==547){i=a;return}else if((m|0)==548){i=a;return}}function gU(){var a=0,b=0,d=0;a=i;if((c[133027]|0)!=0){i=a;return}b=sR(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)!=0){s_(b|0,0,16)}c[b+8>>2]=9;d=sR(36)|0;if((d|0)==0){c[b>>2]=0;sS(b);break}if((c[d-4>>2]&3|0)!=0){s_(d|0,0,36)}c[b>>2]=d;c[b+4>>2]=1;c[133027]=b;i=a;return}}while(0);c[133027]=0;a=c[135158]|0;eQ(((a|0)!=0?a:c[t>>2]|0)|0,33848,(a=i,i=i+16|0,c[a>>2]=19296,c[a+8>>2]=1408,a)|0)|0;i=a;a=c[135158]|0;a7(((a|0)!=0?a:c[t>>2]|0)|0)|0;cz(2)}function gV(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+4608|0;d=c[119462]|0;if((a[379457]&1)==0){e=d}else{f=d+1|0;c[119462]=f;e=f}f=b|0;if((e|0)==0){b5(f|0,4096,31448,(g=i,i=i+8|0,c[g>>2]=445074,g)|0)|0;i=g}else{b5(f|0,4096,46256,(g=i,i=i+16|0,c[g>>2]=445074,c[g+8>>2]=e,g)|0)|0;i=g}e=b+4096|0;if(ha(f)|0){d=c[119462]|0;b5(e|0,512,41480,(g=i,i=i+8|0,c[g>>2]=d,g)|0)|0;i=g}else{b5(e|0,512,40528,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g}g=c[133027]|0;f=g+4|0;d=c[f>>2]|0;if(d>>>0>1){h=g|0;j=1;k=d;while(1){d=c[(c[h>>2]|0)+(j<<2)>>2]|0;if((d|0)==0){l=k}else{sS(c[d+8>>2]|0);sS(c[(c[h>>2]|0)+(j<<2)>>2]|0);c[(c[h>>2]|0)+(j<<2)>>2]=0;l=c[f>>2]|0}d=j+1|0;if(d>>>0<l>>>0){j=d;k=l}else{break}}}c[f>>2]=1;f=g+12|0;sS(c[f>>2]|0);c[f>>2]=0;f=c[133027]|0;g=f+4|0;if((c[g>>2]|0)>>>0>=(c[f+8>>2]|0)>>>0){i=b;return}l=sR(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}s_(l|0,0,12)}}while(0);c[l+4>>2]=2;c[l>>2]=180;k=dT(e|0)|0;e=c[g>>2]|0;c[l+8>>2]=k;k=f|0;c[(c[k>>2]|0)+(e<<2)>>2]=l;l=c[g>>2]|0;c[g>>2]=l+1;if(l>>>0>1){m=l}else{i=b;return}while(1){l=m>>>1;g=c[k>>2]|0;e=g+(l<<2)|0;f=c[e>>2]|0;j=c[g+(m<<2)>>2]|0;if((c[j+4>>2]|0)>>>0<=(c[f+4>>2]|0)>>>0){n=585;break}c[e>>2]=j;c[(c[k>>2]|0)+(m<<2)>>2]=f;if(m>>>0>3){m=l}else{n=583;break}}if((n|0)==583){i=b;return}else if((n|0)==585){i=b;return}}function gW(b){b=b|0;a[281248]=b&1;a[547473]=a[482624]&1;a[547474]=0;hv();b=c[120657]|0;do{if((b|0)!=0){if((a[547473]&1)!=0){break}gp[b&63]()}}while(0);hw();if((a[547475]&1)!=0){c[136866]=0}if((a[547476]&1)!=0){c[136865]=0}if((a[547477]&1)!=0){c[136867]=0}a[547475]=0;a[547476]=0;a[547477]=0;hu();a[547473]=0;b=c[136864]|0;if((b|0)==0){return}f$[c[b+4>>2]&511](c[136867]|0);return}function gX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[383584]&1)!=0){b=c[135158]|0;d=(b|0)!=0?b:c[t>>2]|0;be(37640,27,1,d|0)|0;d=c[135158]|0;b=(d|0)!=0?d:c[t>>2]|0;a7(b|0)|0}b=c[133027]|0;d=b+4|0;e=c[d>>2]|0;if(e>>>0>1){f=b|0;g=1;h=e;while(1){e=c[(c[f>>2]|0)+(g<<2)>>2]|0;if((e|0)==0){i=h}else{sS(c[e+8>>2]|0);sS(c[(c[f>>2]|0)+(g<<2)>>2]|0);c[(c[f>>2]|0)+(g<<2)>>2]=0;i=c[d>>2]|0}e=g+1|0;if(e>>>0<i>>>0){g=e;h=i}else{break}}}c[d>>2]=1;d=b+12|0;sS(c[d>>2]|0);c[d>>2]=0;d=c[133027]|0;b=d+4|0;if((c[b>>2]|0)>>>0>=(c[d+8>>2]|0)>>>0){j=c[16056]|0;gp[j&63]();gY();return}i=sR(12)|0;do{if((i|0)!=0){if((c[i-4>>2]&3|0)==0){break}s_(i|0,0,12)}}while(0);c[i+4>>2]=1;c[i>>2]=120;h=dT(35560)|0;g=c[b>>2]|0;c[i+8>>2]=h;h=d|0;c[(c[h>>2]|0)+(g<<2)>>2]=i;i=c[b>>2]|0;c[b>>2]=i+1;if(i>>>0>1){k=i}else{j=c[16056]|0;gp[j&63]();gY();return}while(1){i=k>>>1;b=c[h>>2]|0;g=b+(i<<2)|0;d=c[g>>2]|0;f=c[b+(k<<2)>>2]|0;if((c[f+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){l=617;break}c[g>>2]=f;c[(c[h>>2]|0)+(k<<2)>>2]=d;if(k>>>0>3){k=i}else{l=618;break}}if((l|0)==617){j=c[16056]|0;gp[j&63]();gY();return}else if((l|0)==618){j=c[16056]|0;gp[j&63]();gY();return}}function gY(){var b=0,d=0,e=0,f=0,g=0;b=i;d=0;do{e=c[383588+(d<<2)>>2]|0;L865:do{if((e|0)!=1){f0[c[16044]&255](d,e);switch(e|0){case 5:{if((a[383584]&1)==0){break L865}f=c[135158]|0;eQ(((f|0)!=0?f:c[t>>2]|0)|0,31664,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[135158]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 0:{if((a[383584]&1)==0){break L865}f=c[135158]|0;eQ(((f|0)!=0?f:c[t>>2]|0)|0,31712,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[135158]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 772:{if((a[383584]&1)==0){break L865}f=c[135158]|0;eQ(((f|0)!=0?f:c[t>>2]|0)|0,31512,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[135158]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 260:{if((a[383584]&1)==0){break L865}f=c[135158]|0;eQ(((f|0)!=0?f:c[t>>2]|0)|0,31168,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[135158]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 516:{if((a[383584]&1)==0){break L865}f=c[135158]|0;eQ(((f|0)!=0?f:c[t>>2]|0)|0,31560,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[135158]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 257:{if((a[383584]&1)==0){break L865}f=c[135158]|0;eQ(((f|0)!=0?f:c[t>>2]|0)|0,31328,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[135158]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};case 2:{if((a[383584]&1)==0){break L865}f=c[135158]|0;eQ(((f|0)!=0?f:c[t>>2]|0)|0,31616,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[135158]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;break L865;break};default:{break L865}}}}while(0);d=d+1|0;}while(d>>>0<8);i=b;return}function gZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+256|0;if((c[120646]|0)==0){i=e;return}f=e|0;a[f]=0;if(f2[c[120642]&255](b)|0){g=b?32272:31608;b5(f|0,256,33016,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=0}else{g=b?30544:30112;b5(f|0,256,30856,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=1}if((a[f]|0)==0){i=e;return}do{if(j){g=c[135158]|0;b=(g|0)!=0?g:c[t>>2]|0;eQ(b|0,29760,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[135158]|0;g=(b|0)!=0?b:c[t>>2]|0;a7(g|0)|0}else{if((a[383584]&1)==0){break}g=c[135158]|0;b=(g|0)!=0?g:c[t>>2]|0;eQ(b|0,48248,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[135158]|0;g=(b|0)!=0?b:c[t>>2]|0;a7(g|0)|0}}while(0);if(!d){i=e;return}d=c[133027]|0;h=d+4|0;j=c[h>>2]|0;if(j>>>0>1){g=d|0;b=1;k=j;while(1){j=c[(c[g>>2]|0)+(b<<2)>>2]|0;if((j|0)==0){l=k}else{sS(c[j+8>>2]|0);sS(c[(c[g>>2]|0)+(b<<2)>>2]|0);c[(c[g>>2]|0)+(b<<2)>>2]=0;l=c[h>>2]|0}j=b+1|0;if(j>>>0<l>>>0){b=j;k=l}else{break}}}c[h>>2]=1;h=d+12|0;sS(c[h>>2]|0);c[h>>2]=0;h=c[133027]|0;d=h+4|0;if((c[d>>2]|0)>>>0>=(c[h+8>>2]|0)>>>0){i=e;return}l=sR(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}s_(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;k=dT(f|0)|0;f=c[d>>2]|0;c[l+8>>2]=k;k=h|0;c[(c[k>>2]|0)+(f<<2)>>2]=l;l=c[d>>2]|0;c[d>>2]=l+1;if(l>>>0>1){m=l}else{i=e;return}while(1){l=m>>>1;d=c[k>>2]|0;f=d+(l<<2)|0;h=c[f>>2]|0;b=c[d+(m<<2)>>2]|0;if((c[b+4>>2]|0)>>>0<=(c[h+4>>2]|0)>>>0){n=663;break}c[f>>2]=b;c[(c[k>>2]|0)+(m<<2)>>2]=h;if(m>>>0>3){m=l}else{n=666;break}}if((n|0)==663){i=e;return}else if((n|0)==666){i=e;return}}function g_(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+256|0;e=c[120646]|0;if((e|0)==0){i=d;return}f=d|0;a[f]=0;g=gm[e&31]()|0;e=g>>>0>b>>>0;do{if(f2[c[120645]&255](b)|0){if(e){h=b+1|0;b5(f|0,256,29408,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=0;break}else{b5(f|0,256,28488,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=0;break}}else{if(e){h=b+1|0;b5(f|0,256,28040,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=1;break}else{b5(f|0,256,27680,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=1;break}}}while(0);if((a[f]|0)==0){i=d;return}do{if(k){g=c[135158]|0;b=(g|0)!=0?g:c[t>>2]|0;eQ(b|0,29760,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[135158]|0;g=(b|0)!=0?b:c[t>>2]|0;a7(g|0)|0}else{if((a[383584]&1)==0){break}g=c[135158]|0;b=(g|0)!=0?g:c[t>>2]|0;eQ(b|0,48248,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[135158]|0;g=(b|0)!=0?b:c[t>>2]|0;a7(g|0)|0}}while(0);j=c[133027]|0;k=j+4|0;g=c[k>>2]|0;if(g>>>0>1){b=j|0;e=1;h=g;while(1){g=c[(c[b>>2]|0)+(e<<2)>>2]|0;if((g|0)==0){l=h}else{sS(c[g+8>>2]|0);sS(c[(c[b>>2]|0)+(e<<2)>>2]|0);c[(c[b>>2]|0)+(e<<2)>>2]=0;l=c[k>>2]|0}g=e+1|0;if(g>>>0<l>>>0){e=g;h=l}else{break}}}c[k>>2]=1;k=j+12|0;sS(c[k>>2]|0);c[k>>2]=0;k=c[133027]|0;j=k+4|0;if((c[j>>2]|0)>>>0>=(c[k+8>>2]|0)>>>0){i=d;return}l=sR(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}s_(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;h=dT(f|0)|0;f=c[j>>2]|0;c[l+8>>2]=h;h=k|0;c[(c[h>>2]|0)+(f<<2)>>2]=l;l=c[j>>2]|0;c[j>>2]=l+1;if(l>>>0>1){m=l}else{i=d;return}while(1){l=m>>>1;j=c[h>>2]|0;f=j+(l<<2)|0;k=c[f>>2]|0;e=c[j+(m<<2)>>2]|0;if((c[e+4>>2]|0)>>>0<=(c[k+4>>2]|0)>>>0){n=699;break}c[f>>2]=e;c[(c[h>>2]|0)+(m<<2)>>2]=k;if(m>>>0>3){m=l}else{n=700;break}}if((n|0)==699){i=d;return}else if((n|0)==700){i=d;return}}function g$(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;d=i;i=i+216|0;e=d|0;f=d+72|0;g=d+144|0;h=4096;j=420498;k=b;while(1){l=h-1|0;if((l|0)==0){m=704;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=4096;p=416402;q=b;break}else{h=l;j=j+1|0;k=k+1|0}}do{if((m|0)==704){a[j]=0;if((a[k]|0)==0){o=4096;p=416402;q=b;break}else{r=k}while(1){h=r+1|0;if((a[h]|0)==0){o=4096;p=416402;q=b;break}else{r=h}}}}while(0);while(1){r=o-1|0;if((r|0)==0){m=708;break}k=a[q]|0;a[p]=k;if(k<<24>>24==0){break}else{o=r;p=p+1|0;q=q+1|0}}do{if((m|0)==708){a[p]=0;if((a[q]|0)==0){break}else{s=q}do{s=s+1|0;}while((a[s]|0)!=0)}}while(0);s=cD(416402,46)|0;if((s|0)!=0){a[s]=0}if((a[404112]&1)==0){hl(424594,416402,51672)}if((a[404113]&1)==0){hl(445074,416402,51160)}do{if((fh(424594,g|0)|0)>=0){if((c[g+8>>2]&61440|0)!=16384){break}hm(424594,51672);if((a[383584]&1)==0){break}s=c[135158]|0;q=(s|0)!=0?s:c[t>>2]|0;eQ(q|0,32096,(u=i,i=i+8|0,c[u>>2]=424594,u)|0)|0;i=u;q=c[135158]|0;s=(q|0)!=0?q:c[t>>2]|0;a7(s|0)|0}}while(0);do{if((fh(445074,f|0)|0)>=0){if((c[f+8>>2]&61440|0)!=16384){break}hm(445074,51160);if((a[383584]&1)==0){break}g=c[135158]|0;s=(g|0)!=0?g:c[t>>2]|0;eQ(s|0,32008,(u=i,i=i+8|0,c[u>>2]=445074,u)|0)|0;i=u;s=c[135158]|0;g=(s|0)!=0?s:c[t>>2]|0;a7(g|0)|0}}while(0);if((a[375332]|0)==0){hs(375332,b)}if((a[404114]|0)==0){i=d;return}if((fh(404114,e|0)|0)<0){i=d;return}if((c[e+8>>2]&61440|0)!=16384){i=d;return}hm(404114,31896);if((a[383584]&1)!=0){e=c[135158]|0;b=(e|0)!=0?e:c[t>>2]|0;eQ(b|0,31832,(u=i,i=i+8|0,c[u>>2]=404114,u)|0)|0;i=u;u=c[135158]|0;b=(u|0)!=0?u:c[t>>2]|0;a7(b|0)|0}b=dz(404114,42504)|0;if((b|0)!=0){a_(b|0)|0;i=d;return}a[404114]=0;if((a[383584]&1)==0){i=d;return}b=c[135158]|0;be(31768,59,1,((b|0)!=0?b:c[t>>2]|0)|0)|0;b=c[135158]|0;a7(((b|0)!=0?b:c[t>>2]|0)|0)|0;i=d;return}function g0(){var b=0,d=0,e=0;b=c[96930]|0;do{if((b|0)==2|(b|0)==3){if((a[404112]&1)==0){hk(424594,391824,51672)}hk(432786,424594,32472);if((a[404113]&1)!=0){break}hk(445074,391824,51160)}else if((b|0)==1){if((a[404112]&1)==0){hk(424594,387728,51672)}if((a[404113]&1)==0){hk(445074,387728,51160)}hk(428690,424594,23624)}else if((b|0)==4){if(!((a[404112]&1)==0|(a[395920]|0)==0|(a[400016]|0)==0)){d=c[135158]|0;e=(d|0)!=0?d:c[t>>2]|0;be(32344,109,1,e|0)|0;e=c[135158]|0;d=(e|0)!=0?e:c[t>>2]|0;a7(d|0)|0}hk(436882,395920,51672);hk(440978,400016,51672);if((a[404113]&1)!=0){break}hk(445074,(a[395920]|0)!=0?395920:400016,51160)}else{hk(428690,424594,23624)}}while(0);hk(532136,424594,547872);if((a[416402]|0)==0){return}if((a[465558]|0)==0){hl(465558,416402,32320)}if((a[469654]|0)==0){hl(469654,416402,32280)}if((a[473750]|0)==0){hl(473750,416402,32264)}if((a[449170]|0)==0){hl(449170,416402,32256)}if((a[371236]|0)!=0){return}hs(371236,416402);return}function g1(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,ag=0,ah=0,ai=0,aj=0,ak=0,am=0,an=0,ao=0,ar=0,at=0,au=0,av=0,aw=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aH=0,aI=0,aK=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0.0,dV=0.0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0;f=i;i=i+13008|0;j=1;k=0;l=i;i=i+168|0;c[l>>2]=0;while(1)switch(j|0){case 1:m=f|0;n=f+8|0;o=f+16|0;p=f+24|0;q=f+32|0;r=f+40|0;s=f+48|0;u=f+56|0;v=f+64|0;w=f+72|0;z=f+144|0;A=f+216|0;B=f+4312|0;C=f+8408|0;D=f+12504|0;E=f+12512|0;a[383586]=1;a[383585]=1;c[96930]=0;c[95897]=1;c[95898]=1;c[95899]=1;c[95900]=1;c[95901]=1;c[95902]=1;c[95903]=1;c[95904]=1;F=s$(541664,j,l)|0;j=510;break;case 510:if((F|0)>0){j=2;break}else{j=3;break};case 2:G=c[135158]|0;ax(52,((G|0)!=0?G:c[t>>2]|0)|0,25784,(H=i,i=i+8|0,c[H>>2]=540639,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;I=F;j=509;break;case 3:a[540637]=1;a[541708]=0;a[541709]=0;a[404112]=0;a[404113]=0;if((d|0)<2){j=4;break}else{j=5;break};case 4:a[541709]=1;j=182;break;case 5:c[1516]=0;c[D>>2]=0;c[E>>2]=48736;c[E+4>>2]=0;c[E+8>>2]=D;c[E+12>>2]=77;c[E+16>>2]=48640;c[E+20>>2]=0;c[E+24>>2]=0;c[E+28>>2]=104;c[E+32>>2]=48392;c[E+36>>2]=1;c[E+40>>2]=0;c[E+44>>2]=115;c[E+48>>2]=48152;c[E+52>>2]=0;c[E+56>>2]=0;c[E+60>>2]=102;c[E+64>>2]=47952;c[E+68>>2]=0;c[E+72>>2]=0;c[E+76>>2]=118;c[E+80>>2]=47792;c[E+84>>2]=1;c[E+88>>2]=0;c[E+92>>2]=103;c[E+96>>2]=47712;c[E+100>>2]=1;c[E+104>>2]=0;c[E+108>>2]=99;c[E+112>>2]=47336;c[E+116>>2]=1;c[E+120>>2]=D;c[E+124>>2]=67;c[E+128>>2]=46952;c[E+132>>2]=1;c[E+136>>2]=0;c[E+140>>2]=109;c[E+144>>2]=46848;c[E+148>>2]=1;c[E+152>>2]=0;c[E+156>>2]=78;c[E+160>>2]=46720;c[E+164>>2]=0;c[E+168>>2]=0;c[E+172>>2]=112;c[E+176>>2]=46632;c[E+180>>2]=0;c[E+184>>2]=0;c[E+188>>2]=106;c[E+192>>2]=46512;c[E+196>>2]=0;c[E+200>>2]=0;c[E+204>>2]=74;c[E+208>>2]=46408;c[E+212>>2]=1;c[E+216>>2]=0;c[E+220>>2]=65;c[E+224>>2]=46296;c[E+228>>2]=1;c[E+232>>2]=0;c[E+236>>2]=83;c[E+240>>2]=46248;c[E+244>>2]=1;c[E+248>>2]=0;c[E+252>>2]=98;c[E+256>>2]=46208;c[E+260>>2]=1;c[E+264>>2]=0;c[E+268>>2]=66;c[E+272>>2]=45888;c[E+276>>2]=0;c[E+280>>2]=0;c[E+284>>2]=52;c[E+288>>2]=45784;c[E+292>>2]=1;c[E+296>>2]=0;c[E+300>>2]=89;c[E+304>>2]=45712;c[E+308>>2]=1;c[E+312>>2]=0;c[E+316>>2]=90;c[E+320>>2]=45656;c[E+324>>2]=1;c[E+328>>2]=0;c[E+332>>2]=80;c[E+336>>2]=45600;c[E+340>>2]=1;c[E+344>>2]=0;c[E+348>>2]=82;c[E+352>>2]=45424;c[E+356>>2]=1;c[E+360>>2]=0;c[E+364>>2]=77;c[E+368>>2]=45368;c[E+372>>2]=1;c[E+376>>2]=0;c[E+380>>2]=85;c[E+384>>2]=45320;c[E+388>>2]=1;c[E+392>>2]=D;c[E+396>>2]=66;c[E+400>>2]=45256;c[E+404>>2]=1;c[E+408>>2]=D;c[E+412>>2]=73;c[E+416>>2]=45176;c[E+420>>2]=0;c[E+424>>2]=D;c[E+428>>2]=110;c[E+432>>2]=44824;c[E+436>>2]=1;c[E+440>>2]=0;c[E+444>>2]=88;c[E+448>>2]=44696;c[E+452>>2]=0;c[E+456>>2]=0;c[E+460>>2]=68;c[E+464>>2]=44560;c[E+468>>2]=0;c[E+472>>2]=D;c[E+476>>2]=102;s_(E+480|0,0,16);J=e+(d<<2)|0;K=0;j=6;break;case 6:c[D>>2]=0;if((K|0)==0){j=7;break}else{L=K;j=8;break};case 7:c[1516]=1;L=1;j=8;break;case 8:if((d|0)==1){M=L;j=162;break}else{j=9;break};case 9:N=e+(L<<2)|0;O=c[N>>2]|0;if((O|0)==0){P=-1;Q=-1;j=17;break}else{R=0;S=O;j=10;break};case 10:if((a[S]|0)==45){j=11;break}else{j=12;break};case 11:if((a[S+1|0]|0)==45){j=12;break}else{T=R;j=13;break};case 12:G=R+1|0;W=c[e+(G+L<<2)>>2]|0;if((W|0)==0){T=-1;j=13;break}else{R=G;S=W;j=10;break};case 13:X=0;Y=O;j=14;break;case 14:if((a[Y]|0)==45){j=15;break}else{j=16;break};case 15:if((a[Y+1|0]|0)==45){P=X;Q=T;j=17;break}else{j=16;break};case 16:W=X+1|0;G=c[e+(W+L<<2)>>2]|0;if((G|0)==0){P=-1;Q=T;j=17;break}else{X=W;Y=G;j=14;break};case 17:Z=(Q|0)==-1;_=(P|0)==-1;if(Z&_){M=L;j=162;break}else{j=18;break};case 18:if((Q|0)>0){j=19;break}else{j=21;break};case 19:if((Q|0)<(P|0)|_){j=20;break}else{j=21;break};case 20:aO(20,N|0,e+(Q+L<<2)|0,J|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=28;break;case 21:if((P|0)>0){j=22;break}else{j=25;break};case 22:if((P|0)<(Q|0)|Z){j=23;break}else{j=25;break};case 23:aO(20,N|0,e+(P+L<<2)|0,J|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((Q|0)==0){j=28;break}else{j=24;break};case 24:$=c[1516]|0;j=40;break;case 25:aa=(Q|0)==0;ab=(P|0)==0;if(aa|ab){j=27;break}else{j=26;break};case 26:G=c[135158]|0;ax(52,((G|0)!=0?G:c[t>>2]|0)|0,33848,(H=i,i=i+16|0,c[H>>2]=50224,c[H+8>>2]=190,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(132,2);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 27:if(aa){j=28;break}else{j=39;break};case 28:ac=c[1516]|0;ad=c[e+(ac<<2)>>2]|0;ae=ad+1|0;ag=a[ae]|0;if(ag<<24>>24==58){j=160;break}else{j=29;break};case 29:ah=ax(2,44432,ag<<24>>24|0,41)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((ah|0)==0){j=160;break}else{j=30;break};case 30:ai=ad+2|0;G=(a[ah+1|0]|0)==58;aj=G&(a[ai]|0)!=0;if(G){j=31;break}else{j=36;break};case 31:if(aj){j=32;break}else{j=33;break};case 32:c[16082]=ai;ak=ac+1|0;am=ai;j=34;break;case 33:G=c[e+(ac+1<<2)>>2]|0;c[16082]=G;ak=ac+2|0;am=G;j=34;break;case 34:c[1516]=ak;if((am|0)==0){j=160;break}else{j=35;break};case 35:an=a[ah]|0;ao=ak;j=49;break;case 36:if(aj){j=37;break}else{j=38;break};case 37:G=as(40,ai|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aO(16,ae|0,ai|0,G+1|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;an=a[ah]|0;ao=ac;j=49;break;case 38:G=ac+1|0;c[1516]=G;an=a[ah]|0;ao=G;j=49;break;case 39:if(ab){$=L;j=40;break}else{j=160;break};case 40:ar=0;j=41;break;case 41:at=c[E+(ar<<4)>>2]|0;if((at|0)==0){j=160;break}else{j=42;break};case 42:G=aJ(104,at|0,(c[e+($<<2)>>2]|0)+2|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=44;break}else{j=43;break};case 43:ar=ar+1|0;j=41;break;case 44:au=$+1|0;if((c[E+(ar<<4)+4>>2]|0)==0){av=au;j=47;break}else{j=45;break};case 45:aw=c[e+(au<<2)>>2]|0;if((aw|0)==0){j=160;break}else{j=46;break};case 46:c[16082]=aw;av=$+2|0;j=47;break;case 47:c[1516]=av;ay=c[E+(ar<<4)+8>>2]|0;az=c[E+(ar<<4)+12>>2]|0;if((ay|0)==0){an=az;ao=av;j=49;break}else{j=48;break};case 48:c[ay>>2]=az;j=139;break;case 49:switch(an|0){case 68:{j=50;break};case 104:{j=51;break};case 52:{j=52;break};case 106:{j=53;break};case 74:{j=54;break};case 65:{j=55;break};case 115:{j=58;break};case 102:{j=64;break};case 103:{j=65;break};case 98:{j=71;break};case 66:{j=77;break};case 89:{j=83;break};case 90:{j=89;break};case 83:{j=95;break};case 118:{j=101;break};case 109:{j=102;break};case 78:{j=105;break};case 112:{j=108;break};case 99:{j=109;break};case 80:case 82:{j=114;break};case 77:{j=120;break};case 85:{j=128;break};case 88:{j=134;break};case 0:{j=139;break};case 63:{j=160;break};case-1:{M=ao;j=162;break};default:{j=161;break}}break;case 50:K=c[1516]|0;j=6;break;case 51:aP(8);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(132,0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 52:c[95898]=257;j=50;break;case 53:c[95898]=516;j=50;break;case 54:c[95898]=772;j=50;break;case 55:G=ax(66,c[16082]|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aA=G-1|0;if(aA>>>0>7){j=56;break}else{j=57;break};case 56:G=c[135158]|0;aN(6,44304,57,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(8);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(202,44176);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 57:c[383588+(aA<<2)>>2]=5;j=50;break;case 58:aB=4096;aC=424594;aD=c[16082]|0;j=59;break;case 59:aE=aB-1|0;if((aE|0)==0){j=61;break}else{j=60;break};case 60:G=a[aD]|0;a[aC]=G;if(G<<24>>24==0){j=63;break}else{aB=aE;aC=aC+1|0;aD=aD+1|0;j=59;break};case 61:a[aC]=0;if((a[aD]|0)==0){j=63;break}else{aF=aD;j=62;break};case 62:G=aF+1|0;if((a[G]|0)==0){j=63;break}else{aF=G;j=62;break};case 63:a[404112]=1;j=50;break;case 64:a[383587]=1;j=50;break;case 65:aH=4096;aI=387728;aK=c[16082]|0;j=66;break;case 66:aQ=aH-1|0;if((aQ|0)==0){j=68;break}else{j=67;break};case 67:G=a[aK]|0;a[aI]=G;if(G<<24>>24==0){j=70;break}else{aH=aQ;aI=aI+1|0;aK=aK+1|0;j=66;break};case 68:a[aI]=0;if((a[aK]|0)==0){j=70;break}else{aR=aK;j=69;break};case 69:G=aR+1|0;if((a[G]|0)==0){j=70;break}else{aR=G;j=69;break};case 70:c[96930]=1;j=50;break;case 71:aS=4096;aT=391824;aU=c[16082]|0;j=72;break;case 72:aV=aS-1|0;if((aV|0)==0){j=74;break}else{j=73;break};case 73:G=a[aU]|0;a[aT]=G;if(G<<24>>24==0){j=76;break}else{aS=aV;aT=aT+1|0;aU=aU+1|0;j=72;break};case 74:a[aT]=0;if((a[aU]|0)==0){j=76;break}else{aW=aU;j=75;break};case 75:G=aW+1|0;if((a[G]|0)==0){j=76;break}else{aW=G;j=75;break};case 76:c[96930]=2;j=50;break;case 77:aX=4096;aY=391824;aZ=c[16082]|0;j=78;break;case 78:a_=aX-1|0;if((a_|0)==0){j=80;break}else{j=79;break};case 79:G=a[aZ]|0;a[aY]=G;if(G<<24>>24==0){j=82;break}else{aX=a_;aY=aY+1|0;aZ=aZ+1|0;j=78;break};case 80:a[aY]=0;if((a[aZ]|0)==0){j=82;break}else{a$=aZ;j=81;break};case 81:G=a$+1|0;if((a[G]|0)==0){j=82;break}else{a$=G;j=81;break};case 82:c[96930]=3;j=50;break;case 83:a0=4096;a1=395920;a2=c[16082]|0;j=84;break;case 84:a3=a0-1|0;if((a3|0)==0){j=86;break}else{j=85;break};case 85:G=a[a2]|0;a[a1]=G;if(G<<24>>24==0){j=88;break}else{a0=a3;a1=a1+1|0;a2=a2+1|0;j=84;break};case 86:a[a1]=0;if((a[a2]|0)==0){j=88;break}else{a4=a2;j=87;break};case 87:G=a4+1|0;if((a[G]|0)==0){j=88;break}else{a4=G;j=87;break};case 88:c[96930]=4;j=50;break;case 89:a5=4096;a6=400016;a7=c[16082]|0;j=90;break;case 90:a8=a5-1|0;if((a8|0)==0){j=92;break}else{j=91;break};case 91:G=a[a7]|0;a[a6]=G;if(G<<24>>24==0){j=94;break}else{a5=a8;a6=a6+1|0;a7=a7+1|0;j=90;break};case 92:a[a6]=0;if((a[a7]|0)==0){j=94;break}else{a9=a7;j=93;break};case 93:G=a9+1|0;if((a[G]|0)==0){j=94;break}else{a9=G;j=93;break};case 94:c[96930]=4;j=50;break;case 95:ba=4096;bb=445074;bc=c[16082]|0;j=96;break;case 96:bd=ba-1|0;if((bd|0)==0){j=98;break}else{j=97;break};case 97:G=a[bc]|0;a[bb]=G;if(G<<24>>24==0){j=100;break}else{ba=bd;bb=bb+1|0;bc=bc+1|0;j=96;break};case 98:a[bb]=0;if((a[bc]|0)==0){j=100;break}else{be=bc;j=99;break};case 99:G=be+1|0;if((a[G]|0)==0){j=100;break}else{be=G;j=99;break};case 100:a[404113]=1;j=50;break;case 101:a[383584]=1;j=50;break;case 102:G=ax(66,c[16082]|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;bf=G-1|0;if(bf>>>0>7){j=103;break}else{j=104;break};case 103:G=c[135158]|0;aN(6,44056,52,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(8);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(202,44176);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 104:c[383588+(bf<<2)>>2]=2;j=50;break;case 105:G=ax(66,c[16082]|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;bg=G-1|0;if(bg>>>0>7){j=106;break}else{j=107;break};case 106:G=c[135158]|0;aN(6,43888,58,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(8);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(202,44176);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 107:c[383588+(bg<<2)>>2]=0;j=50;break;case 108:c[95898]=260;j=50;break;case 109:bh=4096;bi=404114;bj=c[16082]|0;j=110;break;case 110:bk=bh-1|0;if((bk|0)==0){j=112;break}else{j=111;break};case 111:G=a[bj]|0;a[bi]=G;if(G<<24>>24==0){j=50;break}else{bh=bk;bi=bi+1|0;bj=bj+1|0;j=110;break};case 112:a[bi]=0;if((a[bj]|0)==0){j=50;break}else{bl=bj;j=113;break};case 113:G=bl+1|0;if((a[G]|0)==0){j=50;break}else{bl=G;j=113;break};case 114:bm=4096;bn=536233;bo=c[16082]|0;j=115;break;case 115:bp=bm-1|0;if((bp|0)==0){j=117;break}else{j=116;break};case 116:G=a[bo]|0;a[bn]=G;if(G<<24>>24==0){j=119;break}else{bm=bp;bn=bn+1|0;bo=bo+1|0;j=115;break};case 117:a[bn]=0;if((a[bo]|0)==0){j=119;break}else{bq=bo;j=118;break};case 118:G=bq+1|0;if((a[G]|0)==0){j=119;break}else{bq=G;j=118;break};case 119:a[540330]=(an|0)==80|0;a[540329]=(an|0)==82|0;j=50;break;case 120:br=c[16082]|0;G=aJ(104,br|0,43816)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=121;break}else{j=122;break};case 121:a[540332]=1;a[540333]=1;j=50;break;case 122:G=aJ(104,br|0,43760)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=123;break}else{j=124;break};case 123:a[540332]=1;j=50;break;case 124:G=aJ(104,br|0,43456)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=125;break}else{j=126;break};case 125:a[540333]=1;j=50;break;case 126:G=aJ(104,br|0,43328)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=50;break}else{j=127;break};case 127:G=c[135158]|0;aN(6,43032,54,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(8);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(202,44176);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 128:bs=4096;bt=465558;bu=c[16082]|0;j=129;break;case 129:bv=bs-1|0;if((bv|0)==0){j=131;break}else{j=130;break};case 130:G=a[bu]|0;a[bt]=G;if(G<<24>>24==0){j=133;break}else{bs=bv;bt=bt+1|0;bu=bu+1|0;j=129;break};case 131:a[bt]=0;if((a[bu]|0)==0){j=133;break}else{bw=bu;j=132;break};case 132:G=bw+1|0;if((a[G]|0)==0){j=133;break}else{bw=G;j=132;break};case 133:a[465555]=1;j=50;break;case 134:bx=4096;by=449170;bz=c[16082]|0;j=135;break;case 135:bA=bx-1|0;if((bA|0)==0){j=137;break}else{j=136;break};case 136:G=a[bz]|0;a[by]=G;if(G<<24>>24==0){j=50;break}else{bx=bA;by=by+1|0;bz=bz+1|0;j=135;break};case 137:a[by]=0;if((a[bz]|0)==0){j=50;break}else{bB=bz;j=138;break};case 138:G=bB+1|0;if((a[G]|0)==0){j=50;break}else{bB=G;j=138;break};case 139:switch(c[D>>2]|0){case 77:{j=140;break};case 67:{j=141;break};case 66:{j=146;break};case 73:{j=152;break};case 110:{j=158;break};case 102:{j=159;break};default:{j=50;break}}break;case 140:a[541709]=1;j=50;break;case 141:bC=4096;bD=408210;bE=c[16082]|0;j=142;break;case 142:bF=bC-1|0;if((bF|0)==0){j=144;break}else{j=143;break};case 143:G=a[bE]|0;a[bD]=G;if(G<<24>>24==0){j=50;break}else{bC=bF;bD=bD+1|0;bE=bE+1|0;j=142;break};case 144:a[bD]=0;if((a[bE]|0)==0){j=50;break}else{bG=bE;j=145;break};case 145:G=bG+1|0;if((a[G]|0)==0){j=50;break}else{bG=G;j=145;break};case 146:bH=4096;bI=469654;bJ=c[16082]|0;j=147;break;case 147:bK=bH-1|0;if((bK|0)==0){j=149;break}else{j=148;break};case 148:G=a[bJ]|0;a[bI]=G;if(G<<24>>24==0){j=151;break}else{bH=bK;bI=bI+1|0;bJ=bJ+1|0;j=147;break};case 149:a[bI]=0;if((a[bJ]|0)==0){j=151;break}else{bL=bJ;j=150;break};case 150:G=bL+1|0;if((a[G]|0)==0){j=151;break}else{bL=G;j=150;break};case 151:a[465556]=1;j=50;break;case 152:bM=4096;bN=473750;bO=c[16082]|0;j=153;break;case 153:bP=bM-1|0;if((bP|0)==0){j=155;break}else{j=154;break};case 154:G=a[bO]|0;a[bN]=G;if(G<<24>>24==0){j=157;break}else{bM=bP;bN=bN+1|0;bO=bO+1|0;j=153;break};case 155:a[bN]=0;if((a[bO]|0)==0){j=157;break}else{bQ=bO;j=156;break};case 156:G=bQ+1|0;if((a[G]|0)==0){j=157;break}else{bQ=G;j=156;break};case 157:a[465557]=1;j=50;break;case 158:a[465554]=1;j=50;break;case 159:as(72,10)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;as(226,42648)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=42520,c[H+8>>2]=42464,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=42104,c[H+8>>2]=42024,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=41920,c[H+8>>2]=41832,c[H+16>>2]=23808,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=41704,c[H+8>>2]=41632,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=41608,c[H+8>>2]=41536,c[H+16>>2]=23808,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=41472,c[H+8>>2]=41416,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=41112,c[H+8>>2]=40976,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=40856,c[H+8>>2]=40768,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=40728,c[H+8>>2]=40768,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=40680,c[H+8>>2]=40768,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=40640,c[H+8>>2]=40768,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=40576,c[H+8>>2]=40768,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=40512,c[H+8>>2]=40768,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=40472,c[H+8>>2]=40768,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=40096,c[H+8>>2]=40768,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=40016,c[H+8>>2]=39880,c[H+16>>2]=23808,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=39840,c[H+8>>2]=40768,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=39744,c[H+8>>2]=39672,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=39632,c[H+8>>2]=39560,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=39488,c[H+8>>2]=39432,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=39192,c[H+8>>2]=39088,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=38928,c[H+8>>2]=38848,c[H+16>>2]=23808,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=38824,c[H+8>>2]=38776,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=38744,c[H+8>>2]=38672,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=38616,c[H+8>>2]=38560,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=38240,c[H+8>>2]=38152,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;aJ(92,42592,(H=i,i=i+24|0,c[H>>2]=38008,c[H+8>>2]=37928,c[H+16>>2]=23576,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;ap(132,0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 160:aP(8);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(202,44176);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 161:G=c[135158]|0;aN(6,42912,46,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(202,44176);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 162:bR=(M|0)<(d|0);if((a[541709]&1)==0){j=165;break}else{j=163;break};case 163:if(bR){j=164;break}else{j=168;break};case 164:G=c[135158]|0;aN(6,42808,71,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(202,44176);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 165:if(bR){j=166;break}else{j=167;break};case 166:ap(56,c[e+(M<<2)>>2]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=168;break;case 167:a[541708]=1;j=168;break;case 168:if((a[404112]&1)==0){j=175;break}else{j=169;break};case 169:G=aJ(14,424594,z|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)<0){j=175;break}else{j=170;break};case 170:if((c[z+8>>2]&61440|0)==16384){bS=4096;bT=453266;bU=424594;j=171;break}else{j=175;break};case 171:bV=bS-1|0;if((bV|0)==0){j=173;break}else{j=172;break};case 172:G=a[bU]|0;a[bT]=G;if(G<<24>>24==0){j=175;break}else{bS=bV;bT=bT+1|0;bU=bU+1|0;j=171;break};case 173:a[bT]=0;if((a[bU]|0)==0){j=175;break}else{bW=bU;j=174;break};case 174:G=bW+1|0;if((a[G]|0)==0){j=175;break}else{bW=G;j=174;break};case 175:if((a[404113]&1)==0){j=182;break}else{j=176;break};case 176:G=aJ(14,445074,w|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)<0){j=182;break}else{j=177;break};case 177:if((c[w+8>>2]&61440|0)==16384){bX=4096;bY=457362;bZ=445074;j=178;break}else{j=182;break};case 178:b_=bX-1|0;if((b_|0)==0){j=180;break}else{j=179;break};case 179:G=a[bZ]|0;a[bY]=G;if(G<<24>>24==0){j=182;break}else{bX=b_;bY=bY+1|0;bZ=bZ+1|0;j=178;break};case 180:a[bY]=0;if((a[bZ]|0)==0){j=182;break}else{b$=bZ;j=181;break};case 181:G=b$+1|0;if((a[G]|0)==0){j=182;break}else{b$=G;j=181;break};case 182:if((a[383584]&1)==0){j=185;break}else{j=183;break};case 183:G=c[135158]|0;aN(6,25360,49,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[t>>2]|0;aN(6,50464,11,1,G|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ax(52,G|0,50176,(H=i,i=i+16|0,c[H>>2]=49560,c[H+8>>2]=32,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;ax(52,G|0,49272,(H=i,i=i+8|0,c[H>>2]=49080,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;if((a[383584]&1)==0){j=185;break}else{j=184;break};case 184:G=c[135158]|0;aN(6,25e3,50,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=185;break;case 185:if((a[540540]&1)==0){j=186;break}else{j=233;break};case 186:a[281176]=103;a[281177]=108;a[281178]=0;a[297724]=114;a[297725]=119;a[297726]=101;a[297727]=98;a[297728]=97;a[297729]=117;a[297730]=100;a[297731]=105;a[297732]=111;a[297733]=0;a[306016]=114;a[306017]=119;a[306018]=101;a[306019]=98;a[306020]=105;a[306021]=110;a[306022]=112;a[306023]=117;a[306024]=116;a[306025]=0;g[70310]=3.0;g[70311]=3.0;a[281248]=a[383587]&1;a[281249]=1;c[70313]=0;c[70314]=0;c[70315]=0;a[297716]=0;a[281264]=1;a[281265]=0;c[70318]=0;a[281266]=0;c[70317]=1;a[289492]=0;a[281276]=1;a[281277]=1;a[281285]=0;a[281278]=1;g[70320]=-1.0;a[281284]=0;c[70322]=4;a[285388]=0;a[297720]=1;a[297692]=1;g[74422]=48.0;a[297693]=1;g[74424]=.05000000074505806;g[74425]=.05000000074505806;g[74426]=1.0;g[74427]=1.0;g[74428]=0.0;g[72372]=59.95000076293945;a[297717]=0;a[297718]=0;a[297719]=1;a[297756]=1;c[74440]=48e3;c[74441]=0;g[74442]=48.0e3;c[75467]=64;a[301872]=1;a[305969]=1;g[76493]=.004999999888241291;g[76494]=0.0;a[379428]=0;c[94858]=20971520;c[94859]=1;g[94860]=3.0;g[94861]=-1.0;a[379448]=0;s_(379452,0,7);a[379459]=1;a[379460]=0;b[189731]=-10181;a[379464]=0;c[89736]=100;s1(306080,2848,2240)|0;s1(308320,1848,1e3)|0;s1(310560,1848,1e3)|0;s1(312800,1848,1e3)|0;s1(315040,1848,1e3)|0;s1(317280,1848,1e3)|0;s1(319520,1848,1e3)|0;s1(321760,1848,1e3)|0;b0=0;j=187;break;case 187:G=324016+(b0*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[324032+(b0*40|0)>>2]=-1;G=b0+1|0;if(G>>>0<56){b0=G;j=187;break}else{b1=0;j=213;break};case 188:if((a[306080+(b2*40|0)|0]&1)==0){j=191;break}else{j=189;break};case 189:if((b2|0)==(c[306084+(b2*40|0)>>2]|0)){j=191;break}else{j=190;break};case 190:G=c[135158]|0;ax(52,((G|0)!=0?G:c[t>>2]|0)|0,33848,(H=i,i=i+16|0,c[H>>2]=23408,c[H+8>>2]=251,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(132,2);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 191:G=b2+1|0;if((G|0)<56){b2=G;j=188;break}else{b3=0;j=192;break};case 192:if((a[308320+(b3*40|0)|0]&1)==0){j=194;break}else{j=193;break};case 193:if((b3|0)==(c[308324+(b3*40|0)>>2]|0)){j=194;break}else{j=190;break};case 194:G=b3+1|0;if((G|0)<56){b3=G;j=192;break}else{b4=0;j=195;break};case 195:if((a[310560+(b4*40|0)|0]&1)==0){j=197;break}else{j=196;break};case 196:if((b4|0)==(c[310564+(b4*40|0)>>2]|0)){j=197;break}else{j=190;break};case 197:G=b4+1|0;if((G|0)<56){b4=G;j=195;break}else{b5=0;j=198;break};case 198:if((a[312800+(b5*40|0)|0]&1)==0){j=200;break}else{j=199;break};case 199:if((b5|0)==(c[312804+(b5*40|0)>>2]|0)){j=200;break}else{j=190;break};case 200:G=b5+1|0;if((G|0)<56){b5=G;j=198;break}else{b6=0;j=201;break};case 201:if((a[315040+(b6*40|0)|0]&1)==0){j=203;break}else{j=202;break};case 202:if((b6|0)==(c[315044+(b6*40|0)>>2]|0)){j=203;break}else{j=190;break};case 203:G=b6+1|0;if((G|0)<56){b6=G;j=201;break}else{b7=0;j=204;break};case 204:if((a[317280+(b7*40|0)|0]&1)==0){j=206;break}else{j=205;break};case 205:if((b7|0)==(c[317284+(b7*40|0)>>2]|0)){j=206;break}else{j=190;break};case 206:G=b7+1|0;if((G|0)<56){b7=G;j=204;break}else{b8=0;j=207;break};case 207:if((a[319520+(b8*40|0)|0]&1)==0){j=209;break}else{j=208;break};case 208:if((b8|0)==(c[319524+(b8*40|0)>>2]|0)){j=209;break}else{j=190;break};case 209:G=b8+1|0;if((G|0)<56){b8=G;j=207;break}else{b9=0;j=210;break};case 210:if((a[321760+(b9*40|0)|0]&1)==0){j=212;break}else{j=211;break};case 211:if((b9|0)==(c[321764+(b9*40|0)>>2]|0)){j=212;break}else{j=190;break};case 212:G=b9+1|0;if((G|0)<56){b9=G;j=210;break}else{j=220;break};case 213:G=326256+(b1*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[326272+(b1*40|0)>>2]=-1;G=b1+1|0;if(G>>>0<56){b1=G;j=213;break}else{ca=0;j=214;break};case 214:G=328496+(ca*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[328512+(ca*40|0)>>2]=-1;G=ca+1|0;if(G>>>0<56){ca=G;j=214;break}else{cb=0;j=215;break};case 215:G=330736+(cb*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[330752+(cb*40|0)>>2]=-1;G=cb+1|0;if(G>>>0<56){cb=G;j=215;break}else{cc=0;j=216;break};case 216:G=332976+(cc*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[332992+(cc*40|0)>>2]=-1;G=cc+1|0;if(G>>>0<56){cc=G;j=216;break}else{cd=0;j=217;break};case 217:G=335216+(cd*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[335232+(cd*40|0)>>2]=-1;G=cd+1|0;if(G>>>0<56){cd=G;j=217;break}else{ce=0;j=218;break};case 218:G=337456+(ce*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[337472+(ce*40|0)>>2]=-1;G=ce+1|0;if(G>>>0<56){ce=G;j=218;break}else{cf=0;j=219;break};case 219:G=339696+(cf*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[339712+(cf*40|0)>>2]=-1;G=cf+1|0;if(G>>>0<56){cf=G;j=219;break}else{b2=0;j=188;break};case 220:g[85482]=.5;a[342542]=1;c[85636]=6;c[85637]=3;g[86662]=1.0;g[86663]=1.0;a[342540]=0;a[342541]=1;c[85483]=0;c[85484]=1;c[85485]=2;c[85486]=3;c[85487]=4;c[85488]=5;c[85489]=6;c[85490]=7;a[540638]=0;s_(540572,0,16);a[540540]=1;aP(50);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cg=(a[383584]&1)!=0;if((a[404114]|0)==0){j=224;break}else{j=221;break};case 221:if(cg){j=222;break}else{j=223;break};case 222:G=c[135158]|0;ax(52,((G|0)!=0?G:c[t>>2]|0)|0,44376,(H=i,i=i+8|0,c[H>>2]=404114,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=223;break;case 223:G=as(168,404114)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(G){j=233;break}else{j=230;break};case 224:if(cg){j=225;break}else{j=226;break};case 225:G=c[135158]|0;aN(6,44248,35,1,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=226;break;case 226:ch=as(168,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[404114]|0)==0){j=229;break}else{j=227;break};case 227:if((a[383584]&1)==0){j=229;break}else{j=228;break};case 228:G=c[135158]|0;ax(52,((G|0)!=0?G:c[t>>2]|0)|0,44120,(H=i,i=i+8|0,c[H>>2]=404114,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(ch){j=233;break}else{j=230;break};case 229:if(ch){j=233;break}else{j=230;break};case 230:G=c[135158]|0;ax(52,((G|0)!=0?G:c[t>>2]|0)|0,43960,(H=i,i=i+8|0,c[H>>2]=404114,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[540637]&1)==0){j=231;break}else{j=232;break};case 231:G=c[135158]|0;ax(52,((G|0)!=0?G:c[t>>2]|0)|0,33848,(H=i,i=i+16|0,c[H>>2]=43784,c[H+8>>2]=832,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;G=c[135158]|0;as(114,((G|0)!=0?G:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(132,2);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 232:a[540639]=112;a[540640]=97;a[540641]=114;a[540642]=115;a[540643]=101;a[540644]=95;a[540645]=99;a[540646]=111;a[540647]=110;a[540648]=102;a[540649]=105;a[540650]=103;a[540651]=95;a[540652]=102;a[540653]=105;a[540654]=108;a[540655]=101;a[540656]=40;a[540657]=41;a[540658]=0;aq(128,541664,1);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 233:G=(a[541709]&1)!=0;W=G?54:322;c[16062]=G?20:46;c[16074]=G?14:18;c[16080]=G?22:12;c[16064]=G?340:386;c[16066]=G?46:204;c[16042]=W;c[16036]=G?238:268;c[16048]=G?174:150;c[16046]=G?94:280;c[16040]=G?50:160;c[16038]=G?384:198;c[16044]=G?4:16;c[16056]=G?4:40;c[16054]=G?56:34;c[16050]=G?6:8;c[16052]=G?50:22;c[16032]=G?42:66;c[16078]=G?32:22;c[16076]=G?64:86;c[16060]=G?74:62;c[16058]=G?36:58;c[16034]=G?30:24;c[16068]=G?30:10;c[16072]=G?36:2;c[16070]=G?96:68;ap(W|0,82);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[16064]|0,477872);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[119468]|0;if((W|0)==0){j=234;break}else{ci=W;j=235;break};case 234:c[119468]=19832;ci=19832;j=235;break;case 235:W=c[119469]|0;if((W|0)==0){j=236;break}else{cj=W;j=237;break};case 236:c[119469]=26968;cj=26968;j=237;break;case 237:aN(8,540396,64,26512,(H=i,i=i+16|0,c[H>>2]=ci,c[H+8>>2]=cj,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[119470]|0;ck=4096;cl=478464;cm=(W|0)==0?26200:W;j=238;break;case 238:cn=ck-1|0;if((cn|0)==0){j=240;break}else{j=239;break};case 239:W=a[cm]|0;a[cl]=W;if(W<<24>>24==0){j=242;break}else{ck=cn;cl=cl+1|0;cm=cm+1|0;j=238;break};case 240:a[cl]=0;if((a[cm]|0)==0){j=242;break}else{co=cm;j=241;break};case 241:W=co+1|0;if((a[W]|0)==0){j=242;break}else{co=W;j=241;break};case 242:a[477948]=a[477885]&1;cp=0;j=243;break;case 243:if(cp>>>0<2){j=244;break}else{j=245;break};case 244:cq=c[10312+(cp<<2)>>2]|0;W=aJ(2,297724,c[cq+28>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=252;break}else{cp=cp+1|0;j=243;break};case 245:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,26264,(H=i,i=i+8|0,c[H>>2]=297724,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=a[383584]|0;if((W&1)==0){cr=W;j=247;break}else{j=246;break};case 246:W=c[135158]|0;aN(6,25936,29,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cr=a[383584]|0;j=247;break;case 247:if((cr&1)==0){cs=cr;j=249;break}else{j=248;break};case 248:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,28224,(H=i,i=i+8|0,c[H>>2]=49064,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cs=a[383584]|0;j=249;break;case 249:if((cs&1)==0){j=251;break}else{j=250;break};case 250:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,28224,(H=i,i=i+8|0,c[H>>2]=44656,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=251;break;case 251:ap(68,25592);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 252:c[136862]=cq;W=aJ(2,281176,36208)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=258;break}else{j=253;break};case 253:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,27416,(H=i,i=i+8|0,c[H>>2]=281176,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=a[383584]|0;if((W&1)==0){ct=W;j=255;break}else{j=254;break};case 254:W=c[135158]|0;aN(6,27048,29,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ct=a[383584]|0;j=255;break;case 255:if((ct&1)==0){j=257;break}else{j=256;break};case 256:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,28224,(H=i,i=i+8|0,c[H>>2]=36208,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=257;break;case 257:ap(68,26656);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 258:c[136863]=72;W=aJ(2,306016,51656)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=264;break}else{j=259;break};case 259:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,29496,(H=i,i=i+8|0,c[H>>2]=306016,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=a[383584]|0;if((W&1)==0){cu=W;j=261;break}else{j=260;break};case 260:W=c[135158]|0;aN(6,28944,29,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cu=a[383584]|0;j=261;break;case 261:if((cu&1)==0){j=263;break}else{j=262;break};case 262:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,28224,(H=i,i=i+8|0,c[H>>2]=51656,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=263;break;case 263:ap(68,27792);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 264:c[136864]=6128;W=a[383584]|0;if((W&1)==0){cv=W;j=266;break}else{j=265;break};case 265:W=c[135158]|0;G=(W|0)!=0?W:c[t>>2]|0;W=aM(c[16080]|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ax(52,G|0,51232,(H=i,i=i+8|0,c[H>>2]=W,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cv=a[383584]|0;j=266;break;case 266:if((cv&1)==0){j=268;break}else{j=267;break};case 267:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,51120,(H=i,i=i+8|0,c[H>>2]=1,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=268;break;case 268:W=aM(c[16080]|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==1){j=270;break}else{j=269;break};case 269:W=c[135158]|0;aN(6,50680,117,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=270;break;case 270:aP(c[16062]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cw=(a[541709]&1)==0;W=a[541708]&1;a[540334]=cw?W^1:0;if(W<<24>>24==0){j=273;break}else{j=271;break};case 271:if(cw){j=272;break}else{j=369;break};case 272:W=as(204,c[96930]|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(W){j=369;break}else{j=493;break};case 273:if(cw){j=274;break}else{j=369;break};case 274:aP(10);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=as(204,c[96930]|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(W){j=275;break}else{j=493;break};case 275:cx=A|0;cy=B|0;cz=C|0;if((a[379457]&1)==0){j=289;break}else{j=276;break};case 276:aq(166,cx|0,445074);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aO(76,cy|0,445074,4096);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cA=ax(44,cx|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cA|0)==0){j=289;break}else{j=277;break};case 277:cB=cA+4|0;cC=cA|0;if((c[cB>>2]|0)==0){j=278;break}else{cD=0;cE=0;j=279;break};case 278:cF=c[cC>>2]|0;cG=0;j=287;break;case 279:cH=c[(c[cC>>2]|0)+(cD<<3)>>2]|0;aO(76,cz|0,cH|0,4096);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=as(40,cy|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=ax(28,cz|0,cy|0,W|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((G|0)==0){j=280;break}else{cI=cE;j=284;break};case 280:G=as(40,cH|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cJ=cH+G|0;j=281;break;case 281:if(cJ>>>0>cH>>>0){j=282;break}else{j=283;break};case 282:G=cJ-1|0;if(((a[G]|0)-48|0)>>>0<10){cJ=G;j=281;break}else{j=283;break};case 283:G=ax(14,cJ|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cI=G>>>0>cE>>>0?G:cE;j=284;break;case 284:G=cD+1|0;cK=c[cB>>2]|0;if(G>>>0<cK>>>0){cD=G;cE=cI;j=279;break}else{j=285;break};case 285:G=c[cC>>2]|0;if((cK|0)==0){cF=G;cG=cI;j=287;break}else{cL=0;cM=G;j=286;break};case 286:ap(138,c[cM+(cL<<3)>>2]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=cL+1|0;W=c[cC>>2]|0;if(G>>>0<(c[cB>>2]|0)>>>0){cL=G;cM=W;j=286;break}else{cF=W;cG=cI;j=287;break};case 287:ap(138,cF|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(138,cA|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[119462]=cG;if((a[383584]&1)==0){j=289;break}else{j=288;break};case 288:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,51432,(H=i,i=i+8|0,c[H>>2]=cG,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=289;break;case 289:if((a[540332]&1)==0){j=290;break}else{j=323;break};case 290:switch(c[96930]|0){case 0:{j=291;break};case 1:{j=299;break};case 2:case 3:{j=307;break};case 4:{j=315;break};default:{j=325;break}}break;case 291:cN=as(c[16070]|0,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cO=as(c[16072]|0,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cN|0)==0|(cO|0)==0){j=295;break}else{j=292;break};case 292:c[v>>2]=0;cP=aJ(12,424594,v|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cQ=c[v>>2]|0;if((cP|0)<1|(cP|0)>(cN|0)){j=294;break}else{j=293;break};case 293:s1(cO|0,cQ|0,cP)|0;j=294;break;case 294:ap(138,cQ|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=295;break;case 295:cR=as(c[16070]|0,1)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cS=as(c[16072]|0,1)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cR|0)==0|(cS|0)==0){j=325;break}else{j=296;break};case 296:c[u>>2]=0;cT=aJ(12,428690,u|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cU=c[u>>2]|0;if((cT|0)<1|(cT|0)>(cR|0)){j=298;break}else{j=297;break};case 297:s1(cS|0,cU|0,cT)|0;j=298;break;case 298:ap(138,cU|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=325;break;case 299:cV=as(c[16070]|0,1280)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cW=as(c[16072]|0,1280)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cV|0)==0|(cW|0)==0){j=303;break}else{j=300;break};case 300:c[s>>2]=0;cX=aJ(12,424594,s|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cY=c[s>>2]|0;if((cX|0)<1|(cX|0)>(cV|0)){j=302;break}else{j=301;break};case 301:s1(cW|0,cY|0,cX)|0;j=302;break;case 302:ap(138,cY|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=303;break;case 303:cZ=as(c[16070]|0,1537)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c_=as(c[16072]|0,1537)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cZ|0)==0|(c_|0)==0){j=325;break}else{j=304;break};case 304:c[r>>2]=0;c$=aJ(12,428690,r|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c0=c[r>>2]|0;if((c$|0)<1|(c$|0)>(cZ|0)){j=306;break}else{j=305;break};case 305:s1(c_|0,c0|0,c$)|0;j=306;break;case 306:ap(138,c0|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=325;break;case 307:c1=as(c[16070]|0,256)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c2=as(c[16072]|0,256)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((c1|0)==0|(c2|0)==0){j=311;break}else{j=308;break};case 308:c[q>>2]=0;c3=aJ(12,424594,q|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c4=c[q>>2]|0;if((c3|0)<1|(c3|0)>(c1|0)){j=310;break}else{j=309;break};case 309:s1(c2|0,c4|0,c3)|0;j=310;break;case 310:ap(138,c4|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=311;break;case 311:c5=as(c[16070]|0,512)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c6=as(c[16072]|0,512)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((c5|0)==0|(c6|0)==0){j=325;break}else{j=312;break};case 312:c[p>>2]=0;c7=aJ(12,432786,p|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c8=c[p>>2]|0;if((c7|0)<1|(c7|0)>(c5|0)){j=314;break}else{j=313;break};case 313:s1(c6|0,c8|0,c7)|0;j=314;break;case 314:ap(138,c8|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=325;break;case 315:c9=as(c[16070]|0,768)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;da=as(c[16072]|0,768)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((c9|0)==0|(da|0)==0){j=319;break}else{j=316;break};case 316:c[o>>2]=0;db=aJ(12,436882,o|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dc=c[o>>2]|0;if((db|0)<1|(db|0)>(c9|0)){j=318;break}else{j=317;break};case 317:s1(da|0,dc|0,db)|0;j=318;break;case 318:ap(138,dc|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=319;break;case 319:dd=as(c[16070]|0,1024)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;de=as(c[16072]|0,1024)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dd|0)==0|(de|0)==0){j=325;break}else{j=320;break};case 320:c[n>>2]=0;df=aJ(12,440978,n|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dg=c[n>>2]|0;if((df|0)<1|(df|0)>(dd|0)){j=322;break}else{j=321;break};case 321:s1(de|0,dg|0,df)|0;j=322;break;case 322:ap(138,dg|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=325;break;case 323:if((a[383584]&1)==0){j=325;break}else{j=324;break};case 324:W=c[135158]|0;aN(6,23912,31,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=325;break;case 325:if((a[379459]&1)==0){j=338;break}else{j=326;break};case 326:aO(84,cx|0,445074,20032);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dh=aJ(24,cx|0,42504)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dh|0)==0){j=338;break}else{j=327;break};case 327:as(154,dh|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[383584]&1)==0){j=329;break}else{j=328;break};case 328:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,51760,(H=i,i=i+8|0,c[H>>2]=cx,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=329;break;case 329:W=as(148,cx|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aN(8,cy|0,4096,51600,(H=i,i=i+16|0,c[H>>2]=cx,c[H+8>>2]=W?19792:19720,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;di=c[133027]|0;dj=di+4|0;if((c[dj>>2]|0)>>>0<(c[di+8>>2]|0)>>>0){j=330;break}else{j=336;break};case 330:dk=as(44,12)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dk|0)==0){j=333;break}else{j=331;break};case 331:if((c[dk-4>>2]&3|0)==0){j=333;break}else{j=332;break};case 332:s_(dk|0,0,12);j=333;break;case 333:W=dk;c[dk+4>>2]=1;c[dk>>2]=180;G=as(118,cy|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dl=c[dj>>2]|0;c[dk+8>>2]=G;dm=di|0;c[(c[dm>>2]|0)+(dl<<2)>>2]=W;W=c[dj>>2]|0;c[dj>>2]=W+1;if(W>>>0>1){dn=W;j=334;break}else{j=336;break};case 334:dp=dn>>>1;W=c[dm>>2]|0;dq=W+(dp<<2)|0;dr=c[dq>>2]|0;ds=c[W+(dn<<2)>>2]|0;if((c[ds+4>>2]|0)>>>0>(c[dr+4>>2]|0)>>>0){j=335;break}else{j=336;break};case 335:c[dq>>2]=ds;c[(c[dm>>2]|0)+(dn<<2)>>2]=dr;if(dn>>>0>3){dn=dp;j=334;break}else{j=336;break};case 336:if((a[383584]&1)==0){j=338;break}else{j=337;break};case 337:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,48248,(H=i,i=i+8|0,c[H>>2]=cy,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=338;break;case 338:if((a[540330]&1)==0){j=351;break}else{j=339;break};case 339:W=aJ(76,536233,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[133033]=W;if((W|0)==0){j=340;break}else{j=341;break};case 340:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,10920,(H=i,i=i+8|0,c[H>>2]=536233,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(202,52744);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 341:a[536232]=1;dt=c[133027]|0;du=dt+4|0;if((c[du>>2]|0)>>>0<(c[dt+8>>2]|0)>>>0){j=342;break}else{j=348;break};case 342:dv=as(44,12)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dv|0)==0){j=345;break}else{j=343;break};case 343:if((c[dv-4>>2]&3|0)==0){j=345;break}else{j=344;break};case 344:s_(dv|0,0,12);j=345;break;case 345:W=dv;c[dv+4>>2]=2;c[dv>>2]=180;dl=as(118,52632)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;G=c[du>>2]|0;c[dv+8>>2]=dl;dw=dt|0;c[(c[dw>>2]|0)+(G<<2)>>2]=W;W=c[du>>2]|0;c[du>>2]=W+1;if(W>>>0>1){dx=W;j=346;break}else{j=348;break};case 346:dy=dx>>>1;W=c[dw>>2]|0;dz=W+(dy<<2)|0;dA=c[dz>>2]|0;dB=c[W+(dx<<2)>>2]|0;if((c[dB+4>>2]|0)>>>0>(c[dA+4>>2]|0)>>>0){j=347;break}else{j=348;break};case 347:c[dz>>2]=dB;c[(c[dw>>2]|0)+(dx<<2)>>2]=dA;if(dx>>>0>3){dx=dy;j=346;break}else{j=348;break};case 348:if((a[383584]&1)==0){j=350;break}else{j=349;break};case 349:W=c[135158]|0;aN(6,52040,36,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=350;break;case 350:c[94859]=1;j=369;break;case 351:if((a[540329]&1)==0){j=369;break}else{j=352;break};case 352:aN(8,cx|0,4096,15088,(H=i,i=i+8|0,c[H>>2]=536233,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=aJ(76,536233,1)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[133033]=W;dC=c[133027]|0;dD=dC+4|0;dE=c[dD>>2]|0;if(dE>>>0>1){j=353;break}else{j=357;break};case 353:dF=dC|0;dG=1;dH=dE;j=354;break;case 354:dI=c[(c[dF>>2]|0)+(dG<<2)>>2]|0;if((dI|0)==0){dJ=dH;j=356;break}else{j=355;break};case 355:ap(138,c[dI+8>>2]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(138,c[(c[dF>>2]|0)+(dG<<2)>>2]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[(c[dF>>2]|0)+(dG<<2)>>2]=0;dJ=c[dD>>2]|0;j=356;break;case 356:W=dG+1|0;if(W>>>0<dJ>>>0){dG=W;dH=dJ;j=354;break}else{j=357;break};case 357:c[dD>>2]=1;W=dC+12|0;ap(138,c[W>>2]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[W>>2]=0;dK=c[133027]|0;dL=dK+4|0;if((c[dL>>2]|0)>>>0<(c[dK+8>>2]|0)>>>0){j=358;break}else{j=364;break};case 358:dM=(c[133033]|0)!=0?cx:14896;dN=as(44,12)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dN|0)==0){j=361;break}else{j=359;break};case 359:if((c[dN-4>>2]&3|0)==0){j=361;break}else{j=360;break};case 360:s_(dN|0,0,12);j=361;break;case 361:W=dN;c[dN+4>>2]=1;c[dN>>2]=180;G=as(118,dM|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dl=c[dL>>2]|0;c[dN+8>>2]=G;dO=dK|0;c[(c[dO>>2]|0)+(dl<<2)>>2]=W;W=c[dL>>2]|0;c[dL>>2]=W+1;if(W>>>0>1){dP=W;j=362;break}else{j=364;break};case 362:dQ=dP>>>1;W=c[dO>>2]|0;dR=W+(dQ<<2)|0;dS=c[dR>>2]|0;dT=c[W+(dP<<2)>>2]|0;if((c[dT+4>>2]|0)>>>0>(c[dS+4>>2]|0)>>>0){j=363;break}else{j=364;break};case 363:c[dR>>2]=dT;c[(c[dO>>2]|0)+(dP<<2)>>2]=dS;if(dP>>>0>3){dP=dQ;j=362;break}else{j=364;break};case 364:if((c[133033]|0)==0){j=368;break}else{j=365;break};case 365:if((a[383584]&1)==0){j=367;break}else{j=366;break};case 366:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,14744,(H=i,i=i+8|0,c[H>>2]=536233,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=367;break;case 367:c[94859]=1;j=369;break;case 368:W=c[135158]|0;aN(6,14232,51,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=369;break;case 369:ap(c[16036]|0,8);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[16048]|0,98);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[16046]|0,62);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[16038]|0,2);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[16040]|0,36);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[16066]|0,477888);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dU=+aL(2);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dV=dU*1.0e3;W=+V(dV)>=1.0?dV>0.0?(al(+U(dV/4294967296.0),4294967295.0)|0)>>>0:~~+af((dV- +(~~dV>>>0))/4294967296.0)>>>0:0;dl=477864;c[dl>>2]=~~dV>>>0;c[dl+4>>2]=W;dV=+aG(2,+(1.0e6/(+h[59739]*+g[94861])));if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=+V(dV)>=1.0?dV>0.0?(al(+U(dV/4294967296.0),4294967295.0)|0)>>>0:~~+af((dV- +(~~dV>>>0))/4294967296.0)>>>0:0;dl=477856;c[dl>>2]=~~dV>>>0;c[dl+4>>2]=W;aP(38);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(48);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(26);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[540334]&1)==0){j=370;break}else{j=371;break};case 370:a[540334]=0;j=372;break;case 371:W=a[540333]&1;a[540334]=W^1;if(W<<24>>24==0){j=374;break}else{j=372;break};case 372:if((a[383584]&1)==0){j=374;break}else{j=373;break};case 373:W=c[135158]|0;aN(6,23744,35,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=374;break;case 374:if((c[133033]|0)!=0|(a[363044]|0)==0){j=492;break}else{j=375;break};case 375:aP(c[16078]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dW=as(44,16)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dW|0)==0){dX=0;j=491;break}else{j=376;break};case 376:if((c[dW-4>>2]&3|0)==0){j=378;break}else{j=377;break};case 377:s_(dW|0,0,16);j=378;break;case 378:dY=dW;dZ=dW+12|0;c[dZ>>2]=1;d_=as(44,12)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((d_|0)==0){j=382;break}else{j=379;break};case 379:if((c[d_-4>>2]&3|0)==0){j=380;break}else{j=381;break};case 380:W=dW;c[W>>2]=d_;d$=W;j=383;break;case 381:s_(d_|0,0,12);W=dW;c[W>>2]=d_;d$=W;j=383;break;case 382:c[dW>>2]=0;c[dZ>>2]=0;j=484;break;case 383:d0=as(158,363044)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((d0|0)==0){j=384;break}else{j=385;break};case 384:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,21160,(H=i,i=i+8|0,c[H>>2]=363044,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=484;break;case 385:d1=d0|0;W=c[d1>>2]|0;if((W|0)==0){j=386;break}else{d2=W;j=387;break};case 386:ap(158,dY|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=486;break;case 387:if((c[d2+20>>2]|0)==0){j=388;break}else{j=389;break};case 388:W=aJ(104,c[d2>>2]|0,50160)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=390;break}else{j=389;break};case 389:W=c[d2+16>>2]|0;if((W|0)==0){j=485;break}else{d2=W;j=387;break};case 390:d3=c[d2+12>>2]|0;if((d3|0)==0){j=485;break}else{j=391;break};case 391:if((a[540468]|0)==0){d4=d3;j=392;break}else{d5=d3;j=398;break};case 392:if((c[d4+20>>2]|0)==0){j=393;break}else{j=397;break};case 393:W=aJ(104,c[d4>>2]|0,37336)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=394;break}else{j=397;break};case 394:d6=d4+8|0;j=395;break;case 395:d7=c[d6>>2]|0;if((d7|0)==0){j=397;break}else{j=396;break};case 396:W=aJ(104,29304,c[d7>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=397;break}else{d6=d7+8|0;j=395;break};case 397:W=c[d4+16>>2]|0;if((W|0)==0){j=485;break}else{d4=W;j=392;break};case 398:if((c[d5+20>>2]|0)==0){j=399;break}else{j=405;break};case 399:W=aJ(104,c[d5>>2]|0,37336)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=400;break}else{j=405;break};case 400:d8=d5+8|0;j=401;break;case 401:d9=c[d8>>2]|0;if((d9|0)==0){j=405;break}else{j=402;break};case 402:W=aJ(104,29304,c[d9>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=403;break}else{d8=d9+8|0;j=401;break};case 403:ea=c[d9+4>>2]|0;if((ea|0)==0){j=405;break}else{j=404;break};case 404:W=aJ(104,ea|0,540468)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=406;break}else{j=405;break};case 405:W=c[d5+16>>2]|0;if((W|0)==0){j=485;break}else{d5=W;j=398;break};case 406:W=c[d5+12>>2]|0;eb=dW+8|0;if((W|0)==0){j=465;break}else{ec=W;j=407;break};case 407:ed=c[ec>>2]|0;W=aJ(104,ed|0,45120)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=408;break}else{j=411;break};case 408:ee=c[ec+4>>2]|0;if((ee|0)==0){j=463;break}else{j=409;break};case 409:if((a[383584]&1)==0){j=463;break}else{j=410;break};case 410:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,43720,(H=i,i=i+8|0,c[H>>2]=ee,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=463;break;case 411:W=aJ(104,ed|0,42448)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=412;break}else{j=463;break};case 412:ef=c[eb>>2]|0;if((ef|0)==(c[dZ>>2]|0)){j=414;break}else{j=413;break};case 413:eg=ef;eh=c[d$>>2]|0;j=416;break;case 414:c[dZ>>2]=ef<<1;W=aJ(88,c[d$>>2]|0,ef*24|0|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ei=W;c[d$>>2]=ei;if((W|0)==0){j=464;break}else{j=415;break};case 415:eg=c[eb>>2]|0;eh=ei;j=416;break;case 416:ej=eh+(eg*12|0)|0;ek=c[ec+12>>2]|0;if((ek|0)==0){j=463;break}else{j=417;break};case 417:s_(ej|0,0,12);el=ej|0;em=eh+(eg*12|0)+8|0;en=ek;eo=1;ep=0;eq=0;j=418;break;case 418:er=c[en>>2]|0;W=aJ(104,er|0,41384)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=419;break}else{j=420;break};case 419:c[el>>2]=c[en+4>>2];es=eo;et=ep;eu=eq;j=461;break;case 420:W=aJ(104,er|0,40464)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=421;break}else{es=eo;et=ep;eu=eq;j=461;break};case 421:if(eo){ev=ep;j=440;break}else{j=422;break};case 422:ew=(eq|0)!=0;if(ew){j=423;break}else{ex=2;j=424;break};case 423:W=as(40,eq|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ex=W+2|0;j=424;break;case 424:ey=aJ(88,eq|0,ex|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((ey|0)==0){j=425;break}else{j=426;break};case 425:c[em>>2]=0;j=463;break;case 426:if(ew){j=427;break}else{j=434;break};case 427:ez=as(40,ey|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;eA=ez>>>0>ex>>>0?0:ex-ez|0;if((eA|0)==0){eB=39408;j=431;break}else{j=428;break};case 428:eC=ey+ez|0;if((eA|0)==1){eD=39408;eE=eC;j=430;break}else{j=429;break};case 429:eF=ey+(ez+1)|0;a[eC]=43;if((eA|0)==2){eD=39409;eE=eF;j=430;break}else{j=490;break};case 430:a[eE]=0;eB=eD;j=431;break;case 431:if((a[eB]|0)==0){j=433;break}else{eG=eB;j=432;break};case 432:W=eG+1|0;if((a[W]|0)==0){j=433;break}else{eG=W;j=432;break};case 433:c[em>>2]=ey;ev=ey;j=440;break;case 434:if((ex|0)==1){eH=39408;eI=ey;j=436;break}else if((ex|0)==0){eJ=39408;j=437;break}else{j=435;break};case 435:eK=ey+1|0;a[ey]=43;if((ex|0)==2){eH=39409;eI=eK;j=436;break}else{j=489;break};case 436:a[eI]=0;eJ=eH;j=437;break;case 437:if((a[eJ]|0)==0){j=439;break}else{eL=eJ;j=438;break};case 438:W=eL+1|0;if((a[W]|0)==0){j=439;break}else{eL=W;j=438;break};case 439:c[em>>2]=ey;ev=ey;j=440;break;case 440:eM=c[en+4>>2]|0;if((eM|0)==0){j=463;break}else{j=441;break};case 441:eN=(ev|0)!=0;if(eN){j=442;break}else{eO=1;j=443;break};case 442:W=as(40,ev|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;eO=W+1|0;j=443;break;case 443:W=as(40,eM|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;eP=W+eO|0;eQ=aJ(88,ev|0,eP|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((eQ|0)==0){j=444;break}else{j=445;break};case 444:c[em>>2]=0;j=463;break;case 445:if(eN){j=446;break}else{j=454;break};case 446:eR=as(40,eQ|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;eS=eR>>>0>eP>>>0?0:eP-eR|0;if((eS|0)==0){eT=eM;j=451;break}else{j=447;break};case 447:eU=eS;eV=eQ+eR|0;eW=eM;j=448;break;case 448:eX=eU-1|0;if((eX|0)==0){j=450;break}else{j=449;break};case 449:W=a[eW]|0;a[eV]=W;if(W<<24>>24==0){j=453;break}else{eU=eX;eV=eV+1|0;eW=eW+1|0;j=448;break};case 450:a[eV]=0;eT=eW;j=451;break;case 451:if((a[eT]|0)==0){j=453;break}else{eY=eT;j=452;break};case 452:W=eY+1|0;if((a[W]|0)==0){j=453;break}else{eY=W;j=452;break};case 453:c[em>>2]=eQ;es=0;et=eQ;eu=eQ;j=461;break;case 454:if((eP|0)==0){eZ=eM;j=458;break}else{e_=eP;e$=eQ;e0=eM;j=455;break};case 455:e1=e_-1|0;if((e1|0)==0){j=457;break}else{j=456;break};case 456:W=a[e0]|0;a[e$]=W;if(W<<24>>24==0){j=460;break}else{e_=e1;e$=e$+1|0;e0=e0+1|0;j=455;break};case 457:a[e$]=0;eZ=e0;j=458;break;case 458:if((a[eZ]|0)==0){j=460;break}else{e2=eZ;j=459;break};case 459:W=e2+1|0;if((a[W]|0)==0){j=460;break}else{e2=W;j=459;break};case 460:c[em>>2]=eQ;es=0;et=eQ;eu=eQ;j=461;break;case 461:W=c[en+16>>2]|0;if((W|0)==0){j=462;break}else{en=W;eo=es;ep=et;eq=eu;j=418;break};case 462:c[eb>>2]=(c[eb>>2]|0)+1;j=463;break;case 463:W=c[ec+16>>2]|0;if((W|0)==0){j=465;break}else{ec=W;j=407;break};case 464:W=c[135158]|0;aN(6,24824,68,1,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=485;break;case 465:if((c[eb>>2]|0)==0){j=466;break}else{j=467;break};case 466:W=c[135158]|0;ax(52,((W|0)!=0?W:c[t>>2]|0)|0,21488,(H=i,i=i+8|0,c[H>>2]=363044,H)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=H;W=c[135158]|0;as(114,((W|0)!=0?W:c[t>>2]|0)|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=485;break;case 467:if((a[367140]|0)==0){j=481;break}else{j=468;break};case 468:e3=aJ(18,367140,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((e3|0)==0){j=481;break}else{j=469;break};case 469:e4=e3+4|0;j=470;break;case 470:e5=c[e4>>2]|0;if((e5|0)==0){j=472;break}else{j=471;break};case 471:W=aJ(104,540468,c[e5+4>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=473;break}else{e4=e5+12|0;j=470;break};case 472:ap(114,e3|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=481;break;case 473:e6=as(118,c[e5+8>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=ax(74,e6|0,27664,m|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=477;break}else{e7=W;j=474;break};case 474:e8=ax(14,e7|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(e8>>>0<(c[eb>>2]|0)>>>0){j=475;break}else{j=476;break};case 475:a[(c[d$>>2]|0)+(e8*12|0)+4|0]=1;j=476;break;case 476:W=ax(74,0,27664,m|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((W|0)==0){j=477;break}else{e7=W;j=474;break};case 477:ap(138,e6|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(114,e3|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(c[16078]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=c[eb>>2]|0;if((W|0)==0){j=481;break}else{e9=0;fa=0;fb=W;j=478;break};case 478:fc=c[d$>>2]|0;if((a[fc+(fa*12|0)+4|0]&1)==0){fd=e9;fe=fb;j=480;break}else{j=479;break};case 479:W=e9+1|0;aO(c[16076]|0,e9|0,1,c[fc+(fa*12|0)+8>>2]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fd=W;fe=c[eb>>2]|0;j=480;break;case 480:W=fa+1|0;if(W>>>0<fe>>>0){e9=fd;fa=W;fb=fe;j=478;break}else{j=481;break};case 481:ff=c[d1>>2]|0;if((ff|0)==0){j=483;break}else{j=482;break};case 482:ap(170,ff|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=483;break;case 483:ap(138,d0|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dX=dY;j=491;break;case 484:ap(158,dY|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dX=0;j=491;break;case 485:ap(158,dY|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=486;break;case 486:fg=c[d1>>2]|0;if((fg|0)==0){j=488;break}else{j=487;break};case 487:ap(170,fg|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=488;break;case 488:ap(138,d0|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dX=0;j=491;break;case 489:a[eK]=0;j=439;break;case 490:a[eF]=0;j=433;break;case 491:c[135134]=dX;j=492;break;case 492:a[540637]=0;a[540636]=1;I=0;j=509;break;case 493:aP(6);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fh=c[120657]|0;if((fh|0)==0){j=496;break}else{j=494;break};case 494:if((a[547473]&1)==0){j=495;break}else{j=496;break};case 495:aP(fh|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=496;break;case 496:aP(44);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[547475]&1)==0){j=498;break}else{j=497;break};case 497:c[136866]=0;j=498;break;case 498:if((a[547476]&1)==0){j=500;break}else{j=499;break};case 499:c[136865]=0;j=500;break;case 500:if((a[547477]&1)==0){j=502;break}else{j=501;break};case 501:c[136867]=0;j=502;break;case 502:a[547475]=0;a[547476]=0;a[547477]=0;aP(c[16034]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aP(c[16074]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fi=c[120666]|0;if((fi|0)==0){j=508;break}else{j=503;break};case 503:fj=fi+4104|0;if((c[fj>>2]|0)==0){j=504;break}else{j=505;break};case 504:fk=fi|0;j=507;break;case 505:fl=fi|0;fm=0;j=506;break;case 506:W=c[fi+4100>>2]|0;aO(94,c[fl>>2]|0,c[W+(fm<<4)+4>>2]|0,c[(c[c[W+(fm<<4)+8>>2]>>2]|0)+(c[W+(fm<<4)+12>>2]<<3)>>2]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;W=fm+1|0;if(W>>>0<(c[fj>>2]|0)>>>0){fm=W;j=506;break}else{fk=fl;j=507;break};case 507:aJ(78,c[fk>>2]|0,fi+4|0)|0;if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(164,c[120666]|0);if((x|0)!=0&(y|0)!=0){k=s0(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=508;break;case 508:s_(477872,0,4800);a[540636]=0;I=1;j=509;break;case 509:i=f;return I|0;case-1:if((k|0)==1){F=y;j=510}x=y=0;break}return 0}function g2(){var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a8=0,a9=0,ba=0,bb=0,bc=0;d=i;i=i+9216|0;e=d|0;f=d+256|0;j=d+768|0;k=d+4864|0;l=d+8960|0;a[547479]=0;m=308016;if((c[77003]|0)==0&((c[m>>2]|0)==65535&(c[m+4>>2]|0)==0)&(c[77008]|0)==-1){n=774}else{m=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,48)|0;o=547640;p=(c[o>>2]&0|m&1|0)==0&(c[o+4>>2]&65536|0)==0;a[547479]=p&1;if(p){q=0}else{n=774}}do{if((n|0)==774){p=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,43)|0;o=547640;if((c[o>>2]&0|p&1|0)==0&(c[o+4>>2]&2048|0)==0){q=0;break}if((a[547704]&1)!=0){q=1;break}gM();q=1}}while(0);a[547704]=q;q=a[383585]|0;if((q&1)==0){r=q}else{do{if((a[547479]&1)==0){q=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,45)|0;o=547640;if((c[o>>2]&0|q&1|0)==0&(c[o+4>>2]&8192|0)==0){s=0;break}if((a[547768]&1)!=0){s=1;break}o=a[482713]&1;a[482713]=o^1;q=o<<24>>24==0?11320:11184;o=c[133027]|0;p=o+4|0;m=c[p>>2]|0;if(m>>>0>1){u=o|0;v=1;w=m;while(1){m=c[(c[u>>2]|0)+(v<<2)>>2]|0;if((m|0)==0){x=w}else{sS(c[m+8>>2]|0);sS(c[(c[u>>2]|0)+(v<<2)>>2]|0);c[(c[u>>2]|0)+(v<<2)>>2]=0;x=c[p>>2]|0}m=v+1|0;if(m>>>0<x>>>0){v=m;w=x}else{break}}}c[p>>2]=1;w=o+12|0;sS(c[w>>2]|0);c[w>>2]=0;w=c[133027]|0;v=w+4|0;L1091:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){u=sR(12)|0;do{if((u|0)!=0){if((c[u-4>>2]&3|0)==0){break}s_(u|0,0,12)}}while(0);c[u+4>>2]=1;c[u>>2]=180;m=dT(q|0)|0;y=c[v>>2]|0;c[u+8>>2]=m;m=w|0;c[(c[m>>2]|0)+(y<<2)>>2]=u;y=c[v>>2]|0;c[v>>2]=y+1;if(y>>>0>1){z=y}else{break}while(1){y=z>>>1;A=c[m>>2]|0;B=A+(y<<2)|0;C=c[B>>2]|0;D=c[A+(z<<2)>>2]|0;if((c[D+4>>2]|0)>>>0<=(c[C+4>>2]|0)>>>0){break L1091}c[B>>2]=D;c[(c[m>>2]|0)+(z<<2)>>2]=C;if(z>>>0>3){z=y}else{break}}}}while(0);v=c[136865]|0;do{if((v|0)!=0){w=c[136862]|0;if((a[482713]&1)!=0){o=c[w+8>>2]|0;f2[o&255](v)|0;break}if(f2[c[w+12>>2]&255](v)|0){break}w=c[135158]|0;o=(w|0)!=0?w:c[t>>2]|0;be(11064,45,1,o|0)|0;o=c[135158]|0;w=(o|0)!=0?o:c[t>>2]|0;a7(w|0)|0;a[383585]=0}}while(0);if((a[383584]&1)==0){s=1;break}v=c[135158]|0;w=(v|0)!=0?v:c[t>>2]|0;eQ(w|0,48248,(E=i,i=i+8|0,c[E>>2]=q,E)|0)|0;i=E;w=c[135158]|0;v=(w|0)!=0?w:c[t>>2]|0;a7(v|0)|0;s=1}else{s=0}}while(0);a[547768]=s;r=a[383585]|0}s=l|0;do{if((r&1)!=0){l=a[547479]|0;if((l&1)==0){z=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,49)|0;x=547640;F=(c[x>>2]&0|z&1|0)!=0|(c[x+4>>2]&131072|0)!=0;G=a[547479]|0}else{F=0;G=l}if((G&1)==0){l=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,50)|0;x=547640;H=(c[x>>2]&0|l&1|0)!=0|(c[x+4>>2]&262144|0)!=0}else{H=0}if(!(F|H)){break}I=F?.5:0.0;if(H){J=I+-.5}else{J=I}I=J+ +g[120691];g[120691]=I;do{if(I>12.0){g[120691]=12.0;L=12.0}else{if(I>=-80.0){L=I;break}g[120691]=-80.0;L=-80.0}}while(0);I=L;b5(s|0,256,11448,(E=i,i=i+8|0,h[E>>3]=I,E)|0)|0;i=E;q=c[133027]|0;x=q+4|0;l=c[x>>2]|0;if(l>>>0>1){z=q|0;v=1;w=l;while(1){l=c[(c[z>>2]|0)+(v<<2)>>2]|0;if((l|0)==0){M=w}else{sS(c[l+8>>2]|0);sS(c[(c[z>>2]|0)+(v<<2)>>2]|0);c[(c[z>>2]|0)+(v<<2)>>2]=0;M=c[x>>2]|0}l=v+1|0;if(l>>>0<M>>>0){v=l;w=M}else{break}}}c[x>>2]=1;w=q+12|0;sS(c[w>>2]|0);c[w>>2]=0;w=c[133027]|0;v=w+4|0;L1136:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){z=sR(12)|0;do{if((z|0)!=0){if((c[z-4>>2]&3|0)==0){break}s_(z|0,0,12)}}while(0);c[z+4>>2]=1;c[z>>2]=180;l=dT(s|0)|0;o=c[v>>2]|0;c[z+8>>2]=l;l=w|0;c[(c[l>>2]|0)+(o<<2)>>2]=z;o=c[v>>2]|0;c[v>>2]=o+1;if(o>>>0>1){N=o}else{break}while(1){o=N>>>1;p=c[l>>2]|0;m=p+(o<<2)|0;u=c[m>>2]|0;y=c[p+(N<<2)>>2]|0;if((c[y+4>>2]|0)>>>0<=(c[u+4>>2]|0)>>>0){break L1136}c[m>>2]=y;c[(c[l>>2]|0)+(N<<2)>>2]=u;if(N>>>0>3){N=o}else{break}}}}while(0);if((a[383584]&1)!=0){v=c[135158]|0;w=(v|0)!=0?v:c[t>>2]|0;eQ(w|0,48248,(E=i,i=i+8|0,c[E>>2]=s,E)|0)|0;i=E;w=c[135158]|0;v=(w|0)!=0?w:c[t>>2]|0;a7(v|0)|0}g[120692]=+X(10.0,+(+g[120691]/20.0))}}while(0);c[135091]=(c[135091]|0)+1;a[540338]=(f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,8328,0,1,0,16)|0)<<16>>16!=0|0;a[540339]=(f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,8328,1,1,0,16)|0)<<16>>16!=0|0;a[540340]=(f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,8328,2,1,0,16)|0)<<16>>16!=0|0;a[540341]=(f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,8328,3,1,0,16)|0)<<16>>16!=0|0;a[540342]=(f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,8328,4,1,0,16)|0)<<16>>16!=0|0;a[540343]=(f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,8328,5,1,0,16)|0)<<16>>16!=0|0;a[540344]=(f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,8328,6,1,0,16)|0)<<16>>16!=0|0;a[540345]=(f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,8328,7,1,0,16)|0)<<16>>16!=0|0;do{if((a[547479]&1)==0){s=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,54)|0;N=547640;if((c[N>>2]&0|s&1|0)==0&(c[N+4>>2]&4194304|0)==0){O=0;break}N=c[(c[136864]|0)+28>>2]|0;if((N|0)==0){O=0;break}if((a[547784]&1)!=0){O=1;break}s=a[547792]&1;M=s^1;a[547792]=M;if((a[383584]&1)==0){P=N;Q=M}else{M=c[135158]|0;N=(M|0)!=0?M:c[t>>2]|0;M=s<<24>>24==0?23808:23576;eQ(N|0,11976,(E=i,i=i+8|0,c[E>>2]=M,E)|0)|0;i=E;M=c[135158]|0;N=(M|0)!=0?M:c[t>>2]|0;a7(N|0)|0;P=c[(c[136864]|0)+28>>2]|0;Q=a[547792]|0}f0[P&255](c[136867]|0,(Q&1)!=0);N=c[136914]|0;if((N|0)==0){O=1;break}M=c[N+32>>2]|0;if((M|0)==0){O=1;break}f0[M&255](c[136866]|0,(a[547792]&1)==0);O=1}else{O=0}}while(0);a[547784]=O;if((c[136908]|0)!=0){do{if((a[547479]&1)==0){O=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,51)|0;Q=547640;if((c[Q>>2]&0|O&1|0)==0&(c[Q+4>>2]&524288|0)==0){R=0;break}if((a[64120]&1)!=0){R=1;break}Q=c[136908]|0;O=Q+28|0;P=c[O>>2]|0;M=Q+20|0;c[M>>2]=P;N=c[Q+12>>2]|0;s=Q+16|0;c[s>>2]=N+(P*136|0);H=Q+4|0;F=c[(c[H>>2]|0)+4>>2]|0;G=Q|0;r=c[G>>2]|0;v=c[N+(P*136|0)+8>>2]|0;w=c[N+(P*136|0)+12>>2]|0;q=c[N+(P*136|0)+16>>2]|0;gn[F&31](r,v,w,q)|0;q=c[s>>2]|0;f4[c[(c[H>>2]|0)+12>>2]&7](c[G>>2]|0,+g[q+24>>2],+g[q+28>>2],+g[q+32>>2],+g[q+36>>2]);f0[c[(c[H>>2]|0)+16>>2]&255](c[G>>2]|0,(a[(c[s>>2]|0)+68|0]&1)!=0);a[Q+9|0]=1;c[O>>2]=(((c[M>>2]|0)+1|0)>>>0)%((c[Q+24>>2]|0)>>>0)|0;R=1}else{R=0}}while(0);a[64120]=R}if((a[547479]&1)==0){R=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,35)|0;Q=547640;S=((c[Q>>2]&0|R&1|0)!=0|(c[Q+4>>2]&8|0)!=0)&1}else{S=0}do{if((a[540335]&1)==0){if((a[547479]&1)!=0){T=0;break}Q=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,36)|0;R=547640;T=((c[R>>2]&0|Q&1|0)!=0|(c[R+4>>2]&16|0)!=0)&1}else{T=0}}while(0);R=T|S;if((a[379448]&1)==0){U=1}else{U=f2[c[(c[136863]|0)+16>>2]&255](c[136866]|0)|0}do{if(R<<24>>24==0|U^1){n=863}else{if((a[547744]&1)!=0){n=863;break}S=a[540335]&1;a[540335]=S^1;T=(a[383584]&1)!=0;if(S<<24>>24==0){if(T){S=c[135158]|0;Q=(S|0)!=0?S:c[t>>2]|0;be(12816,19,1,Q|0)|0;Q=c[135158]|0;S=(Q|0)!=0?Q:c[t>>2]|0;a7(S|0)|0}S=c[136865]|0;if((S|0)==0){break}Q=c[(c[136862]|0)+8>>2]|0;f2[Q&255](S)|0;break}if(T){T=c[135158]|0;S=(T|0)!=0?T:c[t>>2]|0;be(12608,21,1,S|0)|0;S=c[135158]|0;T=(S|0)!=0?S:c[t>>2]|0;a7(T|0)|0}T=c[136865]|0;if((T|0)==0){break}if((a[482713]&1)!=0){break}if(f2[c[(c[136862]|0)+12>>2]&255](T)|0){break}T=c[135158]|0;S=(T|0)!=0?T:c[t>>2]|0;be(12432,81,1,S|0)|0;S=c[135158]|0;T=(S|0)!=0?S:c[t>>2]|0;a7(T|0)|0;a[383585]=0}}while(0);do{if((n|0)==863){T=(a[8368]&1)==0;if(!U){if(T){break}if((a[383584]&1)!=0){S=c[135158]|0;Q=(S|0)!=0?S:c[t>>2]|0;be(12816,19,1,Q|0)|0;Q=c[135158]|0;S=(Q|0)!=0?Q:c[t>>2]|0;a7(S|0)|0}a[540335]=1;S=c[136865]|0;if((S|0)==0){break}Q=c[(c[136862]|0)+8>>2]|0;f2[Q&255](S)|0;break}if(!T){break}if((a[383584]&1)!=0){T=c[135158]|0;S=(T|0)!=0?T:c[t>>2]|0;be(12608,21,1,S|0)|0;S=c[135158]|0;T=(S|0)!=0?S:c[t>>2]|0;a7(T|0)|0}a[540335]=0;T=c[136865]|0;if((T|0)==0){break}if((a[482713]&1)!=0){break}if(f2[c[(c[136862]|0)+12>>2]&255](T)|0){break}T=c[135158]|0;S=(T|0)!=0?T:c[t>>2]|0;be(12432,81,1,S|0)|0;S=c[135158]|0;T=(S|0)!=0?S:c[t>>2]|0;a7(T|0)|0;a[383585]=0}}while(0);a[8368]=U&1;a[547744]=R;do{if((a[547479]&1)==0){R=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,36)|0;U=547640;if((c[U>>2]&0|R&1|0)==0&(c[U+4>>2]&16|0)==0){V=0;W=0;break}V=a[547752]&1^1;W=1}else{V=0;W=0}}while(0);a[540336]=V;a[547752]=W;do{if((a[547479]&1)==0){W=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,33)|0;V=547640;if((c[V>>2]&0|W&1|0)==0&(c[V+4>>2]&2|0)==0){Y=0;Z=0;break}Y=a[547760]&1^1;Z=1}else{Y=0;Z=0}}while(0);a[540336]=(a[540336]&1|Y|0)!=0|0;a[547760]=Z;do{if((a[547479]&1)==0){Z=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,29)|0;Y=547640;if((c[Y>>2]&536870912|Z&1|0)==0&(c[Y+4>>2]&0|0)==0){_=0;n=896;break}if((a[547800]&1)!=0){_=1;n=896;break}a[281248]=a[281248]&1^1;a[547473]=a[482624]&1;a[547474]=0;hv();Y=c[120657]|0;do{if((Y|0)!=0){if((a[547473]&1)!=0){break}gp[Y&63]()}}while(0);hw();if((a[547475]&1)!=0){c[136866]=0}if((a[547476]&1)!=0){c[136865]=0}if((a[547477]&1)!=0){c[136867]=0}a[547475]=0;a[547476]=0;a[547477]=0;hu();a[547473]=0;Y=c[136864]|0;if((Y|0)!=0){f$[c[Y+4>>2]&511](c[136867]|0)}a[547800]=1;if((a[540335]&1)==0){break}gN()}else{_=0;n=896}}while(0);if((n|0)==896){a[547800]=_}do{if((a[540335]&1)!=0){if((a[540336]&1)!=0){break}i=d;return}}while(0);_=a[547479]|0;if((_&1)==0){Y=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,25)|0;Z=547640;$=(c[Z>>2]&33554432|Y&1|0)!=0|(c[Z+4>>2]&0|0)!=0;aa=a[547479]|0}else{$=0;aa=_}if((aa&1)==0){aa=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,26)|0;_=547640;ab=(c[_>>2]&67108864|aa&1|0)!=0|(c[_+4>>2]&0|0)!=0}else{ab=0}do{if($){if((a[547816]&1)!=0){n=915;break}_=a[547480]&1;a[547480]=_^1;aa=_<<24>>24==0;Z=c[136866]|0;if((a[383586]&1)!=0&(Z|0)!=0){if((a[281264]&1)==0){n=910}else{if((a[477949]&1)==0){ac=aa}else{n=910}}if((n|0)==910){ac=1}f0[c[(c[136863]|0)+8>>2]&255](Z,ac)}Z=c[136865]|0;if((a[383585]&1)!=0&(Z|0)!=0){f0[c[(c[136862]|0)+16>>2]&255](Z,(_&a[301872])<<24>>24==0)}c[120672]=aa?c[120673]|0:c[120674]|0}else{n=915}}while(0);do{if((n|0)==915){if((a[547808]&1|0)==(ab&1|0)){break}a[547480]=ab&1;ac=c[136866]|0;if((a[383586]&1)!=0&(ac|0)!=0){if((a[281264]&1)==0){n=919}else{if((a[477949]&1)==0){ad=ab}else{n=919}}if((n|0)==919){ad=1}f0[c[(c[136863]|0)+8>>2]&255](ac,ad)}ac=c[136865]|0;if((a[383585]&1)!=0&(ac|0)!=0){f0[c[(c[136862]|0)+16>>2]&255](ac,(a[301872]&1)==0|ab)}c[120672]=ab?c[120673]|0:c[120674]|0}}while(0);a[547816]=$&1;a[547808]=ab&1;do{if((a[547479]&1)==0){ab=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,31)|0;$=547640;if((c[$>>2]&-2147483648|ab&1|0)==0&(c[$+4>>2]&0|0)==0){ae=0;break}if((a[547672]&1)!=0){ae=1;break}$=e|0;ab=(c[119462]|0)+1|0;c[119462]=ab;ad=c[133027]|0;if((ad|0)==0){af=ab}else{ab=ad+4|0;ac=c[ab>>2]|0;if(ac>>>0>1){aa=ad|0;_=1;Z=ac;while(1){ac=c[(c[aa>>2]|0)+(_<<2)>>2]|0;if((ac|0)==0){ag=Z}else{sS(c[ac+8>>2]|0);sS(c[(c[aa>>2]|0)+(_<<2)>>2]|0);c[(c[aa>>2]|0)+(_<<2)>>2]=0;ag=c[ab>>2]|0}ac=_+1|0;if(ac>>>0<ag>>>0){_=ac;Z=ag}else{break}}}c[ab>>2]=1;Z=ad+12|0;sS(c[Z>>2]|0);c[Z>>2]=0;af=c[119462]|0}b5($|0,256,39496,(E=i,i=i+8|0,c[E>>2]=af,E)|0)|0;i=E;Z=c[133027]|0;L1299:do{if((Z|0)!=0){_=Z+4|0;if((c[_>>2]|0)>>>0>=(c[Z+8>>2]|0)>>>0){break}aa=sR(12)|0;do{if((aa|0)!=0){if((c[aa-4>>2]&3|0)==0){break}s_(aa|0,0,12)}}while(0);c[aa+4>>2]=1;c[aa>>2]=180;ac=dT($|0)|0;Y=c[_>>2]|0;c[aa+8>>2]=ac;ac=Z|0;c[(c[ac>>2]|0)+(Y<<2)>>2]=aa;Y=c[_>>2]|0;c[_>>2]=Y+1;if(Y>>>0>1){ah=Y}else{break}while(1){Y=ah>>>1;V=c[ac>>2]|0;W=V+(Y<<2)|0;U=c[W>>2]|0;R=c[V+(ah<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[U+4>>2]|0)>>>0){break L1299}c[W>>2]=R;c[(c[ac>>2]|0)+(ah<<2)>>2]=U;if(ah>>>0>3){ah=Y}else{break}}}}while(0);if((a[383584]&1)==0){ae=1;break}Z=c[135158]|0;ad=(Z|0)!=0?Z:c[t>>2]|0;eQ(ad|0,48248,(E=i,i=i+8|0,c[E>>2]=$,E)|0)|0;i=E;ad=c[135158]|0;Z=(ad|0)!=0?ad:c[t>>2]|0;a7(Z|0)|0;ae=1}else{ae=0}}while(0);a[547672]=ae;do{if((a[547479]&1)==0){ae=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,32)|0;ah=547640;if((c[ah>>2]&0|ae&1|0)==0&(c[ah+4>>2]&1|0)==0){ai=0;break}if((a[547680]&1)!=0){ai=1;break}ah=e|0;ae=c[119462]|0;if((ae|0)==0){aj=0}else{af=ae-1|0;c[119462]=af;aj=af}af=c[133027]|0;if((af|0)==0){ak=aj}else{ae=af+4|0;ag=c[ae>>2]|0;if(ag>>>0>1){Z=af|0;ad=1;ab=ag;while(1){ag=c[(c[Z>>2]|0)+(ad<<2)>>2]|0;if((ag|0)==0){al=ab}else{sS(c[ag+8>>2]|0);sS(c[(c[Z>>2]|0)+(ad<<2)>>2]|0);c[(c[Z>>2]|0)+(ad<<2)>>2]=0;al=c[ae>>2]|0}ag=ad+1|0;if(ag>>>0<al>>>0){ad=ag;ab=al}else{break}}}c[ae>>2]=1;ab=af+12|0;sS(c[ab>>2]|0);c[ab>>2]=0;ak=c[119462]|0}b5(ah|0,256,39496,(E=i,i=i+8|0,c[E>>2]=ak,E)|0)|0;i=E;ab=c[133027]|0;L1330:do{if((ab|0)!=0){ad=ab+4|0;if((c[ad>>2]|0)>>>0>=(c[ab+8>>2]|0)>>>0){break}Z=sR(12)|0;do{if((Z|0)!=0){if((c[Z-4>>2]&3|0)==0){break}s_(Z|0,0,12)}}while(0);c[Z+4>>2]=1;c[Z>>2]=180;$=dT(ah|0)|0;ag=c[ad>>2]|0;c[Z+8>>2]=$;$=ab|0;c[(c[$>>2]|0)+(ag<<2)>>2]=Z;ag=c[ad>>2]|0;c[ad>>2]=ag+1;if(ag>>>0>1){am=ag}else{break}while(1){ag=am>>>1;ac=c[$>>2]|0;_=ac+(ag<<2)|0;aa=c[_>>2]|0;Y=c[ac+(am<<2)>>2]|0;if((c[Y+4>>2]|0)>>>0<=(c[aa+4>>2]|0)>>>0){break L1330}c[_>>2]=Y;c[(c[$>>2]|0)+(am<<2)>>2]=aa;if(am>>>0>3){am=ag}else{break}}}}while(0);if((a[383584]&1)==0){ai=1;break}ab=c[135158]|0;af=(ab|0)!=0?ab:c[t>>2]|0;eQ(af|0,48248,(E=i,i=i+8|0,c[E>>2]=ah,E)|0)|0;i=E;af=c[135158]|0;ab=(af|0)!=0?af:c[t>>2]|0;a7(ab|0)|0;ai=1}else{ai=0}}while(0);a[547680]=ai;ai=(c[133033]|0)==0;do{if((a[547479]&1)==0){am=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,28)|0;ak=547640;if((c[ak>>2]&268435456|am&1|0)==0&(c[ak+4>>2]&0|0)==0){an=0;break}if((a[547712]&1)!=0){an=1;break}gV();an=1}else{an=0}}while(0);a[547712]=an&1;if(ai){do{if((a[547479]&1)==0){ai=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,27)|0;ak=547640;am=(c[ak>>2]&134217728|ai&1|0)!=0|(c[ak+4>>2]&0|0)!=0;if(an|am^1){ao=am;break}if((a[547720]&1)!=0){ao=am;break}gT();ao=am}else{ao=0}}while(0);a[547720]=ao&1}if((a[532128]&1)!=0){ao=c[120682]|0;if(gQ((c[120681]|0)+(ao<<1)|0,(c[120683]|0)-ao|0)|0){ap=a[383585]&1}else{ap=0}a[383585]=ap}a[532128]=0;do{if(a[8360]|0){if((c[133029]|0)==0){break}L1366:do{if((a[547479]&1)==0){ap=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,33)|0;ao=547640;if((c[ao>>2]&0|ap&1|0)==0&(c[ao+4>>2]&2|0)==0){n=1027;break}ao=c[133027]|0;ap=ao+4|0;an=c[ap>>2]|0;if(an>>>0>1){am=ao|0;ak=1;ai=an;while(1){an=c[(c[am>>2]|0)+(ak<<2)>>2]|0;if((an|0)==0){aq=ai}else{sS(c[an+8>>2]|0);sS(c[(c[am>>2]|0)+(ak<<2)>>2]|0);c[(c[am>>2]|0)+(ak<<2)>>2]=0;aq=c[ap>>2]|0}an=ak+1|0;if(an>>>0<aq>>>0){ak=an;ai=aq}else{break}}}c[ap>>2]=1;ai=ao+12|0;sS(c[ai>>2]|0);c[ai>>2]=0;ai=c[133029]|0;ak=ai+12|0;am=c[ak>>2]|0;an=am;al=ai+28|0;do{if((a[al]&1)==0){aj=ai+16|0;e=ai+8|0;ab=c[e>>2]|0;af=(c[aj>>2]|0)-1&ab;c[aj>>2]=af;ae=ai+20|0;$=c[ae>>2]|0;if((af|0)==($|0)){c[aj>>2]=af+1&ab;ad=c[133027]|0;Z=ad+4|0;if((c[Z>>2]|0)>>>0>=(c[ad+8>>2]|0)>>>0){break L1366}ag=sR(12)|0;do{if((ag|0)!=0){if((c[ag-4>>2]&3|0)==0){break}s_(ag|0,0,12)}}while(0);c[ag+4>>2]=0;c[ag>>2]=30;aa=dT(13072)|0;Y=c[Z>>2]|0;c[ag+8>>2]=aa;aa=ad|0;c[(c[aa>>2]|0)+(Y<<2)>>2]=ag;Y=c[Z>>2]|0;c[Z>>2]=Y+1;if(Y>>>0>1){ar=Y}else{break L1366}while(1){Y=ar>>>1;_=c[aa>>2]|0;ac=_+(Y<<2)|0;U=c[ac>>2]|0;R=c[_+(ar<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[U+4>>2]|0)>>>0){break L1366}c[ac>>2]=R;c[(c[aa>>2]|0)+(ar<<2)>>2]=U;if(ar>>>0>3){ar=Y}else{break L1366}}}else{aa=ai|0;Z=(c[aa>>2]|0)+(af<<3)|0;ag=c[Z>>2]|0;ad=c[Z+4>>2]|0;if((ag|0)==0&(ad|0)==0){as=af;at=$;au=ab}else{Z=ad;ad=ag;ag=am;while(1){Y=ag+(Z<<2)|0;c[Y>>2]=c[Y>>2]^ad;av=c[e>>2]|0;aw=(c[aj>>2]|0)-1&av;c[aj>>2]=aw;Y=(c[aa>>2]|0)+(aw<<3)|0;U=c[Y>>2]|0;R=c[Y+4>>2]|0;if((U|0)==0&(R|0)==0){break}Z=R;ad=U;ag=c[ak>>2]|0}as=aw;at=c[ae>>2]|0;au=av}if((as|0)!=(at|0)){break}c[aj>>2]=at+1&au;break}}else{a[al]=0}}while(0);a[532128]=1;al=c[120683]|0;c[120682]=al;L1400:do{if((c[120671]|0)!=0){ak=0;am=al;while(1){ai=b[(c[120680]|0)+((ak|1)<<1)>>1]|0;ao=am-1|0;c[120682]=ao;b[(c[120681]|0)+(ao<<1)>>1]=ai;ai=b[(c[120680]|0)+(ak<<1)>>1]|0;ao=(c[120682]|0)-1|0;c[120682]=ao;b[(c[120681]|0)+(ao<<1)>>1]=ai;ai=ak+2|0;if(ai>>>0>=(c[120671]|0)>>>0){break L1400}ak=ai;am=c[120682]|0}}}while(0);c[120671]=0;al=c[133027]|0;am=al+4|0;L1405:do{if((c[am>>2]|0)>>>0<(c[al+8>>2]|0)>>>0){ak=(a[540335]&1)!=0?1:30;aj=sR(12)|0;do{if((aj|0)!=0){if((c[aj-4>>2]&3|0)==0){break}s_(aj|0,0,12)}}while(0);c[aj+4>>2]=0;c[aj>>2]=ak;ae=dT(13208)|0;ai=c[am>>2]|0;c[aj+8>>2]=ae;ae=al|0;c[(c[ae>>2]|0)+(ai<<2)>>2]=aj;ai=c[am>>2]|0;c[am>>2]=ai+1;if(ai>>>0>1){ax=ai}else{break}while(1){ai=ax>>>1;ao=c[ae>>2]|0;ap=ao+(ai<<2)|0;ag=c[ap>>2]|0;ad=c[ao+(ax<<2)>>2]|0;if((c[ad+4>>2]|0)>>>0<=(c[ag+4>>2]|0)>>>0){break L1405}c[ap>>2]=ad;c[(c[ae>>2]|0)+(ax<<2)>>2]=ag;if(ax>>>0>3){ax=ai}else{break}}}}while(0);am=c[16032]|0;al=c[133031]|0;gj[am&127](an,al)|0;al=c[133033]|0;if((al|0)==0){break}a[al+33|0]=1;am=al+20|0;ae=c[am>>2]|0;aj=c[al+12>>2]|0;do{if(ae>>>0<2){ak=c[aj>>2]|0;ai=al+28|0;if((ak|0)!=(c[ai>>2]|0)){ay=ai;n=1015;break}c[am>>2]=0;ag=c[al>>2]|0;e3(ag|0,ak|0,0)|0;az=ai}else{ay=al+28|0;n=1015}}while(0);if((n|0)==1015){an=ae-((a[al+32|0]&1)!=0?1:2)&c[al+16>>2];c[am>>2]=an;ai=c[al>>2]|0;ak=c[aj+(an<<2)>>2]|0;e3(ai|0,ak|0,0)|0;az=ay}ak=al|0;ai=cx(c[ak>>2]|0)|0;an=c[az>>2]|0;if((ai|0)>(an|0)){break}ai=c[ak>>2]|0;if((a[al+24|0]&1)==0){e3(ai|0,16,0)|0;ag=c[16052]|0;ad=al+4|0;ap=c[ad>>2]|0;ao=al+8|0;Z=c[ao>>2]|0;gj[ag&127](ap,Z)|0;Z=c[ad>>2]|0;ad=c[ao>>2]|0;ao=c[ak>>2]|0;be(Z|0,1,ad|0,ao|0)|0;break}else{e3(ai|0,an|0,0)|0;break}}else{n=1027}}while(0);do{if((n|0)==1027){ah=c[94859]|0;an=(((c[136932]|0)+1|0)>>>0)%(((ah|0)!=0?ah:1)>>>0)|0;c[136932]=an;if(!((an|0)==0|(c[133033]|0)!=0)){break}an=c[16052]|0;ah=c[133030]|0;ai=c[133031]|0;gj[an&127](ah,ai)|0;ai=c[133029]|0;ah=c[133030]|0;an=ai+12|0;ao=c[an>>2]|0;ad=ah;Z=ai+16|0;ak=c[Z>>2]|0;c[Z>>2]=ak+1;ap=ai|0;ag=(c[ap>>2]|0)+(ak<<3)|0;c[ag>>2]=0;c[ag+4>>2]=0;ag=ai+8|0;ak=c[ag>>2]|0;aa=c[Z>>2]&ak;c[Z>>2]=aa;e=ai+20|0;ab=(aa|0)==(c[e>>2]|0);$=ai+24|0;af=c[$>>2]|0;if((af|0)==0){aA=ab;aB=aa;aC=ak;aD=0}else{U=0;R=0;Y=ab;ab=aa;aa=ak;ak=af;while(1){af=R;ac=c[ao+(af<<2)>>2]|0;_=c[ad+(af<<2)>>2]|0;if((ac|0)==(_|0)){aE=Y;aF=ab;aG=aa;aH=ak}else{af=(c[ap>>2]|0)+(ab<<3)|0;c[af>>2]=_^ac;c[af+4>>2]=R;af=c[ag>>2]|0;ac=(c[Z>>2]|0)+1&af;c[Z>>2]=ac;aE=(ac|0)==(c[e>>2]|0)|Y;aF=ac;aG=af;aH=c[$>>2]|0}af=ta(R,U,1,0)|0;ac=K;_=0;if(ac>>>0<_>>>0|ac>>>0==_>>>0&af>>>0<aH>>>0){U=ac;R=af;Y=aE;ab=aF;aa=aG;ak=aH}else{aA=aE;aB=aF;aC=aG;aD=aH;break}}}do{if(aA){ak=aB+1&aC;c[e>>2]=ak;aa=c[ap>>2]|0;ab=aa+(ak<<3)|0;if((c[ab>>2]|0)==0&(c[ab+4>>2]|0)==0){break}else{aI=ak}do{aI=aI+1&aC;c[e>>2]=aI;ak=aa+(aI<<3)|0;}while(!((c[ak>>2]|0)==0&(c[ak+4>>2]|0)==0))}}while(0);e=c[an>>2]|0;ap=aD<<2;s1(e|0,ah|0,ap)|0;a[ai+28|0]=1}}while(0);f$[c[16048]&511]((a[532128]&1)!=0?184:98);f$[c[16046]&511]((a[532128]&1)!=0?86:62)}else{a[8360]=1}}while(0);L1444:do{if((a[547479]&1)==0){aD=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,47)|0;aI=547640;aC=(c[aI>>2]&0|aD&1|0)!=0|(c[aI+4>>2]&32768|0)!=0;a[540337]=aC&1;if(!aC){break}aC=c[133027]|0;aI=aC+4|0;aD=c[aI>>2]|0;if(aD>>>0>1){aB=aC|0;aA=1;aH=aD;while(1){aD=c[(c[aB>>2]|0)+(aA<<2)>>2]|0;if((aD|0)==0){aJ=aH}else{sS(c[aD+8>>2]|0);sS(c[(c[aB>>2]|0)+(aA<<2)>>2]|0);c[(c[aB>>2]|0)+(aA<<2)>>2]=0;aJ=c[aI>>2]|0}aD=aA+1|0;if(aD>>>0<aJ>>>0){aA=aD;aH=aJ}else{break}}}c[aI>>2]=1;aH=aC+12|0;sS(c[aH>>2]|0);c[aH>>2]=0;aH=c[133027]|0;aA=aH+4|0;if((c[aA>>2]|0)>>>0>=(c[aH+8>>2]|0)>>>0){break}aB=(a[532128]&1)!=0?13512:13368;aD=sR(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}s_(aD|0,0,12)}}while(0);c[aD+4>>2]=0;c[aD>>2]=30;aC=dT(aB|0)|0;aI=c[aA>>2]|0;c[aD+8>>2]=aC;aC=aH|0;c[(c[aC>>2]|0)+(aI<<2)>>2]=aD;aI=c[aA>>2]|0;c[aA>>2]=aI+1;if(aI>>>0>1){aK=aI}else{break}while(1){aI=aK>>>1;aG=c[aC>>2]|0;aF=aG+(aI<<2)|0;aE=c[aF>>2]|0;az=c[aG+(aK<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[aE+4>>2]|0)>>>0){break L1444}c[aF>>2]=az;c[(c[aC>>2]|0)+(aK<<2)>>2]=aE;if(aK>>>0>3){aK=aI}else{break}}}else{a[540337]=0}}while(0);do{if((a[547479]&1)==0){aK=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,34)|0;aJ=547640;if((c[aJ>>2]&0|aK&1|0)==0&(c[aJ+4>>2]&4|0)==0){aL=0;aM=0;break}aL=(a[547776]&1)==0;aM=1}else{aL=0;aM=0}}while(0);do{if((a[536232]&1)==0){if(!aL){break}aJ=j|0;aK=k|0;if((c[133033]|0)==0){c[94859]=1;aC=c[119462]|0;if((aC|0)==0){b5(aJ|0,4096,15288,(E=i,i=i+8|0,c[E>>2]=532136,E)|0)|0;i=E}else{b5(aJ|0,4096,15416,(E=i,i=i+16|0,c[E>>2]=532136,c[E+8>>2]=aC,E)|0)|0;i=E}b5(aK|0,4096,15088,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;c[133033]=h5(aJ,1)|0;aC=c[133027]|0;aA=aC+4|0;aD=c[aA>>2]|0;if(aD>>>0>1){aH=aC|0;aB=1;aI=aD;while(1){aD=c[(c[aH>>2]|0)+(aB<<2)>>2]|0;if((aD|0)==0){aN=aI}else{sS(c[aD+8>>2]|0);sS(c[(c[aH>>2]|0)+(aB<<2)>>2]|0);c[(c[aH>>2]|0)+(aB<<2)>>2]=0;aN=c[aA>>2]|0}aD=aB+1|0;if(aD>>>0<aN>>>0){aB=aD;aI=aN}else{break}}}c[aA>>2]=1;aI=aC+12|0;sS(c[aI>>2]|0);c[aI>>2]=0;aI=c[133027]|0;aB=aI+4|0;L1535:do{if((c[aB>>2]|0)>>>0<(c[aI+8>>2]|0)>>>0){aH=(c[133033]|0)!=0?aK:14896;aD=sR(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}s_(aD|0,0,12)}}while(0);c[aD+4>>2]=1;c[aD>>2]=180;ai=dT(aH|0)|0;ah=c[aB>>2]|0;c[aD+8>>2]=ai;ai=aI|0;c[(c[ai>>2]|0)+(ah<<2)>>2]=aD;ah=c[aB>>2]|0;c[aB>>2]=ah+1;if(ah>>>0>1){aO=ah}else{break}while(1){ah=aO>>>1;an=c[ai>>2]|0;aE=an+(ah<<2)|0;az=c[aE>>2]|0;aF=c[an+(aO<<2)>>2]|0;if((c[aF+4>>2]|0)>>>0<=(c[az+4>>2]|0)>>>0){break L1535}c[aE>>2]=aF;c[(c[ai>>2]|0)+(aO<<2)>>2]=az;if(aO>>>0>3){aO=ah}else{break}}}}while(0);if((c[133033]|0)==0){aB=c[135158]|0;aI=(aB|0)!=0?aB:c[t>>2]|0;be(14232,51,1,aI|0)|0;aI=c[135158]|0;aB=(aI|0)!=0?aI:c[t>>2]|0;a7(aB|0)|0;break}if((a[383584]&1)==0){break}aB=c[135158]|0;aI=(aB|0)!=0?aB:c[t>>2]|0;eQ(aI|0,14744,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;aI=c[135158]|0;aB=(aI|0)!=0?aI:c[t>>2]|0;a7(aB|0)|0;break}else{aB=c[133027]|0;aI=aB+4|0;aK=c[aI>>2]|0;if(aK>>>0>1){aC=aB|0;aA=1;ai=aK;while(1){aK=c[(c[aC>>2]|0)+(aA<<2)>>2]|0;if((aK|0)==0){aP=ai}else{sS(c[aK+8>>2]|0);sS(c[(c[aC>>2]|0)+(aA<<2)>>2]|0);c[(c[aC>>2]|0)+(aA<<2)>>2]=0;aP=c[aI>>2]|0}aK=aA+1|0;if(aK>>>0<aP>>>0){aA=aK;ai=aP}else{break}}}c[aI>>2]=1;ai=aB+12|0;sS(c[ai>>2]|0);c[ai>>2]=0;ai=c[133027]|0;aA=ai+4|0;L1503:do{if((c[aA>>2]|0)>>>0<(c[ai+8>>2]|0)>>>0){aC=sR(12)|0;do{if((aC|0)!=0){if((c[aC-4>>2]&3|0)==0){break}s_(aC|0,0,12)}}while(0);c[aC+4>>2]=2;c[aC>>2]=180;aJ=dT(15688)|0;aK=c[aA>>2]|0;c[aC+8>>2]=aJ;aJ=ai|0;c[(c[aJ>>2]|0)+(aK<<2)>>2]=aC;aK=c[aA>>2]|0;c[aA>>2]=aK+1;if(aK>>>0>1){aQ=aK}else{break}while(1){aK=aQ>>>1;aD=c[aJ>>2]|0;aH=aD+(aK<<2)|0;ah=c[aH>>2]|0;az=c[aD+(aQ<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1503}c[aH>>2]=az;c[(c[aJ>>2]|0)+(aQ<<2)>>2]=ah;if(aQ>>>0>3){aQ=aK}else{break}}}}while(0);if((a[383584]&1)!=0){aA=c[135158]|0;ai=(aA|0)!=0?aA:c[t>>2]|0;be(15560,34,1,ai|0)|0;ai=c[135158]|0;aA=(ai|0)!=0?ai:c[t>>2]|0;a7(aA|0)|0}aA=c[133033]|0;if((aA|0)!=0){ai=c[aA>>2]|0;if((ai|0)!=0){a_(ai|0)|0}sS(c[aA+4>>2]|0);sS(c[aA+12>>2]|0);sS(aA)}c[133033]=0;break}}else{if(!((a[540331]&1)!=0|aL)){break}aA=c[133027]|0;ai=aA+4|0;L1472:do{if((c[ai>>2]|0)>>>0<(c[aA+8>>2]|0)>>>0){aB=sR(12)|0;do{if((aB|0)!=0){if((c[aB-4>>2]&3|0)==0){break}s_(aB|0,0,12)}}while(0);c[aB+4>>2]=1;c[aB>>2]=180;aI=dT(14008)|0;aJ=c[ai>>2]|0;c[aB+8>>2]=aI;aI=aA|0;c[(c[aI>>2]|0)+(aJ<<2)>>2]=aB;aJ=c[ai>>2]|0;c[ai>>2]=aJ+1;if(aJ>>>0>1){aR=aJ}else{break}while(1){aJ=aR>>>1;aC=c[aI>>2]|0;aK=aC+(aJ<<2)|0;ah=c[aK>>2]|0;az=c[aC+(aR<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1472}c[aK>>2]=az;c[(c[aI>>2]|0)+(aR<<2)>>2]=ah;if(aR>>>0>3){aR=aJ}else{break}}}}while(0);if((a[383584]&1)!=0){ai=c[135158]|0;aA=(ai|0)!=0?ai:c[t>>2]|0;be(13688,33,1,aA|0)|0;aA=c[135158]|0;ai=(aA|0)!=0?aA:c[t>>2]|0;a7(ai|0)|0}ai=c[133033]|0;if((ai|0)!=0){aA=c[ai>>2]|0;if((aA|0)!=0){a_(aA|0)|0}sS(c[ai+4>>2]|0);sS(c[ai+12>>2]|0);sS(ai)}c[133033]=0;a[540331]=0;a[536232]=0}}while(0);a[547776]=aM;aM=f|0;L1550:do{if((c[135115]|0)!=0){if((c[(c[136863]|0)+20>>2]|0)==0){break}f=a[547479]|0;if((f&1)==0){aR=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,38)|0;aL=547640;aS=(c[aL>>2]&0|aR&1|0)!=0|(c[aL+4>>2]&64|0)!=0;aT=a[547479]|0}else{aS=0;aT=f}if((aT&1)==0){f=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,39)|0;aL=547640;aU=(c[aL>>2]&0|f&1|0)!=0|(c[aL+4>>2]&128|0)!=0}else{aU=0}do{if(aS){if((a[547696]&1)!=0){n=1120;break}aL=c[135115]|0;f=(((c[135116]|0)+1|0)>>>0)%((c[aL+4>>2]|0)>>>0)|0;c[135116]=f;aV=f;aW=aL;n=1125}else{n=1120}}while(0);do{if((n|0)==1120){if(!aU){break}if((a[547688]&1)!=0){break}aL=c[135116]|0;if((aL|0)==0){f=c[135115]|0;aR=(c[f+4>>2]|0)-1|0;c[135116]=aR;aV=aR;aW=f;n=1125;break}else{f=aL-1|0;c[135116]=f;aV=f;aW=c[135115]|0;n=1125;break}}}while(0);do{if((n|0)==1125){f=c[(c[aW>>2]|0)+(aV<<3)>>2]|0;aL=cD(f|0,46)|0;if((aL|0)==0){break L1550}do{if((da(aL|0,17256)|0)==0){aX=2}else{if((da(aL|0,17064)|0)==0){aX=0;break}if((da(aL|0,16896)|0)==0){aX=0}else{break L1550}}}while(0);aL=c[133027]|0;aR=aL+4|0;aQ=c[aR>>2]|0;if(aQ>>>0>1){aP=aL|0;aO=1;aN=aQ;while(1){aQ=c[(c[aP>>2]|0)+(aO<<2)>>2]|0;if((aQ|0)==0){aY=aN}else{sS(c[aQ+8>>2]|0);sS(c[(c[aP>>2]|0)+(aO<<2)>>2]|0);c[(c[aP>>2]|0)+(aO<<2)>>2]=0;aY=c[aR>>2]|0}aQ=aO+1|0;if(aQ>>>0<aY>>>0){aO=aQ;aN=aY}else{break}}}c[aR>>2]=1;aN=aL+12|0;sS(c[aN>>2]|0);c[aN>>2]=0;aN=c[135116]|0;b5(aM|0,512,16432,(E=i,i=i+16|0,c[E>>2]=aN,c[E+8>>2]=f,E)|0)|0;i=E;aN=c[133027]|0;aO=aN+4|0;L1584:do{if((c[aO>>2]|0)>>>0<(c[aN+8>>2]|0)>>>0){aP=sR(12)|0;do{if((aP|0)!=0){if((c[aP-4>>2]&3|0)==0){break}s_(aP|0,0,12)}}while(0);c[aP+4>>2]=1;c[aP>>2]=120;aQ=dT(aM|0)|0;k=c[aO>>2]|0;c[aP+8>>2]=aQ;aQ=aN|0;c[(c[aQ>>2]|0)+(k<<2)>>2]=aP;k=c[aO>>2]|0;c[aO>>2]=k+1;if(k>>>0>1){aZ=k}else{break}while(1){k=aZ>>>1;j=c[aQ>>2]|0;ai=j+(k<<2)|0;aA=c[ai>>2]|0;aI=c[j+(aZ<<2)>>2]|0;if((c[aI+4>>2]|0)>>>0<=(c[aA+4>>2]|0)>>>0){break L1584}c[ai>>2]=aI;c[(c[aQ>>2]|0)+(aZ<<2)>>2]=aA;if(aZ>>>0>3){aZ=k}else{break}}}}while(0);if((a[383584]&1)!=0){aO=c[135158]|0;aN=(aO|0)!=0?aO:c[t>>2]|0;eQ(aN|0,16192,(E=i,i=i+8|0,c[E>>2]=f,E)|0)|0;i=E;aN=c[135158]|0;aO=(aN|0)!=0?aN:c[t>>2]|0;a7(aO|0)|0}if(f7[c[(c[136863]|0)+20>>2]&127](c[136866]|0,aX,f)|0){break}aO=c[135158]|0;aN=(aO|0)!=0?aO:c[t>>2]|0;be(15920,44,1,aN|0)|0;aN=c[135158]|0;aO=(aN|0)!=0?aN:c[t>>2]|0;a7(aO|0)|0}}while(0);a[547696]=aS&1;a[547688]=aU&1}}while(0);if((c[135134]|0)!=0){aU=a[547479]|0;if((aU&1)==0){aS=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,40)|0;aX=547640;a$=(c[aX>>2]&0|aS&1|0)!=0|(c[aX+4>>2]&256|0)!=0;a0=a[547479]|0}else{a$=0;a0=aU}if((a0&1)==0){aU=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,41)|0;aX=547640;a1=(c[aX>>2]&0|aU&1|0)!=0|(c[aX+4>>2]&512|0)!=0;a2=a[547479]|0}else{a1=0;a2=a0}if((a2&1)==0){a2=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,42)|0;a0=547640;a3=(c[a0>>2]&0|a2&1|0)!=0|(c[a0+4>>2]&1024|0)!=0}else{a3=0}do{if(a$){if((a[547856]&1)!=0){n=1156;break}a0=c[135134]|0;a2=a0+4|0;c[a2>>2]=(((c[a2>>2]|0)+1|0)>>>0)%((c[a0+8>>2]|0)>>>0)|0;is(a0)}else{n=1156}}while(0);L1614:do{if((n|0)==1156){do{if(a1){if((a[547848]&1)!=0){break}a0=c[135134]|0;a2=a0+4|0;aX=c[a2>>2]|0;if((aX|0)==0){a4=c[a0+8>>2]|0}else{a4=aX}c[a2>>2]=a4-1;is(a0);break L1614}}while(0);if(!a3){break}if((a[547840]&1)!=0){break}a0=c[135134]|0;a2=a0|0;aX=(c[a2>>2]|0)+((c[a0+4>>2]|0)*12|0)+4|0;a[aX]=a[aX]&1^1;gp[c[16078]&63]();aX=a0+8|0;aU=c[aX>>2]|0;if((aU|0)!=0){aS=0;E=0;aZ=aU;while(1){aU=c[a2>>2]|0;if((a[aU+(E*12|0)+4|0]&1)==0){a5=aS;a6=aZ}else{go[c[16076]&127](aS,1,c[aU+(E*12|0)+8>>2]|0);a5=aS+1|0;a6=c[aX>>2]|0}aU=E+1|0;if(aU>>>0<a6>>>0){aS=a5;E=aU;aZ=a6}else{break}}}is(a0)}}while(0);a[547848]=a1&1;a[547856]=a$&1;a[547840]=a3&1}if((c[120646]|0)!=0){a3=a[547479]|0;if((a3&1)==0){a$=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,52)|0;a1=547640;a8=(c[a1>>2]&0|a$&1|0)!=0|(c[a1+4>>2]&1048576|0)!=0;a9=a[547479]|0}else{a8=0;a9=a3}if((a9&1)==0){a9=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,53)|0;a3=547640;ba=(c[a3>>2]&0|a9&1|0)!=0|(c[a3+4>>2]&2097152|0)!=0}else{ba=0}do{if(a8){if((a[547832]&1)!=0){n=1177;break}gZ((gm[c[120643]&31]()|0)^1,1)}else{n=1177}}while(0);do{if((n|0)==1177){if(!ba){break}if((a[547824]&1)!=0){break}a3=gm[c[120646]&31]()|0;a9=gm[c[120644]&31]()|0;if((a3|0)==(-1|0)|(a3|0)==0){a1=c[135158]|0;a$=(a1|0)!=0?a1:c[t>>2]|0;be(17520,59,1,a$|0)|0;a$=c[135158]|0;a1=(a$|0)!=0?a$:c[t>>2]|0;a7(a1|0)|0;break}if(a9>>>0<a3>>>0){bb=((a9+1|0)>>>0)%((a3+1|0)>>>0)|0}else{bb=0}g_(bb)}}while(0);a[547832]=a8&1;a[547824]=ba&1}do{if((a[547479]&1)==0){ba=gj[c[(c[136864]|0)+12>>2]&127](c[136867]|0,37)|0;a8=547640;if((c[a8>>2]&0|ba&1|0)==0&(c[a8+4>>2]&32|0)==0){bc=0;break}if((a[547736]&1)!=0){bc=1;break}gX();bc=1}else{bc=0}}while(0);a[547736]=bc;i=d;return}function g3(a,d){a=a|0;d=d|0;var e=0;e=(c[120682]|0)-1|0;c[120682]=e;b[(c[120681]|0)+(e<<1)>>1]=d;d=(c[120682]|0)-1|0;c[120682]=d;b[(c[120681]|0)+(d<<1)>>1]=a;return}function g4(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+4096|0;d=b|0;L1665:do{if((a[540334]&1)!=0){switch(c[96930]|0){case 0:{e=a[383584]|0;if((e&1)==0){f=e}else{e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;be(19568,32,1,g|0)|0;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;f=a[383584]|0}if((f&1)==0){h=f}else{e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;eQ(g|0,19384,(j=i,i=i+8|0,c[j>>2]=424594,j)|0)|0;i=j;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;h=a[383584]|0}if((h&1)!=0){e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;eQ(g|0,19272,(j=i,i=i+8|0,c[j>>2]=428690,j)|0)|0;i=j;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0}hc(424594,0);hc(428690,1);break L1665;break};case 4:{e=a[383584]|0;if((e&1)==0){k=e}else{e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;be(18056,40,1,g|0)|0;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;k=a[383584]|0}if((k&1)==0){l=k}else{e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;eQ(g|0,17920,(j=i,i=i+8|0,c[j>>2]=436882,j)|0)|0;i=j;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;l=a[383584]|0}if((l&1)!=0){e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;eQ(g|0,17720,(j=i,i=i+8|0,c[j>>2]=440978,j)|0)|0;i=j;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0}hc(436882,768);hc(440978,1024);break L1665;break};case 1:{e=a[383584]|0;if((e&1)==0){m=e}else{e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;be(19128,32,1,g|0)|0;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;m=a[383584]|0}if((m&1)==0){n=m}else{e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;eQ(g|0,19384,(j=i,i=i+8|0,c[j>>2]=424594,j)|0)|0;i=j;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;n=a[383584]|0}if((n&1)!=0){e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;eQ(g|0,19272,(j=i,i=i+8|0,c[j>>2]=428690,j)|0)|0;i=j;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0}hc(424594,1280);hc(428690,1537);break L1665;break};case 2:case 3:{e=a[383584]|0;if((e&1)==0){o=e}else{e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;be(18632,30,1,g|0)|0;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;o=a[383584]|0}if((o&1)==0){p=o}else{e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;eQ(g|0,18448,(j=i,i=i+8|0,c[j>>2]=424594,j)|0)|0;i=j;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0;p=a[383584]|0}if((p&1)!=0){e=c[135158]|0;g=(e|0)!=0?e:c[t>>2]|0;eQ(g|0,18272,(j=i,i=i+8|0,c[j>>2]=432786,j)|0)|0;i=j;g=c[135158]|0;e=(g|0)!=0?g:c[t>>2]|0;a7(e|0)|0}hc(424594,256);hc(432786,512);break L1665;break};default:{break L1665}}}}while(0);p=c[133029]|0;if((p|0)!=0){sS(c[p>>2]|0);sS(c[p+12>>2]|0);sS(p)}c[133029]=0;sS(c[133030]|0);c[133030]=0;p=c[135134]|0;if((p|0)!=0){ir(p)}p=c[133033]|0;if((p|0)!=0){o=c[p>>2]|0;if((o|0)!=0){a_(o|0)|0}sS(c[p+4>>2]|0);sS(c[p+12>>2]|0);sS(p)}do{if((a[541709]&1)==0){if((a[541708]&1)!=0){break}p=d|0;if((a[379458]&1)==0){break}hl(p,445074,20032);o=ha(p)|0;if((a[383584]&1)==0){break}n=c[135158]|0;m=(n|0)!=0?n:c[t>>2]|0;n=o?19792:19720;eQ(m|0,19864,(j=i,i=i+16|0,c[j>>2]=p,c[j+8>>2]=n,j)|0)|0;i=j;n=c[135158]|0;p=(n|0)!=0?n:c[t>>2]|0;a7(p|0)|0}}while(0);hv();d=c[120657]|0;do{if((d|0)!=0){if((a[547473]&1)!=0){break}gp[d&63]()}}while(0);hw();if((a[547475]&1)!=0){c[136866]=0}if((a[547476]&1)!=0){c[136865]=0}if((a[547477]&1)!=0){c[136867]=0}a[547475]=0;a[547476]=0;a[547477]=0;gp[c[16034]&63]();gp[c[16074]&63]();d=c[120666]|0;if((d|0)!=0){p=d+4104|0;if((c[p>>2]|0)==0){q=d|0}else{n=d+4100|0;m=d|0;o=0;while(1){l=c[n>>2]|0;hC(c[m>>2]|0,c[l+(o<<4)+4>>2]|0,c[(c[c[l+(o<<4)+8>>2]>>2]|0)+(c[l+(o<<4)+12>>2]<<3)>>2]|0);l=o+1|0;if(l>>>0<(c[p>>2]|0)>>>0){o=l}else{q=m;break}}}m=c[q>>2]|0;q=d+4|0;hD(m,q)|0;ig(c[120666]|0)}s_(477872,0,4800);if((a[383620]&1)==0){a[540636]=0;i=b;return}if((a[383584]&1)!=0){q=c[135158]|0;m=(q|0)!=0?q:c[t>>2]|0;eQ(m|0,23528,(j=i,i=i+8|0,c[j>>2]=383621,j)|0)|0;i=j;m=c[135158]|0;q=(m|0)!=0?m:c[t>>2]|0;a7(q|0)|0}if((bP(383621)|0)<0){q=c[135158]|0;m=(q|0)!=0?q:c[t>>2]|0;eQ(m|0,23248,(j=i,i=i+8|0,c[j>>2]=383621,j)|0)|0;i=j;j=c[135158]|0;m=(j|0)!=0?j:c[t>>2]|0;a7(m|0)|0}a[383620]=0;a[540636]=0;i=b;return}function g5(d,e){d=d|0;e=e|0;var f=0,g=0;f=c[120671]|0;c[120671]=f+1;b[(c[120680]|0)+(f<<1)>>1]=d;d=c[120671]|0;c[120671]=d+1;b[(c[120680]|0)+(d<<1)>>1]=e;e=c[120671]|0;if(e>>>0<(c[120672]|0)>>>0){return}if(gQ(c[120680]|0,e)|0){g=a[383585]&1}else{g=0}a[383585]=g;c[120671]=0;return}function g6(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=f&255;f=c[133033]|0;do{if((f|0)!=0){if((a[536232]&1)==0){break}if((eK(l|0,2,1,c[f>>2]|0)|0)!=1){a[540331]=1;break}n=b[l>>1]|0;i=j;return n|0}}while(0);if(h>>>0<25|(m|0)==3){o=f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,6096,d,m,g,h)|0}else{o=0}l=(m|0)==1;f=(d|0)==0;do{if(l&f){p=547640;q=c[p>>2]|0;r=c[p+4>>2]|0;p=tc(1,0,h|0)|0;s=K;t=((q&p|0)!=0|(r&s|0)!=0)&1|o}else{if(!((m|0)==5&f)){t=o;break}t=(b[547648+(((h|0)==1|((g|0)==1?2:0))<<1)>>1]|0)+o&65535}}while(0);do{if(l){if((h-4|0)>>>0<=3){u=t;break}o=t<<16>>16!=0;do{if(o){if((a[540338+d|0]&1)==0){v=b[540346+(d<<1)>>1]|0;w=1<<h;break}else{g=1<<h;f=540346+(d<<1)|0;m=(e[f>>1]|0|g)&65535;b[f>>1]=m;v=m;w=g;break}}else{g=1<<h;m=540346+(d<<1)|0;f=(e[m>>1]|0)&(g^65535)&65535;b[m>>1]=f;v=f;w=g}}while(0);if((v&65535&w|0)==0){x=o}else{x=(((c[135091]|0)>>>0)%((c[85636]|0)>>>0)|0)>>>0<(c[85637]|0)>>>0&o}u=x&1}else{u=t}}while(0);t=c[133033]|0;if((t|0)==0){n=u;i=j;return n|0}if((a[536232]&1)!=0){n=u;i=j;return n|0}b[k>>1]=u;be(k|0,2,1,c[t>>2]|0)|0;n=u;i=j;return n|0}function g7(){var a=0,b=0,d=0;a=i;dH(37856|0)|0;dH(37776|0)|0;b=c[q>>2]|0;be(50464|0,11,1,b|0)|0;eQ(b|0,50176|0,(d=i,i=i+16|0,c[d>>2]=49560,c[d+8>>2]=32,d)|0)|0;i=d;eQ(b|0,49272|0,(d=i,i=i+8|0,c[d>>2]=49080,d)|0)|0;i=d;dH(37856|0)|0;dH(37728|0)|0;dH(37672|0)|0;dH(37552|0)|0;dH(37416|0)|0;dH(36960|0)|0;dH(36832|0)|0;dH(36736|0)|0;dH(36416|0)|0;dH(36232|0)|0;dH(36080|0)|0;dH(35752|0)|0;dH(35568|0)|0;dH(35496|0)|0;dH(35416|0)|0;dH(34992|0)|0;dH(34864|0)|0;dv(34656|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;dv(34544|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;dv(34472|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;dH(34336|0)|0;dH(34248|0)|0;dH(34120|0)|0;dH(34024|0)|0;dH(33976|0)|0;dH(33688|0)|0;dH(33544|0)|0;dH(33424|0)|0;dH(33304|0)|0;dH(33272|0)|0;dH(33184|0)|0;dH(33112|0)|0;dH(33040|0)|0;dH(32960|0)|0;dH(32912|0)|0;dH(32560|0)|0;i=a;return}function g8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=dz(b|0,42504|0)|0;do{if((e|0)!=0){e3(e|0,0,2)|0;b=cx(e|0)|0;fb(e|0);f=sR(b+1|0)|0;if((f|0)==0){g=c[135158]|0;h=(g|0)!=0?g:c[t>>2]|0;be(34424|0,47,1,h|0)|0;h=c[135158]|0;g=(h|0)!=0?h:c[t>>2]|0;a7(g|0)|0;a_(e|0)|0;break}g=eK(f|0,1,b|0,e|0)|0;if((g|0)<(b|0)){h=c[135158]|0;i=(h|0)!=0?h:c[t>>2]|0;be(28152|0,44,1,i|0)|0;i=c[135158]|0;h=(i|0)!=0?i:c[t>>2]|0;a7(h|0)|0}c[d>>2]=f;a[f+b|0]=0;a_(e|0)|0;j=g;return j|0}}while(0);c[d>>2]=0;j=-1;return j|0}function g9(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[540637]&1)==0){d=c[135158]|0;e=(d|0)!=0?d:c[t>>2]|0;eQ(e|0,33848,(e=i,i=i+16|0,c[e>>2]=43784,c[e+8>>2]=832,e)|0)|0;i=e;e=c[135158]|0;d=(e|0)!=0?e:c[t>>2]|0;a7(d|0)|0;cz(2)}else{f=1024;g=540639;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=1317;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==1317){fi(541664,1)}a[g]=0;if((a[h]|0)==0){fi(541664,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);fi(541664,1)}function ha(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a[383584]&1)!=0){e=c[135158]|0;f=(e|0)!=0?e:c[t>>2]|0;eQ(f|0,20504,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;f=c[135158]|0;e=(f|0)!=0?f:c[t>>2]|0;a7(e|0)|0}e=gm[c[16050]&31]()|0;if((e|0)==0){h=0;i=d;return h|0}f=sR(e)|0;if((f|0)==0){j=c[135158]|0;k=(j|0)!=0?j:c[t>>2]|0;be(18472,70,1,k|0)|0;k=c[135158]|0;j=(k|0)!=0?k:c[t>>2]|0;a7(j|0)|0;h=0;i=d;return h|0}if((a[383584]&1)!=0){j=c[135158]|0;k=(j|0)!=0?j:c[t>>2]|0;eQ(k|0,16248,(g=i,i=i+8|0,c[g>>2]=e,g)|0)|0;i=g;k=c[135158]|0;j=(k|0)!=0?k:c[t>>2]|0;a7(j|0)|0}do{if(gj[c[16052]&127](f,e)|0){j=dz(b|0,52080)|0;if((j|0)==0){l=1328;break}k=(be(f|0,1,e|0,j|0)|0)==(e|0);a_(j|0)|0;if(k){m=1}else{l=1328}}else{l=1328}}while(0);if((l|0)==1328){l=c[135158]|0;e=(l|0)!=0?l:c[t>>2]|0;eQ(e|0,14048,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;g=c[135158]|0;b=(g|0)!=0?g:c[t>>2]|0;a7(b|0)|0;m=0}sS(f);h=m;i=d;return h|0}function hb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+16|0;e=d|0;f=d+8|0;if((a[383584]&1)!=0){g=c[135158]|0;h=(g|0)!=0?g:c[t>>2]|0;eQ(h|0,11816,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;h=c[135158]|0;g=(h|0)!=0?h:c[t>>2]|0;a7(g|0)|0}c[e>>2]=0;g=g8(b,e)|0;if((g|0)<0){h=c[135158]|0;k=(h|0)!=0?h:c[t>>2]|0;eQ(k|0,51928,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;b=c[135158]|0;k=(b|0)!=0?b:c[t>>2]|0;a7(k|0)|0;l=0;i=d;return l|0}if((a[383584]&1)!=0){k=c[135158]|0;b=(k|0)!=0?k:c[t>>2]|0;eQ(b|0,49400,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;j=c[135158]|0;b=(j|0)!=0?j:c[t>>2]|0;a7(b|0)|0}c[f>>2]=0;L1864:do{if((a[379456]&1)==0){m=1351}else{if((a[383584]&1)!=0){b=c[135158]|0;j=(b|0)!=0?b:c[t>>2]|0;be(47216,36,1,j|0)|0;j=c[135158]|0;b=(j|0)!=0?j:c[t>>2]|0;a7(b|0)|0}switch(c[96930]|0){case 0:{n=0;o=1;break};case 1:{n=1280;o=1537;break};case 2:case 3:{n=256;o=512;break};case 4:{n=768;o=1024;break};default:{m=1351;break L1864}}b=f2[c[16070]&255](n)|0;j=f2[c[16070]&255](o)|0;if((b|0)==0){p=0;q=0}else{p=sR(b)|0;q=b}if((j|0)==0){r=0;s=0}else{b=sR(j)|0;c[f>>2]=b;r=b;s=j}do{if((p|0)!=0){j=f2[c[16072]&255](n)|0;if((j|0)==0){break}s1(p|0,j|0,q)|0}}while(0);j=f;if((r|0)==0){u=0;v=s;w=n;x=o;y=q;z=p;A=j;break}b=f2[c[16072]&255](o)|0;if((b|0)==0){u=r;v=s;w=n;x=o;y=q;z=p;A=j;break}s1(r|0,b|0,s)|0;u=r;v=s;w=n;x=o;y=q;z=p;A=j}}while(0);if((m|0)==1351){u=0;v=0;w=-1;x=-1;y=0;z=0;A=f}f=c[e>>2]|0;e=gj[c[16032]&127](f,g)|0;do{if(e){do{if((z|0)!=0){g=f2[c[16072]&255](w)|0;if((g|0)==0){break}s1(g|0,z|0,y)|0}}while(0);if((u|0)==0){break}g=f2[c[16072]&255](x)|0;if((g|0)==0){break}s1(g|0,u|0,v)|0}}while(0);if((z|0)==0){B=u}else{sS(z);B=c[A>>2]|0}if((B|0)!=0){sS(B)}sS(f);l=e;i=d;return l|0}function hc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+8200|0;f=e|0;g=e+4096|0;h=e+8192|0;j=f2[c[16070]&255](d)|0;k=f2[c[16072]&255](d)|0;if((k|0)==0|(j|0)==0){i=e;return}l=dz(b|0,52080)|0;do{if((l|0)!=0){m=(be(k|0,1,j|0,l|0)|0)==(j|0);a_(l|0)|0;if(!m){break}if((a[383584]&1)==0){i=e;return}m=c[135158]|0;n=(m|0)!=0?m:c[t>>2]|0;eQ(n|0,43352,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;n=c[135158]|0;m=(n|0)!=0?n:c[t>>2]|0;a7(m|0)|0;i=e;return}}while(0);b=c[135158]|0;be(45800,42,1,((b|0)!=0?b:c[t>>2]|0)|0)|0;b=c[135158]|0;a7(((b|0)!=0?b:c[t>>2]|0)|0)|0;b=c[135158]|0;be(44720,46,1,((b|0)!=0?b:c[t>>2]|0)|0)|0;b=c[135158]|0;a7(((b|0)!=0?b:c[t>>2]|0)|0)|0;b=f|0;l=g|0;g=d8(45336)|0;do{if((g|0)!=0){b5(b|0,4096,25968,(o=i,i=i+8|0,c[o>>2]=g,o)|0)|0;i=o;fm(h|0)|0;m=bq(h|0)|0;di(l|0,4096,25616,m|0)|0;m=sZ(b|0)|0;n=m>>>0>4096?0:4096-m|0;L1919:do{if((n|0)==0){p=l;q=1382}else{r=n;s=f+m|0;u=l;while(1){v=r-1|0;if((v|0)==0){break}w=a[u]|0;a[s]=w;if(w<<24>>24==0){break L1919}else{r=v;s=s+1|0;u=u+1|0}}a[s]=0;p=u;q=1382}}while(0);do{if((q|0)==1382){if((a[p]|0)==0){break}else{x=p}do{x=x+1|0;}while((a[x]|0)!=0)}}while(0);switch(d|0){case 1:case 1537:{y=23624;break};case 512:{y=23424;break};case 768:{y=23128;break};case 1024:{y=22856;break};case 0:case 1280:case 256:{y=51672;break};default:{y=547872}}u=sZ(b|0)|0;s=u>>>0>4096?0:4096-u|0;L1937:do{if((s|0)==0){z=y;q=1395}else{m=s;n=f+u|0;r=y;while(1){v=m-1|0;if((v|0)==0){break}w=a[r]|0;a[n]=w;if(w<<24>>24==0){break L1937}else{m=v;n=n+1|0;r=r+1|0}}a[n]=0;z=r;q=1395}}while(0);do{if((q|0)==1395){if((a[z]|0)==0){break}else{A=z}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);r=dz(b|0,52080)|0;if((r|0)==0){break}n=(be(k|0,1,j|0,r|0)|0)==(j|0);a_(r|0)|0;if(!n){break}n=c[135158]|0;r=(n|0)!=0?n:c[t>>2]|0;eQ(r|0,25144,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;r=c[135158]|0;n=(r|0)!=0?r:c[t>>2]|0;a7(n|0)|0;i=e;return}}while(0);o=c[135158]|0;be(24480,57,1,((o|0)!=0?o:c[t>>2]|0)|0)|0;o=c[135158]|0;a7(((o|0)!=0?o:c[t>>2]|0)|0)|0;i=e;return}function hd(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;e=i;i=i+8280|0;f=e|0;g=e+48|0;h=e+56|0;j=e+4152|0;k=e+8248|0;l=e+8264|0;m=e+8272|0;L1954:do{if((a[420498]|0)!=0){if((a[477948]&1)!=0){break}n=cD(420498,46)|0;o=(n|0)==0?547872:n+1|0;if((o|0)==0){break}if((s4(o|0,42048)|0)!=0){break}a[383620]=1;o=h|0;n=j|0;p=hh(478464,48016)|0;do{if((p|0)!=0){c[g>>2]=0;q=g8(420498,g)|0;if((q|0)<22){r=c[135158]|0;s=(r|0)!=0?r:c[t>>2]|0;eQ(s|0,35672,(u=i,i=i+8|0,c[u>>2]=107,u)|0)|0;i=u;s=c[135158]|0;r=(s|0)!=0?s:c[t>>2]|0;a7(r|0)|0;sS(c[g>>2]|0);v=0}else{r=q-22|0;L1964:do{if((r|0)>22){s=c[g>>2]|0;w=s+q|0;x=s+22|0;y=s+r|0;while(1){if((d[y+1|0]<<8|d[y]|d[y+2|0]<<16|d[y+3|0]<<24|0)==101010256){if((y+((d[y+21|0]<<8|d[y+20|0])+22)|0)==(w|0)){break}}z=y-1|0;if(z>>>0>x>>>0){y=z}else{A=1419;break L1964}}x=d[y+17|0]<<8|d[y+16|0]|d[y+18|0]<<16|d[y+19|0]<<24;w=s+x|0;L1972:do{if((d[s+(x+1)|0]<<8|d[w]|d[s+(x+2)|0]<<16|d[s+(x+3)|0]<<24|0)==33639248){z=p|0;B=p+4|0;C=w;L1974:while(1){D=a[C+10|0]|0;E=a[C+11|0]|0;F=a[C+16|0]|0;G=a[C+17|0]|0;H=a[C+18|0]|0;I=a[C+19|0]|0;J=d[C+21|0]<<8|d[C+20|0]|d[C+22|0]<<16|d[C+23|0]<<24;K=d[C+25|0]<<8|d[C+24|0]|d[C+26|0]<<16|d[C+27|0]<<24;L=d[C+29|0]<<8|d[C+28|0];M=d[C+33|0]<<8|d[C+32|0];N=d[C+31|0]<<8|d[C+30|0];s_(o|0,0,4096);if(L>>>0>4095){A=1425;break}O=C+46|0;s1(o|0,O|0,L)|0;O=d[C+43|0]<<8|d[C+42|0]|d[C+44|0]<<16|d[C+45|0]<<24;P=O+30+(d[s+(O+27)|0]<<8|d[s+(O+26)|0])+(d[s+(O+29)|0]<<8|d[s+(O+28)|0])|0;if((a[383584]&1)!=0){O=c[135158]|0;Q=(O|0)!=0?O:c[t>>2]|0;eQ(Q|0,28528,(u=i,i=i+24|0,c[u>>2]=P,c[u+8>>2]=J,c[u+16>>2]=K,u)|0)|0;i=u;Q=c[135158]|0;O=(Q|0)!=0?Q:c[t>>2]|0;a7(O|0)|0}O=cD(o|0,46)|0;Q=(O|0)==0?547872:O+1|0;L1980:do{if((Q|0)!=0){O=c[B>>2]|0;R=0;while(1){if(R>>>0>=O>>>0){break L1980}if((s4(c[(c[z>>2]|0)+(R<<3)>>2]|0,Q|0)|0)==0){break L1974}else{R=R+1|0}}}}while(0);Q=L+46+N+M|0;R=C+Q|0;if((d[C+(Q+1)|0]<<8|d[R]|d[C+(Q+2)|0]<<16|d[C+(Q+3)|0]<<24|0)==33639248){C=R}else{break L1972}}if((A|0)==1425){C=c[135158]|0;z=(C|0)!=0?C:c[t>>2]|0;eQ(z|0,35672,(u=i,i=i+8|0,c[u>>2]=141,u)|0)|0;i=u;z=c[135158]|0;C=(z|0)!=0?z:c[t>>2]|0;a7(C|0)|0;S=0;break L1964}C=(G&255)<<8|F&255|(H&255)<<16|(I&255)<<24;z=(E&255)<<8|D&255;B=s+P|0;R=cD(o|0,47)|0;ht(n,420498,(R|0)==0?o:R+1|0);if((z|0)==8){R=sR(K)|0;if((R|0)!=0){s_(f|0,0,48);Q=sR(43784)|0;do{if((Q|0)==0){O=c[135158]|0;T=(O|0)!=0?O:c[t>>2]|0;eQ(T|0,35672,(u=i,i=i+8|0,c[u>>2]=61,u)|0)|0;i=u;T=c[135158]|0;O=(T|0)!=0?T:c[t>>2]|0;a7(O|0)|0}else{O=f+28|0;c[O>>2]=Q;c[Q>>2]=0;c[Q+10992>>2]=0;c[Q+10996>>2]=0;c[Q+43780>>2]=1;c[Q+11e3>>2]=1;c[Q+11004>>2]=0;c[Q+11008>>2]=-15;c[f>>2]=B;c[f+4>>2]=J;c[f+12>>2]=R;c[f+16>>2]=K;T=(ks(f)|0)==1;U=c[O>>2]|0;if((U|0)!=0){sS(U);c[O>>2]=0}if(!T){T=c[135158]|0;O=(T|0)!=0?T:c[t>>2]|0;eQ(O|0,35672,(u=i,i=i+8|0,c[u>>2]=71,u)|0)|0;i=u;O=c[135158]|0;T=(O|0)!=0?O:c[t>>2]|0;a7(T|0)|0;break}if((K|0)==0){V=0}else{T=K;O=R;U=-1;while(1){W=T-1|0;X=d[O]|0;Y=c[8192+(((X^U)&15)<<2)>>2]^U>>>4;Z=Y>>>4^c[8192+((Y&15^X>>>4)<<2)>>2];if((W|0)==0){break}else{T=W;O=O+1|0;U=Z}}V=~Z}if((V|0)!=(C|0)){U=c[135158]|0;O=(U|0)!=0?U:c[t>>2]|0;eQ(O|0,20888,(u=i,i=i+16|0,c[u>>2]=V,c[u+8>>2]=C,u)|0)|0;i=u;O=c[135158]|0;U=(O|0)!=0?O:c[t>>2]|0;a7(U|0)|0}U=dz(n|0,52080)|0;do{if((U|0)!=0){O=(be(R|0,1,K|0,U|0)|0)==(K|0);a_(U|0)|0;if(!O){break}sS(R);O=4096;T=420498;M=n;while(1){N=O-1|0;if((N|0)==0){break}L=a[M]|0;a[T]=L;if(L<<24>>24==0){S=1;break L1964}else{O=N;T=T+1|0;M=M+1|0}}a[T]=0;if((a[M]|0)==0){S=1;break L1964}else{_=M}while(1){O=_+1|0;if((a[O]|0)==0){S=1;break L1964}else{_=O}}}}while(0);U=c[135158]|0;M=(U|0)!=0?U:c[t>>2]|0;eQ(M|0,35672,(u=i,i=i+8|0,c[u>>2]=81,u)|0)|0;i=u;M=c[135158]|0;U=(M|0)!=0?M:c[t>>2]|0;a7(U|0)|0}}while(0);sS(R)}C=c[135158]|0;Q=(C|0)!=0?C:c[t>>2]|0;eQ(Q|0,35672,(u=i,i=i+8|0,c[u>>2]=175,u)|0)|0;i=u;Q=c[135158]|0;C=(Q|0)!=0?Q:c[t>>2]|0;a7(C|0)|0;S=0;break L1964}else if((z|0)==0){C=dz(n|0,52080)|0;if((C|0)!=0){Q=(be(B|0,1,K|0,C|0)|0)==(K|0);a_(C|0)|0;if(Q){S=1;break L1964}}Q=c[135158]|0;eQ(((Q|0)!=0?Q:c[t>>2]|0)|0,35672,(u=i,i=i+8|0,c[u>>2]=165,u)|0)|0;i=u;Q=c[135158]|0;a7(((Q|0)!=0?Q:c[t>>2]|0)|0)|0;S=0;break L1964}else{Q=c[135158]|0;eQ(((Q|0)!=0?Q:c[t>>2]|0)|0,35672,(u=i,i=i+8|0,c[u>>2]=178,u)|0)|0;i=u;Q=c[135158]|0;a7(((Q|0)!=0?Q:c[t>>2]|0)|0)|0;S=0;break L1964}}}while(0);s=c[135158]|0;be(23968,101,1,((s|0)!=0?s:c[t>>2]|0)|0)|0;s=c[135158]|0;a7(((s|0)!=0?s:c[t>>2]|0)|0)|0;s=c[135158]|0;eQ(((s|0)!=0?s:c[t>>2]|0)|0,35672,(u=i,i=i+8|0,c[u>>2]=186,u)|0)|0;i=u;s=c[135158]|0;a7(((s|0)!=0?s:c[t>>2]|0)|0)|0;S=0}else{A=1419}}while(0);if((A|0)==1419){r=c[135158]|0;q=(r|0)!=0?r:c[t>>2]|0;eQ(q|0,35672,(u=i,i=i+8|0,c[u>>2]=113,u)|0)|0;i=u;q=c[135158]|0;r=(q|0)!=0?q:c[t>>2]|0;a7(r|0)|0;S=0}sS(c[g>>2]|0);v=S}r=p+4|0;q=p|0;s=c[q>>2]|0;if((c[r>>2]|0)==0){$=s}else{w=0;x=s;while(1){sS(c[x+(w<<3)>>2]|0);s=w+1|0;y=c[q>>2]|0;if(s>>>0<(c[r>>2]|0)>>>0){w=s;x=y}else{$=y;break}}}sS($);sS(p);if(v){aa=4096;ab=383621;ac=420498}else{break}while(1){x=aa-1|0;if((x|0)==0){break}w=a[ac]|0;a[ab]=w;if(w<<24>>24==0){break L1954}else{aa=x;ab=ab+1|0;ac=ac+1|0}}a[ab]=0;if((a[ac]|0)==0){break L1954}else{ad=ac}while(1){ad=ad+1|0;if((a[ad]|0)==0){break L1954}}}}while(0);p=c[135158]|0;n=(p|0)!=0?p:c[t>>2]|0;eQ(n|0,40992,(u=i,i=i+8|0,c[u>>2]=420498,u)|0)|0;i=u;n=c[135158]|0;p=(n|0)!=0?n:c[t>>2]|0;a7(p|0)|0;a[383620]=0;ae=0;i=e;return ae|0}}while(0);L2045:do{switch(b|0){case 1:{u=m|0;c[u>>2]=(a[420498]|0)!=0?420498:0;c[m+4>>2]=387728;if(he(260,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 0:{if((a[541708]&1)==0){c[l>>2]=420498;if(he(0,l,1)|0){break L2045}else{ae=0}i=e;return ae|0}if((a[477950]&1)==0){u=c[135158]|0;ad=(u|0)!=0?u:c[t>>2]|0;be(26680,78,1,ad|0)|0;ad=c[135158]|0;u=(ad|0)!=0?ad:c[t>>2]|0;a7(u|0)|0;ae=0;i=e;return ae|0}else{if(f2[c[16060]&255](0)|0){break L2045}else{ae=0}i=e;return ae|0}break};case 2:{u=m|0;c[u>>2]=(a[420498]|0)!=0?420498:0;c[m+4>>2]=391824;if(he(257,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 3:{u=m|0;c[u>>2]=(a[420498]|0)!=0?420498:0;c[m+4>>2]=391824;if(he(258,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 4:{u=k|0;c[u>>2]=(a[420498]|0)!=0?420498:0;c[k+4>>2]=(a[395920]|0)!=0?395920:0;c[k+8>>2]=(a[400016]|0)!=0?400016:0;if(he(259,u,3)|0){break L2045}else{ae=0}i=e;return ae|0};default:{u=c[135158]|0;be(40024,39,1,((u|0)!=0?u:c[t>>2]|0)|0)|0;u=c[135158]|0;a7(((u|0)!=0?u:c[t>>2]|0)|0)|0;ae=0;i=e;return ae|0}}}while(0);ae=1;i=e;return ae|0}function he(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=i;i=i+520|0;h=g|0;j=g+368|0;k=g+400|0;l=g+408|0;m=g+416|0;n=g+424|0;o=g+440|0;p=g+456|0;if((f|0)==0|f>>>0>4){q=0;i=g;return q|0}s_(n|0,0,16);s_(o|0,0,16);s_(p|0,0,64);do{if((a[449170]|0)==0){r=0}else{s=dz(449170,11144)|0;if((s|0)==0){r=0;break}e3(s|0,0,2)|0;u=(cx(s|0)|0)+2|0;fb(s|0);v=(u|0)==0?0:u;w=sR(v)|0;if((w|0)==0){a_(s|0)|0;r=0;break}if((c[w-4>>2]&3|0)!=0){s_(w|0,0,v|0)}v=w;x=w;while(1){if((eX(s|0)|0)!=0){y=x;break}cg(x|0,u-x+v|0,s|0)|0;z=x+(sZ(x|0)|0)|0;if((z|0)==0){y=0;break}else{x=z}}x=cm(y|0,-1|0)|0;if((x|0)!=0){a[x]=0}a_(s|0)|0;if((a[383584]&1)==0){r=w;break}x=c[135158]|0;eQ(((x|0)!=0?x:c[t>>2]|0)|0,27080,(A=i,i=i+8|0,c[A>>2]=449170,A)|0)|0;i=A;x=c[135158]|0;a7(((x|0)!=0?x:c[t>>2]|0)|0)|0;r=w}}while(0);y=(a[383584]&1)!=0;do{if((a[477884]&1)==0){if(y){x=c[135158]|0;v=(x|0)!=0?x:c[t>>2]|0;x=c[e>>2]|0;eQ(v|0,39112,(A=i,i=i+8|0,c[A>>2]=x,A)|0)|0;i=A;x=c[135158]|0;v=(x|0)!=0?x:c[t>>2]|0;a7(v|0)|0}v=c[e>>2]|0;x=n|0;c[m>>2]=0;u=g8(v,m)|0;if((u|0)<1){B=u;C=0}else{L2097:do{if((a[465554]&1)==0){v=c[m>>2]|0;c[k>>2]=0;z=a[465555]|0;D=a[465556]|0;E=a[465557]|0;if(((D&1)+(z&1)+(E&1)|0)>1){F=c[135158]|0;G=(F|0)!=0?F:c[t>>2]|0;be(31216,77,1,G|0)|0;G=c[135158]|0;F=(G|0)!=0?G:c[t>>2]|0;a7(F|0)|0;H=u;I=v;break}F=(E|z)&1;G=((D|z)&1)!=0;if(((E|D)&1)!=0|(a[465558]|0)==0){J=1517}else{D=g8(465558,k)|0;if((D|0)>-1){K=30672;L=465558;M=4;N=D}else{J=1517}}do{if((J|0)==1517){if(!(F<<24>>24!=0|(a[469654]|0)==0)){D=g8(469654,k)|0;if((D|0)>-1){K=30272;L=469654;M=6;N=D;break}}if(!(G|(a[473750]|0)==0)){D=g8(473750,k)|0;if((D|0)>-1){K=29920;L=473750;M=8;N=D;break}}if((a[383584]&1)==0){H=u;I=v;break L2097}D=c[135158]|0;E=(D|0)!=0?D:c[t>>2]|0;be(29560,43,1,E|0)|0;E=c[135158]|0;D=(E|0)!=0?E:c[t>>2]|0;a7(D|0)|0;H=u;I=v;break L2097}}while(0);if((a[383584]&1)!=0){G=c[135158]|0;F=(G|0)!=0?G:c[t>>2]|0;eQ(F|0,28976,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=L,A)|0)|0;i=A;F=c[135158]|0;G=(F|0)!=0?F:c[t>>2]|0;a7(G|0)|0}G=u<<2;c[l>>2]=G;F=sR(G)|0;if((F|0)==0){G=c[135158]|0;D=(G|0)!=0?G:c[t>>2]|0;be(28232,67,1,D|0)|0;D=c[135158]|0;G=(D|0)!=0?D:c[t>>2]|0;a7(G|0)|0;c[m>>2]=v;sS(c[k>>2]|0);H=u;I=v;break}G=c[k>>2]|0;D=f1[M&15](G,N,v,u,F,l)|0;if((D|0)==1){if((a[383584]&1)!=0){E=c[135158]|0;z=(E|0)!=0?E:c[t>>2]|0;eQ(z|0,27816,(A=i,i=i+8|0,c[A>>2]=K,A)|0)|0;i=A;z=c[135158]|0;E=(z|0)!=0?z:c[t>>2]|0;a7(E|0)|0}sS(v);c[m>>2]=F;O=c[l>>2]|0;P=F}else{F=c[135158]|0;E=(F|0)!=0?F:c[t>>2]|0;eQ(E|0,27480,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=D,A)|0)|0;i=A;D=c[135158]|0;E=(D|0)!=0?D:c[t>>2]|0;a7(E|0)|0;O=u;P=v}sS(G);H=O;I=P}else{H=u;I=c[m>>2]|0}}while(0);u=(H|0)==0;if((I|0)==0|u){Q=0}else{w=H;s=I;G=-1;while(1){E=w-1|0;D=d[s]|0;F=c[8192+(((D^G)&15)<<2)>>2]^G>>>4;R=F>>>4^c[8192+((F&15^D>>>4)<<2)>>2];if((E|0)==0){break}else{w=E;s=s+1|0;G=R}}Q=~R}c[96931]=Q;G=h;s_(G|0,0,360);s=h+324|0;s1(s|0,62776,32)|0;s=h+360|0;c[s>>2]=H;c[s+4>>2]=0;w=h+64|0;if(u){S=0}else{E=H;D=I;F=0;while(1){z=64-F|0;T=E>>>0<z>>>0?E:z;z=G+F|0;s1(z|0,D|0,T)|0;z=T+(c[w>>2]|0)|0;c[w>>2]=z;if((z|0)==64){hF(h);U=c[w>>2]|0}else{U=z}if((E|0)==(T|0)){S=U;break}else{E=E-T|0;D=D+T|0;F=U}}}c[w>>2]=S+1;a[h+S|0]=-128;F=c[w>>2]|0;if(F>>>0>56){s_(G+F|0,0,64-F|0);hF(h);V=c[w>>2]|0}else{V=F}s_(G+V|0,0,56-V|0);F=c[s>>2]|0;c[h+56>>2]=ev(F>>>29|c[s+4>>2]<<3|0)|0;c[h+60>>2]=ev(F<<3|0>>>29|0)|0;hF(h);c[j>>2]=ev(c[h+324>>2]|0)|0;c[j+4>>2]=ev(c[h+328>>2]|0)|0;c[j+8>>2]=ev(c[h+332>>2]|0)|0;c[j+12>>2]=ev(c[h+336>>2]|0)|0;c[j+16>>2]=ev(c[h+340>>2]|0)|0;c[j+20>>2]=ev(c[h+344>>2]|0)|0;c[j+24>>2]=ev(c[h+348>>2]|0)|0;c[j+28>>2]=ev(c[h+352>>2]|0)|0;F=j;D=0;do{b5(540468+(D<<1)|0,3,18144,(A=i,i=i+8|0,c[A>>2]=d[F+D|0]|0,A)|0)|0;i=A;D=D+1|0;}while(D>>>0<32);if((a[383584]&1)!=0){D=c[135158]|0;F=(D|0)!=0?D:c[t>>2]|0;D=c[96931]|0;eQ(F|0,32056,(A=i,i=i+16|0,c[A>>2]=D,c[A+8>>2]=540468,A)|0)|0;i=A;D=c[135158]|0;F=(D|0)!=0?D:c[t>>2]|0;a7(F|0)|0}c[x>>2]=I;B=H;C=I}c[o>>2]=B;if((B|0)==-1){F=c[135158]|0;D=(F|0)!=0?F:c[t>>2]|0;be(38176,46,1,D|0)|0;D=c[135158]|0;F=(D|0)!=0?D:c[t>>2]|0;a7(F|0)|0;W=0;break}if((a[383584]&1)==0){X=C;Y=B;J=1553;break}F=c[135158]|0;D=(F|0)!=0?F:c[t>>2]|0;eQ(D|0,36872,(A=i,i=i+8|0,c[A>>2]=B,A)|0)|0;i=A;D=c[135158]|0;F=(D|0)!=0?D:c[t>>2]|0;a7(F|0)|0;X=C;Y=B;J=1553}else{if(!y){X=0;Y=0;J=1553;break}F=c[135158]|0;D=(F|0)!=0?F:c[t>>2]|0;be(34912,72,1,D|0)|0;D=c[135158]|0;F=(D|0)!=0?D:c[t>>2]|0;a7(F|0)|0;X=0;Y=0;J=1553}}while(0);L2157:do{if((J|0)==1553){y=p|0;c[p>>2]=c[e>>2];c[p+4>>2]=X;c[p+8>>2]=Y;c[p+12>>2]=r;L2159:do{if(f>>>0>1){B=1;L2160:while(1){Z=e+(B<<2)|0;C=c[Z>>2]|0;do{if((C|0)==0){_=0}else{if((a[477884]&1)!=0){_=C;break}I=g8(C,n+(B<<2)|0)|0;c[o+(B<<2)>>2]=I;if((I|0)==-1){break L2160}_=c[Z>>2]|0}}while(0);c[p+(B<<4)>>2]=_;c[p+(B<<4)+4>>2]=c[n+(B<<2)>>2];c[p+(B<<4)+8>>2]=c[o+(B<<2)>>2];B=B+1|0;if(B>>>0>=f>>>0){break L2159}}B=c[135158]|0;eQ(((B|0)!=0?B:c[t>>2]|0)|0,33632,(A=i,i=i+8|0,c[A>>2]=c[Z>>2],A)|0)|0;i=A;B=c[135158]|0;a7(((B|0)!=0?B:c[t>>2]|0)|0)|0;W=0;break L2157}}while(0);if((b|0)==0){if(f2[c[16060]&255](y)|0){W=1;break}}else{if(f7[c[16058]&127](b,y,f)|0){W=1;break}}x=c[135158]|0;B=(x|0)!=0?x:c[t>>2]|0;be(32512,42,1,B|0)|0;B=c[135158]|0;x=(B|0)!=0?B:c[t>>2]|0;a7(x|0)|0;W=0}}while(0);sS(c[n>>2]|0);sS(c[n+4>>2]|0);sS(c[n+8>>2]|0);sS(c[n+12>>2]|0);sS(r);q=W;i=g;return q|0}function hf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=a[b+4|0]&1;f=a[d+4|0]&1;if(e<<24>>24==f<<24>>24){g=s4(c[b>>2]|0,c[d>>2]|0)|0;return g|0}else{g=(f&255)-(e&255)|0;return g|0}return 0}function hg(a,b){a=a|0;b=b|0;return s4(c[a>>2]|0,c[b>>2]|0)|0}function hh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+8|0;e=d|0;f=sR(12)|0;do{if((f|0)==0){g=0}else{do{if((c[f-4>>2]&3|0)==0){h=f+4|0;j=c[h>>2]|0;if(j>>>0<32){k=h;l=j;m=f;break}j=c[135158]|0;h=(j|0)!=0?j:c[t>>2]|0;eQ(h|0,33848,(n=i,i=i+16|0,c[n>>2]=13888,c[n+8>>2]=69,n)|0)|0;i=n;h=c[135158]|0;j=(h|0)!=0?h:c[t>>2]|0;a7(j|0)|0;cz(2);return 0}else{s_(f|0,0,12);k=f+4|0;l=0;m=f}}while(0);j=f;h=c[j>>2]|0;o=h;p=sT(o,256)|0;if((p|0)==0){if((l|0)!=0){q=0;do{sS(c[h+(q<<3)>>2]|0);q=q+1|0;}while(q>>>0<l>>>0)}sS(o);sS(f);g=0;break}q=p;c[j>>2]=q;h=f+8|0;c[h>>2]=32;r=dT(a|0)|0;L2197:do{if((r|0)==0){s=0;u=l;v=q}else{w=eM(r|0,b|0,e|0)|0;L2199:do{if((w|0)!=0){x=w;y=q;z=l;A=32;while(1){if(z>>>0<A>>>0){B=y;C=A}else{D=A<<1;if(z>>>0>=D>>>0){break}E=sT(y,A<<4)|0;if((E|0)==0){s=r;u=z;v=y;break L2197}F=E;c[j>>2]=F;c[h>>2]=D;B=F;C=D}D=dT(x|0)|0;if((D|0)==0){s=r;u=z;v=B;break L2197}c[B+(z<<3)>>2]=D;D=c[k>>2]|0;F=c[j>>2]|0;c[F+(D<<3)+4>>2]=0;E=D+1|0;c[k>>2]=E;D=eM(0,b|0,e|0)|0;if((D|0)==0){break L2199}else{x=D;y=F;z=E;A=C}}A=c[135158]|0;eQ(((A|0)!=0?A:c[t>>2]|0)|0,33848,(n=i,i=i+16|0,c[n>>2]=13888,c[n+8>>2]=69,n)|0)|0;i=n;A=c[135158]|0;a7(((A|0)!=0?A:c[t>>2]|0)|0)|0;cz(2);return 0}}while(0);sS(r);G=m;i=d;return G|0}}while(0);if((u|0)!=0){r=0;do{sS(c[v+(r<<3)>>2]|0);r=r+1|0;}while(r>>>0<u>>>0)}sS(v);sS(f);g=s}}while(0);sS(g);G=0;i=d;return G|0}function hi(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;i=i+8264|0;g=f|0;h=f+4096|0;j=f+4168|0;k=sR(12)|0;if((k|0)==0){l=0;i=f;return l|0}do{if((c[k-4>>2]&3|0)==0){m=k+4|0;n=c[m>>2]|0;if(n>>>0<32){o=m;p=n;q=k;break}n=c[135158]|0;m=(n|0)!=0?n:c[t>>2]|0;eQ(m|0,33848,(r=i,i=i+16|0,c[r>>2]=13888,c[r+8>>2]=69,r)|0)|0;i=r;m=c[135158]|0;n=(m|0)!=0?m:c[t>>2]|0;a7(n|0)|0;cz(2);return 0}else{s_(k|0,0,12);o=k+4|0;p=0;q=k}}while(0);n=k;m=c[n>>2]|0;s=m;u=sT(s,256)|0;if((u|0)==0){if((p|0)!=0){v=0;do{sS(c[m+(v<<3)>>2]|0);v=v+1|0;}while(v>>>0<p>>>0)}sS(s);sS(k);l=0;i=f;return l|0}s=u;c[n>>2]=s;u=k+8|0;c[u>>2]=32;if((d|0)==0){w=0}else{w=hh(d,48016)|0}d=bT(b|0)|0;L2238:do{if((d|0)==0){v=c[135158]|0;m=(v|0)!=0?v:c[t>>2]|0;eQ(m|0,20160,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;m=c[135158]|0;v=(m|0)!=0?m:c[t>>2]|0;a7(v|0)|0;x=p;y=s}else{v=cb(d|0)|0;L2240:do{if((v|0)!=0){m=j|0;z=(w|0)==0;A=g|0;B=w|0;C=w+4|0;D=h+8|0;E=v;F=s;G=p;H=32;L2242:while(1){I=E+4|0;J=cD(I|0,46)|0;K=(J|0)==0?547872:J+1|0;hj(m,b,I);J=a[E+1036|0]|0;do{if((J<<24>>24|0)==0|(J<<24>>24|0)==10){if((fh(m|0,h|0)|0)<0){L=0;M=1619;break}N=(c[D>>2]&61440|0)==16384;M=1618}else if((J<<24>>24|0)==4){N=1;M=1618}else{L=0;M=1619}}while(0);if((M|0)==1618){M=0;if(e|N^1){L=N;M=1619}else{O=F;P=G;Q=H}}L2249:do{if((M|0)==1619){M=0;if((da(I|0,35160)|0)==0){O=F;P=G;Q=H;break}if((da(I|0,23632)|0)==0){O=F;P=G;Q=H;break}L2253:do{if(!(L|z)){b5(A|0,4096,30736,(r=i,i=i+16|0,c[r>>2]=35160,c[r+8>>2]=K,r)|0)|0;i=r;J=c[C>>2]|0;R=0;while(1){if(R>>>0>=J>>>0){O=F;P=G;Q=H;break L2249}S=c[(c[B>>2]|0)+(R<<3)>>2]|0;if((s4(S|0,K|0)|0)==0){break L2253}if((s4(S|0,A|0)|0)==0){break}else{R=R+1|0}}}}while(0);R=L&1;if(G>>>0<H>>>0){T=F;U=H}else{J=H<<1;if(G>>>0>=J>>>0){M=1629;break L2242}S=sT(F,H<<4)|0;if((S|0)==0){V=F;M=1638;break L2242}W=S;c[n>>2]=W;c[u>>2]=J;T=W;U=J}J=dT(m|0)|0;if((J|0)==0){V=T;M=1638;break L2242}c[T+(G<<3)>>2]=J;J=c[o>>2]|0;W=c[n>>2]|0;c[W+(J<<3)+4>>2]=R;R=J+1|0;c[o>>2]=R;O=W;P=R;Q=U}}while(0);K=cb(d|0)|0;if((K|0)==0){break L2240}else{E=K;F=O;G=P;H=Q}}if((M|0)==1629){H=c[135158]|0;F=(H|0)!=0?H:c[t>>2]|0;eQ(F|0,33848,(r=i,i=i+16|0,c[r>>2]=13888,c[r+8>>2]=69,r)|0)|0;i=r;F=c[135158]|0;H=(F|0)!=0?F:c[t>>2]|0;a7(H|0)|0;cz(2);return 0}else if((M|0)==1638){H=c[135158]|0;eQ(((H|0)!=0?H:c[t>>2]|0)|0,20160,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;H=c[135158]|0;a7(((H|0)!=0?H:c[t>>2]|0)|0)|0;fq(d|0)|0;x=G;y=V;break L2238}}}while(0);fq(d|0)|0;if((w|0)==0){l=q;i=f;return l|0}v=w+4|0;H=w|0;F=c[H>>2]|0;if((c[v>>2]|0)==0){X=F}else{E=0;m=F;while(1){sS(c[m+(E<<3)>>2]|0);F=E+1|0;A=c[H>>2]|0;if(F>>>0<(c[v>>2]|0)>>>0){E=F;m=A}else{X=A;break}}}sS(X);sS(w);l=q;i=f;return l|0}}while(0);if((x|0)!=0){q=0;do{sS(c[y+(q<<3)>>2]|0);q=q+1|0;}while(q>>>0<x>>>0)}sS(y);sS(k);if((w|0)==0){l=0;i=f;return l|0}k=w+4|0;y=w|0;x=c[y>>2]|0;if((c[k>>2]|0)==0){Y=x}else{q=0;X=x;while(1){sS(c[X+(q<<3)>>2]|0);x=q+1|0;d=c[y>>2]|0;if(x>>>0<(c[k>>2]|0)>>>0){q=x;X=d}else{Y=d;break}}}sS(Y);sS(w);l=0;i=f;return l|0}function hj(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1656;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1656){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;p=h}while(1){g=o+1|0;d=p+1|0;if((a[g]|0)==0){n=d;break}else{o=g;p=d}}}}while(0);if(n>>>0>=4096){n=c[135158]|0;p=(n|0)!=0?n:c[t>>2]|0;eQ(p|0,33848,(q=i,i=i+16|0,c[q>>2]=13888,c[q+8>>2]=573,q)|0)|0;i=q;p=c[135158]|0;n=(p|0)!=0?p:c[t>>2]|0;a7(n|0)|0;cz(2)}if((a[b]|0)!=0){hq(b)}n=sZ(b|0)|0;p=n>>>0>4096?0:4096-n|0;L2308:do{if((p|0)==0){r=0;s=e;l=1667}else{o=p;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){u=h;break L2308}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;r=h;s=j;l=1667}}while(0);do{if((l|0)==1667){if((a[s]|0)==0){u=r;break}else{v=s;w=r}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){u=b;break}else{v=e;w=b}}}}while(0);if((u+n|0)>>>0<4096){i=f;return}else{f=c[135158]|0;n=(f|0)!=0?f:c[t>>2]|0;eQ(n|0,33848,(q=i,i=i+16|0,c[q>>2]=13888,c[q+8>>2]=578,q)|0)|0;i=q;q=c[135158]|0;n=(q|0)!=0?q:c[t>>2]|0;a7(n|0)|0;cz(2)}}function hk(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+4096|0;g=f|0;h=4096;j=0;k=g;l=d;while(1){d=h-1|0;if((d|0)==0){m=1675;break}n=a[l]|0;a[k]=n;if(n<<24>>24==0){o=j;break}else{h=d;j=j+1|0;k=k+1|0;l=l+1|0}}do{if((m|0)==1675){a[k]=0;if((a[l]|0)==0){o=j;break}else{p=l;q=j}while(1){h=p+1|0;d=q+1|0;if((a[h]|0)==0){o=d;break}else{p=h;q=d}}}}while(0);if(o>>>0>=4096){o=c[135158]|0;q=(o|0)!=0?o:c[t>>2]|0;eQ(q|0,33848,(r=i,i=i+16|0,c[r>>2]=13888,c[r+8>>2]=409,r)|0)|0;i=r;q=c[135158]|0;o=(q|0)!=0?q:c[t>>2]|0;a7(o|0)|0;cz(2)}o=cD(g|0,46)|0;if((o|0)==0){s=4096;u=0;v=b;w=g}else{a[o]=0;s=4096;u=0;v=b;w=g}while(1){g=s-1|0;if((g|0)==0){m=1683;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=u;break}else{s=g;u=u+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1683){a[v]=0;if((a[w]|0)==0){x=u;break}else{y=w;z=u}while(1){s=y+1|0;g=z+1|0;if((a[s]|0)==0){x=g;break}else{y=s;z=g}}}}while(0);if(x>>>0>=4096){x=c[135158]|0;z=(x|0)!=0?x:c[t>>2]|0;eQ(z|0,33848,(r=i,i=i+16|0,c[r>>2]=13888,c[r+8>>2]=414,r)|0)|0;i=r;z=c[135158]|0;x=(z|0)!=0?z:c[t>>2]|0;a7(x|0)|0;cz(2)}x=sZ(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2347:do{if((z|0)==0){A=0;B=e;m=1692}else{y=z;u=0;w=b+x|0;v=e;while(1){g=y-1|0;if((g|0)==0){break}s=a[v]|0;a[w]=s;if(s<<24>>24==0){C=u;break L2347}else{y=g;u=u+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=u;B=v;m=1692}}while(0);do{if((m|0)==1692){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[135158]|0;x=(f|0)!=0?f:c[t>>2]|0;eQ(x|0,33848,(r=i,i=i+16|0,c[r>>2]=13888,c[r+8>>2]=415,r)|0)|0;i=r;r=c[135158]|0;x=(r|0)!=0?r:c[t>>2]|0;a7(x|0)|0;cz(2)}}function hl(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1700;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1700){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;p=h}while(1){g=o+1|0;d=p+1|0;if((a[g]|0)==0){n=d;break}else{o=g;p=d}}}}while(0);if(n>>>0>=4096){n=c[135158]|0;p=(n|0)!=0?n:c[t>>2]|0;eQ(p|0,33848,(q=i,i=i+16|0,c[q>>2]=13888,c[q+8>>2]=420,q)|0)|0;i=q;p=c[135158]|0;n=(p|0)!=0?p:c[t>>2]|0;a7(n|0)|0;cz(2)}n=sZ(b|0)|0;p=n>>>0>4096?0:4096-n|0;L2373:do{if((p|0)==0){r=0;s=e;l=1709}else{o=p;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){u=h;break L2373}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;r=h;s=j;l=1709}}while(0);do{if((l|0)==1709){if((a[s]|0)==0){u=r;break}else{v=s;w=r}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){u=b;break}else{v=e;w=b}}}}while(0);if((u+n|0)>>>0<4096){i=f;return}else{f=c[135158]|0;n=(f|0)!=0?f:c[t>>2]|0;eQ(n|0,33848,(q=i,i=i+16|0,c[q>>2]=13888,c[q+8>>2]=421,q)|0)|0;i=q;q=c[135158]|0;n=(q|0)!=0?q:c[t>>2]|0;a7(n|0)|0;cz(2)}}function hm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;hq(b);f=cD(416402,47)|0;g=(f|0)==0?416402:f+1|0;f=sZ(b|0)|0;h=f>>>0>4096?0:4096-f|0;L2388:do{if((h|0)==0){j=0;k=g;l=1719}else{m=h;n=0;o=b+f|0;p=g;while(1){q=m-1|0;if((q|0)==0){break}r=a[p]|0;a[o]=r;if(r<<24>>24==0){s=n;break L2388}else{m=q;n=n+1|0;o=o+1|0;p=p+1|0}}a[o]=0;j=n;k=p;l=1719}}while(0);do{if((l|0)==1719){if((a[k]|0)==0){s=j;break}else{u=k;v=j}while(1){g=u+1|0;h=v+1|0;if((a[g]|0)==0){s=h;break}else{u=g;v=h}}}}while(0);if((s+f|0)>>>0>=4096){f=c[135158]|0;s=(f|0)!=0?f:c[t>>2]|0;eQ(s|0,33848,(w=i,i=i+16|0,c[w>>2]=13888,c[w+8>>2]=457,w)|0)|0;i=w;s=c[135158]|0;f=(s|0)!=0?s:c[t>>2]|0;a7(f|0)|0;cz(2)}f=sZ(b|0)|0;s=f>>>0>4096?0:4096-f|0;L2402:do{if((s|0)==0){x=0;y=d;l=1728}else{v=s;u=0;j=b+f|0;k=d;while(1){p=v-1|0;if((p|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=u;break L2402}else{v=p;u=u+1|0;j=j+1|0;k=k+1|0}}a[j]=0;x=u;y=k;l=1728}}while(0);do{if((l|0)==1728){if((a[y]|0)==0){z=x;break}else{A=y;B=x}while(1){d=A+1|0;b=B+1|0;if((a[d]|0)==0){z=b;break}else{A=d;B=b}}}}while(0);if((z+f|0)>>>0<4096){i=e;return}else{e=c[135158]|0;f=(e|0)!=0?e:c[t>>2]|0;eQ(f|0,33848,(w=i,i=i+16|0,c[w>>2]=13888,c[w+8>>2]=458,w)|0)|0;i=w;w=c[135158]|0;f=(w|0)!=0?w:c[t>>2]|0;a7(f|0)|0;cz(2)}}function hn(){var b=0,d=0.0,e=0.0,f=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0,p=0.0;b=i;a[477949]=0;d=+h[59739];if(d<=0.0){i=b;return}e=+h[59740];if(e<=0.0){i=b;return}f=+g[72372];j=f;if(+V(+(1.0-d/j))>.05000000074505806){if((a[383584]&1)==0){k=d;l=f}else{m=c[135158]|0;n=(m|0)!=0?m:c[t>>2]|0;f=d;eQ(n|0,30576,(o=i,i=i+16|0,h[o>>3]=j,h[o+8>>3]=f,o)|0)|0;i=o;n=c[135158]|0;m=(n|0)!=0?n:c[t>>2]|0;a7(m|0)|0;k=+h[59739];l=+g[72372]}do{if(k>l){a[477949]=1;if((a[383584]&1)==0){break}m=c[135158]|0;n=(m|0)!=0?m:c[t>>2]|0;be(30208,57,1,n|0)|0;n=c[135158]|0;m=(n|0)!=0?n:c[t>>2]|0;a7(m|0)|0}}while(0);p=+h[59740]}else{p=e*(j/d)}d=p;g[74442]=d;if((a[383584]&1)!=0){m=c[135158]|0;n=(m|0)!=0?m:c[t>>2]|0;p=d;eQ(n|0,29872,(o=i,i=i+8|0,h[o>>3]=p,o)|0)|0;i=o;o=c[135158]|0;n=(o|0)!=0?o:c[t>>2]|0;a7(n|0)|0}n=c[136866]|0;if((n|0)==0){i=b;return}if((a[477949]&1)!=0){f0[c[(c[136863]|0)+8>>2]&255](n,1);i=b;return}o=(a[547480]&1)!=0;if((a[383586]&1)!=0){f0[c[(c[136863]|0)+8>>2]&255](n,(a[281264]&1)==0|o)}n=c[136865]|0;if((a[383585]&1)!=0&(n|0)!=0){f0[c[(c[136862]|0)+16>>2]&255](n,(a[301872]&1)==0|o)}c[120672]=o?c[120673]|0:c[120674]|0;i=b;return}function ho(){var a=0,b=0,d=0;a=c[136914]|0;if((a|0)==0){b=0;return b|0}d=c[a+4>>2]|0;if((d|0)==0){b=0;return b|0}b=f2[d&255](c[136866]|0)|0;return b|0}function hp(a){a=a|0;var b=0,d=0,e=0;b=c[136914]|0;if((b|0)==0){d=0;return d|0}e=c[b+8>>2]|0;if((e|0)==0){d=0;return d|0}d=gj[e&127](c[136866]|0,a)|0;return d|0}function hq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=cD(b|0,47)|0;g=sZ(b|0)|0;if((f|0)==0){h=g>>>0>4096?0:4096-g|0;L2470:do{if((h|0)==0){j=0;k=19232;l=1788}else{m=b+g|0;do{if((h|0)==1){n=19232;o=m;p=0}else{q=b+(g+1)|0;a[m]=47;if((h|0)==2){n=19233;o=q;p=1;break}a[q]=0;r=1;break L2470}}while(0);a[o]=0;j=p;k=n;l=1788}}while(0);do{if((l|0)==1788){if((a[k]|0)==0){r=j;break}else{s=k;u=j}while(1){n=s+1|0;p=u+1|0;if((a[n]|0)==0){r=p;break}else{s=n;u=p}}}}while(0);if((r+g|0)>>>0<4096){i=d;return}else{r=c[135158]|0;u=(r|0)!=0?r:c[t>>2]|0;eQ(u|0,33848,(v=i,i=i+16|0,c[v>>2]=13888,c[v+8>>2]=450,v)|0)|0;i=v;u=c[135158]|0;r=(u|0)!=0?u:c[t>>2]|0;a7(r|0)|0;cz(2)}}if((f|0)==(b+(g-1)|0)){i=d;return}g=e|0;r=a[f]|0;a[g]=r;a[e+1|0]=0;e=sZ(b|0)|0;f=e>>>0>4096?0:4096-e|0;L2488:do{if((f|0)==0){w=0;x=g;y=r;l=1780}else{u=f;s=0;j=b+e|0;k=g;while(1){p=u-1|0;if((p|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=s;break L2488}else{u=p;s=s+1|0;j=j+1|0;k=k+1|0}}a[j]=0;w=s;x=k;y=a[k]|0;l=1780}}while(0);do{if((l|0)==1780){if(y<<24>>24==0){z=w;break}else{A=x;B=w}while(1){g=A+1|0;b=B+1|0;if((a[g]|0)==0){z=b;break}else{A=g;B=b}}}}while(0);if((z+e|0)>>>0<4096){i=d;return}else{d=c[135158]|0;e=(d|0)!=0?d:c[t>>2]|0;eQ(e|0,33848,(v=i,i=i+16|0,c[v>>2]=13888,c[v+8>>2]=447,v)|0)|0;i=v;v=c[135158]|0;e=(v|0)!=0?v:c[t>>2]|0;a7(e|0)|0;cz(2)}}function hr(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=cD(d|0,47)|0;h=(g|0)==0?d:g+1|0;L2503:do{if((e|0)==0){j=0;k=h;l=1801}else{g=e;d=0;m=b;n=h;while(1){o=g-1|0;if((o|0)==0){break}p=a[n]|0;a[m]=p;if(p<<24>>24==0){q=d;break L2503}else{g=o;d=d+1|0;m=m+1|0;n=n+1|0}}a[m]=0;j=d;k=n;l=1801}}while(0);do{if((l|0)==1801){if((a[k]|0)==0){q=j;break}else{r=k;s=j}while(1){h=r+1|0;b=s+1|0;if((a[h]|0)==0){q=b;break}else{r=h;s=b}}}}while(0);if(q>>>0<e>>>0){i=f;return}else{f=c[135158]|0;e=(f|0)!=0?f:c[t>>2]|0;eQ(e|0,33848,(e=i,i=i+16|0,c[e>>2]=13888,c[e+8>>2]=470,e)|0)|0;i=e;e=c[135158]|0;f=(e|0)!=0?e:c[t>>2]|0;a7(f|0)|0;cz(2)}}function hs(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=4096;g=0;h=b;j=d;while(1){d=f-1|0;if((d|0)==0){k=1809;break}l=a[j]|0;a[h]=l;if(l<<24>>24==0){m=g;break}else{f=d;g=g+1|0;h=h+1|0;j=j+1|0}}do{if((k|0)==1809){a[h]=0;if((a[j]|0)==0){m=g;break}else{n=j;o=g}while(1){f=n+1|0;d=o+1|0;if((a[f]|0)==0){m=d;break}else{n=f;o=d}}}}while(0);if(m>>>0>=4096){m=c[135158]|0;o=(m|0)!=0?m:c[t>>2]|0;eQ(o|0,33848,(p=i,i=i+16|0,c[p>>2]=13888,c[p+8>>2]=475,p)|0)|0;i=p;o=c[135158]|0;m=(o|0)!=0?o:c[t>>2]|0;a7(m|0)|0;cz(2)}if((sZ(b|0)|0)>>>0<2){i=e;return}m=cD(b|0,47)|0;if((m|0)==0){b5(b|0,3,51856,(p=i,i=i+8|0,c[p>>2]=19232,p)|0)|0;i=p;i=e;return}else{a[m+1|0]=0;i=e;return}}function ht(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;if((a[e]|0)==47){g=4096;h=0;j=b;k=e;while(1){l=g-1|0;if((l|0)==0){m=1824;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=h;break}else{g=l;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((m|0)==1824){a[j]=0;if((a[k]|0)==0){o=h;break}else{p=k;q=h}while(1){g=p+1|0;l=q+1|0;if((a[g]|0)==0){o=l;break}else{p=g;q=l}}}}while(0);if(o>>>0<4096){i=f;return}else{o=c[135158]|0;q=(o|0)!=0?o:c[t>>2]|0;eQ(q|0,33848,(r=i,i=i+16|0,c[r>>2]=13888,c[r+8>>2]=562,r)|0)|0;i=r;q=c[135158]|0;o=(q|0)!=0?q:c[t>>2]|0;a7(o|0)|0;cz(2)}}else{s=4096;u=0;v=b;w=d}while(1){d=s-1|0;if((d|0)==0){m=1830;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=u;break}else{s=d;u=u+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1830){a[v]=0;if((a[w]|0)==0){x=u;break}else{y=w;z=u}while(1){s=y+1|0;d=z+1|0;if((a[s]|0)==0){x=d;break}else{y=s;z=d}}}}while(0);if(x>>>0>=4096){x=c[135158]|0;z=(x|0)!=0?x:c[t>>2]|0;eQ(z|0,33848,(r=i,i=i+16|0,c[r>>2]=13888,c[r+8>>2]=565,r)|0)|0;i=r;z=c[135158]|0;x=(z|0)!=0?z:c[t>>2]|0;a7(x|0)|0;cz(2)}do{if((sZ(b|0)|0)>>>0>=2){x=cD(b|0,47)|0;if((x|0)==0){b5(b|0,3,51856,(r=i,i=i+8|0,c[r>>2]=19232,r)|0)|0;i=r;break}else{a[x+1|0]=0;break}}}while(0);x=sZ(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2566:do{if((z|0)==0){A=0;B=e;m=1843}else{y=z;u=0;w=b+x|0;v=e;while(1){d=y-1|0;if((d|0)==0){break}s=a[v]|0;a[w]=s;if(s<<24>>24==0){C=u;break L2566}else{y=d;u=u+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=u;B=v;m=1843}}while(0);do{if((m|0)==1843){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[135158]|0;x=(f|0)!=0?f:c[t>>2]|0;eQ(x|0,33848,(r=i,i=i+16|0,c[r>>2]=13888,c[r+8>>2]=567,r)|0)|0;i=r;r=c[135158]|0;x=(r|0)!=0?r:c[t>>2]|0;a7(x|0)|0;cz(2)}}function hu(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0,s=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+24|0;d=b|0;a[547475]=(c[136866]|0)==0|0;a[547476]=(c[136865]|0)==0|0;a[547477]=(c[136867]|0)==0|0;hn();c[135098]=0;e=d;L2581:do{if((a[289493]|0)!=0){f=hi(289493,33512,0)|0;c[135115]=f;do{if((f|0)!=0){j=f+4|0;if((c[j>>2]|0)==0){sS(c[f>>2]|0);sS(f);break}c[135116]=0;dL(c[f>>2]|0,c[j>>2]|0,8,116);j=c[135115]|0;if((c[j+4>>2]|0)==0){break L2581}else{k=0;l=j}while(1){if((a[383584]&1)==0){m=l}else{j=c[135158]|0;n=(j|0)!=0?j:c[t>>2]|0;j=c[(c[l>>2]|0)+(k<<3)>>2]|0;eQ(n|0,32480,(o=i,i=i+8|0,c[o>>2]=j,o)|0)|0;i=o;j=c[135158]|0;n=(j|0)!=0?j:c[t>>2]|0;a7(n|0)|0;m=c[135115]|0}n=k+1|0;if(n>>>0<(c[m+4>>2]|0)>>>0){k=n;l=m}else{break L2581}}}}while(0);c[135115]=0;c[135116]=0}}while(0);m=c[119474]|0;l=c[119475]|0;k=(m>>>0>l>>>0?m:l)-1|0;l=k>>>1|k;k=l>>>2|l;l=k>>>4|k;k=l>>>8|l;l=((k>>>16|k)+1|0)>>>8;k=(a[531944]&1)==0?l>>>0>1?l:1:c[132991]|0;p=+g[70320];g[119482]=p;do{if(p<0.0){q=+g[119476];if(q>0.0){if((a[281284]&1)==0){r=1862}else{s=q}}else{r=1862}if((r|0)==1862){s=+((c[119472]|0)>>>0>>>0)/+((c[119473]|0)>>>0>>>0)}g[119482]=s;if((a[383584]&1)==0){break}l=c[135158]|0;m=(l|0)!=0?l:c[t>>2]|0;q=s;eQ(m|0,11608,(o=i,i=i+8|0,h[o>>3]=q,o)|0)|0;i=o;m=c[135158]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0}}while(0);do{if((a[281248]&1)==0){if((a[281277]&1)==0){r=~~+bZ(+(+((c[119472]|0)>>>0>>>0)*+g[70310]));u=r;v=~~+bZ(+(+((c[119473]|0)>>>0>>>0)*+g[70311]));break}else{s=+((c[119473]|0)>>>0>>>0);p=+(~~+bZ(+(s*+g[119482]))>>>0>>>0);r=~~+bZ(+(+g[70310]*p));u=r;v=~~+bZ(+(s*+g[70311]));break}}else{u=c[70314]|0;v=c[70315]|0}}while(0);r=(a[383584]&1)==0;do{if((u|0)==0|(v|0)==0){if(r){break}l=c[135158]|0;m=(l|0)!=0?l:c[t>>2]|0;be(49104,30,1,m|0)|0;m=c[135158]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0}else{if(r){break}l=c[135158]|0;m=(l|0)!=0?l:c[t>>2]|0;eQ(m|0,51800,(o=i,i=i+16|0,c[o>>2]=u,c[o+8>>2]=v,o)|0)|0;i=o;m=c[135158]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0}}while(0);c[136873]=0;c[136871]=0;c[136872]=0;r=k<<8;sS(c[136890]|0);sS(c[136893]|0);sS(c[136894]|0);sS(c[136897]|0);sS(c[136900]|0);sS(c[136898]|0);sS(c[136904]|0);s_(547496,0,128);sS(c[136906]|0);c[136906]=0;if((c[119486]|0)==0){l=c[135158]|0;m=(l|0)!=0?l:c[t>>2]|0;be(34736,120,1,m|0)|0;m=c[135158]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0;c[136882]=1;c[136880]=2;c[136881]=3;if(!(iD(547496)|0)){l=c[135158]|0;m=(l|0)!=0?l:c[t>>2]|0;be(46872,53,1,m|0)|0;m=c[135158]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0;hy(45728)}l=ag(r,r)|0;r=l<<1;if(l>>>0>65535){w=(l&2147418112|0)==(l|0)?r:-1}else{w=r}r=sR(w)|0;do{if((r|0)!=0){if((c[r-4>>2]&3|0)==0){break}s_(r|0,0,w|0)}}while(0);c[136906]=r}c[e>>2]=c[1966];c[e+4>>2]=c[1967];c[e+8>>2]=c[1968];c[e+12>>2]=c[1969];c[e+16>>2]=c[1970];c[d>>2]=u;c[d+4>>2]=v;a[d+8|0]=a[281248]&1;if((a[281264]&1)==0){x=0}else{x=a[477949]&1^1}a[d+9|0]=x;a[d+10|0]=a[281277]&1;a[d+11|0]=a[281276]&1;c[d+12>>2]=k;if((a[531944]&1)==0){y=(c[119486]|0)==1|0}else{y=1}a[d+16|0]=y;y=c[136864]|0;k=f7[c[c[136863]>>2]&127](d,547456,547468)|0;c[136866]=k;if((k|0)==0){d=c[135158]|0;x=(d|0)!=0?d:c[t>>2]|0;be(44584,62,1,x|0)|0;x=c[135158]|0;d=(x|0)!=0?x:c[t>>2]|0;a7(d|0)|0;hy(45728)}c[136914]=0;d=c[136863]|0;x=c[d+56>>2]|0;if((x|0)==0){z=d}else{f0[x&255](k,547656);z=c[136863]|0}k=c[z+40>>2]|0;z=c[119483]|0;if((k|0)!=0&(z|0)!=0){f0[k&255](c[136866]|0,z)}z=c[136914]|0;do{if((z|0)!=0){k=c[z+12>>2]|0;x=c[70322]|0;if(!((k|0)!=0&(x|0)!=4)){break}f0[k&255](c[136866]|0,x)}}while(0);do{if((c[136864]|0)==0){if((a[383584]&1)!=0){z=c[135158]|0;x=(z|0)!=0?z:c[t>>2]|0;be(43104,101,1,x|0)|0;x=c[135158]|0;z=(x|0)!=0?x:c[t>>2]|0;a7(z|0)|0}c[136864]=y;if((y|0)==0){z=c[135158]|0;x=(z|0)!=0?z:c[t>>2]|0;be(40864,59,1,x|0)|0;x=c[135158]|0;z=(x|0)!=0?x:c[t>>2]|0;a7(z|0)|0;hy(45728)}z=gm[c[y>>2]&31]()|0;c[136867]=z;if((z|0)!=0){break}z=c[135158]|0;x=(z|0)!=0?z:c[t>>2]|0;be(41928,59,1,x|0)|0;x=c[135158]|0;z=(x|0)!=0?x:c[t>>2]|0;a7(z|0)|0;hy(45728)}}while(0);y=c[136908]|0;if((y|0)!=0){z=y+24|0;x=y+12|0;k=c[x>>2]|0;if((c[z>>2]|0)==0){A=k}else{d=0;v=k;while(1){sS(c[v+(d*136|0)>>2]|0);sS(c[v+(d*136|0)+8>>2]|0);k=d+1|0;u=c[x>>2]|0;if(k>>>0<(c[z>>2]|0)>>>0){d=k;v=u}else{A=u;break}}}sS(A);A=c[y+4>>2]|0;if((A|0)!=0){f0[c[A>>2]&255](c[y>>2]|0,0)}sS(y);c[136908]=0}do{if((a[342552]|0)!=0){y=iC()|0;c[136908]=y;if((y|0)!=0){break}y=c[135158]|0;A=(y|0)!=0?y:c[t>>2]|0;be(36504,45,1,A|0)|0;A=c[135158]|0;y=(A|0)!=0?A:c[t>>2]|0;a7(y|0)|0}}while(0);y=531936;c[y>>2]=0;c[y+4>>2]=0;y=c[120650]|0;if((a[547474]&1)==0&(y|0)!=0){gp[y&63]()}a[547474]=0;do{if((c[136865]|0)==0){y=~~(+g[94860]*65536.0);A=sR(y<<1)|0;c[120680]=A;if((A|0)==0){A=c[135158]|0;v=(A|0)!=0?A:c[t>>2]|0;eQ(v|0,33848,(o=i,i=i+16|0,c[o>>2]=23584,c[o+8>>2]=497,o)|0)|0;i=o;v=c[135158]|0;A=(v|0)!=0?v:c[t>>2]|0;a7(A|0)|0;cz(2)}c[120674]=512;c[120673]=2048;c[120672]=512;A=sR(8192)|0;c[120681]=A;if((A|0)==0){A=c[135158]|0;v=(A|0)!=0?A:c[t>>2]|0;eQ(v|0,33848,(o=i,i=i+16|0,c[o>>2]=23584,c[o+8>>2]=504,o)|0)|0;i=o;v=c[135158]|0;A=(v|0)!=0?v:c[t>>2]|0;a7(A|0)|0;cz(2)}c[120683]=4096;if((a[297756]&1)==0){a[383585]=0;break}A=f7[c[c[136862]>>2]&127]((a[297772]|0)!=0?297772:0,c[74440]|0,c[75467]|0)|0;c[136865]=A;do{if((A|0)==0){v=c[135158]|0;d=(v|0)!=0?v:c[t>>2]|0;be(20040,85,1,d|0)|0;d=c[135158]|0;v=(d|0)!=0?d:c[t>>2]|0;a7(v|0)|0;a[383585]=0}else{if((a[383585]&1)==0){break}v=c[(c[136862]|0)+24>>2]|0;if((v|0)==0){break}if(!(f2[v&255](A)|0)){break}a[482712]=1}}while(0);do{if((a[301872]&1)==0){if((a[383585]&1)==0){break}f0[c[(c[136862]|0)+16>>2]&255](c[136865]|0,1);c[120672]=c[120673]}}while(0);s=+((c[74440]|0)>>>0>>>0)/+g[74442];h[60338]=s;h[60344]=s;A=a[305980]|0;v=c[120668]|0;do{if((v|0)!=0){d=c[120669]|0;if((d|0)==0){break}f$[c[d+8>>2]&511](v)}}while(0);c[120669]=1288;v=jb(s)|0;c[120668]=v;if((v|0)==0){c[120669]=0;v=c[135158]|0;d=(v|0)!=0?v:c[t>>2]|0;v=A<<24>>24!=0?305980:15968;eQ(d|0,18296,(o=i,i=i+8|0,c[o>>2]=v,o)|0)|0;i=o;v=c[135158]|0;d=(v|0)!=0?v:c[t>>2]|0;a7(d|0)|0;a[383585]=0}d=sR(16384)|0;c[120670]=d;if((d|0)==0){d=c[135158]|0;v=(d|0)!=0?d:c[t>>2]|0;eQ(v|0,33848,(o=i,i=i+16|0,c[o>>2]=23584,c[o+8>>2]=561,o)|0)|0;i=o;v=c[135158]|0;d=(v|0)!=0?v:c[t>>2]|0;a7(d|0)|0;cz(2)}c[120671]=0;if(+((c[74440]|0)>>>0>>>0)>=+g[74442]*16.0){d=c[135158]|0;v=(d|0)!=0?d:c[t>>2]|0;eQ(v|0,33848,(o=i,i=i+16|0,c[o>>2]=23584,c[o+8>>2]=565,o)|0)|0;i=o;v=c[135158]|0;d=(v|0)!=0?v:c[t>>2]|0;a7(d|0)|0;cz(2)}d=sR(y<<2)|0;c[120679]=d;if((d|0)==0){d=c[135158]|0;v=(d|0)!=0?d:c[t>>2]|0;eQ(v|0,33848,(o=i,i=i+16|0,c[o>>2]=23584,c[o+8>>2]=566,o)|0)|0;i=o;v=c[135158]|0;d=(v|0)!=0?v:c[t>>2]|0;a7(d|0)|0;cz(2)}a[482748]=0;L2714:do{if((c[120641]|0)==0){if((a[383585]&1)==0){break}if((a[305969]&1)==0){break}d=c[136862]|0;v=c[d+36>>2]|0;do{if((v|0)!=0){if((c[d+32>>2]|0)==0){break}c[120690]=f2[v&255](c[136865]|0)|0;a[482748]=1;break L2714}}while(0);v=c[135158]|0;d=(v|0)!=0?v:c[t>>2]|0;be(13760,97,1,d|0)|0;d=c[135158]|0;v=(d|0)!=0?d:c[t>>2]|0;a7(v|0)|0}}while(0);s=+g[76494];g[120691]=s;g[120692]=+X(10.0,+(s/20.0));y=515544;c[y>>2]=0;c[y+4>>2]=0;if((a[383585]&1)==0){break}if(!((a[482713]&1)==0&(c[120641]|0)!=0)){break}y=c[(c[136862]|0)+12>>2]|0;A=c[136865]|0;f2[y&255](A)|0}}while(0);if((a[547480]&1)==0){B=482656;C=0;D=0;E=B|0;c[E>>2]=C;F=B+4|0;c[F>>2]=D;i=b;return}o=c[136866]|0;if((a[383586]&1)!=0&(o|0)!=0){f0[c[(c[136863]|0)+8>>2]&255](o,1)}o=c[136865]|0;if((a[383585]&1)!=0&(o|0)!=0){f0[c[(c[136862]|0)+16>>2]&255](o,1)}c[120672]=c[120673];B=482656;C=0;D=0;E=B|0;c[E>>2]=C;F=B+4|0;c[F>>2]=D;i=b;return}function hv(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0,q=0,r=0,s=0,u=0.0,v=0;b=i;d=c[136865]|0;e=c[136862]|0;if((d|0)!=0&(e|0)!=0){f$[c[e+20>>2]&511](d)}sS(c[120680]|0);c[120680]=0;c[120671]=0;sS(c[120681]|0);c[120681]=0;if((a[297756]&1)==0){a[383585]=0;i=b;return}d=c[120669]|0;e=c[120668]|0;if((d|0)!=0&(e|0)!=0){f$[c[d+8>>2]&511](e)}c[120669]=0;c[120668]=0;sS(c[120670]|0);c[120670]=0;sS(c[120679]|0);c[120679]=0;e=515544;d=c[e>>2]|0;f=c[e+4>>2]|0;e=0;g=f>>>0<e>>>0|f>>>0==e>>>0&d>>>0<8192>>>0?d:8192;if(g>>>0<3){i=b;return}else{j=1;k=0;l=0}do{l=ta(c[482776+(j<<2)>>2]|0,0,l,k)|0;k=K;j=j+1|0;}while(j>>>0<g>>>0);j=g-1|0;d=tl(l,k,j,0)|0;k=d;d=1;l=0;e=0;do{f=k-(c[482776+(d<<2)>>2]|0)|0;e=ta(ag(f,f)|0,0,e,l)|0;l=K;d=d+1|0;}while(d>>>0<g>>>0);m=+W(+((+(e>>>0)+ +(l>>>0)*4294967296.0)/+((g-2|0)>>>0>>>0)));l=c[120690]|0;n=+(l>>>0>>>0);o=+(k|0)/n;k=(l*3|0)>>>2;e=l>>>2;l=0;d=0;f=1;while(1){p=c[482776+(f<<2)>>2]|0;if(p>>>0<k>>>0){q=(p>>>0<=e>>>0)+d|0;r=l}else{q=d;r=l+1|0}p=f+1|0;if(p>>>0<g>>>0){l=r;d=q;f=p}else{break}}f=a[383584]|0;if((f&1)==0){s=f}else{f=c[135158]|0;d=(f|0)!=0?f:c[t>>2]|0;u=(1.0-o)*100.0;o=+(~~m>>>0>>>0)/n*100.0;eQ(d|0,31904,(v=i,i=i+16|0,h[v>>3]=u,h[v+8>>3]=o,v)|0)|0;i=v;d=c[135158]|0;f=(d|0)!=0?d:c[t>>2]|0;a7(f|0)|0;s=a[383584]|0}if((s&1)==0){i=b;return}s=c[135158]|0;o=+(j>>>0>>>0);eQ(((s|0)!=0?s:c[t>>2]|0)|0,31072,(v=i,i=i+16|0,h[v>>3]=+(r>>>0>>>0)*100.0/o,h[v+8>>3]=+(q>>>0>>>0)*100.0/o,v)|0)|0;i=v;v=c[135158]|0;a7(((v|0)!=0?v:c[t>>2]|0)|0)|0;i=b;return}function hw(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0.0,v=0.0;b=i;d=c[136908]|0;if((d|0)!=0){e=d+24|0;f=d+12|0;g=c[f>>2]|0;if((c[e>>2]|0)==0){j=g}else{k=0;l=g;while(1){sS(c[l+(k*136|0)>>2]|0);sS(c[l+(k*136|0)+8>>2]|0);g=k+1|0;m=c[f>>2]|0;if(g>>>0<(c[e>>2]|0)>>>0){k=g;l=m}else{j=m;break}}}sS(j);j=c[d+4>>2]|0;if((j|0)!=0){f0[c[j>>2]&255](c[d>>2]|0,0)}sS(d);c[136908]=0;s_(547640,0,16)}d=c[136867]|0;j=c[136866]|0;l=c[136864]|0;if((d|0)!=(j|0)&(l|0)!=0){f$[c[l+16>>2]&511](d);n=c[136866]|0}else{n=j}j=c[136863]|0;if((n|0)!=0&(j|0)!=0){f$[c[j+24>>2]&511](n)}sS(c[136890]|0);sS(c[136893]|0);sS(c[136894]|0);sS(c[136897]|0);sS(c[136900]|0);sS(c[136898]|0);sS(c[136904]|0);s_(547496,0,128);sS(c[136906]|0);c[136906]=0;n=c[135115]|0;if((n|0)!=0){j=n+4|0;d=n|0;l=c[d>>2]|0;if((c[j>>2]|0)==0){o=l}else{k=0;e=l;while(1){sS(c[e+(k<<3)>>2]|0);l=k+1|0;f=c[d>>2]|0;if(l>>>0<(c[j>>2]|0)>>>0){k=l;e=f}else{o=f;break}}}sS(o);sS(n)}c[135115]=0;c[135116]=0;if((a[289492]&1)!=0){if((a[383584]&1)==0){i=b;return}n=c[135158]|0;o=(n|0)!=0?n:c[t>>2]|0;be(39920,66,1,o|0)|0;o=c[135158]|0;n=(o|0)!=0?o:c[t>>2]|0;a7(n|0)|0;i=b;return}n=531936;o=c[n+4>>2]|0;e=0;if(o>>>0<e>>>0|o>>>0==e>>>0&(c[n>>2]|0)>>>0<4096>>>0){if((a[383584]&1)==0){i=b;return}n=c[135158]|0;e=(n|0)!=0?n:c[t>>2]|0;eQ(e|0,38936,(p=i,i=i+8|0,c[p>>2]=4096,p)|0)|0;i=p;e=c[135158]|0;n=(e|0)!=0?e:c[t>>2]|0;a7(n|0)|0;i=b;return}else{q=0;r=0;s=0}do{n=515552+(q<<3)|0;s=ta(c[n>>2]|0,c[n+4>>2]|0,s,r)|0;r=K;q=q+1|0;}while(q>>>0<2048);q=ti(s,r,2048,0)|0;r=K;s=0;n=0;e=0;do{o=515552+(e<<3)|0;k=tb(c[o>>2]|0,c[o+4>>2]|0,q,r)|0;o=K;j=tk(k,o,k,o)|0;n=ta(j,K,n,s)|0;s=K;e=e+1|0;}while(e>>>0<2048);u=+(q>>>0)+ +(r|0)*4294967296.0;if((a[383584]&1)==0){i=b;return}v=+W(+((+(n>>>0)+ +(s|0)*4294967296.0)/2047.0))/u;s=c[135158]|0;eQ(((s|0)!=0?s:c[t>>2]|0)|0,38016,(p=i,i=i+24|0,h[p>>3]=1.0e6/u,h[p+8>>3]=v*100.0,c[p+16>>2]=2048,p)|0)|0;i=p;p=c[135158]|0;a7(((p|0)!=0?p:c[t>>2]|0)|0)|0;i=b;return}function hx(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=c[a+4>>2]|0;if((b|0)!=0){d=b;while(1){sS(c[d+4>>2]|0);sS(c[d+8>>2]|0);b=c[d+12>>2]|0;sS(d|0);if((b|0)==0){break}else{d=b}}}d=c[a+16>>2]|0;if((d|0)!=0){b=d;while(1){sS(c[b>>2]|0);d=c[b+4>>2]|0;sS(b);if((d|0)==0){break}else{b=d}}}sS(c[a>>2]|0);sS(a);return}function hy(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[540637]&1)==0){d=c[135158]|0;e=(d|0)!=0?d:c[t>>2]|0;eQ(e|0,33848,(e=i,i=i+16|0,c[e>>2]=43784,c[e+8>>2]=832,e)|0)|0;i=e;e=c[135158]|0;d=(e|0)!=0?e:c[t>>2]|0;a7(d|0)|0;cz(2)}else{f=1024;g=540639;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=2033;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==2033){fi(541664,1)}a[g]=0;if((a[h]|0)==0){fi(541664,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);fi(541664,1)}function hz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+4112|0;f=e|0;g=e+8|0;h=e+4104|0;j=sR(20)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){s_(j|0,0,20)}l=j;if((b|0)==0){k=l;i=e;return k|0}m=dT(b|0)|0;n=j;c[n>>2]=m;if((m|0)==0){sS(j);k=0;i=e;return k|0}o=j+12|0;c[o>>2]=d;d=dz(b|0,11144)|0;if((d|0)==0){sS(m);sS(j);k=0;i=e;return k|0}if((eX(d|0)|0)==0){m=j+8|0;b=j+4|0;p=g|0;q=j+16|0;do{j=sR(16)|0;do{if((j|0)!=0){if((c[j-4>>2]&3|0)==0){break}s_(j|0,0,16)}}while(0);r=j;s=sR(9)|0;u=b7(d|0)|0;v=0;w=8;x=s;while(1){if((u|0)==(-1|0)|(u|0)==10){break}if((v|0)==(w|0)){s=w<<1;y=s;z=sT(x,s|1)|0}else{y=w;z=x}a[z+v|0]=u&255;u=b7(d|0)|0;v=v+1|0;w=y;x=z}a[x+v|0]=0;if((x|0)!=0){w=cm(x|0,35)|0;if((w|0)!=0){a[w]=0}u=c[o>>2]|0;do{if((w|0)==(x|0)){if(u>>>0>=16){A=2105;break}if((b0(x+1|0,37992,8)|0)!=0){B=x;A=2106;break}s=x+9|0;while(1){D=s+1|0;if((bp(a[s]|0)|0)==0){break}else{s=D}}E=a[s]|0;if((E<<24>>24|0)==0){break}else if((E<<24>>24|0)==34){E=eM(D|0,34648,f|0)|0;if((E|0)==0){break}F=dT(E|0)|0}else{E=eM(s|0,33416,f|0)|0;if((E|0)==0){break}F=dT(E|0)|0}if((F|0)==0){break}E=c[q>>2]|0;G=sR(8)|0;do{if((G|0)!=0){if((c[G-4>>2]&3|0)==0){break}H=G;I=H|0;C=0;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=H+4|0;C=0;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255}}while(0);s=G;c[G>>2]=dT(F|0)|0;if((E|0)==0){c[q>>2]=s}else{I=E;do{J=I+4|0;I=c[J>>2]|0;}while((I|0)!=0);c[J>>2]=s}L2905:do{if((a[F]|0)==126){I=d8(45336)|0;E=4096;G=p;H=(I|0)!=0?I:547872;while(1){I=E-1|0;if((I|0)==0){A=2079;break}K=a[H]|0;a[G]=K;if(K<<24>>24==0){break}else{E=I;G=G+1|0;H=H+1|0}}do{if((A|0)==2079){A=0;a[G]=0;if((a[H]|0)==0){break}else{L=H}do{L=L+1|0;}while((a[L]|0)!=0)}}while(0);H=F+1|0;G=sZ(p|0)|0;E=G>>>0>4096?0:4096-G|0;if((E|0)==0){M=H}else{I=E;E=g+G|0;G=H;while(1){H=I-1|0;if((H|0)==0){break}K=a[G]|0;a[E]=K;if(K<<24>>24==0){break L2905}else{I=H;E=E+1|0;G=G+1|0}}a[E]=0;M=G}if((a[M]|0)==0){break}else{N=M}do{N=N+1|0;}while((a[N]|0)!=0)}else{ht(p,c[n>>2]|0,F)}}while(0);s=hz(p,(c[o>>2]|0)+1|0)|0;if((s|0)==0){sS(F);break}G=c[b>>2]|0;if((G|0)==0){E=s+4|0;I=c[E>>2]|0;if((I|0)==0){O=0}else{H=I;do{a[H|0]=1;H=c[H+12>>2]|0;}while((H|0)!=0);O=c[E>>2]|0}c[b>>2]=O;P=O}else{H=G;do{Q=H+12|0;H=c[Q>>2]|0;}while((H|0)!=0);H=s+4|0;G=c[H>>2]|0;if((G|0)==0){R=0}else{E=G;do{a[E|0]=1;E=c[E+12>>2]|0;}while((E|0)!=0);R=c[H>>2]|0}c[Q>>2]=R;P=c[b>>2]|0}c[s+4>>2]=0;if((P|0)==0){S=0}else{E=P;while(1){G=c[E+12>>2]|0;if((G|0)==0){S=E;break}else{E=G}}}c[m>>2]=S;hx(s);sS(F)}else{if(u>>>0>15){A=2105}else{B=x;A=2106}}}while(0);if((A|0)==2105){A=0;u=c[t>>2]|0;be(36632,58,1,u|0)|0;B=x;A=2106}L2952:do{if((A|0)==2106){while(1){A=0;if((bp(a[B]|0)|0)==0){break}else{B=B+1|0;A=2106}}s=sR(9)|0;if((fr(a[B]|0)|0)==0){T=B;U=s;V=0}else{u=B;w=s;s=8;v=0;while(1){if((v|0)==(s|0)){E=v<<1;W=E;X=sT(w,E|1)|0}else{W=s;X=w}E=u+1|0;H=v+1|0;a[X+v|0]=a[u]|0;if((fr(a[E]|0)|0)==0){T=E;U=X;V=H;break}else{u=E;w=X;s=W;v=H}}}a[U+V|0]=0;v=j+4|0;c[v>>2]=U;s=T;while(1){Y=s+1|0;if((bp(a[s]|0)|0)==0){break}else{s=Y}}do{if((a[s]|0)==61){w=Y;while(1){Z=w+1|0;if((bp(a[w]|0)|0)==0){break}else{w=Z}}u=a[w]|0;if((u<<24>>24|0)==34){H=eM(Z|0,34648,h|0)|0;if((H|0)==0){A=2120;break}_=dT(H|0)|0}else if((u<<24>>24|0)==0){A=2120;break}else{u=eM(w|0,33416,h|0)|0;if((u|0)==0){A=2120;break}_=dT(u|0)|0}c[j+8>>2]=_;if((_|0)==0){break}if((c[b>>2]|0)==0){c[b>>2]=r;c[m>>2]=r;break L2952}else{c[(c[m>>2]|0)+12>>2]=r;c[m>>2]=r;break L2952}}else{A=2120}}while(0);if((A|0)==2120){A=0;c[j+8>>2]=0}c[v>>2]=0;sS(U)}}while(0);sS(x)}if((r|0)!=(c[m>>2]|0)){sS(j)}}while((eX(d|0)|0)==0)}a_(d|0)|0;k=l;i=e;return k|0}function hA(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+8192|0;g=f|0;h=f+4096|0;j=b+4|0;while(1){k=c[j>>2]|0;if((k|0)==0){l=0;m=2176;break}if((da(d|0,c[k+4>>2]|0)|0)==0){break}else{j=k+12|0}}if((m|0)==2176){i=f;return l|0}j=c[k+8>>2]|0;k=a[j]|0;do{if((k<<24>>24|0)==58){if((a[j+1|0]|0)!=47){n=e;o=j;p=4096;m=2167;break}d=h|0;b=g|0;a[d]=0;q=ci()|0;r=0;while(1){if(r>>>0>=3){m=2153;break}s=c[8176+(r<<2)>>2]|0;b5(b|0,4096,44664,(u=i,i=i+16|0,c[u>>2]=q,c[u+8>>2]=s,u)|0)|0;i=u;v=fs(b|0,d|0,4095)|0;if((v|0)>-1){m=2152;break}else{r=r+1|0}}if((m|0)==2152){a[h+v|0]=0}else if((m|0)==2153){r=c[135158]|0;be(43232,78,1,((r|0)!=0?r:c[t>>2]|0)|0)|0;r=c[135158]|0;a7(((r|0)!=0?r:c[t>>2]|0)|0)|0}if((a[383584]&1)!=0){r=c[135158]|0;b=(r|0)!=0?r:c[t>>2]|0;eQ(b|0,32840,(u=i,i=i+8|0,c[u>>2]=d,u)|0)|0;i=u;b=c[135158]|0;r=(b|0)!=0?b:c[t>>2]|0;a7(r|0)|0}do{if((sZ(d|0)|0)>>>0<2){w=4096;x=0;y=e;z=d}else{r=cD(d|0,47)|0;if((r|0)==0){b5(d|0,3,51856,(u=i,i=i+8|0,c[u>>2]=19232,u)|0)|0;i=u;w=4096;x=0;y=e;z=d;break}else{a[r+1|0]=0;w=4096;x=0;y=e;z=d;break}}}while(0);while(1){d=w-1|0;if((d|0)==0){m=2162;break}r=a[z]|0;a[y]=r;if(r<<24>>24==0){A=x;break}else{w=d;x=x+1|0;y=y+1|0;z=z+1|0}}do{if((m|0)==2162){a[y]=0;if((a[z]|0)==0){A=x;break}else{B=z;C=x}while(1){d=B+1|0;r=C+1|0;if((a[d]|0)==0){A=r;break}else{B=d;C=r}}}}while(0);if(A>>>0<4096){D=A;E=j+2|0;m=2166;break}else{l=0;i=f;return l|0}}else if((k<<24>>24|0)==126){r=d8(45336)|0;if((r|0)==0){n=e;o=j;p=4096;m=2167;break}else{F=4096;G=0;H=e;I=r}while(1){r=F-1|0;if((r|0)==0){m=2144;break}d=a[I]|0;a[H]=d;if(d<<24>>24==0){J=G;break}else{F=r;G=G+1|0;H=H+1|0;I=I+1|0}}do{if((m|0)==2144){a[H]=0;if((a[I]|0)==0){J=G;break}else{K=I;L=G}while(1){r=K+1|0;d=L+1|0;if((a[r]|0)==0){J=d;break}else{K=r;L=d}}}}while(0);if(J>>>0<4096){D=J;E=j+1|0;m=2166;break}else{l=0;i=f;return l|0}}else{n=e;o=j;p=4096;m=2167}}while(0);if((m|0)==2166){if((D|0)==4096){M=0;N=E;O=0;m=2171}else{n=e+D|0;o=E;p=4096-D|0;m=2167}}L3040:do{if((m|0)==2167){D=p;E=0;e=n;j=o;while(1){J=D-1|0;if((J|0)==0){break}L=a[j]|0;a[e]=L;if(L<<24>>24==0){P=E;Q=p;break L3040}else{D=J;E=E+1|0;e=e+1|0;j=j+1|0}}a[e]=0;M=E;N=j;O=p;m=2171}}while(0);do{if((m|0)==2171){if((a[N]|0)==0){P=M;Q=O;break}else{R=N;S=M}while(1){p=R+1|0;o=S+1|0;if((a[p]|0)==0){P=o;Q=O;break}else{R=p;S=o}}}}while(0);l=P>>>0<Q>>>0;i=f;return l|0}function hB(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;while(1){g=c[f>>2]|0;if((g|0)==0){h=0;i=2195;break}if((da(d|0,c[g+4>>2]|0)|0)==0){break}else{f=g+12|0}}if((i|0)==2195){return h|0}i=c[g+8>>2]|0;if((s4(i|0,51224)|0)==0){a[e]=1;h=1;return h|0}if((s4(i|0,23512)|0)==0){a[e]=1;h=1;return h|0}if((s4(i|0,30680)|0)==0){a[e]=0;h=1;return h|0}if((s4(i|0,45400)|0)!=0){h=0;return h|0}a[e]=0;h=1;return h|0}function hC(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;b=c[f>>2]|0;L3076:do{if((b|0)==0){g=0}else{h=b;while(1){if((a[h|0]&1)==0){if((da(d|0,c[h+4>>2]|0)|0)==0){break}}i=c[h+12>>2]|0;if((i|0)==0){g=h;break L3076}else{h=i}}i=h+8|0;sS(c[i>>2]|0);c[i>>2]=dT(e|0)|0;return}}while(0);b=sR(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)==0){break}s_(b|0,0,16)}}while(0);i=b;c[b+4>>2]=dT(d|0)|0;c[b+8>>2]=dT(e|0)|0;if((g|0)==0){c[f>>2]=i;return}else{c[g+12>>2]=i;return}}function hD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=(d|0)!=0;do{if(f){g=dz(d|0,57168)|0;if((g|0)==0){h=0}else{j=g;break}i=e;return h|0}else{j=c[q>>2]|0}}while(0);d=c[b+16>>2]|0;if((d|0)!=0){g=d;do{eQ(j|0,44528,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0)|0;i=k;g=c[g+4>>2]|0;}while((g|0)!=0)}g=c[b+4>>2]|0;if((g|0)!=0){b=g;do{if((a[b|0]&1)==0){g=c[b+4>>2]|0;d=c[b+8>>2]|0;eQ(j|0,43016,(k=i,i=i+16|0,c[k>>2]=g,c[k+8>>2]=d,k)|0)|0;i=k}b=c[b+12>>2]|0;}while((b|0)!=0)}if(!f){h=1;i=e;return h|0}a_(j|0)|0;h=1;i=e;return h|0}function hE(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a5=0,a6=0,a8=0,a9=0,ba=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0.0,bI=0.0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0;e=i;i=i+12848|0;f=e|0;h=e+72|0;j=e+144|0;k=e+4312|0;l=e+4320|0;m=e+8416|0;n=e+12512|0;o=e+12520|0;p=e+12528|0;q=e+12536|0;r=e+12544|0;s=e+12552|0;u=e+12560|0;v=e+12568|0;w=e+12576|0;x=e+12584|0;y=e+12592|0;z=e+12600|0;A=e+12608|0;B=e+12616|0;C=e+12624|0;D=e+12632|0;E=e+12640|0;F=e+12648|0;G=e+12656|0;H=e+12664|0;I=e+12672|0;J=e+12736|0;K=e+12744|0;L=e+12752|0;M=e+12760|0;N=e+12768|0;O=e+12776|0;P=e+12784|0;Q=e+12792|0;R=e+12800|0;S=e+12808|0;T=e+12816|0;U=e+12824|0;V=e+12832|0;W=e+12840|0;do{if((d|0)==0){X=e+216|0;Y=d8(45384)|0;Z=d8(45336)|0;do{if((Y|0)==0){if((Z|0)==0){_=2240;break}b5(X|0,4096,45200,($=i,i=i+8|0,c[$>>2]=Z,$)|0)|0;i=$;_=2233}else{b5(X|0,4096,45272,($=i,i=i+8|0,c[$>>2]=Y,$)|0)|0;i=$;_=2233}}while(0);if((_|0)==2233){if((a[383584]&1)!=0){Y=c[135158]|0;aa=(Y|0)!=0?Y:c[t>>2]|0;eQ(aa|0,44944,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[135158]|0;Y=(aa|0)!=0?aa:c[t>>2]|0;a7(Y|0)|0}Y=hz(X,0)|0;if((Y|0)!=0|(Z|0)==0){ab=Y}else{b5(X|0,4096,44768,($=i,i=i+8|0,c[$>>2]=Z,$)|0)|0;i=$;if((a[383584]&1)!=0){Y=c[135158]|0;aa=(Y|0)!=0?Y:c[t>>2]|0;eQ(aa|0,44944,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[135158]|0;Y=(aa|0)!=0?aa:c[t>>2]|0;a7(Y|0)|0}ab=hz(X,0)|0}if((ab|0)==0){_=2240}else{ac=ab}}do{if((_|0)==2240){hj(X,44648,44488);if((a[383584]&1)!=0){Y=c[135158]|0;aa=(Y|0)!=0?Y:c[t>>2]|0;eQ(aa|0,44944,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[135158]|0;Y=(aa|0)!=0?aa:c[t>>2]|0;a7(Y|0)|0}Y=hz(X,0)|0;if((Y|0)==0){ad=1}else{ac=Y;break}i=e;return ad|0}}while(0);Z=4096;Y=404114;aa=X;while(1){ae=Z-1|0;if((ae|0)==0){_=2246;break}af=a[aa]|0;a[Y]=af;if(af<<24>>24==0){break}else{Z=ae;Y=Y+1|0;aa=aa+1|0}}do{if((_|0)==2246){a[Y]=0;if((a[aa]|0)==0){break}else{ag=aa}do{ag=ag+1|0;}while((a[ag]|0)!=0)}}while(0);if((ac|0)==0){ad=1}else{ah=ac;break}i=e;return ad|0}else{aa=hz(d,0)|0;if((aa|0)==0){ad=0}else{ah=aa;break}i=e;return ad|0}}while(0);d=l|0;l=4096;ac=d;ag=408210;while(1){ab=l-1|0;if((ab|0)==0){_=2252;break}aa=a[ag]|0;a[ac]=aa;if(aa<<24>>24==0){break}else{l=ab;ac=ac+1|0;ag=ag+1|0}}do{if((_|0)==2252){a[ac]=0;if((a[ag]|0)==0){break}else{ai=ag}do{ai=ai+1|0;}while((a[ai]|0)!=0)}}while(0);ai=eM(d|0,19960,k|0)|0;d=(a[383584]&1)!=0;if((ai|0)==0){aj=d}else{ag=ah+4|0;ac=ai;ai=d;while(1){if(ai){d=c[135158]|0;l=(d|0)!=0?d:c[t>>2]|0;eQ(l|0,18152,($=i,i=i+8|0,c[$>>2]=ac,$)|0)|0;i=$;l=c[135158]|0;d=(l|0)!=0?l:c[t>>2]|0;a7(d|0)|0}d=hz(ac,0)|0;if((d|0)==0){l=c[135158]|0;ab=(l|0)!=0?l:c[t>>2]|0;eQ(ab|0,15752,($=i,i=i+8|0,c[$>>2]=ac,$)|0)|0;i=$;ab=c[135158]|0;l=(ab|0)!=0?ab:c[t>>2]|0;a7(l|0)|0}else{l=c[d+8>>2]|0;if((l|0)!=0){c[l+12>>2]=c[ag>>2];l=d+4|0;c[ag>>2]=c[l>>2];c[l>>2]=0}hx(d)}d=eM(0,27664,k|0)|0;l=(a[383584]&1)!=0;if((d|0)==0){aj=l;break}else{ac=d;ai=l}}}do{if(aj){ai=c[135158]|0;ac=(ai|0)!=0?ai:c[t>>2]|0;be(11512,15,1,ac|0)|0;ac=c[135158]|0;ai=(ac|0)!=0?ac:c[t>>2]|0;a7(ai|0)|0;ai=c[t>>2]|0;ac=c[ah+16>>2]|0;if((ac|0)!=0){k=ac;do{eQ(ai|0,44528,($=i,i=i+8|0,c[$>>2]=c[k>>2],$)|0)|0;i=$;k=c[k+4>>2]|0;}while((k|0)!=0)}k=ah+4|0;ac=c[k>>2]|0;if((ac|0)!=0){ag=ac;do{ac=c[ag+8>>2]|0;l=(a[ag|0]&1)!=0?40832:547872;eQ(ai|0,41904,($=i,i=i+24|0,c[$>>2]=c[ag+4>>2],c[$+8>>2]=ac,c[$+16>>2]=l,$)|0)|0;i=$;ag=c[ag+12>>2]|0;}while((ag|0)!=0)}if((a[383584]&1)==0){ak=k;break}ag=c[135158]|0;ai=(ag|0)!=0?ag:c[t>>2]|0;be(51680,19,1,ai|0)|0;ai=c[135158]|0;ag=(ai|0)!=0?ai:c[t>>2]|0;a7(ag|0)|0;ak=k}else{ak=ah+4|0}}while(0);aj=ak;while(1){al=c[aj>>2]|0;if((al|0)==0){am=ak;break}if((da(48776,c[al+4>>2]|0)|0)==0){_=2276;break}aj=al+12|0}if((_|0)==2276){g[70310]=+sY(c[al+8>>2]|0,0);am=ak}while(1){an=c[am>>2]|0;if((an|0)==0){ao=ak;break}if((da(46752,c[an+4>>2]|0)|0)==0){_=2280;break}am=an+12|0}if((_|0)==2280){g[70311]=+sY(c[an+8>>2]|0,0);ao=ak}while(1){ap=c[ao>>2]|0;if((ap|0)==0){aq=ak;break}if((da(45672,c[ap+4>>2]|0)|0)==0){_=2284;break}ao=ap+12|0}do{if((_|0)==2284){c[(ep()|0)>>2]=0;ao=bb(c[ap+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){aq=ak;break}c[70314]=ao;aq=ak}}while(0);while(1){ar=c[aq>>2]|0;if((ar|0)==0){break}if((da(44504,c[ar+4>>2]|0)|0)==0){_=2289;break}aq=ar+12|0}do{if((_|0)==2289){c[(ep()|0)>>2]=0;aq=bb(c[ar+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[70315]=aq}}while(0);do{if((a[383587]&1)==0){a[n]=0;if(!(hB(ah,42992,n)|0)){break}a[281248]=a[n]&1}}while(0);a[o]=0;if(hB(ah,41872,o)|0){a[281249]=a[o]&1;as=ak}else{as=ak}while(1){at=c[as>>2]|0;if((at|0)==0){break}if((da(40808,c[at+4>>2]|0)|0)==0){_=2298;break}else{as=at+12|0}}do{if((_|0)==2298){c[(ep()|0)>>2]=0;as=bb(c[at+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[70313]=as}}while(0);a[p]=0;if(hB(ah,39848,p)|0){a[297716]=a[p]&1}a[q]=0;if(hB(ah,38912,q)|0){a[281264]=a[q]&1}a[r]=0;if(hB(ah,37976,r)|0){a[281265]=a[r]&1;au=ak}else{au=ak}while(1){av=c[au>>2]|0;if((av|0)==0){_=2310;break}if((da(36552,c[av+4>>2]|0)|0)==0){_=2308;break}else{au=av+12|0}}do{if((_|0)==2308){c[(ep()|0)>>2]=0;au=bb(c[av+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){_=2310;break}c[70318]=au;aw=au}}while(0);if((_|0)==2310){aw=c[70318]|0}if(aw>>>0>3){c[70318]=3}a[s]=0;if(hB(ah,34616,s)|0){a[281266]=a[s]&1;ax=ak}else{ax=ak}while(1){ay=c[ax>>2]|0;if((ay|0)==0){_=2318;break}if((da(33392,c[ay+4>>2]|0)|0)==0){_=2317;break}else{ax=ay+12|0}}do{if((_|0)==2317){c[(ep()|0)>>2]=0;ax=bb(c[ay+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){_=2318;break}c[70317]=ax;az=ax}}while(0);if((_|0)==2318){az=c[70317]|0}ay=az>>>0>1?az:1;c[70317]=ay>>>0<4?ay:4;a[u]=0;if(hB(ah,32456,u)|0){a[289492]=a[u]&1}a[v]=0;if(hB(ah,31880,v)|0){a[281276]=a[v]&1}a[w]=0;if(hB(ah,30960,w)|0){a[281277]=a[w]&1}a[x]=0;if(hB(ah,30552,x)|0){a[281285]=a[x]&1}a[y]=0;if(hB(ah,30152,y)|0){a[281278]=a[y]&1;aA=ak}else{aA=ak}while(1){aB=c[aA>>2]|0;if((aB|0)==0){aC=ak;break}if((da(29848,c[aB+4>>2]|0)|0)==0){_=2332;break}else{aA=aB+12|0}}if((_|0)==2332){g[70320]=+sY(c[aB+8>>2]|0,0);aC=ak}while(1){aD=c[aC>>2]|0;if((aD|0)==0){break}if((da(29472,c[aD+4>>2]|0)|0)==0){_=2335;break}else{aC=aD+12|0}}do{if((_|0)==2335){c[(ep()|0)>>2]=0;aC=bb(c[aD+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[70322]=aC}}while(0);a[z]=0;if(hB(ah,28864,z)|0){a[281284]=a[z]&1;aE=ak}else{aE=ak}while(1){aF=c[aE>>2]|0;if((aF|0)==0){break}if((da(28200,c[aF+4>>2]|0)|0)==0){_=2341;break}else{aE=aF+12|0}}if((_|0)==2341){g[72372]=+sY(c[aF+8>>2]|0,0)}hA(ah,27776,281292)|0;a[A]=0;if(hB(ah,27392,A)|0){a[285388]=a[A]&1}a[B]=0;if(hB(ah,27024,B)|0){a[297720]=a[B]&1}hA(ah,26640,293589)|0;B=ak;while(1){aG=c[B>>2]|0;if((aG|0)==0){break}if((da(26248,c[aG+4>>2]|0)|0)==0){_=2349;break}else{B=aG+12|0}}if((_|0)==2349){g[74422]=+sY(c[aG+8>>2]|0,0)}a[C]=0;if(hB(ah,25912,C)|0){a[297692]=a[C]&1}a[D]=0;if(hB(ah,25568,D)|0){a[297693]=a[D]&1;aH=ak}else{aH=ak}while(1){aI=c[aH>>2]|0;if((aI|0)==0){aJ=ak;break}if((da(25120,c[aI+4>>2]|0)|0)==0){_=2356;break}else{aH=aI+12|0}}if((_|0)==2356){g[74424]=+sY(c[aI+8>>2]|0,0);aJ=ak}while(1){aK=c[aJ>>2]|0;if((aK|0)==0){aL=ak;break}if((da(24392,c[aK+4>>2]|0)|0)==0){_=2359;break}else{aJ=aK+12|0}}if((_|0)==2359){g[74425]=+sY(c[aK+8>>2]|0,0);aL=ak}while(1){aM=c[aL>>2]|0;if((aM|0)==0){aN=ak;break}if((da(23816,c[aM+4>>2]|0)|0)==0){_=2362;break}else{aL=aM+12|0}}do{if((_|0)==2362){c[(ep()|0)>>2]=0;aL=bb(c[aM+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){aN=ak;break}c[135143]=aL;aN=ak}}while(0);while(1){aO=c[aN>>2]|0;if((aO|0)==0){aP=ak;break}if((da(23600,c[aO+4>>2]|0)|0)==0){_=2366;break}else{aN=aO+12|0}}do{if((_|0)==2366){c[(ep()|0)>>2]=0;aN=bb(c[aO+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){aP=ak;break}c[135144]=aN;aP=ak}}while(0);while(1){aQ=c[aP>>2]|0;if((aQ|0)==0){aR=ak;break}if((da(23384,c[aQ+4>>2]|0)|0)==0){_=2370;break}else{aP=aQ+12|0}}do{if((_|0)==2370){c[(ep()|0)>>2]=0;aP=bb(c[aQ+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){aR=ak;break}c[135145]=aP;aR=ak}}while(0);while(1){aS=c[aR>>2]|0;if((aS|0)==0){aT=ak;break}if((da(23104,c[aS+4>>2]|0)|0)==0){_=2374;break}else{aR=aS+12|0}}do{if((_|0)==2374){c[(ep()|0)>>2]=0;aR=bb(c[aS+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){aT=ak;break}c[135146]=aR;aT=ak}}while(0);while(1){aU=c[aT>>2]|0;if((aU|0)==0){break}if((da(22832,c[aU+4>>2]|0)|0)==0){_=2378;break}else{aT=aU+12|0}}do{if((_|0)==2378){c[(ep()|0)>>2]=0;aT=a4(c[aU+8>>2]|0,0,16)|0;if((c[(ep()|0)>>2]|0)!=0){break}g[74426]=+((aT>>>16&255)>>>0>>>0)/255.0;g[74427]=+((aT>>>8&255)>>>0>>>0)/255.0;g[74428]=+((aT&255)>>>0>>>0)/255.0}}while(0);a[E]=0;if(hB(ah,22576,E)|0){a[297717]=a[E]&1}a[F]=0;if(hB(ah,22296,F)|0){a[297718]=a[F]&1}a[G]=0;if(hB(ah,22080,G)|0){a[297719]=a[G]&1}hA(ah,21736,289493)|0;if((da(289493,21104)|0)==0){a[289493]=0;aV=ak}else{aV=ak}while(1){aW=c[aV>>2]|0;if((aW|0)==0){break}if((da(20536,c[aW+4>>2]|0)|0)==0){_=2390;break}else{aV=aW+12|0}}if((_|0)==2390){g[85482]=+sY(c[aW+8>>2]|0,0)}a[H]=0;if(hB(ah,20128,H)|0){a[342542]=a[H]&1}H=I|0;b5(H|0,64,19928,($=i,i=i+8|0,c[$>>2]=1,$)|0)|0;i=$;I=ak;while(1){aX=c[I>>2]|0;if((aX|0)==0){break}if((da(H|0,c[aX+4>>2]|0)|0)==0){_=2396;break}else{I=aX+12|0}}do{if((_|0)==2396){c[(ep()|0)>>2]=0;I=bb(c[aX+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[85483]=I}}while(0);b5(H|0,64,19928,($=i,i=i+8|0,c[$>>2]=2,$)|0)|0;i=$;aX=ak;while(1){aY=c[aX>>2]|0;if((aY|0)==0){break}if((da(H|0,c[aY+4>>2]|0)|0)==0){_=2401;break}else{aX=aY+12|0}}do{if((_|0)==2401){c[(ep()|0)>>2]=0;aX=bb(c[aY+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[85484]=aX}}while(0);b5(H|0,64,19928,($=i,i=i+8|0,c[$>>2]=3,$)|0)|0;i=$;aY=ak;while(1){aZ=c[aY>>2]|0;if((aZ|0)==0){break}if((da(H|0,c[aZ+4>>2]|0)|0)==0){_=2606;break}else{aY=aZ+12|0}}do{if((_|0)==2606){c[(ep()|0)>>2]=0;aY=bb(c[aZ+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[85485]=aY}}while(0);b5(H|0,64,19928,($=i,i=i+8|0,c[$>>2]=4,$)|0)|0;i=$;aZ=ak;while(1){a_=c[aZ>>2]|0;if((a_|0)==0){break}if((da(H|0,c[a_+4>>2]|0)|0)==0){_=2611;break}else{aZ=a_+12|0}}do{if((_|0)==2611){c[(ep()|0)>>2]=0;aZ=bb(c[a_+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[85486]=aZ}}while(0);b5(H|0,64,19928,($=i,i=i+8|0,c[$>>2]=5,$)|0)|0;i=$;a_=ak;while(1){a$=c[a_>>2]|0;if((a$|0)==0){break}if((da(H|0,c[a$+4>>2]|0)|0)==0){_=2616;break}else{a_=a$+12|0}}do{if((_|0)==2616){c[(ep()|0)>>2]=0;a_=bb(c[a$+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[85487]=a_}}while(0);b5(H|0,64,19928,($=i,i=i+8|0,c[$>>2]=6,$)|0)|0;i=$;a$=ak;while(1){a0=c[a$>>2]|0;if((a0|0)==0){break}if((da(H|0,c[a0+4>>2]|0)|0)==0){_=2621;break}else{a$=a0+12|0}}do{if((_|0)==2621){c[(ep()|0)>>2]=0;a$=bb(c[a0+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[85488]=a$}}while(0);b5(H|0,64,19928,($=i,i=i+8|0,c[$>>2]=7,$)|0)|0;i=$;a0=ak;while(1){a1=c[a0>>2]|0;if((a1|0)==0){break}if((da(H|0,c[a1+4>>2]|0)|0)==0){_=2626;break}else{a0=a1+12|0}}do{if((_|0)==2626){c[(ep()|0)>>2]=0;a0=bb(c[a1+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[85489]=a0}}while(0);b5(H|0,64,19928,($=i,i=i+8|0,c[$>>2]=8,$)|0)|0;i=$;a1=ak;while(1){a2=c[a1>>2]|0;if((a2|0)==0){break}if((da(H|0,c[a2+4>>2]|0)|0)==0){_=2631;break}else{a1=a2+12|0}}do{if((_|0)==2631){c[(ep()|0)>>2]=0;a1=bb(c[a2+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[85490]=a1}}while(0);a[J]=0;if(hB(ah,19808,J)|0){a[297756]=a[J]&1;a3=ak}else{a3=ak}while(1){a5=c[a3>>2]|0;if((a5|0)==0){a6=ak;break}if((da(19744,c[a5+4>>2]|0)|0)==0){_=2405;break}else{a3=a5+12|0}}do{if((_|0)==2405){c[(ep()|0)>>2]=0;a3=bb(c[a5+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){a6=ak;break}c[74440]=a3;a6=ak}}while(0);while(1){a8=c[a6>>2]|0;if((a8|0)==0){a9=ak;break}if((da(19616,c[a8+4>>2]|0)|0)==0){_=2409;break}else{a6=a8+12|0}}do{if((_|0)==2409){c[(ep()|0)>>2]=0;a6=bb(c[a8+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){a9=ak;break}c[74441]=a6;a9=ak}}while(0);while(1){ba=c[a9>>2]|0;if((ba|0)==0){bc=ak;break}if((da(19424,c[ba+4>>2]|0)|0)==0){_=2413;break}else{a9=ba+12|0}}L3444:do{if((_|0)==2413){a9=4096;a8=297772;a6=c[ba+8>>2]|0;while(1){a5=a9-1|0;if((a5|0)==0){break}a3=a[a6]|0;a[a8]=a3;if(a3<<24>>24==0){bc=ak;break L3444}else{a9=a5;a8=a8+1|0;a6=a6+1|0}}a[a8]=0;if((a[a6]|0)==0){bc=ak;break}else{bd=a6}while(1){a9=bd+1|0;if((a[a9]|0)==0){bc=ak;break}else{bd=a9}}}}while(0);while(1){bf=c[bc>>2]|0;if((bf|0)==0){break}if((da(19312,c[bf+4>>2]|0)|0)==0){_=2420;break}else{bc=bf+12|0}}do{if((_|0)==2420){c[(ep()|0)>>2]=0;bc=bb(c[bf+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[75467]=bc}}while(0);a[K]=0;if(hB(ah,19192,K)|0){a[301872]=a[K]&1}a[L]=0;if(hB(ah,18808,L)|0){a[305969]=a[L]&1;bg=ak}else{bg=ak}while(1){bh=c[bg>>2]|0;if((bh|0)==0){bi=ak;break}if((da(18544,c[bh+4>>2]|0)|0)==0){_=2428;break}else{bg=bh+12|0}}if((_|0)==2428){g[76493]=+sY(c[bh+8>>2]|0,0);bi=ak}while(1){bj=c[bi>>2]|0;if((bj|0)==0){bk=ak;break}if((da(18360,c[bj+4>>2]|0)|0)==0){_=2431;break}else{bi=bj+12|0}}if((_|0)==2431){g[76494]=+sY(c[bj+8>>2]|0,0);bk=ak}while(1){bl=c[bk>>2]|0;if((bl|0)==0){bm=ak;break}if((da(18128,c[bl+4>>2]|0)|0)==0){_=2434;break}else{bk=bl+12|0}}L3477:do{if((_|0)==2434){bk=32;bj=281176;bi=c[bl+8>>2]|0;while(1){bh=bk-1|0;if((bh|0)==0){break}bg=a[bi]|0;a[bj]=bg;if(bg<<24>>24==0){bm=ak;break L3477}else{bk=bh;bj=bj+1|0;bi=bi+1|0}}a[bj]=0;if((a[bi]|0)==0){bm=ak;break}else{bn=bi}while(1){bk=bn+1|0;if((a[bk]|0)==0){bm=ak;break}else{bn=bk}}}}while(0);while(1){bo=c[bm>>2]|0;if((bo|0)==0){bp=ak;break}if((da(17944,c[bo+4>>2]|0)|0)==0){_=2441;break}else{bm=bo+12|0}}L3488:do{if((_|0)==2441){bm=32;bn=281208;bl=c[bo+8>>2]|0;while(1){bi=bm-1|0;if((bi|0)==0){break}bj=a[bl]|0;a[bn]=bj;if(bj<<24>>24==0){bp=ak;break L3488}else{bm=bi;bn=bn+1|0;bl=bl+1|0}}a[bn]=0;if((a[bl]|0)==0){bp=ak;break}else{bq=bl}while(1){bm=bq+1|0;if((a[bm]|0)==0){bp=ak;break}else{bq=bm}}}}while(0);while(1){br=c[bp>>2]|0;if((br|0)==0){break}if((da(17808,c[br+4>>2]|0)|0)==0){_=2448;break}else{bp=br+12|0}}L3499:do{if((_|0)==2448){bp=32;bq=297724;bo=c[br+8>>2]|0;while(1){bl=bp-1|0;if((bl|0)==0){break}bn=a[bo]|0;a[bq]=bn;if(bn<<24>>24==0){break L3499}else{bp=bl;bq=bq+1|0;bo=bo+1|0}}a[bq]=0;if((a[bo]|0)==0){break}else{bs=bo}do{bs=bs+1|0;}while((a[bs]|0)!=0)}}while(0);hA(ah,17592,301873)|0;bs=ak;while(1){bt=c[bs>>2]|0;if((bt|0)==0){bu=ak;break}if((da(40080,c[bt+4>>2]|0)|0)==0){_=2456;break}else{bs=bt+12|0}}L3511:do{if((_|0)==2456){bs=32;br=306016;bo=c[bt+8>>2]|0;while(1){bq=bs-1|0;if((bq|0)==0){break}bp=a[bo]|0;a[br]=bp;if(bp<<24>>24==0){bu=ak;break L3511}else{bs=bq;br=br+1|0;bo=bo+1|0}}a[br]=0;if((a[bo]|0)==0){bu=ak;break}else{bv=bo}while(1){bs=bv+1|0;if((a[bs]|0)==0){bu=ak;break}else{bv=bs}}}}while(0);while(1){bw=c[bu>>2]|0;if((bw|0)==0){break}if((da(17152,c[bw+4>>2]|0)|0)==0){_=2463;break}else{bu=bw+12|0}}L3522:do{if((_|0)==2463){bu=32;bv=306048;bt=c[bw+8>>2]|0;while(1){bo=bu-1|0;if((bo|0)==0){break}br=a[bt]|0;a[bv]=br;if(br<<24>>24==0){break L3522}else{bu=bo;bv=bv+1|0;bt=bt+1|0}}a[bv]=0;if((a[bt]|0)==0){break}else{bx=bt}do{bx=bx+1|0;}while((a[bx]|0)!=0)}}while(0);if((a[358948]|0)==0){hA(ah,16928,358948)|0}hA(ah,16624,350752)|0;hA(ah,16288,371236)|0;do{if((a[371236]|0)!=0){if((fh(371236,j|0)|0)>=0){if((c[j+8>>2]&61440|0)==16384){break}}bx=c[135158]|0;bw=(bx|0)!=0?bx:c[t>>2]|0;be(15984,84,1,bw|0)|0;bw=c[135158]|0;bx=(bw|0)!=0?bw:c[t>>2]|0;a7(bx|0)|0;a[371236]=0}}while(0);hA(ah,15728,379465)|0;if((da(379465,21104)|0)==0){a[379465]=0}hA(ah,15600,461458)|0;if((da(461458,21104)|0)==0){a[461458]=0}hA(ah,15480,342552)|0;j=ak;while(1){by=c[j>>2]|0;if((by|0)==0){bz=ak;break}if((da(15312,c[by+4>>2]|0)|0)==0){_=2481;break}else{j=by+12|0}}if((_|0)==2481){g[86662]=+sY(c[by+8>>2]|0,0);bz=ak}while(1){bA=c[bz>>2]|0;if((bA|0)==0){break}if((da(15136,c[bA+4>>2]|0)|0)==0){_=2484;break}else{bz=bA+12|0}}if((_|0)==2484){g[86663]=+sY(c[bA+8>>2]|0,0)}a[M]=0;if(hB(ah,15016,M)|0){a[379428]=a[M]&1;bB=ak}else{bB=ak}while(1){bC=c[bB>>2]|0;if((bC|0)==0){bD=ak;break}if((da(14808,c[bC+4>>2]|0)|0)==0){_=2489;break}else{bB=bC+12|0}}do{if((_|0)==2489){c[(ep()|0)>>2]=0;bB=bb(c[bC+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){bD=ak;break}c[94858]=bB*1e6|0;bD=ak}}while(0);while(1){bE=c[bD>>2]|0;if((bE|0)==0){bF=ak;break}if((da(14536,c[bE+4>>2]|0)|0)==0){_=2493;break}else{bD=bE+12|0}}do{if((_|0)==2493){c[(ep()|0)>>2]=0;bD=bb(c[bE+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){bF=ak;break}c[94859]=bD;bF=ak}}while(0);while(1){bG=c[bF>>2]|0;if((bG|0)==0){_=2498;break}if((da(14104,c[bG+4>>2]|0)|0)==0){_=2497;break}else{bF=bG+12|0}}if((_|0)==2497){bH=+sY(c[bG+8>>2]|0,0);g[94860]=bH;bI=bH}else if((_|0)==2498){bI=+g[94860]}if(bI<1.0){g[94860]=1.0;bJ=ak}else{bJ=ak}while(1){bK=c[bJ>>2]|0;if((bK|0)==0){break}if((da(13864,c[bK+4>>2]|0)|0)==0){_=2503;break}else{bJ=bK+12|0}}if((_|0)==2503){g[94861]=+sY(c[bK+8>>2]|0,0)}a[N]=0;if(hB(ah,13552,N)|0){a[379448]=a[N]&1;bL=ak}else{bL=ak}while(1){bM=c[bL>>2]|0;if((bM|0)==0){break}if((da(13384,c[bM+4>>2]|0)|0)==0){_=2508;break}else{bL=bM+12|0}}do{if((_|0)==2508){c[(ep()|0)>>2]=0;bL=bb(c[bM+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[94863]=bL}}while(0);hA(ah,13280,363044)|0;hA(ah,13136,367140)|0;a[O]=0;if(hB(ah,12856,O)|0){a[379456]=a[O]&1}a[P]=0;if(hB(ah,12704,P)|0){a[379457]=a[P]&1}a[Q]=0;if(hB(ah,12536,Q)|0){a[379458]=a[Q]&1}a[R]=0;if(hB(ah,12336,R)|0){a[379459]=a[R]&1}a[S]=0;if(hB(ah,11856,S)|0){a[379460]=a[S]&1;bN=ak}else{bN=ak}while(1){bO=c[bN>>2]|0;if((bO|0)==0){break}if((da(11656,c[bO+4>>2]|0)|0)==0){_=2522;break}else{bN=bO+12|0}}do{if((_|0)==2522){c[(ep()|0)>>2]=0;bN=bb(c[bO+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}b[189731]=bN&65535}}while(0);a[T]=0;if(hB(ah,11488,T)|0){a[379464]=a[T]&1}hA(ah,11336,354848)|0;T=ak;while(1){bP=c[T>>2]|0;if((bP|0)==0){bQ=ak;break}if((da(11256,c[bP+4>>2]|0)|0)==0){_=2529;break}else{T=bP+12|0}}do{if((_|0)==2529){c[(ep()|0)>>2]=0;T=bb(c[bP+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){bQ=ak;break}c[89736]=T;bQ=ak}}while(0);while(1){bR=c[bQ>>2]|0;if((bR|0)==0){bS=ak;break}if((da(11120,c[bR+4>>2]|0)|0)==0){_=2533;break}else{bQ=bR+12|0}}do{if((_|0)==2533){c[(ep()|0)>>2]=0;bQ=bb(c[bR+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){bS=ak;break}c[85636]=bQ;bS=ak}}while(0);while(1){bT=c[bS>>2]|0;if((bT|0)==0){break}if((da(10992,c[bT+4>>2]|0)|0)==0){_=2537;break}else{bS=bT+12|0}}do{if((_|0)==2537){c[(ep()|0)>>2]=0;bS=bb(c[bT+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[85637]=bS}}while(0);a[U]=0;if(hB(ah,10864,U)|0){a[342540]=a[U]&1}a[V]=0;if(hB(ah,52680,V)|0){a[342541]=a[V]&1}hA(ah,52432,346656)|0;a[W]=0;if(hB(ah,51984,W)|0){a[540638]=a[W]&1}L3647:do{if((a[404112]&1)==0){W=m|0;if(!(hA(ah,51832,W)|0)){break}if((da(W|0,21104)|0)==0){a[453266]=0;break}do{if((fh(W|0,h|0)|0)>=0){if((c[h+8>>2]&61440|0)==16384){bU=4096;bV=453266;bW=W}else{break}while(1){V=bU-1|0;if((V|0)==0){_=2553;break}U=a[bW]|0;a[bV]=U;if(U<<24>>24==0){bX=4096;bY=424594;bZ=W;break}else{bU=V;bV=bV+1|0;bW=bW+1|0}}do{if((_|0)==2553){a[bV]=0;if((a[bW]|0)==0){bX=4096;bY=424594;bZ=W;break}else{b_=bW}while(1){V=b_+1|0;if((a[V]|0)==0){bX=4096;bY=424594;bZ=W;break}else{b_=V}}}}while(0);while(1){V=bX-1|0;if((V|0)==0){_=2557;break}U=a[bZ]|0;a[bY]=U;if(U<<24>>24==0){break}else{bX=V;bY=bY+1|0;bZ=bZ+1|0}}do{if((_|0)==2557){a[bY]=0;if((a[bZ]|0)==0){break}else{b$=bZ}do{b$=b$+1|0;}while((a[b$]|0)!=0)}}while(0);hm(424594,51672);break L3647}}while(0);W=c[135158]|0;V=(W|0)!=0?W:c[t>>2]|0;be(51472,72,1,V|0)|0;V=c[135158]|0;W=(V|0)!=0?V:c[t>>2]|0;a7(W|0)|0}}while(0);L3672:do{if((a[404113]&1)==0){b$=m|0;if(!(hA(ah,51328,b$)|0)){break}if((da(b$|0,21104)|0)==0){a[457362]=0;break}do{if((fh(b$|0,f|0)|0)>=0){if((c[f+8>>2]&61440|0)==16384){b0=4096;b1=457362;b2=b$}else{break}while(1){bZ=b0-1|0;if((bZ|0)==0){_=2569;break}bY=a[b2]|0;a[b1]=bY;if(bY<<24>>24==0){b3=4096;b4=445074;b6=b$;break}else{b0=bZ;b1=b1+1|0;b2=b2+1|0}}do{if((_|0)==2569){a[b1]=0;if((a[b2]|0)==0){b3=4096;b4=445074;b6=b$;break}else{b7=b2}while(1){bZ=b7+1|0;if((a[bZ]|0)==0){b3=4096;b4=445074;b6=b$;break}else{b7=bZ}}}}while(0);while(1){bZ=b3-1|0;if((bZ|0)==0){_=2573;break}bY=a[b6]|0;a[b4]=bY;if(bY<<24>>24==0){break}else{b3=bZ;b4=b4+1|0;b6=b6+1|0}}do{if((_|0)==2573){a[b4]=0;if((a[b6]|0)==0){break}else{b8=b6}do{b8=b8+1|0;}while((a[b8]|0)!=0)}}while(0);hm(445074,51160);break L3672}}while(0);b$=c[135158]|0;bZ=(b$|0)!=0?b$:c[t>>2]|0;be(50904,73,1,bZ|0)|0;bZ=c[135158]|0;b$=(bZ|0)!=0?bZ:c[t>>2]|0;a7(b$|0)|0}}while(0);if(!(hA(ah,50544,375332)|0)){b8=c[135158]|0;b6=(b8|0)!=0?b8:c[t>>2]|0;eQ(b6|0,50240,($=i,i=i+8|0,c[$>>2]=375332,$)|0)|0;i=$;$=c[135158]|0;b6=($|0)!=0?$:c[t>>2]|0;a7(b6|0)|0}if((da(375332,21104)|0)==0){a[375332]=0;b9=0}else{b9=0}do{b6=10200+(b9<<2)|0;L3704:do{if((b9|0)==0){$=0;b8=6704;while(1){b4=306080+($*40|0)|0;do{if((a[b4|0]&1)==0){_=2588}else{b3=c[6712+($*20|0)>>2]|0;if(($|0)==56){ca=57;break}b7=($-25|0)>>>0<31?40672:39728;h6(ah,b7,b3,b4);b2=a[b8]|0;if((b2&1)==0){cb=b2}else{h7(ah,b7,b3,b4);cb=a[b8]|0}if((cb&1)==0){_=2588;break}h8(ah,b7,b3,b4);_=2588}}while(0);if((_|0)==2588){_=0;b4=$+1|0;if((b4|0)==56){break L3704}else{ca=b4}}$=ca;b8=6704+(ca*20|0)|0}}else{b8=0;$=6704;while(1){b4=306080+(b9*2240|0)+(b8*40|0)|0;do{if((a[b4|0]&1)==0){_=2597}else{b3=c[6712+(b8*20|0)>>2]|0;if((b8|0)==56){cc=57;break}if((b8-25|0)>>>0<31){_=2597;break}b7=c[b6>>2]|0;h6(ah,b7,b3,b4);b2=a[$]|0;if((b2&1)==0){cd=b2}else{h7(ah,b7,b3,b4);cd=a[$]|0}if((cd&1)==0){_=2597;break}h8(ah,b7,b3,b4);_=2597}}while(0);if((_|0)==2597){_=0;b4=b8+1|0;if((b4|0)==56){break L3704}else{cc=b4}}b8=cc;$=6704+(cc*20|0)|0}}}while(0);b9=b9+1|0;}while(b9>>>0<8);hx(ah);ad=1;i=e;return ad|0}function hF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=ev(c[a>>2]|0)|0;c[a+68>>2]=b;c[a+72>>2]=ev(c[a+4>>2]|0)|0;c[a+76>>2]=ev(c[a+8>>2]|0)|0;c[a+80>>2]=ev(c[a+12>>2]|0)|0;c[a+84>>2]=ev(c[a+16>>2]|0)|0;c[a+88>>2]=ev(c[a+20>>2]|0)|0;c[a+92>>2]=ev(c[a+24>>2]|0)|0;c[a+96>>2]=ev(c[a+28>>2]|0)|0;c[a+100>>2]=ev(c[a+32>>2]|0)|0;c[a+104>>2]=ev(c[a+36>>2]|0)|0;c[a+108>>2]=ev(c[a+40>>2]|0)|0;c[a+112>>2]=ev(c[a+44>>2]|0)|0;c[a+116>>2]=ev(c[a+48>>2]|0)|0;c[a+120>>2]=ev(c[a+52>>2]|0)|0;c[a+124>>2]=ev(c[a+56>>2]|0)|0;c[a+128>>2]=ev(c[a+60>>2]|0)|0;d=16;e=b;while(1){b=c[a+68+(d-15<<2)>>2]|0;f=c[a+68+(d-2<<2)>>2]|0;c[a+68+(d<<2)>>2]=(c[a+68+(d-7<<2)>>2]|0)+e+((b>>>18|b<<14)^b>>>3^(b>>>7|b<<25))+((f>>>19|f<<13)^f>>>10^(f>>>17|f<<15));f=d+1|0;if(f>>>0<64){d=f;e=b}else{break}}e=a+324|0;d=c[e>>2]|0;b=a+328|0;f=c[b>>2]|0;g=a+332|0;h=c[g>>2]|0;i=a+336|0;j=c[i>>2]|0;k=a+340|0;l=c[k>>2]|0;m=a+344|0;n=c[m>>2]|0;o=a+348|0;p=c[o>>2]|0;q=a+352|0;r=c[q>>2]|0;s=f;t=h;u=j;v=l;w=n;x=p;y=r;z=d;A=0;while(1){B=(x&~v^v&w)+y+((v>>>6|v<<26)^(v>>>11|v<<21)^(v>>>25|v<<7))+(c[62520+(A<<2)>>2]|0)+(c[a+68+(A<<2)>>2]|0)|0;C=B+u|0;D=((s^t)&z^s&t)+((z>>>2|z<<30)^(z>>>13|z<<19)^(z>>>22|z<<10))+B|0;B=A+1|0;if(B>>>0<64){u=t;t=s;s=z;y=x;x=w;w=v;v=C;z=D;A=B}else{break}}c[e>>2]=D+d;c[b>>2]=z+f;c[g>>2]=s+h;c[i>>2]=t+j;c[k>>2]=C+l;c[m>>2]=v+n;c[o>>2]=w+p;c[q>>2]=x+r;c[a+64>>2]=0;return}function hG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+4096|0;f=e|0;if((b|0)==15){if((a[383584]&1)!=0){g=c[135158]|0;h=(g|0)!=0?g:c[t>>2]|0;g=c[d>>2]|0;eQ(h|0,26600,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;g=c[135158]|0;h=(g|0)!=0?g:c[t>>2]|0;a7(h|0)|0}h=c[120666]|0;do{if((h|0)==0){c[d+4>>2]=0;k=0}else{a[h+4108|0]=0;g=c[h+4104>>2]|0;l=h+4100|0;m=d;n=0;while(1){if(n>>>0>=g>>>0){o=2655;break}p=c[l>>2]|0;if((da(c[p+(n<<4)+4>>2]|0,c[m>>2]|0)|0)==0){o=2654;break}else{n=n+1|0}}if((o|0)==2654){m=c[(c[c[p+(n<<4)+8>>2]>>2]|0)+(c[p+(n<<4)+12>>2]<<3)>>2]|0;c[d+4>>2]=m;k=m;break}else if((o|0)==2655){c[d+4>>2]=0;k=0;break}}}while(0);if((a[383584]&1)==0){q=1;i=e;return q|0}p=c[135158]|0;h=(p|0)!=0?p:c[t>>2]|0;p=(k|0)==0?16648:k;eQ(h|0,22816,(j=i,i=i+8|0,c[j>>2]=p,j)|0)|0;i=j;p=c[135158]|0;h=(p|0)!=0?p:c[t>>2]|0;a7(h|0)|0;q=1;i=e;return q|0}else if((b|0)==3){a[d]=1;if((a[383584]&1)==0){q=1;i=e;return q|0}h=c[135158]|0;be(30920,38,1,((h|0)!=0?h:c[t>>2]|0)|0)|0;h=c[135158]|0;a7(((h|0)!=0?h:c[t>>2]|0)|0)|0;q=1;i=e;return q|0}else if((b|0)==2){a[d]=a[281278]&1^1;if((a[383584]&1)==0){q=1;i=e;return q|0}h=c[135158]|0;eQ(((h|0)!=0?h:c[t>>2]|0)|0,41792,(j=i,i=i+8|0,c[j>>2]=(a[281278]&1^1)&255,j)|0)|0;i=j;h=c[135158]|0;a7(((h|0)!=0?h:c[t>>2]|0)|0)|0;q=1;i=e;return q|0}else if((b|0)==16){if((a[383584]&1)!=0){h=c[135158]|0;p=(h|0)!=0?h:c[t>>2]|0;be(17768,34,1,p|0)|0;p=c[135158]|0;h=(p|0)!=0?p:c[t>>2]|0;a7(h|0)|0}h=c[120666]|0;if((h|0)!=0){p=h+4104|0;if((c[p>>2]|0)==0){r=h|0}else{k=h+4100|0;m=h|0;l=0;while(1){g=c[k>>2]|0;hC(c[m>>2]|0,c[g+(l<<4)+4>>2]|0,c[(c[c[g+(l<<4)+8>>2]>>2]|0)+(c[g+(l<<4)+12>>2]<<3)>>2]|0);g=l+1|0;if(g>>>0<(c[p>>2]|0)>>>0){l=g}else{r=m;break}}}m=c[r>>2]|0;r=h+4|0;hD(m,r)|0;ig(c[120666]|0)}r=d;if((a[350752]|0)!=0|(a[404114]|0)==0){s=350752}else{m=f|0;ht(m,404114,15448);s=m}m=sR(4112)|0;L3786:do{if((m|0)==0){u=0}else{if((c[m-4>>2]&3|0)!=0){s_(m|0,0,4112)}f=m;if((a[s]|0)==0){v=c[m>>2]|0}else{h=hz(s,0)|0;c[m>>2]=h;v=h}h=m;if((v|0)==0){l=sR(20)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}s_(l|0,0,20)}}while(0);c[h>>2]=l}n=4096;p=m+4|0;k=s;while(1){g=n-1|0;if((g|0)==0){o=2686;break}w=a[k]|0;a[p]=w;if(w<<24>>24==0){break}else{n=g;p=p+1|0;k=k+1|0}}do{if((o|0)==2686){a[p]=0;if((a[k]|0)==0){break}else{x=k}do{x=x+1|0;}while((a[x]|0)!=0)}}while(0);do{if((c[h>>2]|0)!=0){k=d;p=c[k>>2]|0;n=(p|0)==0;do{if(n){y=0;z=0}else{l=0;g=r;while(1){if((c[g+4>>2]|0)==0){A=l;break}w=l+1|0;B=g+8|0;if((c[B>>2]|0)==0){A=w;break}else{l=w;g=B}}if((A|0)==0){y=0;z=0;break}g=A<<4;if(A>>>0<=65535){y=g;z=A;break}y=((g>>>0)/(A>>>0)|0|0)==16?g:-1;z=A}}while(0);g=sR(y)|0;if((g|0)==0){c[m+4100>>2]=0;break}if((c[g-4>>2]&3|0)==0){l=m+4100|0;c[l>>2]=g;C=l}else{s_(g|0,0,y|0);l=m+4100|0;c[l>>2]=g;C=l}c[m+4104>>2]=z;if(n){u=f;break L3786}else{D=0;E=k;F=p}while(1){l=E+4|0;if((c[l>>2]|0)==0){u=f;break L3786}g=c[C>>2]|0;B=g+(D<<4)+4|0;c[B>>2]=dT(F|0)|0;G=dT(c[l>>2]|0)|0;l=bJ(G|0,51592)|0;if((l|0)==0){o=2703;break}a[l]=0;w=g+(D<<4)|0;c[w>>2]=dT(G|0)|0;H=hh(l+2|0,48016)|0;l=g+(D<<4)+8|0;c[l>>2]=H;if((H|0)==0){o=2705;break}H=c[B>>2]|0;I=(c[h>>2]|0)+4|0;while(1){J=c[I>>2]|0;if((J|0)==0){break}if((da(H|0,c[J+4>>2]|0)|0)==0){o=2709;break}else{I=J+12|0}}if((o|0)==2709){o=0;I=dT(c[J+8>>2]|0)|0;H=c[l>>2]|0;K=c[H+4>>2]|0;L=H|0;H=0;while(1){if(H>>>0>=K>>>0){break}if((da(c[(c[L>>2]|0)+(H<<3)>>2]|0,I|0)|0)==0){o=2712;break}else{H=H+1|0}}if((o|0)==2712){o=0;c[g+(D<<4)+12>>2]=H}sS(I)}sS(G);L=a[383584]|0;if((L&1)==0){M=L}else{L=c[135158]|0;K=(L|0)!=0?L:c[t>>2]|0;be(37520,24,1,K|0)|0;K=c[135158]|0;L=(K|0)!=0?K:c[t>>2]|0;a7(L|0)|0;M=a[383584]|0}if((M&1)==0){N=M}else{L=c[135158]|0;K=(L|0)!=0?L:c[t>>2]|0;L=c[w>>2]|0;eQ(K|0,29376,(j=i,i=i+8|0,c[j>>2]=L,j)|0)|0;i=j;L=c[135158]|0;K=(L|0)!=0?L:c[t>>2]|0;a7(K|0)|0;N=a[383584]|0}if((N&1)==0){O=N}else{K=c[135158]|0;L=(K|0)!=0?K:c[t>>2]|0;K=c[B>>2]|0;eQ(L|0,24912,(j=i,i=i+8|0,c[j>>2]=K,j)|0)|0;i=j;K=c[135158]|0;L=(K|0)!=0?K:c[t>>2]|0;a7(L|0)|0;O=a[383584]|0}if((O&1)==0){P=O}else{L=c[135158]|0;K=(L|0)!=0?L:c[t>>2]|0;L=c[C>>2]|0;Q=c[(c[c[L+(D<<4)+8>>2]>>2]|0)+(c[L+(D<<4)+12>>2]<<3)>>2]|0;eQ(K|0,21672,(j=i,i=i+8|0,c[j>>2]=Q,j)|0)|0;i=j;Q=c[135158]|0;K=(Q|0)!=0?Q:c[t>>2]|0;a7(K|0)|0;P=a[383584]|0}if((P&1)!=0){K=c[135158]|0;Q=(K|0)!=0?K:c[t>>2]|0;be(19096,29,1,Q|0)|0;Q=c[135158]|0;K=(Q|0)!=0?Q:c[t>>2]|0;a7(K|0)|0}K=c[l>>2]|0;if((c[K+4>>2]|0)!=0){Q=0;L=K;while(1){if((a[383584]&1)==0){R=L}else{K=c[135158]|0;S=(K|0)!=0?K:c[t>>2]|0;K=c[(c[L>>2]|0)+(Q<<3)>>2]|0;eQ(S|0,16872,(j=i,i=i+8|0,c[j>>2]=K,j)|0)|0;i=j;K=c[135158]|0;S=(K|0)!=0?K:c[t>>2]|0;a7(S|0)|0;R=c[l>>2]|0}S=Q+1|0;if(S>>>0<(c[R+4>>2]|0)>>>0){Q=S;L=R}else{break}}}L=E+8|0;Q=c[L>>2]|0;if((Q|0)==0){u=f;break L3786}else{D=D+1|0;E=L;F=Q}}if((o|0)==2703){sS(G);break}else if((o|0)==2705){sS(G);break}}}while(0);ig(f);u=0}}while(0);c[120666]=u;q=1;i=e;return q|0}else if((b|0)==6){if((a[383584]&1)!=0){u=c[135158]|0;G=(u|0)!=0?u:c[t>>2]|0;u=c[d>>2]|0;eQ(G|0,13240,(j=i,i=i+8|0,c[j>>2]=u,j)|0)|0;i=j;u=c[135158]|0;G=(u|0)!=0?u:c[t>>2]|0;a7(G|0)|0}G=c[133027]|0;if((G|0)==0){q=1;i=e;return q|0}u=G+4|0;F=c[u>>2]|0;if(F>>>0>1){E=G|0;D=1;R=F;while(1){F=c[(c[E>>2]|0)+(D<<2)>>2]|0;if((F|0)==0){T=R}else{sS(c[F+8>>2]|0);sS(c[(c[E>>2]|0)+(D<<2)>>2]|0);c[(c[E>>2]|0)+(D<<2)>>2]=0;T=c[u>>2]|0}F=D+1|0;if(F>>>0<T>>>0){D=F;R=T}else{break}}}c[u>>2]=1;u=G+12|0;sS(c[u>>2]|0);c[u>>2]=0;u=c[133027]|0;G=c[d>>2]|0;T=u+4|0;R=c[T>>2]|0;if(R>>>0>=(c[u+8>>2]|0)>>>0){q=1;i=e;return q|0}D=c[d+4>>2]|0;E=sR(12)|0;do{if((E|0)!=0){if((c[E-4>>2]&3|0)==0){break}s_(E|0,0,12)}}while(0);c[E+4>>2]=1;c[E>>2]=D;if((G|0)==0){U=0;V=R}else{R=dT(G|0)|0;U=R;V=c[T>>2]|0}c[E+8>>2]=U;U=u|0;c[(c[U>>2]|0)+(V<<2)>>2]=E;E=c[T>>2]|0;c[T>>2]=E+1;if(E>>>0>1){W=E}else{q=1;i=e;return q|0}while(1){E=W>>>1;T=c[U>>2]|0;V=T+(E<<2)|0;u=c[V>>2]|0;R=c[T+(W<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[u+4>>2]|0)>>>0){q=1;o=2846;break}c[V>>2]=R;c[(c[U>>2]|0)+(W<<2)>>2]=u;if(W>>>0>3){W=E}else{q=1;o=2847;break}}if((o|0)==2846){i=e;return q|0}else if((o|0)==2847){i=e;return q|0}}else if((b|0)==1){W=c[d>>2]|0;if((a[383584]&1)!=0){U=c[135158]|0;E=(U|0)!=0?U:c[t>>2]|0;eQ(E|0,11216,(j=i,i=i+8|0,c[j>>2]=W,j)|0)|0;i=j;E=c[135158]|0;U=(E|0)!=0?E:c[t>>2]|0;a7(U|0)|0}if((a[297720]&1)==0){q=1;i=e;return q|0}c[119483]=W;U=c[136863]|0;if((U|0)==0){q=0;i=e;return q|0}E=c[U+40>>2]|0;if((E|0)==0){q=0;i=e;return q|0}U=c[136866]|0;if((U|0)==0){q=1;i=e;return q|0}f0[E&255](U,W);q=1;i=e;return q|0}else if((b|0)==7){if((a[383584]&1)!=0){W=c[135158]|0;U=(W|0)!=0?W:c[t>>2]|0;be(51296,29,1,U|0)|0;U=c[135158]|0;W=(U|0)!=0?U:c[t>>2]|0;a7(W|0)|0}a[477936]=1;q=1;i=e;return q|0}else if((b|0)==8){W=c[d>>2]|0;c[119485]=W;if((a[383584]&1)==0){q=1;i=e;return q|0}U=c[135158]|0;eQ(((U|0)!=0?U:c[t>>2]|0)|0,48408,(j=i,i=i+8|0,c[j>>2]=W,j)|0)|0;i=j;W=c[135158]|0;a7(((W|0)!=0?W:c[t>>2]|0)|0)|0;q=1;i=e;return q|0}else if((b|0)==9){c[d>>2]=(a[375332]|0)!=0?375332:0;if((a[383584]&1)==0){q=1;i=e;return q|0}W=c[135158]|0;eQ(((W|0)!=0?W:c[t>>2]|0)|0,46536,(j=i,i=i+8|0,c[j>>2]=375332,j)|0)|0;i=j;W=c[135158]|0;a7(((W|0)!=0?W:c[t>>2]|0)|0)|0;q=1;i=e;return q|0}else if((b|0)==10){W=c[d>>2]|0;do{if((W|0)==0){if((a[383584]&1)==0){break}U=c[135158]|0;E=(U|0)!=0?U:c[t>>2]|0;be(45448,47,1,E|0)|0;E=c[135158]|0;U=(E|0)!=0?E:c[t>>2]|0;a7(U|0)|0}else if((W|0)==2){if((a[383584]&1)==0){break}U=c[135158]|0;be(44200,45,1,((U|0)!=0?U:c[t>>2]|0)|0)|0;U=c[135158]|0;a7(((U|0)!=0?U:c[t>>2]|0)|0)|0}else if((W|0)==1){if((a[383584]&1)==0){break}U=c[135158]|0;be(42736,47,1,((U|0)!=0?U:c[t>>2]|0)|0)|0;U=c[135158]|0;a7(((U|0)!=0?U:c[t>>2]|0)|0)|0}else{q=0;i=e;return q|0}}while(0);c[119486]=W;q=1;i=e;return q|0}else if((b|0)==11){s_(477952,0,512);W=c[d+16>>2]|0;if((W|0)!=0){U=d;E=W;while(1){W=c[U>>2]|0;do{if(W>>>0<=7){if((c[U+4>>2]|0)!=1){break}u=c[U+12>>2]|0;if(u>>>0>15){break}c[477952+(W<<6)+(u<<2)>>2]=E}}while(0);W=c[U+36>>2]|0;if((W|0)==0){break}else{U=U+20|0;E=W}}}if((a[383584]&1)==0){X=0}else{E=c[135158]|0;U=(E|0)!=0?E:c[t>>2]|0;be(28104,42,1,U|0)|0;U=c[135158]|0;E=(U|0)!=0?U:c[t>>2]|0;a7(E|0)|0;X=0}while(1){E=X+1|0;U=0;do{W=c[477952+(X<<6)+(U<<2)>>2]|0;do{if((W|0)!=0){if((a[383584]&1)==0){break}f=c[135158]|0;u=(f|0)!=0?f:c[t>>2]|0;f=c[5768+(U<<2)>>2]|0;eQ(u|0,27720,(j=i,i=i+24|0,c[j>>2]=E,c[j+8>>2]=f,c[j+16>>2]=W,j)|0)|0;i=j;f=c[135158]|0;u=(f|0)!=0?f:c[t>>2]|0;a7(u|0)|0}}while(0);U=U+1|0;}while(U>>>0<16);if(E>>>0<8){X=E}else{q=1;break}}i=e;return q|0}else if((b|0)==12){if((a[383584]&1)!=0){X=c[135158]|0;U=(X|0)!=0?X:c[t>>2]|0;be(27344,42,1,U|0)|0;U=c[135158]|0;X=(U|0)!=0?U:c[t>>2]|0;a7(X|0)|0}c[120640]=c[d>>2];q=1;i=e;return q|0}else if((b|0)==13){if((a[383584]&1)!=0){X=c[135158]|0;U=(X|0)!=0?X:c[t>>2]|0;be(26976,47,1,U|0)|0;U=c[135158]|0;X=(U|0)!=0?U:c[t>>2]|0;a7(X|0)|0}c[120642]=c[d>>2];c[482572>>2]=c[d+4>>2];c[482576>>2]=c[d+8>>2];c[482580>>2]=c[d+12>>2];c[482584>>2]=c[d+16>>2];c[482588>>2]=c[d+20>>2];c[482592>>2]=c[d+24>>2];q=1;i=e;return q|0}else if((b|0)==14|(b|0)==65550){if((a[383584]&1)!=0){X=c[135158]|0;U=(X|0)!=0?X:c[t>>2]|0;be(26560,34,1,U|0)|0;U=c[135158]|0;X=(U|0)!=0?U:c[t>>2]|0;a7(X|0)|0}X=c[d>>2]|0;do{if((X|0)==0){if((a[383584]&1)==0){break}U=c[135158]|0;W=(U|0)!=0?U:c[t>>2]|0;be(26208,37,1,W|0)|0;W=c[135158]|0;U=(W|0)!=0?W:c[t>>2]|0;a7(U|0)|0}else if((X|0)==2){if((a[383584]&1)!=0){U=c[135158]|0;W=(U|0)!=0?U:c[t>>2]|0;be(25864,41,1,W|0)|0;W=c[135158]|0;U=(W|0)!=0?W:c[t>>2]|0;a7(U|0)|0}c[136863]=72}else if((X|0)==1|(X|0)==3){U=c[135158]|0;be(25448,116,1,((U|0)!=0?U:c[t>>2]|0)|0)|0;U=c[135158]|0;a7(((U|0)!=0?U:c[t>>2]|0)|0)|0;q=0;i=e;return q|0}else{if((a[383584]&1)==0){q=0;i=e;return q|0}U=c[135158]|0;be(25080,39,1,((U|0)!=0?U:c[t>>2]|0)|0)|0;U=c[135158]|0;a7(((U|0)!=0?U:c[t>>2]|0)|0)|0;q=0;i=e;return q|0}}while(0);c[d+8>>2]=20;c[d+12>>2]=80;if((b&65536|0)==0){s1(482596,d|0,40)|0;q=1;i=e;return q|0}else{c[120649]=c[d>>2];c[482600>>2]=c[d+4>>2];c[482604>>2]=c[d+8>>2];c[482608>>2]=c[d+12>>2];a[482612|0]=a[d+16|0]|0;q=1;i=e;return q|0}}else if((b|0)==18){X=a[d]|0;if((a[383584]&1)==0){Y=X&1}else{U=c[135158]|0;W=(U|0)!=0?U:c[t>>2]|0;U=X&1;X=U<<24>>24!=0?23808:23576;eQ(W|0,24240,(j=i,i=i+8|0,c[j>>2]=X,j)|0)|0;i=j;X=c[135158]|0;W=(X|0)!=0?X:c[t>>2]|0;a7(W|0)|0;Y=U}a[477950]=Y;q=1;i=e;return q|0}else if((b|0)==19){c[d>>2]=0;q=1;i=e;return q|0}else if((b|0)==21){if((a[383584]&1)!=0){Y=c[135158]|0;U=(Y|0)!=0?Y:c[t>>2]|0;be(23336,44,1,U|0)|0;U=c[135158]|0;Y=(U|0)!=0?U:c[t>>2]|0;a7(Y|0)|0}c[120660]=c[d>>2];c[482644>>2]=c[d+4>>2];c[482648>>2]=c[d+8>>2];c[482652>>2]=c[d+12>>2];q=1;i=e;return q|0}else if((b|0)==131072){if((a[383584]&1)!=0){Y=c[135158]|0;U=(Y|0)!=0?Y:c[t>>2]|0;be(23048,48,1,U|0)|0;U=c[135158]|0;Y=(U|0)!=0?U:c[t>>2]|0;a7(Y|0)|0}Y=dz(d|0,42504)|0;if((Y|0)==0){q=0;i=e;return q|0}a_(Y|0)|0;Y=4096;U=358948;W=d;while(1){X=Y-1|0;if((X|0)==0){break}u=a[W]|0;a[U]=u;if(u<<24>>24==0){q=1;o=2872;break}else{Y=X;U=U+1|0;W=W+1|0}}if((o|0)==2872){i=e;return q|0}a[U]=0;if((a[W]|0)==0){q=1;i=e;return q|0}else{Z=W}while(1){W=Z+1|0;if((a[W]|0)==0){q=1;break}else{Z=W}}i=e;return q|0}else if((b|0)==131073|(b|0)==131074){L4037:do{if((d|0)==0){a[420498]=0}else{Z=4096;W=420498;U=d;while(1){o=Z-1|0;if((o|0)==0){break}Y=a[U]|0;a[W]=Y;if(Y<<24>>24==0){break L4037}else{Z=o;W=W+1|0;U=U+1|0}}a[W]=0;if((a[U]|0)==0){break}else{_=U}do{_=_+1|0;}while((a[_]|0)!=0)}}while(0);_=(a[383584]&1)!=0;if((b|0)==131074){if(_){U=c[135158]|0;W=(U|0)!=0?U:c[t>>2]|0;be(22768,42,1,W|0)|0;W=c[135158]|0;U=(W|0)!=0?W:c[t>>2]|0;a7(U|0)|0}a[532112]=1;q=1;i=e;return q|0}else{if(!_){q=1;i=e;return q|0}_=c[135158]|0;U=(_|0)!=0?_:c[t>>2]|0;be(22536,35,1,U|0)|0;U=c[135158]|0;_=(U|0)!=0?U:c[t>>2]|0;a7(_|0)|0;q=1;i=e;return q|0}}else if((b|0)==17){_=c[120666]|0;if((_|0)==0){$=0}else{$=a[_+4108|0]&1}a[d]=$;q=1;i=e;return q|0}else{if((a[383584]&1)==0){q=0;i=e;return q|0}$=c[135158]|0;eQ((($|0)!=0?$:c[t>>2]|0)|0,22256,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;j=c[135158]|0;a7(((j|0)!=0?j:c[t>>2]|0)|0)|0;q=0;i=e;return q|0}return 0}function hH(){return 1}function hI(a,b){a=a|0;b=b|0;return}function hJ(a){a=a|0;c[136858]=a;return}function hK(a){a=a|0;c[136860]=a;return}function hL(a){a=a|0;c[136854]=a;return}function hM(a){a=a|0;c[136852]=a;return}function hN(a){a=a|0;c[136850]=a;return}function hO(){return}function hP(a){a=a|0;return 0}function hQ(){return}function hR(){return 0}function hS(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function hT(){return 0}function hU(a,b){a=a|0;b=b|0;return 0}function hV(a,b){a=a|0;b=b|0;return 0}function hW(a){a=a|0;return 0}function hX(a){a=a|0;return 0}function hY(){return}function hZ(a,b,c){a=a|0;b=b|0;c=c|0;return}function h_(a){a=a|0;h[a+24>>3]=60.0;h[a+32>>3]=3.0e4;c[a>>2]=320;c[a+4>>2]=240;c[a+8>>2]=320;c[a+12>>2]=240;g[a+16>>2]=1.3333333730697632;return}function h$(){var a=0;a=sR(153600)|0;do{if((a|0)!=0){if((c[a-4>>2]&3|0)==0){break}s_(a|0,0,153600)}}while(0);c[136848]=a;return}function h0(){sS(c[136848]|0);c[136848]=0;return}function h1(b){b=b|0;s_(b|0,0,16);c[b>>2]=38360;c[b+4>>2]=547872;a[b+12|0]=0;c[b+8>>2]=547872;return}function h2(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[136856]=a;c[d>>2]=2;gj[a&127](10,d)|0;i=b;return}function h3(){var a=0,d=0;gp[c[136854]&63]();a=c[136848]|0;d=0;do{b[a+(d<<1)>>1]=128;d=d+1|0;}while(d>>>0<76800);gr[c[136850]&127](a,320,240,640);return}function h4(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+4|0;if((c[b>>2]|0)==1){d=0;return d|0}e=a|0;f=c[(c[e>>2]|0)+4>>2]|0;g=f|0;h=(c[g>>2]|0)-1|0;c[g>>2]=h;if((h|0)!=0){d=c[f+8>>2]|0;return d|0}h=a+12|0;sS(c[h>>2]|0);a=f+8|0;c[h>>2]=c[a>>2];c[a>>2]=0;a=c[e>>2]|0;f=a+4|0;g=c[f>>2]|0;i=(c[b>>2]|0)-1|0;c[b>>2]=i;c[f>>2]=c[a+(i<<2)>>2];sS(g);g=1;while(1){i=g<<1;a=c[b>>2]|0;if(i>>>0>a>>>0){j=0}else{f=c[e>>2]|0;j=(c[f+(g<<2)>>2]|0)>>>0<(c[f+(i<<2)>>2]|0)>>>0}f=i|1;if(f>>>0>a>>>0){k=0}else{a=c[e>>2]|0;k=(c[a+(g<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0}if(!(j|k)){break}do{if(k|j^1){if(!(j|k^1)){l=f;break}a=c[e>>2]|0;l=(c[a+(i<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0?f:i}else{l=i}}while(0);i=c[e>>2]|0;f=i+(g<<2)|0;a=c[f>>2]|0;c[f>>2]=c[i+(l<<2)>>2];c[(c[e>>2]|0)+(l<<2)>>2]=a;g=l}d=c[h>>2]|0;return d|0}function h5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+16|0;f=e|0;g=f|0;h=f;j=sR(36)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){s_(j|0,0,36)}l=j;m=f;L4129:do{if((d|0)==0){a[j+24|0]=1;n=dz(b|0,42504)|0;c[j>>2]=n;if((n|0)==0){o=c[135158]|0;p=(o|0)!=0?o:c[t>>2]|0;eQ(p|0,25992,(q=i,i=i+8|0,c[q>>2]=b,q)|0)|0;i=q;p=c[135158]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0;break}s_(m|0,0,16);if((eK(m|0,4,4,n|0)|0)!=4){o=c[135158]|0;p=(o|0)!=0?o:c[t>>2]|0;be(22336,49,1,p|0)|0;p=c[135158]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0;r=n;s=2960;break}o=c[f>>2]|0;if(!((o|0)==1112757809|(o|0)==827740994)){o=c[135158]|0;p=(o|0)!=0?o:c[t>>2]|0;be(19440,58,1,p|0)|0;p=c[135158]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0;u=n;s=2959;break}if((c[f+8>>2]|0)!=(c[96931]|0)){o=c[135158]|0;p=(o|0)!=0?o:c[t>>2]|0;be(17280,151,1,p|0)|0;p=c[135158]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0}o=c[h+12>>2]|0;do{if((o|0)!=0){p=sR(o)|0;c[j+4>>2]=p;c[j+8>>2]=o;if((p|0)==0){u=n;s=2959;break L4129}if((eK(p|0,1,o|0,n|0)|0)!=(o|0)){v=c[135158]|0;w=(v|0)!=0?v:c[t>>2]|0;be(15160,53,1,w|0)|0;w=c[135158]|0;v=(w|0)!=0?w:c[t>>2]|0;a7(v|0)|0;u=n;s=2959;break L4129}if((gm[c[16050]&31]()|0)==(o|0)){v=c[16032]|0;gj[v&127](p,o)|0;break}else{p=c[135158]|0;v=(p|0)!=0?p:c[t>>2]|0;be(12896,102,1,v|0)|0;v=c[135158]|0;p=(v|0)!=0?v:c[t>>2]|0;a7(p|0)|0;break}}}while(0);p=o+16|0;c[j+28>>2]=p;x=n;y=p;s=2954}else{p=dz(b|0,52080)|0;c[j>>2]=p;if((p|0)==0){v=c[135158]|0;w=(v|0)!=0?v:c[t>>2]|0;eQ(w|0,40144,(q=i,i=i+8|0,c[q>>2]=b,q)|0)|0;i=q;w=c[135158]|0;v=(w|0)!=0?w:c[t>>2]|0;a7(v|0)|0;break}c[g>>2]=0;c[g+4>>2]=0;c[f>>2]=827740994;c[f+8>>2]=c[96931];v=gm[c[16050]&31]()|0;c[h+12>>2]=v;be(m|0,4,4,p|0)|0;w=v+16|0;c[j+28>>2]=w;c[j+8>>2]=v;if((v|0)==0){x=p;y=w;s=2954;break}z=sR(v)|0;c[j+4>>2]=z;if((z|0)==0){u=p;s=2959;break}A=c[16052]|0;gj[A&127](z,v)|0;be(z|0,1,v|0,p|0)|0;x=p;y=w;s=2954}}while(0);do{if((s|0)==2954){m=sR(4194304)|0;if((m|0)==0){c[j+12>>2]=0;u=x;s=2959;break}if((c[m-4>>2]&3|0)!=0){s_(m|0,0,4194304)}h=m;c[j+12>>2]=h;c[h>>2]=y;c[j+16>>2]=1048575;k=l;i=e;return k|0}}while(0);if((s|0)==2959){if((u|0)!=0){r=u;s=2960}}if((s|0)==2960){a_(r|0)|0}sS(c[j+4>>2]|0);sS(c[j+12>>2]|0);sS(j);k=0;i=e;return k|0}function h6(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+128|0;h=g+64|0;b5(h|0,64,40720,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=e,j)|0)|0;i=j;j=g|0;e=b+4|0;while(1){k=c[e>>2]|0;if((k|0)==0){l=2985;break}if((da(h|0,c[k+4>>2]|0)|0)==0){break}else{e=k+12|0}}if((l|0)==2985){i=g;return}e=64;h=0;b=j;d=c[k+8>>2]|0;while(1){k=e-1|0;if((k|0)==0){l=2972;break}m=a[d]|0;a[b]=m;if(m<<24>>24==0){n=h;break}else{e=k;h=h+1|0;b=b+1|0;d=d+1|0}}do{if((l|0)==2972){a[b]=0;if((a[d]|0)==0){n=h;break}else{o=d;p=h}while(1){e=o+1|0;k=p+1|0;if((a[e]|0)==0){n=k;break}else{o=e;p=k}}}}while(0);if(n>>>0>=64){i=g;return}do{if((sZ(j|0)|0)==1){n=a[j]|0;if((dO(n|0)|0)==0){q=0;l=2978;break}r=s2(n|0)|0}else{q=0;l=2978}}while(0);L4195:do{if((l|0)==2978){while(1){l=0;if((q|0)==67){r=0;break L4195}if((s4(c[6160+(q<<3)>>2]|0,j|0)|0)==0){break}else{q=q+1|0;l=2978}}r=c[6164+(q<<3)>>2]|0}}while(0);c[f+12>>2]=r;i=g;return}function h7(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+136|0;h=g|0;j=g+8|0;k=g+72|0;b5(k|0,64,40624,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;l=j|0;e=b+4|0;while(1){m=c[e>>2]|0;if((m|0)==0){n=3013;break}if((da(k|0,c[m+4>>2]|0)|0)==0){break}else{e=m+12|0}}if((n|0)==3013){i=g;return}e=64;k=0;b=l;d=c[m+8>>2]|0;while(1){m=e-1|0;if((m|0)==0){n=2992;break}o=a[d]|0;a[b]=o;if(o<<24>>24==0){p=k;break}else{e=m;k=k+1|0;b=b+1|0;d=d+1|0}}do{if((n|0)==2992){a[b]=0;if((a[d]|0)==0){p=k;break}else{q=d;r=k}while(1){e=q+1|0;m=r+1|0;if((a[e]|0)==0){p=m;break}else{q=e;r=m}}}}while(0);if(p>>>0>=64){i=g;return}if((da(l|0,40760)|0)==0){p=f+16|0;c[p>>2]=65535;c[p+4>>2]=0;i=g;return}if((a[l]|0)!=104){p=a5(l|0,0,0)|0;l=f+16|0;c[l>>2]=p;c[l+4>>2]=K;i=g;return}l=j+1|0;if(((a[l]|0)-48|0)>>>0>=10){i=g;return}c[h>>2]=0;j=a4(l|0,h|0,0)|0;l=c[h>>2]|0;if((l|0)==0){h=c[135158]|0;p=(h|0)!=0?h:c[t>>2]|0;be(39784,49,1,p|0)|0;p=c[135158]|0;h=(p|0)!=0?p:c[t>>2]|0;a7(h|0)|0;i=g;return}do{if((s4(l|0,26920)|0)==0){s=-32768}else{if((s4(l|0,26504)|0)==0){s=16384;break}if((s4(l|0,26192)|0)==0){s=8192;break}h=(s4(l|0,25776)|0)==0;if(h){s=h?4096:0;break}i=g;return}}while(0);l=f+16|0;c[l>>2]=s&65535|j&4095;c[l+4>>2]=0;i=g;return}function h8(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+128|0;h=g|0;j=g+64|0;b5(j|0,64,40560,(k=i,i=i+16|0,c[k>>2]=d,c[k+8>>2]=e,k)|0)|0;i=k;k=h|0;e=b+4|0;while(1){l=c[e>>2]|0;if((l|0)==0){m=3037;break}if((da(j|0,c[l+4>>2]|0)|0)==0){break}else{e=l+12|0}}if((m|0)==3037){i=g;return}e=64;j=0;b=k;d=c[l+8>>2]|0;while(1){l=e-1|0;if((l|0)==0){m=3022;break}n=a[d]|0;a[b]=n;if(n<<24>>24==0){o=j;break}else{e=l;j=j+1|0;b=b+1|0;d=d+1|0}}do{if((m|0)==3022){a[b]=0;if((a[d]|0)==0){o=j;break}else{p=d;q=j}while(1){e=p+1|0;l=q+1|0;if((a[e]|0)==0){o=l;break}else{p=e;q=l}}}}while(0);if(o>>>0>=64){i=g;return}if((da(k|0,40760)|0)==0){c[f+32>>2]=-1;i=g;return}if((sZ(k|0)|0)>>>0<=1){i=g;return}o=a[k]|0;if(!((o<<24>>24|0)==43|(o<<24>>24|0)==45)){i=g;return}o=bb(h+1|0,0,0)|0;if((a[k]|0)==43){c[f+32>>2]=o|-65536;i=g;return}else{c[f+32>>2]=o<<16|65535;i=g;return}}function h9(){var a=0,b=0,d=0,e=0,f=0;a=sR(48)|0;if((a|0)==0){b=0;return b|0}if((c[a-4>>2]&3|0)!=0){s_(a|0,0,48)}d=bz()|0;c[a+44>>2]=d;if((d|0)==0){sS(a);b=0;return b|0}s_(62824,0,1292);d=5088;e=276;while(1){c[62824+(e<<2)>>2]=c[d>>2];f=c[d+12>>2]|0;if((f|0)==0){b=a;break}else{d=d+8|0;e=f}}return b|0}function ia(a){a=a|0;var b=0;b=cG(c[a+44>>2]|0)|0;s1(a|0,b|0,44)|0;return}function ib(a,b){a=a|0;b=b|0;return}function ic(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;g=b;do{if((f|0)==3){if((h|0)>322){i=0;break}j=c[62824+(h<<2)>>2]|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else if((f|0)==2){if((h|0)==1){i=c[b+36>>2]&65535;break}else if((h|0)==2){i=a[b+40|0]|0;break}else if((h|0)==0){i=c[b+32>>2]&65535;break}else if((h|0)==3){i=a[b+41|0]|0;break}else{i=0;break}}else if((f|0)==1){j=c[d+(e<<2)>>2]|0;if(h>>>0>=56){i=0;break}if((a[j+(h*40|0)|0]&1)==0){i=0;break}k=c[j+(h*40|0)+12>>2]|0;if((k|0)>322){i=0;break}j=c[62824+(k<<2)>>2]|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else{i=0}}while(0);return i|0}function id(b,d){b=b|0;d=d|0;var e=0,f=0;if(d>>>0>=56){e=0;return e|0}if((a[306080+(d*40|0)|0]&1)==0){e=0;return e|0}f=c[306092+(d*40|0)>>2]|0;if((f|0)>322){e=0;return e|0}d=c[62824+(f<<2)>>2]|0;e=(a[b+(d>>>3)|0]&1<<(d&7)|0)!=0;return e|0}function ie(a){a=a|0;aU(c[a+44>>2]|0);sS(a);return}function ig(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)==0){return}b=a+4104|0;if((c[b>>2]|0)!=0){d=a+4100|0;e=0;do{sS(c[(c[d>>2]|0)+(e<<4)>>2]|0);sS(c[(c[d>>2]|0)+(e<<4)+4>>2]|0);f=c[(c[d>>2]|0)+(e<<4)+8>>2]|0;if((f|0)!=0){g=f+4|0;h=f|0;i=c[h>>2]|0;if((c[g>>2]|0)==0){j=i}else{k=0;l=i;while(1){sS(c[l+(k<<3)>>2]|0);i=k+1|0;m=c[h>>2]|0;if(i>>>0<(c[g>>2]|0)>>>0){k=i;l=m}else{j=m;break}}}sS(j);sS(f)}e=e+1|0;}while(e>>>0<(c[b>>2]|0)>>>0)}b=c[a>>2]|0;if((b|0)!=0){hx(b)}sS(c[a+4100>>2]|0);sS(a);return}
function ih(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;if(e>>>0<19){j=2;return j|0}k=c[i>>2]|0;l=a[b]|0;m=l&255;n=c[8192+((m&15^15)<<2)>>2]^268435455;o=n>>>4^c[8192+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=66){j=3;return j|0}l=a[b+1|0]|0;m=l&255;n=c[8192+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[8192+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=80){j=3;return j|0}l=a[b+2|0]|0;m=l&255;n=c[8192+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[8192+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=83){j=3;return j|0}l=a[b+3|0]|0;m=l&255;n=c[8192+(((m^o)&15)<<2)>>2]^o>>>4;if(l<<24>>24!=49){j=3;return j|0}l=0;o=0;p=0;q=1;r=n>>>4^c[8192+((n&15^m>>>4)<<2)>>2];m=4;n=7;while(1){s=d[b+m|0]|0;t=c[8192+(((s^r)&15)<<2)>>2]^r>>>4;u=t>>>4^c[8192+((t&15^s>>>4)<<2)>>2];t=m+1|0;v=tk(s&127,0,q,p)|0;w=ta(v,K,o,l)|0;if((s&128|0)!=0){x=0;y=0;z=0;A=1;B=u;C=t;D=n;break}s=q<<7|0>>>25;v=p<<7|q>>>25;E=ta(w,K,s,v)|0;l=K;o=E;p=v;q=s;r=u;m=t;n=n+1|0}while(1){n=d[b+C|0]|0;m=c[8192+(((n^B)&15)<<2)>>2]^B>>>4;r=m>>>4^c[8192+((m&15^n>>>4)<<2)>>2];m=C+1|0;q=tk(n&127,0,A,z)|0;F=ta(q,K,y,x)|0;if((n&128|0)!=0){G=0;H=0;I=0;J=1;L=r;M=m;N=D;break}n=A<<7|0>>>25;q=z<<7|A>>>25;p=ta(F,K,n,q)|0;x=K;y=p;z=q;A=n;B=r;C=m;D=D+1|0}while(1){O=a[b+M|0]|0;D=O&255;C=c[8192+(((D^L)&15)<<2)>>2]^L>>>4;P=C>>>4^c[8192+((C&15^D>>>4)<<2)>>2];Q=M+1|0;C=tk(D&127,0,J,I)|0;R=ta(C,K,H,G)|0;if((D&128|0)!=0){break}D=J<<7|0>>>25;C=I<<7|J>>>25;B=ta(R,K,D,C)|0;G=K;H=B;I=C;J=D;L=P;M=Q;N=N+1|0}M=w;w=F;F=R;if((F|0)==0){S=P;T=Q}else{R=tk(O&127,0,J,I)|0;I=ta(R,K,H,G)|0;G=P;P=Q;Q=0;while(1){H=d[b+P|0]|0;R=c[8192+(((H^G)&15)<<2)>>2]^G>>>4;U=R>>>4^c[8192+((R&15^H>>>4)<<2)>>2];H=Q+1|0;if(H>>>0<F>>>0){G=U;P=P+1|0;Q=H}else{break}}S=U;T=I+N|0}if(M>>>0>g>>>0){j=5;return j|0}if(w>>>0>k>>>0){j=6;return j|0}k=e-12|0;e=T;T=0;M=0;N=S;S=-1;I=0;L4376:while(1){U=e;Q=T;P=N;G=S;F=I;while(1){H=U;R=P;V=G;W=F;L4380:while(1){X=H;Y=R;while(1){if(X>>>0<k>>>0){Z=0;_=0;$=0;aa=1;ab=Y;ac=X}else{break L4376}while(1){J=d[b+ac|0]|0;O=c[8192+(((J^ab)&15)<<2)>>2]^ab>>>4;ad=O>>>4^c[8192+((O&15^J>>>4)<<2)>>2];ae=ac+1|0;O=tk(J&127,0,aa,$)|0;af=ta(O,K,_,Z)|0;if((J&128|0)!=0){break}J=aa<<7|0>>>25;O=$<<7|aa>>>25;L=ta(af,K,J,O)|0;Z=K;_=L;$=O;aa=J;ab=ad;ac=ae}ag=af;ah=ag&3;if((ah|0)==0){ai=3124;break}else if((ah|0)==1){ai=3126;break}else if((ah|0)==2|(ah|0)==3){break L4380}else{X=ae;Y=ad}}if((ai|0)==3124){ai=0;J=(ag>>>2)+1|0;O=W;L=V;D=J;while(1){C=a[f+O|0]|0;a[h+O|0]=C;B=C&255;C=c[8192+(((B^L)&15)<<2)>>2]^L>>>4;A=C>>>4^c[8192+((C&15^B>>>4)<<2)>>2];B=D-1|0;if((B|0)==0){aj=ae;ak=ad;al=A;am=J;break}else{O=O+1|0;L=A;D=B}}}else if((ai|0)==3126){ai=0;D=(ag>>>2)+1|0;L=W;O=V;J=ad;B=ae;A=D;while(1){C=A-1|0;z=a[b+B|0]|0;y=z&255;x=c[8192+(((y^J)&15)<<2)>>2]^J>>>4;m=y>>>4;an=x>>>4^c[8192+((x&15^m)<<2)>>2];a[h+L|0]=z;z=c[8192+(((y^O)&15)<<2)>>2]^O>>>4;ao=z>>>4^c[8192+((z&15^m)<<2)>>2];if((C|0)==0){break}else{L=L+1|0;O=ao;J=an;B=B+1|0;A=C}}aj=D+ae|0;ak=an;al=ao;am=D}H=aj;R=ak;V=al;W=am+W|0}ap=(ag>>>2)+1|0;R=0;H=0;A=0;B=1;J=ad;O=ae;while(1){L=d[b+O|0]|0;C=c[8192+(((L^J)&15)<<2)>>2]^J>>>4;aq=C>>>4^c[8192+((C&15^L>>>4)<<2)>>2];ar=O+1|0;C=tk(L&127,0,B,A)|0;as=ta(C,K,H,R)|0;if((L&128|0)!=0){break}L=B<<7|0>>>25;C=A<<7|B>>>25;m=ta(as,K,L,C)|0;R=K;H=m;A=C;B=L;J=aq;O=ar}O=as;J=O>>1;at=(O&1|0)==0?J:-J|0;if((ah|0)!=2){break}J=W;O=V;B=at+Q|0;A=ap;while(1){H=A-1|0;R=a[f+B|0]|0;a[h+J|0]=R;L=R&255;R=c[8192+(((L^O)&15)<<2)>>2]^O>>>4;au=R>>>4^c[8192+((R&15^L>>>4)<<2)>>2];if((H|0)==0){break}else{J=J+1|0;O=au;B=B+1|0;A=H}}U=ar;Q=ap+Q+at|0;P=aq;G=au;F=ap+W|0}F=W;G=V;P=at+M|0;U=ap;while(1){A=U-1|0;B=a[h+P|0]|0;a[h+F|0]=B;O=B&255;B=c[8192+(((O^G)&15)<<2)>>2]^G>>>4;av=B>>>4^c[8192+((B&15^O>>>4)<<2)>>2];if((A|0)==0){break}else{F=F+1|0;G=av;P=P+1|0;U=A}}e=ar;T=Q;M=ap+M+at|0;N=aq;S=av;I=ap+W|0}W=d[b+X|0]|0;ap=c[8192+(((W^Y)&15)<<2)>>2]^Y>>>4;Y=ap>>>4^c[8192+((ap&15^W>>>4)<<2)>>2];ap=d[b+(X+1)|0]|0;I=c[8192+(((ap^Y)&15)<<2)>>2]^Y>>>4;Y=I>>>4^c[8192+((I&15^ap>>>4)<<2)>>2];I=d[b+(X+2)|0]|0;av=c[8192+(((I^Y)&15)<<2)>>2]^Y>>>4;Y=av>>>4^c[8192+((av&15^I>>>4)<<2)>>2];av=d[b+(X+3)|0]|0;S=c[8192+(((av^Y)&15)<<2)>>2]^Y>>>4;Y=S>>>4^c[8192+((S&15^av>>>4)<<2)>>2];S=d[b+(X+4)|0]|0;aq=c[8192+(((S^Y)&15)<<2)>>2]^Y>>>4;Y=aq>>>4^c[8192+((aq&15^S>>>4)<<2)>>2];aq=ap<<8|W|I<<16|av<<24;av=d[b+(X+5)|0]|0;I=c[8192+(((av^Y)&15)<<2)>>2]^Y>>>4;Y=I>>>4^c[8192+((I&15^av>>>4)<<2)>>2];I=d[b+(X+6)|0]|0;W=c[8192+(((I^Y)&15)<<2)>>2]^Y>>>4;Y=W>>>4^c[8192+((W&15^I>>>4)<<2)>>2];W=d[b+(X+7)|0]|0;ap=c[8192+(((W^Y)&15)<<2)>>2]^Y>>>4;Y=~(ap>>>4^c[8192+((ap&15^W>>>4)<<2)>>2]);ap=(d[b+(X+9)|0]|0)<<8|(d[b+(X+8)|0]|0)|(d[b+(X+10)|0]|0)<<16|(d[b+(X+11)|0]|0)<<24;if((f|0)==0|(g|0)==0){aw=0}else{X=g;g=f;f=-1;while(1){b=X-1|0;N=d[g]|0;at=c[8192+(((N^f)&15)<<2)>>2]^f>>>4;ax=at>>>4^c[8192+((at&15^N>>>4)<<2)>>2];if((b|0)==0){break}else{X=b;g=g+1|0;f=ax}}aw=~ax}if((aw|0)!=(aq|0)){j=9;return j|0}if((av<<8|S|I<<16|W<<24|0)!=(~V|0)){j=10;return j|0}if((ap|0)!=(Y|0)){j=11;return j|0}c[i>>2]=w;j=1;return j|0}function ii(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;j=c[i>>2]|0;if(e>>>0<=17){k=4;return k|0}l=a[b]|0;m=l&255;n=c[8192+((m&15^15)<<2)>>2]^268435455;o=n>>>4^c[8192+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=85){k=4;return k|0}l=a[b+1|0]|0;m=l&255;n=c[8192+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[8192+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=80){k=4;return k|0}l=a[b+2|0]|0;m=l&255;n=c[8192+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[8192+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=83){k=4;return k|0}l=a[b+3|0]|0;m=l&255;n=c[8192+(((m^o)&15)<<2)>>2]^o>>>4;if(l<<24>>24!=49){k=4;return k|0}l=0;o=0;p=0;q=1;r=4;s=n>>>4^c[8192+((n&15^m>>>4)<<2)>>2];while(1){if(r>>>0<e>>>0){m=d[b+r|0]|0;n=c[8192+(((m^s)&15)<<2)>>2]^s>>>4;t=n>>>4^c[8192+((n&15^m>>>4)<<2)>>2];n=r+1|0;u=tk(m&127,0,q,p)|0;v=ta(u,K,o,l)|0;if((m&128|0)==0){w=K;x=v;y=n;z=t}else{A=0;B=0;C=0;D=1;E=n;F=t;break}}else{w=l;x=o;y=r;z=s}t=q<<7|0>>>25;n=p<<7|q>>>25;m=ta(x,w,t,n)|0;l=K;o=m;p=n;q=t;r=y;s=z}while(1){if(E>>>0<e>>>0){z=d[b+E|0]|0;s=c[8192+(((z^F)&15)<<2)>>2]^F>>>4;G=s>>>4^c[8192+((s&15^z>>>4)<<2)>>2];H=E+1|0;s=tk(z&127,0,D,C)|0;I=ta(s,K,B,A)|0;if((z&128|0)==0){J=K;L=I;M=H;N=G}else{break}}else{J=A;L=B;M=E;N=F}z=D<<7|0>>>25;s=C<<7|D>>>25;y=ta(L,J,z,s)|0;A=K;B=y;C=s;D=z;E=M;F=N}N=v;v=I;I=(N|0)==(g|0);F=(v|0)==(g|0);if(!(I|F)){k=7;return k|0}M=I?v:N;c[i>>2]=M;if(j>>>0<M>>>0){k=6;return k|0}j=e-12|0;if(H>>>0<j>>>0){i=-1;E=-1;D=G;C=0;B=0;A=H;while(1){J=0;L=0;z=0;s=1;y=A;r=D;while(1){if(y>>>0<e>>>0){q=d[b+y|0]|0;p=c[8192+(((q^r)&15)<<2)>>2]^r>>>4;O=p>>>4^c[8192+((p&15^q>>>4)<<2)>>2];P=y+1|0;p=tk(q&127,0,s,z)|0;Q=ta(p,K,L,J)|0;if((q&128|0)==0){R=K;S=Q;T=P;U=O}else{break}}else{R=J;S=L;T=y;U=r}q=s<<7|0>>>25;p=z<<7|s>>>25;o=ta(S,R,q,p)|0;J=K;L=o;z=p;s=q;y=T;r=U}r=Q;if((r|0)==0){V=P;W=B;X=C;Y=O;Z=E;_=i}else{y=i;s=E;z=C;L=B;J=r;while(1){q=J-1|0;if(L>>>0<g>>>0){p=a[f+L|0]|0;o=p&255;l=c[8192+(((o^s)&15)<<2)>>2]^s>>>4;$=p;aa=L+1|0;ab=l>>>4^c[8192+((l&15^o>>>4)<<2)>>2]}else{$=0;aa=L;ab=s}if(z>>>0<M>>>0){a[h+z|0]=$;o=$&255;l=c[8192+(((o^y)&15)<<2)>>2]^y>>>4;ac=l>>>4^c[8192+((l&15^o>>>4)<<2)>>2]}else{ac=y}if((q|0)==0){break}else{y=ac;s=ab;z=z+1|0;L=aa;J=q}}V=P;W=aa;X=r+C|0;Y=O;Z=ab;_=ac}while(1){if(V>>>0<e>>>0){J=a[b+V|0]|0;L=J&255;z=c[8192+(((L^Y)&15)<<2)>>2]^Y>>>4;ad=J;ae=V+1|0;af=z>>>4^c[8192+((z&15^L>>>4)<<2)>>2]}else{ad=0;ae=V;af=Y}if(W>>>0<g>>>0){L=a[f+W|0]|0;z=L&255;J=c[8192+(((z^Z)&15)<<2)>>2]^Z>>>4;ag=L;ah=W+1|0;ai=J>>>4^c[8192+((J&15^z>>>4)<<2)>>2]}else{ag=0;ah=W;ai=Z}z=ag^ad;if(X>>>0<M>>>0){a[h+X|0]=z;J=z&255;z=c[8192+(((J^_)&15)<<2)>>2]^_>>>4;aj=z>>>4^c[8192+((z&15^J>>>4)<<2)>>2]}else{aj=_}ak=X+1|0;if(ad<<24>>24==0){break}else{V=ae;W=ah;X=ak;Y=af;Z=ai;_=aj}}if(ae>>>0<j>>>0){i=aj;E=ai;D=af;C=ak;B=ah;A=ae}else{al=aj;am=ai;an=af;ao=ak;ap=ah;aq=ae;break}}}else{al=-1;am=-1;an=G;ao=0;ap=0;aq=H}if(ap>>>0<g>>>0){H=al;G=am;ae=ao;ah=ap;while(1){ak=a[f+ah|0]|0;af=ak&255;ai=c[8192+(((af^G)&15)<<2)>>2]^G>>>4;aj=af>>>4;ar=ai>>>4^c[8192+((ai&15^aj)<<2)>>2];ai=ah+1|0;if(ae>>>0<M>>>0){a[h+ae|0]=ak;ak=c[8192+(((af^H)&15)<<2)>>2]^H>>>4;as=ak>>>4^c[8192+((ak&15^aj)<<2)>>2]}else{as=H}if(ai>>>0<g>>>0){H=as;G=ar;ae=ae+1|0;ah=ai}else{break}}at=as;au=ar;av=g-ap+ao|0;aw=g}else{at=al;au=am;av=ao;aw=ap}if(av>>>0<M>>>0){ap=at;ao=au;am=av;av=aw;while(1){if(av>>>0<g>>>0){aw=a[f+av|0]|0;al=aw&255;ar=c[8192+(((al^ao)&15)<<2)>>2]^ao>>>4;ax=aw;ay=av+1|0;az=ar>>>4^c[8192+((ar&15^al>>>4)<<2)>>2]}else{ax=0;ay=av;az=ao}a[h+am|0]=ax;al=ax&255;ar=c[8192+(((al^ap)&15)<<2)>>2]^ap>>>4;aw=ar>>>4^c[8192+((ar&15^al>>>4)<<2)>>2];al=am+1|0;if(al>>>0<M>>>0){ap=aw;ao=az;am=al;av=ay}else{aA=aw;aB=az;break}}}else{aA=at;aB=au}if(aq>>>0<e>>>0){au=d[b+aq|0]|0;at=c[8192+(((au^an)&15)<<2)>>2]^an>>>4;aC=au;aD=aq+1|0;aE=at>>>4^c[8192+((at&15^au>>>4)<<2)>>2]}else{aC=0;aD=aq;aE=an}if(aD>>>0<e>>>0){an=d[b+aD|0]|0;aq=c[8192+(((an^aE)&15)<<2)>>2]^aE>>>4;aF=an<<8;aG=aD+1|0;aH=aq>>>4^c[8192+((aq&15^an>>>4)<<2)>>2]}else{aF=0;aG=aD;aH=aE}if(aG>>>0<e>>>0){aE=d[b+aG|0]|0;aD=c[8192+(((aE^aH)&15)<<2)>>2]^aH>>>4;aI=aE<<16;aJ=aG+1|0;aK=aD>>>4^c[8192+((aD&15^aE>>>4)<<2)>>2]}else{aI=0;aJ=aG;aK=aH}if(aJ>>>0<e>>>0){aH=d[b+aJ|0]|0;aG=c[8192+(((aH^aK)&15)<<2)>>2]^aK>>>4;aL=aH<<24;aM=aJ+1|0;aN=aG>>>4^c[8192+((aG&15^aH>>>4)<<2)>>2]}else{aL=0;aM=aJ;aN=aK}aK=aF|aC|aI|aL;if(aM>>>0<e>>>0){aL=d[b+aM|0]|0;aI=c[8192+(((aL^aN)&15)<<2)>>2]^aN>>>4;aO=aL;aP=aM+1|0;aQ=aI>>>4^c[8192+((aI&15^aL>>>4)<<2)>>2]}else{aO=0;aP=aM;aQ=aN}if(aP>>>0<e>>>0){aN=d[b+aP|0]|0;aM=c[8192+(((aN^aQ)&15)<<2)>>2]^aQ>>>4;aR=aN<<8;aS=aP+1|0;aT=aM>>>4^c[8192+((aM&15^aN>>>4)<<2)>>2]}else{aR=0;aS=aP;aT=aQ}if(aS>>>0<e>>>0){aQ=d[b+aS|0]|0;aP=c[8192+(((aQ^aT)&15)<<2)>>2]^aT>>>4;aU=aQ<<16;aV=aS+1|0;aW=aP>>>4^c[8192+((aP&15^aQ>>>4)<<2)>>2]}else{aU=0;aV=aS;aW=aT}if(aV>>>0<e>>>0){aT=d[b+aV|0]|0;aS=c[8192+(((aT^aW)&15)<<2)>>2]^aW>>>4;aX=aT<<24;aY=aV+1|0;aZ=aS>>>4^c[8192+((aS&15^aT>>>4)<<2)>>2]}else{aX=0;aY=aV;aZ=aW}aW=aR|aO|aU|aX;aX=~aB;if(aY>>>0<e>>>0){a_=d[b+aY|0]|0;a$=aY+1|0}else{a_=0;a$=aY}if(a$>>>0<e>>>0){a0=(d[b+a$|0]|0)<<8;a1=a$+1|0}else{a0=0;a1=a$}if(a1>>>0<e>>>0){a2=(d[b+a1|0]|0)<<16;a3=a1+1|0}else{a2=0;a3=a1}if(a3>>>0<e>>>0){a4=(d[b+a3|0]|0)<<24}else{a4=0}a3=~aA;if((a0|a_|a2|a4|0)!=(~aZ|0)){k=4;return k|0}if(!((aK|0)!=(aX|0)|I^1)){return((aW|0)==(a3|0)&(M|0)==(v|0)?1:8)|0}if((aW|0)!=(aX|0)|F^1){k=7;return k|0}k=(aK|0)==(a3|0)&(M|0)==(N|0)?1:8;return k|0}function ij(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if(e>>>0<8){j=4;return j|0}if((a[b]|0)!=80){j=4;return j|0}if((a[b+1|0]|0)!=65){j=4;return j|0}if((a[b+2|0]|0)!=84){j=4;return j|0}if((a[b+3|0]|0)!=67){j=4;return j|0}if((a[b+4|0]|0)!=72){j=4;return j|0}s1(h|0,f|0,g)|0;c[i>>2]=g;g=e-3|0;if(g>>>0<5){j=4;return j|0}f=e-2|0;k=5;while(1){l=k+3|0;m=d[b+(k+1)|0]<<8|d[b+k|0]<<16|d[b+(k+2)|0];if((m|0)==4542278){if((l|0)==(e|0)){j=1;n=3264;break}if((l|0)==(g|0)){n=3245;break}}if(l>>>0>f>>>0){j=4;n=3273;break}o=k+5|0;p=d[b+l|0]<<8|d[b+(k+4)|0];if((p|0)==0){if(o>>>0>g>>>0){j=4;n=3271;break}l=d[b+o|0]<<8|d[b+(k+6)|0];if((l|0)==0){j=4;n=3267;break}q=b+(k+7)|0;r=m;s=l;while(1){t=s-1|0;a[h+r|0]=a[q]|0;if((t|0)==0){break}else{r=r+1|0;s=t}}u=l;v=k+8|0}else{if(o>>>0>(e-p|0)>>>0){j=4;n=3261;break}else{w=o;x=m;y=p}while(1){s=y-1|0;a[h+x|0]=a[b+w|0]|0;if((s|0)==0){break}else{w=w+1|0;x=x+1|0;y=s}}u=p;v=p+o|0}l=u+m|0;if(l>>>0>(c[i>>2]|0)>>>0){c[i>>2]=l}if(v>>>0>g>>>0){j=4;n=3260;break}else{k=v}}if((n|0)==3261){return j|0}else if((n|0)==3267){return j|0}else if((n|0)==3245){c[i>>2]=d[b+(k+4)|0]<<8|d[b+g|0]<<16|d[b+(k+5)|0];j=1;return j|0}else if((n|0)==3260){return j|0}else if((n|0)==3273){return j|0}else if((n|0)==3271){return j|0}else if((n|0)==3264){return j|0}return 0}function ik(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+8|0;e=d|0;f=c[135158]|0;be(50816,85,1,((f|0)!=0?f:c[t>>2]|0)|0)|0;f=c[135158]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;c[e>>2]=0;f=dz(b|0,11144)|0;if((f|0)==0){g=0;i=d;return g|0}b=sR(4)|0;if((b|0)==0){a_(f|0)|0;g=0;i=d;return g|0}if((c[b-4>>2]&3|0)!=0){h=b;C=0;a[h]=C&255;C=C>>8;a[h+1|0]=C&255;C=C>>8;a[h+2|0]=C&255;C=C>>8;a[h+3|0]=C&255}h=b;e3(f|0,0,2)|0;j=cx(f|0)|0;fb(f|0);k=sR(j+1|0)|0;do{if((k|0)==0){l=0;m=3288}else{a[k+j|0]=0;if((eK(k|0,1,j|0,f|0)|0)!=(j|0)){l=k;m=3288;break}a_(f|0)|0;c[e>>2]=k;do{if((s6(k|0,50152,5)|0)==0){n=bJ(k|0,47704)|0;if((n|0)==0){o=k;break}p=n+3|0;c[e>>2]=p;q=p;m=3283}else{q=k;m=3283}}while(0);do{if((m|0)==3283){p=sZ(q|0)|0;n=sR(p+1|0)|0;if((n|0)==0){o=k;break}a[n+p|0]=0;p=bJ(q|0,12424)|0;r=bJ(q|0,52624)|0;if((p|0)==0|(r|0)==0){s=q;u=n}else{v=q;w=n;x=p;p=r;while(1){r=x-v|0;s1(w|0,v|0,r)|0;y=w+r|0;r=p+3|0;z=bJ(r|0,12424)|0;A=bJ(r|0,52624)|0;if((z|0)==0|(A|0)==0){s=r;u=y;break}else{v=r;w=y;x=z;p=A}}}p=sZ(s|0)|0;s1(u|0,s|0,p)|0;a[u+p|0]=0;sS(k);c[e>>2]=n;p=il(e)|0;c[b>>2]=p;if((p|0)==0){o=n;break}sS(n);g=h;i=d;return g|0}}while(0);sS(o)}}while(0);if((m|0)==3288){sS(l);a_(f|0)|0}f=c[b>>2]|0;if((f|0)!=0){im(f)}sS(b);g=0;i=d;return g|0}function il(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=sR(24)|0;if((g|0)==0){h=0;i=d;return h|0}if((c[g-4>>2]&3|0)!=0){s_(g|0,0,24)}j=g;k=c[b>>2]|0;while(1){l=k+1|0;if((bp(a[k]|0)|0)==0){break}else{k=l}}c[b>>2]=k;L4649:do{if((a[k]|0)==60){m=cm(k|0,62)|0;if((m|0)==0){n=0;break}o=m-l|0;p=sR(o+1|0)|0;if((p|0)==0){n=0;break}s1(p|0,l|0,o)|0;a[p+o|0]=0;o=p;while(1){if((bp(a[o]|0)|0)==0){q=o;break}else{o=o+1|0}}while(1){r=a[q]|0;if(r<<24>>24==0){s=0;break}if((bp(r<<24>>24|0)|0)==0){q=q+1|0}else{t=3311;break}}if((t|0)==3311){s=a[q]|0}r=(bp(s|0)|0)!=0?q:0;if((r|0)==0){u=dT(o|0)|0;c[g>>2]=u;if((u|0)==0){n=p;break}if((a[u]|0)==0){n=p;break}}else{u=r-o|0;v=sR(u+1|0)|0;if((v|0)==0){c[g>>2]=0;n=p;break}s1(v|0,o|0,u)|0;a[v+u|0]=0;c[g>>2]=v;if((a[v]|0)==0){n=p;break}v=dT(r|0)|0;if((v|0)==0){w=0}else{r=v+((sZ(v|0)|0)-1)|0;if((a[r]|0)==47){a[r]=0}r=eM(v|0,16864,e|0)|0;L4672:do{if((r|0)==0){x=0}else{u=r;y=0;z=0;while(1){A=bJ(u|0,14736)|0;if((A|0)==0){x=z;break L4672}B=A+2|0;C=cD(B|0,34)|0;if((C|0)==0){x=z;break L4672}if((C|0)!=(u+((sZ(u|0)|0)-1)|0)){x=z;break L4672}D=A-u|0;A=sR(D+1|0)|0;if((A|0)==0){E=0}else{s1(A|0,u|0,D)|0;a[A+D|0]=0;E=A}A=C-B|0;C=sR(A+1|0)|0;if((C|0)==0){x=z;break L4672}s1(C|0,B|0,A)|0;a[C+A|0]=0;if((E|0)==0){x=z;break L4672}A=sR(12)|0;if((A|0)==0){x=z;break L4672}if((c[A-4>>2]&3|0)!=0){s_(A|0,0,12)}B=A;c[A>>2]=E;c[A+4>>2]=C;if((y|0)==0){F=B}else{c[y+8>>2]=B;F=z}C=eM(0,16864,e|0)|0;if((C|0)==0){x=F;break}else{u=C;y=B;z=F}}}}while(0);sS(v);w=x}c[g+8>>2]=w}if(((bJ(k|0,37512)|0)+1|0)==(m|0)){c[b>>2]=m+1}else{r=c[g>>2]|0;o=(sZ(r|0)|0)+4|0;z=sR(o)|0;if((z|0)==0){n=p;break}b5(z|0,o|0,29368,(o=i,i=i+8|0,c[o>>2]=r,o)|0)|0;i=o;o=m+1|0;r=bJ(o|0,24896)|0;y=cm(o|0,60)|0;u=bJ(o|0,z|0)|0;if((u|0)==0){sS(z);n=p;break}L4701:do{if((r|0)==0){t=3349}else{B=o;while(1){if(B>>>0>=r>>>0){break}if((bp(a[B]|0)|0)==0){t=3349;break L4701}else{B=B+1|0}}B=bJ(r|0,21664)|0;if((B|0)==0){sS(z);n=p;break L4649}C=r+9|0;A=B-C|0;B=sR(A+1|0)|0;if((B|0)==0){G=0}else{s1(B|0,C|0,A)|0;a[B+A|0]=0;G=B}c[g+4>>2]=G;H=u}}while(0);do{if((t|0)==3349){if((u|0)==(y|0)){r=y-o|0;m=sR(r+1|0)|0;if((m|0)==0){I=0}else{s1(m|0,o|0,r)|0;a[m+r|0]=0;I=m}c[g+4>>2]=I;H=y;break}c[f>>2]=y;m=cm(y|0,60)|0;r=bJ(y|0,19088)|0;L4720:do{if((r|0)!=0&(m|0)!=0&m>>>0<r>>>0){v=0;B=0;while(1){A=il(f)|0;if((A|0)==0){break}if((B|0)==0){J=A}else{c[B+16>>2]=A;J=v}C=c[f>>2]|0;D=cm(C|0,60)|0;K=bJ(C|0,19088)|0;if((K|0)!=0&(D|0)!=0&D>>>0<K>>>0){v=J;B=A}else{L=J;M=C;break L4720}}sS(z);n=p;break L4649}else{L=0;M=y}}while(0);c[g+12>>2]=L;r=bJ(M|0,z|0)|0;if((r|0)!=0){H=r;break}sS(z);n=p;break L4649}}while(0);c[b>>2]=H+(sZ(z|0)|0);sS(z)}sS(p);h=j;i=d;return h|0}else{n=0}}while(0);sS(n);im(j);h=0;i=d;return h|0}function im(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((b|0)!=0){d=b;while(1){b=c[d+16>>2]|0;im(d);if((b|0)==0){break}else{d=b}}}d=c[a+8>>2]|0;if((d|0)!=0){b=d;while(1){d=c[b+8>>2]|0;sS(c[b>>2]|0);sS(c[b+4>>2]|0);sS(b);if((d|0)==0){break}else{b=d}}}sS(c[a>>2]|0);sS(c[a+4>>2]|0);sS(a);return}function io(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b;g=f-a|0;h=g>>2;do{if((h|0)==0){j=0}else{if(h>>>0<=65535){j=g;break}j=((g>>>0)/(h>>>0)|0|0)==4?g:-1}}while(0);k=sR(j)|0;if((k|0)==0){l=c[135158]|0;m=(l|0)!=0?l:c[t>>2]|0;eQ(m|0,33848,(m=i,i=i+16|0,c[m>>2]=50224,c[m+8>>2]=150,m)|0)|0;i=m;m=c[135158]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0;cz(2)}if((c[k-4>>2]&3|0)!=0){s_(k|0,0,j|0)}j=a;s1(k|0,j|0,g)|0;s5(j|0,b|0,d-f|0);f=d+(-h<<2)|0;s1(f|0,k|0,g)|0;sS(k);i=e;return}function ip(a){a=a|0;return 1}function iq(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=i;i=i+8256|0;k=j|0;l=j+8|0;m=j+64|0;n=j+4160|0;o=n|0;fm(k|0)|0;di(o|0,4096,11680,bq(k|0)|0)|0;k=sZ(o|0)|0;p=k>>>0>4096?0:4096-k|0;L4758:do{if((p|0)==0){q=50536;r=3387}else{s=n+k|0;do{if((p|0)==1){u=50536;v=s}else{w=n+(k+1)|0;a[s]=98;if((p|0)==2){u=50537;v=w;break}x=n+(k+2)|0;a[w]=109;if((p|0)==3){u=50538;v=x;break}w=n+(k+3)|0;a[x]=112;if((p|0)==4){u=50539;v=w;break}a[w]=0;break L4758}}while(0);a[v]=0;q=u;r=3387}}while(0);do{if((r|0)==3387){if((a[q]|0)==0){break}else{y=q}do{y=y+1|0;}while((a[y]|0)!=0)}}while(0);y=m|0;hj(y,371236,o);o=dz(y|0,52080)|0;if((o|0)==0){m=c[135158]|0;q=(m|0)!=0?m:c[t>>2]|0;eQ(q|0,37352,(q=i,i=i+8|0,c[q>>2]=y,q)|0)|0;i=q;q=c[135158]|0;y=(q|0)!=0?q:c[t>>2]|0;a7(y|0)|0;z=0;i=j;return z|0}y=l|0;q=e*3|0;m=q+3&-4;u=ag(m,f)|0;v=u+54|0;a[y]=66;a[l+1|0]=77;a[l+2|0]=v&255;a[l+3|0]=v>>>8&255;a[l+4|0]=v>>>16&255;a[l+5|0]=v>>>24&255;v=l+6|0;C=0;a[v]=C&255;C=C>>8;a[v+1|0]=C&255;C=C>>8;a[v+2|0]=C&255;C=C>>8;a[v+3|0]=C&255;a[l+10|0]=54;a[l+11|0]=0;a[l+12|0]=0;a[l+13|0]=0;a[l+14|0]=40;a[l+15|0]=0;a[l+16|0]=0;a[l+17|0]=0;a[l+18|0]=e&255;a[l+19|0]=e>>>8&255;a[l+20|0]=e>>>16&255;a[l+21|0]=e>>>24&255;a[l+22|0]=f&255;a[l+23|0]=f>>>8&255;a[l+24|0]=f>>>16&255;a[l+25|0]=f>>>24&255;a[l+26|0]=1;a[l+27|0]=0;a[l+28|0]=24;s_(l+29|0,0,5);a[l+34|0]=u&255;a[l+35|0]=u>>>8&255;a[l+36|0]=u>>>16&255;a[l+37|0]=u>>>24&255;a[l+38|0]=19;a[l+39|0]=11;a[l+40|0]=0;a[l+41|0]=0;a[l+42|0]=19;a[l+43|0]=11;s_(l+44|0,0,10);l=(be(y|0,1,54,o|0)|0)==54;do{if(l){y=(f|0)==0;do{if(y){A=0}else{u=f<<2;if(f>>>0<=65535){A=u;break}A=((u>>>0)/(f>>>0)|0|0)==4?u:-1}}while(0);u=sR(A)|0;if((u|0)==0){break}if((c[u-4>>2]&3|0)!=0){s_(u|0,0,A|0)}v=u;p=0;while(1){if((p|0)>=(f|0)){r=3405;break}k=sR(m)|0;if((k|0)==0){r=3404;break}if((c[k-4>>2]&3|0)!=0){s_(k|0,0,m|0)}c[v+(p<<2)>>2]=k;p=p+1|0}do{if((r|0)==3404){c[v+(p<<2)>>2]=0;r=3421}else if((r|0)==3405){do{if(h){if((f|0)>0){B=d;D=0}else{r=3419;break}while(1){k=c[v+(D<<2)>>2]|0;s1(k|0,B|0,q)|0;k=D+1|0;if((k|0)<(f|0)){B=B+g|0;D=k}else{r=3419;break}}}else{k=(f|0)>0;if((c[119486]|0)==1){if(!k){r=3419;break}if((e|0)==0){E=0;break}else{F=d;G=0}while(1){n=F;s=0;w=c[v+(G<<2)>>2]|0;while(1){x=c[n>>2]|0;a[w]=x&255;a[w+1|0]=x>>>8&255;a[w+2|0]=x>>>16&255;x=s+1|0;if(x>>>0<e>>>0){n=n+4|0;s=x;w=w+3|0}else{break}}w=G+1|0;if((w|0)<(f|0)){F=F+g|0;G=w}else{r=3419;break}}}else{if(!k){r=3419;break}if((e|0)==0){E=0;break}else{H=d;I=0}while(1){w=0;s=H;n=c[v+(I<<2)>>2]|0;while(1){x=b[s>>1]|0;J=x&255;a[n]=(J&255)>>>2&7|J<<3;a[n+1|0]=(x&65535)>>>5<<2&255|(x&65535)>>>9&3;J=(x&65535)>>>11&65535;a[n+2|0]=(J<<3|J>>>2)&255;J=w+1|0;if(J>>>0<e>>>0){w=J;s=s+2|0;n=n+3|0}else{break}}n=I+1|0;if((n|0)<(f|0)){H=H+g|0;I=n}else{r=3419;break}}}}}while(0);if((r|0)==3419){if(y){break}else{E=0}}while(1){be(c[v+(E<<2)>>2]|0,1,m|0,o|0)|0;k=E+1|0;if(k>>>0<f>>>0){E=k}else{r=3421;break}}}}while(0);do{if((r|0)==3421){if((f|0)>0){K=0}else{break}do{sS(c[v+(K<<2)>>2]|0);K=K+1|0;}while((K|0)<(f|0))}}while(0);sS(u)}else{v=c[135158]|0;be(29312,51,1,((v|0)!=0?v:c[t>>2]|0)|0)|0;v=c[135158]|0;a7(((v|0)!=0?v:c[t>>2]|0)|0)|0}}while(0);a_(o|0)|0;z=l;i=j;return z|0}function ir(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+544|0;e=d|0;if((b|0)==0){i=d;return}f=b|0;if((c[f>>2]|0)!=0){g=e|0;h=d+512|0;do{if((a[367140]|0)!=0){j=hz(367140,0)|0;if((j|0)==0){k=sR(20)|0;if((k|0)==0){l=c[135158]|0;m=(l|0)!=0?l:c[t>>2]|0;be(52568,53,1,m|0)|0;m=c[135158]|0;l=(m|0)!=0?m:c[t>>2]|0;a7(l|0)|0;break}if((c[k-4>>2]&3|0)!=0){s_(k|0,0,20)}n=k}else{n=j}s_(g|0,0,512);s_(h|0,0,32);j=b+8|0;k=c[j>>2]|0;do{if((k|0)!=0){l=0;m=k;while(1){if((a[(c[f>>2]|0)+(l*12|0)+4|0]&1)==0){o=m}else{b5(h|0,32,50144,(p=i,i=i+8|0,c[p>>2]=l,p)|0)|0;i=p;q=sZ(g|0)|0;r=q>>>0>512?0:512-q|0;L4849:do{if((r|0)==0){s=h;u=3448}else{v=r;w=e+q|0;x=h;while(1){y=v-1|0;if((y|0)==0){break}z=a[x]|0;a[w]=z;if(z<<24>>24==0){break L4849}else{v=y;w=w+1|0;x=x+1|0}}a[w]=0;s=x;u=3448}}while(0);do{if((u|0)==3448){u=0;if((a[s]|0)==0){break}else{A=s}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);o=c[j>>2]|0}x=l+1|0;if(x>>>0<o>>>0){l=x;m=o}else{break}}if((a[g]|0)==0){break}a[e+((sZ(g|0)|0)-1)|0]=0}}while(0);hC(n,540468,g);if(!(hD(n,367140)|0)){j=c[135158]|0;k=(j|0)!=0?j:c[t>>2]|0;eQ(k|0,47616,(p=i,i=i+8|0,c[p>>2]=367140,p)|0)|0;i=p;k=c[135158]|0;j=(k|0)!=0?k:c[t>>2]|0;a7(j|0)|0}hx(n)}}while(0);n=b+8|0;p=c[f>>2]|0;if((c[n>>2]|0)==0){B=p}else{g=0;e=p;while(1){sS(c[e+(g*12|0)+8>>2]|0);p=g+1|0;o=c[f>>2]|0;if(p>>>0<(c[n>>2]|0)>>>0){g=p;e=o}else{B=o;break}}}sS(B)}sS(b);i=d;return}function is(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+256|0;e=d|0;f=c[133027]|0;g=f+4|0;h=c[g>>2]|0;if(h>>>0>1){j=f|0;k=1;l=h;while(1){h=c[(c[j>>2]|0)+(k<<2)>>2]|0;if((h|0)==0){m=l}else{sS(c[h+8>>2]|0);sS(c[(c[j>>2]|0)+(k<<2)>>2]|0);c[(c[j>>2]|0)+(k<<2)>>2]=0;m=c[g>>2]|0}h=k+1|0;if(h>>>0<m>>>0){k=h;l=m}else{break}}}c[g>>2]=1;g=f+12|0;sS(c[g>>2]|0);c[g>>2]=0;g=e|0;e=c[b+4>>2]|0;f=c[b>>2]|0;b=(a[f+(e*12|0)+4|0]&1)!=0?29664:29184;m=c[f+(e*12|0)>>2]|0;b5(g|0,256,19064,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=b,c[f+16>>2]=m,f)|0)|0;i=f;m=c[133027]|0;b=m+4|0;L4883:do{if((c[b>>2]|0)>>>0<(c[m+8>>2]|0)>>>0){e=sR(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}s_(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=180;l=dT(g|0)|0;k=c[b>>2]|0;c[e+8>>2]=l;l=m|0;c[(c[l>>2]|0)+(k<<2)>>2]=e;k=c[b>>2]|0;c[b>>2]=k+1;if(k>>>0>1){n=k}else{break}while(1){k=n>>>1;j=c[l>>2]|0;h=j+(k<<2)|0;o=c[h>>2]|0;p=c[j+(n<<2)>>2]|0;if((c[p+4>>2]|0)>>>0<=(c[o+4>>2]|0)>>>0){break L4883}c[h>>2]=p;c[(c[l>>2]|0)+(n<<2)>>2]=o;if(n>>>0>3){n=k}else{break}}}}while(0);if((a[383584]&1)==0){i=d;return}n=c[135158]|0;eQ(((n|0)!=0?n:c[t>>2]|0)|0,48248,(f=i,i=i+8|0,c[f>>2]=g,f)|0)|0;i=f;f=c[135158]|0;a7(((f|0)!=0?f:c[t>>2]|0)|0)|0;i=d;return}function it(a,b,d){a=a|0;b=b|0;d=d|0;b=a$(d|0)|0;if((b|0)==0){return b|0}c[74440]=dm()|0;return b|0}function iu(a,b,c){a=a|0;b=b|0;c=c|0;return bW(b|0,c|0)|0}function iv(a){a=a|0;return aV()|0}function iw(a){a=a|0;return fH()|0}function ix(a,b){a=a|0;b=b|0;eA(b|0);return}function iy(a){a=a|0;es();return}function iz(a){a=a|0;return dc()|0}function iA(a){a=a|0;return bx()|0}function iB(b,d){b=b|0;d=+d;var e=0,f=0,h=0,i=0,j=0.0;e=b+24|0;if((c[e>>2]|0)!=0){f=b+12|0;h=0;do{i=c[f>>2]|0;if((a[i+(h*136|0)+20|0]&1)==0){g[i+(h*136|0)+56>>2]=d;g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2]*d;g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]*d;j=+g[i+(h*136|0)+60>>2];g[i+(h*136|0)+24>>2]=j+(+g[i+(h*136|0)+40>>2]-j)*d;j=+g[i+(h*136|0)+64>>2];g[i+(h*136|0)+28>>2]=j+(+g[i+(h*136|0)+44>>2]-j)*d}else{g[i+(h*136|0)+24>>2]=+g[i+(h*136|0)+40>>2];g[i+(h*136|0)+28>>2]=+g[i+(h*136|0)+44>>2];g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2];g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]}h=h+1|0;}while(h>>>0<(c[e>>2]|0)>>>0)}e=c[b+16>>2]|0;f4[c[(c[b+4>>2]|0)+12>>2]&7](c[b>>2]|0,+g[e+24>>2],+g[e+28>>2],+g[e+32>>2],+g[e+36>>2]);return}function iC(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0.0,aY=0.0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a5=0,a6=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0;b=i;i=i+9240|0;d=b|0;e=b+64|0;f=b+320|0;h=b+328|0;j=b+392|0;k=b+456|0;l=b+520|0;m=b+584|0;n=b+4680|0;o=b+8776|0;p=b+8792|0;q=b+8856|0;r=b+9112|0;s=b+9176|0;u=sR(32)|0;if((u|0)==0){v=0;i=b;return v|0}if((c[u-4>>2]&3|0)!=0){s_(u|0,0,32)}w=u;x=c[(c[136863]|0)+52>>2]|0;do{if((x|0)==0){y=c[135158]|0;z=(y|0)!=0?y:c[t>>2]|0;be(48800,71,1,z|0)|0;z=c[135158]|0;y=(z|0)!=0?z:c[t>>2]|0;a7(y|0)|0}else{y=u+4|0;f0[x&255](c[136866]|0,y);z=u;c[z>>2]=c[136866];if((c[y>>2]|0)==0){break}A=hz(342552,0)|0;if((A|0)==0){B=c[135158]|0;C=(B|0)!=0?B:c[t>>2]|0;eQ(C|0,49960,(D=i,i=i+8|0,c[D>>2]=342552,D)|0)|0;i=D;C=c[135158]|0;B=(C|0)!=0?C:c[t>>2]|0;a7(B|0)|0;break}B=A+4|0;C=B;while(1){E=c[C>>2]|0;if((E|0)==0){F=3512;break}if((da(37176,c[E+4>>2]|0)|0)==0){F=3511;break}else{C=E+12|0}}L4935:do{if((F|0)==3511){c[(ep()|0)>>2]=0;C=a4(c[E+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){F=3512;break}if((C|0)==0){break}G=C*136|0;if(C>>>0>65535){H=((G>>>0)/(C>>>0)|0|0)==136?G:-1}else{H=G}G=sR(H)|0;if((G|0)==0){c[u+12>>2]=0;break}if((c[G-4>>2]&3|0)!=0){s_(G|0,0,H|0)}I=G;G=u+12|0;c[G>>2]=I;J=u+24|0;c[J>>2]=C;C=k|0;L=l|0;M=m|0;N=n|0;O=o;P=p|0;Q=q|0;R=r|0;S=s|0;T=o+8|0;U=o|0;V=o+4|0;W=d|0;X=e|0;Y=h|0;Z=j|0;b5(C|0,64,16816,(D=i,i=i+8|0,c[D>>2]=0,D)|0)|0;i=D;L4948:do{if(hA(A,C,M)|0){_=I;$=0;L4949:while(1){b5(L|0,64,12400,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;aa=_+($*136|0)+69|0;ab=B;while(1){ac=c[ab>>2]|0;if((ac|0)==0){break}if((da(L|0,c[ac+4>>2]|0)|0)==0){F=3526;break}else{ab=ac+12|0}}L4954:do{if((F|0)==3526){F=0;ab=64;ad=aa;ae=c[ac+8>>2]|0;while(1){af=ab-1|0;if((af|0)==0){break}ag=a[ae]|0;a[ad]=ag;if(ag<<24>>24==0){break L4954}else{ab=af;ad=ad+1|0;ae=ae+1|0}}a[ad]=0;if((a[ae]|0)==0){break}else{ah=ae}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);ht(N,342552,M);s_(O|0,0,12);if((a[547628]&1)==0){if(!(i2(N,o,16,0)|0)){F=3534;break}}else{if(!(i2(N,o,0,16)|0)){F=3534;break}}c[_+($*136|0)+8>>2]=c[T>>2];c[_+($*136|0)+12>>2]=c[U>>2];c[_+($*136|0)+16>>2]=c[V>>2];aa=_+($*136|0)+44|0;g[aa>>2]=0.0;ae=_+($*136|0)+40|0;g[ae>>2]=0.0;ad=_+($*136|0)+52|0;g[ad>>2]=1.0;ab=_+($*136|0)+48|0;g[ab>>2]=1.0;b5(P|0,64,50088,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;af=B;while(1){ai=c[af>>2]|0;if((ai|0)==0){break}if((da(P|0,c[ai+4>>2]|0)|0)==0){F=3538;break}else{af=ai+12|0}}do{if((F|0)==3538){F=0;af=256;ag=0;aj=Q;ak=c[ai+8>>2]|0;while(1){al=af-1|0;if((al|0)==0){F=3541;break}am=a[ak]|0;a[aj]=am;if(am<<24>>24==0){an=ag;break}else{af=al;ag=ag+1|0;aj=aj+1|0;ak=ak+1|0}}do{if((F|0)==3541){F=0;a[aj]=0;if((a[ak]|0)==0){an=ag;break}else{ao=ak;ap=ag}while(1){af=ao+1|0;al=ap+1|0;if((a[af]|0)==0){an=al;break}else{ao=af;ap=al}}}}while(0);if(an>>>0>=256){break}ag=hh(Q,47552)|0;ak=ag+4|0;if((c[ak>>2]|0)>>>0<4){F=3545;break L4949}aj=ag|0;g[ae>>2]=+sY(c[c[aj>>2]>>2]|0,0);g[aa>>2]=+sY(c[(c[aj>>2]|0)+8>>2]|0,0);g[ab>>2]=+sY(c[(c[aj>>2]|0)+16>>2]|0,0);g[ad>>2]=+sY(c[(c[aj>>2]|0)+24>>2]|0,0);if((ag|0)==0){break}al=c[aj>>2]|0;if((c[ak>>2]|0)==0){aq=al}else{af=0;am=al;while(1){sS(c[am+(af<<3)>>2]|0);al=af+1|0;ar=c[aj>>2]|0;if(al>>>0<(c[ak>>2]|0)>>>0){af=al;am=ar}else{aq=ar;break}}}sS(aq);sS(ag)}}while(0);b5(R|0,64,45096,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;am=_+($*136|0)+68|0;a[am]=0;hB(A,R,am)|0;b5(S|0,64,43704,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;am=B;while(1){as=c[am>>2]|0;if((as|0)==0){F=3554;break L4949}if((da(S|0,c[as+4>>2]|0)|0)==0){break}else{am=as+12|0}}c[(ep()|0)>>2]=0;am=a4(c[as+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){F=3554;break}af=(am|0)==0;do{if(af){at=0}else{ak=am*104|0;if(am>>>0<=65535){at=ak;break}at=((ak>>>0)/(am>>>0)|0|0)==104?ak:-1}}while(0);ak=sR(at)|0;if((ak|0)==0){F=3561;break}if((c[ak-4>>2]&3|0)!=0){s_(ak|0,0,at|0)}aj=ak;ak=_+($*136|0)|0;c[ak>>2]=aj;ar=_+($*136|0)+4|0;c[ar>>2]=am;L5001:do{if(!af){al=c[U>>2]|0;au=c[V>>2]|0;b5(W|0,64,39384,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=0,D)|0)|0;i=D;av=B;while(1){aw=c[av>>2]|0;if((aw|0)==0){ax=0;F=3572;break L4949}if((da(W|0,c[aw+4>>2]|0)|0)==0){break}else{av=aw+12|0}}av=256;ag=0;ay=X;az=c[aw+8>>2]|0;while(1){aA=av-1|0;if((aA|0)==0){F=3569;break}aB=a[az]|0;a[ay]=aB;if(aB<<24>>24==0){aC=ag;break}else{av=aA;ag=ag+1|0;ay=ay+1|0;az=az+1|0}}do{if((F|0)==3569){F=0;a[ay]=0;if((a[az]|0)==0){aC=ag;break}else{aD=az;aE=ag}while(1){av=aD+1|0;aA=aE+1|0;if((a[av]|0)==0){aC=aA;break}else{aD=av;aE=aA}}}}while(0);if(aC>>>0<256){aF=aj;aG=0;aH=al;aI=au}else{ax=0;F=3572;break L4949}while(1){aJ=hh(X,47552)|0;if((aJ|0)==0){F=3574;break L4949}aK=aJ+4|0;aL=c[aK>>2]|0;if(aL>>>0<6){F=3576;break L4949}aM=aJ|0;ag=c[aM>>2]|0;az=c[ag+8>>2]|0;ay=c[ag+16>>2]|0;aN=c[ag+24>>2]|0;aA=c[ag>>2]|0;ag=aF+(aG*104|0)+24|0;c[ag>>2]=0;c[ag+4>>2]=0;L5019:do{if((da(aA|0,33960)|0)==0){c[aF+(aG*104|0)+20>>2]=1}else{av=aF+(aG*104|0)+20|0;if((da(aA|0,32896)|0)==0){c[av>>2]=2;break}c[av>>2]=0;av=eM(aA|0,48016,f|0)|0;if((av|0)!=0){aB=av;do{av=0;while(1){if(av>>>0>=56){aO=0;aP=56;break}if((da(c[840+(av<<3)>>2]|0,aB|0)|0)==0){F=3587;break}else{av=av+1|0}}if((F|0)==3587){F=0;aO=0;aP=c[844+(av<<3)>>2]|0}aQ=tc(1,0,aP|0)|0;aR=K;aS=c[ag+4>>2]|aR;c[ag>>2]=c[ag>>2]|aQ;c[ag+4>>2]=aS;aB=eM(0,48016,f|0)|0;}while((aB|0)!=0)}if((c[ag>>2]&0|0)==0&(c[ag+4>>2]&524288|0)==0){break}b5(Y|0,64,31480,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aG,D)|0)|0;i=D;aB=aF+(aG*104|0)+40|0;aS=B;while(1){aT=c[aS>>2]|0;if((aT|0)==0){break L5019}if((da(Y|0,c[aT+4>>2]|0)|0)==0){break}else{aS=aT+12|0}}aS=64;aQ=aB;aR=c[aT+8>>2]|0;while(1){aU=aS-1|0;if((aU|0)==0){break}aV=a[aR]|0;a[aQ]=aV;if(aV<<24>>24==0){break L5019}else{aS=aU;aQ=aQ+1|0;aR=aR+1|0}}a[aQ]=0;if((a[aR]|0)==0){break}else{aW=aR}do{aW=aW+1|0;}while((a[aW]|0)!=0)}}while(0);aX=+(aH>>>0>>>0);g[aF+(aG*104|0)>>2]=+sY(az,0)/aX;aY=+(aI>>>0>>>0);g[aF+(aG*104|0)+4>>2]=+sY(ay,0)/aY;if((da(aN|0,30848)|0)==0){c[aF+(aG*104|0)+8>>2]=0;aZ=0}else{if((da(aN|0,30480)|0)!=0){F=3602;break L4949}c[aF+(aG*104|0)+8>>2]=1;aZ=1}do{if((c[aF+(aG*104|0)+20>>2]|0)!=0){if((aZ|0)!=0){F=3607;break L4949}b5(Z|0,64,29272,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aG,D)|0)|0;i=D;ag=aF+(aG*104|0)+32|0;aA=B;while(1){a_=c[aA>>2]|0;if((a_|0)==0){F=3614;break}if((da(Z|0,c[a_+4>>2]|0)|0)==0){F=3613;break}else{aA=a_+12|0}}if((F|0)==3613){F=0;g[ag>>2]=+sY(c[a_+8>>2]|0,0);break}else if((F|0)==3614){F=0;g[ag>>2]=1.0;break}}}while(0);g[aF+(aG*104|0)+12>>2]=+sY(c[(c[aM>>2]|0)+32>>2]|0,0)/aX;g[aF+(aG*104|0)+16>>2]=+sY(c[(c[aM>>2]|0)+40>>2]|0,0)/aY;ay=c[aM>>2]|0;if((c[aK>>2]|0)==0){a$=ay}else{az=0;aA=ay;while(1){sS(c[aA+(az<<3)>>2]|0);ay=az+1|0;aR=c[aM>>2]|0;if(ay>>>0<(c[aK>>2]|0)>>>0){az=ay;aA=aR}else{a$=aR;break}}}sS(a$);sS(aJ);aA=aG+1|0;if(aA>>>0>=(c[ar>>2]|0)>>>0){break L5001}az=c[ak>>2]|0;aR=c[U>>2]|0;ay=c[V>>2]|0;b5(W|0,64,39384,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aA,D)|0)|0;i=D;aQ=B;while(1){a0=c[aQ>>2]|0;if((a0|0)==0){ax=aA;F=3572;break L4949}if((da(W|0,c[a0+4>>2]|0)|0)==0){break}else{aQ=a0+12|0}}aQ=256;aS=0;aB=X;aU=c[a0+8>>2]|0;while(1){aV=aQ-1|0;if((aV|0)==0){F=3624;break}a1=a[aU]|0;a[aB]=a1;if(a1<<24>>24==0){a2=aS;break}else{aQ=aV;aS=aS+1|0;aB=aB+1|0;aU=aU+1|0}}do{if((F|0)==3624){F=0;a[aB]=0;if((a[aU]|0)==0){a2=aS;break}else{a3=aU;a5=aS}while(1){aQ=a3+1|0;aV=a5+1|0;if((a[aQ]|0)==0){a2=aV;break}else{a3=aQ;a5=aV}}}}while(0);if(a2>>>0<256){aF=az;aG=aA;aH=aR;aI=ay}else{ax=aA;F=3572;break L4949}}}}while(0);a[_+($*136|0)+20|0]=0;g[_+($*136|0)+60>>2]=+g[ae>>2]+ +g[ab>>2]*.5;g[_+($*136|0)+64>>2]=+g[aa>>2]+ +g[ad>>2]*.5;ak=$+1|0;a6=c[J>>2]|0;if(ak>>>0>=a6>>>0){F=3521;break}ar=c[G>>2]|0;b5(C|0,64,16816,(D=i,i=i+8|0,c[D>>2]=ak,D)|0)|0;i=D;if(hA(A,C,M)|0){_=ar;$=ak}else{a8=ak;F=3522;break L4948}}if((F|0)==3607){ak=c[135158]|0;ar=(ak|0)!=0?ak:c[t>>2]|0;be(29688,69,1,ar|0)|0;ar=c[135158]|0;ak=(ar|0)!=0?ar:c[t>>2]|0;a7(ak|0)|0;ak=c[aM>>2]|0;if((c[aK>>2]|0)==0){a9=ak}else{ar=0;aj=ak;while(1){sS(c[aj+(ar<<3)>>2]|0);ak=ar+1|0;af=c[aM>>2]|0;if(ak>>>0<(c[aK>>2]|0)>>>0){ar=ak;aj=af}else{a9=af;break}}}sS(a9);sS(aJ);ba=aG}else if((F|0)==3572){aj=c[135158]|0;eQ(((aj|0)!=0?aj:c[t>>2]|0)|0,38504,(D=i,i=i+8|0,c[D>>2]=W,D)|0)|0;i=D;aj=c[135158]|0;a7(((aj|0)!=0?aj:c[t>>2]|0)|0)|0;ba=ax}else if((F|0)==3574){aj=c[135158]|0;be(37272,62,1,((aj|0)!=0?aj:c[t>>2]|0)|0)|0;aj=c[135158]|0;a7(((aj|0)!=0?aj:c[t>>2]|0)|0)|0;ba=aG}else if((F|0)==3521){L5090:do{if((a6|0)!=0){aj=0;ar=a6;L5091:while(1){af=c[G>>2]|0;ak=af+(aj*136|0)+4|0;if((c[ak>>2]|0)==0){bb=ar;bc=aj+1|0}else{am=af+(aj*136|0)|0;au=aj+1|0;al=0;do{aS=c[am>>2]|0;bd=aS+(al*104|0)+40|0;if((a[bd]|0)==0){c[aS+(al*104|0)+36>>2]=(au>>>0)%(ar>>>0)|0}else{aU=0;while(1){if(aU>>>0>=ar>>>0){break L5091}if((da(af+(aU*136|0)+69|0,bd|0)|0)==0){break}else{aU=aU+1|0}}if((aU|0)<0){break L5091}c[aS+(al*104|0)+36>>2]=aU}al=al+1|0;}while(al>>>0<(c[ak>>2]|0)>>>0);bb=c[J>>2]|0;bc=au}if(bc>>>0<bb>>>0){aj=bc;ar=bb}else{break L5090}}ar=c[135158]|0;eQ(((ar|0)!=0?ar:c[t>>2]|0)|0,18952,(D=i,i=i+8|0,c[D>>2]=bd,D)|0)|0;i=D;ar=c[135158]|0;a7(((ar|0)!=0?ar:c[t>>2]|0)|0)|0;ar=c[135158]|0;be(21384,64,1,((ar|0)!=0?ar:c[t>>2]|0)|0)|0;ar=c[135158]|0;a7(((ar|0)!=0?ar:c[t>>2]|0)|0)|0;break L4935}}while(0);hx(A);ar=c[G>>2]|0;aj=u+16|0;c[aj>>2]=ar;gn[c[(c[y>>2]|0)+4>>2]&31](c[z>>2]|0,c[ar+8>>2]|0,c[ar+12>>2]|0,c[ar+16>>2]|0)|0;ar=c[aj>>2]|0;f4[c[(c[y>>2]|0)+12>>2]&7](c[z>>2]|0,+g[ar+24>>2],+g[ar+28>>2],+g[ar+32>>2],+g[ar+36>>2]);f0[c[(c[y>>2]|0)+16>>2]&255](c[z>>2]|0,(a[(c[aj>>2]|0)+68|0]&1)!=0);f0[c[c[y>>2]>>2]&255](c[z>>2]|0,1);a[u+8|0]=1;fZ[c[(c[y>>2]|0)+20>>2]&7](c[z>>2]|0,+g[86662]);iB(w,1.0);c[u+28>>2]=(((c[u+20>>2]|0)+1|0)>>>0)%((c[J>>2]|0)>>>0)|0;v=w;i=b;return v|0}else if((F|0)==3576){aj=aJ|0;ar=c[aj>>2]|0;if((aL|0)==0){bf=ar}else{ad=0;aa=ar;while(1){sS(c[aa+(ad<<3)>>2]|0);ar=ad+1|0;ab=c[aj>>2]|0;if(ar>>>0<(c[aK>>2]|0)>>>0){ad=ar;aa=ab}else{bf=ab;break}}}sS(bf);sS(aJ);aa=c[135158]|0;be(35328,85,1,((aa|0)!=0?aa:c[t>>2]|0)|0)|0;aa=c[135158]|0;a7(((aa|0)!=0?aa:c[t>>2]|0)|0)|0;ba=aG}else if((F|0)==3561){c[_+($*136|0)>>2]=0;aa=c[135158]|0;be(41320,58,1,((aa|0)!=0?aa:c[t>>2]|0)|0)|0;aa=c[135158]|0;a7(((aa|0)!=0?aa:c[t>>2]|0)|0)|0;bg=$;break}else if((F|0)==3602){aa=c[135158]|0;eQ(((aa|0)!=0?aa:c[t>>2]|0)|0,30024,(D=i,i=i+8|0,c[D>>2]=aN,D)|0)|0;i=D;aa=c[135158]|0;a7(((aa|0)!=0?aa:c[t>>2]|0)|0)|0;aa=c[aM>>2]|0;if((c[aK>>2]|0)==0){bh=aa}else{ad=0;aj=aa;while(1){sS(c[aj+(ad<<3)>>2]|0);aa=ad+1|0;ab=c[aM>>2]|0;if(aa>>>0<(c[aK>>2]|0)>>>0){ad=aa;aj=ab}else{bh=ab;break}}}sS(bh);sS(aJ);ba=aG}else if((F|0)==3554){aj=c[135158]|0;eQ(((aj|0)!=0?aj:c[t>>2]|0)|0,42360,(D=i,i=i+8|0,c[D>>2]=S,D)|0)|0;i=D;aj=c[135158]|0;a7(((aj|0)!=0?aj:c[t>>2]|0)|0)|0;bg=$;break}else if((F|0)==3545){aj=c[135158]|0;eQ(((aj|0)!=0?aj:c[t>>2]|0)|0,46104,(D=i,i=i+8|0,c[D>>2]=Q,D)|0)|0;i=D;aj=c[135158]|0;a7(((aj|0)!=0?aj:c[t>>2]|0)|0)|0;bg=$;break}else if((F|0)==3534){aj=c[135158]|0;eQ(((aj|0)!=0?aj:c[t>>2]|0)|0,52512,(D=i,i=i+8|0,c[D>>2]=M,D)|0)|0;i=D;aj=c[135158]|0;a7(((aj|0)!=0?aj:c[t>>2]|0)|0)|0;bg=$;break}aj=c[135158]|0;eQ(((aj|0)!=0?aj:c[t>>2]|0)|0,40384,(D=i,i=i+8|0,c[D>>2]=ba,D)|0)|0;i=D;aj=c[135158]|0;a7(((aj|0)!=0?aj:c[t>>2]|0)|0)|0;bg=$}else{a8=0;F=3522}}while(0);if((F|0)==3522){M=c[135158]|0;Q=(M|0)!=0?M:c[t>>2]|0;eQ(Q|0,14592,(D=i,i=i+8|0,c[D>>2]=C,D)|0)|0;i=D;Q=c[135158]|0;M=(Q|0)!=0?Q:c[t>>2]|0;a7(M|0)|0;bg=a8}M=c[135158]|0;Q=(M|0)!=0?M:c[t>>2]|0;eQ(Q|0,24760,(D=i,i=i+8|0,c[D>>2]=bg,D)|0)|0;i=D;Q=c[135158]|0;M=(Q|0)!=0?Q:c[t>>2]|0;a7(M|0)|0}}while(0);if((F|0)==3512){z=c[135158]|0;y=(z|0)!=0?z:c[t>>2]|0;be(29192,62,1,y|0)|0;y=c[135158]|0;z=(y|0)!=0?y:c[t>>2]|0;a7(z|0)|0}hx(A)}}while(0);F=u+24|0;D=u+12|0;bg=c[D>>2]|0;if((c[F>>2]|0)==0){bi=bg}else{a8=0;ba=bg;while(1){sS(c[ba+(a8*136|0)>>2]|0);sS(c[ba+(a8*136|0)+8>>2]|0);bg=a8+1|0;aG=c[D>>2]|0;if(bg>>>0<(c[F>>2]|0)>>>0){a8=bg;ba=aG}else{bi=aG;break}}}sS(bi);bi=c[u+4>>2]|0;if((bi|0)!=0){f0[c[bi>>2]&255](c[u>>2]|0,0)}sS(u);v=0;i=b;return v|0}function iD(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,W=0,X=0.0,Y=0.0,_=0.0,$=0,aa=0,ab=0,ac=0,ad=0.0,ae=0.0,af=0.0,ah=0.0,ai=0.0,aj=0.0,ak=0,al=0,am=0.0,an=0.0,ao=0,ap=0,aq=0;e=i;f=d+64|0;sS(c[f>>2]|0);g=d+76|0;sS(c[g>>2]|0);h=d+80|0;sS(c[h>>2]|0);j=d+92|0;sS(c[j>>2]|0);k=d+104|0;sS(c[k>>2]|0);l=d+96|0;sS(c[l>>2]|0);m=d+120|0;sS(c[m>>2]|0);s_(f|0,0,64);n=d|0;o=c[n>>2]|0;p=d+12|0;q=c[p>>2]|0;r=d+4|0;s=c[r>>2]|0;do{if((o|0)==(q|0)){if((s|0)!=(c[d+16>>2]|0)){u=3658;break}a[d+60|0]=1;v=1}else{u=3658}}while(0);if((u|0)==3658){c[d+36>>2]=96;c[d+40>>2]=78;a[d+60|0]=0;v=0}w=d+44|0;c[w>>2]=0;x=(q<<3)+56&-64;c[d+116>>2]=x;c[d+108>>2]=q;c[d+112>>2]=s;y=ag(x,s)|0;x=y>>3;if(x>>>0>65535){z=(y>>>3|0)==(x|0)?y:-1}else{z=y}y=sR(z)|0;if((y|0)==0){c[k>>2]=0;A=0;i=e;return A|0}if((c[y-4>>2]&3|0)!=0){s_(y|0,0,z|0)}c[k>>2]=y;y=c[d+24>>2]|0;if((y|0)!=0){k=(o<<2)+28&-32;c[d+100>>2]=k;o=ag(k,s)|0;s=o>>2;if(s>>>0>65535){B=(o>>>2|0)==(s|0)?o:-1}else{B=o}o=sR(B)|0;if((o|0)==0){c[l>>2]=0;A=0;i=e;return A|0}if((c[o-4>>2]&3|0)!=0){s_(o|0,0,B|0)}c[l>>2]=o}o=c[d+28>>2]|0;l=(o|0)==0;if(!l){B=(q<<2)+28&-32;c[d+124>>2]=B;q=ag(c[d+16>>2]|0,B)|0;B=q>>2;if(B>>>0>65535){C=(q>>>2|0)==(B|0)?q:-1}else{C=q}q=sR(C)|0;if((q|0)==0){c[m>>2]=0;A=0;i=e;return A|0}if((c[q-4>>2]&3|0)!=0){s_(q|0,0,C|0)}c[m>>2]=q}q=v<<24>>24==0;L5185:do{if(q){if((y|0)==2){c[d+48>>2]=4}else if((y|0)==3){c[d+48>>2]=56}else if((y|0)==4){c[d+48>>2]=2}else if((y|0)!=0){A=0;i=e;return A|0}if((o|0)==2){c[d+52>>2]=54;break}else if((o|0)==4){c[d+52>>2]=38;break}else if((o|0)==0){break}else{A=0;i=e;return A|0}}else{if((y|0)==(o|0)){c[d+56>>2]=34;A=1;i=e;return A|0}v=(y|0)==2;if(v&l){c[d+56>>2]=4;A=1;i=e;return A|0}if(!((y|0)!=3|l^1)){c[d+56>>2]=56;break}m=(y|0)==3;C=(o|0)==4;if(m&C){c[d+56>>2]=28;break}if(v&(o|0)==3){c[d+56>>2]=26;break}do{if(m){if((o|0)!=2){D=0;break}c[d+56>>2]=50;break L5185}else{if((y|0)==4){if(!l){D=0;break}c[d+56>>2]=2;break L5185}else if((y|0)!=0){D=0;break}if((o|0)==2){c[d+56>>2]=54;break L5185}else if((o|0)==4){c[d+56>>2]=38;break L5185}else{D=1;break}}}while(0);if(v&C){c[d+56>>2]=22;break}if(D&(o|0)==1){c[d+56>>2]=6;break}else{A=0;i=e;return A|0}}}while(0);if(!q){A=1;i=e;return A|0}q=c[d+32>>2]|0;L5237:do{if((q|0)==1){c[d+68>>2]=1;c[d+72>>2]=1;c[d+84>>2]=1;o=d+88|0;c[o>>2]=1;D=c[p>>2]|0;y=D<<1;if(D>>>0>65535){E=(D&2147483647|0)==(D|0)?y:-1}else{E=y}y=sR(E)|0;do{if((y|0)!=0){if((c[y-4>>2]&3|0)==0){break}s_(y|0,0,E|0)}}while(0);C=d+64|0;c[C>>2]=y;v=c[p>>2]|0;D=v<<2;if(v>>>0>65535){F=(v&1073741823|0)==(v|0)?D:-1}else{F=D}D=sR(F)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}s_(D|0,0,F|0)}}while(0);c[g>>2]=D;y=d+16|0;v=ag(c[y>>2]|0,c[o>>2]|0)|0;l=v<<1;if(v>>>0>65535){G=(v&2147483647|0)==(v|0)?l:-1}else{G=l}l=sR(G)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}s_(l|0,0,G|0)}}while(0);c[h>>2]=l;o=c[y>>2]|0;D=o<<2;if(o>>>0>65535){H=(o&1073741823|0)==(o|0)?D:-1}else{H=D}D=sR(H)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}s_(D|0,0,H|0)}}while(0);c[j>>2]=D;if((c[C>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}l=c[n>>2]|0;o=c[p>>2]|0;v=(l<<16|0)/(o|0)|0;m=c[r>>2]|0;B=c[y>>2]|0;s=((m<<15|0)/(B|0)|0)-32768|0;k=(m<<16|0)/(B|0)|0;if((o|0)>0){m=((l<<15|0)/(o|0)|0)-32768|0;l=0;while(1){c[(c[g>>2]|0)+(l<<2)>>2]=m>>16;b[(c[C>>2]|0)+(l<<1)>>1]=16384;z=l+1|0;if((z|0)<(o|0)){m=m+v|0;l=z}else{break}}I=c[y>>2]|0}else{I=B}L5279:do{if((I|0)>0){l=s;v=0;while(1){c[(c[j>>2]|0)+(v<<2)>>2]=l>>16;b[(c[h>>2]|0)+(v<<1)>>1]=16384;m=v+1|0;if((m|0)>=(I|0)){break L5279}l=l+k|0;v=m}}}while(0);c[w>>2]=2}else if((q|0)==2){c[d+68>>2]=2;c[d+72>>2]=2;c[d+84>>2]=2;k=d+88|0;c[k>>2]=2;s=c[p>>2]|0;B=s<<1;y=s<<2;if(B>>>0>65535){J=(B&2147483646|0)==(B|0)?y:-1}else{J=y}y=sR(J)|0;do{if((y|0)!=0){if((c[y-4>>2]&3|0)==0){break}s_(y|0,0,J|0)}}while(0);B=d+64|0;c[B>>2]=y;s=c[p>>2]|0;v=s<<2;if(s>>>0>65535){K=(s&1073741823|0)==(s|0)?v:-1}else{K=v}v=sR(K)|0;do{if((v|0)!=0){if((c[v-4>>2]&3|0)==0){break}s_(v|0,0,K|0)}}while(0);c[g>>2]=v;y=d+16|0;s=ag(c[y>>2]|0,c[k>>2]|0)|0;l=s<<1;if(s>>>0>65535){L=(s&2147483647|0)==(s|0)?l:-1}else{L=l}l=sR(L)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}s_(l|0,0,L|0)}}while(0);c[h>>2]=l;k=c[y>>2]|0;v=k<<2;if(k>>>0>65535){M=(k&1073741823|0)==(k|0)?v:-1}else{M=v}v=sR(M)|0;do{if((v|0)!=0){if((c[v-4>>2]&3|0)==0){break}s_(v|0,0,M|0)}}while(0);c[j>>2]=v;if((c[B>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}l=c[n>>2]|0;k=c[p>>2]|0;s=(l<<16|0)/(k|0)|0;m=c[r>>2]|0;o=c[y>>2]|0;C=((m<<15|0)/(o|0)|0)-32768|0;D=(m<<16|0)/(o|0)|0;if((k|0)>0){m=((l<<15|0)/(k|0)|0)-32768|0;l=0;while(1){c[(c[g>>2]|0)+(l<<2)>>2]=m>>16;z=l<<1;x=z|1;b[(c[B>>2]|0)+(x<<1)>>1]=m>>>2&16383;N=c[B>>2]|0;b[N+(z<<1)>>1]=16384-(b[N+(x<<1)>>1]|0)&65535;x=l+1|0;if((x|0)<(k|0)){m=m+s|0;l=x}else{break}}O=c[y>>2]|0}else{O=o}if((O|0)>0){P=C;Q=0}else{break}while(1){c[(c[j>>2]|0)+(Q<<2)>>2]=P>>16;l=Q<<1;s=l|1;b[(c[h>>2]|0)+(s<<1)>>1]=P>>>2&16383;m=c[h>>2]|0;b[m+(l<<1)>>1]=16384-(b[m+(s<<1)>>1]|0)&65535;s=Q+1|0;if((s|0)>=(O|0)){break L5237}P=P+D|0;Q=s}}else if((q|0)==3){D=c[n>>2]|0;C=c[p>>2]|0;if((D|0)>(C|0)){o=((D|0)/(C|0)|0)-1|0;D=o>>>1|o;o=D>>>2|D;D=o>>>4|o;o=D>>>8|D;R=((o>>>16|o)<<3)+8|0}else{R=8}o=d+68|0;c[o>>2]=R;c[d+72>>2]=R;D=d+84|0;c[D>>2]=R;y=d+88|0;c[y>>2]=R;s=ag(R,C)|0;C=s<<1;if(s>>>0>65535){S=(s&2147483647|0)==(s|0)?C:-1}else{S=C}C=sR(S)|0;do{if((C|0)!=0){if((c[C-4>>2]&3|0)==0){break}s_(C|0,0,S|0)}}while(0);s=d+64|0;c[s>>2]=C;m=c[p>>2]|0;l=m<<2;if(m>>>0>65535){T=(m&1073741823|0)==(m|0)?l:-1}else{T=l}l=sR(T)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}s_(l|0,0,T|0)}}while(0);c[g>>2]=l;C=d+16|0;m=ag(c[C>>2]|0,c[y>>2]|0)|0;k=m<<1;if(m>>>0>65535){U=(m&2147483647|0)==(m|0)?k:-1}else{U=k}k=sR(U)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}s_(k|0,0,U|0)}}while(0);c[h>>2]=k;y=c[C>>2]|0;l=y<<2;if(y>>>0>65535){W=(y&1073741823|0)==(y|0)?l:-1}else{W=l}l=sR(W)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}s_(l|0,0,W|0)}}while(0);c[j>>2]=l;if((c[s>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}k=c[n>>2]|0;y=c[p>>2]|0;m=-32768-(R<<15)|0;B=((k<<15|0)/(y|0)|0)+m|0;v=(k<<16|0)/(y|0)|0;x=c[r>>2]|0;N=c[C>>2]|0;z=((x<<15|0)/(N|0)|0)+m|0;m=(x<<16|0)/(N|0)|0;if((k|0)>(y|0)){X=+(y|0)/+(k|0)}else{X=1.0}if((x|0)>(N|0)){Y=+(N|0)/+(x|0)}else{Y=1.0}x=c[o>>2]|0;L5372:do{if((y|0)>0){N=x<<15;_=+(x>>1|0);if((x|0)>0){$=0;aa=B}else{k=0;ab=B;while(1){c[(c[g>>2]|0)+(k<<2)>>2]=ab>>16;ac=k+1|0;if((ac|0)<(y|0)){k=ac;ab=ab+v|0}else{break L5372}}}while(1){c[(c[g>>2]|0)+($<<2)>>2]=aa>>16;ad=+((aa&65535)+N|0)*152587890625.0e-16;ab=ag($,x)|0;k=0;do{ae=(ad- +(k|0))*3.141592653589793;af=ae/_;ah=X*ae;if(+V(+ah)<1.0e-4){ai=16384.0}else{ai=+Z(+ah)/ah*16384.0}if(+V(+af)<1.0e-4){aj=1.0}else{aj=+Z(+af)/af}b[(c[s>>2]|0)+(k+ab<<1)>>1]=~~(X*ai*aj);k=k+1|0;}while((k|0)<(x|0));k=$+1|0;if((k|0)<(y|0)){$=k;aa=aa+v|0}else{break}}}}while(0);v=c[C>>2]|0;y=c[D>>2]|0;if((v|0)<=0){break}x=y<<15;_=+(y>>1|0);if((y|0)>0){ak=0;al=z}else{s=0;B=z;while(1){c[(c[j>>2]|0)+(s<<2)>>2]=B>>16;o=s+1|0;if((o|0)>=(v|0)){break L5237}s=o;B=B+m|0}}while(1){c[(c[j>>2]|0)+(ak<<2)>>2]=al>>16;ad=+((al&65535)+x|0)*152587890625.0e-16;B=ag(ak,y)|0;s=0;do{af=(ad- +(s|0))*3.141592653589793;ah=af/_;ae=Y*af;if(+V(+ae)<1.0e-4){am=16384.0}else{am=+Z(+ae)/ae*16384.0}if(+V(+ah)<1.0e-4){an=1.0}else{an=+Z(+ah)/ah}b[(c[h>>2]|0)+(s+B<<1)>>1]=~~(Y*am*an);s=s+1|0;}while((s|0)<(y|0));s=ak+1|0;if((s|0)>=(v|0)){break L5237}ak=s;al=al+m|0}}else{A=0;i=e;return A|0}}while(0);iT(f,c[p>>2]|0,c[n>>2]|0);f=d+16|0;iT(d+80|0,c[f>>2]|0,c[r>>2]|0);al=(c[n>>2]|0)-(c[d+68>>2]|0)|0;n=c[p>>2]|0;p=0;while(1){if((p|0)>=(n|0)){break}ao=c[(c[g>>2]|0)+(p<<2)>>2]|0;if((ao|0)>(al|0)|(ao|0)<0){u=3826;break}else{p=p+1|0}}if((u|0)==3826){al=c[t>>2]|0;eQ(al|0,46440,(ap=i,i=i+16|0,c[ap>>2]=p,c[ap+8>>2]=ao,ap)|0)|0;i=ap;A=0;i=e;return A|0}ao=(c[r>>2]|0)-(c[d+84>>2]|0)|0;d=c[f>>2]|0;f=0;while(1){if((f|0)>=(d|0)){A=1;u=3832;break}aq=c[(c[j>>2]|0)+(f<<2)>>2]|0;if((aq|0)>(ao|0)|(aq|0)<0){break}else{f=f+1|0}}if((u|0)==3832){i=e;return A|0}eQ(c[t>>2]|0,49368,(ap=i,i=i+16|0,c[ap>>2]=f,c[ap+8>>2]=aq,ap)|0)|0;i=ap;A=0;i=e;return A|0}function iE(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=0;i=a;a=c;while(1){c=0;do{j=b[a+(c<<1)>>1]|0;b[i+(c<<1)>>1]=(j&65535)>>>1&32736|j&31;c=c+1|0;}while((c|0)<(d|0));c=g+1|0;if((c|0)<(e|0)){g=c;i=i+(h<<1)|0;a=a+(f<<1)|0}else{break}}return}function iF(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=0;i=a;a=c;while(1){c=0;do{j=b[a+(c<<1)>>1]|0;b[i+(c<<1)>>1]=j<<1&-64|j&31|(j&65535)>>>4&32;c=c+1|0;}while((c|0)<(d|0));c=g+1|0;if((c|0)<(e|0)){g=c;i=i+(h<<1)|0;a=a+(f<<1)|0}else{break}}return}function iG(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=0;j=a;a=b;while(1){b=0;do{k=e[a+(b<<1)>>1]|0;l=k>>>10&31;m=k>>>5&31;n=k&31;c[j+(b<<2)>>2]=n<<3|n>>>2|(m<<3|m>>>2)<<8|(l<<3|l>>>2)<<16|-16777216;b=b+1|0;}while((b|0)<(d|0));b=h+1|0;if((b|0)<(f|0)){h=b;j=j+(i<<2)|0;a=a+(g<<1)|0}else{break}}return}function iH(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=0;j=a;a=b;while(1){b=0;do{k=e[a+(b<<1)>>1]|0;l=k>>>5&63;m=k&31;c[j+(b<<2)>>2]=m<<3|m>>>2|(k>>>11<<3|k>>>13)<<16|(l<<2|l>>>4)<<8|-16777216;b=b+1|0;}while((b|0)<(d|0));b=h+1|0;if((b|0)<(f|0)){h=b;j=j+(i<<2)|0;a=a+(g<<1)|0}else{break}}return}function iI(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<3|m>>>7&7)&255;a[l+2|0]=(m>>>10<<3|m>>>12&7)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function iJ(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<2|m>>>9&3)&255;a[l+2|0]=(m>>>11<<3|m>>>13)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function iK(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>2;g=0;k=a;a=b;while(1){if(i){b=a;l=0;while(1){c[k+(l<<2)>>2]=d[b]|0|(d[b+1|0]|0)<<8|(d[b+2|0]|0)<<16|-16777216;m=l+1|0;if((m|0)<(e|0)){b=b+3|0;l=m}else{break}}}l=g+1|0;if((l|0)<(f|0)){g=l;k=k+(j<<2)|0;a=a+h|0}else{break}}return}function iL(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>1;g=h>>2;h=0;k=a;a=d;while(1){if(i){d=0;do{l=c[a+(d<<2)>>2]|0;b[k+(d<<1)>>1]=(l>>>11<<5&992|l>>>3&31|l>>>19<<10&31744)&65535;d=d+1|0;}while((d|0)<(e|0))}d=h+1|0;if((d|0)<(f|0)){h=d;k=k+(j<<1)|0;a=a+(g<<2)|0}else{break}}return}function iM(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=h>>2;h=b;b=0;k=d;while(1){if(i){d=h;l=0;while(1){m=c[k+(l<<2)>>2]|0;a[d]=m&255;a[d+1|0]=m>>>8&255;a[d+2|0]=m>>>16&255;m=l+1|0;if((m|0)<(e|0)){d=d+3|0;l=m}else{break}}}l=b+1|0;if((l|0)<(f|0)){h=h+g|0;b=l;k=k+(j<<2)|0}else{break}}return}function iN(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)<=0){return}h=(d|0)>0;i=f>>2;f=g>>2;g=a;a=0;j=b;while(1){if(h){b=0;do{k=c[j+(b<<2)>>2]|0;c[g+(b<<2)>>2]=k>>>16&255|k&-16711936|k<<16&16711680;b=b+1|0;}while((b|0)<(d|0))}b=a+1|0;if((b|0)<(e|0)){g=g+(i<<2)|0;a=b;j=j+(f<<2)|0}else{break}}return}function iO(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[a+104>>2]|0;g=a+16|0;h=c[g>>2]|0;if((h|0)<=0){return}i=a+92|0;j=a+116|0;k=a+12|0;l=a+88|0;m=e>>2;e=a+84|0;n=0;o=c[a+80>>2]|0;a=d;d=c[k>>2]|0;p=h;while(1){h=ag(c[j>>2]>>3,c[(c[i>>2]|0)+(n<<2)>>2]|0)|0;if((d|0)>0){q=0;do{r=c[e>>2]|0;if((r|0)==0){s=0;t=0;u=0;v=0}else{w=c[j>>2]>>3;x=0;y=0;z=f+(q+h<<3)|0;A=0;B=0;C=0;while(1){D=c[z>>2]|0;E=c[z+4>>2]|0;F=b[o+(A<<1)>>1]|0;G=ag(((E>>>16|0<<16)&65535)<<16>>16,F)|0;H=ag((E&65535)<<16>>16,F)|0;I=ag(((D>>>16|E<<16)&65535)<<16>>16,F)|0;E=A+1|0;J=G+(C<<16)>>16;K=H+(B<<16)>>16;L=I+(x<<16)>>16;M=(ag((D&65535)<<16>>16,F)|0)+(y<<16)>>16;if(E>>>0<r>>>0){x=L;y=M;z=z+(w<<3)|0;A=E;B=K;C=J}else{break}}s=L>>>3;t=M>>>3;u=K>>>3;v=J>>>3}C=v&65535;B=u&65535;A=s&65535;w=t&65535;if(C<<16>>16>255){N=-16777216}else{N=C<<16>>16<0?0:v<<24}if(B<<16>>16>255){O=16711680}else{O=B<<16>>16<0?0:u<<16&16711680}if(A<<16>>16>255){P=65280}else{P=A<<16>>16<0?0:s<<8&65280}if(w<<16>>16>255){Q=255}else{Q=w<<16>>16<0?0:t&255}c[a+(q<<2)>>2]=O|N|P|Q;q=q+1|0;R=c[k>>2]|0;}while((q|0)<(R|0));S=R;T=c[g>>2]|0}else{S=d;T=p}q=n+1|0;if((q|0)>=(T|0)){break}n=q;o=o+(c[l>>2]<<1)|0;a=a+(m<<2)|0;d=S;p=T}return}function iP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[b+60|0]&1)!=0){gk[c[b+56>>2]&63](d,e,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[b+8>>2]|0);return}f=b+44|0;if((c[f>>2]|0)==0){if((c[b+24>>2]|0)==0){go[c[b+36>>2]&127](b,e,c[b+8>>2]|0)}else{g=b+96|0;h=b+100|0;gk[c[b+48>>2]&63](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,c[b+8>>2]|0);go[c[b+36>>2]&127](b,c[g>>2]|0,c[h>>2]|0)}h=c[b+40>>2]|0;if((c[b+28>>2]|0)==0){go[h&127](b,d,c[b+20>>2]|0);return}else{g=b+120|0;i=b+124|0;go[h&127](b,c[g>>2]|0,c[i>>2]|0);gk[c[b+52>>2]&63](d,c[g>>2]|0,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[i>>2]|0);return}}else{i=c[b+8>>2]|0;if((c[b+24>>2]|0)==0){j=e;k=i}else{g=b+96|0;h=b+100|0;gk[c[b+48>>2]&63](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,i);j=c[g>>2]|0;k=c[h>>2]|0}h=(c[b+28>>2]|0)!=0;g=b+20|0;if(h){l=b+124|0;m=c[b+120>>2]|0}else{l=g;m=d}i=b+12|0;e=b+16|0;gh[c[f>>2]&15](b,m,j,c[i>>2]|0,c[e>>2]|0,c[b>>2]|0,c[b+4>>2]|0,c[l>>2]|0,k);if(!h){return}gk[c[b+52>>2]&63](d,c[b+120>>2]|0,c[i>>2]|0,c[e>>2]|0,c[g>>2]|0,c[b+124>>2]|0);return}}function iQ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c=(e|0)>-1?e:-e|0;g=(f|0)>-1?f:-f|0;h=(g|0)<(c|0)?g:c;if((d|0)>0){i=b;j=a;k=0}else{return}while(1){s1(j|0,i|0,h)|0;a=k+1|0;if((a|0)<(d|0)){i=i+f|0;j=j+e|0;k=a}else{break}}return}function iR(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=a+112|0;g=c[f>>2]|0;if((g|0)<=0){return}h=a+64|0;i=a+108|0;j=e>>2;e=a+116|0;k=a+76|0;l=a+68|0;m=a+72|0;n=0;o=c[a+104>>2]|0;a=d;d=c[i>>2]|0;p=g;while(1){if((d|0)>0){g=0;q=c[h>>2]|0;while(1){r=c[(c[k>>2]|0)+(g<<2)>>2]|0;s=c[l>>2]|0;if((s|0)==0){t=0;u=0;v=0;w=0;x=0;y=0;z=0;A=0}else{B=0;C=0;D=0;E=0;F=0;while(1){G=c[a+(E+r<<2)>>2]|0;H=b[q+(E<<1)>>1]|0;I=((ag(G>>>17&32640,H)|0)>>>16)+(F&65535)|0;J=((ag(G>>>9&32640,H)|0)>>>16)+(B&65535)|0;K=((ag(G>>>1&32640,H)|0)>>>16)+(C&65535)|0;L=((ag(G<<7&32640,H)|0)>>>16)+(D&65535)|0;H=E+1|0;if(H>>>0<s>>>0){B=J&65535;C=K&65535;D=L&65535;E=H;F=I&65535}else{break}}F=K&65535;t=J&65535;u=0;v=0<<16|F>>>16;w=F<<16|0>>>16;x=0;y=L&65535;z=I<<16|0>>>16;A=0<<16|0>>>16}F=o+(g<<3)|0;c[F>>2]=y|A|w|u;c[F+4>>2]=x|z|v|t;F=g+1|0;M=c[i>>2]|0;if((F|0)<(M|0)){g=F;q=q+(c[m>>2]<<1)|0}else{break}}N=M;O=c[f>>2]|0}else{N=d;O=p}q=n+1|0;if((q|0)<(O|0)){n=q;o=o+(c[e>>2]>>3<<3)|0;a=a+(j<<2)|0;d=N;p=O}else{break}}return}function iS(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;a=((g<<15|0)/(e|0)|0)-32768|0;k=(g<<16|0)/(e|0)|0;g=((h<<15|0)/(f|0)|0)-32768|0;l=(h<<16|0)/(f|0)|0;h=(a|0)<0?0:a;a=d;if((f|0)<=0){return}d=j>>2;j=i>>2;if((e|0)<=0){return}i=(g|0)<0?0:g;g=b;b=0;while(1){m=ag(i>>16,d)|0;n=h;o=0;while(1){c[g+(o<<2)>>2]=c[a+((n>>16)+m<<2)>>2];p=o+1|0;if((p|0)<(e|0)){n=n+k|0;o=p}else{break}}o=b+1|0;if((o|0)<(f|0)){i=i+l|0;g=g+(j<<2)|0;b=o}else{break}}return}function iT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=a+4|0;f=d-(c[e>>2]|0)|0;if((b|0)<=0){return}d=a+12|0;g=a|0;h=a+8|0;a=0;do{i=(c[d>>2]|0)+(a<<2)|0;j=c[i>>2]|0;k=j-f|0;l=-j|0;do{if((k|0)>0){c[i>>2]=f;m=c[g>>2]|0;n=ag(c[h>>2]|0,a)|0;o=m+(n<<1)|0;p=c[e>>2]|0;if((k|0)>(p|0)){s_(o|0,0,p<<1|0);break}else{q=o;s5(m+(n+k<<1)|0,q|0,p-k<<1|0);s_(q|0,0,k<<1|0);break}}}while(0);do{if((j|0)<0){k=(c[d>>2]|0)+(a<<2)|0;c[k>>2]=(c[k>>2]|0)-j;k=c[g>>2]|0;i=ag(c[h>>2]|0,a)|0;q=c[e>>2]|0;p=k+(i<<1)|0;if((q|0)<(l|0)){s_(p|0,0,q<<1|0);break}else{s5(p|0,k+(i-j<<1)|0,q+j<<1|0);s_(k+(i+j+(c[e>>2]|0)<<1)|0,0,l<<1|0);break}}}while(0);a=a+1|0;}while((a|0)<(b|0));return}function iU(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a5=0;f=i;i=i+1824|0;h=f|0;j=f+8|0;k=f+1032|0;l=f+1040|0;m=f+1048|0;n=f+1112|0;o=f+1176|0;p=f+1184|0;q=f+1248|0;r=f+1312|0;s=f+1376|0;u=f+1440|0;v=f+1504|0;w=f+1568|0;x=f+1632|0;y=f+1696|0;z=f+1760|0;s_(e|0,0,109528);c[e>>2]=0;A=d+4|0;B=A;while(1){C=c[B>>2]|0;if((C|0)==0){break}if((da(46400,c[C+4>>2]|0)|0)==0){D=4027;break}else{B=C+12|0}}do{if((D|0)==4027){c[(ep()|0)>>2]=0;B=a4(c[C+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}if((B|0)==0){E=c[135158]|0;F=(E|0)!=0?E:c[t>>2]|0;be(36904,55,1,F|0)|0;F=c[135158]|0;E=(F|0)!=0?F:c[t>>2]|0;a7(E|0)|0;G=0;i=f;return G|0}E=B>>>0<16?B:16;B=e+72|0;c[B>>2]=E;F=m|0;H=n|0;I=p|0;J=q|0;K=r|0;L=s|0;M=u|0;N=v|0;O=w|0;P=x|0;Q=y|0;R=z|0;L5665:do{if((E|0)!=0){S=0;while(1){b5(F|0,64,29672,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;L5668:do{if(hA(d,F,e+76+(S*4148|0)|0)|0){b5(H|0,64,29256,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;a[o]=0;if(hB(d,H,o)|0){c[e+76+(S*4148|0)+4136>>2]=(a[o]&1)!=0?1:2}else{c[e+76+(S*4148|0)+4136>>2]=0}b5(I|0,64,28472,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;U=A;while(1){V=c[U>>2]|0;if((V|0)==0){break}if((da(I|0,c[V+4>>2]|0)|0)==0){D=4040;break}else{U=V+12|0}}do{if((D|0)==4040){D=0;U=64;W=0;X=J;Y=c[V+8>>2]|0;while(1){Z=U-1|0;if((Z|0)==0){D=4043;break}_=a[Y]|0;a[X]=_;if(_<<24>>24==0){$=W;break}else{U=Z;W=W+1|0;X=X+1|0;Y=Y+1|0}}do{if((D|0)==4043){D=0;a[X]=0;if((a[Y]|0)==0){$=W;break}else{aa=Y;ab=W}while(1){U=aa+1|0;Z=ab+1|0;if((a[U]|0)==0){$=Z;break}else{aa=U;ab=Z}}}}while(0);if($>>>0>=64){break}c[e+76+(S*4148|0)+4140>>2]=iZ(J)|0}}while(0);s_(K|0,0,64);b5(L|0,64,28016,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;W=A;while(1){ac=c[W>>2]|0;if((ac|0)==0){break}if((da(L|0,c[ac+4>>2]|0)|0)==0){D=4050;break}else{W=ac+12|0}}do{if((D|0)==4050){D=0;W=64;Y=0;X=K;Z=c[ac+8>>2]|0;while(1){U=W-1|0;if((U|0)==0){D=4053;break}_=a[Z]|0;a[X]=_;if(_<<24>>24==0){ad=Y;break}else{W=U;Y=Y+1|0;X=X+1|0;Z=Z+1|0}}do{if((D|0)==4053){D=0;a[X]=0;if((a[Z]|0)==0){ad=Y;break}else{ae=Z;af=Y}while(1){W=ae+1|0;U=af+1|0;if((a[W]|0)==0){ad=U;break}else{ae=W;af=U}}}}while(0);if(ad>>>0>=64){break}c[e+76+(S*4148|0)+4144>>2]=a4(K|0,0,0)|0}}while(0);s_(M|0,0,64);s_(N|0,0,64);s_(O|0,0,64);b5(P|0,64,46704,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;Y=A;while(1){ag=c[Y>>2]|0;if((ag|0)==0){break}if((da(P|0,c[ag+4>>2]|0)|0)==0){D=4060;break}else{Y=ag+12|0}}L5708:do{if((D|0)==4060){D=0;Y=64;Z=M;X=c[ag+8>>2]|0;while(1){U=Y-1|0;if((U|0)==0){break}W=a[X]|0;a[Z]=W;if(W<<24>>24==0){break L5708}else{Y=U;Z=Z+1|0;X=X+1|0}}a[Z]=0;if((a[X]|0)==0){break}else{ah=X}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);b5(P|0,64,46616,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;X=A;while(1){ai=c[X>>2]|0;if((ai|0)==0){break}if((da(P|0,c[ai+4>>2]|0)|0)==0){D=4068;break}else{X=ai+12|0}}L5720:do{if((D|0)==4068){D=0;X=64;Z=N;Y=c[ai+8>>2]|0;while(1){U=X-1|0;if((U|0)==0){break}W=a[Y]|0;a[Z]=W;if(W<<24>>24==0){break L5720}else{X=U;Z=Z+1|0;Y=Y+1|0}}a[Z]=0;if((a[Y]|0)==0){break}else{aj=Y}do{aj=aj+1|0;}while((a[aj]|0)!=0)}}while(0);b5(P|0,64,46496,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;Y=A;while(1){ak=c[Y>>2]|0;if((ak|0)==0){break}if((da(P|0,c[ak+4>>2]|0)|0)==0){D=4076;break}else{Y=ak+12|0}}L5732:do{if((D|0)==4076){D=0;Y=64;Z=O;X=c[ak+8>>2]|0;while(1){U=Y-1|0;if((U|0)==0){break}W=a[X]|0;a[Z]=W;if(W<<24>>24==0){break L5732}else{Y=U;Z=Z+1|0;X=X+1|0}}a[Z]=0;if((a[X]|0)==0){break}else{al=X}do{al=al+1|0;}while((a[al]|0)!=0)}}while(0);L5741:do{if((a[M]|0)==0){if((a[N]|0)!=0){break}if((a[O]|0)==0){am=1;break L5668}}else{X=64;Z=N;Y=M;while(1){U=X-1|0;if((U|0)==0){D=4086;break}W=a[Y]|0;a[Z]=W;if(W<<24>>24==0){an=64;ao=O;ap=M;break}else{X=U;Z=Z+1|0;Y=Y+1|0}}do{if((D|0)==4086){D=0;a[Z]=0;if((a[Y]|0)==0){an=64;ao=O;ap=M;break}else{aq=Y}while(1){X=aq+1|0;if((a[X]|0)==0){an=64;ao=O;ap=M;break}else{aq=X}}}}while(0);while(1){Y=an-1|0;if((Y|0)==0){break}Z=a[ap]|0;a[ao]=Z;if(Z<<24>>24==0){break L5741}else{an=Y;ao=ao+1|0;ap=ap+1|0}}a[ao]=0;if((a[ap]|0)==0){break}else{ar=ap}do{ar=ar+1|0;}while((a[ar]|0)!=0)}}while(0);a[e+76+(S*4148|0)+4104|0]=1;Y=e+76+(S*4148|0)+4108|0;c[Y>>2]=0;Z=e+76+(S*4148|0)+4112|0;c[Z>>2]=0;X=e+76+(S*4148|0)+4116|0;g[X>>2]=1.0;U=e+76+(S*4148|0)+4120|0;g[U>>2]=1.0;b5(R|0,64,19672,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;hB(d,R,e+76+(S*4148|0)+4132|0)|0;do{if((a[N]|0)!=0){if((da(N|0,18608)|0)==0){c[Y>>2]=0;break}if((da(N|0,18408)|0)==0){c[Y>>2]=2;break}if((da(N|0,18232)|0)==0){c[Y>>2]=1;break}else{W=c[135158]|0;_=(W|0)!=0?W:c[t>>2]|0;be(46352,40,1,_|0)|0;_=c[135158]|0;W=(_|0)!=0?_:c[t>>2]|0;a7(W|0)|0;am=0;break L5668}}}while(0);do{if((a[O]|0)!=0){if((da(O|0,18608)|0)==0){c[Z>>2]=0;break}if((da(O|0,18408)|0)==0){c[Z>>2]=2;break}if((da(O|0,18232)|0)==0){c[Z>>2]=1;break}else{W=c[135158]|0;_=(W|0)!=0?W:c[t>>2]|0;be(46352,40,1,_|0)|0;_=c[135158]|0;W=(_|0)!=0?_:c[t>>2]|0;a7(W|0)|0;am=0;break L5668}}}while(0);W=(c[Y>>2]|0)==1;b5(Q|0,64,46288,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;L5782:do{if(W){_=A;while(1){as=c[_>>2]|0;if((as|0)==0){break}if((da(Q|0,c[as+4>>2]|0)|0)==0){D=4111;break}else{_=as+12|0}}do{if((D|0)==4111){D=0;c[(ep()|0)>>2]=0;_=bb(c[as+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4124>>2]=_;break L5782}}while(0);b5(Q|0,64,46232,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;_=A;while(1){at=c[_>>2]|0;if((at|0)==0){break L5782}if((da(Q|0,c[at+4>>2]|0)|0)==0){break}else{_=at+12|0}}c[(ep()|0)>>2]=0;_=bb(c[at+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4124>>2]=_}else{_=A;while(1){au=c[_>>2]|0;if((au|0)==0){break}if((da(Q|0,c[au+4>>2]|0)|0)==0){D=4120;break}else{_=au+12|0}}if((D|0)==4120){D=0;g[X>>2]=+sY(c[au+8>>2]|0,0);break}b5(Q|0,64,46232,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;_=A;while(1){av=c[_>>2]|0;if((av|0)==0){break L5782}if((da(Q|0,c[av+4>>2]|0)|0)==0){break}else{_=av+12|0}}g[X>>2]=+sY(c[av+8>>2]|0,0)}}while(0);X=(c[Z>>2]|0)==1;b5(Q|0,64,46288,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;if(X){aw=A}else{X=A;while(1){ax=c[X>>2]|0;if((ax|0)==0){break}if((da(Q|0,c[ax+4>>2]|0)|0)==0){D=4137;break}else{X=ax+12|0}}if((D|0)==4137){D=0;g[U>>2]=+sY(c[ax+8>>2]|0,0);am=1;break}b5(Q|0,64,46192,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;X=A;while(1){ay=c[X>>2]|0;if((ay|0)==0){am=1;break L5668}if((da(Q|0,c[ay+4>>2]|0)|0)==0){break}else{X=ay+12|0}}g[U>>2]=+sY(c[ay+8>>2]|0,0);am=1;break}while(1){az=c[aw>>2]|0;if((az|0)==0){break}if((da(Q|0,c[az+4>>2]|0)|0)==0){D=4128;break}else{aw=az+12|0}}do{if((D|0)==4128){D=0;c[(ep()|0)>>2]=0;U=bb(c[az+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4128>>2]=U;am=1;break L5668}}while(0);b5(Q|0,64,46192,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;U=A;while(1){aA=c[U>>2]|0;if((aA|0)==0){am=1;break L5668}if((da(Q|0,c[aA+4>>2]|0)|0)==0){break}else{U=aA+12|0}}c[(ep()|0)>>2]=0;U=bb(c[aA+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){am=1;break}c[e+76+(S*4148|0)+4128>>2]=U;am=1}else{U=c[135158]|0;eQ(((U|0)!=0?U:c[t>>2]|0)|0,46784,(T=i,i=i+8|0,c[T>>2]=F,T)|0)|0;i=T;U=c[135158]|0;a7(((U|0)!=0?U:c[t>>2]|0)|0)|0;am=0}}while(0);if(!am){G=0;break}S=S+1|0;if(S>>>0>=(c[B>>2]|0)>>>0){break L5665}}i=f;return G|0}}while(0);B=j|0;Q=A;while(1){aB=c[Q>>2]|0;if((aB|0)==0){break}if((da(27304,c[aB+4>>2]|0)|0)==0){D=4147;break}else{Q=aB+12|0}}L5836:do{if((D|0)==4147){Q=1024;O=0;N=B;R=c[aB+8>>2]|0;while(1){M=Q-1|0;if((M|0)==0){D=4150;break}P=a[R]|0;a[N]=P;if(P<<24>>24==0){aC=O;break}else{Q=M;O=O+1|0;N=N+1|0;R=R+1|0}}do{if((D|0)==4150){a[N]=0;if((a[R]|0)==0){aC=O;break}else{aD=R;aE=O}while(1){Q=aD+1|0;M=aE+1|0;if((a[Q]|0)==0){aC=M;break}else{aD=Q;aE=M}}}}while(0);if(aC>>>0>=1024){break}O=eM(B|0,27664,k|0)|0;if((O|0)==0){break}R=e+66444|0;N=O;L5848:while(1){O=c[R>>2]|0;if(O>>>0>=8){break L5836}M=e+66448+(O*4168|0)+64|0;O=A;while(1){aF=c[O>>2]|0;if((aF|0)==0){break L5848}if((da(N|0,c[aF+4>>2]|0)|0)==0){break}else{O=aF+12|0}}O=4096;Q=0;P=M;E=c[aF+8>>2]|0;while(1){S=O-1|0;if((S|0)==0){D=4162;break}U=a[E]|0;a[P]=U;if(U<<24>>24==0){aG=Q;break}else{O=S;Q=Q+1|0;P=P+1|0;E=E+1|0}}do{if((D|0)==4162){D=0;a[P]=0;if((a[E]|0)==0){aG=Q;break}else{aH=E;aI=Q}while(1){O=aH+1|0;M=aI+1|0;if((a[O]|0)==0){aG=M;break}else{aH=O;aI=M}}}}while(0);if(aG>>>0>=4096){break}Q=64;E=e+66448+((c[R>>2]|0)*4168|0)|0;P=N;while(1){M=Q-1|0;if((M|0)==0){D=4169;break}O=a[P]|0;a[E]=O;if(O<<24>>24==0){break}else{Q=M;E=E+1|0;P=P+1|0}}do{if((D|0)==4169){D=0;a[E]=0;if((a[P]|0)==0){break}else{aJ=P}do{aJ=aJ+1|0;}while((a[aJ]|0)!=0)}}while(0);b5(F|0,64,26904,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;a[l]=0;if(hB(d,F,l)|0){c[e+66448+((c[R>>2]|0)*4168|0)+4160>>2]=(a[l]&1)!=0?1:2}else{c[e+66448+((c[R>>2]|0)*4168|0)+4160>>2]=0}b5(H|0,64,26488,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;P=A;while(1){aK=c[P>>2]|0;if((aK|0)==0){break}if((da(H|0,c[aK+4>>2]|0)|0)==0){D=4177;break}else{P=aK+12|0}}do{if((D|0)==4177){D=0;P=64;E=0;Q=I;M=c[aK+8>>2]|0;while(1){O=P-1|0;if((O|0)==0){D=4180;break}S=a[M]|0;a[Q]=S;if(S<<24>>24==0){aL=E;break}else{P=O;E=E+1|0;Q=Q+1|0;M=M+1|0}}do{if((D|0)==4180){D=0;a[Q]=0;if((a[M]|0)==0){aL=E;break}else{aM=M;aN=E}while(1){P=aM+1|0;O=aN+1|0;if((a[P]|0)==0){aL=O;break}else{aM=P;aN=O}}}}while(0);if(aL>>>0>=64){break}E=iZ(I)|0;c[e+66448+((c[R>>2]|0)*4168|0)+4164>>2]=E}}while(0);c[R>>2]=(c[R>>2]|0)+1;E=eM(0,27664,k|0)|0;if((E|0)==0){break L5836}else{N=E}}R=c[135158]|0;eQ(((R|0)!=0?R:c[t>>2]|0)|0,47272,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;R=c[135158]|0;a7(((R|0)!=0?R:c[t>>2]|0)|0)|0;G=0;i=f;return G|0}}while(0);R=A;while(1){aO=c[R>>2]|0;if((aO|0)==0){G=1;D=4267;break}if((da(25352,c[aO+4>>2]|0)|0)==0){break}else{R=aO+12|0}}if((D|0)==4267){i=f;return G|0}R=1024;E=0;M=B;Q=c[aO+8>>2]|0;while(1){O=R-1|0;if((O|0)==0){D=4191;break}P=a[Q]|0;a[M]=P;if(P<<24>>24==0){aP=E;break}else{R=O;E=E+1|0;M=M+1|0;Q=Q+1|0}}do{if((D|0)==4191){a[M]=0;if((a[Q]|0)==0){aP=E;break}else{aQ=Q;aR=E}while(1){R=aQ+1|0;O=aR+1|0;if((a[R]|0)==0){aP=O;break}else{aQ=R;aR=O}}}}while(0);if(aP>>>0>=1024){G=1;i=f;return G|0}E=eM(B|0,27664,h|0)|0;L5911:do{if((E|0)!=0){Q=e+99792|0;M=E;L5913:while(1){N=c[Q>>2]|0;if(N>>>0>=64){break L5911}O=64;R=e+99796+(N*80|0)|0;P=M;while(1){S=O-1|0;if((S|0)==0){D=4200;break}U=a[P]|0;a[R]=U;if(U<<24>>24==0){break}else{O=S;R=R+1|0;P=P+1|0}}do{if((D|0)==4200){D=0;a[R]=0;if((a[P]|0)==0){break}else{aS=P}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);b5(F|0,64,23224,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;b5(H|0,64,23016,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;b5(I|0,64,22688,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;b5(J|0,64,22472,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;b5(K|0,64,22192,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;P=A;while(1){aT=c[P>>2]|0;if((aT|0)==0){D=4211;break L5913}if((da(F|0,c[aT+4>>2]|0)|0)==0){break}else{P=aT+12|0}}P=64;R=0;O=L;S=c[aT+8>>2]|0;while(1){U=P-1|0;if((U|0)==0){D=4208;break}X=a[S]|0;a[O]=X;if(X<<24>>24==0){aU=R;break}else{P=U;R=R+1|0;O=O+1|0;S=S+1|0}}do{if((D|0)==4208){D=0;a[O]=0;if((a[S]|0)==0){aU=R;break}else{aV=S;aW=R}while(1){P=aV+1|0;U=aW+1|0;if((a[P]|0)==0){aU=U;break}else{aV=P;aW=U}}}}while(0);if(aU>>>0>=64){D=4211;break}do{if((da(L|0,22048)|0)==0){c[e+99796+(N*80|0)+68>>2]=0;aX=A;D=4225}else{if((da(L|0,21456)|0)==0){c[e+99796+(N*80|0)+68>>2]=2;aX=A;D=4225;break}if((da(L|0,20816)|0)==0){c[e+99796+(N*80|0)+68>>2]=3;aX=A;D=4225;break}if((da(L|0,20432)|0)==0){c[e+99796+(N*80|0)+68>>2]=1;aX=A;D=4225;break}if((da(L|0,19992)|0)==0){c[e+99796+(N*80|0)+68>>2]=4;aX=A;D=4225;break}if((da(L|0,19840)|0)!=0){D=4223;break L5913}c[e+99796+(N*80|0)+68>>2]=5;aY=A}}while(0);L5953:do{if((D|0)==4225){while(1){D=0;aZ=c[aX>>2]|0;if((aZ|0)==0){a_=A;break}if((da(I|0,c[aZ+4>>2]|0)|0)==0){D=4227;break}else{aX=aZ+12|0;D=4225}}do{if((D|0)==4227){D=0;c[(ep()|0)>>2]=0;R=a4(c[aZ+8>>2]|0,0,0)|0;if((c[(ep()|0)>>2]|0)!=0){a_=A;break}if((R|0)==1){c[e+99796+(N*80|0)+72>>2]=2;aY=A;break L5953}else if((R|0)==2){c[e+99796+(N*80|0)+72>>2]=3;aY=A;break L5953}else{D=4231;break L5913}}}while(0);while(1){a$=c[a_>>2]|0;if((a$|0)==0){D=4236;break L5913}if((da(H|0,c[a$+4>>2]|0)|0)==0){break}else{a_=a$+12|0}}c[(ep()|0)>>2]=0;R=a4(c[a$+8>>2]|0,0,16)|0;if((c[(ep()|0)>>2]|0)!=0){D=4236;break L5913}c[e+99796+(N*80|0)+72>>2]=1;c[e+99796+(N*80|0)+64>>2]=R;aY=A}}while(0);while(1){a0=c[aY>>2]|0;if((a0|0)==0){a1=A;break}if((da(J|0,c[a0+4>>2]|0)|0)==0){D=4239;break}else{aY=a0+12|0}}do{if((D|0)==4239){D=0;c[(ep()|0)>>2]=0;R=a4(c[a0+8>>2]|0,0,16)|0;if((c[(ep()|0)>>2]|0)!=0){a1=A;break}b[e+99796+(N*80|0)+76>>1]=R&65535;a1=A}}while(0);while(1){a2=c[a1>>2]|0;if((a2|0)==0){break}if((da(K|0,c[a2+4>>2]|0)|0)==0){D=4243;break}else{a1=a2+12|0}}do{if((D|0)==4243){D=0;c[(ep()|0)>>2]=0;R=a4(c[a2+8>>2]|0,0,16)|0;if((c[(ep()|0)>>2]|0)!=0){break}b[e+99796+(N*80|0)+78>>1]=R&65535}}while(0);c[Q>>2]=(c[Q>>2]|0)+1;M=eM(0,27664,h|0)|0;if((M|0)==0){break L5911}}if((D|0)==4211){M=c[135158]|0;Q=(M|0)!=0?M:c[t>>2]|0;be(47896,54,1,Q|0)|0;Q=c[135158]|0;M=(Q|0)!=0?Q:c[t>>2]|0;a7(M|0)|0;G=0;i=f;return G|0}else if((D|0)==4223){M=c[135158]|0;be(47752,39,1,((M|0)!=0?M:c[t>>2]|0)|0)|0;M=c[135158]|0;a7(((M|0)!=0?M:c[t>>2]|0)|0)|0;G=0;i=f;return G|0}else if((D|0)==4236){M=c[135158]|0;be(47560,54,1,((M|0)!=0?M:c[t>>2]|0)|0)|0;M=c[135158]|0;a7(((M|0)!=0?M:c[t>>2]|0)|0)|0;G=0;i=f;return G|0}else if((D|0)==4231){M=c[135158]|0;be(13936,52,1,((M|0)!=0?M:c[t>>2]|0)|0)|0;M=c[135158]|0;a7(((M|0)!=0?M:c[t>>2]|0)|0)|0;G=0;i=f;return G|0}}}while(0);hA(d,26176,e+104916|0)|0;K=e+109016|0;J=A;while(1){a3=c[J>>2]|0;if((a3|0)==0){G=1;D=4260;break}if((da(25752,c[a3+4>>2]|0)|0)==0){break}else{J=a3+12|0}}if((D|0)==4260){i=f;return G|0}J=512;H=K;I=c[a3+8>>2]|0;while(1){L=J-1|0;if((L|0)==0){break}F=a[I]|0;a[H]=F;if(F<<24>>24==0){G=1;D=4261;break}else{J=L;H=H+1|0;I=I+1|0}}if((D|0)==4261){i=f;return G|0}a[H]=0;if((a[I]|0)==0){G=1;i=f;return G|0}else{a5=I}while(1){J=a5+1|0;if((a[J]|0)==0){G=1;break}else{a5=J}}i=f;return G|0}}while(0);a5=c[135158]|0;be(49312,50,1,((a5|0)!=0?a5:c[t>>2]|0)|0)|0;a5=c[135158]|0;a7(((a5|0)!=0?a5:c[t>>2]|0)|0)|0;G=0;i=f;return G|0}function iV(){return 547872|0}function iW(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+8200|0;g=f|0;h=f+4104|0;c[g>>2]=b;j=f+8|0;k=e+8|0;while(1){l=c[k>>2]|0;if((l|0)==0){break}if((da(41296,c[l>>2]|0)|0)==0){m=4273;break}else{k=l+8|0}}do{if((m|0)==4273){k=c[l+4>>2]|0;if((k|0)==0){break}else{n=4096;o=0;p=j;q=k}while(1){k=n-1|0;if((k|0)==0){m=4277;break}e=a[q]|0;a[p]=e;if(e<<24>>24==0){r=o;break}else{n=k;o=o+1|0;p=p+1|0;q=q+1|0}}do{if((m|0)==4277){a[p]=0;if((a[q]|0)==0){r=o;break}else{s=q;u=o}while(1){k=s+1|0;e=u+1|0;if((a[k]|0)==0){r=e;break}else{s=k;u=e}}}}while(0);if(r>>>0>=4096){i=f;return b|0}sS(b);c[g>>2]=0;e=h|0;ht(e,d,j);if((a[383584]&1)==0){v=g8(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}k=c[135158]|0;eQ(((k|0)!=0?k:c[t>>2]|0)|0,48088,(k=i,i=i+8|0,c[k>>2]=e,k)|0)|0;i=k;k=c[135158]|0;a7(((k|0)!=0?k:c[t>>2]|0)|0)|0;v=g8(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}}while(0);a[j]=0;i=f;return b|0}function iX(a,b){a=a|0;b=b|0;var c=0,d=0;if((a|0)==0){c=b;return c|0}d=cD(a|0,46)|0;a=(d|0)==0?547872:d+1|0;if((da(a|0,28888)|0)==0){c=0;return c|0}if((da(a|0,48792)|0)==0){c=0;return c|0}if((da(a|0,18888)|0)==0){c=2;return c|0}if((da(a|0,48240)|0)==0){c=2;return c|0}else{return((da(a|0,40968)|0)==0?2:b)|0}return 0}function iY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+4096|0;f=e|0;g=b+72|0;h=c[g>>2]|0;if((h|0)!=0){j=f|0;k=0;l=h;while(1){h=b+76+(k*4148|0)|0;if((a[h]|0)==0){m=l}else{n=4096;o=j;p=h;while(1){q=n-1|0;if((q|0)==0){r=4307;break}s=a[p]|0;a[o]=s;if(s<<24>>24==0){break}else{n=q;o=o+1|0;p=p+1|0}}do{if((r|0)==4307){r=0;a[o]=0;if((a[p]|0)==0){break}else{t=p}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);ht(h,d,j);m=c[g>>2]|0}p=k+1|0;if(p>>>0<m>>>0){k=p;l=m}else{break}}}m=b+66444|0;if((c[m>>2]|0)!=0){l=f|0;k=0;do{g=b+66448+(k*4168|0)+64|0;j=4096;t=l;p=g;while(1){o=j-1|0;if((o|0)==0){r=4314;break}n=a[p]|0;a[t]=n;if(n<<24>>24==0){break}else{j=o;t=t+1|0;p=p+1|0}}do{if((r|0)==4314){r=0;a[t]=0;if((a[p]|0)==0){break}else{u=p}do{u=u+1|0;}while((a[u]|0)!=0)}}while(0);ht(g,d,l);k=k+1|0;}while(k>>>0<(c[m>>2]|0)>>>0)}m=b+104916|0;if((a[m]|0)==0){i=e;return}b=f|0;f=4096;k=b;l=m;while(1){u=f-1|0;if((u|0)==0){r=4321;break}p=a[l]|0;a[k]=p;if(p<<24>>24==0){break}else{f=u;k=k+1|0;l=l+1|0}}do{if((r|0)==4321){a[k]=0;if((a[l]|0)==0){break}else{v=l}do{v=v+1|0;}while((a[v]|0)!=0)}}while(0);ht(m,d,b);i=e;return}function iZ(a){a=a|0;var b=0,d=0,e=0;b=i;if((da(a|0,18032)|0)==0){d=0;i=b;return d|0}if((da(a|0,17880)|0)==0){d=1;i=b;return d|0}if((da(a|0,17696)|0)==0){d=2;i=b;return d|0}if((da(a|0,17488)|0)==0){d=3;i=b;return d|0}e=c[135158]|0;eQ(((e|0)!=0?e:c[t>>2]|0)|0,46968,(e=i,i=i+8|0,c[e>>2]=a,e)|0)|0;i=e;e=c[135158]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;d=0;i=b;return d|0}function i_(b,e){b=b|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=sR(1032)|0;if((b|0)==0){f=0;return f|0}if((c[b-4>>2]&3|0)!=0){s_(b|0,0,1032)}g=b;h=~~+bZ(+(e/10.0));i=b;j=(h|0)==0?1:h;c[i>>2]=j;h=sR(ag(j*12800|0,j)|0)|0;k=b+1028|0;c[k>>2]=h;if((h|0)==0){sS(b);f=0;return f|0}else{l=0;m=j;n=h}while(1){h=ag(ag(m*50|0,m)|0,l)|0;c[g+4+(l<<2)>>2]=n+h;j=l*7|0;o=c[i>>2]|0;p=0;q=o;while(1){r=p*5|0;s=0;t=q;u=q;while(1){v=s+r|0;w=((1<<(v&7)&(d[8408+((v>>>3)+j)|0]|0)|0)!=0)<<31>>31;if((t|0)==0){x=0;y=u}else{v=0;z=u;while(1){if((z|0)==0){A=0}else{B=v+h|0;C=0;D=z;while(1){a[n+(B+(ag((((ag(D,p)|0)+C|0)*5|0)+s|0,D)|0))|0]=w;E=C+1|0;if(E>>>0<o>>>0){C=E;D=o}else{A=o;break}}}D=v+1|0;if(D>>>0<A>>>0){v=D;z=A}else{x=A;y=A;break}}}z=s+1|0;if(z>>>0<5){s=z;t=x;u=y}else{break}}u=p+1|0;if(u>>>0<10){p=u;q=y}else{break}}q=l+1|0;if(q>>>0>=256){f=b;break}l=q;m=o;n=c[k>>2]|0}return f|0}function i$(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=e|0;c[f>>2]=0;e=sZ(d|0)|0;if((e|0)==0){return}g=b+4|0;h=b;b=0;i=0;j=0;while(1){k=sR(52)|0;if((k|0)==0){l=4369;break}if((c[k-4>>2]&3|0)!=0){s_(k|0,0,52)}m=k;c[k>>2]=c[g+(a[d+i|0]<<2)>>2];n=c[h>>2]|0;o=n*5|0;c[k+4>>2]=o;p=n*10|0;c[k+8>>2]=p;c[k+12>>2]=o;c[k+32>>2]=o;c[k+36>>2]=p;c[k+40>>2]=0;c[k+44>>2]=p;c[k+24>>2]=b;c[k+28>>2]=0;c[k+48>>2]=0;if((i|0)==0){c[f>>2]=m;q=c[h>>2]|0}else{c[j+48>>2]=m;q=n}n=i+1|0;if(n>>>0<e>>>0){b=(q*6|0)+b|0;i=n;j=m}else{l=4370;break}}if((l|0)==4370){return}else if((l|0)==4369){return}}function i0(a,b){a=a|0;b=b|0;var d=0;a=b|0;b=c[a>>2]|0;if((b|0)==0){c[a>>2]=0;return}else{d=b}while(1){b=c[d+48>>2]|0;sS(d);if((b|0)==0){break}else{d=b}}c[a>>2]=0;return}function i1(a){a=a|0;sS(c[a+1028>>2]|0);sS(a);return}function i2(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0;h=i;i=i+1912|0;j=h|0;k=h+16|0;l=h+784|0;m=h+792|0;n=h+840|0;o=h+856|0;p=h+1880|0;q=h+1888|0;r=h+1904|0;if((bJ(b|0,44920)|0)!=0){c[r>>2]=0;if((g8(b,r)|0)<0){s=c[135158]|0;u=(s|0)!=0?s:c[t>>2]|0;eQ(u|0,28896,(v=i,i=i+8|0,c[v>>2]=b,v)|0)|0;i=v;u=c[135158]|0;s=(u|0)!=0?u:c[t>>2]|0;a7(s|0)|0;w=0;i=h;return w|0}s=c[r>>2]|0;if((a[s+2|0]|0)!=2){r=c[135158]|0;u=(r|0)!=0?r:c[t>>2]|0;be(24416,56,1,u|0)|0;u=c[135158]|0;r=(u|0)!=0?u:c[t>>2]|0;a7(r|0)|0;sS(s);w=0;i=h;return w|0}r=a[s+16|0]|0;u=d[s+13|0]<<8|d[s+12|0];x=d[s+15|0]<<8|d[s+14|0];if((a[383584]&1)!=0){y=r&255;z=c[135158]|0;A=(z|0)!=0?z:c[t>>2]|0;eQ(A|0,21112,(v=i,i=i+24|0,c[v>>2]=u,c[v+8>>2]=x,c[v+16>>2]=y,v)|0)|0;i=v;y=c[135158]|0;A=(y|0)!=0?y:c[t>>2]|0;a7(A|0)|0}A=ag(x,u)|0;y=sR(A<<2)|0;z=y;B=e+8|0;c[B>>2]=z;c[e>>2]=u;c[e+4>>2]=x;if((y|0)==0){y=c[135158]|0;x=(y|0)!=0?y:c[t>>2]|0;be(18832,52,1,x|0)|0;x=c[135158]|0;y=(x|0)!=0?x:c[t>>2]|0;a7(y|0)|0;sS(s);w=0;i=h;return w|0}L6176:do{if((r<<24>>24|0)==32){if((A|0)==0){break}else{C=0;D=z}while(1){y=C<<2;c[D+(C<<2)>>2]=d[s+((y|1)+18)|0]<<8|d[s+(y+18)|0]<<g|d[s+((y|2)+18)|0]<<f|d[s+((y|3)+18)|0]<<24;y=C+1|0;if(y>>>0>=A>>>0){break L6176}C=y;D=c[B>>2]|0}}else if((r<<24>>24|0)==24){if((A|0)==0){break}else{E=0;F=z}while(1){y=E*3|0;c[F+(E<<2)>>2]=d[s+(y+18)|0]<<g|d[s+(y+19)|0]<<8|d[s+(y+20)|0]<<f|-16777216;y=E+1|0;if(y>>>0>=A>>>0){break L6176}E=y;F=c[B>>2]|0}}else{y=c[135158]|0;be(16656,88,1,((y|0)!=0?y:c[t>>2]|0)|0)|0;y=c[135158]|0;a7(((y|0)!=0?y:c[t>>2]|0)|0)|0;sS(s);sS(c[B>>2]|0);c[B>>2]=0;w=0;i=h;return w|0}}while(0);sS(s);w=1;i=h;return w|0}if((bJ(b|0,48944)|0)==0){w=0;i=h;return w|0}if((a[383584]&1)!=0){s=c[135158]|0;B=(s|0)!=0?s:c[t>>2]|0;be(36696,38,1,B|0)|0;B=c[135158]|0;s=(B|0)!=0?B:c[t>>2]|0;a7(s|0)|0}s=e+8|0;B=e|0;F=e+4|0;e=n;E=p|0;p=q;c[s>>2]=0;c[B>>2]=0;c[F>>2]=0;A=dz(b|0,42504)|0;if((A|0)==0){w=0;i=h;return w|0}e3(A|0,0,2)|0;b=cx(A|0)|0;fb(A|0);s_(m|0,0,48);c[e>>2]=c[326];c[e+4>>2]=c[327];c[e+8>>2]=c[328];c[e+12>>2]=c[329];s_(o|0,0,1024);if((eK(E|0,1,8,A|0)|0)==8){L6202:do{if((s6(E|0,6056,8)|0)==0){z=cx(A|0)|0;do{if((z|0)<(b|0)&(z|0)>-1){r=l;D=r+1|0;C=r+2|0;y=r+3|0;x=q|0;u=q+4|0;G=q+8|0;H=n|0;I=n+4|0;J=n+8|0;K=n+9|0;L=n+10|0;M=n+11|0;N=n+12|0;O=k|0;P=0;Q=0;R=0;S=0;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;L6207:while(1){s_(p|0,0,12);c[l>>2]=0;if((eK(r|0,1,4,A|0)|0)!=4){_=4407;break}c[x>>2]=d[D]<<16|d[r]<<24|d[C]<<8|d[y];if((eK(u|0,1,4,A|0)|0)==4){$=0}else{_=4407;break}while(1){if($>>>0>=4){_=4411;break}if((s6(u|0,c[8296+($<<3)>>2]|0,4)|0)==0){_=4410;break}else{$=$+1|0}}L6213:do{if((_|0)==4410){_=0;switch(c[8300+($<<3)>>2]|0){case 1:{_=4413;break L6207;break};case 2:{if(R|S|T){_=4415;break L6207}sS(c[G>>2]|0);aa=c[x>>2]|0;ab=aa+4|0;ac=sR(ab)|0;if((ac|0)==0){_=4417;break L6207}if((c[ac-4>>2]&3|0)!=0){s_(ac|0,0,ab|0)}c[G>>2]=ac;if((eK(ac|0,1,ab|0,A|0)|0)!=(ab|0)){_=4421;break L6207}if((aa|0)!=13){_=4423;break L6207}aa=d[ac+1|0]<<16|d[ac]<<24|d[ac+2|0]<<8|d[ac+3|0];c[H>>2]=aa;ab=d[ac+5|0]<<16|d[ac+4|0]<<24|d[ac+6|0]<<8|d[ac+7|0];c[I>>2]=ab;ad=a[ac+8|0]|0;a[J]=ad;ae=a[ac+9|0]|0;a[K]=ae;af=a[ac+10|0]|0;a[L]=af;a[M]=a[ac+11|0]|0;ah=a[ac+12|0]|0;a[N]=ah;if((aa|0)==0|(ab|0)==0){_=4425;break L6207}switch(ae<<24>>24){case 0:{ai=ad&255;aj=0;while(1){if(aj>>>0>=5){_=4433;break L6207}if((c[6032+(aj<<2)>>2]|0)==(ai|0)){break}else{aj=aj+1|0}}break};case 3:{aj=ad&255;ai=0;while(1){if(ai>>>0>=4){_=4436;break L6207}if((c[6016+(ai<<2)>>2]|0)==(aj|0)){break}else{ai=ai+1|0}}break};case 2:case 4:case 6:{if(!((ad<<24>>24|0)==8|(ad<<24>>24|0)==16)){_=4430;break L6207}break};default:{_=4437;break L6207}}if(af<<24>>24!=0){_=4439;break L6207}sS(ac);c[G>>2]=0;ak=U;al=0;am=0;an=1;ao=Q;ap=P;aq=ae;ar=ab;as=ah;at=aa;au=ad;break L6213;break};case 4:{if(U|R^1|T|S){_=4444;break L6207}ai=c[x>>2]|0;if(((ai>>>0)%3|0|0)!=0){_=4446;break L6207}aj=(ai>>>0)/3|0;if(ai>>>0>770){_=4452;break L6207}if((eK(O|0,3,aj|0,A|0)|0)!=(aj|0)){_=4452;break L6207}if(ai>>>0>=3){ai=0;do{av=ai*3|0;c[o+(ai<<2)>>2]=d[k+av|0]<<16|d[k+(av+1)|0]<<8|d[k+(av+2)|0]|-16777216;ai=ai+1|0;}while(ai>>>0<aj>>>0)}if((e3(A|0,4,1)|0)>-1){ak=1;al=0;am=0;an=R;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z;break L6213}else{_=4452;break L6207}break};case 3:{if(T|R^1){_=4455;break L6207}if(!(V<<24>>24!=3|U)){_=4455;break L6207}aj=c[x>>2]|0;ai=aj+P|0;ad=sT(Q,ai)|0;if((ad|0)==0){aw=Q;_=4459;break L6207}if((eK(ad+P|0,1,aj|0,A|0)|0)!=(aj|0)){aw=ad;_=4459;break L6207}if((e3(A|0,4,1)|0)<0){aw=ad;_=4459;break L6207}else{ak=U;al=0;am=1;an=R;ao=ad;ap=ai;aq=V;ar=W;as=X;at=Y;au=Z;break L6213}break};case 5:{if(!(R&S)){_=4461;break L6207}if((e3(A|0,4,1)|0)<0){_=4463;break L6207}else{ak=U;al=1;am=1;an=1;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z;break L6213}break};default:{_=4411;break L6213}}}}while(0);if((_|0)==4411){_=0;if((e3(A|0,(c[x>>2]|0)+4|0,1)|0)<0){_=4412;break}else{ak=U;al=T;am=S;an=R;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z}}ai=cx(A|0)|0;if((ai|0)<(b|0)&(ai|0)>-1){P=ap;Q=ao;R=an;S=am;T=al;U=ak;V=aq;W=ar;X=as;Y=at;Z=au}else{_=4465;break}}if((_|0)==4407){Z=c[t>>2]|0;eQ(Z|0,48024,(v=i,i=i+8|0,c[v>>2]=613,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4412){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=620,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4413){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=624,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4415){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=628,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4417){c[G>>2]=0}else if((_|0)==4421){sS(ac)}else if((_|0)==4423){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=154,v)|0)|0;i=v;_=4440}else if((_|0)==4425){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=165,v)|0)|0;i=v;_=4440}else if((_|0)==4430){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=170,v)|0)|0;i=v;_=4440}else if((_|0)==4433){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=186,v)|0)|0;i=v;_=4440}else if((_|0)==4436){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=202,v)|0)|0;i=v;_=4440}else if((_|0)==4437){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=205,v)|0)|0;i=v;_=4440}else if((_|0)==4439){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=217,v)|0)|0;i=v;_=4440}else if((_|0)==4444){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=638,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4446){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=641,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4452){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=644,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4455){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=651,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4459){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=654,v)|0)|0;i=v;ax=0;ay=aw;break L6202}else if((_|0)==4461){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=661,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4463){eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=664,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4465){if(!(an&am&al)){az=ao;break}c[m+36>>2]=0;c[m+40>>2]=0;c[m+24>>2]=0;c[m+8>>2]=0;Z=m+20|0;c[Z>>2]=0;c[m+44>>2]=0;Y=sR(43784)|0;if((Y|0)==0){X=c[t>>2]|0;eQ(X|0,48024,(v=i,i=i+8|0,c[v>>2]=675,v)|0)|0;i=v;ax=0;ay=ao;break L6202}X=m+28|0;c[X>>2]=Y;c[Y>>2]=0;c[Y+10992>>2]=0;c[Y+10996>>2]=0;c[Y+43780>>2]=1;c[Y+11e3>>2]=1;c[Y+11004>>2]=0;c[Y+11008>>2]=15;switch(aq&255|0){case 0:{aA=((ag(at,au&255)|0)+7|0)>>>3;break};case 2:{aA=((ag((au&255)*3|0,at)|0)+7|0)>>>3;break};case 3:{aA=((ag(at,au&255)|0)+7|0)>>>3;break};case 4:{aA=((ag((au&255)<<1,at)|0)+7|0)>>>3;break};case 6:{aA=((ag((au&255)<<2,at)|0)+7|0)>>>3;break};default:{aA=0}}Y=as<<24>>24==1;W=(ag(ar,aA+1|0)|0)<<(Y&1);V=sR(W)|0;if((V|0)==0){U=c[t>>2]|0;eQ(U|0,48024,(v=i,i=i+8|0,c[v>>2]=683,v)|0)|0;i=v;ax=0;ay=ao;break L6202}c[m>>2]=ao;c[m+4>>2]=ap;c[m+16>>2]=W;c[m+12>>2]=V;W=(ks(m)|0)==1;U=c[X>>2]|0;if((U|0)!=0){sS(U);c[X>>2]=0}if(!W){W=c[t>>2]|0;eQ(W|0,48024,(v=i,i=i+8|0,c[v>>2]=693,v)|0)|0;i=v;ax=V;ay=ao;break L6202}c[B>>2]=at;c[F>>2]=ar;W=sR(ag(ar<<2,at)|0)|0;X=W;c[s>>2]=X;if((W|0)==0){W=c[t>>2]|0;eQ(W|0,48024,(v=i,i=i+8|0,c[v>>2]=701,v)|0)|0;i=v;ax=V;ay=ao;break L6202}W=c[Z>>2]|0;Z=o|0;L6301:do{if(Y){U=j;T=j|0;S=j+4|0;R=j+9|0;P=j+8|0;x=0;O=W;N=V;M=at;L6303:while(1){L=c[5904+(x<<4)>>2]|0;do{if(M>>>0>L>>>0){K=c[I>>2]|0;J=c[5908+(x<<4)>>2]|0;if(K>>>0<=J>>>0){aB=N;aC=O;break}u=c[5912+(x<<4)>>2]|0;y=((M-1-L+u|0)>>>0)/(u>>>0)|0;C=c[5916+(x<<4)>>2]|0;r=((K-1-J+C|0)>>>0)/(C>>>0)|0;K=y<<2;aD=sR(ag(r,K)|0)|0;D=aD;if((aD|0)==0){break L6303}c[U>>2]=c[e>>2];c[U+4>>2]=c[e+4>>2];c[U+8>>2]=c[e+8>>2];c[U+12>>2]=c[e+12>>2];c[T>>2]=y;c[S>>2]=r;switch(d[R]|0){case 0:{aE=((ag(d[P]|0,y)|0)+7|0)>>>3;break};case 2:{aE=((ag(y*3|0,d[P]|0)|0)+7|0)>>>3;break};case 3:{aE=((ag(d[P]|0,y)|0)+7|0)>>>3;break};case 4:{aE=((ag(y<<1,d[P]|0)|0)+7|0)>>>3;break};case 6:{aE=((ag(d[P]|0,K)|0)+7|0)>>>3;break};default:{aE=0}}K=ag(aE+1|0,r)|0;if(K>>>0>O>>>0){_=4495;break L6303}if(!(kr(D,j,N,K,Z)|0)){_=4497;break L6303}ai=N+K|0;ad=O-K|0;if(!((r|0)==0|(y|0)==0)){K=D;D=X+((ag(c[H>>2]|0,J)|0)+L<<2)|0;J=0;while(1){aj=D;aa=0;while(1){c[aj>>2]=c[K+(aa<<2)>>2];ah=aa+1|0;if(ah>>>0<y>>>0){aj=aj+(u<<2)|0;aa=ah}else{break}}aa=J+1|0;aj=D+((ag(c[H>>2]|0,C)|0)<<2)|0;if(aa>>>0<r>>>0){K=K+(y<<2)|0;D=aj;J=aa}else{break}}}sS(aD);aB=ai;aC=ad}else{aB=N;aC=O}}while(0);L=x+1|0;if(L>>>0>=7){break L6301}x=L;O=aC;N=aB;M=c[H>>2]|0}if((_|0)==4495){sS(aD)}else if((_|0)==4497){sS(aD)}eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=706,v)|0)|0;i=v;ax=V;ay=ao;break L6202}else{if(kr(X,n,V,W,Z)|0){break}eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=709,v)|0)|0;i=v;ax=V;ay=ao;break L6202}}while(0);a_(A|0)|0;sS(ao);sS(V);if((f|0)==16&(g|0)==0){w=1;i=h;return w|0}Z=ag(c[F>>2]|0,c[B>>2]|0)|0;W=c[s>>2]|0;if((Z|0)==0){w=1;i=h;return w|0}else{aF=0}while(1){X=W+(aF<<2)|0;H=c[X>>2]|0;c[X>>2]=(H&255)<<g|H&-16777216|(H>>>16&255)<<f|H&65280;H=aF+1|0;if(H>>>0<Z>>>0){aF=H}else{w=1;break}}i=h;return w|0}if((_|0)==4440){sS(ac);c[G>>2]=0}eQ(c[t>>2]|0,48024,(v=i,i=i+8|0,c[v>>2]=631,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else{az=0}}while(0);z=c[t>>2]|0;eQ(z|0,48024,(v=i,i=i+8|0,c[v>>2]=672,v)|0)|0;i=v;ax=0;ay=az}else{z=c[t>>2]|0;eQ(z|0,48024,(v=i,i=i+8|0,c[v>>2]=606,v)|0)|0;i=v;ax=0;ay=0}}while(0);a_(A|0)|0;aG=ax;aH=ay}else{ay=c[t>>2]|0;eQ(ay|0,48024,(v=i,i=i+8|0,c[v>>2]=603,v)|0)|0;i=v;a_(A|0)|0;aG=0;aH=0}sS(c[s>>2]|0);sS(aH);sS(aG);w=0;i=h;return w|0}function i3(a,b,c){a=a|0;b=b|0;c=c|0;return-1|0}function i4(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function i5(a){a=a|0;return 1}function i6(a){a=a|0;return 1}function i7(a,b){a=a|0;b=b|0;return}function i8(a){a=a|0;return}function i9(a){a=a|0;return 1}function ja(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0.0,N=0,O=0.0,P=0.0,Q=0,R=0.0,S=0.0;d=~~(16777216.0/+h[b+16>>3]);e=c[b+8>>2]|0;if((e|0)==0){f=0;i=b+12|0;c[i>>2]=f;return}j=a+20|0;k=a+4|0;l=a+16|0;m=a+8|0;n=a+12|0;o=a;a=c[b>>2]|0;p=c[b+4>>2]|0;q=e;e=0;r=c[j>>2]|0;while(1){L6363:do{if((q|0)==0){s=a;t=r;u=4541}else{v=a;w=q;x=r;while(1){if(x>>>0<=16777215){y=x;z=w;A=v;break L6363}B=c[l>>2]|0;if((B|0)==0){C=c[n>>2]|0;c[l>>2]=C;D=C}else{D=B}B=D-1|0;c[l>>2]=B;E=+g[v>>2];g[(c[k>>2]|0)+(B<<2)>>2]=E;g[(c[k>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;B=v+8|0;E=+g[v+4>>2];g[(c[m>>2]|0)+(c[l>>2]<<2)>>2]=E;g[(c[m>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;C=(c[j>>2]|0)-16777216|0;c[j>>2]=C;F=w-1|0;if((F|0)==0){s=B;t=C;u=4541;break}else{v=B;w=F;x=C}}}}while(0);if((u|0)==4541){u=0;if(t>>>0<16777216){y=t;z=0;A=s}else{f=e;u=4547;break}}x=p;w=e;v=y;do{C=c[k>>2]|0;F=c[l>>2]|0;B=c[m>>2]|0;G=c[n>>2]|0;H=c[o>>2]|0;I=ag(G<<1,v>>>16)|0;J=I+G|0;E=+((v&65535)>>>0>>>0)*152587890625.0e-16;if((G|0)==0){K=0.0;L=0.0}else{M=0.0;N=0;O=0.0;while(1){P=+g[H+(N+I<<2)>>2]+E*+g[H+(J+N<<2)>>2];Q=N+F|0;R=O+ +g[C+(Q<<2)>>2]*P;S=M+ +g[B+(Q<<2)>>2]*P;Q=N+1|0;if(Q>>>0<G>>>0){M=S;N=Q;O=R}else{K=S;L=R;break}}}g[x>>2]=L;g[x+4>>2]=K;x=x+8|0;w=w+1|0;v=(c[j>>2]|0)+d|0;c[j>>2]=v;}while(v>>>0<16777216);if((z|0)==0){f=w;u=4548;break}else{a=A;p=x;q=z;e=w;r=v}}if((u|0)==4547){i=b+12|0;c[i>>2]=f;return}else if((u|0)==4548){i=b+12|0;c[i>>2]=f;return}}function jb(b){b=+b;var d=0,e=0,f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,u=0.0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0,F=0.0,G=0.0,H=0;d=i;e=sR(28)|0;if((e|0)==0){f=0;i=d;return f|0}if((c[e-4>>2]&3|0)!=0){s_(e|0,0,28)}s_(e|0,0,28);h=e+12|0;if(b<1.0){j=b*.825;k=~~+af(+(16.0/b))+3&-4}else{j=.825;k=16}c[h>>2]=k;l=k<<9;m=sR((l+(k<<2)<<2)+132|0)|0;k=m+132&-128;c[k-4>>2]=m;m=k;c[e+24>>2]=m;if((k|0)==0){sS(c[m-4>>2]|0);sS(e);f=0;i=d;return f|0}c[e>>2]=m;c[e+4>>2]=m+(l<<2);k=c[h>>2]|0;n=k<<1;c[e+8>>2]=m+(n+l<<2);b=1.0;o=0.0;p=1.0;q=1.0;r=0.0;l=0;while(1){s=r+q*p/(b*b);u=o+1.0;v=l+1|0;if(v>>>0<18){b=b*u;o=u;p=p*30.25;q=q*.25;r=s;l=v}else{break}}r=+(k|0)*.5;q=+(k<<8|0);if((k|0)>0){l=0;while(1){v=ag(l,n)|0;w=0;do{p=+((w<<8)+l|0)/q*2.0+-1.0;o=j*r*p*3.141592653589793;if(+V(+o)<1.0e-5){x=1.0}else{x=+Z(+o)/o}o=+W(+(1.0-p*p))*5.5;p=o*o;o=1.0;b=0.0;u=1.0;y=1.0;z=0.0;A=0;while(1){B=z+y*u/(o*o);C=b+1.0;D=A+1|0;if(D>>>0<18){o=o*C;b=C;u=p*u;y=y*.25;z=B;A=D}else{break}}g[m+(w+v<<2)>>2]=j*x*B/s;w=w+1|0;}while((w|0)<(k|0));w=l+1|0;if((w|0)<256){l=w}else{E=0;break}}while(1){l=E+1|0;w=ag(l,n)|0;v=E<<1;A=ag(v,k)|0;D=ag(v|1,k)|0;v=0;do{g[m+(v+D<<2)>>2]=+g[m+(v+w<<2)>>2]- +g[m+(v+A<<2)>>2];v=v+1|0;}while((v|0)<(k|0));if((l|0)<255){E=l}else{break}}E=k*510|0;n=k*511|0;v=0;do{B=+((v<<8)+256|0)/q*2.0+-1.0;x=j*r*B*3.141592653589793;if(+V(+x)<1.0e-5){F=1.0}else{F=+Z(+x)/x}x=+W(+(1.0-B*B))*5.5;B=x*x;x=1.0;z=0.0;y=1.0;u=1.0;p=0.0;A=0;while(1){G=p+u*y/(x*x);b=z+1.0;w=A+1|0;if(w>>>0<18){x=x*b;z=b;y=B*y;u=u*.25;p=G;A=w}else{break}}g[m+(v+n<<2)>>2]=j*F*G/s- +g[m+(v+E<<2)>>2];v=v+1|0;}while((v|0)<(k|0))}k=a[383584]|0;if((k&1)==0){H=k}else{k=c[135158]|0;v=(k|0)!=0?k:c[t>>2]|0;be(48872,30,1,v|0)|0;v=c[135158]|0;k=(v|0)!=0?v:c[t>>2]|0;a7(k|0)|0;H=a[383584]|0}if((H&1)==0){f=e;i=d;return f|0}H=c[135158]|0;k=c[h>>2]|0;eQ(((H|0)!=0?H:c[t>>2]|0)|0,36576,(H=i,i=i+16|0,c[H>>2]=8,c[H+8>>2]=k,H)|0)|0;i=H;H=c[135158]|0;a7(((H|0)!=0?H:c[t>>2]|0)|0)|0;f=e;i=d;return f|0}function jc(a){a=a|0;if((a|0)==0){sS(a);return}sS(c[(c[a+24>>2]|0)-4>>2]|0);sS(a);return}function jd(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=sZ(e|0)|0;if(g>>>0<=c>>>0){h=c+1|0;do{if((h|0)==0){i=e}else{j=h;k=b;l=e;while(1){m=j-1|0;if((m|0)==0){n=4594;break}o=a[l]|0;a[k]=o;if(o<<24>>24==0){n=4658;break}else{j=m;k=k+1|0;l=l+1|0}}if((n|0)==4658){return}else if((n|0)==4594){a[k]=0;i=l;break}}}while(0);if((a[i]|0)==0){return}else{p=i}do{p=p+1|0;}while((a[p]|0)!=0);return}if(!f){f=c+1|0;p=c-2|0;L6458:do{if((p|0)==0){q=e;n=4602}else{i=p;h=b;j=e;while(1){m=i-1|0;if((m|0)==0){break}o=a[j]|0;a[h]=o;if(o<<24>>24==0){break L6458}else{i=m;h=h+1|0;j=j+1|0}}a[h]=0;q=j;n=4602}}while(0);do{if((n|0)==4602){if((a[q]|0)==0){break}else{r=q}do{r=r+1|0;}while((a[r]|0)!=0)}}while(0);r=sZ(b|0)|0;q=r>>>0>f>>>0?0:f-r|0;if((q|0)==0){s=35168}else{f=b+r|0;do{if((q|0)==1){t=35168;u=f}else{j=b+(r+1)|0;a[f]=46;if((q|0)==2){t=35169;u=j;break}h=b+(r+2)|0;a[j]=46;if((q|0)==3){t=35170;u=h;break}j=b+(r+3)|0;a[h]=46;if((q|0)==4){t=35171;u=j;break}a[j]=0;return}}while(0);a[u]=0;s=t}if((a[s]|0)==0){return}else{v=s}do{v=v+1|0;}while((a[v]|0)!=0);return}v=g-c|0;g=(d>>>0)%(((v<<1)+4|0)>>>0)|0;d=v+4|0;s=g-2|0;t=d+v-g|0;if(g>>>0<2){u=c+1|0;do{if((u|0)==0){w=e}else{q=u;r=b;f=e;while(1){j=q-1|0;if((j|0)==0){n=4614;break}h=a[f]|0;a[r]=h;if(h<<24>>24==0){n=4646;break}else{q=j;r=r+1|0;f=f+1|0}}if((n|0)==4614){a[r]=0;w=f;break}else if((n|0)==4646){return}}}while(0);if((a[w]|0)==0){return}else{x=w}do{x=x+1|0;}while((a[x]|0)!=0);return}if(g>>>0<(v+2|0)>>>0){x=e+s|0;s=c+1|0;do{if((s|0)==0){y=x}else{w=s;u=b;q=x;while(1){j=w-1|0;if((j|0)==0){n=4621;break}h=a[q]|0;a[u]=h;if(h<<24>>24==0){n=4649;break}else{w=j;u=u+1|0;q=q+1|0}}if((n|0)==4621){a[u]=0;y=q;break}else if((n|0)==4649){return}}}while(0);if((a[y]|0)==0){return}else{z=y}do{z=z+1|0;}while((a[z]|0)!=0);return}if(g>>>0<d>>>0){d=e+v|0;v=c+1|0;do{if((v|0)==0){A=d}else{g=v;z=b;y=d;while(1){x=g-1|0;if((x|0)==0){n=4628;break}s=a[y]|0;a[z]=s;if(s<<24>>24==0){n=4652;break}else{g=x;z=z+1|0;y=y+1|0}}if((n|0)==4652){return}else if((n|0)==4628){a[z]=0;A=y;break}}}while(0);if((a[A]|0)==0){return}else{B=A}do{B=B+1|0;}while((a[B]|0)!=0);return}else{B=e+t|0;t=c+1|0;do{if((t|0)==0){C=B}else{c=t;e=b;A=B;while(1){d=c-1|0;if((d|0)==0){n=4634;break}v=a[A]|0;a[e]=v;if(v<<24>>24==0){n=4648;break}else{c=d;e=e+1|0;A=A+1|0}}if((n|0)==4634){a[e]=0;C=A;break}else if((n|0)==4648){return}}}while(0);if((a[C]|0)==0){return}else{D=C}do{D=D+1|0;}while((a[D]|0)!=0);return}}function je(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b+44|0;e=c[d>>2]|0;f=e+8|0;if((c[f>>2]|0)!=0){g=e|0;e=0;do{sS(c[(c[g>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while(e>>>0<(c[f>>2]|0)>>>0)}c[f>>2]=0;do{if((c[b+113712>>2]|0)==0){h=4668}else{f=c[d>>2]|0;if((f|0)==0){break}e=f+8|0;g=f+4|0;i=c[g>>2]|0;if((c[e>>2]|0)>>>0<i>>>0){j=f|0}else{k=(i<<1)+2|0;c[g>>2]=k;g=f|0;c[g>>2]=sT(c[g>>2]|0,k*12|0)|0;j=g}g=dT(45344)|0;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)>>2]=g;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=56;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1;h=4668}}while(0);do{if((h|0)==4668){j=c[d>>2]|0;if((j|0)==0){break}b=j+8|0;e=j+4|0;g=c[e>>2]|0;if((c[b>>2]|0)>>>0<g>>>0){l=j|0}else{k=(g<<1)+2|0;c[e>>2]=k;e=j|0;c[e>>2]=sT(c[e>>2]|0,k*12|0)|0;l=e}e=dT(45304)|0;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)>>2]=e;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)+4>>2]=55;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)+8>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[d>>2]|0;if((b|0)==0){break}e=b+8|0;k=b+4|0;j=c[k>>2]|0;if((c[e>>2]|0)>>>0<j>>>0){m=b|0}else{g=(j<<1)+2|0;c[k>>2]=g;k=b|0;c[k>>2]=sT(c[k>>2]|0,g*12|0)|0;m=k}k=dT(45240)|0;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)>>2]=k;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=58;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1;e=c[d>>2]|0;if((e|0)==0){break}k=e+8|0;g=e+4|0;b=c[g>>2]|0;if((c[k>>2]|0)>>>0<b>>>0){n=e|0}else{j=(b<<1)+2|0;c[g>>2]=j;g=e|0;c[g>>2]=sT(c[g>>2]|0,j*12|0)|0;n=g}g=dT(45080)|0;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)>>2]=g;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)+4>>2]=5;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)+8>>2]=0;c[k>>2]=(c[k>>2]|0)+1;k=c[d>>2]|0;if((k|0)==0){break}g=k+8|0;j=k+4|0;e=c[j>>2]|0;if((c[g>>2]|0)>>>0<e>>>0){o=k|0}else{b=(e<<1)+2|0;c[j>>2]=b;j=k|0;c[j>>2]=sT(c[j>>2]|0,b*12|0)|0;o=j}j=dT(44792)|0;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)>>2]=j;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)+4>>2]=59;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)+8>>2]=0;c[g>>2]=(c[g>>2]|0)+1;g=c[d>>2]|0;if((g|0)==0){break}j=g+8|0;b=g+4|0;k=c[b>>2]|0;if((c[j>>2]|0)>>>0<k>>>0){p=g|0}else{e=(k<<1)+2|0;c[b>>2]=e;b=g|0;c[b>>2]=sT(c[b>>2]|0,e*12|0)|0;p=b}b=dT(44680)|0;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)>>2]=b;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)+4>>2]=60;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)+8>>2]=0;c[j>>2]=(c[j>>2]|0)+1;j=c[d>>2]|0;if((j|0)==0){break}b=j+8|0;e=j+4|0;g=c[e>>2]|0;if((c[b>>2]|0)>>>0<g>>>0){q=j|0}else{k=(g<<1)+2|0;c[e>>2]=k;e=j|0;c[e>>2]=sT(c[e>>2]|0,k*12|0)|0;q=e}e=dT(44544)|0;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)>>2]=e;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)+4>>2]=61;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)+8>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[d>>2]|0;if((b|0)==0){break}e=b+8|0;k=b+4|0;j=c[k>>2]|0;if((c[e>>2]|0)>>>0<j>>>0){r=b|0}else{g=(j<<1)+2|0;c[k>>2]=g;k=b|0;c[k>>2]=sT(c[k>>2]|0,g*12|0)|0;r=k}k=dT(44416)|0;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)>>2]=k;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=62;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1}}while(0);do{if((a[540636]&1)!=0){if((a[541709]&1)!=0){break}if((c[120646]|0)!=0){r=c[d>>2]|0;if((r|0)==0){return}q=r+8|0;p=r+4|0;o=c[p>>2]|0;if((c[q>>2]|0)>>>0<o>>>0){s=r|0}else{n=(o<<1)+2|0;c[p>>2]=n;p=r|0;c[p>>2]=sT(c[p>>2]|0,n*12|0)|0;s=p}p=dT(44288)|0;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)>>2]=p;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)+4>>2]=69;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)+8>>2]=0;c[q>>2]=(c[q>>2]|0)+1}q=c[d>>2]|0;if((q|0)==0){return}p=q+8|0;n=q+4|0;r=c[n>>2]|0;if((c[p>>2]|0)>>>0<r>>>0){t=q|0}else{o=(r<<1)+2|0;c[n>>2]=o;n=q|0;c[n>>2]=sT(c[n>>2]|0,o*12|0)|0;t=n}n=dT(44160)|0;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)>>2]=n;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)+4>>2]=67;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)+8>>2]=0;c[p>>2]=(c[p>>2]|0)+1;p=c[d>>2]|0;if((p|0)==0){return}n=p+8|0;o=p+4|0;q=c[o>>2]|0;if((c[n>>2]|0)>>>0<q>>>0){u=p|0}else{r=(q<<1)+2|0;c[o>>2]=r;o=p|0;c[o>>2]=sT(c[o>>2]|0,r*12|0)|0;u=o}o=dT(44040)|0;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)>>2]=o;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)+4>>2]=68;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)+8>>2]=0;c[n>>2]=(c[n>>2]|0)+1;n=c[d>>2]|0;if((n|0)==0){return}o=n+8|0;r=n+4|0;p=c[r>>2]|0;if((c[o>>2]|0)>>>0<p>>>0){v=n|0}else{q=(p<<1)+2|0;c[r>>2]=q;r=n|0;c[r>>2]=sT(c[r>>2]|0,q*12|0)|0;v=r}r=dT(43872)|0;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)>>2]=r;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=72;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1;o=c[d>>2]|0;if((o|0)==0){return}r=o+8|0;q=o+4|0;n=c[q>>2]|0;if((c[r>>2]|0)>>>0<n>>>0){w=o|0}else{p=(n<<1)+2|0;c[q>>2]=p;q=o|0;c[q>>2]=sT(c[q>>2]|0,p*12|0)|0;w=q}q=dT(43800)|0;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)>>2]=q;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)+4>>2]=86;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)+8>>2]=0;c[r>>2]=(c[r>>2]|0)+1;r=c[d>>2]|0;if((r|0)==0){return}q=r+8|0;p=r+4|0;o=c[p>>2]|0;if((c[q>>2]|0)>>>0<o>>>0){x=r|0}else{n=(o<<1)+2|0;c[p>>2]=n;p=r|0;c[p>>2]=sT(c[p>>2]|0,n*12|0)|0;x=p}p=dT(43688)|0;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)>>2]=p;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)+4>>2]=80;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)+8>>2]=0;c[q>>2]=(c[q>>2]|0)+1}}while(0);x=c[d>>2]|0;if((x|0)==0){return}w=x+8|0;v=x+4|0;u=c[v>>2]|0;if((c[w>>2]|0)>>>0<u>>>0){y=x|0}else{t=(u<<1)+2|0;c[v>>2]=t;v=x|0;c[v>>2]=sT(c[v>>2]|0,t*12|0)|0;y=v}v=dT(43424)|0;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)>>2]=v;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)+4>>2]=85;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)+8>>2]=0;c[w>>2]=(c[w>>2]|0)+1;w=c[d>>2]|0;if((w|0)==0){return}d=w+8|0;y=w+4|0;v=c[y>>2]|0;if((c[d>>2]|0)>>>0<v>>>0){z=w|0}else{t=(v<<1)+2|0;c[y>>2]=t;y=w|0;c[y>>2]=sT(c[y>>2]|0,t*12|0)|0;z=y}y=dT(43312)|0;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)>>2]=y;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)+4>>2]=87;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)+8>>2]=0;c[d>>2]=(c[d>>2]|0)+1;return}function jf(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0;e=i;i=i+22120|0;f=e|0;h=e+16|0;j=e+528|0;k=e+1552|0;l=e+5648|0;m=e+9744|0;n=e+9768|0;o=e+9832|0;p=e+13928|0;q=e+18024|0;r=d+8|0;s=c[r>>2]|0;u=c[r+4>>2]|0;do{if((s&1|0)==0&(u&0|0)==0){if(!((s&2|0)==0&(u&0|0)==0)){v=1;break}if(!((s&4|0)==0&(u&0|0)==0)){v=2;break}if(!((s&8|0)==0&(u&0|0)==0)){v=3;break}if(!((s&32|0)==0&(u&0|0)==0)){v=5;break}if(!((s&16|0)==0&(u&0|0)==0)){v=4;break}if(!((s&128|0)==0&(u&0|0)==0)){v=8;break}v=(s&64|0)==0&(u&0|0)==0?10:7}else{v=0}}while(0);u=d+40|0;s=c[u>>2]|0;r=c[s+8>>2]|0;if((r|0)==0){w=0;x=0}else{y=r-1|0;r=c[s>>2]|0;w=c[r+(y*12|0)+4>>2]|0;x=c[r+(y*12|0)>>2]|0}y=c[136914]|0;do{if((y|0)!=0){if((c[y+24>>2]|0)==0){break}f8[c[y+20>>2]&15](c[136866]|0,64360,0,320,240,1.0)}}while(0);switch(w|0){case 69:case 62:case 61:case 59:case 58:case 26:case 5:case 4:case 60:{z=jg(d,v)|0;i=e;return z|0};default:{}}if((w-12|0)>>>0<2){y=n|0;n=c[u>>2]|0;r=n+8|0;s=c[r>>2]|0;A=(s|0)==0;if(A){B=0}else{B=c[(c[n>>2]|0)+((s-1|0)*12|0)+4>>2]|0}C=(a[281285]&1)==0;D=C?1:c[119472]|0;E=C?1:c[119473]|0;L6686:do{switch(v|0){case 4:{F=d+48|0;if(!A){G=s-1|0;c[r>>2]=G;sS(c[(c[n>>2]|0)+(G*12|0)>>2]|0)}if((F|0)!=0){c[F>>2]=c[(c[n>>2]|0)+((c[r>>2]|0)*12|0)+8>>2]}if((B|0)!=12){break L6686}if((a[281285]&1)!=0){break L6686}G=c[u>>2]|0;H=c[F>>2]|0;if((G|0)==0){break L6686}F=G+8|0;I=G+4|0;J=c[I>>2]|0;if((c[F>>2]|0)>>>0<J>>>0){L=G|0}else{M=(J<<1)+2|0;c[I>>2]=M;I=G|0;c[I>>2]=sT(c[I>>2]|0,M*12|0)|0;L=I}I=dT(547872)|0;c[(c[L>>2]|0)+((c[F>>2]|0)*12|0)>>2]=I;c[(c[L>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=13;c[(c[L>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=H;c[F>>2]=(c[F>>2]|0)+1;break};case 9:{a[d+53|0]=1;break};case 5:{F=d+48|0;if(!A){H=s-1|0;c[r>>2]=H;sS(c[(c[n>>2]|0)+(H*12|0)>>2]|0)}if((F|0)!=0){c[F>>2]=c[(c[n>>2]|0)+((c[r>>2]|0)*12|0)+8>>2]}if((B|0)!=13){break L6686}H=c[u>>2]|0;I=c[F>>2]|0;if((H|0)==0){break L6686}F=H+8|0;M=H+4|0;G=c[M>>2]|0;if((c[F>>2]|0)>>>0<G>>>0){N=H|0}else{J=(G<<1)+2|0;c[M>>2]=J;M=H|0;c[M>>2]=sT(c[M>>2]|0,J*12|0)|0;N=M}M=dT(547872)|0;c[(c[N>>2]|0)+((c[F>>2]|0)*12|0)>>2]=M;c[(c[N>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=12;c[(c[N>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=I;c[F>>2]=(c[F>>2]|0)+1;break};case 7:{F=d+48|0;if(!A){I=s-1|0;c[r>>2]=I;sS(c[(c[n>>2]|0)+(I*12|0)>>2]|0)}if((F|0)==0){break L6686}c[F>>2]=c[(c[n>>2]|0)+((c[r>>2]|0)*12|0)+8>>2];break};case 1:{do{if((B|0)==12){c[135144]=(c[135144]|0)+E;F=c[135146]|0;if(F>>>0<E>>>0){break}c[135146]=F-E}else{c[135146]=(c[135146]|0)+E}}while(0);F=c[(c[136914]|0)+16>>2]|0;if((F|0)==0){break L6686}f$[F&511](c[136866]|0);break};case 0:{do{if((B|0)==12){c[135144]=(c[135144]|0)-E;c[135146]=(c[135146]|0)+E}else{F=c[135146]|0;if(F>>>0<E>>>0){break}c[135146]=F-E}}while(0);F=c[(c[136914]|0)+16>>2]|0;if((F|0)==0){break L6686}f$[F&511](c[136866]|0);break};case 8:{if(!C){break L6686}f0[c[(c[136863]|0)+44>>2]&255](c[136866]|0,m);if((B|0)==12){c[135145]=(c[135145]|0)+(c[135143]|0);c[135146]=(c[135146]|0)+(c[135144]|0);c[135143]=0;c[135144]=0}else{c[135145]=(c[m+16>>2]|0)-(c[135143]|0);c[135146]=(c[m+20>>2]|0)-(c[135144]|0)}F=c[(c[136914]|0)+16>>2]|0;if((F|0)==0){break L6686}f$[F&511](c[136866]|0);break};case 2:{do{if((B|0)==12){c[135143]=(c[135143]|0)-D;c[135145]=(c[135145]|0)+D}else{F=c[135145]|0;if(F>>>0<D>>>0){break}c[135145]=F-D}}while(0);F=c[(c[136914]|0)+16>>2]|0;if((F|0)==0){break L6686}f$[F&511](c[136866]|0);break};case 3:{do{if((B|0)==12){c[135143]=(c[135143]|0)+D;F=c[135145]|0;if(F>>>0<D>>>0){break}c[135145]=F-D}else{c[135145]=(c[135145]|0)+D}}while(0);F=c[(c[136914]|0)+16>>2]|0;if((F|0)==0){break L6686}f$[F&511](c[136866]|0);break};default:{}}}while(0);m=c[u>>2]|0;C=c[m+8>>2]|0;if((C|0)==0){O=B}else{O=c[(c[m>>2]|0)+((C-1|0)*12|0)+4>>2]|0}ji(d);if((a[281285]&1)==0){if((O|0)==12){P=16328}else{P=(O|0)==13?16088:0}O=c[135143]|0;C=c[135144]|0;m=c[135145]|0;B=c[135146]|0;b5(y|0,64,15824,(Q=i,i=i+40|0,c[Q>>2]=P,c[Q+8>>2]=O,c[Q+16>>2]=C,c[Q+24>>2]=m,c[Q+32>>2]=B,Q)|0)|0;i=Q}else{c[135143]=0;c[135144]=0;B=c[119472]|0;m=(c[135145]|0)-1+B|0;C=m-((m>>>0)%(B>>>0)|0)|0;c[135145]=C;O=c[119473]|0;P=(c[135146]|0)-1+O|0;r=P-((P>>>0)%(O>>>0)|0)|0;c[135146]=r;n=(m>>>0)/(B>>>0)|0;B=(P>>>0)/(O>>>0)|0;b5(y|0,64,16784,(Q=i,i=i+40|0,c[Q>>2]=16984,c[Q+8>>2]=C,c[Q+16>>2]=r,c[Q+24>>2]=n,c[Q+32>>2]=B,Q)|0)|0;i=Q}if((a[y]|0)!=0){B=dT(y|0)|0;if((sZ(B|0)|0)>>>0>48){a[B+46|0]=46;a[B+47|0]=46;a[B+48|0]=46;a[B+49|0]=0}y=(sZ(B|0)|0)*6|0;n=y+15|0;r=(305-y|0)>>>1;C=d+28|0;O=c[C>>2]|0;P=d+32|0;m=r+5|0;s=c[P>>2]|0;A=y+5+m|0;N=s>>>1;if(A>>>0>m>>>0){L=112;do{F=ag(L,N)|0;I=L>>>1;M=m;do{J=((M>>>1)+I&1)+1|0;b[O+(M+F<<1)>>1]=(J<<13|J<<9|J<<5|12)&65535;M=M+1|0;}while(M>>>0<A>>>0);L=L+1|0;}while(L>>>0<128);R=c[C>>2]|0;S=c[P>>2]|0}else{R=O;S=s}s=y+10|0;y=r+s|0;O=S>>>1;if(y>>>0>r>>>0){L=107;do{A=ag(L,O)|0;N=L>>>1;M=r;do{F=((M>>>1)+N&1)+1|0;b[R+(M+A<<1)>>1]=(F<<13|F<<10|F<<5|12)&65535;M=M+1|0;}while(M>>>0<y>>>0);L=L+1|0;}while(L>>>0<112);T=c[C>>2]|0;U=c[P>>2]|0}else{T=R;U=S}S=r+n|0;n=cN(S|0,-5|0)|0;R=n;n=U>>>1;if(K){L=107;do{y=ag(L,n)|0;O=L>>>1;M=R;do{A=((M>>>1)+O&1)+1|0;b[T+(M+y<<1)>>1]=(A<<13|A<<10|A<<5|12)&65535;M=M+1|0;}while(M>>>0<S>>>0);L=L+1|0;}while(L>>>0<128);V=c[C>>2]|0;W=c[P>>2]|0}else{V=T;W=U}U=m+s|0;s=W>>>1;if(U>>>0>m>>>0){T=s<<7;L=m;do{S=(L>>>1&1)+1|0;b[V+(L+T<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;L=L+1|0;}while(L>>>0<U>>>0);L=s*129|0;T=m;do{S=(T>>>1&1)+1|0;b[V+(T+L<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;T=T+1|0;}while(T>>>0<U>>>0);T=s*130|0;L=m;do{S=2-(L>>>1&1)|0;b[V+(L+T<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;L=L+1|0;}while(L>>>0<U>>>0);L=s*131|0;T=m;do{S=2-(T>>>1&1)|0;b[V+(T+L<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;T=T+1|0;}while(T>>>0<U>>>0);T=s*132|0;s=m;do{L=(s>>>1&1)+1|0;b[V+(s+T<<1)>>1]=(L<<13|L<<10|L<<5|12)&65535;s=s+1|0;}while(s>>>0<U>>>0);X=c[C>>2]|0;Y=c[P>>2]|0}else{X=V;Y=W}W=Y>>>1;Y=112;do{V=ag(Y,W)|0;P=Y>>>1;C=r;do{U=((C>>>1)+P&1)+1|0;b[X+(C+V<<1)>>1]=(U<<13|U<<10|U<<5|12)&65535;C=C+1|0;}while(C>>>0<m>>>0);Y=Y+1|0;}while(Y>>>0<133);jj(d,r+8|0,115,B,0);sS(B)}B=c[135145]|0;if((B|0)==0){c[135145]=D;Z=D}else{Z=B}B=c[135146]|0;if((B|0)==0){c[135146]=E;_=E}else{_=B}g[2715]=+(Z>>>0>>>0)/+(_>>>0>>>0);_=c[(c[136914]|0)+16>>2]|0;if((_|0)==0){z=0;i=e;return z|0}f$[_&511](c[136866]|0);z=0;i=e;return z|0}_=d+52|0;L6831:do{switch(((a[_]&1)==0?v:10)|0){case 1:{Z=d+48|0;B=(c[Z>>2]|0)+1|0;if(B>>>0<(c[(c[d+44>>2]|0)+8>>2]|0)>>>0){c[Z>>2]=B;$=0;break L6831}else{c[Z>>2]=0;$=0;break L6831}break};case 6:{c[d+48>>2]=0;a[_]=1;$=0;break};case 7:{a[_]=1;Z=c[u>>2]|0;B=c[Z+8>>2]|0;if(B>>>0>1){E=d+48|0;D=(E|0)==0;r=Z;Z=B;do{B=r+8|0;if((Z|0)!=0){Y=Z-1|0;c[B>>2]=Y;sS(c[(c[r>>2]|0)+(Y*12|0)>>2]|0)}if(!D){c[E>>2]=c[(c[r>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]}r=c[u>>2]|0;Z=c[r+8>>2]|0;}while(Z>>>0>1)}z=jg(d,6)|0;i=e;return z|0};case 5:{Z=c[u>>2]|0;r=Z+8|0;if((c[r>>2]|0)>>>0<=1){$=0;break L6831}a[_]=1;E=d+48|0;D=c[r>>2]|0;if((D|0)!=0){B=D-1|0;c[r>>2]=B;sS(c[(c[Z>>2]|0)+(B*12|0)>>2]|0)}if((E|0)==0){$=0;break L6831}c[E>>2]=c[(c[Z>>2]|0)+((c[r>>2]|0)*12|0)+8>>2];$=0;break};case 9:{a[d+53|0]=1;$=0;break};case 0:{r=d+48|0;Z=c[r>>2]|0;if((Z|0)==0){c[r>>2]=(c[(c[d+44>>2]|0)+8>>2]|0)-1;$=0;break L6831}else{c[r>>2]=Z-1;$=0;break L6831}break};case 4:{Z=c[d+44>>2]|0;if((c[Z+8>>2]|0)==0){z=0;i=e;return z|0}r=d+48|0;E=c[r>>2]|0;B=c[Z>>2]|0;Z=c[B+(E*12|0)>>2]|0;D=c[B+(E*12|0)+4>>2]|0;B=D-31|0;do{if(!(B>>>0<24&((B>>>0)%3|0|0)==0|(D|0)==28)){if((D-73|0)>>>0<4|(D|0)==78|(D|0)==79){break}if((D|0)==88|(D|0)==71|(D|0)==57|(D|0)==1){break}Y=w-31|0;m=(w|0)==28;if(Y>>>0<24&((Y>>>0)%3|0|0)==0|m){if(m){m=p|0;hj(m,x,Z);jh(d+4180|0,iX(m,3)|0,m)}else{hj(d+4256+(((Y>>>0)/3|0)*4148|0)|0,x,Z)}a[_]=1;Y=c[u>>2]|0;m=c[Y+8>>2]|0;if((m|0)==0){aa=0}else{X=c[(c[Y>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((X|0)==26){$=0;break L6831}else{aa=X}}X=(r|0)==0;W=aa;C=Y;Y=m;while(1){m=C+8|0;if((Y|0)!=0){V=Y-1|0;c[m>>2]=V;sS(c[(c[C>>2]|0)+(V*12|0)>>2]|0)}if(!X){c[r>>2]=c[(c[C>>2]|0)+((c[m>>2]|0)*12|0)+8>>2]}m=c[u>>2]|0;V=c[m+8>>2]|0;if((V|0)==0){ab=W}else{ab=c[(c[m>>2]|0)+((V-1|0)*12|0)+4>>2]|0}if((ab|0)==26){$=0;break L6831}else{W=ab;C=m;Y=V}}}switch(w|0){case 56:{Y=c[c[(c[15704]|0)+113712>>2]>>2]|0;C=c[Y+(E*12|0)>>2]|0;hG(131072,c[Y+(E*12|0)+4>>2]|0)|0;Y=(C|0)==0;a[(c[15704]|0)+4176|0]=Y&1;L6892:do{if(Y){a[420498]=0}else{W=4096;X=420498;V=C;while(1){m=W-1|0;if((m|0)==0){break}P=a[V]|0;a[X]=P;if(P<<24>>24==0){break L6892}else{W=m;X=X+1|0;V=V+1|0}}a[X]=0;if((a[V]|0)==0){break}else{ac=V}do{ac=ac+1|0;}while((a[ac]|0)!=0)}}while(0);if((a[383584]&1)!=0){C=c[135158]|0;Y=(C|0)!=0?C:c[t>>2]|0;be(22536,35,1,Y|0)|0;Y=c[135158]|0;C=(Y|0)!=0?Y:c[t>>2]|0;a7(C|0)|0}a[_]=1;C=c[u>>2]|0;Y=c[C+8>>2]|0;if((Y|0)==0){ad=0;ae=C;af=Y}else{V=c[(c[C>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((V|0)==4){$=-1;break L6831}else{ad=V;ae=C;af=Y}}while(1){Y=ae+8|0;if((af|0)==0){ah=0;ai=ae;aj=ae|0}else{C=af-1|0;c[Y>>2]=C;V=ae|0;sS(c[(c[V>>2]|0)+(C*12|0)>>2]|0);ah=c[Y>>2]|0;ai=c[u>>2]|0;aj=V}c[r>>2]=c[(c[aj>>2]|0)+(ah*12|0)+8>>2];V=c[ai+8>>2]|0;if((V|0)==0){ak=ad}else{ak=c[(c[ai>>2]|0)+((V-1|0)*12|0)+4>>2]|0}if((ak|0)==4){$=-1;break L6831}else{ad=ak;ae=ai;af=V}}break};case 57:{a[_]=1;V=c[u>>2]|0;Y=c[V+8>>2]|0;if((Y|0)==0){al=0}else{C=c[(c[V>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((C|0)==4){$=0;break L6831}else{al=C}}C=(r|0)==0;X=al;W=V;V=Y;while(1){Y=W+8|0;if((V|0)!=0){m=V-1|0;c[Y>>2]=m;sS(c[(c[W>>2]|0)+(m*12|0)>>2]|0)}if(!C){c[r>>2]=c[(c[W>>2]|0)+((c[Y>>2]|0)*12|0)+8>>2]}Y=c[u>>2]|0;m=c[Y+8>>2]|0;if((m|0)==0){am=X}else{am=c[(c[Y>>2]|0)+((m-1|0)*12|0)+4>>2]|0}if((am|0)==4){$=0;break L6831}else{X=am;W=Y;V=m}}break};case 79:{V=4096;W=375332;X=x;while(1){C=V-1|0;if((C|0)==0){an=5056;break}m=a[X]|0;a[W]=m;if(m<<24>>24==0){break}else{V=C;W=W+1|0;X=X+1|0}}do{if((an|0)==5056){a[W]=0;if((a[X]|0)==0){break}else{ao=X}do{ao=ao+1|0;}while((a[ao]|0)!=0)}}while(0);a[_]=1;X=c[u>>2]|0;W=c[X+8>>2]|0;if((W|0)==0){ap=0}else{V=c[(c[X>>2]|0)+((W-1|0)*12|0)+4>>2]|0;if((V|0)==61){$=0;break L6831}else{ap=V}}V=(r|0)==0;C=ap;m=X;X=W;while(1){W=m+8|0;if((X|0)!=0){Y=X-1|0;c[W>>2]=Y;sS(c[(c[m>>2]|0)+(Y*12|0)>>2]|0)}if(!V){c[r>>2]=c[(c[m>>2]|0)+((c[W>>2]|0)*12|0)+8>>2]}W=c[u>>2]|0;Y=c[W+8>>2]|0;if((Y|0)==0){aq=C}else{aq=c[(c[W>>2]|0)+((Y-1|0)*12|0)+4>>2]|0}if((aq|0)==61){$=0;break L6831}else{C=aq;m=W;X=Y}}break};case 78:{X=4096;m=461458;C=x;while(1){V=X-1|0;if((V|0)==0){an=5014;break}Y=a[C]|0;a[m]=Y;if(Y<<24>>24==0){break}else{X=V;m=m+1|0;C=C+1|0}}do{if((an|0)==5014){a[m]=0;if((a[C]|0)==0){break}else{ar=C}do{ar=ar+1|0;}while((a[ar]|0)!=0)}}while(0);a[_]=1;C=c[u>>2]|0;m=c[C+8>>2]|0;if((m|0)==0){as=0}else{X=c[(c[C>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((X|0)==61){$=0;break L6831}else{as=X}}X=(r|0)==0;V=as;Y=C;C=m;while(1){m=Y+8|0;if((C|0)!=0){W=C-1|0;c[m>>2]=W;sS(c[(c[Y>>2]|0)+(W*12|0)>>2]|0)}if(!X){c[r>>2]=c[(c[Y>>2]|0)+((c[m>>2]|0)*12|0)+8>>2]}m=c[u>>2]|0;W=c[m+8>>2]|0;if((W|0)==0){at=V}else{at=c[(c[m>>2]|0)+((W-1|0)*12|0)+4>>2]|0}if((at|0)==61){$=0;break L6831}else{V=at;Y=m;C=W}}break};case 73:{C=4096;Y=379465;V=x;while(1){X=C-1|0;if((X|0)==0){an=4981;break}W=a[V]|0;a[Y]=W;if(W<<24>>24==0){break}else{C=X;Y=Y+1|0;V=V+1|0}}do{if((an|0)==4981){a[Y]=0;if((a[V]|0)==0){break}else{au=V}do{au=au+1|0;}while((a[au]|0)!=0)}}while(0);V=4096;Y=d+54|0;C=x;while(1){X=V-1|0;if((X|0)==0){an=4986;break}W=a[C]|0;a[Y]=W;if(W<<24>>24==0){break}else{V=X;Y=Y+1|0;C=C+1|0}}do{if((an|0)==4986){a[Y]=0;if((a[C]|0)==0){break}else{av=C}do{av=av+1|0;}while((a[av]|0)!=0)}}while(0);a[_]=1;C=c[u>>2]|0;Y=c[C+8>>2]|0;if((Y|0)==0){aw=0}else{V=c[(c[C>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((V|0)==61){$=0;break L6831}else{aw=V}}V=(r|0)==0;X=aw;W=C;C=Y;while(1){Y=W+8|0;if((C|0)!=0){m=C-1|0;c[Y>>2]=m;sS(c[(c[W>>2]|0)+(m*12|0)>>2]|0)}if(!V){c[r>>2]=c[(c[W>>2]|0)+((c[Y>>2]|0)*12|0)+8>>2]}Y=c[u>>2]|0;m=c[Y+8>>2]|0;if((m|0)==0){ax=X}else{ax=c[(c[Y>>2]|0)+((m-1|0)*12|0)+4>>2]|0}if((ax|0)==61){$=0;break L6831}else{X=ax;W=Y;C=m}}break};case 75:{C=4096;W=457362;X=x;while(1){V=C-1|0;if((V|0)==0){an=5028;break}m=a[X]|0;a[W]=m;if(m<<24>>24==0){break}else{C=V;W=W+1|0;X=X+1|0}}do{if((an|0)==5028){a[W]=0;if((a[X]|0)==0){break}else{ay=X}do{ay=ay+1|0;}while((a[ay]|0)!=0)}}while(0);a[_]=1;X=c[u>>2]|0;W=c[X+8>>2]|0;if((W|0)==0){az=0}else{C=c[(c[X>>2]|0)+((W-1|0)*12|0)+4>>2]|0;if((C|0)==61){$=0;break L6831}else{az=C}}C=(r|0)==0;V=az;m=X;X=W;while(1){W=m+8|0;if((X|0)!=0){Y=X-1|0;c[W>>2]=Y;sS(c[(c[m>>2]|0)+(Y*12|0)>>2]|0)}if(!C){c[r>>2]=c[(c[m>>2]|0)+((c[W>>2]|0)*12|0)+8>>2]}W=c[u>>2]|0;Y=c[W+8>>2]|0;if((Y|0)==0){aA=V}else{aA=c[(c[W>>2]|0)+((Y-1|0)*12|0)+4>>2]|0}if((aA|0)==61){$=0;break L6831}else{V=aA;m=W;X=Y}}break};case 88:{hj(342552,x,Z);X=c[136908]|0;if((X|0)!=0){m=X+24|0;V=X+12|0;C=c[V>>2]|0;if((c[m>>2]|0)==0){aB=C}else{Y=0;W=C;while(1){sS(c[W+(Y*136|0)>>2]|0);sS(c[W+(Y*136|0)+8>>2]|0);C=Y+1|0;P=c[V>>2]|0;if(C>>>0<(c[m>>2]|0)>>>0){Y=C;W=P}else{aB=P;break}}}sS(aB);W=c[X+4>>2]|0;if((W|0)!=0){f0[c[W>>2]&255](c[X>>2]|0,0)}sS(X)}W=iC()|0;c[136908]=W;if((W|0)==0){W=c[135158]|0;Y=(W|0)!=0?W:c[t>>2]|0;be(36504,45,1,Y|0)|0;Y=c[135158]|0;W=(Y|0)!=0?Y:c[t>>2]|0;a7(W|0)|0}a[_]=1;W=c[u>>2]|0;Y=c[W+8>>2]|0;if((Y|0)==0){aC=0}else{m=c[(c[W>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((m|0)==60){$=0;break L6831}else{aC=m}}m=(r|0)==0;V=aC;P=W;W=Y;while(1){Y=P+8|0;if((W|0)!=0){C=W-1|0;c[Y>>2]=C;sS(c[(c[P>>2]|0)+(C*12|0)>>2]|0)}if(!m){c[r>>2]=c[(c[P>>2]|0)+((c[Y>>2]|0)*12|0)+8>>2]}Y=c[u>>2]|0;C=c[Y+8>>2]|0;if((C|0)==0){aD=V}else{aD=c[(c[Y>>2]|0)+((C-1|0)*12|0)+4>>2]|0}if((aD|0)==60){$=0;break L6831}else{V=aD;P=Y;W=C}}break};case 74:{W=4096;P=289493;V=x;while(1){m=W-1|0;if((m|0)==0){an=5042;break}X=a[V]|0;a[P]=X;if(X<<24>>24==0){break}else{W=m;P=P+1|0;V=V+1|0}}do{if((an|0)==5042){a[P]=0;if((a[V]|0)==0){break}else{aE=V}do{aE=aE+1|0;}while((a[aE]|0)!=0)}}while(0);a[_]=1;V=c[u>>2]|0;P=c[V+8>>2]|0;if((P|0)==0){aF=0}else{W=c[(c[V>>2]|0)+((P-1|0)*12|0)+4>>2]|0;if((W|0)==61){$=0;break L6831}else{aF=W}}W=(r|0)==0;m=aF;X=V;V=P;while(1){P=X+8|0;if((V|0)!=0){C=V-1|0;c[P>>2]=C;sS(c[(c[X>>2]|0)+(C*12|0)>>2]|0)}if(!W){c[r>>2]=c[(c[X>>2]|0)+((c[P>>2]|0)*12|0)+8>>2]}P=c[u>>2]|0;C=c[P+8>>2]|0;if((C|0)==0){aG=m}else{aG=c[(c[P>>2]|0)+((C-1|0)*12|0)+4>>2]|0}if((aG|0)==61){$=0;break L6831}else{m=aG;X=P;V=C}}break};case 76:{V=4096;X=453266;m=x;while(1){W=V-1|0;if((W|0)==0){an=5e3;break}C=a[m]|0;a[X]=C;if(C<<24>>24==0){break}else{V=W;X=X+1|0;m=m+1|0}}do{if((an|0)==5e3){a[X]=0;if((a[m]|0)==0){break}else{aH=m}do{aH=aH+1|0;}while((a[aH]|0)!=0)}}while(0);a[_]=1;m=c[u>>2]|0;X=c[m+8>>2]|0;if((X|0)==0){aI=0}else{V=c[(c[m>>2]|0)+((X-1|0)*12|0)+4>>2]|0;if((V|0)==61){$=0;break L6831}else{aI=V}}V=(r|0)==0;W=aI;C=m;m=X;while(1){X=C+8|0;if((m|0)!=0){P=m-1|0;c[X>>2]=P;sS(c[(c[C>>2]|0)+(P*12|0)>>2]|0)}if(!V){c[r>>2]=c[(c[C>>2]|0)+((c[X>>2]|0)*12|0)+8>>2]}X=c[u>>2]|0;P=c[X+8>>2]|0;if((P|0)==0){aJ=W}else{aJ=c[(c[X>>2]|0)+((P-1|0)*12|0)+4>>2]|0}if((aJ|0)==61){$=0;break L6831}else{W=aJ;C=X;m=P}}break};case 71:{m=q|0;hj(m,x,Z);C=h|0;gZ(1,0);gm[c[120648]&31]()|0;W=gm[c[120646]&31]()|0;if((W|0)!=0){V=W-1|0;s_(f|0,0,16);c[f>>2]=m;W=c[120647]|0;gj[W&127](V,f)|0;g_(V);b5(C|0,512,34096,(Q=i,i=i+8|0,c[Q>>2]=m,Q)|0)|0;i=Q;if((a[383584]&1)!=0){V=c[135158]|0;W=(V|0)!=0?V:c[t>>2]|0;eQ(W|0,48248,(Q=i,i=i+8|0,c[Q>>2]=C,Q)|0)|0;i=Q;W=c[135158]|0;V=(W|0)!=0?W:c[t>>2]|0;a7(V|0)|0}V=c[133027]|0;W=V+4|0;P=c[W>>2]|0;if(P>>>0>1){X=V|0;Y=1;U=P;while(1){P=c[(c[X>>2]|0)+(Y<<2)>>2]|0;if((P|0)==0){aK=U}else{sS(c[P+8>>2]|0);sS(c[(c[X>>2]|0)+(Y<<2)>>2]|0);c[(c[X>>2]|0)+(Y<<2)>>2]=0;aK=c[W>>2]|0}P=Y+1|0;if(P>>>0<aK>>>0){Y=P;U=aK}else{break}}}c[W>>2]=1;U=V+12|0;sS(c[U>>2]|0);c[U>>2]=0;U=c[133027]|0;Y=U+4|0;L7126:do{if((c[Y>>2]|0)>>>0<(c[U+8>>2]|0)>>>0){X=sR(12)|0;do{if((X|0)!=0){if((c[X-4>>2]&3|0)==0){break}s_(X|0,0,12)}}while(0);c[X+4>>2]=0;c[X>>2]=180;P=dT(C|0)|0;s=c[Y>>2]|0;c[X+8>>2]=P;P=U|0;c[(c[P>>2]|0)+(s<<2)>>2]=X;s=c[Y>>2]|0;c[Y>>2]=s+1;if(s>>>0>1){aL=s}else{break}while(1){s=aL>>>1;T=c[P>>2]|0;L=T+(s<<2)|0;S=c[L>>2]|0;R=c[T+(aL<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[S+4>>2]|0)>>>0){break L7126}c[L>>2]=R;c[(c[P>>2]|0)+(aL<<2)>>2]=S;if(aL>>>0>3){aL=s}else{break}}}}while(0);g$(m);g0();gZ(0,0)}Y=540624;U=c[Y+4>>2]|0;C=540624;c[C>>2]=c[Y>>2]|1;c[C+4>>2]=U;a[_]=1;U=c[u>>2]|0;C=c[U+8>>2]|0;if((C|0)==0){aM=0;aN=U;aO=C}else{Y=c[(c[U>>2]|0)+((C-1|0)*12|0)+4>>2]|0;if((Y|0)==4){$=-1;break L6831}else{aM=Y;aN=U;aO=C}}while(1){C=aN+8|0;if((aO|0)==0){aP=0;aQ=aN;aR=aN|0}else{U=aO-1|0;c[C>>2]=U;Y=aN|0;sS(c[(c[Y>>2]|0)+(U*12|0)>>2]|0);aP=c[C>>2]|0;aQ=c[u>>2]|0;aR=Y}c[r>>2]=c[(c[aR>>2]|0)+(aP*12|0)+8>>2];Y=c[aQ+8>>2]|0;if((Y|0)==0){aS=aM}else{aS=c[(c[aQ>>2]|0)+((Y-1|0)*12|0)+4>>2]|0}if((aS|0)==4){$=-1;break L6831}else{aM=aS;aN=aQ;aO=Y}}break};default:{hj(420498,x,Z);m=540624;Y=c[m+4>>2]|0;C=540624;c[C>>2]=c[m>>2]|2;c[C+4>>2]=Y;a[_]=1;Y=c[u>>2]|0;C=c[Y+8>>2]|0;if((C|0)==0){aT=0;aU=Y;aV=C;an=5070}else{m=c[(c[Y>>2]|0)+((C-1|0)*12|0)+4>>2]|0;if((m|0)!=4){aT=m;aU=Y;aV=C;an=5070}}if((an|0)==5070){while(1){an=0;C=aU+8|0;if((aV|0)==0){aW=0;aX=aU;aY=aU|0}else{Y=aV-1|0;c[C>>2]=Y;m=aU|0;sS(c[(c[m>>2]|0)+(Y*12|0)>>2]|0);aW=c[C>>2]|0;aX=c[u>>2]|0;aY=m}c[r>>2]=c[(c[aY>>2]|0)+(aW*12|0)+8>>2];m=c[aX+8>>2]|0;if((m|0)==0){aZ=aT}else{aZ=c[(c[aX>>2]|0)+((m-1|0)*12|0)+4>>2]|0}if((aZ|0)==4){break}else{aT=aZ;aU=aX;aV=m;an=5070}}}a[d+53|0]=1;$=-1;break L6831}}}}while(0);E=o|0;hj(E,x,Z);B=c[u>>2]|0;m=c[r>>2]|0;if((B|0)!=0){C=B+8|0;Y=B+4|0;U=c[Y>>2]|0;if((c[C>>2]|0)>>>0<U>>>0){a_=B|0}else{V=(U<<1)+2|0;c[Y>>2]=V;Y=B|0;c[Y>>2]=sT(c[Y>>2]|0,V*12|0)|0;a_=Y}Y=dT(E|0)|0;c[(c[a_>>2]|0)+((c[C>>2]|0)*12|0)>>2]=Y;c[(c[a_>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=D;c[(c[a_>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=m;c[C>>2]=(c[C>>2]|0)+1}c[r>>2]=0;a[_]=1;$=0;break};case 2:{C=d+48|0;m=c[C>>2]|0;if(m>>>0>8){c[C>>2]=m-8;$=0;break L6831}else{c[C>>2]=0;$=0;break L6831}break};case 3:{C=d+48|0;m=(c[C>>2]|0)+8|0;Y=c[(c[d+44>>2]|0)+8>>2]|0;if(m>>>0<Y>>>0){c[C>>2]=m;$=0;break L6831}else{c[C>>2]=Y-1;$=0;break L6831}break};default:{$=0}}}while(0);a_=c[u>>2]|0;u=c[a_+8>>2]|0;if((u|0)==0){a$=w;a0=x}else{x=u-1|0;u=c[a_>>2]|0;a$=c[u+(x*12|0)+4>>2]|0;a0=c[u+(x*12|0)>>2]|0}L7168:do{if((a[_]&1)!=0){do{if((a$|0)!=1){x=a$-31|0;if(x>>>0<24&((x>>>0)%3|0|0)==0|(a$|0)==28){break}if((a$-73|0)>>>0<4|(a$|0)==78|(a$|0)==79){break}if(!((a$|0)==88|(a$|0)==71|(a$|0)==57|(a$|0)==56)){break L7168}}}while(0);a[_]=0;r=d+44|0;D=c[r>>2]|0;Z=D+8|0;if((c[Z>>2]|0)!=0){x=D|0;D=0;do{sS(c[(c[x>>2]|0)+(D*12|0)>>2]|0);D=D+1|0;}while(D>>>0<(c[Z>>2]|0)>>>0)}c[Z>>2]=0;L7180:do{if((a$|0)==56){D=k|0;x=l|0;u=d+113712|0;a_=c[u>>2]|0;w=c[a_+4>>2]|0;if((w|0)==0){break}else{a1=0;a2=a_}while(1){a_=c[a2>>2]|0;o=c[a_+(a1*12|0)>>2]|0;an=c[a_+(a1*12|0)+8>>2]|0;L7184:do{if((o|0)==0){a_=4096;aV=D;aX=an;while(1){aU=a_-1|0;if((aU|0)==0){break}aZ=a[aX]|0;a[aV]=aZ;if(aZ<<24>>24==0){break L7184}else{a_=aU;aV=aV+1|0;aX=aX+1|0}}a[aV]=0;if((a[aX]|0)==0){break}else{a3=aX}do{a3=a3+1|0;}while((a[a3]|0)!=0)}else{aX=cD(o|0,47)|0;hk(x,(aX|0)==0?o:aX+1|0,547872);b5(D|0,4096,17872,(Q=i,i=i+16|0,c[Q>>2]=x,c[Q+8>>2]=an,Q)|0)|0;i=Q}}while(0);an=c[r>>2]|0;if((an|0)!=0){o=an+8|0;aX=an+4|0;aV=c[aX>>2]|0;if((c[o>>2]|0)>>>0<aV>>>0){a4=an|0}else{a_=(aV<<1)+2|0;c[aX>>2]=a_;aX=an|0;c[aX>>2]=sT(c[aX>>2]|0,a_*12|0)|0;a4=aX}aX=dT(D|0)|0;c[(c[a4>>2]|0)+((c[o>>2]|0)*12|0)>>2]=aX;c[(c[a4>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=0;c[(c[a4>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1}o=a1+1|0;if(o>>>0>=w>>>0){break L7180}a1=o;a2=c[u>>2]|0}}else{u=c[r>>2]|0;w=j|0;if((a[a0]|0)==0){if((u|0)==0){break}D=u+8|0;x=u+4|0;o=c[x>>2]|0;if((c[D>>2]|0)>>>0<o>>>0){a5=u|0}else{aX=(o<<1)+2|0;c[x>>2]=aX;x=u|0;c[x>>2]=sT(c[x>>2]|0,aX*12|0)|0;a5=x}x=dT(19232)|0;c[(c[a5>>2]|0)+((c[D>>2]|0)*12|0)>>2]=x;c[(c[a5>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=a$;c[(c[a5>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;break}do{if((a$|0)==57){a6=547872}else if((a$|0)==28){a6=18936}else{D=a$-31|0;if(D>>>0<24&((D>>>0)%3|0|0)==0){a6=18600;break}if((a$|0)==88){a6=18400;break}if((a$-73|0)>>>0<4|(a$|0)==78|(a$|0)==79){a6=547872;break}D=c[d+4168>>2]|0;if((D|0)==0){a6=478464;break}if((a[D]|0)==0){a[w]=0;a6=w;break}else{b5(w|0,1024,18224,(Q=i,i=i+8|0,c[Q>>2]=D,Q)|0)|0;i=Q;a6=w;break}}}while(0);w=hi(a0,a6,1)|0;if((w|0)==0){break}D=w|0;x=w+4|0;dL(c[D>>2]|0,c[x>>2]|0,8,94);aX=(a$-73|0)>>>0<4|(a$|0)==78|(a$|0)==79;o=(u|0)==0;if(!(o|aX^1)){a_=u+8|0;an=u+4|0;aV=c[an>>2]|0;if((c[a_>>2]|0)>>>0<aV>>>0){a8=u|0}else{aU=(aV<<1)+2|0;c[an>>2]=aU;an=u|0;c[an>>2]=sT(c[an>>2]|0,aU*12|0)|0;a8=an}an=dT(18008)|0;c[(c[a8>>2]|0)+((c[a_>>2]|0)*12|0)>>2]=an;c[(c[a8>>2]|0)+((c[a_>>2]|0)*12|0)+4>>2]=3;c[(c[a8>>2]|0)+((c[a_>>2]|0)*12|0)+8>>2]=0;c[a_>>2]=(c[a_>>2]|0)+1}a_=c[x>>2]|0;do{if((a_|0)==0){a9=c[D>>2]|0}else{an=u+8|0;aU=u+4|0;aV=u|0;if(aX){aZ=0;aT=a_;while(1){aW=c[D>>2]|0;do{if((a[aW+(aZ<<3)+4|0]&1)==0){ba=aT}else{aY=c[aW+(aZ<<3)>>2]|0;if((a[a0]|0)==0){bb=aY}else{aO=cD(aY|0,47)|0;bb=(aO|0)==0?aY:aO+1|0}if(o){ba=aT;break}aO=c[aU>>2]|0;if((c[an>>2]|0)>>>0>=aO>>>0){aY=(aO<<1)+2|0;c[aU>>2]=aY;c[aV>>2]=sT(c[aV>>2]|0,aY*12|0)|0}aY=dT(bb|0)|0;c[(c[aV>>2]|0)+((c[an>>2]|0)*12|0)>>2]=aY;c[(c[aV>>2]|0)+((c[an>>2]|0)*12|0)+4>>2]=a$;c[(c[aV>>2]|0)+((c[an>>2]|0)*12|0)+8>>2]=0;c[an>>2]=(c[an>>2]|0)+1;ba=c[x>>2]|0}}while(0);aW=aZ+1|0;if(aW>>>0<ba>>>0){aZ=aW;aT=ba}else{bc=ba;break}}}else{aT=0;aZ=a_;while(1){aW=c[D>>2]|0;aY=a[aW+(aT<<3)+4|0]|0;aO=c[aW+(aT<<3)>>2]|0;if((a[a0]|0)==0){bd=aO}else{aW=cD(aO|0,47)|0;bd=(aW|0)==0?aO:aW+1|0}aW=(aY&1)!=0?a$:0;if(o){bf=aZ}else{aY=c[aU>>2]|0;if((c[an>>2]|0)>>>0>=aY>>>0){aO=(aY<<1)+2|0;c[aU>>2]=aO;c[aV>>2]=sT(c[aV>>2]|0,aO*12|0)|0}aO=dT(bd|0)|0;c[(c[aV>>2]|0)+((c[an>>2]|0)*12|0)>>2]=aO;c[(c[aV>>2]|0)+((c[an>>2]|0)*12|0)+4>>2]=aW;c[(c[aV>>2]|0)+((c[an>>2]|0)*12|0)+8>>2]=0;c[an>>2]=(c[an>>2]|0)+1;bf=c[x>>2]|0}aW=aT+1|0;if(aW>>>0<bf>>>0){aT=aW;aZ=bf}else{bc=bf;break}}}aZ=c[D>>2]|0;if((bc|0)==0){a9=aZ;break}else{bg=0;bh=aZ}while(1){sS(c[bh+(bg<<3)>>2]|0);aZ=bg+1|0;aT=c[D>>2]|0;if(aZ>>>0<(c[x>>2]|0)>>>0){bg=aZ;bh=aT}else{a9=aT;break}}}}while(0);sS(a9);sS(w)}}while(0);Z=d+48|0;x=c[(c[r>>2]|0)+8>>2]|0;D=(x|0)==0;if(!((c[Z>>2]|0)>>>0<x>>>0|D)){c[Z>>2]=x-1;break}if(!D){break}c[Z>>2]=0}}while(0);ji(d);z=$;i=e;return z|0}function jg(b,d){b=b|0;d=d|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0.0,S=0.0,T=0.0,U=0.0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0.0,aU=0,aV=0.0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0.0,a2=0,a3=0.0,a4=0,a5=0.0,a6=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0;f=i;i=i+13184|0;j=f|0;k=f+128|0;l=f+192|0;m=f+256|0;n=f+320|0;o=f+384|0;p=f+448|0;q=f+512|0;r=f+4608|0;s=f+4672|0;u=f+8768|0;v=f+9024|0;w=f+9088|0;c[b+32>>2]=640;do{if((d|0)==6){x=0;y=0}else{z=c[b+48>>2]|0;A=c[c[b+44>>2]>>2]|0;B=c[A+(z*12|0)>>2]|0;C=c[A+(z*12|0)+4>>2]|0;if((C|0)==57){x=547872;y=57;break}else if((C|0)==71){x=b+54|0;y=71;break}else{x=B;y=C;break}}}while(0);C=b+40|0;B=c[C>>2]|0;z=B+8|0;A=c[z>>2]|0;if((A|0)==0){D=0}else{D=c[(c[B>>2]|0)+((A-1|0)*12|0)+4>>2]|0}E=b+52|0;F=(a[E]&1)==0?d:10;L7277:do{switch(F|0){case 5:{if(A>>>0<=1){break L7277}d=b+48|0;G=A-1|0;c[z>>2]=G;H=B|0;sS(c[(c[H>>2]|0)+(G*12|0)>>2]|0);if((d|0)!=0){c[d>>2]=c[(c[H>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]}a[E]=1;break};case 2:case 3:case 4:case 8:{H=(F|0)==4;if((y|0)==55&H){d=b+54|0;G=b+48|0;I=c[G>>2]|0;if((B|0)!=0){J=B+4|0;L=c[J>>2]|0;if(A>>>0<L>>>0){M=B|0}else{N=(L<<1)+2|0;c[J>>2]=N;J=B|0;c[J>>2]=sT(c[J>>2]|0,N*12|0)|0;M=J}J=dT(d|0)|0;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)>>2]=J;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=1;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=I;c[z>>2]=(c[z>>2]|0)+1}c[G>>2]=0;a[E]=1;break L7277}do{if((y|0)==56){if(!H){break L7277}}else{if(((y-73|0)>>>0<4|(y|0)==78|(y|0)==79)&H){break}L7298:do{switch(y|0){case 69:case 62:case 61:case 59:case 58:case 26:case 5:case 4:case 60:case 71:case 57:{if(!H){break L7298}G=b+48|0;I=c[G>>2]|0;if((B|0)!=0){J=B+4|0;d=c[J>>2]|0;if(A>>>0<d>>>0){O=B|0}else{N=(d<<1)+2|0;c[J>>2]=N;J=B|0;c[J>>2]=sT(c[J>>2]|0,N*12|0)|0;O=J}J=dT(x|0)|0;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)>>2]=J;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=I;c[z>>2]=(c[z>>2]|0)+1}c[G>>2]=0;a[E]=1;break L7277;break};default:{if(!((y|0)==12&H)){break L7298}G=c[b+48>>2]|0;if((B|0)!=0){I=B+4|0;J=c[I>>2]|0;if(A>>>0<J>>>0){P=B|0}else{N=(J<<1)+2|0;c[I>>2]=N;I=B|0;c[I>>2]=sT(c[I>>2]|0,N*12|0)|0;P=I}I=dT(547872)|0;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)>>2]=I;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=12;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=G;c[z>>2]=(c[z>>2]|0)+1}f0[c[(c[136863]|0)+44>>2]&255](c[136866]|0,540572);g[2715]=+((c[135145]|0)>>>0>>>0)/+((c[135146]|0)>>>0>>>0);c[70322]=7;G=c[(c[136914]|0)+12>>2]|0;if((G|0)==0){break L7277}f0[G&255](c[136866]|0,7);break L7277}}}while(0);G=b+113708|0;I=c[G>>2]|0;if((y-6|0)>>>0<20){switch(y|0){case 18:{if((F|0)==8){c[70318]=0;break L7277}else if((F|0)==2){N=c[70318]|0;if((N|0)==0){break L7277}c[70318]=N-1;break L7277}else if((F|0)==3|(F|0)==4){N=c[70318]|0;if(N>>>0>=3){break L7277}c[70318]=N+1;break L7277}else{break L7277}break};case 20:{N=c[70317]|0;if((F|0)==3|(F|0)==4){J=N+1|0;c[70317]=J;Q=J}else if((F|0)==8){c[70317]=1;Q=1}else if((F|0)==2){J=N-1|0;c[70317]=J;Q=J}else{Q=N}J=Q>>>0<4?Q:4;d=J>>>0>1?J:1;c[70317]=d;J=c[136863]|0;L=c[136866]|0;if(!((N|0)!=(d|0)&(J|0)!=0&(L|0)!=0)){break L7277}f0[c[J+8>>2]&255](L,0);break L7277;break};case 9:{if((F|0)==8){c[135150]=0;L=c[(c[136914]|0)+16>>2]|0;if((L|0)==0){break L7277}f$[L&511](c[136866]|0);break L7277}else if((F|0)==2){L=c[135150]|0;if((L|0)==0){break L7277}c[135150]=L-1;L=c[(c[136914]|0)+16>>2]|0;if((L|0)==0){break L7277}f$[L&511](c[136866]|0);break L7277}else{if(!((F|0)==3&(c[135150]|0)==0)){break L7277}c[135150]=1;L=c[(c[136914]|0)+16>>2]|0;if((L|0)==0){break L7277}f$[L&511](c[136866]|0);break L7277}break};case 21:case 22:{L=(y|0)==21?281240:281244;R=+g[L>>2];if((F|0)==8){g[L>>2]=3.0;S=3.0}else if((F|0)==2){T=R+-1.0;g[L>>2]=T;S=T}else if((F|0)==3){T=R+1.0;g[L>>2]=T;S=T}else{S=R}T=+bZ(+S);U=T>1.0?T:1.0;g[L>>2]=U;if(R==U){break L7277}if((a[281248]&1)!=0){break L7277}gW(0);break L7277;break};case 19:{if((F|0)==8){a[281266]=0;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){a[281266]=a[281266]&1^1;break L7277}else{break L7277}break};case 23:{if((F|0)==8){a[281278]=1;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){a[281278]=a[281278]&1^1;break L7277}else{break L7277}break};case 10:{do{if((F|0)==8){a[281285]=0}else{if((F-2|0)>>>0>=3){break}a[281285]=a[281285]&1^1}}while(0);L=c[(c[136914]|0)+16>>2]|0;if((L|0)==0){break L7277}f$[L&511](c[136866]|0);break L7277;break};case 15:{if((F|0)==3){L=c[135149]|0;if(L>>>0<3){J=L+1|0;c[135149]=J;V=J}else{V=L}f0[c[(c[136863]|0)+40>>2]&255](c[136866]|0,V);break L7277}else if((F|0)==8){g[76493]=.004999999888241291;a[305969]=1;f0[c[(c[136863]|0)+40>>2]&255](c[136866]|0,c[135149]|0);break L7277}else if((F|0)==2){L=c[135149]|0;if((L|0)==0){W=0}else{J=L-1|0;c[135149]=J;W=J}f0[c[(c[136863]|0)+40>>2]&255](c[136866]|0,W);break L7277}else{break L7277}break};case 24:{if((F|0)==8){J=531936;c[J>>2]=0;c[J+4>>2]=0;break L7277}else if((F|0)!=4){break L7277}if((a[289492]&1)!=0){break L7277}J=531936;L=c[J>>2]|0;d=c[J+4>>2]|0;J=0;N=d>>>0>J>>>0|d>>>0==J>>>0&L>>>0>2048>>>0?2048:L;if(N>>>0<2){break L7277}else{X=0;Y=0;Z=0}do{L=515552+(X<<3)|0;Z=ta(c[L>>2]|0,c[L+4>>2]|0,Z,Y)|0;Y=K;X=X+1|0;}while(X>>>0<N>>>0);L=ti(Z,Y,N,0)|0;U=1.0e6/(+(L>>>0)+ +(K|0)*4294967296.0);L=u|0;b5(L|0,256,26928,(_=i,i=i+8|0,h[_>>3]=U,_)|0)|0;i=_;J=c[133027]|0;d=J+4|0;L7388:do{if((c[d>>2]|0)>>>0<(c[J+8>>2]|0)>>>0){$=sR(12)|0;do{if(($|0)!=0){if((c[$-4>>2]&3|0)==0){break}s_($|0,0,12)}}while(0);c[$+4>>2]=1;c[$>>2]=180;aa=dT(L|0)|0;ab=c[d>>2]|0;c[$+8>>2]=aa;aa=J|0;c[(c[aa>>2]|0)+(ab<<2)>>2]=$;ab=c[d>>2]|0;c[d>>2]=ab+1;if(ab>>>0>1){ac=ab}else{break}while(1){ab=ac>>>1;ad=c[aa>>2]|0;ae=ad+(ab<<2)|0;af=c[ae>>2]|0;ag=c[ad+(ac<<2)>>2]|0;if((c[ag+4>>2]|0)>>>0<=(c[af+4>>2]|0)>>>0){break L7388}c[ae>>2]=ag;c[(c[aa>>2]|0)+(ac<<2)>>2]=af;if(ac>>>0>3){ac=ab}else{break}}}}while(0);if((a[383584]&1)!=0){d=c[135158]|0;J=(d|0)!=0?d:c[t>>2]|0;eQ(J|0,48248,(_=i,i=i+8|0,c[_>>2]=L,_)|0)|0;i=_;J=c[135158]|0;d=(J|0)!=0?J:c[t>>2]|0;a7(d|0)|0}g[72372]=U;hn();R=+((c[74440]|0)>>>0>>>0)/+g[74442];h[60338]=R;h[60344]=R;f0[c[(c[136863]|0)+8>>2]&255](c[136866]|0,0);break L7277;break};case 11:{do{if((F|0)==8){c[70322]=4}else if((F|0)==2){d=c[70322]|0;if((d|0)==0){break}c[70322]=d-1}else if((F|0)==3){d=c[70322]|0;if(d>>>0>=7){break}c[70322]=d+1}}while(0);L=c[(c[136914]|0)+12>>2]|0;if((L|0)==0){break L7277}f0[L&255](c[136866]|0,c[70322]|0);break L7277;break};case 17:{if((F|0)==8){a[281265]=0;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){a[281265]=a[281265]&1^1;break L7277}else{break L7277}break};case 7:{if((F|0)==8){ah=1}else{ah=a[281276]&1^1}a[281276]=ah;L=c[c[136914]>>2]|0;if((L|0)==0){break L7277}go[L&127](c[136866]|0,1,(ah&1)!=0);break L7277;break};case 14:{if(!H){break L7277}gW((a[281248]&1)==0);break L7277;break};case 16:{if((F|0)==2|(F|0)==3|(F|0)==4){a[281264]=a[281264]&1^1;break L7277}else if((F|0)==8){a[281264]=1;break L7277}else{break L7277}break};default:{break L7277}}}if((y-27|0)>>>0<28){L=w|0;d=y-31|0;J=y-32|0;N=y-33|0;if((y|0)==27){if((F|0)==8){a[281276]=1;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){a[281276]=a[281276]&1^1;break L7277}else{break L7277}}else if((y|0)==29){if(!((c[(c[136863]|0)+20>>2]|0)!=0&H)){break L7277}if((a[383584]&1)!=0){aa=c[135158]|0;$=(aa|0)!=0?aa:c[t>>2]|0;be(45624,31,1,$|0)|0;$=c[135158]|0;aa=($|0)!=0?$:c[t>>2]|0;a7(aa|0)|0}aa=b+4252|0;$=c[aa>>2]|0;L7438:do{if(($|0)!=0){ab=3;af=0;while(1){ag=iX(b+4256+(af*4148|0)|0,3)|0;if(!((ag|0)==0|(ag|0)==2)){break L7438}if((ab|0)==3){ai=ag}else{if((ab|0)==(ag|0)){ai=ab}else{break L7438}}ag=af+1|0;if(ag>>>0<$>>>0){ab=ai;af=ag}else{break}}if((ai|0)==3){break}hj(L,(a[289493]|0)!=0?289493:375332,(ai|0)==2?45584:45408);af=sR(20)|0;if((af|0)==0){break L7277}if((c[af-4>>2]&3|0)!=0){s_(af|0,0,20)}ab=af;af=p|0;ag=q|0;ae=r|0;ad=s|0;aj=j|0;b5(aj|0,128,11024,(_=i,i=i+8|0,c[_>>2]=c[aa>>2],_)|0)|0;i=_;hC(ab,46400,aj);if((c[aa>>2]|0)!=0){ak=l|0;al=k|0;am=0;do{b5(af|0,64,29672,(_=i,i=i+8|0,c[_>>2]=am,_)|0)|0;i=_;hC(ab,af,b+4256+(am*4148|0)|0);an=b+4256+(am*4148|0)+4136|0;if((c[an>>2]|0)!=0){b5(af|0,64,29256,(_=i,i=i+8|0,c[_>>2]=am,_)|0)|0;i=_;hC(ab,af,(c[an>>2]|0)==1?51224:30680)}b5(af|0,64,28472,(_=i,i=i+8|0,c[_>>2]=am,_)|0)|0;i=_;an=c[b+4256+(am*4148|0)+4140>>2]|0;if((an|0)==1){ao=17880}else if((an|0)==2){ao=17696}else if((an|0)==3){ao=17488}else if((an|0)==0){ao=18032}else{ao=17240}hC(ab,af,ao);an=b+4256+(am*4148|0)+4144|0;if((c[an>>2]|0)!=0){b5(af|0,64,28016,(_=i,i=i+8|0,c[_>>2]=am,_)|0)|0;i=_;ap=c[an>>2]|0;b5(aj|0,128,11024,(_=i,i=i+8|0,c[_>>2]=ap,_)|0)|0;i=_;hC(ab,af,aj)}b5(ak|0,64,19672,(_=i,i=i+8|0,c[_>>2]=am,_)|0)|0;i=_;hC(ab,ak,(a[b+4256+(am*4148|0)+4132|0]&1)!=0?51224:30680);do{if((a[b+4256+(am*4148|0)+4104|0]&1)!=0){ap=c[b+4256+(am*4148|0)+4108>>2]|0;U=+g[b+4256+(am*4148|0)+4116>>2];an=c[b+4256+(am*4148|0)+4124>>2]|0;b5(al|0,64,19240,(_=i,i=i+16|0,c[_>>2]=57160,c[_+8>>2]=am,_)|0)|0;i=_;if((ap|0)==2){aq=18408}else if((ap|0)==1){aq=18232}else if((ap|0)==0){aq=18608}else{aq=19768}hC(ab,al,aq);b5(al|0,64,19024,(_=i,i=i+16|0,c[_>>2]=57160,c[_+8>>2]=am,_)|0)|0;i=_;if((ap|0)==1){b5(aj|0,128,11024,(_=i,i=i+8|0,c[_>>2]=an,_)|0)|0;i=_;hC(ab,al,aj)}else{R=U;b5(aj|0,128,42608,(_=i,i=i+8|0,h[_>>3]=R,_)|0)|0;i=_;hC(ab,al,aj)}an=c[b+4256+(am*4148|0)+4112>>2]|0;R=+g[b+4256+(am*4148|0)+4120>>2];ap=c[b+4256+(am*4148|0)+4128>>2]|0;b5(al|0,64,19240,(_=i,i=i+16|0,c[_>>2]=57152,c[_+8>>2]=am,_)|0)|0;i=_;if((an|0)==2){ar=18408}else if((an|0)==1){ar=18232}else if((an|0)==0){ar=18608}else{ar=19768}hC(ab,al,ar);b5(al|0,64,19024,(_=i,i=i+16|0,c[_>>2]=57152,c[_+8>>2]=am,_)|0)|0;i=_;if((an|0)==1){b5(aj|0,128,11024,(_=i,i=i+8|0,c[_>>2]=ap,_)|0)|0;i=_;hC(ab,al,aj);break}else{U=R;b5(aj|0,128,42608,(_=i,i=i+8|0,h[_>>3]=U,_)|0)|0;i=_;hC(ab,al,aj);break}}}while(0);am=am+1|0;}while(am>>>0<(c[aa>>2]|0)>>>0)}am=b+70624|0;do{if((c[am>>2]|0)!=0){s_(ag|0,0,4096);al=4096;ak=ag;af=b+70628|0;while(1){ap=al-1|0;if((ap|0)==0){as=5348;break}an=a[af]|0;a[ak]=an;if(an<<24>>24==0){break}else{al=ap;ak=ak+1|0;af=af+1|0}}do{if((as|0)==5348){a[ak]=0;if((a[af]|0)==0){break}else{at=af}do{at=at+1|0;}while((a[at]|0)!=0)}}while(0);if((c[am>>2]|0)>>>0>1){af=1;do{ak=sZ(ag|0)|0;al=ak>>>0>4096?0:4096-ak|0;L7501:do{if((al|0)==0){au=27664;as=5355}else{ap=q+ak|0;do{if((al|0)==1){av=27664;aw=ap}else{an=q+(ak+1)|0;a[ap]=59;if((al|0)==2){av=27665;aw=an;break}a[an]=0;break L7501}}while(0);a[aw]=0;au=av;as=5355}}while(0);do{if((as|0)==5355){as=0;if((a[au]|0)==0){break}else{ax=au}do{ax=ax+1|0;}while((a[ax]|0)!=0)}}while(0);al=b+70628+(af*4168|0)|0;ak=sZ(ag|0)|0;ap=ak>>>0>4096?0:4096-ak|0;L7512:do{if((ap|0)==0){ay=al;as=5362}else{an=ap;az=q+ak|0;aA=al;while(1){aB=an-1|0;if((aB|0)==0){break}aC=a[aA]|0;a[az]=aC;if(aC<<24>>24==0){break L7512}else{an=aB;az=az+1|0;aA=aA+1|0}}a[az]=0;ay=aA;as=5362}}while(0);do{if((as|0)==5362){as=0;if((a[ay]|0)==0){break}else{aD=ay}do{aD=aD+1|0;}while((a[aD]|0)!=0)}}while(0);af=af+1|0;}while(af>>>0<(c[am>>2]|0)>>>0)}hC(ab,27304,ag);if((c[am>>2]|0)==0){break}else{aE=0}do{af=b+70628+(aE*4168|0)|0;hC(ab,af,b+70628+(aE*4168|0)+64|0);aA=b+70628+(aE*4168|0)+4160|0;if((c[aA>>2]|0)!=0){b5(ae|0,64,26904,(_=i,i=i+8|0,c[_>>2]=af,_)|0)|0;i=_;hC(ab,ae,(c[aA>>2]|0)!=1?51224:30680)}b5(ae|0,64,26488,(_=i,i=i+8|0,c[_>>2]=af,_)|0)|0;i=_;af=c[b+70628+(aE*4168|0)+4164>>2]|0;if((af|0)==3){aF=17488}else if((af|0)==0){aF=18032}else if((af|0)==1){aF=17880}else if((af|0)==2){aF=17696}else{aF=17240}hC(ab,ae,aF);aE=aE+1|0;}while(aE>>>0<(c[am>>2]|0)>>>0)}}while(0);am=b+109096|0;if((a[am]|0)!=0){hC(ab,26176,am)}am=b+113196|0;if((a[am]|0)!=0){hC(ab,25752,am)}am=b+103972|0;L7542:do{if((c[am>>2]|0)!=0){s_(ad|0,0,4096);ae=4096;ag=ad;af=b+103976|0;while(1){aA=ae-1|0;if((aA|0)==0){as=5382;break}az=a[af]|0;a[ag]=az;if(az<<24>>24==0){break}else{ae=aA;ag=ag+1|0;af=af+1|0}}do{if((as|0)==5382){a[ag]=0;if((a[af]|0)==0){break}else{aG=af}do{aG=aG+1|0;}while((a[aG]|0)!=0)}}while(0);if((c[am>>2]|0)>>>0>1){af=1;do{ag=sZ(ad|0)|0;ae=ag>>>0>4096?0:4096-ag|0;L7555:do{if((ae|0)==0){aH=27664;as=5389}else{aA=s+ag|0;do{if((ae|0)==1){aI=27664;aJ=aA}else{az=s+(ag+1)|0;a[aA]=59;if((ae|0)==2){aI=27665;aJ=az;break}a[az]=0;break L7555}}while(0);a[aJ]=0;aH=aI;as=5389}}while(0);do{if((as|0)==5389){as=0;if((a[aH]|0)==0){break}else{aK=aH}do{aK=aK+1|0;}while((a[aK]|0)!=0)}}while(0);ae=b+103976+(af*80|0)|0;ag=sZ(ad|0)|0;aA=ag>>>0>4096?0:4096-ag|0;L7566:do{if((aA|0)==0){aL=ae;as=5396}else{az=aA;al=s+ag|0;ak=ae;while(1){ap=az-1|0;if((ap|0)==0){break}an=a[ak]|0;a[al]=an;if(an<<24>>24==0){break L7566}else{az=ap;al=al+1|0;ak=ak+1|0}}a[al]=0;aL=ak;as=5396}}while(0);do{if((as|0)==5396){as=0;if((a[aL]|0)==0){break}else{aM=aL}do{aM=aM+1|0;}while((a[aM]|0)!=0)}}while(0);af=af+1|0;}while(af>>>0<(c[am>>2]|0)>>>0)}hC(ab,25352,ad);if((c[am>>2]|0)==0){break}af=k|0;ak=l|0;al=m|0;ae=n|0;ag=o|0;aA=0;while(1){az=b+103976+(aA*80|0)|0;b5(af|0,64,23224,(_=i,i=i+8|0,c[_>>2]=az,_)|0)|0;i=_;b5(ak|0,64,23016,(_=i,i=i+8|0,c[_>>2]=az,_)|0)|0;i=_;b5(al|0,64,22688,(_=i,i=i+8|0,c[_>>2]=az,_)|0)|0;i=_;b5(ae|0,64,22472,(_=i,i=i+8|0,c[_>>2]=az,_)|0)|0;i=_;b5(ag|0,64,22192,(_=i,i=i+8|0,c[_>>2]=az,_)|0)|0;i=_;switch(c[b+103976+(aA*80|0)+68>>2]|0){case 2:{aN=21456;break};case 3:{aN=20816;break};case 1:{aN=20432;break};case 4:{aN=19992;break};case 5:{aN=19840;break};case 0:{aN=22048;break};default:{aN=19768}}hC(ab,af,aN);b5(aj|0,128,51704,(_=i,i=i+8|0,c[_>>2]=e[b+103976+(aA*80|0)+76>>1]|0,_)|0)|0;i=_;hC(ab,ae,aj);b5(aj|0,128,51704,(_=i,i=i+8|0,c[_>>2]=e[b+103976+(aA*80|0)+78>>1]|0,_)|0)|0;i=_;hC(ab,ag,aj);az=c[b+103976+(aA*80|0)+72>>2]|0;if((az|0)==1){ap=c[b+103976+(aA*80|0)+64>>2]|0;b5(aj|0,128,51704,(_=i,i=i+8|0,c[_>>2]=ap,_)|0)|0;i=_;hC(ab,ak,aj)}else if((az|0)==2){b5(aj|0,128,11024,(_=i,i=i+8|0,c[_>>2]=1,_)|0)|0;i=_;hC(ab,al,aj)}else if((az|0)==3){b5(aj|0,128,11024,(_=i,i=i+8|0,c[_>>2]=2,_)|0)|0;i=_;hC(ab,al,aj)}aA=aA+1|0;if(aA>>>0>=(c[am>>2]|0)>>>0){break L7542}}}}while(0);hD(ab,L)|0;hx(ab);jh(0,ai,L);break L7277}}while(0);L=iX(547872,2)|0;jh(0,(L|0)==3?2:L,0);break L7277}else if((y|0)==30){do{if((F|0)==8){c[b+4252>>2]=0}else if((F|0)==2){L=b+4252|0;aa=c[L>>2]|0;if((aa|0)==0){break}c[L>>2]=aa-1}else if((F|0)==3|(F|0)==4){aa=b+4252|0;L=c[aa>>2]|0;if(L>>>0>=8){break}c[aa>>2]=L+1}}while(0);a[E]=1;break L7277}else{L=(y|0)==28;if(!(((d>>>0)%3|0|0)==0|L)){if(((J>>>0)%3|0|0)==0){aa=(J>>>0)/3|0;if((F|0)==8){c[b+4256+(aa*4148|0)+4136>>2]=0;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){$=b+4256+(aa*4148|0)+4136|0;c[$>>2]=(((c[$>>2]|0)+((F|0)==2?2:1)|0)>>>0)%3|0;break L7277}else{break L7277}}if(((N>>>0)%3|0|0)!=0){break L7277}$=(N>>>0)/3|0;if((F|0)==8){g[b+4256+($*4148|0)+4120>>2]=0.0;g[b+4256+($*4148|0)+4116>>2]=0.0;a[b+4256+($*4148|0)+4104|0]=0;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){aa=b+4256+($*4148|0)+4116|0;am=((~~+g[aa>>2]+((F|0)==2?5:1)|0)>>>0)%6|0;a[b+4256+($*4148|0)+4104|0]=(am|0)!=0|0;U=+(am>>>0>>>0);g[b+4256+($*4148|0)+4120>>2]=U;g[aa>>2]=U;break L7277}else{break L7277}}if(L){aO=b+4256+(((d>>>0)/3|0)*4148|0)|0}else{aO=0}if((F|0)==8){if((aO|0)==0){break L7277}a[aO|0]=0;break L7277}else if((F|0)!=4){break L7277}L=b+48|0;aa=c[L>>2]|0;if((B|0)!=0){$=B+4|0;am=c[$>>2]|0;if(A>>>0<am>>>0){aP=B|0}else{aj=(am<<1)+2|0;c[$>>2]=aj;$=B|0;c[$>>2]=sT(c[$>>2]|0,aj*12|0)|0;aP=$}$=dT(289493)|0;c[(c[aP>>2]|0)+((c[z>>2]|0)*12|0)>>2]=$;c[(c[aP>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[aP>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=aa;c[z>>2]=(c[z>>2]|0)+1}c[L>>2]=0;a[E]=1;break L7277}}if(y>>>0>65535){L=y-65536|0;if((F|0)==2){aa=c[120666]|0;$=c[aa+4100>>2]|0;aj=$+(L<<4)+12|0;am=c[(c[$+(L<<4)+8>>2]|0)+4>>2]|0;c[aj>>2]=(((c[aj>>2]|0)-1+am|0)>>>0)%(am>>>0)|0;a[aa+4108|0]=1;break L7277}else if((F|0)==3|(F|0)==4){aa=c[120666]|0;am=c[aa+4100>>2]|0;aj=am+(L<<4)+12|0;c[aj>>2]=(((c[aj>>2]|0)+1|0)>>>0)%((c[(c[am+(L<<4)+8>>2]|0)+4>>2]|0)>>>0)|0;a[aa+4108|0]=1;break L7277}else if((F|0)==8){aa=c[120666]|0;c[(c[aa+4100>>2]|0)+(L<<4)+12>>2]=0;a[aa+4108|0]=1;break L7277}else{break L7277}}L7640:do{switch(y|0){case 93:{aa=383588+(I<<2)|0;L=c[aa>>2]|0;am=0;while(1){if(am>>>0>=8){aQ=0;break}if((L|0)==(c[1448+(am<<2)>>2]|0)){aQ=am;break}else{am=am+1|0}}if((F|0)==2){aR=c[1448+((aQ+7&7)<<2)>>2]|0}else if((F|0)==3|(F|0)==4){aR=c[1448+((aQ+1&7)<<2)>>2]|0}else if((F|0)==8){aR=1}else{break L7277}c[aa>>2]=aR;f0[c[16044]&255](I,aR);break L7277;break};case 90:{if((F|0)==2){U=+g[86663]+-.009999999776482582;g[86663]=U;aS=1;aT=U;as=5544}else if((F|0)==3|(F|0)==4){U=+g[86663]+.009999999776482582;g[86663]=U;aS=1;aT=U;as=5544}else if((F|0)==8){g[86663]=1.0;aU=1;aV=1.0}else{aS=0;aT=+g[86663];as=5544}do{if((as|0)==5544){if(aT<.009999999776482582){g[86663]=.009999999776482582;aU=aS;aV=.009999999776482582;break}if(aT<=2.0){aU=aS;aV=aT;break}g[86663]=2.0;aU=aS;aV=2.0}}while(0);aa=c[136908]|0;if(!(aU&(aa|0)!=0)){break L7277}iB(aa,aV);break L7277;break};case 91:{if((F|0)==8){c[G>>2]=0;break L7277}else if((F|0)==2){if((I|0)==0){break L7277}c[G>>2]=I-1;break L7277}else if((F|0)==3){if(I>>>0>=7){break L7277}c[G>>2]=I+1;break L7277}else{break L7277}break};case 92:{aa=(c[136864]|0)+20|0;if((c[aa>>2]|0)==0){am=341932+(I<<2)|0;if((F|0)==8){c[am>>2]=I;aW=I}else if((F|0)==2){L=(c[am>>2]|0)-1|0;c[am>>2]=L;aW=L}else if((F|0)==3){L=(c[am>>2]|0)+1|0;c[am>>2]=L;aW=L}else{aW=c[am>>2]|0}if((aW|0)<-1){c[am>>2]=-1;break L7277}if((aW|0)<=7){break L7277}c[am>>2]=7;break L7277}else{am=341964+(I<<2)|0;L=c[am>>2]|0;if((F|0)==8){c[am>>2]=0;aX=0}else if((F|0)==2){ab=L-1|0;c[am>>2]=ab;aX=ab}else if((F|0)==3){ab=L+1|0;c[am>>2]=ab;aX=ab}else{aX=L}L=c[342508+(I<<2)>>2]|0;if((L|0)==1){aY=80}else if((L|0)==2){aY=144}else if((L|0)==0){aY=48}else{aY=16}f_[c[aa>>2]&15](c[136867]|0,aX,I,0,aY);break L7277}break};case 94:{aa=342508+(I<<2)|0;L=c[aa>>2]|0;ab=L+4|0;c[aa>>2]=ab;if((F|0)==8){c[aa>>2]=1;aZ=1}else if((F|0)==2){am=L+3|0;c[aa>>2]=am;aZ=am}else if((F|0)==3){am=L+5|0;c[aa>>2]=am;aZ=am}else{aZ=ab}ab=aZ&3;c[aa>>2]=ab;aa=c[(c[136864]|0)+20>>2]|0;if((aa|0)==0){break L7277}if((ab|0)==2){a_=128}else if((ab|0)==0){a_=32}else if((ab|0)==1){a_=64}else{break L7277}f_[aa&15](c[136867]|0,c[341964+(I<<2)>>2]|0,I,0,a_);break L7277;break};case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:case 108:case 109:case 110:{aa=c[(c[136864]|0)+20>>2]|0;if((aa|0)==0){break L7640}if((F|0)==2){a$=2}else if((F|0)==8){a$=8}else{ab=(F|0)==3;if(ab){a$=ab?4:0}else{break L7640}}ab=y-95|0;f_[aa&15](c[136867]|0,c[341964+(ab<<2)>>2]|0,I,c[1552+(ab<<2)>>2]|0,a$);break};case 73:{break};case 76:{if((F|0)!=8){break L7277}a[453266]=0;break L7277;break};case 78:{if((F|0)!=8){break L7277}a[461458]=0;break L7277;break};case 75:{if((F|0)!=8){break L7277}a[457362]=0;break L7277;break};case 74:{if((F|0)!=8){break L7277}a[289493]=0;break L7277;break};case 79:{if((F|0)!=8){break L7277}a[375332]=0;break L7277;break};case 89:{if((F|0)==2){U=+g[86662]+-.009999999776482582;g[86662]=U;a0=1;a1=U;as=5533}else if((F|0)==3|(F|0)==4){U=+g[86662]+.009999999776482582;g[86662]=U;a0=1;a1=U;as=5533}else if((F|0)==8){g[86662]=1.0;a2=1;a3=1.0}else{a0=0;a1=+g[86662];as=5533}do{if((as|0)==5533){if(a1<0.0){g[86662]=0.0;a2=a0;a3=0.0;break}if(a1<=1.0){a2=a0;a3=a1;break}g[86662]=1.0;a2=a0;a3=1.0}}while(0);ab=c[136908]|0;if(!(a2&(ab|0)!=0)){break L7277}fZ[c[(c[ab+4>>2]|0)+20>>2]&7](c[ab>>2]|0,a3);break L7277;break};case 80:{if(!H){break L7277}gX();ab=540624;aa=c[ab+4>>2]|0;am=540624;c[am>>2]=c[ab>>2]|1;c[am+4>>2]=aa;a4=-1;i=f;return a4|0};case 81:{if((F|0)==8){a[482713]=0;break L7277}else{a[482713]=a[482713]&1^1;break L7277}break};case 82:{if((F|0)==8){g[76493]=.004999999888241291;a[305969]=1;break L7277}else if((F|0)==2){U=+g[76493];if(U>0.0){R=U+-.001;g[76493]=R;a5=R}else{a5=U}if(a5<5.0e-4){a[305969]=0;g[76493]=0.0;break L7277}else{a[305969]=1;break L7277}}else if((F|0)==3){U=+g[76493];if(U<.2){g[76493]=U+.001}a[305969]=1;break L7277}else{break L7277}break};case 63:{if((F|0)==8){a[379428]=0;aa=c[133029]|0;if((aa|0)!=0){sS(c[aa>>2]|0);sS(c[aa+12>>2]|0);sS(aa)}c[133029]=0;sS(c[133030]|0);c[133030]=0;break L7277}else if(!((F|0)==4|(F|0)==3|(F|0)==2)){break L7277}aa=a[379428]&1;a[379428]=aa^1;if(aa<<24>>24==0){gS();break L7277}aa=c[133029]|0;if((aa|0)!=0){sS(c[aa>>2]|0);sS(c[aa+12>>2]|0);sS(aa)}c[133029]=0;sS(c[133030]|0);c[133030]=0;break L7277;break};case 84:{if((F|0)==8|(F|0)==2){aa=540624;am=c[aa+4>>2]|0;ab=540624;c[ab>>2]=c[aa>>2]&-257;c[ab+4>>2]=am;break L7277}else if((F|0)==3){am=540624;ab=c[am+4>>2]|0;aa=540624;c[aa>>2]=c[am>>2]|256;c[aa+4>>2]=ab;break L7277}else{break L7277}break};case 70:{ab=gm[c[120646]&31]()|0;aa=gm[c[120644]&31]()|0;if((F-3|0)>>>0<2){a6=1}else{am=(F|0)==2;if(am){a6=am<<31>>31}else{break L7277}}am=ab+1|0;gZ(1,0);g_(((aa+am+a6|0)>>>0)%(am>>>0)|0);gZ(0,0);break L7277;break};case 85:{if(!H){break L7277}am=540624;aa=c[am+4>>2]|0|0;ab=540624;c[ab>>2]=c[am>>2]&-1026|1024;c[ab+4>>2]=aa;a4=-1;i=f;return a4|0};case 86:{if(!H){break L7277}if((a[540636]&1)==0){break L7277}aa=540624;ab=c[aa+4>>2]|0;am=540624;c[am>>2]=c[aa>>2]|1;c[am+4>>2]=ab;a4=-1;i=f;return a4|0};case 87:{if(!H){break L7277}ab=540624;am=c[ab+4>>2]|0;aa=540624;c[aa>>2]=c[ab>>2]&-2;c[aa+4>>2]=am;a4=-1;i=f;return a4|0};case 88:{if((F|0)==4){am=b+48|0;aa=c[am>>2]|0;if((B|0)!=0){ab=B+4|0;L=c[ab>>2]|0;if(A>>>0<L>>>0){a8=B|0}else{aj=(L<<1)+2|0;c[ab>>2]=aj;ab=B|0;c[ab>>2]=sT(c[ab>>2]|0,aj*12|0)|0;a8=ab}ab=dT(461458)|0;c[(c[a8>>2]|0)+((c[z>>2]|0)*12|0)>>2]=ab;c[(c[a8>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=88;c[(c[a8>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=aa;c[z>>2]=(c[z>>2]|0)+1}c[am>>2]=0;a[E]=1;break L7277}else if((F|0)!=8){break L7277}am=c[136908]|0;if((am|0)!=0){aa=am+24|0;ab=am+12|0;aj=c[ab>>2]|0;if((c[aa>>2]|0)==0){a9=aj}else{L=0;$=aj;while(1){sS(c[$+(L*136|0)>>2]|0);sS(c[$+(L*136|0)+8>>2]|0);aj=L+1|0;ad=c[ab>>2]|0;if(aj>>>0<(c[aa>>2]|0)>>>0){L=aj;$=ad}else{a9=ad;break}}}sS(a9);$=c[am+4>>2]|0;if(($|0)!=0){f0[c[$>>2]&255](c[am>>2]|0,0)}sS(am)}c[136908]=0;a[342552]=0;break L7277;break};case 67:case 68:{if((F|0)==4){if((y|0)==67){gV()}else{gT()}$=540624;L=c[$+4>>2]|0;aa=540624;c[aa>>2]=c[$>>2]|1;c[aa+4>>2]=L;a4=-1;i=f;return a4|0}else if((F|0)==8){c[119462]=0;break L7277}else if((F|0)==2){L=c[119462]|0;if((L|0)==0){break L7277}c[119462]=L-1;break L7277}else if((F|0)==3){c[119462]=(c[119462]|0)+1;break L7277}else{break L7277}break};case 72:{if(!H){break L7277}do{if((a[297719]&1)!=0|(c[120649]|0)!=0){L=c[136914]|0;do{if((L|0)!=0){aa=c[L+24>>2]|0;if((aa|0)==0){break}go[aa&127](c[136866]|0,0,0)}}while(0);if((c[136863]|0)==0){break}gN()}}while(0);gM();break L7277;break};case 64:{if((F-3|0)>>>0<2){c[94859]=(c[94859]|0)+1;break L7277}if((F|0)==8){c[94859]=1;break L7277}else if((F|0)!=2){break L7277}am=c[94859]|0;if(am>>>0<=1){break L7277}c[94859]=am-1;break L7277;break};case 65:{if((F-3|0)>>>0<2|(F|0)==2){a[540638]=a[540638]&1^1;break L7277}if((F|0)!=8){break L7277}a[540638]=1;break L7277;break};default:{break L7277}}}while(0);if((F|0)!=8){break L7277}a[379465]=0;a[b+54|0]=0;break L7277}}while(0);H=b+48|0;I=c[H>>2]|0;if((B|0)!=0){G=B+4|0;d=c[G>>2]|0;if(A>>>0<d>>>0){ba=B|0}else{N=(d<<1)+2|0;c[G>>2]=N;G=B|0;c[G>>2]=sT(c[G>>2]|0,N*12|0)|0;ba=G}G=dT(547872)|0;c[(c[ba>>2]|0)+((c[z>>2]|0)*12|0)>>2]=G;c[(c[ba>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[ba>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=I;c[z>>2]=(c[z>>2]|0)+1}c[H>>2]=0;a[E]=1;break};case 0:{H=b+48|0;I=c[H>>2]|0;if((I|0)==0){c[H>>2]=(c[(c[b+44>>2]|0)+8>>2]|0)-1;break L7277}else{c[H>>2]=I-1;break L7277}break};case 1:{I=b+48|0;H=(c[I>>2]|0)+1|0;if(H>>>0<(c[(c[b+44>>2]|0)+8>>2]|0)>>>0){c[I>>2]=H;break L7277}else{c[I>>2]=0;break L7277}break};case 6:{c[b+48>>2]=0;a[E]=1;break};case 9:{a[b+53|0]=1;break};default:{}}}while(0);z=c[C>>2]|0;C=c[z+8>>2]|0;if((C|0)==0){bb=D}else{bb=c[(c[z>>2]|0)+((C-1|0)*12|0)+4>>2]|0}L7868:do{if(!((a[E]&1)==0|(bb|0)==1)){C=bb-31|0;if(C>>>0<24&((C>>>0)%3|0|0)==0|(bb|0)==28){break}if((bb-73|0)>>>0<4|(bb|0)==78|(bb|0)==79){break}if((bb|0)==88|(bb|0)==71|(bb|0)==57|(bb|0)==56){break}a[E]=0;switch(bb|0){case 61:{C=b+44|0;z=c[C>>2]|0;D=z+8|0;if((c[D>>2]|0)!=0){ba=z|0;z=0;do{sS(c[(c[ba>>2]|0)+(z*12|0)>>2]|0);z=z+1|0;}while(z>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;z=c[C>>2]|0;if((z|0)==0){break L7868}ba=z+8|0;y=z+4|0;B=c[y>>2]|0;if((c[ba>>2]|0)>>>0<B>>>0){bc=z|0}else{A=(B<<1)+2|0;c[y>>2]=A;y=z|0;c[y>>2]=sT(c[y>>2]|0,A*12|0)|0;bc=y}y=dT(51384)|0;c[(c[bc>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=y;c[(c[bc>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=73;c[(c[bc>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[C>>2]|0;if((ba|0)==0){break L7868}y=ba+8|0;A=ba+4|0;z=c[A>>2]|0;if((c[y>>2]|0)>>>0<z>>>0){bd=ba|0}else{B=(z<<1)+2|0;c[A>>2]=B;A=ba|0;c[A>>2]=sT(c[A>>2]|0,B*12|0)|0;bd=A}A=dT(51200)|0;c[(c[bd>>2]|0)+((c[y>>2]|0)*12|0)>>2]=A;c[(c[bd>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=74;c[(c[bd>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7868}A=y+8|0;B=y+4|0;ba=c[B>>2]|0;if((c[A>>2]|0)>>>0<ba>>>0){bf=y|0}else{z=(ba<<1)+2|0;c[B>>2]=z;B=y|0;c[B>>2]=sT(c[B>>2]|0,z*12|0)|0;bf=B}B=dT(51040)|0;c[(c[bf>>2]|0)+((c[A>>2]|0)*12|0)>>2]=B;c[(c[bf>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=75;c[(c[bf>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L7868}B=A+8|0;z=A+4|0;y=c[z>>2]|0;if((c[B>>2]|0)>>>0<y>>>0){bg=A|0}else{ba=(y<<1)+2|0;c[z>>2]=ba;z=A|0;c[z>>2]=sT(c[z>>2]|0,ba*12|0)|0;bg=z}z=dT(50616)|0;c[(c[bg>>2]|0)+((c[B>>2]|0)*12|0)>>2]=z;c[(c[bg>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=76;c[(c[bg>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[C>>2]|0;if((B|0)==0){break L7868}z=B+8|0;ba=B+4|0;A=c[ba>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){bh=B|0}else{y=(A<<1)+2|0;c[ba>>2]=y;ba=B|0;c[ba>>2]=sT(c[ba>>2]|0,y*12|0)|0;bh=ba}ba=dT(50400)|0;c[(c[bh>>2]|0)+((c[z>>2]|0)*12|0)>>2]=ba;c[(c[bh>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=78;c[(c[bh>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[C>>2]|0;if((z|0)==0){break L7868}ba=z+8|0;y=z+4|0;B=c[y>>2]|0;if((c[ba>>2]|0)>>>0<B>>>0){bi=z|0}else{A=(B<<1)+2|0;c[y>>2]=A;y=z|0;c[y>>2]=sT(c[y>>2]|0,A*12|0)|0;bi=y}y=dT(50064)|0;c[(c[bi>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=y;c[(c[bi>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=79;c[(c[bi>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;break L7868;break};case 62:{ba=b+44|0;y=c[ba>>2]|0;A=y+8|0;if((c[A>>2]|0)!=0){z=y|0;y=0;do{sS(c[(c[z>>2]|0)+(y*12|0)>>2]|0);y=y+1|0;}while(y>>>0<(c[A>>2]|0)>>>0)}c[A>>2]=0;y=c[ba>>2]|0;if((y|0)==0){break L7868}z=y+8|0;C=y+4|0;D=c[C>>2]|0;if((c[z>>2]|0)>>>0<D>>>0){bj=y|0}else{B=(D<<1)+2|0;c[C>>2]=B;C=y|0;c[C>>2]=sT(c[C>>2]|0,B*12|0)|0;bj=C}C=dT(52016)|0;c[(c[bj>>2]|0)+((c[z>>2]|0)*12|0)>>2]=C;c[(c[bj>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=63;c[(c[bj>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[ba>>2]|0;if((z|0)==0){break L7868}C=z+8|0;B=z+4|0;y=c[B>>2]|0;if((c[C>>2]|0)>>>0<y>>>0){bk=z|0}else{D=(y<<1)+2|0;c[B>>2]=D;B=z|0;c[B>>2]=sT(c[B>>2]|0,D*12|0)|0;bk=B}B=dT(51872)|0;c[(c[bk>>2]|0)+((c[C>>2]|0)*12|0)>>2]=B;c[(c[bk>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=64;c[(c[bk>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[ba>>2]|0;if((C|0)==0){break L7868}B=C+8|0;D=C+4|0;z=c[D>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){bl=C|0}else{y=(z<<1)+2|0;c[D>>2]=y;D=C|0;c[D>>2]=sT(c[D>>2]|0,y*12|0)|0;bl=D}D=dT(51720)|0;c[(c[bl>>2]|0)+((c[B>>2]|0)*12|0)>>2]=D;c[(c[bl>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=65;c[(c[bl>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[ba>>2]|0;if((B|0)==0){break L7868}D=B+8|0;y=B+4|0;C=c[y>>2]|0;if((c[D>>2]|0)>>>0<C>>>0){bm=B|0}else{z=(C<<1)+2|0;c[y>>2]=z;y=B|0;c[y>>2]=sT(c[y>>2]|0,z*12|0)|0;bm=y}y=dT(51552)|0;c[(c[bm>>2]|0)+((c[D>>2]|0)*12|0)>>2]=y;c[(c[bm>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=84;c[(c[bm>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;break L7868;break};case 58:{D=b+44|0;y=c[D>>2]|0;z=y+8|0;if((c[z>>2]|0)!=0){B=y|0;y=0;do{sS(c[(c[B>>2]|0)+(y*12|0)>>2]|0);y=y+1|0;}while(y>>>0<(c[z>>2]|0)>>>0)}c[z>>2]=0;y=c[120666]|0;if((y|0)==0){B=c[D>>2]|0;if((B|0)==0){break L7868}ba=B+8|0;A=B+4|0;C=c[A>>2]|0;if((c[ba>>2]|0)>>>0<C>>>0){bn=B|0}else{F=(C<<1)+2|0;c[A>>2]=F;A=B|0;c[A>>2]=sT(c[A>>2]|0,F*12|0)|0;bn=A}A=dT(52488)|0;c[(c[bn>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=A;c[(c[bn>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=65535;c[(c[bn>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;break L7868}ba=c[y+4104>>2]|0;if((ba|0)==0){break L7868}else{bo=0;bp=y}while(1){y=c[D>>2]|0;A=c[(c[bp+4100>>2]|0)+(bo<<4)>>2]|0;F=bo+65536|0;if((y|0)!=0){B=y+8|0;C=y+4|0;a9=c[C>>2]|0;if((c[B>>2]|0)>>>0<a9>>>0){bq=y|0}else{a8=(a9<<1)+2|0;c[C>>2]=a8;C=y|0;c[C>>2]=sT(c[C>>2]|0,a8*12|0)|0;bq=C}C=dT(A|0)|0;c[(c[bq>>2]|0)+((c[B>>2]|0)*12|0)>>2]=C;c[(c[bq>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=F;c[(c[bq>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1}B=bo+1|0;if(B>>>0>=ba>>>0){break L7868}bo=B;bp=c[120666]|0}break};case 59:{ba=b+44|0;D=c[ba>>2]|0;z=D+8|0;if((c[z>>2]|0)!=0){B=D|0;D=0;do{sS(c[(c[B>>2]|0)+(D*12|0)>>2]|0);D=D+1|0;}while(D>>>0<(c[z>>2]|0)>>>0)}c[z>>2]=0;D=c[ba>>2]|0;if((D|0)==0){break L7868}B=D+8|0;F=D+4|0;C=c[F>>2]|0;if((c[B>>2]|0)>>>0<C>>>0){br=D|0}else{A=(C<<1)+2|0;c[F>>2]=A;F=D|0;c[F>>2]=sT(c[F>>2]|0,A*12|0)|0;br=F}F=dT(10896)|0;c[(c[br>>2]|0)+((c[B>>2]|0)*12|0)>>2]=F;c[(c[br>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=81;c[(c[br>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[ba>>2]|0;if((B|0)==0){break L7868}F=B+8|0;A=B+4|0;D=c[A>>2]|0;if((c[F>>2]|0)>>>0<D>>>0){bs=B|0}else{C=(D<<1)+2|0;c[A>>2]=C;A=B|0;c[A>>2]=sT(c[A>>2]|0,C*12|0)|0;bs=A}A=dT(52712)|0;c[(c[bs>>2]|0)+((c[F>>2]|0)*12|0)>>2]=A;c[(c[bs>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=82;c[(c[bs>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;break L7868;break};case 69:{F=b+44|0;A=c[F>>2]|0;C=A+8|0;if((c[C>>2]|0)!=0){B=A|0;A=0;do{sS(c[(c[B>>2]|0)+(A*12|0)>>2]|0);A=A+1|0;}while(A>>>0<(c[C>>2]|0)>>>0)}c[C>>2]=0;A=c[F>>2]|0;if((A|0)==0){break L7868}B=A+8|0;ba=A+4|0;z=c[ba>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){bt=A|0}else{D=(z<<1)+2|0;c[ba>>2]=D;ba=A|0;c[ba>>2]=sT(c[ba>>2]|0,D*12|0)|0;bt=ba}ba=dT(11160)|0;c[(c[bt>>2]|0)+((c[B>>2]|0)*12|0)>>2]=ba;c[(c[bt>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=70;c[(c[bt>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[F>>2]|0;if((B|0)==0){break L7868}ba=B+8|0;D=B+4|0;A=c[D>>2]|0;if((c[ba>>2]|0)>>>0<A>>>0){bu=B|0}else{z=(A<<1)+2|0;c[D>>2]=z;D=B|0;c[D>>2]=sT(c[D>>2]|0,z*12|0)|0;bu=D}D=dT(11032)|0;c[(c[bu>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=D;c[(c[bu>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=71;c[(c[bu>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;break L7868;break};case 5:{ba=b+44|0;D=c[ba>>2]|0;z=D+8|0;if((c[z>>2]|0)!=0){B=D|0;D=0;do{sS(c[(c[B>>2]|0)+(D*12|0)>>2]|0);D=D+1|0;}while(D>>>0<(c[z>>2]|0)>>>0)}c[z>>2]=0;D=c[ba>>2]|0;if((D|0)==0){break L7868}B=D+8|0;F=D+4|0;C=c[F>>2]|0;if((c[B>>2]|0)>>>0<C>>>0){bv=D|0}else{A=(C<<1)+2|0;c[F>>2]=A;F=D|0;c[F>>2]=sT(c[F>>2]|0,A*12|0)|0;bv=F}F=dT(14136)|0;c[(c[bv>>2]|0)+((c[B>>2]|0)*12|0)>>2]=F;c[(c[bv>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=26;c[(c[bv>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[ba>>2]|0;if((B|0)==0){break L7868}F=B+8|0;A=B+4|0;D=c[A>>2]|0;if((c[F>>2]|0)>>>0<D>>>0){bw=B|0}else{C=(D<<1)+2|0;c[A>>2]=C;A=B|0;c[A>>2]=sT(c[A>>2]|0,C*12|0)|0;bw=A}A=dT(13920)|0;c[(c[bw>>2]|0)+((c[F>>2]|0)*12|0)>>2]=A;c[(c[bw>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=10;c[(c[bw>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[ba>>2]|0;if((F|0)==0){break L7868}A=F+8|0;C=F+4|0;B=c[C>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bx=F|0}else{D=(B<<1)+2|0;c[C>>2]=D;C=F|0;c[C>>2]=sT(c[C>>2]|0,D*12|0)|0;bx=C}C=dT(13576)|0;c[(c[bx>>2]|0)+((c[A>>2]|0)*12|0)>>2]=C;c[(c[bx>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=11;c[(c[bx>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[ba>>2]|0;if((A|0)==0){break L7868}C=A+8|0;D=A+4|0;F=c[D>>2]|0;if((c[C>>2]|0)>>>0<F>>>0){by=A|0}else{B=(F<<1)+2|0;c[D>>2]=B;D=A|0;c[D>>2]=sT(c[D>>2]|0,B*12|0)|0;by=D}D=dT(13416)|0;c[(c[by>>2]|0)+((c[C>>2]|0)*12|0)>>2]=D;c[(c[by>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=12;c[(c[by>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[ba>>2]|0;if((C|0)==0){break L7868}D=C+8|0;B=C+4|0;A=c[B>>2]|0;if((c[D>>2]|0)>>>0<A>>>0){bz=C|0}else{F=(A<<1)+2|0;c[B>>2]=F;B=C|0;c[B>>2]=sT(c[B>>2]|0,F*12|0)|0;bz=B}B=dT(13312)|0;c[(c[bz>>2]|0)+((c[D>>2]|0)*12|0)>>2]=B;c[(c[bz>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=14;c[(c[bz>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[ba>>2]|0;if((D|0)==0){break L7868}B=D+8|0;F=D+4|0;C=c[F>>2]|0;if((c[B>>2]|0)>>>0<C>>>0){bA=D|0}else{A=(C<<1)+2|0;c[F>>2]=A;F=D|0;c[F>>2]=sT(c[F>>2]|0,A*12|0)|0;bA=F}F=dT(13168)|0;c[(c[bA>>2]|0)+((c[B>>2]|0)*12|0)>>2]=F;c[(c[bA>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=15;c[(c[bA>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[ba>>2]|0;if((B|0)==0){break L7868}F=B+8|0;A=B+4|0;D=c[A>>2]|0;if((c[F>>2]|0)>>>0<D>>>0){bB=B|0}else{C=(D<<1)+2|0;c[A>>2]=C;A=B|0;c[A>>2]=sT(c[A>>2]|0,C*12|0)|0;bB=A}A=dT(13008)|0;c[(c[bB>>2]|0)+((c[F>>2]|0)*12|0)>>2]=A;c[(c[bB>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=16;c[(c[bB>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[ba>>2]|0;if((F|0)==0){break L7868}A=F+8|0;C=F+4|0;B=c[C>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bC=F|0}else{D=(B<<1)+2|0;c[C>>2]=D;C=F|0;c[C>>2]=sT(c[C>>2]|0,D*12|0)|0;bC=C}C=dT(12736)|0;c[(c[bC>>2]|0)+((c[A>>2]|0)*12|0)>>2]=C;c[(c[bC>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=17;c[(c[bC>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[ba>>2]|0;if((A|0)==0){break L7868}C=A+8|0;D=A+4|0;F=c[D>>2]|0;if((c[C>>2]|0)>>>0<F>>>0){bD=A|0}else{B=(F<<1)+2|0;c[D>>2]=B;D=A|0;c[D>>2]=sT(c[D>>2]|0,B*12|0)|0;bD=D}D=dT(12576)|0;c[(c[bD>>2]|0)+((c[C>>2]|0)*12|0)>>2]=D;c[(c[bD>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=18;c[(c[bD>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[ba>>2]|0;if((C|0)==0){break L7868}D=C+8|0;B=C+4|0;A=c[B>>2]|0;if((c[D>>2]|0)>>>0<A>>>0){bE=C|0}else{F=(A<<1)+2|0;c[B>>2]=F;B=C|0;c[B>>2]=sT(c[B>>2]|0,F*12|0)|0;bE=B}B=dT(12376)|0;c[(c[bE>>2]|0)+((c[D>>2]|0)*12|0)>>2]=B;c[(c[bE>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=19;c[(c[bE>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[ba>>2]|0;if((D|0)==0){break L7868}B=D+8|0;F=D+4|0;C=c[F>>2]|0;if((c[B>>2]|0)>>>0<C>>>0){bF=D|0}else{A=(C<<1)+2|0;c[F>>2]=A;F=D|0;c[F>>2]=sT(c[F>>2]|0,A*12|0)|0;bF=F}F=dT(11904)|0;c[(c[bF>>2]|0)+((c[B>>2]|0)*12|0)>>2]=F;c[(c[bF>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=20;c[(c[bF>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[ba>>2]|0;if((B|0)==0){break L7868}F=B+8|0;A=B+4|0;D=c[A>>2]|0;if((c[F>>2]|0)>>>0<D>>>0){bG=B|0}else{C=(D<<1)+2|0;c[A>>2]=C;A=B|0;c[A>>2]=sT(c[A>>2]|0,C*12|0)|0;bG=A}A=dT(11720)|0;c[(c[bG>>2]|0)+((c[F>>2]|0)*12|0)>>2]=A;c[(c[bG>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=21;c[(c[bG>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[ba>>2]|0;if((F|0)==0){break L7868}A=F+8|0;C=F+4|0;B=c[C>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bH=F|0}else{D=(B<<1)+2|0;c[C>>2]=D;C=F|0;c[C>>2]=sT(c[C>>2]|0,D*12|0)|0;bH=C}C=dT(11536)|0;c[(c[bH>>2]|0)+((c[A>>2]|0)*12|0)>>2]=C;c[(c[bH>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=22;c[(c[bH>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[ba>>2]|0;if((A|0)==0){break L7868}C=A+8|0;D=A+4|0;F=c[D>>2]|0;if((c[C>>2]|0)>>>0<F>>>0){bI=A|0}else{B=(F<<1)+2|0;c[D>>2]=B;D=A|0;c[D>>2]=sT(c[D>>2]|0,B*12|0)|0;bI=D}D=dT(11368)|0;c[(c[bI>>2]|0)+((c[C>>2]|0)*12|0)>>2]=D;c[(c[bI>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=23;c[(c[bI>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[ba>>2]|0;if((C|0)==0){break L7868}D=C+8|0;B=C+4|0;A=c[B>>2]|0;if((c[D>>2]|0)>>>0<A>>>0){bJ=C|0}else{F=(A<<1)+2|0;c[B>>2]=F;B=C|0;c[B>>2]=sT(c[B>>2]|0,F*12|0)|0;bJ=B}B=dT(11288)|0;c[(c[bJ>>2]|0)+((c[D>>2]|0)*12|0)>>2]=B;c[(c[bJ>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=24;c[(c[bJ>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;break L7868;break};case 60:{D=b+44|0;B=c[D>>2]|0;F=B+8|0;if((c[F>>2]|0)!=0){C=B|0;B=0;do{sS(c[(c[C>>2]|0)+(B*12|0)>>2]|0);B=B+1|0;}while(B>>>0<(c[F>>2]|0)>>>0)}c[F>>2]=0;B=c[D>>2]|0;do{if((B|0)!=0){C=B+8|0;ba=B+4|0;z=c[ba>>2]|0;if((c[C>>2]|0)>>>0<z>>>0){bK=B|0}else{A=(z<<1)+2|0;c[ba>>2]=A;ba=B|0;c[ba>>2]=sT(c[ba>>2]|0,A*12|0)|0;bK=ba}ba=dT(49512)|0;c[(c[bK>>2]|0)+((c[C>>2]|0)*12|0)>>2]=ba;c[(c[bK>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=88;c[(c[bK>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[D>>2]|0;if((C|0)==0){break}ba=C+8|0;A=C+4|0;z=c[A>>2]|0;if((c[ba>>2]|0)>>>0<z>>>0){bL=C|0}else{a8=(z<<1)+2|0;c[A>>2]=a8;A=C|0;c[A>>2]=sT(c[A>>2]|0,a8*12|0)|0;bL=A}A=dT(49224)|0;c[(c[bL>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=A;c[(c[bL>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=89;c[(c[bL>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[D>>2]|0;if((ba|0)==0){break}A=ba+8|0;a8=ba+4|0;C=c[a8>>2]|0;if((c[A>>2]|0)>>>0<C>>>0){bM=ba|0}else{z=(C<<1)+2|0;c[a8>>2]=z;a8=ba|0;c[a8>>2]=sT(c[a8>>2]|0,z*12|0)|0;bM=a8}a8=dT(48952)|0;c[(c[bM>>2]|0)+((c[A>>2]|0)*12|0)>>2]=a8;c[(c[bM>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=90;c[(c[bM>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[D>>2]|0;if((A|0)==0){break}a8=A+8|0;z=A+4|0;ba=c[z>>2]|0;if((c[a8>>2]|0)>>>0<ba>>>0){bN=A|0}else{C=(ba<<1)+2|0;c[z>>2]=C;z=A|0;c[z>>2]=sT(c[z>>2]|0,C*12|0)|0;bN=z}z=dT(48688)|0;c[(c[bN>>2]|0)+((c[a8>>2]|0)*12|0)>>2]=z;c[(c[bN>>2]|0)+((c[a8>>2]|0)*12|0)+4>>2]=91;c[(c[bN>>2]|0)+((c[a8>>2]|0)*12|0)+8>>2]=0;c[a8>>2]=(c[a8>>2]|0)+1;a8=c[D>>2]|0;if((a8|0)==0){break}z=a8+8|0;C=a8+4|0;A=c[C>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){bO=a8|0}else{ba=(A<<1)+2|0;c[C>>2]=ba;C=a8|0;c[C>>2]=sT(c[C>>2]|0,ba*12|0)|0;bO=C}C=dT(48592)|0;c[(c[bO>>2]|0)+((c[z>>2]|0)*12|0)>>2]=C;c[(c[bO>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=92;c[(c[bO>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[D>>2]|0;if((z|0)==0){break}C=z+8|0;ba=z+4|0;a8=c[ba>>2]|0;if((c[C>>2]|0)>>>0<a8>>>0){bP=z|0}else{A=(a8<<1)+2|0;c[ba>>2]=A;ba=z|0;c[ba>>2]=sT(c[ba>>2]|0,A*12|0)|0;bP=ba}ba=dT(48336)|0;c[(c[bP>>2]|0)+((c[C>>2]|0)*12|0)>>2]=ba;c[(c[bP>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=93;c[(c[bP>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1}}while(0);B=c[136864]|0;if((B|0)==0){break L7868}if((c[B+20>>2]|0)==0){break L7868}B=c[D>>2]|0;if((B|0)==0){break L7868}F=B+8|0;C=B+4|0;ba=c[C>>2]|0;if((c[F>>2]|0)>>>0<ba>>>0){bQ=B|0}else{A=(ba<<1)+2|0;c[C>>2]=A;C=B|0;c[C>>2]=sT(c[C>>2]|0,A*12|0)|0;bQ=C}C=dT(48072)|0;c[(c[bQ>>2]|0)+((c[F>>2]|0)*12|0)>>2]=C;c[(c[bQ>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=94;c[(c[bQ>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[D>>2]|0;if((F|0)==0){break L7868}C=F+8|0;A=F+4|0;B=c[A>>2]|0;if((c[C>>2]|0)>>>0<B>>>0){bR=F|0}else{ba=(B<<1)+2|0;c[A>>2]=ba;A=F|0;c[A>>2]=sT(c[A>>2]|0,ba*12|0)|0;bR=A}A=dT(47888)|0;c[(c[bR>>2]|0)+((c[C>>2]|0)*12|0)>>2]=A;c[(c[bR>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=95;c[(c[bR>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[D>>2]|0;if((C|0)==0){break L7868}A=C+8|0;ba=C+4|0;F=c[ba>>2]|0;if((c[A>>2]|0)>>>0<F>>>0){bS=C|0}else{B=(F<<1)+2|0;c[ba>>2]=B;ba=C|0;c[ba>>2]=sT(c[ba>>2]|0,B*12|0)|0;bS=ba}ba=dT(47744)|0;c[(c[bS>>2]|0)+((c[A>>2]|0)*12|0)>>2]=ba;c[(c[bS>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=96;c[(c[bS>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[D>>2]|0;if((A|0)==0){break L7868}ba=A+8|0;B=A+4|0;C=c[B>>2]|0;if((c[ba>>2]|0)>>>0<C>>>0){bT=A|0}else{F=(C<<1)+2|0;c[B>>2]=F;B=A|0;c[B>>2]=sT(c[B>>2]|0,F*12|0)|0;bT=B}B=dT(47544)|0;c[(c[bT>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=B;c[(c[bT>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=97;c[(c[bT>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[D>>2]|0;if((ba|0)==0){break L7868}B=ba+8|0;F=ba+4|0;A=c[F>>2]|0;if((c[B>>2]|0)>>>0<A>>>0){bU=ba|0}else{C=(A<<1)+2|0;c[F>>2]=C;F=ba|0;c[F>>2]=sT(c[F>>2]|0,C*12|0)|0;bU=F}F=dT(47264)|0;c[(c[bU>>2]|0)+((c[B>>2]|0)*12|0)>>2]=F;c[(c[bU>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=98;c[(c[bU>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[D>>2]|0;if((B|0)==0){break L7868}F=B+8|0;C=B+4|0;ba=c[C>>2]|0;if((c[F>>2]|0)>>>0<ba>>>0){bV=B|0}else{A=(ba<<1)+2|0;c[C>>2]=A;C=B|0;c[C>>2]=sT(c[C>>2]|0,A*12|0)|0;bV=C}C=dT(43392)|0;c[(c[bV>>2]|0)+((c[F>>2]|0)*12|0)>>2]=C;c[(c[bV>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=99;c[(c[bV>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[D>>2]|0;if((F|0)==0){break L7868}C=F+8|0;A=F+4|0;B=c[A>>2]|0;if((c[C>>2]|0)>>>0<B>>>0){bW=F|0}else{ba=(B<<1)+2|0;c[A>>2]=ba;A=F|0;c[A>>2]=sT(c[A>>2]|0,ba*12|0)|0;bW=A}A=dT(42056)|0;c[(c[bW>>2]|0)+((c[C>>2]|0)*12|0)>>2]=A;c[(c[bW>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=100;c[(c[bW>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[D>>2]|0;if((C|0)==0){break L7868}A=C+8|0;ba=C+4|0;F=c[ba>>2]|0;if((c[A>>2]|0)>>>0<F>>>0){bX=C|0}else{B=(F<<1)+2|0;c[ba>>2]=B;ba=C|0;c[ba>>2]=sT(c[ba>>2]|0,B*12|0)|0;bX=ba}ba=dT(25640)|0;c[(c[bX>>2]|0)+((c[A>>2]|0)*12|0)>>2]=ba;c[(c[bX>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=101;c[(c[bX>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[D>>2]|0;if((A|0)==0){break L7868}ba=A+8|0;B=A+4|0;C=c[B>>2]|0;if((c[ba>>2]|0)>>>0<C>>>0){bY=A|0}else{F=(C<<1)+2|0;c[B>>2]=F;B=A|0;c[B>>2]=sT(c[B>>2]|0,F*12|0)|0;bY=B}B=dT(25208)|0;c[(c[bY>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=B;c[(c[bY>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=102;c[(c[bY>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[D>>2]|0;if((ba|0)==0){break L7868}B=ba+8|0;F=ba+4|0;A=c[F>>2]|0;if((c[B>>2]|0)>>>0<A>>>0){b_=ba|0}else{C=(A<<1)+2|0;c[F>>2]=C;F=ba|0;c[F>>2]=sT(c[F>>2]|0,C*12|0)|0;b_=F}F=dT(46488)|0;c[(c[b_>>2]|0)+((c[B>>2]|0)*12|0)>>2]=F;c[(c[b_>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=103;c[(c[b_>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[D>>2]|0;if((B|0)==0){break L7868}F=B+8|0;C=B+4|0;ba=c[C>>2]|0;if((c[F>>2]|0)>>>0<ba>>>0){b$=B|0}else{A=(ba<<1)+2|0;c[C>>2]=A;C=B|0;c[C>>2]=sT(c[C>>2]|0,A*12|0)|0;b$=C}C=dT(46344)|0;c[(c[b$>>2]|0)+((c[F>>2]|0)*12|0)>>2]=C;c[(c[b$>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=104;c[(c[b$>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[D>>2]|0;if((F|0)==0){break L7868}C=F+8|0;A=F+4|0;B=c[A>>2]|0;if((c[C>>2]|0)>>>0<B>>>0){b0=F|0}else{ba=(B<<1)+2|0;c[A>>2]=ba;A=F|0;c[A>>2]=sT(c[A>>2]|0,ba*12|0)|0;b0=A}A=dT(31296)|0;c[(c[b0>>2]|0)+((c[C>>2]|0)*12|0)>>2]=A;c[(c[b0>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=105;c[(c[b0>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[D>>2]|0;if((C|0)==0){break L7868}A=C+8|0;ba=C+4|0;F=c[ba>>2]|0;if((c[A>>2]|0)>>>0<F>>>0){b1=C|0}else{B=(F<<1)+2|0;c[ba>>2]=B;ba=C|0;c[ba>>2]=sT(c[ba>>2]|0,B*12|0)|0;b1=ba}ba=dT(27864)|0;c[(c[b1>>2]|0)+((c[A>>2]|0)*12|0)>>2]=ba;c[(c[b1>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=106;c[(c[b1>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[D>>2]|0;if((A|0)==0){break L7868}ba=A+8|0;B=A+4|0;C=c[B>>2]|0;if((c[ba>>2]|0)>>>0<C>>>0){b2=A|0}else{F=(C<<1)+2|0;c[B>>2]=F;B=A|0;c[B>>2]=sT(c[B>>2]|0,F*12|0)|0;b2=B}B=dT(46096)|0;c[(c[b2>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=B;c[(c[b2>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=107;c[(c[b2>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[D>>2]|0;if((ba|0)==0){break L7868}B=ba+8|0;F=ba+4|0;A=c[F>>2]|0;if((c[B>>2]|0)>>>0<A>>>0){b3=ba|0}else{C=(A<<1)+2|0;c[F>>2]=C;F=ba|0;c[F>>2]=sT(c[F>>2]|0,C*12|0)|0;b3=F}F=dT(45872)|0;c[(c[b3>>2]|0)+((c[B>>2]|0)*12|0)>>2]=F;c[(c[b3>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=108;c[(c[b3>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[D>>2]|0;if((B|0)==0){break L7868}F=B+8|0;C=B+4|0;ba=c[C>>2]|0;if((c[F>>2]|0)>>>0<ba>>>0){b4=B|0}else{A=(ba<<1)+2|0;c[C>>2]=A;C=B|0;c[C>>2]=sT(c[C>>2]|0,A*12|0)|0;b4=C}C=dT(45776)|0;c[(c[b4>>2]|0)+((c[F>>2]|0)*12|0)>>2]=C;c[(c[b4>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=109;c[(c[b4>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[D>>2]|0;if((F|0)==0){break L7868}C=F+8|0;A=F+4|0;B=c[A>>2]|0;if((c[C>>2]|0)>>>0<B>>>0){b6=F|0}else{ba=(B<<1)+2|0;c[A>>2]=ba;A=F|0;c[A>>2]=sT(c[A>>2]|0,ba*12|0)|0;b6=A}A=dT(45704)|0;c[(c[b6>>2]|0)+((c[C>>2]|0)*12|0)>>2]=A;c[(c[b6>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=110;c[(c[b6>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;break L7868;break};case 26:{C=v|0;A=b+44|0;ba=c[A>>2]|0;F=ba+8|0;if((c[F>>2]|0)!=0){B=ba|0;ba=0;do{sS(c[(c[B>>2]|0)+(ba*12|0)>>2]|0);ba=ba+1|0;}while(ba>>>0<(c[F>>2]|0)>>>0)}c[F>>2]=0;ba=c[A>>2]|0;do{if((ba|0)!=0){B=ba+8|0;D=ba+4|0;z=c[D>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){b7=ba|0}else{a8=(z<<1)+2|0;c[D>>2]=a8;D=ba|0;c[D>>2]=sT(c[D>>2]|0,a8*12|0)|0;b7=D}D=dT(15640)|0;c[(c[b7>>2]|0)+((c[B>>2]|0)*12|0)>>2]=D;c[(c[b7>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=29;c[(c[b7>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[A>>2]|0;if((B|0)==0){break}D=B+8|0;a8=B+4|0;z=c[a8>>2]|0;if((c[D>>2]|0)>>>0<z>>>0){b8=B|0}else{y=(z<<1)+2|0;c[a8>>2]=y;a8=B|0;c[a8>>2]=sT(c[a8>>2]|0,y*12|0)|0;b8=a8}a8=dT(15512)|0;c[(c[b8>>2]|0)+((c[D>>2]|0)*12|0)>>2]=a8;c[(c[b8>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=27;c[(c[b8>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[A>>2]|0;if((D|0)==0){break}a8=D+8|0;y=D+4|0;B=c[y>>2]|0;if((c[a8>>2]|0)>>>0<B>>>0){b9=D|0}else{z=(B<<1)+2|0;c[y>>2]=z;y=D|0;c[y>>2]=sT(c[y>>2]|0,z*12|0)|0;b9=y}y=dT(15368)|0;c[(c[b9>>2]|0)+((c[a8>>2]|0)*12|0)>>2]=y;c[(c[b9>>2]|0)+((c[a8>>2]|0)*12|0)+4>>2]=28;c[(c[b9>>2]|0)+((c[a8>>2]|0)*12|0)+8>>2]=0;c[a8>>2]=(c[a8>>2]|0)+1;a8=c[A>>2]|0;if((a8|0)==0){break}y=a8+8|0;z=a8+4|0;D=c[z>>2]|0;if((c[y>>2]|0)>>>0<D>>>0){ca=a8|0}else{B=(D<<1)+2|0;c[z>>2]=B;z=a8|0;c[z>>2]=sT(c[z>>2]|0,B*12|0)|0;ca=z}z=dT(15232)|0;c[(c[ca>>2]|0)+((c[y>>2]|0)*12|0)>>2]=z;c[(c[ca>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=30;c[(c[ca>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1}}while(0);ba=b+4252|0;if((c[ba>>2]|0)==0){break L7868}else{cb=0}do{b5(C|0,64,15048,(_=i,i=i+8|0,c[_>>2]=cb,_)|0)|0;i=_;F=c[A>>2]|0;y=cb*3|0;z=y+31|0;if((F|0)!=0){B=F+8|0;a8=F+4|0;D=c[a8>>2]|0;if((c[B>>2]|0)>>>0<D>>>0){cc=F|0}else{a9=(D<<1)+2|0;c[a8>>2]=a9;a8=F|0;c[a8>>2]=sT(c[a8>>2]|0,a9*12|0)|0;cc=a8}a8=dT(C|0)|0;c[(c[cc>>2]|0)+((c[B>>2]|0)*12|0)>>2]=a8;c[(c[cc>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=z;c[(c[cc>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1}b5(C|0,64,14848,(_=i,i=i+8|0,c[_>>2]=cb,_)|0)|0;i=_;B=c[A>>2]|0;z=y+32|0;if((B|0)!=0){a8=B+8|0;a9=B+4|0;F=c[a9>>2]|0;if((c[a8>>2]|0)>>>0<F>>>0){cd=B|0}else{D=(F<<1)+2|0;c[a9>>2]=D;a9=B|0;c[a9>>2]=sT(c[a9>>2]|0,D*12|0)|0;cd=a9}a9=dT(C|0)|0;c[(c[cd>>2]|0)+((c[a8>>2]|0)*12|0)>>2]=a9;c[(c[cd>>2]|0)+((c[a8>>2]|0)*12|0)+4>>2]=z;c[(c[cd>>2]|0)+((c[a8>>2]|0)*12|0)+8>>2]=0;c[a8>>2]=(c[a8>>2]|0)+1}b5(C|0,64,14568,(_=i,i=i+8|0,c[_>>2]=cb,_)|0)|0;i=_;a8=c[A>>2]|0;z=y+33|0;if((a8|0)!=0){y=a8+8|0;a9=a8+4|0;D=c[a9>>2]|0;if((c[y>>2]|0)>>>0<D>>>0){ce=a8|0}else{B=(D<<1)+2|0;c[a9>>2]=B;a9=a8|0;c[a9>>2]=sT(c[a9>>2]|0,B*12|0)|0;ce=a9}a9=dT(C|0)|0;c[(c[ce>>2]|0)+((c[y>>2]|0)*12|0)>>2]=a9;c[(c[ce>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=z;c[(c[ce>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1}cb=cb+1|0;}while(cb>>>0<(c[ba>>2]|0)>>>0);break};default:{je(b);break L7868}}}}while(0);ji(b);a4=0;i=f;return a4|0}function jh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;if((a[383584]&1)!=0){g=c[135158]|0;h=(g|0)!=0?g:c[t>>2]|0;g=(e|0)!=0?e:17472;eQ(h|0,17656,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;h=c[135158]|0;g=(h|0)!=0?h:c[t>>2]|0;a7(g|0)|0}if(!(f7[c[(c[136863]|0)+20>>2]&127](c[136866]|0,d,e)|0)){d=c[135158]|0;g=(d|0)!=0?d:c[t>>2]|0;be(17192,46,1,g|0)|0;g=c[135158]|0;d=(g|0)!=0?g:c[t>>2]|0;a7(d|0)|0;a[285388]=0;i=f;return}d=(e|0)!=0;g=4096;h=281292;j=d?e:547872;while(1){k=g-1|0;if((k|0)==0){l=5921;break}m=a[j]|0;a[h]=m;if(m<<24>>24==0){break}else{g=k;h=h+1|0;j=j+1|0}}do{if((l|0)==5921){a[h]=0;if((a[j]|0)==0){break}else{n=j}do{n=n+1|0;}while((a[n]|0)!=0)}}while(0);a[285388]=1;if((b|0)==0|d^1){i=f;return}d=hz(e,0)|0;if((d|0)!=0){iU(d,b)|0;iY(b,e);hx(d)}a[(c[15704]|0)+52|0]=1;i=f;return}function ji(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0.0,ax=0.0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0;e=i;i=i+1480|0;f=e|0;j=e+256|0;k=e+512|0;l=e+576|0;m=e+832|0;n=e+1088|0;o=e+1160|0;p=e+1416|0;do{if((a[d+52|0]&1)!=0){q=540624;if((c[q>>2]&4|0)==0&(c[q+4>>2]&0|0)==0){break}if((a[d+53|0]&1)!=0){break}i=e;return}}while(0);q=d+48|0;r=c[q>>2]|0;s=r+17|0;t=d+44|0;u=c[(c[t>>2]|0)+8>>2]|0;v=s>>>0>u>>>0?u:s;s=u>>>0>17?r>>>0<8?0:r-8|0:0;r=(v-s|0)>>>0>17?s+17|0:v;v=d+28|0;u=c[v>>2]|0;w=d+32|0;x=(c[w>>2]|0)>>>1;y=0;do{z=ag(y,x)|0;A=y>>>1;B=0;do{C=((B>>>1)+A&1)+1|0;b[u+(B+z<<1)>>1]=(C<<9|C<<13|C<<5|12)&65535;B=B+1|0;}while(B>>>0<320);y=y+1|0;}while(y>>>0<240);y=c[v>>2]|0;u=(c[w>>2]|0)>>>1;x=u*5|0;B=5;do{z=(B>>>1&1)+1|0;b[y+(B+x<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=u*6|0;x=5;do{z=2-(x>>>1&1)|0;b[y+(x+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=u*7|0;B=5;do{z=2-(B>>>1&1)|0;b[y+(B+x<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=u<<3;x=5;do{z=(x>>>1&1)+1|0;b[y+(x+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=u*9|0;u=5;do{B=(u>>>1&1)+1|0;b[y+(u+x<<1)>>1]=(B<<10|B<<13|B<<5|12)&65535;u=u+1|0;}while(u>>>0<315);u=c[v>>2]|0;x=(c[w>>2]|0)>>>1;y=x*230|0;B=5;do{z=2-(B>>>1&1)|0;b[u+(B+y<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=x*231|0;y=5;do{z=2-(y>>>1&1)|0;b[u+(y+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;y=y+1|0;}while(y>>>0<315);y=x*232|0;B=5;do{z=(B>>>1&1)+1|0;b[u+(B+y<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=x*233|0;y=5;do{z=(y>>>1&1)+1|0;b[u+(y+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;y=y+1|0;}while(y>>>0<315);y=x*234|0;x=5;do{B=2-(x>>>1&1)|0;b[u+(x+y<<1)>>1]=(B<<10|B<<13|B<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=c[v>>2]|0;y=(c[w>>2]|0)>>>1;u=5;do{B=ag(u,y)|0;z=u>>>1&1;A=z+1|0;C=(A<<10|A<<13|A<<5|12)&65535;b[x+(B+5<<1)>>1]=C;A=2-z|0;z=(A<<10|A<<13|A<<5|12)&65535;b[x+(B+6<<1)>>1]=z;b[x+(B+7<<1)>>1]=z;b[x+(B+8<<1)>>1]=C;b[x+(B+9<<1)>>1]=C;u=u+1|0;}while(u>>>0<235);u=c[v>>2]|0;v=(c[w>>2]|0)>>>1;w=5;do{x=ag(w,v)|0;y=w>>>1&1;C=2-y|0;B=(C<<10|C<<13|C<<5|12)&65535;b[u+(x+310<<1)>>1]=B;b[u+(x+311<<1)>>1]=B;C=y+1|0;y=(C<<10|C<<13|C<<5|12)&65535;b[u+(x+312<<1)>>1]=y;b[u+(x+313<<1)>>1]=y;b[u+(x+314<<1)>>1]=B;w=w+1|0;}while(w>>>0<235);w=c[d+40>>2]|0;u=c[w+8>>2]|0;L8323:do{if((u|0)==0){D=0;E=0;F=5967}else{v=u-1|0;B=c[w>>2]|0;x=c[B+(v*12|0)>>2]|0;y=c[B+(v*12|0)+4>>2]|0;switch(y|0){case 57:{b5(f|0,256,28840,(G=i,i=i+8|0,c[G>>2]=x,G)|0)|0;i=G;H=57;break L8323;break};case 5:{a[f|0]=86;a[f+1|0]=73;a[f+2|0]=68;a[f+3|0]=69;a[f+4|0]=79;a[f+5|0]=32;a[f+6|0]=79;a[f+7|0]=80;a[f+8|0]=84;a[f+9|0]=73;a[f+10|0]=79;a[f+11|0]=78;a[f+12|0]=83;a[f+13|0]=0;H=5;break L8323;break};case 71:{b5(f|0,256,24376,(G=i,i=i+8|0,c[G>>2]=x,G)|0)|0;i=G;H=71;break L8323;break};case 26:{a[f|0]=83;a[f+1|0]=72;a[f+2|0]=65;a[f+3|0]=68;a[f+4|0]=69;a[f+5|0]=82;a[f+6|0]=32;a[f+7|0]=79;a[f+8|0]=80;a[f+9|0]=84;a[f+10|0]=73;a[f+11|0]=79;a[f+12|0]=78;a[f+13|0]=83;a[f+14|0]=0;H=26;break L8323;break};case 59:{a[f|0]=65;a[f+1|0]=85;a[f+2|0]=68;a[f+3|0]=73;a[f+4|0]=79;a[f+5|0]=32;a[f+6|0]=79;a[f+7|0]=80;a[f+8|0]=84;a[f+9|0]=73;a[f+10|0]=79;a[f+11|0]=78;a[f+12|0]=83;a[f+13|0]=0;H=59;break L8323;break};case 69:{a[f|0]=68;a[f+1|0]=73;a[f+2|0]=83;a[f+3|0]=75;a[f+4|0]=32;a[f+5|0]=79;a[f+6|0]=80;a[f+7|0]=84;a[f+8|0]=73;a[f+9|0]=79;a[f+10|0]=78;a[f+11|0]=83;a[f+12|0]=0;H=69;break L8323;break};case 58:{a[f|0]=67;a[f+1|0]=79;a[f+2|0]=82;a[f+3|0]=69;a[f+4|0]=32;a[f+5|0]=79;a[f+6|0]=80;a[f+7|0]=84;a[f+8|0]=73;a[f+9|0]=79;a[f+10|0]=78;a[f+11|0]=83;a[f+12|0]=0;H=58;break L8323;break};default:{D=x;E=y;F=5967;break L8323}}}}while(0);L8333:do{if((F|0)==5967){w=E-31|0;if(w>>>0<24&((w>>>0)%3|0|0)==0|(E|0)==28){w=f|0;b5(w|0,256,52456,(G=i,i=i+8|0,c[G>>2]=D,G)|0)|0;i=G;H=E;break}if((E-60|0)>>>0<3|(E|0)==12|(E|0)==13|(E|0)==4){w=f|0;b5(w|0,256,49944,(G=i,i=i+8|0,c[G>>2]=D,G)|0)|0;i=G;H=E;break}switch(E|0){case 78:{b5(f|0,256,40232,(G=i,i=i+8|0,c[G>>2]=D,G)|0)|0;i=G;H=78;break L8333;break};case 76:{b5(f|0,256,41208,(G=i,i=i+8|0,c[G>>2]=D,G)|0)|0;i=G;H=76;break L8333;break};case 73:{b5(f|0,256,44992,(G=i,i=i+8|0,c[G>>2]=D,G)|0)|0;i=G;H=73;break L8333;break};case 79:{b5(f|0,256,39352,(G=i,i=i+8|0,c[G>>2]=D,G)|0)|0;i=G;H=79;break L8333;break};case 56:{a[f|0]=76;a[f+1|0]=79;a[f+2|0]=65;a[f+3|0]=68;a[f+4|0]=32;a[f+5|0]=72;a[f+6|0]=73;a[f+7|0]=83;a[f+8|0]=84;a[f+9|0]=79;a[f+10|0]=82;a[f+11|0]=89;a[f+12|0]=0;H=56;break L8333;break};case 74:{b5(f|0,256,43616,(G=i,i=i+8|0,c[G>>2]=D,G)|0)|0;i=G;H=74;break L8333;break};case 88:{b5(f|0,256,45992,(G=i,i=i+8|0,c[G>>2]=D,G)|0)|0;i=G;H=88;break L8333;break};case 75:{b5(f|0,256,42232,(G=i,i=i+8|0,c[G>>2]=D,G)|0)|0;i=G;H=75;break L8333;break};default:{w=c[d+4160>>2]|0;u=(w|0)==0?c[119468]|0:w;b5(f|0,256,37112,(G=i,i=i+16|0,c[G>>2]=(u|0)==0?38360:u,c[G+8>>2]=D,G)|0)|0;i=G;H=E;break L8333}}}}while(0);E=j|0;jd(E,45,((c[135098]|0)>>>0)/15|0,f|0,1);jj(d,30,15,E,1);E=c[d+4160>>2]|0;f=(E|0)==0?c[119468]|0:E;E=c[d+4164>>2]|0;j=(E|0)==0?c[119469]|0:E;E=k|0;b5(E|0,64,35144,(G=i,i=i+24|0,c[G>>2]=33840,c[G+8>>2]=(f|0)==0?38360:f,c[G+16>>2]=(j|0)==0?547872:j,G)|0)|0;i=G;jj(d,30,216,E,1);if(s>>>0>=r>>>0){i=e;return}E=d+113708|0;j=m|0;f=o|0;o=p|0;p=l|0;l=n+8|0;k=n|0;D=n;u=(H|0)==60?24:(H|0)==61?24:19;w=H-31|0;y=w>>>0<24&((w>>>0)%3|0|0)==0|(H|0)==28;w=m+1|0;x=m+2|0;v=m+3|0;B=m+4|0;C=m+5|0;z=m+6|0;A=m+7|0;I=m+8|0;J=m+9|0;L=m+10|0;M=d+4252|0;N=(H-73|0)>>>0<4|(H|0)==78|(H|0)==79;O=(H|0)==56;P=m+11|0;Q=m+12|0;R=m+13|0;S=m+14|0;T=m+15|0;U=m+16|0;V=m+17|0;X=m+18|0;m=n+9|0;Y=n+10|0;Z=n+11|0;_=n+12|0;$=n+13|0;aa=n+14|0;ab=n+15|0;n=s;s=27;while(1){ac=c[c[t>>2]>>2]|0;ad=c[ac+(n*12|0)>>2]|0;ae=c[ac+(n*12|0)+4>>2]|0;ac=c[E>>2]|0;L8357:do{if((ae-27|0)>>>0<28){do{if(y){af=ae-31|0;if(!(af>>>0<24&((af>>>0)%3|0|0)==0|(ae|0)==28)){break}a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break L8357}}while(0);if((ae|0)==30){af=c[M>>2]|0;b5(j|0,256,51e3,(G=i,i=i+8|0,c[G>>2]=af,G)|0)|0;i=G;ah=u;ai=30;break}else if((ae|0)==29){a[j]=0;ah=u;ai=29;break}else if((ae|0)==27){b5(j|0,256,31448,(G=i,i=i+8|0,c[G>>2]=(a[281276]&1)!=0?30792:30384,G)|0)|0;i=G;ah=u;ai=27;break}else if((ae|0)==28){a[j]=46;a[w]=46;a[x]=46;a[v]=0;ah=u;ai=28;break}else{af=ae-31|0;aj=(af>>>0)/3|0;ak=(af>>>0)%3|0;if((ak|0)==2){af=~~+g[d+4256+(aj*4148|0)+4116>>2];if((af|0)==0){a[j]=68;a[w]=111;a[x]=110;a[v]=39;a[B]=116;a[C]=32;a[z]=99;a[A]=97;a[I]=114;a[J]=101;a[L]=0;ah=u;ai=ae;break}else{b5(j|0,256,49952,(G=i,i=i+8|0,c[G>>2]=af,G)|0)|0;i=G;ah=u;ai=ae;break}}else if((ak|0)==0){af=d+4256+(aj*4148|0)|0;if((a[af]|0)==0){a[j]=78;a[w]=47;a[x]=65;a[v]=0;ah=u;ai=ae;break}else{hr(j,af,256);ah=u;ai=ae;break}}else if((ak|0)==1){ak=c[d+4256+(aj*4148|0)+4136>>2]|0;if((ak|0)==1){a[j]=76;a[w]=105;a[x]=110;a[v]=101;a[B]=97;a[C]=114;a[z]=0;ah=u;ai=ae;break}else if((ak|0)==2){a[j]=78;a[w]=101;a[x]=97;a[v]=114;a[B]=101;a[C]=115;a[z]=116;a[A]=0;ah=u;ai=ae;break}else if((ak|0)==0){a[j]=68;a[w]=111;a[x]=110;a[v]=39;a[B]=116;a[C]=32;a[z]=99;a[A]=97;a[I]=114;a[J]=101;a[L]=0;ah=u;ai=ae;break}else{ah=u;ai=ae;break}}else{ah=u;ai=ae;break}}}else{do{if(!((H|0)==88|(H|0)==71|(H|0)==57)){if(N){break}if(O){a[j]=0;ah=0;ai=ae;break L8357}if(ae>>>0>65535){ak=ae-65536|0;aj=c[(c[120666]|0)+4100>>2]|0;af=256;al=j;am=c[(c[c[aj+(ak<<4)+8>>2]>>2]|0)+(c[aj+(ak<<4)+12>>2]<<3)>>2]|0;while(1){ak=af-1|0;if((ak|0)==0){break}aj=a[am]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=ae;break L8357}else{af=ak;al=al+1|0;am=am+1|0}}a[al]=0;if((a[am]|0)==0){ah=u;ai=ae;break L8357}else{an=am}while(1){af=an+1|0;if((a[af]|0)==0){ah=u;ai=ae;break L8357}else{an=af}}}switch(ae|0){case 17:{am=256;al=j;af=(a[281265]&1)!=0?29664:29184;while(1){ak=am-1|0;if((ak|0)==0){break}aj=a[af]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=17;break L8357}else{am=ak;al=al+1|0;af=af+1|0}}a[al]=0;if((a[af]|0)==0){ah=u;ai=17;break L8357}else{ao=af}while(1){am=ao+1|0;if((a[am]|0)==0){ah=u;ai=17;break L8357}else{ao=am}}break};case 24:{do{if((a[289492]&1)==0){af=531936;al=c[af>>2]|0;am=c[af+4>>2]|0;af=0;ak=am>>>0>af>>>0|am>>>0==af>>>0&al>>>0>2048>>>0?2048:al;if(ak>>>0<2){break}else{ap=0;aq=0;ar=0}do{al=515552+(ap<<3)|0;ar=ta(c[al>>2]|0,c[al+4>>2]|0,ar,aq)|0;aq=K;ap=ap+1|0;}while(ap>>>0<ak>>>0);al=ti(ar,aq,ak,0)|0;af=K;am=0;aj=0;as=0;do{at=515552+(as<<3)|0;au=tb(c[at>>2]|0,c[at+4>>2]|0,al,af)|0;at=K;av=tk(au,at,au,at)|0;aj=ta(av,K,aj,am)|0;am=K;as=as+1|0;}while(as>>>0<ak>>>0);aw=+(al>>>0)+ +(af|0)*4294967296.0;ax=+W(+((+(aj>>>0)+ +(am|0)*4294967296.0)/+((ak-1|0)>>>0>>>0)))/aw*100.0;b5(j|0,256,26448,(G=i,i=i+24|0,h[G>>3]=1.0e6/aw,h[G+8>>3]=ax,c[G+16>>2]=ak,G)|0)|0;i=G;ah=u;ai=24;break L8357}}while(0);a[j]=78;a[w]=47;a[x]=65;a[v]=0;ah=u;ai=24;break L8357;break};case 15:{as=256;av=j;at=1320+(c[135149]<<5)|0;while(1){au=as-1|0;if((au|0)==0){break}ay=a[at]|0;a[av]=ay;if(ay<<24>>24==0){ah=u;ai=15;break L8357}else{as=au;av=av+1|0;at=at+1|0}}a[av]=0;if((a[at]|0)==0){ah=u;ai=15;break L8357}else{az=at}while(1){as=az+1|0;if((a[as]|0)==0){ah=u;ai=15;break L8357}else{az=as}}break};case 94:{at=c[342508+(ac<<2)>>2]|0;if((at|0)==2){a[j]=82;a[w]=105;a[x]=103;a[v]=104;a[B]=116;a[C]=32;a[z]=83;a[A]=116;a[I]=105;a[J]=99;a[L]=107;a[P]=0;ah=u;ai=94;break L8357}else if((at|0)==3){a[j]=68;a[w]=117;a[x]=97;a[v]=108;a[B]=32;a[C]=65;a[z]=110;a[A]=97;a[I]=108;a[J]=111;a[L]=103;a[P]=0;ah=u;ai=94;break L8357}else if((at|0)==1){a[j]=76;a[w]=101;a[x]=102;a[v]=116;a[B]=32;a[C]=83;a[z]=116;a[A]=105;a[I]=99;a[J]=107;a[L]=0;ah=u;ai=94;break L8357}else if((at|0)==0){a[j]=78;a[w]=111;a[x]=110;a[v]=101;a[B]=0;ah=u;ai=94;break L8357}else{ah=u;ai=94;break L8357}break};case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:case 108:case 109:case 110:{at=c[1552+(ae-95<<2)>>2]|0;a[l]=85;a[m]=110;a[Y]=107;a[Z]=110;a[_]=111;a[$]=119;a[aa]=110;a[ab]=0;av=306080+(ac*2240|0)+(at*40|0)+16|0;at=c[av+4>>2]|0;c[k>>2]=c[av>>2];c[k+4>>2]=at;at=c[(c[136864]|0)+20>>2]|0;if((at|0)==0){aA=256;aB=j;aC=l}else{f_[at&15](D,0,0,0,256);aA=256;aB=j;aC=l}while(1){at=aA-1|0;if((at|0)==0){break}av=a[aC]|0;a[aB]=av;if(av<<24>>24==0){ah=u;ai=ae;break L8357}else{aA=at;aB=aB+1|0;aC=aC+1|0}}a[aB]=0;if((a[aC]|0)==0){ah=u;ai=ae;break L8357}else{aD=aC}while(1){at=aD+1|0;if((a[at]|0)==0){ah=u;ai=ae;break L8357}else{aD=at}}break};case 82:{b5(j|0,256,25744,(G=i,i=i+8|0,h[G>>3]=+g[76493],G)|0)|0;i=G;ah=u;ai=82;break L8357;break};case 84:{at=540624;b5(j|0,256,((c[at>>2]&256|0)!=0|(c[at+4>>2]&0|0)!=0?29664:29184)|0,(G=i,i=i+1|0,i=i+7>>3<<3,c[G>>2]=0,G)|0)|0;i=G;ah=u;ai=84;break L8357;break};case 73:{at=256;av=j;as=(a[379465]|0)!=0?379465:25336;while(1){au=at-1|0;if((au|0)==0){break}ay=a[as]|0;a[av]=ay;if(ay<<24>>24==0){ah=u;ai=73;break L8357}else{at=au;av=av+1|0;as=as+1|0}}a[av]=0;if((a[as]|0)==0){ah=u;ai=73;break L8357}else{aE=as}while(1){at=aE+1|0;if((a[at]|0)==0){ah=u;ai=73;break L8357}else{aE=at}}break};case 78:{as=256;av=j;at=(a[461458]|0)!=0?461458:25336;while(1){au=as-1|0;if((au|0)==0){break}ay=a[at]|0;a[av]=ay;if(ay<<24>>24==0){ah=u;ai=78;break L8357}else{as=au;av=av+1|0;at=at+1|0}}a[av]=0;if((a[at]|0)==0){ah=u;ai=78;break L8357}else{aF=at}while(1){as=aF+1|0;if((a[as]|0)==0){ah=u;ai=78;break L8357}else{aF=as}}break};case 75:{at=256;av=j;as=(a[457362]|0)!=0?457362:24744;while(1){au=at-1|0;if((au|0)==0){break}ay=a[as]|0;a[av]=ay;if(ay<<24>>24==0){ah=u;ai=75;break L8357}else{at=au;av=av+1|0;as=as+1|0}}a[av]=0;if((a[as]|0)==0){ah=u;ai=75;break L8357}else{aG=as}while(1){at=aG+1|0;if((a[at]|0)==0){ah=u;ai=75;break L8357}else{aG=at}}break};case 23:{as=256;av=j;at=(a[281278]&1)!=0?29664:29184;while(1){au=as-1|0;if((au|0)==0){break}ay=a[at]|0;a[av]=ay;if(ay<<24>>24==0){ah=u;ai=23;break L8357}else{as=au;av=av+1|0;at=at+1|0}}a[av]=0;if((a[at]|0)==0){ah=u;ai=23;break L8357}else{aH=at}while(1){as=aH+1|0;if((a[as]|0)==0){ah=u;ai=23;break L8357}else{aH=as}}break};case 55:case 56:case 58:case 12:case 14:case 5:case 59:case 69:case 26:case 28:case 57:case 71:case 60:case 61:case 62:{a[j]=46;a[w]=46;a[x]=46;a[v]=0;ah=u;ai=ae;break L8357;break};case 1:{a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break L8357;break};case 0:{a[j]=40;a[w]=70;a[x]=73;a[v]=76;a[B]=69;a[C]=41;a[z]=0;ah=6;ai=0;break L8357;break};case 66:{at=256;av=j;as=(c[94863]|0)!=0?29664:29184;while(1){au=at-1|0;if((au|0)==0){break}ay=a[as]|0;a[av]=ay;if(ay<<24>>24==0){ah=u;ai=66;break L8357}else{at=au;av=av+1|0;as=as+1|0}}a[av]=0;if((a[as]|0)==0){ah=u;ai=66;break L8357}else{aI=as}while(1){at=aI+1|0;if((a[at]|0)==0){ah=u;ai=66;break L8357}else{aI=at}}break};case 65:{as=256;av=j;at=(a[540638]&1)!=0?29664:29184;while(1){au=as-1|0;if((au|0)==0){break}ay=a[at]|0;a[av]=ay;if(ay<<24>>24==0){ah=u;ai=65;break L8357}else{as=au;av=av+1|0;at=at+1|0}}a[av]=0;if((a[at]|0)==0){ah=u;ai=65;break L8357}else{aJ=at}while(1){as=aJ+1|0;if((a[as]|0)==0){ah=u;ai=65;break L8357}else{aJ=as}}break};case 21:{b5(j|0,256,26896,(G=i,i=i+8|0,h[G>>3]=+g[70310],G)|0)|0;i=G;ah=u;ai=21;break L8357;break};case 19:{at=256;av=j;as=(a[281266]&1)!=0?29664:29184;while(1){au=at-1|0;if((au|0)==0){break}ay=a[as]|0;a[av]=ay;if(ay<<24>>24==0){ah=u;ai=19;break L8357}else{at=au;av=av+1|0;as=as+1|0}}a[av]=0;if((a[as]|0)==0){ah=u;ai=19;break L8357}else{aK=as}while(1){at=aK+1|0;if((a[at]|0)==0){ah=u;ai=19;break L8357}else{aK=at}}break};case 22:{b5(j|0,256,26896,(G=i,i=i+8|0,h[G>>3]=+g[70311],G)|0)|0;i=G;ah=u;ai=22;break L8357;break};case 63:{as=256;av=j;at=(a[379428]&1)!=0?29664:29184;while(1){au=as-1|0;if((au|0)==0){break}ay=a[at]|0;a[av]=ay;if(ay<<24>>24==0){ah=u;ai=63;break L8357}else{as=au;av=av+1|0;at=at+1|0}}a[av]=0;if((a[at]|0)==0){ah=u;ai=63;break L8357}else{aL=at}while(1){as=aL+1|0;if((a[as]|0)==0){ah=u;ai=63;break L8357}else{aL=as}}break};case 64:{b5(j|0,256,51e3,(G=i,i=i+8|0,c[G>>2]=c[94859],G)|0)|0;i=G;ah=u;ai=64;break L8357;break};case 18:{b5(j|0,256,51e3,(G=i,i=i+8|0,c[G>>2]=c[70318],G)|0)|0;i=G;ah=u;ai=18;break L8357;break};case 11:{at=256;av=j;as=10320+((c[70322]|0)*68|0)|0;while(1){au=at-1|0;if((au|0)==0){break}ay=a[as]|0;a[av]=ay;if(ay<<24>>24==0){ah=u;ai=11;break L8357}else{at=au;av=av+1|0;as=as+1|0}}a[av]=0;if((a[as]|0)==0){ah=u;ai=11;break L8357}else{aM=as}while(1){at=aM+1|0;if((a[at]|0)==0){ah=u;ai=11;break L8357}else{aM=at}}break};case 70:{as=gm[c[120646]&31]()|0;av=gm[c[120644]&31]()|0;if(av>>>0<as>>>0){as=av+1|0;b5(j|0,256,51e3,(G=i,i=i+8|0,c[G>>2]=as,G)|0)|0;i=G;ah=u;ai=70;break L8357}else{a[j]=78;a[w]=111;a[x]=32;a[v]=68;a[B]=105;a[C]=115;a[z]=107;a[A]=0;ah=u;ai=70;break L8357}break};case 88:{as=cD(342552,47)|0;av=256;at=j;au=(as|0)==0?342552:as+1|0;while(1){as=av-1|0;if((as|0)==0){break}ay=a[au]|0;a[at]=ay;if(ay<<24>>24==0){ah=u;ai=88;break L8357}else{av=as;at=at+1|0;au=au+1|0}}a[at]=0;if((a[au]|0)==0){ah=u;ai=88;break L8357}else{aN=au}while(1){av=aN+1|0;if((a[av]|0)==0){ah=u;ai=88;break L8357}else{aN=av}}break};case 20:{b5(j|0,256,51e3,(G=i,i=i+8|0,c[G>>2]=c[70317],G)|0)|0;i=G;ah=u;ai=20;break L8357;break};case 89:{b5(j|0,256,23736,(G=i,i=i+8|0,h[G>>3]=+g[86662],G)|0)|0;i=G;ah=u;ai=89;break L8357;break};case 90:{b5(j|0,256,23736,(G=i,i=i+8|0,h[G>>3]=+g[86663],G)|0)|0;i=G;ah=u;ai=90;break L8357;break};case 79:{au=256;at=j;av=(a[375332]|0)!=0?375332:24744;while(1){as=au-1|0;if((as|0)==0){break}ay=a[av]|0;a[at]=ay;if(ay<<24>>24==0){ah=u;ai=79;break L8357}else{au=as;at=at+1|0;av=av+1|0}}a[at]=0;if((a[av]|0)==0){ah=u;ai=79;break L8357}else{aO=av}while(1){au=aO+1|0;if((a[au]|0)==0){ah=u;ai=79;break L8357}else{aO=au}}break};case 93:{switch(c[383588+(ac<<2)>>2]|0){case 1:{aP=256;aQ=j;aR=22464;break};case 5:{aP=256;aQ=j;aR=22168;break};case 257:{aP=256;aQ=j;aR=22032;break};case 2:{aP=256;aQ=j;aR=21376;break};case 516:{aP=256;aQ=j;aR=20800;break};case 772:{aP=256;aQ=j;aR=20416;break};case 260:{aP=256;aQ=j;aR=19976;break};case 0:{aP=256;aQ=j;aR=22680;break};default:{aP=256;aQ=j;aR=19832}}while(1){av=aP-1|0;if((av|0)==0){break}at=a[aR]|0;a[aQ]=at;if(at<<24>>24==0){ah=u;ai=93;break L8357}else{aP=av;aQ=aQ+1|0;aR=aR+1|0}}a[aQ]=0;if((a[aR]|0)==0){ah=u;ai=93;break L8357}else{aS=aR}while(1){av=aS+1|0;if((a[av]|0)==0){ah=u;ai=93;break L8357}else{aS=av}}break};case 7:{if((a[281276]&1)==0){a[j]=80;a[w]=111;a[x]=105;a[v]=110;a[B]=116;a[C]=32;a[z]=102;a[A]=105;a[I]=108;a[J]=116;a[L]=101;a[P]=114;a[Q]=105;a[R]=110;a[S]=103;a[T]=0;ah=u;ai=7;break L8357}else{a[j]=66;a[w]=105;a[x]=108;a[v]=105;a[B]=110;a[C]=101;a[z]=97;a[A]=114;a[I]=32;a[J]=102;a[L]=105;a[P]=108;a[Q]=116;a[R]=101;a[S]=114;a[T]=105;a[U]=110;a[V]=103;a[X]=0;ah=u;ai=7;break L8357}break};case 9:{b5(j|0,256,11024,(G=i,i=i+8|0,c[G>>2]=c[135150],G)|0)|0;i=G;ah=u;ai=9;break L8357;break};case 16:{av=256;at=j;au=(a[281264]&1)!=0?29664:29184;while(1){as=av-1|0;if((as|0)==0){break}ay=a[au]|0;a[at]=ay;if(ay<<24>>24==0){ah=u;ai=16;break L8357}else{av=as;at=at+1|0;au=au+1|0}}a[at]=0;if((a[au]|0)==0){ah=u;ai=16;break L8357}else{aT=au}while(1){av=aT+1|0;if((a[av]|0)==0){ah=u;ai=16;break L8357}else{aT=av}}break};case 8:{au=540624;b5(j|0,256,((c[au>>2]&65536|0)!=0|(c[au+4>>2]&0|0)!=0?29664:29184)|0,(G=i,i=i+1|0,i=i+7>>3<<3,c[G>>2]=0,G)|0)|0;i=G;ah=u;ai=8;break L8357;break};case 10:{au=256;at=j;av=(a[281285]&1)!=0?29664:29184;while(1){as=au-1|0;if((as|0)==0){break}ay=a[av]|0;a[at]=ay;if(ay<<24>>24==0){ah=u;ai=10;break L8357}else{au=as;at=at+1|0;av=av+1|0}}a[at]=0;if((a[av]|0)==0){ah=u;ai=10;break L8357}else{aU=av}while(1){au=aU+1|0;if((a[au]|0)==0){ah=u;ai=10;break L8357}else{aU=au}}break};case 67:case 68:{b5(j|0,256,11024,(G=i,i=i+8|0,c[G>>2]=c[119462],G)|0)|0;i=G;ah=u;ai=ae;break L8357;break};case 81:{av=256;at=j;au=(a[482713]&1)!=0?29664:29184;while(1){as=av-1|0;if((as|0)==0){break}ay=a[au]|0;a[at]=ay;if(ay<<24>>24==0){ah=u;ai=81;break L8357}else{av=as;at=at+1|0;au=au+1|0}}a[at]=0;if((a[au]|0)==0){ah=u;ai=81;break L8357}else{aV=au}while(1){av=aV+1|0;if((a[av]|0)==0){ah=u;ai=81;break L8357}else{aV=av}}break};case 76:{au=256;at=j;av=(a[453266]|0)!=0?453266:24744;while(1){as=au-1|0;if((as|0)==0){break}ay=a[av]|0;a[at]=ay;if(ay<<24>>24==0){ah=u;ai=76;break L8357}else{au=as;at=at+1|0;av=av+1|0}}a[at]=0;if((a[av]|0)==0){ah=u;ai=76;break L8357}else{aW=av}while(1){au=aW+1|0;if((a[au]|0)==0){ah=u;ai=76;break L8357}else{aW=au}}break};case 74:{av=256;at=j;au=(a[289493]|0)!=0?289493:25336;while(1){as=av-1|0;if((as|0)==0){break}ay=a[au]|0;a[at]=ay;if(ay<<24>>24==0){ah=u;ai=74;break L8357}else{av=as;at=at+1|0;au=au+1|0}}a[at]=0;if((a[au]|0)==0){ah=u;ai=74;break L8357}else{aX=au}while(1){av=aX+1|0;if((a[av]|0)==0){ah=u;ai=74;break L8357}else{aX=av}}break};case 91:{b5(j|0,256,23504,(G=i,i=i+8|0,c[G>>2]=ac+1,G)|0)|0;i=G;ah=u;ai=91;break L8357;break};case 92:{au=c[341932+(ac<<2)>>2]|0;if(au>>>0>=8){a[j]=68;a[w]=105;a[x]=115;a[v]=97;a[B]=98;a[C]=108;a[z]=101;a[A]=100;a[I]=0;ah=u;ai=92;break L8357}at=341996+(au<<6)|0;if((a[at]|0)==0){b5(j|0,256,23208,(G=i,i=i+8|0,c[G>>2]=au,G)|0)|0;i=G;ah=u;ai=92;break L8357}else{aY=256;aZ=j;a_=at}while(1){at=aY-1|0;if((at|0)==0){break}au=a[a_]|0;a[aZ]=au;if(au<<24>>24==0){ah=u;ai=92;break L8357}else{aY=at;aZ=aZ+1|0;a_=a_+1|0}}a[aZ]=0;if((a[a_]|0)==0){ah=u;ai=92;break L8357}else{a$=a_}while(1){at=a$+1|0;if((a[at]|0)==0){ah=u;ai=92;break L8357}else{a$=at}}break};default:{a[j]=0;ah=0;ai=ae;break L8357}}}}while(0);if((ae|0)==0){a[j]=40;a[w]=70;a[x]=73;a[v]=76;a[B]=69;a[C]=41;a[z]=0;ah=6;ai=0;break}else if((ae|0)==3){a[j]=0;ah=0;ai=3;break}else{a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break}}}while(0);ae=(n|0)==(c[q>>2]|0);ac=256;at=f;au=ad;while(1){av=ac-1|0;if((av|0)==0){F=6156;break}as=a[au]|0;a[at]=as;if(as<<24>>24==0){a0=64;a1=o;a2=j;break}else{ac=av;at=at+1|0;au=au+1|0}}do{if((F|0)==6156){F=0;a[at]=0;if((a[au]|0)==0){a0=64;a1=o;a2=j;break}else{a3=au}while(1){ac=a3+1|0;if((a[ac]|0)==0){a0=64;a1=o;a2=j;break}else{a3=ac}}}}while(0);while(1){au=a0-1|0;if((au|0)==0){F=6160;break}at=a[a2]|0;a[a1]=at;if(at<<24>>24==0){break}else{a0=au;a1=a1+1|0;a2=a2+1|0}}do{if((F|0)==6160){F=0;a[a1]=0;if((a[a2]|0)==0){break}else{a4=a2}do{a4=a4+1|0;}while((a[a4]|0)!=0)}}while(0);if(ai>>>0<2){au=-3-ah|0;jd(f,au+48|0,((c[135098]|0)>>>0)/15|0,ad,ae);a5=au}else{jd(o,ah,((c[135098]|0)>>>0)/15|0,j,ae);a5=-3-ah|0}au=a5+48|0;b5(p|0,256,19352,(G=i,i=i+48|0,c[G>>2]=ae?62:32,c[G+8>>2]=au,c[G+16>>2]=au,c[G+24>>2]=f,c[G+32>>2]=ah,c[G+40>>2]=o,G)|0)|0;i=G;jj(d,15,s,p,ae);au=n+1|0;if(au>>>0<r>>>0){n=au;s=s+11|0}else{break}}i=e;return}function jj(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=a[h]|0;if(j<<24>>24==0){return}k=e+4152|0;l=i?32639:-1;i=e+32|0;m=e+28|0;e=h;h=f;f=j;while(1){j=h+4|0;n=h+3|0;o=h+2|0;p=h+1|0;q=0;r=f;while(1){s=q*5|0;t=q+g|0;u=c[k>>2]|0;if((1<<(s&7)&(d[u+((s>>3)+((r&255)*7|0))|0]|0)|0)==0){v=r;w=u}else{u=(ag((c[i>>2]|0)>>>1,t)|0)+h|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;v=a[e]|0;w=c[k>>2]|0}u=s+1|0;if(((d[w+(((v&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){x=v;y=w}else{u=p+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;x=a[e]|0;y=c[k>>2]|0}u=s+2|0;if(((d[y+(((x&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){z=x;A=y}else{u=o+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;z=a[e]|0;A=c[k>>2]|0}u=s+3|0;if(((d[A+(((z&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){B=z;C=A}else{u=n+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;B=a[e]|0;C=c[k>>2]|0}u=s+4|0;if(((d[C+(((B&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)!=0){u=j+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l}u=q+1|0;if((u|0)>=10){break}q=u;r=a[e]|0}r=e+1|0;q=a[r]|0;if(q<<24>>24==0){break}else{e=r;h=h+6|0;f=q}}return}function jk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+16|0;f=e|0;g=a+4|0;h=c[g>>2]|0;L8657:do{if((h|0)==0){j=0}else{k=a|0;l=c[k>>2]|0;L8659:do{if((b|0)==0){m=0;while(1){do{if((c[l+(m*12|0)>>2]|0)==0){if((da(c[l+(m*12|0)+4>>2]|0,358948)|0)!=0){break}if((da(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L8659}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L8657}}}else{m=0;while(1){o=c[l+(m*12|0)>>2]|0;do{if((o|0)!=0){if((da(b|0,o|0)|0)!=0){break}if((da(c[l+(m*12|0)+4>>2]|0,358948)|0)!=0){break}if((da(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L8659}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L8657}}}}while(0);if((n|0)==0){i=e;return}m=f;o=l+(n*12|0)|0;c[m>>2]=c[o>>2];c[m+4>>2]=c[o+4>>2];c[m+8>>2]=c[o+8>>2];s5(l+12|0,l|0,n*12|0|0);o=c[k>>2]|0;c[o>>2]=c[m>>2];c[o+4>>2]=c[m+4>>2];c[o+8>>2]=c[m+8>>2];i=e;return}}while(0);n=a+8|0;f=c[n>>2]|0;if((j|0)==(f|0)){h=j-1|0;j=a|0;m=c[j>>2]|0;o=m+(h*12|0)|0;sS(c[o>>2]|0);sS(c[m+(h*12|0)+4>>2]|0);sS(c[m+(h*12|0)+8>>2]|0);s_(o|0,0,12);c[g>>2]=(c[g>>2]|0)-1;p=c[n>>2]|0;q=j}else{p=f;q=a|0}a=c[q>>2]|0;s5(a+12|0,a|0,(p*12|0)-12|0);if((b|0)==0){r=0}else{r=dT(b|0)|0}c[c[q>>2]>>2]=r;r=dT(358948)|0;c[(c[q>>2]|0)+4>>2]=r;r=dT(d|0)|0;c[(c[q>>2]|0)+8>>2]=r;c[g>>2]=(c[g>>2]|0)+1;i=e;return}function jl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;if((a|0)==0){i=b;return}d=a+12|0;e=c[d>>2]|0;do{if((e|0)!=0){f=dz(e|0,57168)|0;if((f|0)==0){break}g=a+4|0;if((c[g>>2]|0)!=0){h=a|0;j=0;do{k=c[h>>2]|0;l=c[k+(j*12|0)>>2]|0;m=c[k+(j*12|0)+4>>2]|0;n=c[k+(j*12|0)+8>>2]|0;eQ(f|0,36216,(k=i,i=i+24|0,c[k>>2]=(l|0)==0?547872:l,c[k+8>>2]=m,c[k+16>>2]=n,k)|0)|0;i=k;j=j+1|0;}while(j>>>0<(c[g>>2]|0)>>>0)}a_(f|0)|0}}while(0);sS(c[d>>2]|0);d=a+8|0;e=a|0;g=c[e>>2]|0;if((c[d>>2]|0)==0){o=g}else{j=0;h=g;while(1){g=h+(j*12|0)|0;sS(c[g>>2]|0);sS(c[h+(j*12|0)+4>>2]|0);sS(c[h+(j*12|0)+8>>2]|0);s_(g|0,0,12);g=j+1|0;k=c[e>>2]|0;if(g>>>0<(c[d>>2]|0)>>>0){j=g;h=k}else{o=k;break}}}sS(o);sS(a);i=b;return}function jm(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+72|0;h=f|0;j=f+8|0;k=f+40|0;l=b+4|0;m=c[l>>2]|0;if((m|0)==0){i=f;return}if((gm[c[m+16>>2]&31]()|0)==0){i=f;return}m=j|0;a[m]=0;n=c[l>>2]|0;do{if((n|0)==0){o=6251}else{f0[c[n+28>>2]&255](1,j);p=c[l>>2]|0;if((p|0)==0){o=6251;break}q=gm[c[p+16>>2]&31]()|0;p=c[l>>2]|0;r=k|0;a[r]=0;if((p|0)==0){s=0;u=r;break}f0[c[p+28>>2]&255](q,k);q=c[l>>2]|0;if((q|0)==0){s=0;u=r;break}do{if((gm[c[q+16>>2]&31]()|0)==1){if((a[m]&1)!=0){break}i=f;return}}while(0);q=c[l>>2]|0;if((q|0)==0){s=0;u=r;break}s=gm[c[q+16>>2]&31]()|0;u=r}}while(0);if((o|0)==6251){n=k|0;a[n]=0;s=0;u=n}n=s-1|0;k=b+1636|0;c[k>>2]=n;if((a[u]&1)==0){v=n}else{c[k>>2]=s;v=s}if((a[m]&1)==0){g[j+12>>2]=1.0;g[j+16>>2]=1.0;c[j+8>>2]=0;c[j+4>>2]=0;a[m]=1}j=b+1124|0;s=j;s1(j|0,m|0,32)|0;if((v|0)>1){v=1;while(1){m=v+1|0;j=s+(v<<5)|0;n=j|0;a[n]=0;u=c[l>>2]|0;if((u|0)==0){o=6266}else{f0[c[u+28>>2]&255](m,j);if((a[n]&1)==0){o=6266}}if((o|0)==6266){o=0;g[s+(v<<5)+16>>2]=1.0;g[s+(v<<5)+12>>2]=1.0;c[s+(v<<5)+8>>2]=0;c[s+(v<<5)+4>>2]=0;a[n]=1}if((m|0)<(c[k>>2]|0)){v=m}else{break}}}jn(b,d,e,c[b+1728>>2]|0,c[b+1732>>2]|0);e=c[k>>2]|0;if((e|0)>0){d=b+740|0;v=0;while(1){m=(c[d+(v*24|0)>>2]|0)-1|0;n=m>>>1|m;m=n>>>2|n;n=m>>>4|m;m=n>>>8|n;n=(m>>>16|m)+1|0;c[d+(v*24|0)+16>>2]=n;m=(c[d+(v*24|0)+4>>2]|0)-1|0;j=m>>>1|m;m=j>>>2|j;j=m>>>4|m;m=j>>>8|j;j=(m>>>16|m)+1|0;c[d+(v*24|0)+20>>2]=j;if((a[383584]&1)!=0){m=c[135158]|0;u=(m|0)!=0?m:c[t>>2]|0;eQ(u|0,41736,(w=i,i=i+24|0,c[w>>2]=v,c[w+8>>2]=n,c[w+16>>2]=j,w)|0)|0;i=w;j=c[135158]|0;n=(j|0)!=0?j:c[t>>2]|0;a7(n|0)|0}n=v+1|0;j=c[k>>2]|0;if((n|0)<(j|0)){v=n}else{x=j;break}}}else{x=e}e=b+676|0;v=e;d=e;bM(x|0,d|0);x=(a[281276]&1)!=0?9729:9728;if((c[k>>2]|0)>0){e=b+740|0;j=b+2584|0;n=0;do{a6(3553,c[v+(n<<2)>>2]|0);a[h]=0;u=c[l>>2]|0;do{if((u|0)==0){y=33071;z=x}else{m=n+2|0;if(gj[c[u+20>>2]&127](m,h)|0){A=(a[h]&1)!=0?9729:9728}else{A=x}q=c[l>>2]|0;if((q|0)==0){y=33071;z=A;break}p=f2[c[q+24>>2]&255](m)|0;if((p|0)==2){y=10497;z=A;break}else if((p|0)==3){y=33648;z=A;break}else if((p|0)==0|(p|0)==1){y=33071;z=A;break}else{y=0;z=A;break}}}while(0);fI(3553,10240,z|0);fI(3553,10241,z|0);fI(3553,10242,y|0);fI(3553,10243,y|0);do{if((a[s+(n<<5)|0]&1)==0){o=6294}else{if((a[s+(n<<5)+28|0]&1)==0){o=6294;break}do{if((a[j]&1)==0){u=bd(7939)|0;if((u|0)==0){B=0;break}B=(bJ(u|0,22648)|0)!=0}else{B=0}}while(0);if((a[383584]&1)!=0){u=c[135158]|0;r=(u|0)!=0?u:c[t>>2]|0;u=B?49896:47440;eQ(r|0,52384,(w=i,i=i+16|0,c[w>>2]=22648,c[w+8>>2]=u,w)|0)|0;i=w;u=c[135158]|0;r=(u|0)!=0?u:c[t>>2]|0;a7(r|0)|0}if(!B){r=c[135158]|0;u=(r|0)!=0?r:c[t>>2]|0;be(22392,67,1,u|0)|0;u=c[135158]|0;r=(u|0)!=0?u:c[t>>2]|0;a7(r|0)|0}if((a[383584]&1)!=0){r=c[135158]|0;u=(r|0)!=0?r:c[t>>2]|0;eQ(u|0,22120,(w=i,i=i+8|0,c[w>>2]=n,w)|0)|0;i=w;u=c[135158]|0;r=(u|0)!=0?u:c[t>>2]|0;a7(r|0)|0}eG(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5126,0)}}while(0);if((o|0)==6294){o=0;eG(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5121,0)}n=n+1|0;}while((n|0)<(c[k>>2]|0))}a6(3553,0);a6(3553,0);n=b+612|0;e=n;w=n;ek(c[k>>2]|0,w|0);n=0;while(1){if((n|0)>=(c[k>>2]|0)){o=6300;break}ck(36160,c[e+(n<<2)>>2]|0);dX(36160,36064,3553,c[v+(n<<2)>>2]|0,0);if((cJ(36160)|0)==36053){n=n+1|0}else{o=6299;break}}if((o|0)==6299){cr(c[k>>2]|0,w|0);w=c[135158]|0;n=(w|0)!=0?w:c[t>>2]|0;be(22920,94,1,n|0)|0;n=c[135158]|0;w=(n|0)!=0?n:c[t>>2]|0;a7(w|0)|0;br(c[k>>2]|0,d|0);d=c[135158]|0;k=(d|0)!=0?d:c[t>>2]|0;be(48480,78,1,k|0)|0;k=c[135158]|0;d=(k|0)!=0?k:c[t>>2]|0;a7(d|0)|0;i=f;return}else if((o|0)==6300){a[b+1640|0]=1;i=f;return}}function jn(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+8|0;j=h|0;k=c[a+1832>>2]|0;l=c[a+1836>>2]|0;c[j>>2]=0;er(3379,j|0);m=a+1636|0;if((c[m>>2]|0)<=0){i=h;return}n=a+1124|0;o=a+740|0;p=+(f>>>0>>>0);q=+(e>>>0>>>0);e=b;b=d;d=k;k=l;l=0;f=0;while(1){a=c[n+(f<<5)+4>>2]|0;if((a|0)==0){r=+g[n+(f<<5)+12>>2];c[o+(f*24|0)>>2]=~~(+(e>>>0>>>0)*r);c[o+(f*24|0)+8>>2]=~~(+(d>>>0>>>0)*r)}else if((a|0)==1){s=c[n+(f<<5)+20>>2]|0;c[o+(f*24|0)+8>>2]=s;c[o+(f*24|0)>>2]=s}else if((a|0)==2){a=~~(q*+g[n+(f<<5)+12>>2]);c[o+(f*24|0)+8>>2]=a;c[o+(f*24|0)>>2]=a}a=c[n+(f<<5)+8>>2]|0;if((a|0)==1){s=c[n+(f<<5)+24>>2]|0;c[o+(f*24|0)+12>>2]=s;c[o+(f*24|0)+4>>2]=s}else if((a|0)==2){s=~~(p*+g[n+(f<<5)+16>>2]);c[o+(f*24|0)+12>>2]=s;c[o+(f*24|0)+4>>2]=s}else if((a|0)==0){r=+g[n+(f<<5)+16>>2];c[o+(f*24|0)+4>>2]=~~(+(b>>>0>>>0)*r);c[o+(f*24|0)+12>>2]=~~(+(k>>>0>>>0)*r)}a=o+(f*24|0)|0;s=c[a>>2]|0;u=c[j>>2]|0;if(s>>>0>u>>>0){c[a>>2]=u;v=1;w=u}else{v=l;w=s}s=o+(f*24|0)+4|0;x=c[s>>2]|0;if(x>>>0>u>>>0){c[s>>2]=u;y=1;z=u}else{y=v;z=x}x=o+(f*24|0)+8|0;A=c[x>>2]|0;if(A>>>0>u>>>0){c[x>>2]=u;B=1;C=u}else{B=y;C=A}A=o+(f*24|0)+12|0;D=c[A>>2]|0;if(D>>>0>u>>>0){c[A>>2]=u;E=6326}else{if(B){E=6326}else{F=0;G=w;H=z;I=C;J=D}}if((E|0)==6326){E=0;D=c[135158]|0;K=(D|0)!=0?D:c[t>>2]|0;eQ(K|0,21936,(K=i,i=i+16|0,c[K>>2]=u,c[K+8>>2]=u,K)|0)|0;i=K;K=c[135158]|0;u=(K|0)!=0?K:c[t>>2]|0;a7(u|0)|0;F=1;G=c[a>>2]|0;H=c[s>>2]|0;I=c[x>>2]|0;J=c[A>>2]|0}A=f+1|0;if((A|0)<(c[m>>2]|0)){e=G;b=H;d=I;k=J;l=F;f=A}else{break}}i=h;return}function jo(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+64|0;j=h|0;k=c[(c[b>>2]|0)+24>>2]|0;if((k|0)==0){l=+(d>>>0>>>0)/+(e>>>0>>>0)}else{l=+gb[k&3](d,e)}do{if((a[281285]&1)==0){if((a[b+1714|0]&1)==0){c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=d;c[b+1748>>2]=e;m=d;n=e;o=0;p=0;break}q=+g[119482];do{if((c[70322]|0)==7){k=c[135146]|0;r=c[135145]|0;s=k;t=(c[b+1732>>2]|0)-(c[135144]|0)-k|0;u=c[135143]|0}else{if(+V(+(l-q))<9999999747378752.0e-20){r=d;s=e;t=0;u=0;break}if(l>q){v=(q/l+-1.0)*.5+.5;w=+(d>>>0>>>0);k=~~+bZ(+(w*(.5-v)));r=~~+bZ(+(w*2.0*v));s=e;t=0;u=k;break}else{v=(l/q+-1.0)*.5+.5;w=+(e>>>0>>>0);k=~~+bZ(+(w*(.5-v)));r=d;s=~~+bZ(+(w*2.0*v));t=k;u=0;break}}}while(0);c[b+1736>>2]=u;c[b+1740>>2]=t;c[b+1744>>2]=r;c[b+1748>>2]=s;m=r;n=s;o=u;p=t}else{k=b+1736|0;x=(a[b+1714|0]&1)==0;if((c[70322]|0)==7){y=c[135145]|0;z=c[135146]|0;A=y;B=z;C=d-y|0;D=e-z|0}else{z=c[119473]|0;y=~~+bZ(+(+g[119482]*+(z>>>0>>>0)));do{if(y>>>0>d>>>0|z>>>0>e>>>0){E=0;F=0}else{if(x){E=(d>>>0)%(y>>>0)|0;F=(e>>>0)%(z>>>0)|0;break}else{G=(d>>>0)/(y>>>0)|0;H=(e>>>0)/(z>>>0)|0;I=G>>>0<H>>>0?G:H;H=d-(ag(I,y)|0)|0;E=H;F=e-(ag(I,z)|0)|0;break}}}while(0);A=d-E|0;B=e-F|0;C=E;D=F}c[b+1744>>2]=A;c[b+1748>>2]=B;z=(C|0)/2|0;c[k>>2]=z;y=(D|0)/2|0;c[b+1740>>2]=y;m=A;n=B;o=z;p=y}}while(0);fk(o|0,p|0,m|0,n|0);p=b+1936|0;s_(p|0,0,48);g[b+1996>>2]=1.0;g[p>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;if(f){l=+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0;q=+Y(+l);v=+Z(+l);s_(j|0,0,60);g[j+40>>2]=1.0;g[j+60>>2]=1.0;g[j>>2]=q;g[j+20>>2]=q;g[j+16>>2]=-0.0-v;g[j+4>>2]=v;jT(b+1872|0,j,p);J=b+1760|0;K=J;c[K>>2]=m;L=b+1764|0;M=L;c[M>>2]=n;i=h;return}else{j=b+1872|0;s1(j|0,p|0,64)|0;J=b+1760|0;K=J;c[K>>2]=m;L=b+1764|0;M=L;c[M>>2]=n;i=h;return}}function jp(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+8|0;h=f|0;j=sR(2592)|0;if((j|0)==0){k=0;i=f;return k|0}if((c[j-4>>2]&3|0)!=0){s_(j|0,0,2592)}l=j;m=c[120654]|0;n=c[120655]|0;L8865:do{if((a[281208]|0)==0){do{if((bs(12448)|0)!=0){if(!(j2()|0)){break}o=j;c[o>>2]=8080;p=8080;q=o;break L8865}}while(0);c[j>>2]=0;r=6373}else{o=(da(41096,281208)|0)==0;s=o?8080:0;if(!o){o=c[135158]|0;u=(o|0)!=0?o:c[t>>2]|0;eQ(u|0,23152,(v=i,i=i+8|0,c[v>>2]=281208,v)|0)|0;i=v;u=c[135158]|0;o=(u|0)!=0?u:c[t>>2]|0;a7(o|0)|0;r=6373;break}if(!(f7[c[s+8>>2]&127](1,m,n)|0)){o=c[135158]|0;u=(o|0)!=0?o:c[t>>2]|0;eQ(u|0,23672,(v=i,i=i+16|0,c[v>>2]=23896,c[v+8>>2]=281208,v)|0)|0;i=v;u=c[135158]|0;o=(u|0)!=0?u:c[t>>2]|0;a7(o|0)|0;r=6373;break}if(gm[c[s>>2]&31]()|0){o=j;c[o>>2]=s;p=s;q=o;break}else{o=c[135158]|0;u=(o|0)!=0?o:c[t>>2]|0;o=c[s+68>>2]|0;eQ(u|0,23448,(v=i,i=i+8|0,c[v>>2]=o,v)|0)|0;i=v;o=c[135158]|0;u=(o|0)!=0?o:c[t>>2]|0;a7(u|0)|0;r=6373;break}}}while(0);if((r|0)==6373){sS(j);k=0;i=f;return k|0}n=j+2476|0;m=b;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];c[n+12>>2]=c[m+12>>2];c[n+16>>2]=c[m+16>>2];if((a[383584]&1)==0){w=p}else{m=c[135158]|0;n=(m|0)!=0?m:c[t>>2]|0;m=c[p+68>>2]|0;eQ(n|0,35104,(v=i,i=i+8|0,c[v>>2]=m,v)|0)|0;i=v;m=c[135158]|0;n=(m|0)!=0?m:c[t>>2]|0;a7(n|0)|0;w=c[q>>2]|0}n=j+1720|0;m=j+1724|0;f0[c[w+20>>2]&255](n,m);if((a[383584]&1)!=0){w=c[135158]|0;p=(w|0)!=0?w:c[t>>2]|0;w=c[n>>2]|0;u=c[m>>2]|0;eQ(p|0,33792,(v=i,i=i+16|0,c[v>>2]=w,c[v+8>>2]=u,v)|0)|0;i=v;u=c[135158]|0;w=(u|0)!=0?u:c[t>>2]|0;a7(w|0)|0}w=b+9|0;f$[c[(c[q>>2]|0)+12>>2]&511]((a[w]&1)!=0?c[70317]|0:0);u=c[b>>2]|0;p=c[b+4>>2]|0;o=b+8|0;s=(a[o]&1)!=0;if(s&(u|0)==0&(p|0)==0){x=c[n>>2]|0;y=c[m>>2]|0}else{x=u;y=p}if(!(f7[c[(c[q>>2]|0)+16>>2]&127](x,y,s)|0)){sS(j);k=0;i=f;return k|0}ea()|0;s=bd(7936)|0;y=bd(7937)|0;if((a[383584]&1)!=0){x=c[135158]|0;p=(x|0)!=0?x:c[t>>2]|0;eQ(p|0,32744,(v=i,i=i+16|0,c[v>>2]=s,c[v+8>>2]=y,v)|0)|0;i=v;y=c[135158]|0;s=(y|0)!=0?y:c[t>>2]|0;a7(s|0)|0}s=bd(7938)|0;if((a[383584]&1)!=0){y=c[135158]|0;p=(y|0)!=0?y:c[t>>2]|0;eQ(p|0,32176,(v=i,i=i+8|0,c[v>>2]=s,v)|0)|0;i=v;s=c[135158]|0;p=(s|0)!=0?s:c[t>>2]|0;a7(p|0)|0}p=c[(c[q>>2]|0)+52>>2]|0;s=1616;y=40592;do{x=f2[p&255](y)|0;u=c[s+4>>2]|0;C=x;a[u]=C&255;C=C>>8;a[u+1|0]=C&255;C=C>>8;a[u+2|0]=C&255;C=C>>8;a[u+3|0]=C&255;s=s+8|0;y=c[s>>2]|0;}while((y|0)!=0);fe(770,771);a[547628]=0;y=j+2584|0;do{if((a[y]&1)==0){s=bd(7939)|0;if((s|0)==0){z=0;break}z=(bJ(s|0,25728)|0)!=0}else{z=0}}while(0);if((a[383584]&1)!=0){s=c[135158]|0;p=(s|0)!=0?s:c[t>>2]|0;s=z?49896:47440;eQ(p|0,52384,(v=i,i=i+16|0,c[v>>2]=25728,c[v+8>>2]=s,v)|0)|0;i=v;s=c[135158]|0;p=(s|0)!=0?s:c[t>>2]|0;a7(p|0)|0}do{if(z){if((a[383584]&1)==0){break}p=c[135158]|0;s=(p|0)!=0?p:c[t>>2]|0;be(25280,52,1,s|0)|0;s=c[135158]|0;p=(s|0)!=0?s:c[t>>2]|0;a7(p|0)|0}else{a[547628]=1;p=c[135158]|0;s=(p|0)!=0?p:c[t>>2]|0;be(24624,117,1,s|0)|0;s=c[135158]|0;p=(s|0)!=0?s:c[t>>2]|0;a7(p|0)|0}}while(0);a[j+8|0]=a[w]&1;a[j+1713|0]=a[o]&1;o=j+1728|0;w=j+1732|0;f0[c[(c[q>>2]|0)+20>>2]&255](o,w);if((a[383584]&1)!=0){z=c[135158]|0;p=(z|0)!=0?z:c[t>>2]|0;z=c[o>>2]|0;s=c[w>>2]|0;eQ(p|0,31408,(v=i,i=i+16|0,c[v>>2]=z,c[v+8>>2]=s,v)|0)|0;i=v;s=c[135158]|0;z=(s|0)!=0?s:c[t>>2]|0;a7(z|0)|0}if((c[n>>2]|0)==0){if((c[m>>2]|0)!=0){r=6401}}else{r=6401}if((r|0)==6401){c[n>>2]=c[o>>2];c[m>>2]=c[w>>2]}m=j+2016|0;c[m>>2]=(a[482614]&1)!=0?168:136;n=j+48|0;c[n>>2]=4;z=(c[120649]|0)==2;s=j+1710|0;a[s]=z&1;if(z){c[n>>2]=1}z=j+2020|0;c[z>>2]=8;c[68260]=c[(c[q>>2]|0)+52>>2];p=c[120654]|0;u=c[120655]|0;a[273048]=a[y]&1;c[68258]=p;c[68256]=u;if((a[285388]&1)==0){A=0}else{A=(a[281292]|0)!=0?281292:0}u=iX(A,2)|0;do{if((u|0)==3){if((a[383584]&1)==0){break}p=c[135158]|0;y=(p|0)!=0?p:c[t>>2]|0;be(27616,41,1,y|0)|0;y=c[135158]|0;p=(y|0)!=0?y:c[t>>2]|0;a7(p|0)|0}else if((u|0)==2){if((a[383584]&1)!=0){p=c[135158]|0;y=(p|0)!=0?p:c[t>>2]|0;be(27256,44,1,y|0)|0;y=c[135158]|0;p=(y|0)!=0?y:c[t>>2]|0;a7(p|0)|0}p=j+4|0;c[p>>2]=7968;if(kb(A)|0){break}y=c[135158]|0;be(26096,73,1,((y|0)!=0?y:c[t>>2]|0)|0)|0;y=c[135158]|0;a7(((y|0)!=0?y:c[t>>2]|0)|0)|0;if(f2[c[c[p>>2]>>2]&255](0)|0){break}p=c[135158]|0;be(30744,47,1,((p|0)!=0?p:c[t>>2]|0)|0)|0;p=c[135158]|0;a7(((p|0)!=0?p:c[t>>2]|0)|0)|0;gp[c[(c[q>>2]|0)+4>>2]&63]();sS(j);k=0;i=f;return k|0}else{p=c[135158]|0;be(26800,89,1,((p|0)!=0?p:c[t>>2]|0)|0)|0;p=c[135158]|0;a7(((p|0)!=0?p:c[t>>2]|0)|0)|0}}while(0);A=j+4|0;u=c[A>>2]|0;if((u|0)!=0){p=(gm[c[u+40>>2]&31]()|0)+1|0;u=c[n>>2]|0;c[n>>2]=p>>>0>u>>>0?p:u}u=a[383584]|0;if((u&1)==0){B=u}else{u=c[135158]|0;p=(u|0)!=0?u:c[t>>2]|0;u=c[n>>2]|0;eQ(p|0,21064,(v=i,i=i+8|0,c[v>>2]=u,v)|0)|0;i=v;u=c[135158]|0;p=(u|0)!=0?u:c[t>>2]|0;a7(p|0)|0;B=a[383584]|0}if((B&1)!=0){B=c[135158]|0;p=(B|0)!=0?B:c[t>>2]|0;B=c[A>>2]|0;if((B|0)==0){D=0}else{D=gm[c[B+16>>2]&31]()|0}eQ(p|0,30344,(v=i,i=i+8|0,c[v>>2]=D,v)|0)|0;i=v;v=c[135158]|0;D=(v|0)!=0?v:c[t>>2]|0;a7(D|0)|0}D=c[b+12>>2]<<8;v=j+1832|0;c[v>>2]=D;p=j+1836|0;c[p>>2]=D;a[j+1714|0]=a[b+10|0]&1;D=c[A>>2]|0;if((D|0)!=0){f$[c[D+12>>2]&511](0)}jo(j,c[o>>2]|0,c[w>>2]|0,1);D=c[A>>2]|0;if((D|0)!=0){f$[c[D+12>>2]&511](1)}jo(j,c[o>>2]|0,c[w>>2]|0,1);a[h]=0;w=c[A>>2]|0;do{if((w|0)==0){r=6430}else{if(!(gj[c[w+20>>2]&127](1,h)|0)){r=6430;break}c[j+468>>2]=(a[h]&1)!=0?9729:9728}}while(0);if((r|0)==6430){c[j+468>>2]=(a[b+11|0]&1)!=0?9729:9728}r=c[A>>2]|0;do{if((r|0)==0){E=33071}else{A=f2[c[r+24>>2]&255](1)|0;if((A|0)==2){E=10497;break}else if((A|0)==0|(A|0)==1){E=33071;break}else if((A|0)==3){E=33648;break}else{E=0;break}}}while(0);c[j+2040>>2]=E;E=(a[b+16|0]&1)!=0;r=E?32993:6407;A=j+2028|0;c[A>>2]=r;h=j+2032|0;c[h>>2]=r;c[j+2036>>2]=E?5121:33635;c[j+2044>>2]=E?4:2;if(!((a[547628]&1)==0|E^1)){c[A>>2]=6408;c[h>>2]=6408}dG(2929);dG(2884);dG(3024);h=j+1840|0;s1(h|0,808,32)|0;c[j+2e3>>2]=c[m>>2];c[j+2008>>2]=h;c[j+2004>>2]=c[z>>2];c[j+2012>>2]=808;z=ag(c[p>>2]|0,c[v>>2]|0)|0;h=z<<2;m=z>>>0>65535;if(m){F=(z&1073741823|0)==(z|0)?h:-1}else{F=h}A=sR(F)|0;do{if((A|0)!=0){if((c[A-4>>2]&3|0)==0){break}s_(A|0,0,F|0)}}while(0);c[j+472>>2]=A;if(m){G=(z&1073741823|0)==(z|0)?h:-1}else{G=h}h=sR(G)|0;if((h|0)==0){c[j+476>>2]=0;gp[c[(c[q>>2]|0)+4>>2]&63]();sS(j);k=0;i=f;return k|0}if((c[h-4>>2]&3|0)!=0){s_(h|0,0,G|0)}c[j+476>>2]=h;jR(j,b);do{if((c[n>>2]|0)!=0){b=j+1768|0;h=j+1800|0;G=0;do{c[b+(G<<2)>>2]=c[v>>2];c[h+(G<<2)>>2]=c[p>>2];G=G+1|0;H=c[n>>2]|0;}while(G>>>0<H>>>0);if((H|0)==0){break}G=j+12|0;h=j+52|0;b=0;do{c[h+(b*52|0)>>2]=c[G>>2];g[h+(b*52|0)+4>>2]=+((c[v>>2]|0)>>>0>>>0);g[h+(b*52|0)+12>>2]=+((c[v>>2]|0)>>>0>>>0);g[h+(b*52|0)+8>>2]=+((c[p>>2]|0)>>>0>>>0);g[h+(b*52|0)+16>>2]=+((c[p>>2]|0)>>>0>>>0);z=h+(b*52|0)+20|0;s1(z|0,808,32)|0;b=b+1|0;}while(b>>>0<(c[n>>2]|0)>>>0)}}while(0);jm(j,c[v>>2]|0,c[p>>2]|0);do{if((a[s]&1)!=0){if(jS(l,c[v>>2]|0,c[p>>2]|0)|0){break}gp[c[(c[q>>2]|0)+4>>2]&63]();sS(j);k=0;i=f;return k|0}}while(0);if(!((d|0)==0|(e|0)==0)){f0[c[(c[q>>2]|0)+48>>2]&255](d,e)}if((a[297692]&1)!=0){c[j+2052>>2]=jV(j,293589,+g[74422])|0?7888:0}switch(ea()|0){case 1280:{e=c[135158]|0;be(29928,39,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[135158]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;break};case 1281:{e=c[135158]|0;be(29616,40,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[135158]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;break};case 1282:{e=c[135158]|0;be(29136,44,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[135158]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;break};case 1285:{e=c[135158]|0;be(28424,40,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[135158]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0;break};case 0:{k=j;i=f;return k|0};default:{e=c[135158]|0;be(27968,45,1,((e|0)!=0?e:c[t>>2]|0)|0)|0;e=c[135158]|0;a7(((e|0)!=0?e:c[t>>2]|0)|0)|0}}gp[c[(c[q>>2]|0)+4>>2]&63]();sS(j);k=0;i=f;return k|0}function jq(b,d,e,f,h,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ab=0,ac=0.0,ad=0,ae=0.0,af=0.0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0;k=i;i=i+992|0;l=k|0;m=k+64|0;n=k+96|0;o=k+928|0;p=k+936|0;q=b+4|0;r=c[q>>2]|0;if((r|0)!=0){f$[c[r+12>>2]&511](1)}r=b+1640|0;if((a[r]&1)!=0){jn(b,e,f,c[b+1760>>2]|0,c[b+1764>>2]|0);a6(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);ck(36160,c[b+612>>2]|0);s=c[b+740>>2]|0;u=c[b+744>>2]|0;v=c[(c[b>>2]|0)+24>>2]|0;if((v|0)!=0){+gb[v&3](s,u)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=s;c[b+1748>>2]=u;fk(0,0,s|0,u|0);u=b+1936|0;s_(u|0,0,48);g[b+1996>>2]=1.0;g[u>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;s=b+1872|0;s1(s|0,u|0,64)|0;c[b+2e3>>2]=168}u=b+1711|0;do{if((a[u]&1)!=0){a[u]=0;s=b;v=b+1728|0;w=b+1732|0;f0[c[(c[s>>2]|0)+36>>2]&255](c[v>>2]|0,c[w>>2]|0);if((a[r]&1)==0){jo(b,c[v>>2]|0,c[w>>2]|0,1);break}w=b+1636|0;if((c[w>>2]|0)>0){v=b+740|0;x=v;y=b+612|0;z=y;A=b+676|0;B=0;while(1){C=c[x+(B*24|0)+8>>2]|0;D=x+(B*24|0)+16|0;E=c[x+(B*24|0)+12>>2]|0;F=x+(B*24|0)+20|0;if(C>>>0>(c[D>>2]|0)>>>0){G=6492}else{if(E>>>0>(c[F>>2]|0)>>>0){G=6492}}do{if((G|0)==6492){G=0;H=(C>>>0>E>>>0?C:E)-1|0;I=H>>>1|H;H=I>>>2|I;I=H>>>4|H;H=I>>>8|I;I=(H>>>16|H)+1|0;c[F>>2]=I;c[D>>2]=I;ck(36160,c[z+(B<<2)>>2]|0);I=A+(B<<2)|0;a6(3553,c[I>>2]|0);eG(3553,0,32993,c[D>>2]|0,c[F>>2]|0,0,32993,5121,0);dX(36160,36064,3553,c[I>>2]|0,0);if((cJ(36160)|0)!=36053){I=c[135158]|0;H=(I|0)!=0?I:c[t>>2]|0;be(38288,50,1,H|0)|0;H=c[135158]|0;I=(H|0)!=0?H:c[t>>2]|0;a7(I|0)|0}if((a[383584]&1)==0){break}I=c[135158]|0;H=(I|0)!=0?I:c[t>>2]|0;I=c[D>>2]|0;J=c[F>>2]|0;eQ(H|0,37064,(H=i,i=i+24|0,c[H>>2]=B,c[H+8>>2]=I,c[H+16>>2]=J,H)|0)|0;i=H;H=c[135158]|0;J=(H|0)!=0?H:c[t>>2]|0;a7(J|0)|0}}while(0);F=B+1|0;if((F|0)<(c[w>>2]|0)){B=F}else{K=y;L=v;break}}}else{K=b+612|0;L=b+740|0}a6(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);ck(36160,c[K>>2]|0);v=c[L>>2]|0;y=c[b+744>>2]|0;B=c[(c[s>>2]|0)+24>>2]|0;if((B|0)!=0){+gb[B&3](v,y)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=v;c[b+1748>>2]=y;fk(0,0,v|0,y|0);y=b+1936|0;s_(y|0,0,48);g[b+1996>>2]=1.0;g[y>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;v=b+1872|0;s1(v|0,y|0,64)|0;c[b+2e3>>2]=168}}while(0);L=b+44|0;K=c[L>>2]|0;L9059:do{if((d|0)==0){a6(3553,c[b+12+(K<<2)>>2]|0);M=b+1708|0}else{u=b+48|0;y=((K+1|0)>>>0)%((c[u>>2]|0)>>>0)|0;c[L>>2]=y;a6(3553,c[b+12+(y<<2)>>2]|0);y=b+1708|0;if((a[y]&1)!=0){M=y;break}v=c[L>>2]|0;B=b+1768|0;w=B+(v<<2)|0;if((c[w>>2]|0)==(e|0)){if((c[b+1800+(v<<2)>>2]|0)==(f|0)){G=6506}else{G=6504}}else{G=6504}do{if((G|0)==6504){A=b+472|0;if((c[A>>2]|0)==0){G=6506;break}c[w>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;fS(3317,(e<<2&4^4)+4|0);z=b+1832|0;x=b+1836|0;eI(3553,0,0,0,c[z>>2]|0,c[x>>2]|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[A>>2]|0);N=+(e>>>0>>>0)/+((c[z>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[x>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==6506){w=c[u>>2]|0;s=((v-1+w|0)>>>0)%(w>>>0)|0;if((c[B+(s<<2)>>2]|0)==(e|0)){if((c[b+1800+(s<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[b+2472|0]&1)!=0){c[o>>2]=0;B=fY[c[(c[b>>2]|0)+60>>2]&3](d,e,f,h,(c[b+2044>>2]|0)==4,c[L>>2]|0,o)|0;v=c[o>>2]|0;if((v|0)==0){u=c[135158]|0;s=(u|0)!=0?u:c[t>>2]|0;be(39272,55,1,s|0)|0;s=c[135158]|0;u=(s|0)!=0?s:c[t>>2]|0;a7(u|0)|0;M=y;break}if(!B){M=y;break}f0[c[137124]&255](3553,v);M=y;break}v=b+2044|0;B=ag(c[v>>2]|0,e)|0;do{if((B&1|0)==0){if((B&2|0)!=0){P=2;break}P=(B&4^4)+4|0}else{P=1}}while(0);fS(3317,P|0);B=c[v>>2]|0;do{if((B|0)==4){if((a[547628]&1)==0){break}u=b+476|0;s=c[u>>2]|0;w=b+480|0;x=w;z=w;w=b+484|0;if((c[z>>2]|0)==(e|0)){if((c[w>>2]|0)!=(f|0)){G=6521}}else{G=6521}if((G|0)==6521){c[z>>2]=e;c[w>>2]=f;c[b+492>>2]=e;c[b+496>>2]=f;c[b+504>>2]=0;c[b+508>>2]=1;c[b+512>>2]=1;iD(x)|0}c[b+488>>2]=h;c[b+500>>2]=e<<2;iP(x,s,d);eI(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y;break L9059}}while(0);if(((h>>>0)/(B>>>0)|0|0)==(e|0)){eI(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,d|0);M=y;break}v=ag(B,e)|0;u=b+476|0;if((f|0)!=0){s=c[u>>2]|0;x=d;w=0;while(1){s1(s|0,x|0,v)|0;z=w+1|0;if(z>>>0<f>>>0){s=s+v|0;x=x+h|0;w=z}else{break}}}eI(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y}}while(0);if((a[M]&1)!=0){h=c[L>>2]|0;d=b+1768|0;P=d+(h<<2)|0;if((c[P>>2]|0)==(e|0)){if((c[b+1800+(h<<2)>>2]|0)==(f|0)){G=6535}else{G=6533}}else{G=6533}do{if((G|0)==6533){if((c[b+472>>2]|0)==0){G=6535;break}c[P>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;N=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==6535){P=c[b+48>>2]|0;o=((h-1+P|0)>>>0)%(P>>>0)|0;if((c[d+(o<<2)>>2]|0)==(e|0)){if((c[b+1800+(o<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[r]&1)==0){ck(36160,0);jo(b,c[b+1728>>2]|0,c[b+1732>>2]|0,1)}dG(2929);dG(2960);dG(2884);dG(3024);dG(3042);fe(770,771);aW(0.0,0.0,0.0,1.0)}d=p;s_(d|0,0,52);c[p>>2]=c[b+12+(c[L>>2]<<2)>>2];g[p+4>>2]=+(e>>>0>>>0);g[p+8>>2]=+(f>>>0>>>0);L=b+1832|0;g[p+12>>2]=+((c[L>>2]|0)>>>0>>>0);h=b+1836|0;g[p+16>>2]=+((c[h>>2]|0)>>>0>>>0);G=p+20|0;o=b+1840|0;s1(G|0,o|0,32)|0;dK(16384);if((a[281266]&1)!=0){gp[c[(c[b>>2]|0)+44>>2]&63]();dK(16384)}G=c[q>>2]|0;do{if((G|0)==0){P=b+2e3|0;K=b+1872|0;Q=P;R=P;S=K;T=K}else{f3[c[G+8>>2]&3](e,f,c[L>>2]|0,c[h>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[135098]|0,p,b+52|0,0,0);K=c[q>>2]|0;P=b+2e3|0;w=P;x=b+1872|0;v=x;if((K|0)==0){Q=P;R=w;S=x;T=v;break}s=c[K+32>>2]|0;f2[s&255](w)|0;s=c[q>>2]|0;if((s|0)==0){Q=P;R=w;S=x;T=v;break}K=c[s+36>>2]|0;f2[K&255](v)|0;Q=P;R=w;S=x;T=v}}while(0);dB(5,0,4);if((a[r]&1)!=0){r=m;s_(r|0,0,32);h=b+2008|0;c[h>>2]=m;L=b+1636|0;f=c[L>>2]|0;e=b+740|0;G=m+8|0;v=m+24|0;x=m+20|0;w=m+28|0;if((f|0)>1){m=b+676|0;P=b+612|0;K=b;s=b+1740|0;B=b+1736|0;z=b+1744|0;A=b+1748|0;F=b+1936|0;D=b+52|0;E=n|0;C=F;J=b+1956|0;H=b+1976|0;I=b+1996|0;U=b+1984|0;V=b+1988|0;W=b+1992|0;X=1;Y=0;while(1){Z=X-1|0;_=e+(Z*24|0)|0;N=+((c[_>>2]|0)>>>0>>>0);$=e+(Z*24|0)+16|0;O=+((c[$>>2]|0)>>>0>>>0);aa=N/O;ab=e+(Z*24|0)+4|0;ac=+((c[ab>>2]|0)>>>0>>>0);ad=e+(Z*24|0)+20|0;ae=+((c[ad>>2]|0)>>>0>>>0);af=ac/ae;g[G>>2]=aa;g[v>>2]=aa;g[x>>2]=af;g[w>>2]=af;ah=m+(Z<<2)|0;c[n+(Z*52|0)>>2]=c[ah>>2];g[n+(Z*52|0)+4>>2]=N;g[n+(Z*52|0)+8>>2]=ac;g[n+(Z*52|0)+12>>2]=O;g[n+(Z*52|0)+16>>2]=ae;ai=n+(Z*52|0)+20|0;s1(ai|0,r|0,32)|0;ck(36160,c[P+(X<<2)>>2]|0);ai=c[q>>2]|0;if((ai|0)!=0){f$[c[ai+12>>2]&511](X+1|0)}a6(3553,c[ah>>2]|0);dK(16384);ah=c[e+(X*24|0)>>2]|0;ai=c[e+(X*24|0)+4>>2]|0;Z=c[(c[K>>2]|0)+24>>2]|0;if((Z|0)!=0){+gb[Z&3](ah,ai)}c[s>>2]=0;c[B>>2]=0;c[z>>2]=ah;c[A>>2]=ai;fk(0,0,ah|0,ai|0);s_(F|0,0,48);g[I>>2]=1.0;g[C>>2]=2.0;g[J>>2]=2.0;g[H>>2]=-1.0;g[U>>2]=-1.0;g[V>>2]=-1.0;g[W>>2]=-0.0;s1(S|0,F|0,64)|0;ai=c[q>>2]|0;do{if((ai|0)!=0){f3[c[ai+8>>2]&3](c[_>>2]|0,c[ab>>2]|0,c[$>>2]|0,c[ad>>2]|0,c[z>>2]|0,c[A>>2]|0,c[135098]|0,p,D,E,Y);ah=c[q>>2]|0;if((ah|0)==0){break}Z=c[ah+32>>2]|0;f2[Z&255](R)|0;Z=c[q>>2]|0;if((Z|0)==0){break}ah=c[Z+36>>2]|0;f2[ah&255](T)|0}}while(0);dB(5,0,4);ad=Y+1|0;$=X+1|0;ab=c[L>>2]|0;if(($|0)<(ab|0)){X=$;Y=ad}else{aj=ad;ak=ab;break}}}else{aj=0;ak=f}f=ak-1|0;ak=e+(f*24|0)|0;Y=e+(f*24|0)+16|0;ae=+((c[ak>>2]|0)>>>0>>>0)/+((c[Y>>2]|0)>>>0>>>0);X=e+(f*24|0)+4|0;E=e+(f*24|0)+20|0;O=+((c[X>>2]|0)>>>0>>>0)/+((c[E>>2]|0)>>>0>>>0);g[G>>2]=ae;g[v>>2]=ae;g[x>>2]=O;g[w>>2]=O;ck(36160,0);w=c[q>>2]|0;if((w|0)!=0){f$[c[w+12>>2]&511]((c[L>>2]|0)+1|0)}a6(3553,c[b+676+((c[L>>2]|0)-1<<2)>>2]|0);dK(16384);jo(b,c[b+1728>>2]|0,c[b+1732>>2]|0,1);L=c[q>>2]|0;do{if((L|0)==0){c[Q>>2]=c[b+2016>>2]}else{f3[c[L+8>>2]&3](c[ak>>2]|0,c[X>>2]|0,c[Y>>2]|0,c[E>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[135098]|0,p,b+52|0,n|0,aj);w=c[q>>2]|0;c[Q>>2]=c[b+2016>>2];if((w|0)==0){break}x=c[w+32>>2]|0;f2[x&255](R)|0;x=c[q>>2]|0;if((x|0)==0){break}w=c[x+36>>2]|0;f2[w&255](T)|0}}while(0);dB(5,0,4);c[h>>2]=o}h=b+52|0;s5(b+104|0,h|0,((c[b+48>>2]|0)*52|0)-52|0);s1(h|0,d|0,52)|0;do{if((a[b+2576|0]&1)!=0){d=c[b+2572>>2]|0;if((d|0)==0){break}h=l|0;g[h>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2580>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;T=Q;c[T>>2]=136;aj=b+2008|0;c[aj>>2]=808;n=b+2004|0;c[n>>2]=h;a6(3553,d|0);d=c[q>>2]|0;do{if((d|0)!=0){f$[c[d+12>>2]&511](15);h=c[q>>2]|0;p=b+1936|0;if((h|0)==0){break}E=c[h+32>>2]|0;f2[E&255](R)|0;E=c[q>>2]|0;if((E|0)==0){break}h=c[E+36>>2]|0;f2[h&255](p)|0}}while(0);e$(3042);if((a[b+2577|0]&1)==0){dB(5,0,4)}else{fk(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);dB(5,0,4);fk(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}dG(3042);c[T>>2]=c[b+2016>>2];c[aj>>2]=o;c[n>>2]=c[b+2020>>2]}}while(0);do{if((j|0)!=0){d=c[b+2052>>2]|0;if((d|0)==0){break}go[c[d+8>>2]&127](b,j,0)}}while(0);if((a[b+2496|0]&1)!=0){a6(3553,c[b+2500>>2]|0);j=l|0;g[j>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2568>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;l=c[q>>2]|0;if((l|0)!=0){f$[c[l+12>>2]&511](15)}e$(3042);l=Q;c[l>>2]=b+2536;Q=b+2008|0;c[Q>>2]=b+2504;d=b+2004|0;c[d>>2]=j;j=b+1936|0;p=c[q>>2]|0;do{if((p|0)!=0){h=c[p+32>>2]|0;f2[h&255](R)|0;h=c[q>>2]|0;if((h|0)==0){break}E=c[h+36>>2]|0;f2[E&255](j)|0}}while(0);if((a[b+2497|0]&1)==0){dB(5,0,4)}else{fk(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);dB(5,0,4);fk(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}dG(3042);c[l>>2]=c[b+2016>>2];c[Q>>2]=o;c[d>>2]=c[b+2020>>2]}d=b;gp[c[(c[d>>2]|0)+28>>2]&63]();if((a[M]&1)==0){al=c[d>>2]|0;am=al+44|0;an=c[am>>2]|0;gp[an&63]();ao=c[135098]|0;ap=ao+1|0;c[135098]=ap;i=k;return 1}M=c[q>>2]|0;if((M|0)!=0){f$[c[M+12>>2]&511](0)}a6(3553,0);al=c[d>>2]|0;am=al+44|0;an=c[am>>2]|0;gp[an&63]();ao=c[135098]|0;ap=ao+1|0;c[135098]=ap;i=k;return 1}function jr(a,b){a=a|0;b=b|0;c[b>>2]=7944;return}function js(a,b){a=a|0;b=b|0;c[b>>2]=7904;return}function jt(a){a=a|0;return c[a+1644+(((((c[a+44>>2]|0)+1|0)>>>0)%((c[a+48>>2]|0)>>>0)|0)<<2)>>2]|0}function ju(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;if((a[383584]&1)!=0){f=c[135158]|0;g=(f|0)!=0?f:c[t>>2]|0;f=d?41184:40208;eQ(g|0,42176,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;g=c[135158]|0;f=(g|0)!=0?g:c[t>>2]|0;a7(f|0)|0}f$[c[(c[b>>2]|0)+12>>2]&511](d?0:c[70317]|0);i=e;return}function jv(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;f=d+8|0;f_[c[(c[b>>2]|0)+32>>2]&15](e,f,b+1728|0,b+1732|0,c[135098]|0);do{if((a[e]&1)==0){if((a[f]&1)==0){break}a[b+1711|0]=1}else{a[b+1712|0]=1}}while(0);i=d;return(a[b+1712|0]&1)==0|0}function jw(a){a=a|0;return gm[c[(c[a>>2]|0)+40>>2]&31]()|0}function jx(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0;f=i;i=i+8|0;h=f|0;j=b;if((d|0)==3){k=0;i=f;return k|0}l=b+4|0;m=c[l>>2]|0;if((m|0)!=0){gp[c[m+4>>2]&63]()}m=(d|0)==2;c[l>>2]=m?7968:0;if(!m){m=c[135158]|0;d=(m|0)!=0?m:c[t>>2]|0;eQ(d|0,28768,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;d=c[135158]|0;m=(d|0)!=0?d:c[t>>2]|0;a7(m|0)|0;k=0;i=f;return k|0}m=b+1640|0;if((a[m]&1)!=0){d=b+1636|0;br(c[d>>2]|0,b+676|0);o=b+612|0;cr(c[d>>2]|0,o|0);a[m]=0;c[d>>2]=0;s_(o|0,0,128)}o=b+44|0;d=b+12|0;a6(3553,c[d+(c[o>>2]<<2)>>2]|0);if(!(f2[c[c[l>>2]>>2]&255](e)|0)){e=c[135158]|0;m=(e|0)!=0?e:c[t>>2]|0;be(24288,81,1,m|0)|0;m=c[135158]|0;e=(m|0)!=0?m:c[t>>2]|0;a7(e|0)|0;if(f2[c[c[l>>2]>>2]&255](0)|0){k=0;i=f;return k|0}c[l>>2]=0;k=0;i=f;return k|0}a[h]=0;e=c[l>>2]|0;if((e|0)==0){p=6622}else{if(!(gj[c[e+20>>2]&127](1,h)|0)){p=6622}}if((p|0)==6622){a[h]=a[281276]&1}e=c[l>>2]|0;do{if((e|0)==0){q=33071}else{m=f2[c[e+24>>2]&255](1)|0;if((m|0)==2){q=10497;break}else if((m|0)==0|(m|0)==1){q=33071;break}else if((m|0)==3){q=33648;break}else{q=0;break}}}while(0);e=a[h]&1;a[b+2487|0]=e;h=e<<24>>24!=0?9729:9728;e=b+468|0;m=b+2040|0;if((h|0)==(c[e>>2]|0)){if((q|0)!=(c[m>>2]|0)){p=6630}}else{p=6630}if((p|0)==6630){c[e>>2]=h;c[m>>2]=q;q=b+48|0;h=c[q>>2]|0;if((h|0)!=0){p=0;r=h;while(1){h=c[j+12+(p<<2)>>2]|0;if((h|0)==0){s=r}else{a6(3553,h|0);fI(3553,10242,c[m>>2]|0);fI(3553,10243,c[m>>2]|0);fI(3553,10240,c[e>>2]|0);fI(3553,10241,c[e>>2]|0);s=c[q>>2]|0}h=p+1|0;if(h>>>0<s>>>0){p=h;r=s}else{break}}}a6(3553,c[j+12+(c[o>>2]<<2)>>2]|0)}s=c[l>>2]|0;do{if((s|0)!=0){r=(gm[c[s+40>>2]&31]()|0)+1|0;p=b+48|0;q=c[p>>2]|0;if(r>>>0<=q>>>0){break}e=b+1708|0;if((a[e]&1)!=0){cr(q|0,b+1644|0)}if((a[b+1709|0]&1)!=0){b3(c[p>>2]|0,b+1676|0)}a[e]=0;e=d;br(c[p>>2]|0,e|0);c[p>>2]=r;if((a[383584]&1)!=0){q=c[135158]|0;m=(q|0)!=0?q:c[t>>2]|0;eQ(m|0,21064,(n=i,i=i+8|0,c[n>>2]=r,n)|0)|0;i=n;r=c[135158]|0;m=(r|0)!=0?r:c[t>>2]|0;a7(m|0)|0}c[o>>2]=0;jR(b,b+2476|0);do{if((c[p>>2]|0)!=0){m=b+1832|0;r=b+1768|0;q=b+1836|0;h=b+1800|0;u=0;do{c[r+(u<<2)>>2]=c[m>>2];c[h+(u<<2)>>2]=c[q>>2];u=u+1|0;v=c[p>>2]|0;}while(u>>>0<v>>>0);if((v|0)==0){break}u=b+52|0;h=0;do{c[u+(h*52|0)>>2]=c[e>>2];g[u+(h*52|0)+4>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+12>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+8>>2]=+((c[q>>2]|0)>>>0>>>0);g[u+(h*52|0)+16>>2]=+((c[q>>2]|0)>>>0>>>0);r=u+(h*52|0)+20|0;s1(r|0,808,32)|0;h=h+1|0;}while(h>>>0<(c[p>>2]|0)>>>0)}}while(0);if((a[b+1710|0]&1)==0){break}p=c[b+1832>>2]|0;e=c[b+1836>>2]|0;jS(j,p,e)|0}}while(0);jm(b,c[b+1832>>2]|0,c[b+1836>>2]|0);j=c[l>>2]|0;if((j|0)!=0){f$[c[j+12>>2]&511](0)}j=b+1728|0;v=b+1732|0;jo(b,c[j>>2]|0,c[v>>2]|0,1);o=c[l>>2]|0;if((o|0)!=0){f$[c[o+12>>2]&511](1)}jo(b,c[j>>2]|0,c[v>>2]|0,1);k=1;i=f;return k|0}function jy(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[b+2052>>2]|0;if((d|0)!=0){f$[c[d+4>>2]&511](b)}d=b+4|0;e=c[d>>2]|0;if((e|0)!=0){gp[c[e+4>>2]&63]()}c[d>>2]=0;d=b+48|0;br(c[d>>2]|0,b+12|0);e=b+2572|0;if((c[e>>2]|0)!=0){br(1,e|0)}e=b+2500|0;if((c[e>>2]|0)!=0){br(1,e|0)}e=b+544|0;sS(c[e>>2]|0);sS(c[b+556>>2]|0);sS(c[b+560>>2]|0);sS(c[b+572>>2]|0);sS(c[b+584>>2]|0);sS(c[b+576>>2]|0);sS(c[b+600>>2]|0);s_(e|0,0,64);e=b+1640|0;if((a[e]&1)!=0){f=b+1636|0;br(c[f>>2]|0,b+676|0);g=b+612|0;cr(c[f>>2]|0,g|0);a[e]=0;c[f>>2]=0;s_(g|0,0,128)}g=b+1708|0;if((a[g]&1)!=0){cr(c[d>>2]|0,b+1644|0)}if((a[b+1709|0]&1)==0){a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;gp[k&63]();l=b+472|0;m=l;n=c[m>>2]|0;sS(n);o=b+476|0;p=o;q=c[p>>2]|0;sS(q);sS(b);return}b3(c[d>>2]|0,b+1676|0);a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;gp[k&63]();l=b+472|0;m=l;n=c[m>>2]|0;sS(n);o=b+476|0;p=o;q=c[p>>2]|0;sS(q);sS(b);return}function jz(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=d;c[e>>2]=c[1966];c[e+4>>2]=c[1967];c[e+8>>2]=c[1968];c[e+12>>2]=c[1969];c[e+16>>2]=c[1970];a[d+9|0]=a[281264]&1;a[d+10|0]=0;a[d+11|0]=a[281276]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[70322]|0)==7){c[d>>2]=c[135145];c[d+4>>2]=c[135146]}e=jp(d,0,0)|0;c[136866]=e;c[136914]=7904;c[e+2052>>2]=jV(e,293589,+g[74422])|0?7888:0;i=b;return}function jA(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=c[136866]|0;if((e|0)==0){i=b;return}c[136866]=0;jy(e);e=d;c[e>>2]=c[1966];c[e+4>>2]=c[1967];c[e+8>>2]=c[1968];c[e+12>>2]=c[1969];c[e+16>>2]=c[1970];a[d+9|0]=a[281264]&1;a[d+10|0]=0;a[d+11|0]=a[281276]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[70322]|0)==7){c[d>>2]=c[135145];c[d+4>>2]=c[135146]}e=jp(d,0,0)|0;c[136866]=e;c[136914]=7904;c[e+2052>>2]=jV(e,293589,+g[74422])|0?7888:0;i=b;return}function jB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0.0,j=0.0,k=0.0;d=i;i=i+64|0;e=d|0;f=b*90|0;c[a+1716>>2]=f;b=a+1936|0;s_(b|0,0,48);g[a+1996>>2]=1.0;g[b>>2]=2.0;g[a+1956>>2]=2.0;g[a+1976>>2]=-1.0;g[a+1984>>2]=-1.0;g[a+1988>>2]=-1.0;g[a+1992>>2]=-0.0;h=+(f>>>0>>>0)*3.141592653589793/180.0;j=+Y(+h);k=+Z(+h);s_(e|0,0,60);g[e+40>>2]=1.0;g[e+60>>2]=1.0;g[e>>2]=j;g[e+20>>2]=j;g[e+16>>2]=-0.0-k;g[e+4>>2]=k;jT(a+1872|0,e,b);i=d;return}function jC(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+1736|0;e=b;c[e>>2]=c[d>>2];c[e+4>>2]=c[d+4>>2];c[e+8>>2]=c[d+8>>2];c[e+12>>2]=c[d+12>>2];c[e+16>>2]=c[d+16>>2];c[e+20>>2]=c[d+20>>2];c[b+16>>2]=c[a+1728>>2];d=a+1732|0;c[b+20>>2]=c[d>>2];a=b+4|0;c[a>>2]=(c[d>>2]|0)-((c[b+12>>2]|0)+(c[a>>2]|0));return}function jD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((a[b+1708|0]&1)==0){if((a[b+1640|0]&1)!=0){e=6693}}else{e=6693}if((e|0)==6693){ck(36160,0)}e=b+1736|0;f=b+1744|0;g=(c[f>>2]|0)*3|0;do{if((g&1|0)==0){if((g&2|0)!=0){h=2;break}h=(g&4^4)+4|0}else{h=1}}while(0);fS(3333,h|0);h=b+1748|0;ej(c[e>>2]|0,c[b+1740>>2]|0,c[f>>2]|0,c[h>>2]|0,6407,5121,d|0);b=ag(c[h>>2]|0,c[f>>2]|0)|0;f=0;h=d;while(1){d=h+2|0;e=a[d]|0;a[d]=a[h]|0;a[h]=e;e=f+1|0;if(e>>>0>b>>>0){break}else{f=e;h=h+3|0}}return 1}function jE(a,b){a=a|0;b=b|0;return f2[c[(c[a>>2]|0)+52>>2]&255](b)|0}function jF(b){b=b|0;a[b+1711|0]=1;return}function jG(b,c,d){b=b|0;c=c|0;d=d|0;a[b+2576|0]=c&1;a[b+2577|0]=d&1;return}function jH(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;g[a+2504>>2]=b;g[a+2508>>2]=c;f=b+d;g[a+2512>>2]=f;g[a+2516>>2]=c;g[a+2520>>2]=b;b=c+e;g[a+2524>>2]=b;g[a+2528>>2]=f;g[a+2532>>2]=b;return}function jI(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;f=1.0-c;g[a+2536>>2]=b;g[a+2540>>2]=f;c=b+d;g[a+2544>>2]=c;g[a+2548>>2]=f;g[a+2552>>2]=b;b=f-e;g[a+2556>>2]=b;g[a+2560>>2]=c;g[a+2564>>2]=b;return}function jJ(b,c){b=b|0;c=c|0;a[b+2497|0]=c&1;return}function jK(a,b){a=a|0;b=+b;g[a+2568>>2]=b;return}function jL(b,d){b=b|0;d=d|0;var e=0,f=0.0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;L9342:do{if((d|0)==6){if((a[540636]&1)==0){break}f=+g[119476];if(f>0.0){g[2698]=f;break}else{g[2698]=+((c[119472]|0)>>>0>>>0)/+((c[119473]|0)>>>0>>>0);break}}else if((d|0)==4){f=+g[70320];if(f>=0.0){g[2664]=f;break}f=+g[119476];do{if(f>0.0){if((a[281284]&1)==0){break}g[2664]=f;break L9342}}while(0);g[2664]=+((c[119472]|0)>>>0>>>0)/+((c[119473]|0)>>>0>>>0)}else if((d|0)==5){h=c[119472]|0;j=c[119473]|0;if((h|0)==0|(j|0)==0){break}k=h>>>0<j>>>0?h:j;if(k>>>0>1){l=1;m=1;while(1){if(((h>>>0)%(l>>>0)|0|0)==0){n=((j>>>0)%(l>>>0)|0|0)==0?l:m}else{n=m}o=l+1|0;if(o>>>0<k>>>0){l=o;m=n}else{p=n;break}}}else{p=1}m=(h>>>0)/(p>>>0)|0;l=(j>>>0)/(p>>>0)|0;b5(10660,64,30192,(k=i,i=i+16|0,c[k>>2]=m,c[k+8>>2]=l,k)|0)|0;i=k;g[2681]=+(m>>>0>>>0)/+(l>>>0>>>0)}}while(0);g[119482]=+g[10384+(d*68|0)>>2];a[b+1714|0]=1;a[b+1711|0]=1;i=e;return}function jM(b,d,e,f,h,i){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=+i;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=b+2572|0;k=c[j>>2]|0;if((k|0)==0){bM(1,j|0);a6(3553,c[j>>2]|0);fI(3553,10242,33071);fI(3553,10243,33071);fI(3553,10240,9729);fI(3553,10241,9729)}else{a6(3553,k|0)}g[b+2580>>2]=i;k=ag(e?4:2,f)|0;if((k&2|0)==0){l=(k&4^4)+4|0}else{l=2}fS(3317,l|0);if(e){e=(a[547628]&1)!=0?6408:32993;eG(3553,0,e|0,f|0,h|0,0,e|0,5121,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;a6(3553,s|0);return}else{eG(3553,0,6408,f|0,h|0,0,6408,32819,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;a6(3553,s|0);return}}function jN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+2052>>2]|0;if((e|0)==0){return}go[c[e+8>>2]&127](a,b,d);return}function jO(a,b){a=a|0;b=b|0;var d=0;d=c[(c[a>>2]|0)+64>>2]|0;if((d|0)==0){return}f$[d&511](b);return}function jP(b,d){b=b|0;d=d|0;var e=0;a[b+2496|0]=d&1;e=c[(c[b>>2]|0)+64>>2]|0;if((e|0)==0){return}if((a[b+1713|0]&1)==0){return}f$[e&511](d);return}function jQ(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0;h=b+2500|0;i=c[h>>2]|0;if((i|0)==0){bM(1,h|0);j=c[h>>2]|0}else{j=i}a6(3553,j|0);fI(3553,10242,33071);fI(3553,10243,33071);fI(3553,10240,9729);fI(3553,10241,9729);fS(3317,(e<<2&4^4)+4|0);j=(a[547628]&1)!=0?6408:32993;eG(3553,0,j|0,e|0,f|0,0,j|0,5121,d|0);g[b+2504>>2]=0.0;g[b+2508>>2]=0.0;g[b+2512>>2]=1.0;g[b+2516>>2]=0.0;g[b+2520>>2]=0.0;g[b+2524>>2]=1.0;g[b+2528>>2]=1.0;g[b+2532>>2]=1.0;g[b+2536>>2]=0.0;g[b+2540>>2]=1.0;g[b+2544>>2]=1.0;g[b+2548>>2]=1.0;g[b+2552>>2]=0.0;g[b+2556>>2]=0.0;g[b+2560>>2]=1.0;g[b+2564>>2]=0.0;return 1}function jR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0;e=i;f=b+1710|0;g=a[f]|0;if((g&1)==0&(c[137124]|0)!=0){h=(f2[c[(c[b>>2]|0)+56>>2]&255](d)|0)&1;j=h;k=a[f]|0}else{j=0;k=g}g=b+2472|0;a[g]=j;j=c[b+2028>>2]|0;f=c[b+2032>>2]|0;h=c[b+2036>>2]|0;do{if((k&1)==0){l=j;m=h;n=f}else{if((c[b+2044>>2]|0)!=4){l=j;m=h;n=f;break}d=b+2584|0;do{if((a[d]&1)==0){o=bd(7939)|0;if((o|0)==0){p=0;break}p=(bJ(o|0,45976)|0)!=0}else{p=0}}while(0);if((a[383584]&1)!=0){o=c[135158]|0;q=(o|0)!=0?o:c[t>>2]|0;o=p?49896:47440;eQ(q|0,52384,(r=i,i=i+16|0,c[r>>2]=45976,c[r+8>>2]=o,r)|0)|0;i=r;o=c[135158]|0;q=(o|0)!=0?o:c[t>>2]|0;a7(q|0)|0}if(p){l=6408;m=5121;n=6408;break}do{if((a[d]&1)==0){q=bd(7939)|0;if((q|0)==0){s=0;break}s=(bJ(q|0,44928)|0)!=0}else{s=0}}while(0);if((a[383584]&1)!=0){d=c[135158]|0;q=(d|0)!=0?d:c[t>>2]|0;d=s?49896:47440;eQ(q|0,52384,(r=i,i=i+16|0,c[r>>2]=44928,c[r+8>>2]=d,r)|0)|0;i=r;d=c[135158]|0;q=(d|0)!=0?d:c[t>>2]|0;a7(q|0)|0}if(s){l=6408;m=5121;n=6408;break}q=c[135158]|0;d=(q|0)!=0?q:c[t>>2]|0;be(43512,76,1,d|0)|0;d=c[135158]|0;q=(d|0)!=0?d:c[t>>2]|0;a7(q|0)|0;l=6407;m=33635;n=6407}}while(0);s=b+48|0;r=b+12|0;p=r;bM(c[s>>2]|0,r|0);if((c[s>>2]|0)==0){u=b+44|0;v=u;w=c[v>>2]|0;x=p+(w<<2)|0;y=c[x>>2]|0;a6(3553,y|0);i=e;return}r=b+2040|0;f=b+468|0;h=b+1832|0;j=b+1836|0;k=b+472|0;q=0;do{a6(3553,c[p+(q<<2)>>2]|0);fI(3553,10242,c[r>>2]|0);fI(3553,10243,c[r>>2]|0);fI(3553,10240,c[f>>2]|0);fI(3553,10241,c[f>>2]|0);if((a[g]&1)==0){eG(3553,0,l|0,c[h>>2]|0,c[j>>2]|0,0,n|0,m|0,c[k>>2]|0)}q=q+1|0;}while(q>>>0<(c[s>>2]|0)>>>0);u=b+44|0;v=u;w=c[v>>2]|0;x=p+(w<<2)|0;y=c[x>>2]|0;a6(3553,y|0);i=e;return}
function jS(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+16|0;g=f|0;h=f+8|0;if((a[383584]&1)!=0){j=c[135158]|0;k=(j|0)!=0?j:c[t>>2]|0;eQ(k|0,18752,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;k=c[135158]|0;j=(k|0)!=0?k:c[t>>2]|0;a7(j|0)|0}c[g>>2]=0;c[h>>2]=0;er(3379,g|0);er(34024,h|0);if((a[383584]&1)!=0){j=c[135158]|0;k=(j|0)!=0?j:c[t>>2]|0;j=c[g>>2]|0;g=c[h>>2]|0;eQ(k|0,16552,(l=i,i=i+16|0,c[l>>2]=j,c[l+8>>2]=g,l)|0)|0;i=l;g=c[135158]|0;j=(g|0)!=0?g:c[t>>2]|0;a7(j|0)|0}a6(3553,0);j=b+48|0;ek(c[j>>2]|0,b+1644|0);g=(a[482612]&1)==0;k=(a[482613]&1)!=0;do{if(k){do{if((a[b+2584|0]&1)==0){h=bd(7939)|0;if((h|0)==0){m=0;break}m=(bJ(h|0,14504)|0)!=0}else{m=0}}while(0);if((a[383584]&1)!=0){h=c[135158]|0;n=(h|0)!=0?h:c[t>>2]|0;h=m?49896:47440;eQ(n|0,52384,(l=i,i=i+16|0,c[l>>2]=14504,c[l+8>>2]=h,l)|0)|0;i=l;h=c[135158]|0;n=(h|0)!=0?h:c[t>>2]|0;a7(n|0)|0}if(m){break}else{o=0}i=f;return o|0}}while(0);L9452:do{if(g){if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=6804;break L9452}ck(36160,c[b+1644+(m<<2)>>2]|0);dX(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=cJ(36160)|0;if((n|0)==36053){m=m+1|0}else{q=m;r=n;p=6803;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=6804;break L9452}ck(36160,c[b+1644+(m<<2)>>2]|0);dX(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=cJ(36160)|0;if((n|0)==36053){m=m+1|0}else{q=m;r=n;p=6803;break}}}}else{dk(c[j>>2]|0,b+1676|0);a[b+1709|0]=1;if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=6804;break L9452}ck(36160,c[b+1644+(m<<2)>>2]|0);dX(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;dw(36161,c[n>>2]|0);cB(36161,35056,d|0,e|0);dw(36161,0);el(36160,36096,36161,c[n>>2]|0);el(36160,36128,36161,c[n>>2]|0);n=cJ(36160)|0;if((n|0)==36053){m=m+1|0}else{q=m;r=n;p=6803;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=6804;break L9452}ck(36160,c[b+1644+(m<<2)>>2]|0);dX(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;dw(36161,c[n>>2]|0);cB(36161,33189,d|0,e|0);dw(36161,0);el(36160,36096,36161,c[n>>2]|0);n=cJ(36160)|0;if((n|0)==36053){m=m+1|0}else{q=m;r=n;p=6803;break}}}}}while(0);if((p|0)==6804){ck(36160,0);a[b+1708|0]=1;o=1;i=f;return o|0}else if((p|0)==6803){p=c[135158]|0;eQ(((p|0)!=0?p:c[t>>2]|0)|0,12256,(l=i,i=i+16|0,c[l>>2]=q,c[l+8>>2]=r,l)|0)|0;i=l;l=c[135158]|0;a7(((l|0)!=0?l:c[t>>2]|0)|0)|0;o=0;i=f;return o|0}return 0}function jT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0.0,A=0,B=0.0,C=0,D=0.0;d=i;i=i+64|0;e=d|0;f=+g[c>>2];h=+g[c+4>>2];j=+g[c+8>>2];k=+g[c+12>>2];l=+g[c+16>>2];m=+g[c+20>>2];n=+g[c+24>>2];o=+g[c+28>>2];p=+g[c+32>>2];q=+g[c+36>>2];r=+g[c+40>>2];s=+g[c+44>>2];t=+g[c+48>>2];u=+g[c+52>>2];v=+g[c+56>>2];w=+g[c+60>>2];c=0;do{x=+g[b+(c<<2)>>2];y=c+4|0;z=+g[b+(y<<2)>>2];A=c+8|0;B=+g[b+(A<<2)>>2];C=c+12|0;D=+g[b+(C<<2)>>2];g[e+(c<<2)>>2]=x*f+0.0+z*h+B*j+D*k;g[e+(y<<2)>>2]=x*l+0.0+z*m+B*n+D*o;g[e+(A<<2)>>2]=x*p+0.0+z*q+B*r+D*s;g[e+(C<<2)>>2]=x*t+0.0+z*u+B*v+D*w;c=c+1|0;}while(c>>>0<4);c=a;a=e;s1(c|0,a|0,64)|0;i=d;return}function jU(a){a=a|0;var b=0;b=c[a+2048>>2]|0;if((b|0)==0){return}f$[c[(c[a+2056>>2]|0)+12>>2]&511](b);br(1,a+2060|0);b=c[a+2076>>2]|0;if((b|0)==0){return}sS(b);return}function jV(b,d,e){b=b|0;d=d|0;e=+e;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0;d=i;if((a[297692]&1)==0){f=0;i=d;return f|0}h=b+2056|0;j=b+2048|0;k=i_((a[293589]|0)!=0?293589:547872,+g[74422])|0;c[j>>2]=k;if((k|0)==0){k=c[135158]|0;l=(k|0)!=0?k:c[t>>2]|0;eQ(l|0,49e3,(m=i,i=i+8|0,c[m>>2]=45008,m)|0)|0;i=m;l=c[135158]|0;k=(l|0)!=0?l:c[t>>2]|0;a7(k|0)|0;c[h>>2]=0;c[j>>2]=0;j=c[135158]|0;k=(j|0)!=0?j:c[t>>2]|0;be(48280,49,1,k|0)|0;k=c[135158]|0;j=(k|0)!=0?k:c[t>>2]|0;a7(j|0)|0;f=0;i=d;return f|0}if((a[383584]&1)!=0){j=c[135158]|0;k=(j|0)!=0?j:c[t>>2]|0;eQ(k|0,45128,(m=i,i=i+8|0,c[m>>2]=45008,m)|0)|0;i=m;m=c[135158]|0;k=(m|0)!=0?m:c[t>>2]|0;a7(k|0)|0}c[h>>2]=8384;h=b+2060|0;bM(1,h|0);a6(3553,c[h>>2]|0);fI(3553,10242,33071);fI(3553,10243,33071);fI(3553,10240,9729);fI(3553,10241,9729);a6(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);er(3379,b+2064|0);e=+g[74426];g[b+2344>>2]=e;n=+g[74427];g[b+2348>>2]=n;o=+g[74428];g[b+2352>>2]=o;g[b+2356>>2]=1.0;p=+g[74426];g[b+2360>>2]=p;q=+g[74427];g[b+2364>>2]=q;r=+g[74428];g[b+2368>>2]=r;g[b+2372>>2]=1.0;s=+g[74426];g[b+2376>>2]=s;u=+g[74427];g[b+2380>>2]=u;v=+g[74428];g[b+2384>>2]=v;g[b+2388>>2]=1.0;w=+g[74426];g[b+2392>>2]=w;x=+g[74427];g[b+2396>>2]=x;y=+g[74428];g[b+2400>>2]=y;g[b+2404>>2]=1.0;g[b+2408>>2]=e*.3;g[b+2412>>2]=n*.3;g[b+2416>>2]=o*.3;g[b+2420>>2]=1.0;g[b+2424>>2]=p*.3;g[b+2428>>2]=q*.3;g[b+2432>>2]=r*.3;g[b+2436>>2]=1.0;g[b+2440>>2]=s*.3;g[b+2444>>2]=u*.3;g[b+2448>>2]=v*.3;g[b+2452>>2]=1.0;g[b+2456>>2]=w*.3;g[b+2460>>2]=x*.3;g[b+2464>>2]=y*.3;g[b+2468>>2]=1.0;f=1;i=d;return f|0}function jW(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0.0,ae=0.0,af=0.0,ah=0.0;f=i;i=i+168|0;h=f|0;j=f+64|0;k=f+96|0;l=f+128|0;m=f+160|0;do{if((e|0)==0){n=+g[74424];o=+g[74425];if((a[297693]&1)==0){p=n;q=o;r=1.0;break}p=n;q=o;r=+((c[b+1744>>2]|0)>>>0>>>0)/+((c[b+1720>>2]|0)>>>0>>>0)}else{p=+g[e>>2];q=+g[e+4>>2];r=+g[e+8>>2]}}while(0);e=b+2048|0;if((c[e>>2]|0)==0){i=f;return}s=b+4|0;t=c[s>>2]|0;if((t|0)!=0){f$[c[t+12>>2]&511](15)}jo(b,c[b+1728>>2]|0,c[b+1732>>2]|0,0);e$(3042);a6(3553,c[b+2060>>2]|0);t=l|0;u=b+2e3|0;v=u;w=b+2008|0;c[w>>2]=t;x=b+2080|0;if((da(x|0,d|0)|0)==0){y=c[b+2336>>2]|0;z=c[b+2340>>2]|0;A=b+2068|0;B=b+2072|0}else{C=b+2056|0;go[c[(c[C>>2]|0)+4>>2]&127](c[e>>2]|0,d,m);D=c[m>>2]|0;E=c[D+24>>2]|0;F=(c[D+4>>2]|0)+E|0;G=c[D+28>>2]|0;H=(c[D+8>>2]|0)+G|0;I=c[D+48>>2]|0;if((I|0)==0){J=H;K=G;L=F;M=E}else{N=H;H=G;G=F;F=E;E=I;while(1){I=c[E+24>>2]|0;O=(c[E+4>>2]|0)+I|0;P=c[E+28>>2]|0;Q=(c[E+8>>2]|0)+P|0;R=(I|0)<(F|0)?I:F;I=(O|0)>(G|0)?O:G;O=(P|0)<(H|0)?P:H;P=(Q|0)>(N|0)?Q:N;Q=c[E+48>>2]|0;if((Q|0)==0){J=P;K=O;L=I;M=R;break}else{N=P;H=O;G=I;F=R;E=Q}}}E=L-M|0;L=J-K|0;J=E-1|0;F=J>>>1|J;J=F>>>2|F;F=J>>>4|J;J=F>>>8|F;F=(J>>>16|J)+1|0;J=L-1|0;G=J>>>1|J;J=G>>>2|G;G=J>>>4|J;J=G>>>8|G;G=(J>>>16|J)+1|0;J=c[b+2064>>2]|0;H=(F|0)>(J|0)?J:F;F=(G|0)>(J|0)?J:G;G=b+2068|0;J=c[G>>2]|0;N=b+2072|0;do{if((H|0)>(J|0)){S=6843}else{Q=c[N>>2]|0;if((F|0)>(Q|0)){S=6843;break}T=J;U=Q;V=b+2076|0}}while(0);if((S|0)==6843){J=b+2076|0;Q=c[J>>2]|0;c[J>>2]=sT(Q,ag(H<<2,F)|0)|0;eG(3553,0,6408,H|0,F|0,0,6408,5121,0);c[G>>2]=H;c[N>>2]=F;T=H;U=F;V=J}J=c[V>>2]|0;s_(J|0,0,ag(U<<2,T)|0);if((D|0)!=0){T=D;do{D=c[V>>2]|0;U=c[G>>2]|0;J=c[N>>2]|0;F=(c[T+24>>2]|0)-M|0;H=c[T+8>>2]|0;Q=J-H+(K-(c[T+28>>2]|0))|0;R=Q-1|0;I=c[T>>2]|0;O=(F|0)<0;P=(c[T+4>>2]|0)+(O?F:0)|0;W=(R|0)<0;X=(W?R:0)+H|0;if(O){_=I+(-F|0)|0;$=0}else{_=I;$=F}if(W){aa=_+(ag(c[T+12>>2]|0,1-Q|0)|0)|0;ab=0}else{aa=_;ab=R}R=($+P|0)>(U|0)?U-$|0:P;P=(ab+X|0)>(J|0)?J-ab|0:X;do{if((P|0)>0){X=T+12|0;if((R|0)<=0){break}J=aa;Q=D+((ag(ab,U)|0)+$<<2)|0;W=0;while(1){F=Q;I=0;while(1){a[F]=-1;a[F+1|0]=-1;a[F+2|0]=-1;a[F+3|0]=a[J+I|0]|0;O=I+1|0;if((O|0)<(R|0)){F=F+4|0;I=O}else{break}}I=W+1|0;if((I|0)<(P|0)){J=J+(c[X>>2]|0)|0;Q=Q+(U<<2)|0;W=I}else{break}}}}while(0);T=c[T+48>>2]|0;}while((T|0)!=0)}fS(3317,8);eI(3553,0,0,0,c[G>>2]|0,c[N>>2]|0,6408,5121,c[V>>2]|0);f0[c[(c[C>>2]|0)+8>>2]&255](c[e>>2]|0,m);m=256;e=x;x=d;while(1){d=m-1|0;if((d|0)==0){S=6859;break}C=a[x]|0;a[e]=C;if(C<<24>>24==0){break}else{m=d;e=e+1|0;x=x+1|0}}do{if((S|0)==6859){a[e]=0;if((a[x]|0)==0){break}else{ac=x}do{ac=ac+1|0;}while((a[ac]|0)!=0)}}while(0);c[b+2336>>2]=E;c[b+2340>>2]=L;y=E;z=L;A=G;B=N}N=j|0;G=k|0;o=+(y|0);n=+((c[b+1744>>2]|0)>>>0>>>0);ad=p+r*o/n;ae=+(z|0);af=+((c[b+1748>>2]|0)>>>0>>>0);ah=q+r*ae/af;g[N>>2]=p;g[j+8>>2]=ad;g[j+16>>2]=p;g[j+24>>2]=ad;g[j+4>>2]=ah;g[j+12>>2]=ah;g[j+20>>2]=q;g[j+28>>2]=q;r=2.0/n;n=2.0/af;af=p-r;g[G>>2]=af;p=ah-n;g[k+4>>2]=p;ah=ad-r;g[k+8>>2]=ah;g[k+12>>2]=p;g[k+16>>2]=af;af=q-n;g[k+20>>2]=af;g[k+24>>2]=ah;g[k+28>>2]=af;af=o/+(c[A>>2]|0);o=1.0-ae/+(c[B>>2]|0);g[t>>2]=0.0;g[l+8>>2]=af;g[l+16>>2]=0.0;g[l+24>>2]=af;g[l+4>>2]=o;g[l+12>>2]=o;g[l+20>>2]=1.0;g[l+28>>2]=1.0;l=u;c[l>>2]=G;G=b+2004|0;c[G>>2]=b+2408;u=b+1872|0;t=c[s>>2]|0;do{if((t|0)!=0){B=c[t+32>>2]|0;f2[B&255](v)|0;B=c[s>>2]|0;if((B|0)==0){break}A=c[B+36>>2]|0;f2[A&255](u)|0}}while(0);dB(5,0,4);c[l>>2]=N;c[G>>2]=b+2344;N=c[s>>2]|0;do{if((N|0)!=0){t=c[N+32>>2]|0;f2[t&255](v)|0;t=c[s>>2]|0;if((t|0)==0){break}A=c[t+36>>2]|0;f2[A&255](u)|0}}while(0);dB(5,0,4);c[l>>2]=c[b+2016>>2];c[w>>2]=b+1840;c[G>>2]=c[b+2020>>2];a6(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);dG(3042);G=b+1936|0;s_(G|0,0,48);g[b+1996>>2]=1.0;g[G>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;o=+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0;af=+Y(+o);ae=+Z(+o);s_(h|0,0,60);g[h+40>>2]=1.0;g[h+60>>2]=1.0;g[h>>2]=af;g[h+20>>2]=af;g[h+16>>2]=-0.0-ae;g[h+4>>2]=ae;jT(u,h,G);i=f;return}function jX(a){a=a|0;return}function jY(a,b){a=a|0;b=b|0;return}function jZ(){return}function j_(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;if(a[8152]|0){e=0}else{a[8152]=1;e=1}return e|0}function j$(a,b){a=a|0;b=b|0;c[a>>2]=c[95892];c[b>>2]=c[95894];return}function j0(){return a[8152]|0}function j1(a,b){a=a|0;b=b|0;return+(+(a>>>0>>>0)/+(b>>>0>>>0))}function j2(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;if((a[383584]&1)!=0){g=c[135158]|0;h=(g|0)!=0?g:c[t>>2]|0;be(35888,45,1,h|0)|0;h=c[135158]|0;g=(h|0)!=0?h:c[t>>2]|0;a7(g|0)|0}if(a[8152]|0){if((a[383584]&1)==0){j=1;i=b;return j|0}g=c[135158]|0;h=(g|0)!=0?g:c[t>>2]|0;be(28696,64,1,h|0)|0;h=c[135158]|0;g=(h|0)!=0?h:c[t>>2]|0;a7(g|0)|0;j=1;i=b;return j|0}g=fN(0)|0;c[135430]=g;do{if((g|0)!=0){do{if((c_(g|0,0,0)|0)!=0){if((eV(c[135430]|0,8032,541736,1,f|0)|0)==0){break}h=bm(c[135430]|0,c[135434]|0,0,8016)|0;c[135432]=h;if((h|0)==0){break}h=eP(c[135430]|0,c[135434]|0,0,0)|0;c[135428]=h;if((h|0)==0){break}if((d_(c[135430]|0,h|0,h|0,c[135432]|0)|0)==0){break}h=c[135430]|0;k=c[135428]|0;fR(h|0,k|0,12375,d|0)|0;k=c[135430]|0;h=c[135428]|0;fR(k|0,h|0,12374,e|0)|0;h=c[d>>2]|0;c[95892]=h;k=c[e>>2]|0;c[95894]=k;if((a[383584]&1)==0){j=1;i=b;return j|0}l=c[135158]|0;m=(l|0)!=0?l:c[t>>2]|0;eQ(m|0,24192,(m=i,i=i+16|0,c[m>>2]=h,c[m+8>>2]=k,m)|0)|0;i=m;m=c[135158]|0;k=(m|0)!=0?m:c[t>>2]|0;a7(k|0)|0;j=1;i=b;return j|0}}while(0);k=c[135430]|0;if((k|0)==0){break}d_(k|0,0,0,0)|0;k=c[135432]|0;if((k|0)!=0){m=c[135430]|0;dN(m|0,k|0)|0}k=c[135428]|0;if((k|0)!=0){m=c[135430]|0;a3(m|0,k|0)|0}k=c[135430]|0;cs(k|0)|0}}while(0);c[135432]=0;c[135428]=0;c[135430]=0;c[135434]=0;a[8152]=0;j=0;i=b;return j|0}function j3(){var b=0,d=0;b=c[135430]|0;if((b|0)!=0){d_(b|0,0,0,0)|0;b=c[135432]|0;if((b|0)!=0){d=c[135430]|0;dN(d|0,b|0)|0}b=c[135428]|0;if((b|0)!=0){d=c[135430]|0;a3(d|0,b|0)|0}b=c[135430]|0;cs(b|0)|0}c[135432]=0;c[135428]=0;c[135430]=0;c[135434]=0;a[8152]=0;return}function j4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)==1){d=(bs(12448)|0)!=0}else{d=0}return d|0}function j5(){var b=0,d=0,e=0.0,f=0,g=0,j=0,k=0,l=0,m=0;b=i;i=i+128|0;d=b|0;a[d]=0;e=+bk()*1.0e3;f=~~e>>>0;g=+V(e)>=1.0?e>0.0?(al(+U(e/4294967296.0),4294967295.0)|0)>>>0:~~+af((e- +(~~e>>>0))/4294967296.0)>>>0:0;do{if((c[135098]|0)==0){c[70292]=f;c[70293]=g;c[70290]=f;c[70291]=g;b5(d|0,128,31448,(j=i,i=i+8|0,c[j>>2]=540396,j)|0)|0;i=j}else{k=531936;l=c[k>>2]|0;m=ta(l,c[k+4>>2]|0,1,0)|0;k=531936;c[k>>2]=m;c[k+4>>2]=K;k=tb(f,g,c[70292]|0,c[70293]|0)|0;m=515552+((l&2047)<<3)|0;c[m>>2]=k;c[m+4>>2]=K;c[70292]=f;c[70293]=g;m=c[135098]|0;if((m&255|0)==0){k=tb(f,g,c[70290]|0,c[70291]|0)|0;c[70290]=f;c[70291]=g;e=256.0e6/(+(k>>>0)+ +(K|0)*4294967296.0);b5(d|0,128,13728,(j=i,i=i+24|0,c[j>>2]=540396,h[j+8>>3]=e,c[j+16>>2]=m,j)|0)|0;i=j;break}else{i=b;return}}}while(0);if((a[383584]&1)==0){i=b;return}g=c[135158]|0;eQ(((g|0)!=0?g:c[t>>2]|0)|0,48248,(j=i,i=i+8|0,c[j>>2]=d,j)|0)|0;i=j;j=c[135158]|0;a7(((j|0)!=0?j:c[t>>2]|0)|0)|0;i=b;return}function j6(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;g=i;i=i+24|0;h=g|0;j=g+8|0;cU(h|0,j|0,g+16|0);k=c[h>>2]|0;c[e>>2]=k;h=c[j>>2]|0;c[f>>2]=h;a[d]=(c[e>>2]|0)==(c[95892]|0)&(h|0)==(c[95894]|0)&1^1;c[95892]=k;c[95894]=h;a[b]=0;i=g;return}function j7(a){a=a|0;return 0}function j8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return 0}function j9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;c[a>>2]=0;d=sR(48)|0;if((d|0)==0){return}if((c[d-4>>2]&3|0)!=0){s_(d|0,0,48)}e=bz()|0;c[d+44>>2]=e;if((e|0)==0){sS(d);return}s_(62824,0,1292);e=5088;f=276;while(1){c[62824+(f<<2)>>2]=c[e>>2];g=c[e+12>>2]|0;if((g|0)==0){break}else{e=e+8|0;f=g}}c[a>>2]=6128;c[b>>2]=d;return}function ka(a){a=a|0;return cw(a|0)|0}function kb(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a5=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0.0,cX=0.0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,db=0,dc=0,dd=0,de=0,df=0,dg=0;e=i;i=i+848|0;f=e|0;j=e+64|0;k=e+128|0;l=e+192|0;m=e+256|0;n=e+320|0;o=e+384|0;p=e+448|0;q=e+512|0;r=e+576|0;s=e+640|0;u=e+704|0;v=e+768|0;w=e+832|0;x=sR(109528)|0;if((x|0)==0){c[68254]=0;y=0;i=e;return y|0}if((c[x-4>>2]&3|0)!=0){s_(x|0,0,109528)}z=x;c[68254]=z;L26:do{if((d|0)==0){A=c[135158]|0;B=(A|0)!=0?A:c[t>>2]|0;be(28632,59,1,B|0)|0;B=c[135158]|0;A=(B|0)!=0?B:c[t>>2]|0;a7(A|0)|0;c[(c[68254]|0)+72>>2]=1;A=dT(((a[273048]&1)!=0?20216:20576)|0)|0;c[(c[68254]|0)+4172>>2]=A;A=dT(((a[273048]&1)!=0?21232:21760)|0)|0;B=c[68254]|0;c[B+4176>>2]=A;a[B+4|0]=1}else{B=cD(d|0,46)|0;A=(B|0)==0?547872:B+1|0;if((da(A|0,40968)|0)==0){B=4096;C=x+76|0;D=d;while(1){E=B-1|0;if((E|0)==0){F=25;break}G=a[D]|0;a[C]=G;if(G<<24>>24==0){break}else{B=E;C=C+1|0;D=D+1|0}}do{if((F|0)==25){a[C]=0;if((a[D]|0)==0){break}else{H=D}do{H=H+1|0;}while((a[H]|0)!=0)}}while(0);c[x+72>>2]=1;a[x+4|0]=1;break}do{if((da(A|0,48240)|0)==0){D=hz(d,0)|0;if((D|0)==0){break}C=iU(D,c[68254]|0)|0;a[(c[68254]|0)+4|0]=1;hx(D);if(C){break L26}}else{C=v|0;if((a[383584]&1)!=0){D=c[135158]|0;B=(D|0)!=0?D:c[t>>2]|0;eQ(B|0,24544,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;B=c[135158]|0;D=(B|0)!=0?B:c[t>>2]|0;a7(D|0)|0}D=ik(d)|0;B=(D|0)!=0;L46:do{if(B){E=D|0;G=c[E>>2]|0;if((G|0)==0){break}else{J=G}L49:while(1){do{if((c[J+20>>2]|0)==0){if((da(c[J>>2]|0,18888)|0)!=0){break}K=J+8|0;G=K;while(1){L=c[G>>2]|0;if((L|0)==0){F=46;break}if((da(16752,c[L>>2]|0)|0)==0){F=41;break}else{G=L+8|0}}L57:do{if((F|0)==41){F=0;G=c[L+4>>2]|0;if((G|0)==0){F=46;break}else{M=64;N=C;O=G}while(1){G=M-1|0;if((G|0)==0){break}P=a[O]|0;a[N]=P;if(P<<24>>24==0){break L57}else{M=G;N=N+1|0;O=O+1|0}}a[N]=0;if((a[O]|0)==0){break}else{Q=O}do{Q=Q+1|0;}while((a[Q]|0)!=0)}}while(0);if((F|0)==46){F=0;a[C]=0}if((da(C|0,14560)|0)==0){break L49}}}while(0);G=c[J+16>>2]|0;if((G|0)==0){break L46}else{J=G}}c[x>>2]=2;G=K;while(1){R=c[G>>2]|0;if((R|0)==0){F=56;break}if((da(12360,c[R>>2]|0)|0)==0){F=51;break}else{G=R+8|0}}L73:do{if((F|0)==51){G=c[R+4>>2]|0;if((G|0)==0){F=56;break}else{S=64;T=C;U=G}while(1){G=S-1|0;if((G|0)==0){break}P=a[U]|0;a[T]=P;if(P<<24>>24==0){break L73}else{S=G;T=T+1|0;U=U+1|0}}a[T]=0;if((a[U]|0)==0){break}else{V=U}do{V=V+1|0;}while((a[V]|0)!=0)}}while(0);if((F|0)==56){a[C]=0}G=x+4|0;a[G]=(da(C|0,52472)|0)==0|0;P=x+5|0;W=K;while(1){X=c[W>>2]|0;if((X|0)==0){F=61;break}if((da(50024,c[X>>2]|0)|0)==0){F=60;break}else{W=X+8|0}}do{if((F|0)==60){W=c[X+4>>2]|0;if((W|0)==0){F=61;break}else{Y=64;Z=0;_=P;$=W}while(1){W=Y-1|0;if((W|0)==0){F=64;break}aa=a[$]|0;a[_]=aa;if(aa<<24>>24==0){ab=Z;break}else{Y=W;Z=Z+1|0;_=_+1|0;$=$+1|0}}do{if((F|0)==64){a[_]=0;if((a[$]|0)==0){ab=Z;break}else{ac=$;ad=Z}while(1){W=ac+1|0;aa=ad+1|0;if((a[W]|0)==0){ab=aa;break}else{ac=W;ad=aa}}}}while(0);if(ab>>>0>=64){break}if((a[383584]&1)==0){break}aa=c[135158]|0;eQ(((aa|0)!=0?aa:c[t>>2]|0)|0,47480,(I=i,i=i+8|0,c[I>>2]=P,I)|0)|0;i=I;aa=c[135158]|0;a7(((aa|0)!=0?aa:c[t>>2]|0)|0)|0}}while(0);if((F|0)==61){a[P]=0}do{if((a[G]&1)==0){aa=c[135158]|0;W=(aa|0)!=0?aa:c[t>>2]|0;be(45016,57,1,W|0)|0;W=c[135158]|0;aa=(W|0)!=0?W:c[t>>2]|0;a7(aa|0)|0}else{if((a[383584]&1)==0){break}aa=c[135158]|0;W=(aa|0)!=0?aa:c[t>>2]|0;be(46032,54,1,W|0)|0;W=c[135158]|0;aa=(W|0)!=0?W:c[t>>2]|0;a7(aa|0)|0}}while(0);P=c[J+12>>2]|0;aa=x+72|0;L107:do{if((P|0)==0){F=394}else{W=f|0;ae=j|0;af=k|0;ag=l|0;ah=m|0;ai=n|0;aj=o|0;ak=p|0;al=q|0;am=r|0;an=s|0;ao=u|0;ap=x+66444|0;aq=x+99792|0;ar=x+109012|0;as=x+109016|0;at=P;L109:while(1){if((c[aa>>2]|0)>>>0>=16){break L107}do{if((c[at+20>>2]|0)==0){au=at+4|0;av=c[au>>2]|0;if((av|0)==0){break}aw=dT(av|0)|0;if((aw|0)==0){break}av=c[aa>>2]|0;ax=c[at>>2]|0;if((da(ax|0,43680)|0)==0){ay=z+76+(av*4148|0)+4096|0;if((c[ay>>2]|0)!=0){F=82;break L109}az=iW(aw,d,at)|0;if((az|0)==0){F=84;break L109}c[ay>>2]=az;break}if((da(ax|0,39368)|0)!=0){if((da(ax|0,35176)|0)==0){sS(aw);az=c[ap>>2]|0;if(az>>>0>7){ay=c[135158]|0;aA=(ay|0)!=0?ay:c[t>>2]|0;be(13432,58,1,aA|0)|0;aA=c[135158]|0;ay=(aA|0)!=0?aA:c[t>>2]|0;a7(ay|0)|0;break}ay=z+66448+(az*4168|0)|0;aA=at+8|0;aB=aA;while(1){aC=c[aB>>2]|0;if((aC|0)==0){F=251;break}if((da(15664,c[aC>>2]|0)|0)==0){F=246;break}else{aB=aC+8|0}}L131:do{if((F|0)==246){F=0;aB=c[aC+4>>2]|0;if((aB|0)==0){F=251;break}else{aD=64;aE=ay;aF=aB}while(1){aB=aD-1|0;if((aB|0)==0){break}aG=a[aF]|0;a[aE]=aG;if(aG<<24>>24==0){break L131}else{aD=aB;aE=aE+1|0;aF=aF+1|0}}a[aE]=0;if((a[aF]|0)==0){break}else{aH=aF}do{aH=aH+1|0;}while((a[aH]|0)!=0)}}while(0);if((F|0)==251){F=0;a[ay]=0}aB=z+66448+(az*4168|0)+64|0;aG=aA;while(1){aI=c[aG>>2]|0;if((aI|0)==0){F=260;break}if((da(13336,c[aI>>2]|0)|0)==0){F=255;break}else{aG=aI+8|0}}L145:do{if((F|0)==255){F=0;aG=c[aI+4>>2]|0;if((aG|0)==0){F=260;break}else{aJ=4096;aK=aB;aL=aG}while(1){aG=aJ-1|0;if((aG|0)==0){break}aM=a[aL]|0;a[aK]=aM;if(aM<<24>>24==0){break L145}else{aJ=aG;aK=aK+1|0;aL=aL+1|0}}a[aK]=0;if((a[aL]|0)==0){break}else{aN=aL}do{aN=aN+1|0;}while((a[aN]|0)!=0)}}while(0);if((F|0)==260){F=0;a[aB]=0}s_(W|0,0,64);aG=aA;while(1){aO=c[aG>>2]|0;if((aO|0)==0){F=269;break}if((da(13184,c[aO>>2]|0)|0)==0){F=264;break}else{aG=aO+8|0}}L159:do{if((F|0)==264){F=0;aG=c[aO+4>>2]|0;if((aG|0)==0){F=269;break}else{aP=64;aQ=W;aR=aG}while(1){aG=aP-1|0;if((aG|0)==0){break}aA=a[aR]|0;a[aQ]=aA;if(aA<<24>>24==0){break L159}else{aP=aG;aQ=aQ+1|0;aR=aR+1|0}}a[aQ]=0;if((a[aR]|0)==0){break}else{aS=aR}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);if((F|0)==269){F=0;a[W]=0}if((a[ay]|0)==0){F=271;break L109}if((a[aB]|0)==0){F=273;break L109}do{if((da(W|0,12600)|0)==0){c[z+66448+(az*4168|0)+4160>>2]=1}else{if((da(W|0,12416)|0)==0){c[z+66448+(az*4168|0)+4160>>2]=2;break}if((a[W]|0)!=0){F=280;break L109}c[z+66448+(az*4168|0)+4160>>2]=0}}while(0);c[ap>>2]=(c[ap>>2]|0)+1;break}if((da(ax|0,32832)|0)!=0){if((da(ax|0,31456)|0)!=0){break}sS(aw);if((c[ar>>2]|0)!=0){F=367;break L109}az=at+8|0;aB=az;while(1){aT=c[aB>>2]|0;if((aT|0)==0){F=376;break}if((da(16840,c[aT>>2]|0)|0)==0){F=371;break}else{aB=aT+8|0}}L188:do{if((F|0)==371){F=0;aB=c[aT+4>>2]|0;if((aB|0)==0){F=376;break}else{aU=512;aV=as;aW=aB}while(1){aB=aU-1|0;if((aB|0)==0){break}ax=a[aW]|0;a[aV]=ax;if(ax<<24>>24==0){aX=az;break L188}else{aU=aB;aV=aV+1|0;aW=aW+1|0}}a[aV]=0;if((a[aW]|0)==0){aX=az;break}else{aY=aW}while(1){aB=aY+1|0;if((a[aB]|0)==0){aX=az;break}else{aY=aB}}}}while(0);if((F|0)==376){F=0;a[as]=0;aX=az}while(1){aZ=c[aX>>2]|0;if((aZ|0)==0){F=384;break}if((da(16752,c[aZ>>2]|0)|0)==0){F=379;break}else{aX=aZ+8|0}}L201:do{if((F|0)==379){F=0;az=c[aZ+4>>2]|0;if((az|0)==0){F=384;break}else{a_=64;a$=W;a0=az}while(1){az=a_-1|0;if((az|0)==0){break}aB=a[a0]|0;a[a$]=aB;if(aB<<24>>24==0){break L201}else{a_=az;a$=a$+1|0;a0=a0+1|0}}a[a$]=0;if((a[a0]|0)==0){break}else{a1=a0}do{a1=a1+1|0;}while((a[a1]|0)!=0)}}while(0);if((F|0)==384){F=0;a[W]=0}if((da(W|0,19840)|0)!=0){F=386;break L109}az=c[au>>2]|0;if((az|0)==0){F=388;break L109}aB=dT(az|0)|0;c[ar>>2]=aB;if((aB|0)==0){F=392;break L109}az=iW(aB,d,at)|0;c[ar>>2]=az;if((az|0)==0){F=391;break L109}else{break}}sS(aw);az=c[aq>>2]|0;if(az>>>0>63){F=285;break L109}aB=z+99796+(az*80|0)|0;ax=at+8|0;ay=ax;while(1){a2=c[ay>>2]|0;if((a2|0)==0){F=294;break}if((da(15664,c[a2>>2]|0)|0)==0){F=289;break}else{ay=a2+8|0}}L220:do{if((F|0)==289){F=0;ay=c[a2+4>>2]|0;if((ay|0)==0){F=294;break}else{a3=64;a5=aB;a8=ay}while(1){ay=a3-1|0;if((ay|0)==0){break}au=a[a8]|0;a[a5]=au;if(au<<24>>24==0){a9=ax;break L220}else{a3=ay;a5=a5+1|0;a8=a8+1|0}}a[a5]=0;if((a[a8]|0)==0){a9=ax;break}else{ba=a8}while(1){ay=ba+1|0;if((a[ay]|0)==0){a9=ax;break}else{ba=ay}}}}while(0);if((F|0)==294){F=0;a[aB]=0;a9=ax}while(1){bb=c[a9>>2]|0;if((bb|0)==0){F=302;break}if((da(15528,c[bb>>2]|0)|0)==0){F=297;break}else{a9=bb+8|0}}L233:do{if((F|0)==297){F=0;ay=c[bb+4>>2]|0;if((ay|0)==0){F=302;break}else{bc=64;bd=W;bf=ay}while(1){ay=bc-1|0;if((ay|0)==0){break}au=a[bf]|0;a[bd]=au;if(au<<24>>24==0){bg=ax;break L233}else{bc=ay;bd=bd+1|0;bf=bf+1|0}}a[bd]=0;if((a[bf]|0)==0){bg=ax;break}else{bh=bf}while(1){ay=bh+1|0;if((a[ay]|0)==0){bg=ax;break}else{bh=ay}}}}while(0);if((F|0)==302){F=0;a[W]=0;bg=ax}while(1){bi=c[bg>>2]|0;if((bi|0)==0){F=310;break}if((da(15392,c[bi>>2]|0)|0)==0){F=305;break}else{bg=bi+8|0}}L246:do{if((F|0)==305){F=0;ay=c[bi+4>>2]|0;if((ay|0)==0){F=310;break}else{bj=64;bk=ae;bl=ay}while(1){ay=bj-1|0;if((ay|0)==0){break}au=a[bl]|0;a[bk]=au;if(au<<24>>24==0){bm=ax;break L246}else{bj=ay;bk=bk+1|0;bl=bl+1|0}}a[bk]=0;if((a[bl]|0)==0){bm=ax;break}else{bn=bl}while(1){ay=bn+1|0;if((a[ay]|0)==0){bm=ax;break}else{bn=ay}}}}while(0);if((F|0)==310){F=0;a[ae]=0;bm=ax}while(1){bo=c[bm>>2]|0;if((bo|0)==0){F=318;break}if((da(15248,c[bo>>2]|0)|0)==0){F=313;break}else{bm=bo+8|0}}L259:do{if((F|0)==313){F=0;ay=c[bo+4>>2]|0;if((ay|0)==0){F=318;break}else{bp=64;bq=af;br=ay}while(1){ay=bp-1|0;if((ay|0)==0){break}au=a[br]|0;a[bq]=au;if(au<<24>>24==0){bs=ax;break L259}else{bp=ay;bq=bq+1|0;br=br+1|0}}a[bq]=0;if((a[br]|0)==0){bs=ax;break}else{bt=br}while(1){ay=bt+1|0;if((a[ay]|0)==0){bs=ax;break}else{bt=ay}}}}while(0);if((F|0)==318){F=0;a[af]=0;bs=ax}while(1){bu=c[bs>>2]|0;if((bu|0)==0){F=326;break}if((da(15064,c[bu>>2]|0)|0)==0){F=321;break}else{bs=bu+8|0}}L272:do{if((F|0)==321){F=0;ay=c[bu+4>>2]|0;if((ay|0)==0){F=326;break}else{bv=64;bw=ag;bx=ay}while(1){ay=bv-1|0;if((ay|0)==0){break}au=a[bx]|0;a[bw]=au;if(au<<24>>24==0){by=ax;break L272}else{bv=ay;bw=bw+1|0;bx=bx+1|0}}a[bw]=0;if((a[bx]|0)==0){by=ax;break}else{bz=bx}while(1){ay=bz+1|0;if((a[ay]|0)==0){by=ax;break}else{bz=ay}}}}while(0);if((F|0)==326){F=0;a[ag]=0;by=ax}while(1){bA=c[by>>2]|0;if((bA|0)==0){F=334;break}if((da(14872,c[bA>>2]|0)|0)==0){F=329;break}else{by=bA+8|0}}L285:do{if((F|0)==329){F=0;ax=c[bA+4>>2]|0;if((ax|0)==0){F=334;break}else{bB=64;bC=ah;bD=ax}while(1){ax=bB-1|0;if((ax|0)==0){break}ay=a[bD]|0;a[bC]=ay;if(ay<<24>>24==0){break L285}else{bB=ax;bC=bC+1|0;bD=bD+1|0}}a[bC]=0;if((a[bD]|0)==0){break}else{bE=bD}do{bE=bE+1|0;}while((a[bE]|0)!=0)}}while(0);if((F|0)==334){F=0;a[ah]=0}if((a[W]|0)==0){F=337;break L109}if((a[aB]|0)==0){F=337;break L109}do{if((da(W|0,22048)|0)==0){c[z+99796+(az*80|0)+68>>2]=0;F=351}else{if((da(W|0,20432)|0)==0){c[z+99796+(az*80|0)+68>>2]=1;F=351;break}if((da(W|0,21456)|0)==0){c[z+99796+(az*80|0)+68>>2]=2;F=351;break}if((da(W|0,20816)|0)==0){c[z+99796+(az*80|0)+68>>2]=3;F=351;break}if((da(W|0,19992)|0)==0){c[z+99796+(az*80|0)+68>>2]=4;F=351;break}if((da(W|0,19840)|0)!=0){F=349;break L109}c[z+99796+(az*80|0)+68>>2]=5}}while(0);do{if((F|0)==351){F=0;if((a[af]|0)==0){if((a[ae]|0)==0){F=358;break L109}c[z+99796+(az*80|0)+64>>2]=a4(ae|0,0,16)|0;c[z+99796+(az*80|0)+72>>2]=1;break}aB=a4(af|0,0,0)|0;if((aB|0)==1){c[z+99796+(az*80|0)+72>>2]=2;break}else if((aB|0)==2){c[z+99796+(az*80|0)+72>>2]=3;break}else{F=355;break L109}}}while(0);if((a[ag]|0)!=0){b[z+99796+(az*80|0)+76>>1]=(a4(ag|0,0,16)|0)&65535}if((a[ah]|0)!=0){b[z+99796+(az*80|0)+78>>1]=(a4(ah|0,0,16)|0)&65535}c[aq>>2]=(c[aq>>2]|0)+1;break}if((a[G]&1)!=0){if((c[z+76+(av*4148|0)+4096>>2]|0)==0){F=89;break L109}}aB=iW(aw,d,at)|0;if((aB|0)==0){F=91;break L109}c[z+76+(av*4148|0)+4100>>2]=aB;aB=z+76+(av*4148|0)+4144|0;c[aB>>2]=0;ax=z+76+(av*4148|0)+4136|0;c[ax>>2]=0;ay=z+76+(av*4148|0)+4132|0;a[ay]=0;au=z+76+(av*4148|0)+4116|0;g[au>>2]=1.0;aG=z+76+(av*4148|0)+4120|0;g[aG>>2]=1.0;aA=z+76+(av*4148|0)+4112|0;c[aA>>2]=0;aM=z+76+(av*4148|0)+4108|0;c[aM>>2]=0;bF=z+76+(av*4148|0)+4104|0;a[bF]=0;bG=at+8|0;bH=bG;while(1){bI=c[bH>>2]|0;if((bI|0)==0){F=96;break}if((da(13184,c[bI>>2]|0)|0)==0){F=95;break}else{bH=bI+8|0}}do{if((F|0)==95){F=0;bH=c[bI+4>>2]|0;if((bH|0)==0){F=96;break}else{bJ=64;bK=0;bL=W;bN=bH}while(1){bH=bJ-1|0;if((bH|0)==0){F=99;break}az=a[bN]|0;a[bL]=az;if(az<<24>>24==0){bO=bK;break}else{bJ=bH;bK=bK+1|0;bL=bL+1|0;bN=bN+1|0}}do{if((F|0)==99){F=0;a[bL]=0;if((a[bN]|0)==0){bO=bK;break}else{bP=bN;bQ=bK}while(1){bH=bP+1|0;az=bQ+1|0;if((a[bH]|0)==0){bO=az;break}else{bP=bH;bQ=az}}}}while(0);if(bO>>>0>=64){bR=bG;F=109;break}if((da(W|0,12416)|0)==0){c[ax>>2]=2;if((a[383584]&1)==0){bR=bG;F=109;break}az=c[135158]|0;bH=(az|0)!=0?az:c[t>>2]|0;be(11744,42,1,bH|0)|0;bH=c[135158]|0;az=(bH|0)!=0?bH:c[t>>2]|0;a7(az|0)|0;bR=bG;F=109;break}if((da(W|0,12600)|0)!=0){az=c[135158]|0;bH=(az|0)!=0?az:c[t>>2]|0;be(11392,54,1,bH|0)|0;bH=c[135158]|0;az=(bH|0)!=0?bH:c[t>>2]|0;a7(az|0)|0;bS=0;break}c[ax>>2]=1;if((a[383584]&1)==0){bR=bG;F=109;break}az=c[135158]|0;be(11560,41,1,((az|0)!=0?az:c[t>>2]|0)|0)|0;az=c[135158]|0;a7(((az|0)!=0?az:c[t>>2]|0)|0)|0;bR=bG;F=109}}while(0);if((F|0)==96){F=0;a[W]=0;bR=bG;F=109}do{if((F|0)==109){while(1){F=0;bT=c[bR>>2]|0;if((bT|0)==0){F=116;break}if((da(11312,c[bT>>2]|0)|0)==0){F=111;break}else{bR=bT+8|0;F=109}}L363:do{if((F|0)==111){F=0;ax=c[bT+4>>2]|0;if((ax|0)==0){F=116;break}else{bU=64;bV=ae;bW=ax}while(1){ax=bU-1|0;if((ax|0)==0){break}az=a[bW]|0;a[bV]=az;if(az<<24>>24==0){bX=bG;break L363}else{bU=ax;bV=bV+1|0;bW=bW+1|0}}a[bV]=0;if((a[bW]|0)==0){bX=bG;break}else{bY=bW}while(1){ax=bY+1|0;if((a[ax]|0)==0){bX=bG;break}else{bY=ax}}}}while(0);if((F|0)==116){F=0;a[ae]=0;bX=bG}while(1){bZ=c[bX>>2]|0;if((bZ|0)==0){F=124;break}if((da(11176,c[bZ>>2]|0)|0)==0){F=119;break}else{bX=bZ+8|0}}L376:do{if((F|0)==119){F=0;ax=c[bZ+4>>2]|0;if((ax|0)==0){F=124;break}else{b_=64;b$=af;b0=ax}while(1){ax=b_-1|0;if((ax|0)==0){break}az=a[b0]|0;a[b$]=az;if(az<<24>>24==0){b1=bG;break L376}else{b_=ax;b$=b$+1|0;b0=b0+1|0}}a[b$]=0;if((a[b0]|0)==0){b1=bG;break}else{b2=b0}while(1){ax=b2+1|0;if((a[ax]|0)==0){b1=bG;break}else{b2=ax}}}}while(0);if((F|0)==124){F=0;a[af]=0;b1=bG}while(1){b3=c[b1>>2]|0;if((b3|0)==0){F=132;break}if((da(11056,c[b3>>2]|0)|0)==0){F=127;break}else{b1=b3+8|0}}L389:do{if((F|0)==127){F=0;ax=c[b3+4>>2]|0;if((ax|0)==0){F=132;break}else{b4=64;b5=ag;b6=ax}while(1){ax=b4-1|0;if((ax|0)==0){break}az=a[b6]|0;a[b5]=az;if(az<<24>>24==0){b7=bG;break L389}else{b4=ax;b5=b5+1|0;b6=b6+1|0}}a[b5]=0;if((a[b6]|0)==0){b7=bG;break}else{b8=b6}while(1){ax=b8+1|0;if((a[ax]|0)==0){b7=bG;break}else{b8=ax}}}}while(0);if((F|0)==132){F=0;a[ag]=0;b7=bG}while(1){b9=c[b7>>2]|0;if((b9|0)==0){F=140;break}if((da(10912,c[b9>>2]|0)|0)==0){F=135;break}else{b7=b9+8|0}}L402:do{if((F|0)==135){F=0;ax=c[b9+4>>2]|0;if((ax|0)==0){F=140;break}else{ca=64;cb=ah;cc=ax}while(1){ax=ca-1|0;if((ax|0)==0){break}az=a[cc]|0;a[cb]=az;if(az<<24>>24==0){cd=bG;break L402}else{ca=ax;cb=cb+1|0;cc=cc+1|0}}a[cb]=0;if((a[cc]|0)==0){cd=bG;break}else{ce=cc}while(1){ax=ce+1|0;if((a[ax]|0)==0){cd=bG;break}else{ce=ax}}}}while(0);if((F|0)==140){F=0;a[ah]=0;cd=bG}while(1){cf=c[cd>>2]|0;if((cf|0)==0){F=148;break}if((da(52736,c[cf>>2]|0)|0)==0){F=143;break}else{cd=cf+8|0}}L415:do{if((F|0)==143){F=0;ax=c[cf+4>>2]|0;if((ax|0)==0){F=148;break}else{cg=64;ch=ai;ci=ax}while(1){ax=cg-1|0;if((ax|0)==0){break}az=a[ci]|0;a[ch]=az;if(az<<24>>24==0){cj=bG;break L415}else{cg=ax;ch=ch+1|0;ci=ci+1|0}}a[ch]=0;if((a[ci]|0)==0){cj=bG;break}else{ck=ci}while(1){ax=ck+1|0;if((a[ax]|0)==0){cj=bG;break}else{ck=ax}}}}while(0);if((F|0)==148){F=0;a[ai]=0;cj=bG}while(1){cl=c[cj>>2]|0;if((cl|0)==0){F=156;break}if((da(52560,c[cl>>2]|0)|0)==0){F=151;break}else{cj=cl+8|0}}L428:do{if((F|0)==151){F=0;ax=c[cl+4>>2]|0;if((ax|0)==0){F=156;break}else{cm=64;cn=aj;co=ax}while(1){ax=cm-1|0;if((ax|0)==0){break}az=a[co]|0;a[cn]=az;if(az<<24>>24==0){cp=bG;break L428}else{cm=ax;cn=cn+1|0;co=co+1|0}}a[cn]=0;if((a[co]|0)==0){cp=bG;break}else{cq=co}while(1){ax=cq+1|0;if((a[ax]|0)==0){cp=bG;break}else{cq=ax}}}}while(0);if((F|0)==156){F=0;a[aj]=0;cp=bG}while(1){cr=c[cp>>2]|0;if((cr|0)==0){F=164;break}if((da(52024,c[cr>>2]|0)|0)==0){F=159;break}else{cp=cr+8|0}}L441:do{if((F|0)==159){F=0;ax=c[cr+4>>2]|0;if((ax|0)==0){F=164;break}else{cs=64;ct=ak;cu=ax}while(1){ax=cs-1|0;if((ax|0)==0){break}az=a[cu]|0;a[ct]=az;if(az<<24>>24==0){cv=bG;break L441}else{cs=ax;ct=ct+1|0;cu=cu+1|0}}a[ct]=0;if((a[cu]|0)==0){cv=bG;break}else{cw=cu}while(1){ax=cw+1|0;if((a[ax]|0)==0){cv=bG;break}else{cw=ax}}}}while(0);if((F|0)==164){F=0;a[ak]=0;cv=bG}while(1){cx=c[cv>>2]|0;if((cx|0)==0){F=172;break}if((da(51896,c[cx>>2]|0)|0)==0){F=167;break}else{cv=cx+8|0}}L454:do{if((F|0)==167){F=0;ax=c[cx+4>>2]|0;if((ax|0)==0){F=172;break}else{cy=64;cz=al;cA=ax}while(1){ax=cy-1|0;if((ax|0)==0){break}az=a[cA]|0;a[cz]=az;if(az<<24>>24==0){cB=bG;break L454}else{cy=ax;cz=cz+1|0;cA=cA+1|0}}a[cz]=0;if((a[cA]|0)==0){cB=bG;break}else{cC=cA}while(1){ax=cC+1|0;if((a[ax]|0)==0){cB=bG;break}else{cC=ax}}}}while(0);if((F|0)==172){F=0;a[al]=0;cB=bG}while(1){cE=c[cB>>2]|0;if((cE|0)==0){F=180;break}if((da(51744,c[cE>>2]|0)|0)==0){F=175;break}else{cB=cE+8|0}}L467:do{if((F|0)==175){F=0;ax=c[cE+4>>2]|0;if((ax|0)==0){F=180;break}else{cF=64;cG=am;cH=ax}while(1){ax=cF-1|0;if((ax|0)==0){break}az=a[cH]|0;a[cG]=az;if(az<<24>>24==0){cI=bG;break L467}else{cF=ax;cG=cG+1|0;cH=cH+1|0}}a[cG]=0;if((a[cH]|0)==0){cI=bG;break}else{cJ=cH}while(1){ax=cJ+1|0;if((a[ax]|0)==0){cI=bG;break}else{cJ=ax}}}}while(0);if((F|0)==180){F=0;a[am]=0;cI=bG}while(1){cK=c[cI>>2]|0;if((cK|0)==0){F=188;break}if((da(51576,c[cK>>2]|0)|0)==0){F=183;break}else{cI=cK+8|0}}L480:do{if((F|0)==183){F=0;ax=c[cK+4>>2]|0;if((ax|0)==0){F=188;break}else{cL=64;cM=an;cN=ax}while(1){ax=cL-1|0;if((ax|0)==0){break}az=a[cN]|0;a[cM]=az;if(az<<24>>24==0){cO=bG;break L480}else{cL=ax;cM=cM+1|0;cN=cN+1|0}}a[cM]=0;if((a[cN]|0)==0){cO=bG;break}else{cP=cN}while(1){ax=cP+1|0;if((a[ax]|0)==0){cO=bG;break}else{cP=ax}}}}while(0);if((F|0)==188){F=0;a[an]=0;cO=bG}while(1){cQ=c[cO>>2]|0;if((cQ|0)==0){F=196;break}if((da(51408,c[cQ>>2]|0)|0)==0){F=191;break}else{cO=cQ+8|0}}L493:do{if((F|0)==191){F=0;ax=c[cQ+4>>2]|0;if((ax|0)==0){F=196;break}else{cR=64;cS=ao;cT=ax}while(1){ax=cR-1|0;if((ax|0)==0){break}az=a[cT]|0;a[cS]=az;if(az<<24>>24==0){break L493}else{cR=ax;cS=cS+1|0;cT=cT+1|0}}a[cS]=0;if((a[cT]|0)==0){break}else{cU=cT}do{cU=cU+1|0;}while((a[cU]|0)!=0)}}while(0);if((F|0)==196){F=0;a[ao]=0}a[ay]=(da(ao|0,51224)|0)==0|0;do{if((a[an]|0)!=0){ax=a4(an|0,0,0)|0;c[aB>>2]=ax;if((a[383584]&1)==0){break}az=c[135158]|0;bH=(az|0)!=0?az:c[t>>2]|0;eQ(bH|0,51064,(I=i,i=i+8|0,c[I>>2]=ax,I)|0)|0;i=I;ax=c[135158]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}}while(0);do{if((a[ae]|0)==0){cV=0}else{cW=+sY(ae,0);g[au>>2]=cW;g[aG>>2]=cW;a[bF]=1;if((a[383584]&1)==0){cV=1;break}bH=c[135158]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cX=cW;eQ(ax|0,50640,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[135158]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0;cV=1}}while(0);if((a[af]|0)==0){cY=cV}else{cX=+sY(af,0);g[au>>2]=cX;a[bF]=1;if((a[383584]&1)!=0){bH=c[135158]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cW=cX;eQ(ax|0,50424,(I=i,i=i+8|0,h[I>>3]=cW,I)|0)|0;i=I;ax=c[135158]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}cY=cV+1|0}if((a[ag]|0)==0){cZ=cV}else{cW=+sY(ag,0);g[aG>>2]=cW;a[bF]=1;if((a[383584]&1)!=0){bH=c[135158]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cX=cW;eQ(ax|0,50104,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[135158]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}cZ=cV+1|0}if((a[ah]|0)==0){c_=cY;c$=cZ}else{bH=a4(ah|0,0,0)|0;c[z+76+(av*4148|0)+4128>>2]=bH;c[z+76+(av*4148|0)+4124>>2]=bH;a[bF]=1;c[aA>>2]=1;c[aM>>2]=1;if((a[383584]&1)!=0){ax=c[135158]|0;az=(ax|0)!=0?ax:c[t>>2]|0;eQ(az|0,49528,(I=i,i=i+8|0,c[I>>2]=bH,I)|0)|0;i=I;bH=c[135158]|0;az=(bH|0)!=0?bH:c[t>>2]|0;a7(az|0)|0}c_=cY+1|0;c$=cZ+1|0}if((a[ai]|0)==0){c0=c_}else{az=a4(ai|0,0,0)|0;c[z+76+(av*4148|0)+4124>>2]=az;a[bF]=1;c[aM>>2]=1;if((a[383584]&1)!=0){bH=c[135158]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;eQ(ax|0,49240,(I=i,i=i+8|0,c[I>>2]=az,I)|0)|0;i=I;az=c[135158]|0;ax=(az|0)!=0?az:c[t>>2]|0;a7(ax|0)|0}c0=c_+1|0}if((a[aj]|0)==0){c1=c$}else{ax=a4(aj|0,0,0)|0;c[z+76+(av*4148|0)+4128>>2]=ax;a[bF]=1;c[aA>>2]=1;if((a[383584]&1)!=0){az=c[135158]|0;bH=(az|0)!=0?az:c[t>>2]|0;eQ(bH|0,48968,(I=i,i=i+8|0,c[I>>2]=ax,I)|0)|0;i=I;ax=c[135158]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}c1=c$+1|0}if((a[ak]|0)==0){c2=c0;c3=c1}else{cX=+sY(ak,0);g[aG>>2]=cX;g[au>>2]=cX;a[bF]=1;c[aA>>2]=2;c[aM>>2]=2;if((a[383584]&1)!=0){bH=c[135158]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cW=cX;eQ(ax|0,48696,(I=i,i=i+8|0,h[I>>3]=cW,I)|0)|0;i=I;ax=c[135158]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}c2=c0+1|0;c3=c1+1|0}if((a[al]|0)==0){c4=c2}else{cW=+sY(al,0);g[au>>2]=cW;a[bF]=1;c[aM>>2]=2;if((a[383584]&1)!=0){bH=c[135158]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cX=cW;eQ(ax|0,48600,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[135158]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}c4=c2+1|0}if((a[am]|0)==0){c5=c3}else{cX=+sY(am,0);g[aG>>2]=cX;a[bF]=1;c[aA>>2]=2;if((a[383584]&1)!=0){bH=c[135158]|0;ax=(bH|0)!=0?bH:c[t>>2]|0;cW=cX;eQ(ax|0,48352,(I=i,i=i+8|0,h[I>>3]=cW,I)|0)|0;i=I;ax=c[135158]|0;bH=(ax|0)!=0?ax:c[t>>2]|0;a7(bH|0)|0}c5=c3+1|0}if(c4>>>0>1){bS=0;break}bS=c5>>>0<2}}while(0);if(!bS){F=238;break L109}c[aa>>2]=(c[aa>>2]|0)+1}}while(0);aA=c[at+16>>2]|0;if((aA|0)==0){F=394;break L107}else{at=aA}}if((F|0)==82){at=c[135158]|0;am=(at|0)!=0?at:c[t>>2]|0;be(42280,75,1,am|0)|0;am=c[135158]|0;at=(am|0)!=0?am:c[t>>2]|0;a7(at|0)|0;sS(aw);break L46}else if((F|0)==84){at=c[135158]|0;be(40304,74,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;break L46}else if((F|0)==89){at=c[135158]|0;be(38400,98,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;sS(aw);break L46}else if((F|0)==91){at=c[135158]|0;be(40304,74,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;break L46}else if((F|0)==238){at=c[135158]|0;be(37192,78,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;break L46}else if((F|0)==271){at=c[135158]|0;be(13016,51,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=282}else if((F|0)==273){at=c[135158]|0;be(12752,57,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=282}else if((F|0)==280){at=c[135158]|0;be(11928,46,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=282}else if((F|0)==285){at=c[135158]|0;be(15848,51,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=364}else if((F|0)==337){at=c[135158]|0;be(14656,57,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=364}else if((F|0)==349){at=c[135158]|0;be(14152,56,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=364}else if((F|0)==355){at=c[135158]|0;be(13936,52,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=364}else if((F|0)==358){at=c[135158]|0;be(13592,65,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=364}else if((F|0)==367){at=c[135158]|0;be(17e3,46,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=392}else if((F|0)==386){at=c[135158]|0;be(16352,52,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=392}else if((F|0)==388){c[ar>>2]=0;F=392}else if((F|0)==391){at=c[135158]|0;be(16112,48,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;F=392}if((F|0)==282){at=c[135158]|0;am=(at|0)!=0?at:c[t>>2]|0;be(33904,51,1,am|0)|0;am=c[135158]|0;at=(am|0)!=0?am:c[t>>2]|0;a7(at|0)|0;break L46}else if((F|0)==364){at=c[135158]|0;be(32208,46,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;break L46}else if((F|0)==392){at=c[135158]|0;be(30800,40,1,((at|0)!=0?at:c[t>>2]|0)|0)|0;at=c[135158]|0;a7(((at|0)!=0?at:c[t>>2]|0)|0)|0;break L46}}}while(0);do{if((F|0)==394){if((c[aa>>2]|0)!=0){break}G=c[135158]|0;P=(G|0)!=0?G:c[t>>2]|0;be(30392,82,1,P|0)|0;P=c[135158]|0;G=(P|0)!=0?P:c[t>>2]|0;a7(G|0)|0;break L46}}while(0);aa=c[E>>2]|0;if((aa|0)!=0){im(aa)}sS(D);break L26}else{aa=c[135158]|0;eQ(((aa|0)!=0?aa:c[t>>2]|0)|0,21160,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;aa=c[135158]|0;a7(((aa|0)!=0?aa:c[t>>2]|0)|0)|0}}while(0);C=c[135158]|0;aa=(C|0)!=0?C:c[t>>2]|0;be(29968,51,1,aa|0)|0;aa=c[135158]|0;C=(aa|0)!=0?aa:c[t>>2]|0;a7(C|0)|0;if(!B){break}C=c[D>>2]|0;if((C|0)!=0){im(C)}sS(D)}}while(0);A=c[135158]|0;C=(A|0)!=0?A:c[t>>2]|0;be(35824,56,1,C|0)|0;C=c[135158]|0;A=(C|0)!=0?C:c[t>>2]|0;a7(A|0)|0;y=0;i=e;return y|0}}while(0);iY(c[68254]|0,d);d=(a[273048]&1)==0;L602:do{if((a[(c[68254]|0)+4|0]&1)==0){aw=c[135158]|0;bS=(aw|0)!=0?aw:c[t>>2]|0;be(24096,90,1,bS|0)|0;bS=c[135158]|0;aw=(bS|0)!=0?bS:c[t>>2]|0;a7(aw|0)|0}else{aw=kn(d?20576:20216,d?21760:21232,0)|0;c[70114]=aw;if((aw|0)==0){aw=c[135158]|0;bS=(aw|0)!=0?aw:c[t>>2]|0;be(21e3,60,1,bS|0)|0;bS=c[135158]|0;aw=(bS|0)!=0?bS:c[t>>2]|0;a7(aw|0)|0;break}else{c6=0}while(1){c7=c[68254]|0;if(c6>>>0>=(c[c7+72>>2]|0)>>>0){F=418;break}c8=c7+76+(c6*4148|0)|0;aw=c7+76+(c6*4148|0)+4096|0;if((a[c8]|0)==0){c9=c[aw>>2]|0;db=c[c7+76+(c6*4148|0)+4100>>2]|0}else{if((g8(c8,aw)|0)<1){F=415;break}bS=dT(c[aw>>2]|0)|0;c[c7+76+(c6*4148|0)+4100>>2]=bS;if((bS|0)==0){F=415;break}c5=c[aw>>2]|0;if((c5|0)==0){F=415;break}else{c9=c5;db=bS}}a[c8]=0;bS=kn(c9,db,c6)|0;c5=c6+1|0;c[280456+(c5<<2)>>2]=bS;if((bS|0)==0){F=417;break}else{c6=c5}}if((F|0)==415){c5=c[135158]|0;bS=(c5|0)!=0?c5:c[t>>2]|0;eQ(bS|0,27912,(I=i,i=i+8|0,c[I>>2]=c8,I)|0)|0;i=I;bS=c[135158]|0;c5=(bS|0)!=0?bS:c[t>>2]|0;a7(c5|0)|0;break}else if((F|0)==417){c5=c[135158]|0;eQ(((c5|0)!=0?c5:c[t>>2]|0)|0,27560,(I=i,i=i+8|0,c[I>>2]=c6,I)|0)|0;i=I;c5=c[135158]|0;a7(((c5|0)!=0?c5:c[t>>2]|0)|0)|0;break}else if((F|0)==418){c5=w;L620:do{if((c[c7+66444>>2]|0)==0){dc=0}else{bM(1,280416);bS=c[68254]|0;if((c[bS+66444>>2]|0)==0){dc=0;break}aw=w|0;c4=w+4|0;c3=w+8|0;c2=0;c1=bS;while(1){if((a[383584]&1)==0){dd=c1}else{bS=c[135158]|0;c0=(bS|0)!=0?bS:c[t>>2]|0;bS=c1+66448+(c2*4168|0)+64|0;eQ(c0|0,29080,(I=i,i=i+8|0,c[I>>2]=bS,I)|0)|0;i=I;bS=c[135158]|0;c0=(bS|0)!=0?bS:c[t>>2]|0;a7(c0|0)|0;dd=c[68254]|0}s_(c5|0,0,12);c0=dd+66448+(c2*4168|0)+64|0;if((a[547628]&1)==0){if(!(i2(c0,w,16,0)|0)){break}}else{if(!(i2(c0,w,0,16)|0)){break}}a6(3553,c[280416+(c2<<2)>>2]|0);fI(3553,10242,33071);fI(3553,10243,33071);c0=(c[(c[68254]|0)+66448+(c2*4168|0)+4160>>2]|0)==2?9728:9729;fI(3553,10240,c0|0);fI(3553,10241,c0|0);fS(3317,4);c0=(a[547628]&1)!=0?6408:32993;bS=c[c3>>2]|0;eG(3553,0,c0|0,c[aw>>2]|0,c[c4>>2]|0,0,c0|0,5121,bS|0);a6(3553,0);sS(bS);bS=c2+1|0;c0=c[68254]|0;if(bS>>>0<(c[c0+66444>>2]|0)>>>0){c2=bS;c1=c0}else{dc=0;break L620}}c1=c[135158]|0;eQ(((c1|0)!=0?c1:c[t>>2]|0)|0,28360,(I=i,i=i+8|0,c[I>>2]=(c[68254]|0)+66448+(c2*4168|0)+64,I)|0)|0;i=I;c1=c[135158]|0;a7(((c1|0)!=0?c1:c[t>>2]|0)|0)|0;c1=c[135158]|0;be(18696,48,1,((c1|0)!=0?c1:c[t>>2]|0)|0)|0;c1=c[135158]|0;a7(((c1|0)!=0?c1:c[t>>2]|0)|0)|0;break L602}}while(0);do{ko(dc,c[280456+(dc<<2)>>2]|0,273056+(dc*460|0)|0);dc=dc+1|0;de=c[68254]|0;}while(dc>>>0<=(c[de+72>>2]|0)>>>0);do{if((c[de+99792>>2]|0)!=0){c5=f2[c[16072]&255](2)|0;c1=c[68254]|0;c4=c[c1+99792>>2]|0;aw=sR(12)|0;if((aw|0)==0){c[70112]=0}else{if((c[aw-4>>2]&3|0)!=0){s_(aw|0,0,12)}c3=aw;D=(c4|0)==0;do{if(D){df=0}else{B=c4*112|0;if(c4>>>0<=65535){df=B;break}df=((B>>>0)/(c4>>>0)|0|0)==112?B:-1}}while(0);c2=sR(df)|0;do{if((c2|0)!=0){if((c[c2-4>>2]&3|0)==0){break}s_(c2|0,0,df|0)}}while(0);B=c2;c0=aw;c[c0>>2]=B;c[aw+4>>2]=c4;L652:do{if(!D){bS=aw+8|0;c$=aw+10|0;z=(c5|0)==0?62808:c5;c_=0;cZ=B;while(1){cY=64;cV=cZ+(c_*112|0)|0;cU=c1+99796+(c_*80|0)|0;while(1){cT=cY-1|0;if((cT|0)==0){F=445;break}cS=a[cU]|0;a[cV]=cS;if(cS<<24>>24==0){break}else{cY=cT;cV=cV+1|0;cU=cU+1|0}}do{if((F|0)==445){F=0;a[cV]=0;if((a[cU]|0)==0){break}else{dg=cU}do{dg=dg+1|0;}while((a[dg]|0)!=0)}}while(0);c[(c[c0>>2]|0)+(c_*112|0)+76>>2]=c[c1+99796+(c_*80|0)+64>>2];c[(c[c0>>2]|0)+(c_*112|0)+84>>2]=c[c1+99796+(c_*80|0)+68>>2];cU=b[c1+99796+(c_*80|0)+76>>1]|0;b[(c[c0>>2]|0)+(c_*112|0)+80>>1]=cU<<16>>16==0?-1:cU;b[(c[c0>>2]|0)+(c_*112|0)+82>>1]=b[c1+99796+(c_*80|0)+78>>1]|0;cU=c[c1+99796+(c_*80|0)+72>>2]|0;if((cU|0)==1){c[(c[c0>>2]|0)+(c_*112|0)+72>>2]=z}else if((cU|0)==2){c[(c[c0>>2]|0)+(c_*112|0)+68>>2]=bS;a[(c[c0>>2]|0)+(c_*112|0)+64|0]=1}else if((cU|0)==3){c[(c[c0>>2]|0)+(c_*112|0)+68>>2]=c$;a[(c[c0>>2]|0)+(c_*112|0)+64|0]=1}else{c[(c[c0>>2]|0)+(c_*112|0)+72>>2]=62808}cU=c_+1|0;if(cU>>>0>=c4>>>0){break L652}c_=cU;cZ=c[c0>>2]|0}}}while(0);c[70112]=c3;if((aw|0)!=0){break}}c0=c[135158]|0;c4=(c0|0)!=0?c0:c[t>>2]|0;be(16496,50,1,c4|0)|0;c4=c[135158]|0;c0=(c4|0)!=0?c4:c[t>>2]|0;a7(c0|0)|0}}while(0);a[7856]=1;c0=c[68254]|0;c4=c0+72|0;c[280456+((c[c4>>2]|0)+1<<2)>>2]=c[70114];c1=273056+(((c[c4>>2]|0)+1|0)*460|0)|0;s1(c1|0,273056,460)|0;if((a[c0+4|0]&1)==0){c[70129]=c[70114];s1(279956,273056,460)|0}else{c0=(a[273048]&1)!=0;c1=kn(c0?49664:52120,c0?12104:14312,15)|0;c[70129]=c1;ko(0,c1,279956)}if((c[70288]|0)!=0){c1=0;do{ds(c[281040+(c1<<2)>>2]|0);c1=c1+1|0;}while(c1>>>0<(c[70288]|0)>>>0)}c[70288]=0;c1=0;while(1){e7(1,256376+(c1*1040|0)|0);e7(1,256896+(c1*1040|0)|0);c0=c1+1|0;if(c0>>>0<16){c1=c0}else{y=1;break}}i=e;return y|0}}}while(0);kc();y=0;i=e;return y|0}function kc(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;eE(0);f=e;g=e;h=0;do{j=c[280456+(h<<2)>>2]|0;do{if((j|0)!=0){if((h|0)!=0&(j|0)==(c[70114]|0)){break}c[e>>2]=0;c[e+4>>2]=0;cj(j|0,2,d|0,g|0);if((c[d>>2]|0)>0){k=0;do{l=f+(k<<2)|0;df(j|0,c[l>>2]|0);by(c[l>>2]|0);k=k+1|0;}while((k|0)<(c[d>>2]|0))}cy(j|0)}}while(0);h=h+1|0;}while(h>>>0<16);h=c[68254]|0;do{if((h|0)==0){m=0}else{d=c[h+66444>>2]|0;if((d|0)==0){m=h;break}br(d|0,280416);m=c[68254]|0}}while(0);s_(280456,0,64);s_(273056,0,7360);a[7856]=0;c[136966]=0;if((m|0)!=0){if((c[m+72>>2]|0)==0){n=m}else{h=0;d=m;while(1){sS(c[d+76+(h*4148|0)+4096>>2]|0);sS(c[(c[68254]|0)+76+(h*4148|0)+4100>>2]|0);m=h+1|0;f=c[68254]|0;if(m>>>0<(c[f+72>>2]|0)>>>0){h=m;d=f}else{n=f;break}}}sS(c[n+109012>>2]|0);sS(c[68254]|0);c[68254]=0}n=c[70112]|0;if((n|0)!=0){sS(c[n>>2]|0);sS(n)}c[70112]=0;if((c[70288]|0)!=0){n=0;do{ds(c[281040+(n<<2)>>2]|0);n=n+1|0;}while(n>>>0<(c[70288]|0)>>>0)}c[70288]=0;n=0;do{d=256376+(n*1040|0)|0;if((c[d>>2]|0)!=0){fM(1,d|0)}d=256896+(n*1040|0)|0;if((c[d>>2]|0)!=0){fM(1,d|0)}n=n+1|0;}while(n>>>0<16);s_(256376,0,16640);i=b;return}function kd(){return c[(c[68254]|0)+72>>2]|0}function ke(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==0|a[7856]^1){e=0;return e|0}f=c[(c[68254]|0)+76+((b-1|0)*4148|0)+4136>>2]|0;if((f|0)==0){e=0;return e|0}a[d]=(f|0)==1|0;e=1;return e|0}function kf(b){b=b|0;var d=0;if((b|0)==0|a[7856]^1){d=0;return d|0}d=c[(c[68254]|0)+76+((b-1|0)*4148|0)+4140>>2]|0;return d|0}function kg(e,f,h,j,k,l,m,n,o,p,q){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;r=i;i=i+920|0;s=r|0;t=r+512|0;u=r+896|0;v=r+904|0;w=r+912|0;if(!(a[7856]|0)){i=r;return}x=c[136966]|0;if((c[280456+(x<<2)>>2]|0)==0){i=r;return}y=t|0;z=u|0;g[z>>2]=+(e>>>0>>>0);g[u+4>>2]=+(f>>>0>>>0);f=v|0;g[f>>2]=+(k>>>0>>>0);g[v+4>>2]=+(l>>>0>>>0);l=w|0;g[l>>2]=+(h>>>0>>>0);g[w+4>>2]=+(j>>>0>>>0);j=c[273076+(x*460|0)>>2]|0;if((j|0)>-1){bj(j|0,1,z|0)}z=c[273080+(x*460|0)>>2]|0;if((z|0)>-1){bj(z|0,1,f|0)}f=c[273084+(x*460|0)>>2]|0;if((f|0)>-1){bj(f|0,1,l|0)}l=c[273088+(x*460|0)>>2]|0;f=c[136966]|0;if((l|0)>-1&(f|0)!=0){z=c[(c[68254]|0)+76+((f-1|0)*4148|0)+4144>>2]|0;if((z|0)==0){A=m}else{A=(m>>>0)%(z>>>0)|0}b_(l|0,A|0);B=A}else{B=m}m=c[273096+(x*460|0)>>2]|0;if((m|0)>-1){b_(m|0,((a[532128]&1)!=0?-1:1)|0)}m=c[68254]|0;if((c[m+66444>>2]|0)==0){D=0}else{A=0;l=m;while(1){m=273100+(x*460|0)+(A<<2)|0;if((c[m>>2]|0)>-1){c7(A+33985|0);a6(3553,c[280416+(A<<2)>>2]|0);z=A+1|0;b_(c[m>>2]|0,z|0);E=c[68254]|0;F=z}else{E=l;F=A+1|0}z=c[E+66444>>2]|0;if(F>>>0<z>>>0){A=F;l=E}else{D=z;break}}}E=D+1|0;do{if((c[136966]|0)>>>0>1){l=273132+(x*460|0)|0;if((c[l>>2]|0)>-1){c7(D+33985|0);b_(c[l>>2]|0,E|0);a6(3553,c[n>>2]|0)}l=D+2|0;F=c[273140+(x*460|0)>>2]|0;if((F|0)>-1){bj(F|0,1,n+12|0)}F=c[273136+(x*460|0)>>2]|0;if((F|0)>-1){bj(F|0,1,n+4|0)}F=c[273144+(x*460|0)>>2]|0;if((F|0)>-1){c[t>>2]=F;c[t+4>>2]=2;c[t+8>>2]=0;F=t+12|0;A=s;z=n+20|0;s1(A|0,z|0,32)|0;G=8;H=1;I=F}else{G=0;H=0;I=y}if((q|0)==0){J=I;K=H;L=l;M=G;N=0;break}c7(q+33985+D|0);a6(3553,c[p+((q-1|0)*52|0)>>2]|0);F=I;z=H;A=l;l=0;m=G;while(1){f=c[273148+(x*460|0)+(l<<4)>>2]|0;if((f|0)!=0){b_(f|0,A|0)}f=c[273148+(x*460|0)+(l<<4)+8>>2]|0;if((f|0)>-1){bj(f|0,1,p+(l*52|0)+12|0)}f=c[273148+(x*460|0)+(l<<4)+4>>2]|0;if((f|0)>-1){bj(f|0,1,p+(l*52|0)+4|0)}f=c[273148+(x*460|0)+(l<<4)+12>>2]|0;if((f|0)>-1){c[F>>2]=f;c[F+4>>2]=2;c[F+8>>2]=m<<2;f=z+1|0;j=F+12|0;w=s+(m<<2)|0;h=p+(l*52|0)+20|0;s1(w|0,h|0,32)|0;O=m+8|0;P=f;Q=j}else{O=m;P=z;Q=F}j=l+1|0;if(j>>>0<q>>>0){F=Q;z=P;A=A+1|0;l=j;m=O}else{break}}J=Q;K=P;L=q+2+D|0;M=O;N=0}else{c7(D+33985|0);a6(3553,0);if((c[(c[68254]|0)+72>>2]|0)==0){J=y;K=0;L=E;M=0;N=0;break}m=D+33986|0;l=0;while(1){c7(m+l|0);a6(3553,0);A=l+1|0;if(A>>>0<(c[(c[68254]|0)+72>>2]|0)>>>0){l=A}else{J=y;K=0;L=E;M=0;N=0;break}}}}while(0);while(1){E=273404+(x*460|0)+(N<<4)|0;if((c[E>>2]|0)>-1){c7(L+33984|0);a6(3553,c[o+(N*52|0)>>2]|0);b_(c[E>>2]|0,L|0);R=L+1|0}else{R=L}E=c[273404+(x*460|0)+(N<<4)+8>>2]|0;if((E|0)>-1){bj(E|0,1,o+(N*52|0)+12|0)}E=c[273404+(x*460|0)+(N<<4)+4>>2]|0;if((E|0)>-1){bj(E|0,1,o+(N*52|0)+4|0)}E=c[273404+(x*460|0)+(N<<4)+12>>2]|0;if((E|0)>-1){c[J>>2]=E;c[J+4>>2]=2;c[J+8>>2]=M<<2;E=K+1|0;D=J+12|0;O=s+(M<<2)|0;q=o+(N*52|0)+20|0;s1(O|0,q|0,32)|0;S=M+8|0;T=E;U=D}else{S=M;T=K;U=J}D=N+1|0;if(D>>>0<7){J=U;K=T;L=R+1|0;M=S;N=D}else{break}}if((S|0)!=0){N=c[136966]|0;km(c[256896+(N*1040|0)>>2]|0,256900+(N*1040|0)|0,257412+(N*1040|0)|0,s|0,S,y,T)}c7(33984);T=c[70112]|0;if((T|0)==0){i=r;return}if((c[136966]|0)==1){y=c[T+4>>2]|0;S=y>>>0<64?y:64;y=c[136864]|0;if((y|0)!=0){s=4;N=0;M=0;R=y;while(1){y=c[200+(s-4<<2)>>2]|0;V=((f1[c[R+8>>2]&15](c[136867]|0,248,0,1,0,y)|0)<<16>>16!=0)<<s|N;W=((f1[c[(c[136864]|0)+8>>2]&15](c[136867]|0,248,1,1,0,y)|0)<<16>>16!=0)<<s|M;y=s+1|0;if(y>>>0>=16){break}s=y;N=V&65535;M=W&65535;R=c[136864]|0}R=T+8|0;C=W<<16|V&65535;b[R>>1]=C&65535;b[R+2>>1]=C>>16}L837:do{if((S|0)!=0){R=T|0;V=0;while(1){W=c[R>>2]|0;c[280520+(V<<3)>>2]=W+(V*112|0);switch(c[W+(V*112|0)+84>>2]|0){case 0:{if((a[W+(V*112|0)+64|0]&1)==0){X=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{X=b[c[W+(V*112|0)+68>>2]>>1]|0}M=b[W+(V*112|0)+80>>1]&X;N=b[W+(V*112|0)+82>>1]|0;g[280524+(V<<3)>>2]=N<<16>>16==0|M<<16>>16==N<<16>>16?+((M&65535)>>>0):0.0;break};case 1:{M=W+(V*112|0)+88|0;N=c[M>>2]|0;s=(a[W+(V*112|0)+64|0]&1)==0;if(s){Y=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{Y=b[c[W+(V*112|0)+68>>2]>>1]|0}y=b[W+(V*112|0)+80>>1]|0;L=y&Y;K=b[W+(V*112|0)+82>>1]|0;U=K<<16>>16==0;J=W+(V*112|0)+92|0;if((N|0)==((U|L<<16>>16==K<<16>>16?L&65535:0)|0)){Z=c[J>>2]|0}else{c[J>>2]=N;if(s){_=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{_=b[c[W+(V*112|0)+68>>2]>>1]|0}s=_&y;c[M>>2]=U|s<<16>>16==K<<16>>16?s&65535:0;Z=N}g[280524+(V<<3)>>2]=+(Z>>>0>>>0);break};case 2:{N=W+(V*112|0)+104|0;s=(a[W+(V*112|0)+64|0]&1)==0;if(s){$=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{$=b[c[W+(V*112|0)+68>>2]>>1]|0}K=b[W+(V*112|0)+80>>1]|0;U=K&$;M=b[W+(V*112|0)+82>>1]|0;y=M<<16>>16==0;if((c[N>>2]|0)==((y|U<<16>>16==M<<16>>16?U&65535:0)|0)){aa=c[W+(V*112|0)+96>>2]|0}else{if(s){ab=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ab=b[c[W+(V*112|0)+68>>2]>>1]|0}s=ab&K;c[N>>2]=y|s<<16>>16==M<<16>>16?s&65535:0;c[W+(V*112|0)+96>>2]=B;aa=B}g[280524+(V<<3)>>2]=+(aa|0);break};case 3:{s=W+(V*112|0)+104|0;M=(a[W+(V*112|0)+64|0]&1)==0;if(M){ac=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ac=b[c[W+(V*112|0)+68>>2]>>1]|0}y=b[W+(V*112|0)+80>>1]|0;N=y&ac;K=b[W+(V*112|0)+82>>1]|0;U=K<<16>>16==0;if((c[s>>2]|0)==((U|N<<16>>16==K<<16>>16?N&65535:0)|0)){ad=c[W+(V*112|0)+108>>2]|0}else{if(M){ae=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ae=b[c[W+(V*112|0)+68>>2]>>1]|0}M=ae&y;c[s>>2]=U|M<<16>>16==K<<16>>16?M&65535:0;M=W+(V*112|0)+108|0;K=(c[M>>2]|0)+1|0;c[M>>2]=K;ad=K}g[280524+(V<<3)>>2]=+(ad|0);break};case 4:{K=W+(V*112|0)+104|0;M=(a[W+(V*112|0)+64|0]&1)==0;if(M){af=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{af=b[c[W+(V*112|0)+68>>2]>>1]|0}U=b[W+(V*112|0)+80>>1]|0;s=U&af;y=b[W+(V*112|0)+82>>1]|0;N=y<<16>>16==0;if((c[K>>2]|0)==((N|s<<16>>16==y<<16>>16?s&65535:0)|0)){ag=c[W+(V*112|0)+100>>2]|0}else{if(M){ah=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ah=b[c[W+(V*112|0)+68>>2]>>1]|0}M=ah&U;c[K>>2]=N|M<<16>>16==y<<16>>16?M&65535:0;M=W+(V*112|0)+96|0;y=c[M>>2]|0;c[W+(V*112|0)+100>>2]=y;c[M>>2]=B;ag=y}g[280524+(V<<3)>>2]=+(ag|0);break};default:{}}V=V+1|0;if(V>>>0>=S>>>0){break L837}}}}while(0);c[70258]=S;ai=S}else{ai=c[70258]|0}if((ai|0)==0){i=r;return}else{aj=0}do{ai=d3(c[280456+(c[136966]<<2)>>2]|0,c[280520+(aj<<3)>>2]|0)|0;bS(ai|0,+(+g[280524+(aj<<3)>>2]));aj=aj+1|0;}while(aj>>>0<(c[70258]|0)>>>0);i=r;return}function kh(b){b=b|0;var d=0;if(!(a[7856]|0)){return}if((c[70288]|0)!=0){d=0;do{ds(c[281040+(d<<2)>>2]|0);d=d+1|0;}while(d>>>0<(c[70288]|0)>>>0)}c[70288]=0;c[136966]=b;eE(c[280456+(b<<2)>>2]|0);return}function ki(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(!(a[7856]|0)){b=0;return b|0}d=c[(c[68254]|0)+72>>2]|0;if((d|0)==0){b=0;return b|0}else{e=0;f=1}while(1){if((c[273404+(f*460|0)>>2]|0)>-1){g=(e|0)==0?1:e}else{g=e}if((c[273420+(f*460|0)>>2]|0)>-1){h=g>>>0<2?2:g}else{h=g}if((c[273436+(f*460|0)>>2]|0)>-1){i=h>>>0<3?3:h}else{i=h}if((c[273452+(f*460|0)>>2]|0)>-1){j=i>>>0<4?4:i}else{j=i}if((c[273468+(f*460|0)>>2]|0)>-1){k=j>>>0<5?5:j}else{k=j}if((c[273484+(f*460|0)>>2]|0)>-1){l=k>>>0<6?6:k}else{l=k}if((c[273500+(f*460|0)>>2]|0)>-1){m=l>>>0<7?7:l}else{m=l}n=f+1|0;if(n>>>0>d>>>0){b=m;break}else{e=m;f=n}}return b|0}function kj(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0|a[7856]^1){a[d|0]=0;return}else{e=d|0;d=(c[68254]|0)+76+((b-1|0)*4148|0)+4104|0;s1(e|0,d|0,32)|0;return}}function kk(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+560|0;e=d|0;f=d+512|0;if(!(a[7856]|0)){g=0;i=d;return g|0}if((a[(c[68254]|0)+4|0]&1)==0){g=0;i=d;return g|0}h=f|0;j=c[136966]|0;k=c[273060+(j*460|0)>>2]|0;if((k|0)>-1){c[f>>2]=k;c[f+4>>2]=2;c[f+8>>2]=0;k=f+12|0;f=e;l=c[b+8>>2]|0;s1(f|0,l|0,32)|0;m=k;n=1;o=8}else{m=h;n=0;o=0}k=c[273064+(j*460|0)>>2]|0;if((k|0)>-1){c[m>>2]=k;c[m+4>>2]=2;c[m+8>>2]=o<<2;k=n+1|0;l=m+12|0;f=e+(o<<2)|0;p=c[b>>2]|0;s1(f|0,p|0,32)|0;q=l;r=k;s=o+8|0}else{q=m;r=n;s=o}o=c[273068+(j*460|0)>>2]|0;if((o|0)>-1){c[q>>2]=o;c[q+4>>2]=4;c[q+8>>2]=s<<2;o=r+1|0;n=q+12|0;m=e+(s<<2)|0;k=c[b+4>>2]|0;s1(m|0,k|0,64)|0;t=n;u=o;v=s+16|0}else{t=q;u=r;v=s}s=c[273072+(j*460|0)>>2]|0;if((s|0)>-1){c[t>>2]=s;c[t+4>>2]=2;c[t+8>>2]=v<<2;t=u+1|0;s=e+(v<<2)|0;r=c[b+12>>2]|0;s1(s|0,r|0,32)|0;w=t;x=v+8|0}else{w=u;x=v}if((x|0)==0){g=1;i=d;return g|0}km(c[256376+(j*1040|0)>>2]|0,256380+(j*1040|0)|0,256892+(j*1040|0)|0,e|0,x,h,w);g=1;i=d;return g|0}function kl(b){b=b|0;var d=0,e=0;if(!(a[7856]|0)){d=0;return d|0}if((a[(c[68254]|0)+4|0]&1)==0){d=0;return d|0}e=c[273056+((c[136966]|0)*460|0)>>2]|0;if((e|0)<=-1){d=1;return d|0}fy(e|0,1,0,b|0);d=1;return d|0}function km(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;ce(34962,a|0);if((c[d>>2]|0)==(f|0)){a=e;i=b;j=f<<2;if((s6(a|0,i|0,j|0)|0)!=0){k=i;l=a;m=j;n=688}}else{k=b;l=e;m=f<<2;n=688}if((n|0)==688){s1(k|0,l|0,m)|0;d1(34962,m|0,l|0,35044);c[d>>2]=f}if((h|0)==0){ce(34962,0);return}else{o=0}do{f=c[g+(o*12|0)>>2]|0;dP(f|0);d=c[70288]|0;c[70288]=d+1;c[281040+(d<<2)>>2]=f;cc(f|0,c[g+(o*12|0)+4>>2]|0,5126,0,0,c[g+(o*12|0)+8>>2]|0);o=o+1|0;}while(o>>>0<h>>>0);ce(34962,0);return}function kn(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+88|0;g=f|0;h=f+64|0;j=f+72|0;k=f+80|0;l=ff()|0;if((l|0)==0){m=0;i=f;return m|0}n=(b|0)!=0;do{if(n){if((a[383584]&1)!=0){o=c[135158]|0;p=(o|0)!=0?o:c[t>>2]|0;be(27216,37,1,p|0)|0;p=c[135158]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0}o=bY(35633)|0;if(kq(o,26784,b)|0){cF(l|0,o|0);break}o=c[135158]|0;p=(o|0)!=0?o:c[t>>2]|0;eQ(p|0,26384,(q=i,i=i+8|0,c[q>>2]=e,q)|0)|0;i=q;p=c[135158]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0;m=0;i=f;return m|0}}while(0);b=(d|0)!=0;do{if(b){if((a[383584]&1)!=0){o=c[135158]|0;p=(o|0)!=0?o:c[t>>2]|0;be(26056,39,1,p|0)|0;p=c[135158]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0}o=bY(35632)|0;if(kq(o,25704,d)|0){cF(l|0,o|0);break}o=c[135158]|0;p=(o|0)!=0?o:c[t>>2]|0;eQ(p|0,25216,(q=i,i=i+8|0,c[q>>2]=e,q)|0)|0;i=q;p=c[135158]|0;o=(p|0)!=0?p:c[t>>2]|0;a7(o|0)|0;m=0;i=f;return m|0}}while(0);if(!(n|b)){m=l;i=f;return m|0}if((a[383584]&1)!=0){b=c[135158]|0;n=(b|0)!=0?b:c[t>>2]|0;be(24584,33,1,n|0)|0;n=c[135158]|0;b=(n|0)!=0?n:c[t>>2]|0;a7(b|0)|0}b4(l|0);ed(l|0,35714,k|0);c[h>>2]=0;ed(l|0,35716,j|0);b=c[j>>2]|0;do{if((b|0)!=0){j=sR(b)|0;if((j|0)==0){break}eH(l|0,b|0,h|0,j|0);do{if((c[h>>2]|0)>0){if((a[383584]&1)==0){break}n=c[135158]|0;d=(n|0)!=0?n:c[t>>2]|0;eQ(d|0,23640,(q=i,i=i+8|0,c[q>>2]=j,q)|0)|0;i=q;d=c[135158]|0;n=(d|0)!=0?d:c[t>>2]|0;a7(n|0)|0}}while(0);sS(j)}}while(0);if((c[k>>2]|0)!=1){k=c[135158]|0;h=(k|0)!=0?k:c[t>>2]|0;eQ(h|0,23840,(q=i,i=i+8|0,c[q>>2]=e,q)|0)|0;i=q;e=c[135158]|0;h=(e|0)!=0?e:c[t>>2]|0;a7(h|0)|0;m=0;i=f;return m|0}eE(l|0);eE(l|0);h=g|0;b5(h|0,64,30736,(q=i,i=i+16|0,c[q>>2]=(c[68254]|0)+5,c[q+8>>2]=30336,q)|0)|0;i=q;g=d3(l|0,h|0)|0;L1040:do{if((g|0)>-1){r=g}else{e=0;while(1){if(e>>>0>=2){r=-1;break L1040}b5(h|0,64,30736,(q=i,i=i+16|0,c[q>>2]=c[7848+(e<<2)>>2],c[q+8>>2]=30336,q)|0)|0;i=q;k=d3(l|0,h|0)|0;if((k|0)>-1){r=k;break}else{e=e+1|0}}}}while(0);b_(r|0,0);eE(0);m=l;i=f;return m|0}function ko(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e+64|0;eE(b|0);g=e|0;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=47424,h)|0)|0;i=h;j=d3(b|0,g|0)|0;L1047:do{if((j|0)>-1){k=j}else{l=0;while(1){if(l>>>0>=2){k=-1;break L1047}b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(l<<2)>>2],c[h+8>>2]=47424,h)|0)|0;i=h;m=d3(b|0,g|0)|0;if((m|0)>-1){k=m;break}else{l=l+1|0}}}}while(0);c[d>>2]=k;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=45960,h)|0)|0;i=h;k=d3(b|0,g|0)|0;L1052:do{if((k|0)>-1){n=k}else{j=0;while(1){if(j>>>0>=2){n=-1;break L1052}b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(j<<2)>>2],c[h+8>>2]=45960,h)|0)|0;i=h;l=e9(b|0,g|0)|0;if((l|0)>-1){n=l;break}else{j=j+1|0}}}}while(0);c[d+4>>2]=n;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=44904,h)|0)|0;i=h;n=d3(b|0,g|0)|0;L1057:do{if((n|0)>-1){o=n}else{k=0;while(1){if(k>>>0>=2){o=-1;break L1057}b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(k<<2)>>2],c[h+8>>2]=44904,h)|0)|0;i=h;j=e9(b|0,g|0)|0;if((j|0)>-1){o=j;break}else{k=k+1|0}}}}while(0);c[d+8>>2]=o;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=43504,h)|0)|0;i=h;o=d3(b|0,g|0)|0;L1062:do{if((o|0)>-1){p=o}else{n=0;while(1){if(n>>>0>=2){p=-1;break L1062}b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(n<<2)>>2],c[h+8>>2]=43504,h)|0)|0;i=h;k=e9(b|0,g|0)|0;if((k|0)>-1){p=k;break}else{n=n+1|0}}}}while(0);c[d+12>>2]=p;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=42160,h)|0)|0;i=h;p=d3(b|0,g|0)|0;L1067:do{if((p|0)>-1){q=p}else{o=0;while(1){if(o>>>0>=2){q=-1;break L1067}b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(o<<2)>>2],c[h+8>>2]=42160,h)|0)|0;i=h;n=e9(b|0,g|0)|0;if((n|0)>-1){q=n;break}else{o=o+1|0}}}}while(0);c[d+16>>2]=q;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=41168,h)|0)|0;i=h;q=d3(b|0,g|0)|0;L1072:do{if((q|0)>-1){r=q}else{p=0;while(1){if(p>>>0>=2){r=-1;break L1072}b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(p<<2)>>2],c[h+8>>2]=41168,h)|0)|0;i=h;o=d3(b|0,g|0)|0;if((o|0)>-1){r=o;break}else{p=p+1|0}}}}while(0);c[d+20>>2]=r;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=40128,h)|0)|0;i=h;r=d3(b|0,g|0)|0;L1077:do{if((r|0)>-1){s=r}else{q=0;while(1){if(q>>>0>=2){s=-1;break L1077}b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(q<<2)>>2],c[h+8>>2]=40128,h)|0)|0;i=h;p=d3(b|0,g|0)|0;if((p|0)>-1){s=p;break}else{q=q+1|0}}}}while(0);c[d+24>>2]=s;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=39256,h)|0)|0;i=h;s=d3(b|0,g|0)|0;L1082:do{if((s|0)>-1){t=s}else{r=0;while(1){if(r>>>0>=2){t=-1;break L1082}b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(r<<2)>>2],c[h+8>>2]=39256,h)|0)|0;i=h;q=d3(b|0,g|0)|0;if((q|0)>-1){t=q;break}else{r=r+1|0}}}}while(0);c[d+28>>2]=t;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=38272,h)|0)|0;i=h;t=d3(b|0,g|0)|0;L1087:do{if((t|0)>-1){u=t}else{s=0;while(1){if(s>>>0>=2){u=-1;break L1087}b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(s<<2)>>2],c[h+8>>2]=38272,h)|0)|0;i=h;r=d3(b|0,g|0)|0;if((r|0)>-1){u=r;break}else{s=s+1|0}}}}while(0);c[d+32>>2]=u;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=37048,h)|0)|0;i=h;u=d3(b|0,g|0)|0;L1092:do{if((u|0)>-1){v=u}else{t=0;while(1){if(t>>>0>=2){v=-1;break L1092}b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(t<<2)>>2],c[h+8>>2]=37048,h)|0)|0;i=h;s=d3(b|0,g|0)|0;if((s|0)>-1){v=s;break}else{t=t+1|0}}}}while(0);c[d+40>>2]=v;v=c[68254]|0;if((c[v+66444>>2]|0)!=0){g=0;u=v;do{c[d+44+(g<<2)>>2]=d3(b|0,u+66448+(g*4168|0)|0)|0;g=g+1|0;u=c[68254]|0;}while(g>>>0<(c[u+66444>>2]|0)>>>0)}u=d+76|0;s_(u|0,-1|0,16);kp(b,u,35096);g=f|0;if(a>>>0>1){b5(g|0,64,33776,(h=i,i=i+8|0,c[h>>2]=a,h)|0)|0;i=h;kp(b,u,g);w=0}else{w=0}while(1){u=w+1|0;b5(g|0,64,32736,(h=i,i=i+8|0,c[h>>2]=u,h)|0)|0;i=h;f=d+92+(w<<4)|0;s_(f|0,-1|0,16);kp(b,f,g);if((w|0)!=0&u>>>0<a>>>0){v=a-w|0;b5(g|0,64,33776,(h=i,i=i+8|0,c[h>>2]=v,h)|0)|0;i=h;kp(b,f,g)}if(u>>>0<16){w=u}else{break}}w=d+348|0;s_(w|0,-1|0,16);kp(b,w,32168);b5(g|0,64,31400,(h=i,i=i+8|0,c[h>>2]=1,h)|0)|0;i=h;w=d+364|0;s_(w|0,-1|0,16);kp(b,w,g);b5(g|0,64,31400,(h=i,i=i+8|0,c[h>>2]=2,h)|0)|0;i=h;w=d+380|0;s_(w|0,-1|0,16);kp(b,w,g);b5(g|0,64,31400,(h=i,i=i+8|0,c[h>>2]=3,h)|0)|0;i=h;w=d+396|0;s_(w|0,-1|0,16);kp(b,w,g);b5(g|0,64,31400,(h=i,i=i+8|0,c[h>>2]=4,h)|0)|0;i=h;w=d+412|0;s_(w|0,-1|0,16);kp(b,w,g);b5(g|0,64,31400,(h=i,i=i+8|0,c[h>>2]=5,h)|0)|0;i=h;w=d+428|0;s_(w|0,-1|0,16);kp(b,w,g);b5(g|0,64,31400,(h=i,i=i+8|0,c[h>>2]=6,h)|0)|0;i=h;h=d+444|0;s_(h|0,-1|0,16);kp(b,h,g);eE(0);i=e;return}function kp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+320|0;f=e|0;g=e+64|0;b5(g|0,64,30736,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=30336,h)|0)|0;i=h;j=e+128|0;b5(j|0,64,30736,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=39256,h)|0)|0;i=h;k=e+192|0;b5(k|0,64,30736,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=41168,h)|0)|0;i=h;l=e+256|0;b5(l|0,64,30736,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=45960,h)|0)|0;i=h;d=b|0;if((c[d>>2]|0)<0){m=f|0;n=(c[68254]|0)+5|0;b5(m|0,64,30736,(h=i,i=i+16|0,c[h>>2]=n,c[h+8>>2]=g,h)|0)|0;i=h;n=d3(a|0,m|0)|0;L1112:do{if((n|0)>-1){o=n}else{p=0;while(1){if(p>>>0>=2){o=-1;break L1112}b5(m|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(p<<2)>>2],c[h+8>>2]=g,h)|0)|0;i=h;q=d3(a|0,m|0)|0;if((q|0)>-1){o=q;break}else{p=p+1|0}}}}while(0);c[d>>2]=o}o=b+8|0;if((c[o>>2]|0)<0){d=f|0;m=(c[68254]|0)+5|0;b5(d|0,64,30736,(h=i,i=i+16|0,c[h>>2]=m,c[h+8>>2]=j,h)|0)|0;i=h;m=d3(a|0,d|0)|0;L1120:do{if((m|0)>-1){r=m}else{g=0;while(1){if(g>>>0>=2){r=-1;break L1120}b5(d|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(g<<2)>>2],c[h+8>>2]=j,h)|0)|0;i=h;n=d3(a|0,d|0)|0;if((n|0)>-1){r=n;break}else{g=g+1|0}}}}while(0);c[o>>2]=r}r=b+4|0;if((c[r>>2]|0)<0){o=f|0;d=(c[68254]|0)+5|0;b5(o|0,64,30736,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=k,h)|0)|0;i=h;d=d3(a|0,o|0)|0;L1128:do{if((d|0)>-1){s=d}else{j=0;while(1){if(j>>>0>=2){s=-1;break L1128}b5(o|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(j<<2)>>2],c[h+8>>2]=k,h)|0)|0;i=h;m=d3(a|0,o|0)|0;if((m|0)>-1){s=m;break}else{j=j+1|0}}}}while(0);c[r>>2]=s}s=b+12|0;if((c[s>>2]|0)>=0){i=e;return}b=f|0;b5(b|0,64,30736,(h=i,i=i+16|0,c[h>>2]=(c[68254]|0)+5,c[h+8>>2]=l,h)|0)|0;i=h;f=d3(a|0,b|0)|0;L1137:do{if((f|0)>-1){t=f}else{r=0;while(1){if(r>>>0>=2){t=-1;break L1137}b5(b|0,64,30736,(h=i,i=i+16|0,c[h>>2]=c[7848+(r<<2)>>2],c[h+8>>2]=l,h)|0)|0;i=h;o=e9(a|0,b|0)|0;if((o|0)>-1){t=o;break}else{r=r+1|0}}}}while(0);c[s>>2]=t;i=e;return}function kq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+72|0;g=f|0;h=f+8|0;j=f+48|0;k=f+64|0;l=f+16|0;s_(l|0,0,32);do{if((a[273048]&1)!=0){if((bJ(e|0,23432)|0)!=0){break}m=((c[68256]|0)*10|0)+((c[68258]|0)*100|0)|0;if((m|0)==310){n=140}else if((m|0)==320){n=150}else if((m|0)==300){n=130}else{n=m}b5(l|0,32,23136,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;if((a[383584]&1)==0){break}m=c[135158]|0;p=(m|0)!=0?m:c[t>>2]|0;eQ(p|0,22872,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;p=c[135158]|0;m=(p|0)!=0?p:c[t>>2]|0;a7(m|0)|0}}while(0);n=j|0;c[n>>2]=l;c[j+4>>2]=d;c[j+8>>2]=e;ca(b|0,3,n|0,0);bo(b|0);dg(b|0,35713,k|0);c[g>>2]=0;dg(b|0,35716,h|0);n=c[h>>2]|0;if((n|0)==0){q=c[k>>2]|0;r=(q|0)==1;i=f;return r|0}h=sR(n)|0;if((h|0)==0){q=c[k>>2]|0;r=(q|0)==1;i=f;return r|0}eN(b|0,n|0,g|0,h|0);do{if((c[g>>2]|0)>0){if((a[383584]&1)==0){break}n=c[135158]|0;b=(n|0)!=0?n:c[t>>2]|0;eQ(b|0,22616,(o=i,i=i+8|0,c[o>>2]=h,o)|0)|0;i=o;b=c[135158]|0;n=(b|0)!=0?b:c[t>>2]|0;a7(n|0)|0}}while(0);sS(h);q=c[k>>2]|0;r=(q|0)==1;i=f;return r|0}function kr(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=i;k=e|0;l=e+4|0;m=e+9|0;switch(d[m]|0){case 0:{n=d[e+8|0]|0;o=((ag(c[k>>2]|0,n)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 2:{n=(d[e+8|0]|0)*3|0;o=((ag(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 3:{n=d[e+8|0]|0;o=((ag(c[k>>2]|0,n)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 4:{n=d[e+8|0]<<1;o=((ag(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 6:{n=d[e+8|0]<<2;o=((ag(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};default:{o=0;p=0}}n=o+1|0;if((ag(c[l>>2]|0,n)|0)>>>0>g>>>0){q=0;i=j;return q|0}g=sR(o)|0;do{if((g|0)!=0){if((c[g-4>>2]&3|0)==0){break}s_(g|0,0,o|0)}}while(0);r=sR(o)|0;L1180:do{if((r|0)==0){s=c[t>>2]|0;eQ(s|0,48024,(u=i,i=i+8|0,c[u>>2]=394,u)|0)|0;i=u;v=0}else{if((c[r-4>>2]&3|0)!=0){s_(r|0,0,o|0)}if((c[l>>2]|0)==0){v=1;break}s=e+8|0;w=(p|0)==0;x=(o|0)==0;y=0;z=f;A=b;L1186:while(1){L1188:do{switch(d[z]|0){case 1:{if(w){B=0}else{C=0;while(1){D=C+1|0;a[r+C|0]=a[z+D|0]|0;if(D>>>0<p>>>0){C=D}else{B=p;break}}}if(B>>>0<o>>>0){E=B}else{break L1188}while(1){C=E+1|0;a[r+E|0]=(a[z+C|0]|0)+(a[r+(E-B)|0]|0)&255;if(C>>>0<o>>>0){E=C}else{break}}break};case 2:{if(x){break L1188}else{F=0}while(1){C=F+1|0;a[r+F|0]=(a[z+C|0]|0)+(a[g+F|0]|0)&255;if(C>>>0<o>>>0){F=C}else{break}}break};case 3:{if(w){G=0}else{C=0;while(1){D=C+1|0;a[r+C|0]=((d[g+C|0]|0)>>>1)+(a[z+D|0]|0)&255;if(D>>>0<p>>>0){C=D}else{G=p;break}}}if(G>>>0<o>>>0){H=G}else{break L1188}while(1){C=H+1|0;a[r+H|0]=(((d[g+H|0]|0)+(d[r+(H-G)|0]|0)|0)>>>1)+(d[z+C|0]|0)&255;if(C>>>0<o>>>0){H=C}else{break}}break};case 4:{if(w){I=0}else{C=0;while(1){D=C+1|0;a[r+C|0]=(a[z+D|0]|0)+(a[g+C|0]|0)&255;if(D>>>0<p>>>0){C=D}else{I=p;break}}}if(I>>>0<o>>>0){J=I}else{break L1188}while(1){C=J-I|0;D=a[r+C|0]|0;K=D&255;L=a[g+J|0]|0;M=L&255;N=a[g+C|0]|0;C=N&255;O=M+K-C|0;P=O-K|0;K=(P|0)>-1?P:-P|0;P=O-M|0;M=(P|0)>-1?P:-P|0;P=O-C|0;C=(P|0)>-1?P:-P|0;if((K|0)>(M|0)|(K|0)>(C|0)){Q=(M|0)>(C|0)?N:L}else{Q=D}D=J+1|0;a[r+J|0]=(a[z+D|0]|0)+Q&255;if(D>>>0<o>>>0){J=D}else{break}}break};case 0:{D=z+1|0;s1(r|0,D|0,o)|0;break};default:{break L1186}}}while(0);L1218:do{switch(a[m]|0){case 0:{D=c[k>>2]|0;L=a[s]|0;N=L&255;if(L<<24>>24==16){if((D|0)==0){break L1218}else{R=0}while(1){c[A+(R<<2)>>2]=(d[r+(R<<1)|0]|0)*65793|0|-16777216;R=R+1|0;if(R>>>0>=D>>>0){break L1218}}}L=(1<<N)-1|0;if((D|0)==0){break L1218}C=8-N|0;M=(c[8256+(N<<2)>>2]|0)*65793|0;K=0;P=0;while(1){c[A+(P<<2)>>2]=ag(M,(d[r+(K>>>3)|0]|0)>>>((C-(K&7)|0)>>>0)&L)|0|-16777216;O=P+1|0;if(O>>>0<D>>>0){K=K+N|0;P=O}else{break}}break};case 2:{P=c[k>>2]|0;N=(d[s]|0)>>>3;if((P|0)==0){break L1218}K=N<<1;D=K+N|0;L=0;C=r;while(1){c[A+(L<<2)>>2]=d[C]<<16|d[C+N|0]<<8|d[C+K|0]|-16777216;M=L+1|0;if(M>>>0<P>>>0){L=M;C=C+D|0}else{break}}break};case 3:{D=c[k>>2]|0;C=d[s]|0;L=(1<<C)-1|0;if((D|0)==0){break L1218}P=8-C|0;K=0;N=0;while(1){c[A+(N<<2)>>2]=c[h+(((d[r+(K>>>3)|0]|0)>>>((P-(K&7)|0)>>>0)&L)<<2)>>2];M=N+1|0;if(M>>>0<D>>>0){K=K+C|0;N=M}else{break}}break};case 4:{N=c[k>>2]|0;C=(d[s]|0)>>>3;if((N|0)==0){break L1218}K=C<<1;D=0;L=r;while(1){c[A+(D<<2)>>2]=d[L+C|0]<<24|((d[L]|0)*65793|0);P=D+1|0;if(P>>>0<N>>>0){D=P;L=L+K|0}else{break}}break};case 6:{K=c[k>>2]|0;L=(d[s]|0)>>>3;if((K|0)==0){break L1218}D=L<<1;N=D+L|0;C=N+L|0;P=0;M=r;while(1){c[A+(P<<2)>>2]=d[M+L|0]<<8|d[M]<<16|d[M+D|0]|d[M+N|0]<<24;O=P+1|0;if(O>>>0<K>>>0){P=O;M=M+C|0}else{break}}break};default:{}}}while(0);s1(g|0,r|0,o)|0;C=y+1|0;if(C>>>0<(c[l>>2]|0)>>>0){y=C;z=z+n|0;A=A+(c[k>>2]<<2)|0}else{v=1;break L1180}}eQ(c[t>>2]|0,48024,(u=i,i=i+8|0,c[u>>2]=439,u)|0)|0;i=u;v=0}}while(0);sS(r);sS(g);q=v;i=j;return q|0}function ks(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+16|0;d=b|0;e=b+8|0;if((a|0)==0){f=-2;i=b;return f|0}g=c[a+28>>2]|0;if((g|0)==0){f=-2;i=b;return f|0}h=g;j=(c[h+11008>>2]|0)>0?9:8;k=a+4|0;l=c[k>>2]|0;m=h+11e3|0;n=c[m>>2]|0;c[m>>2]=0;m=h+43780|0;if((c[m>>2]|0)<0){f=-3;i=b;return f|0}o=h+11004|0;c[o>>2]=c[o>>2]|1;if((n|0)!=0){c[d>>2]=c[k>>2];n=a+16|0;c[e>>2]=c[n>>2];o=g;p=a|0;q=a+12|0;r=c[q>>2]|0;s=kt(o,c[p>>2]|0,d,r,r,e,j|4)|0;c[m>>2]=s;r=c[d>>2]|0;c[p>>2]=(c[p>>2]|0)+r;c[k>>2]=(c[k>>2]|0)-r;p=a+8|0;c[p>>2]=(c[p>>2]|0)+r;c[a+40>>2]=c[o+28>>2];o=c[e>>2]|0;c[q>>2]=(c[q>>2]|0)+o;c[n>>2]=(c[n>>2]|0)-o;n=a+20|0;c[n>>2]=(c[n>>2]|0)+o;if((s|0)<0){f=-3;i=b;return f|0}if((s|0)==0){f=1;i=b;return f|0}c[m>>2]=-1;f=-5;i=b;return f|0}s=h+10996|0;o=c[s>>2]|0;if((o|0)!=0){n=a+16|0;q=c[n>>2]|0;r=o>>>0<q>>>0?o:q;q=a+12|0;o=c[q>>2]|0;p=h+10992|0;t=(c[p>>2]|0)+(h+11012)|0;s1(o|0,t|0,r)|0;c[q>>2]=(c[q>>2]|0)+r;c[n>>2]=(c[n>>2]|0)-r;n=a+20|0;c[n>>2]=(c[n>>2]|0)+r;n=c[s>>2]|0;c[s>>2]=n-r;c[p>>2]=(c[p>>2]|0)+r&32767;if((c[m>>2]|0)!=0){f=0;i=b;return f|0}f=(n|0)==(r|0)|0;i=b;return f|0}r=h+10992|0;n=g;g=a|0;p=h+11012|0;q=a+8|0;t=n+28|0;o=a+40|0;u=a+16|0;v=a+12|0;w=a+20|0;a=c[r>>2]|0;L1276:do{if((l|0)==0){x=a;while(1){c[d>>2]=c[k>>2];c[e>>2]=32768-x;y=kt(n,c[g>>2]|0,d,p,h+11012+x|0,e,j)|0;c[m>>2]=y;z=c[d>>2]|0;c[g>>2]=(c[g>>2]|0)+z;c[k>>2]=(c[k>>2]|0)-z;c[q>>2]=(c[q>>2]|0)+z;c[o>>2]=c[t>>2];z=c[e>>2]|0;c[s>>2]=z;A=c[u>>2]|0;B=z>>>0<A>>>0?z:A;A=c[v>>2]|0;z=(c[r>>2]|0)+(h+11012)|0;s1(A|0,z|0,B)|0;c[v>>2]=(c[v>>2]|0)+B;c[u>>2]=(c[u>>2]|0)-B;c[w>>2]=(c[w>>2]|0)+B;z=(c[s>>2]|0)-B|0;c[s>>2]=z;A=(c[r>>2]|0)+B&32767;c[r>>2]=A;if((y|0)<0){f=-3;C=886;break}if((y|0)==0){D=z;break L1276}else if((y|0)==1){f=-5;C=893;break}if((c[u>>2]|0)==0){f=-5;C=894;break}else{x=A}}if((C|0)==886){i=b;return f|0}else if((C|0)==893){i=b;return f|0}else if((C|0)==894){i=b;return f|0}}else{x=a;while(1){c[d>>2]=c[k>>2];c[e>>2]=32768-x;A=kt(n,c[g>>2]|0,d,p,h+11012+x|0,e,j)|0;c[m>>2]=A;y=c[d>>2]|0;c[g>>2]=(c[g>>2]|0)+y;c[k>>2]=(c[k>>2]|0)-y;c[q>>2]=(c[q>>2]|0)+y;c[o>>2]=c[t>>2];y=c[e>>2]|0;c[s>>2]=y;z=c[u>>2]|0;B=y>>>0<z>>>0?y:z;z=c[v>>2]|0;y=(c[r>>2]|0)+(h+11012)|0;s1(z|0,y|0,B)|0;c[v>>2]=(c[v>>2]|0)+B;c[u>>2]=(c[u>>2]|0)-B;c[w>>2]=(c[w>>2]|0)+B;y=(c[s>>2]|0)-B|0;c[s>>2]=y;z=(c[r>>2]|0)+B&32767;c[r>>2]=z;if((A|0)<0){f=-3;C=895;break}if((A|0)==0){D=y;break L1276}if((c[u>>2]|0)==0){f=-5;C=896;break}else{x=z}}if((C|0)==895){i=b;return f|0}else if((C|0)==896){i=b;return f|0}}}while(0);f=(D|0)!=0?-5:1;i=b;return f|0}function kt(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gj=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0,hQ=0,hR=0,hS=0,hT=0,hU=0,hV=0,hW=0,hX=0,hY=0,hZ=0,h_=0,h$=0,h0=0,h1=0,h2=0,h3=0,h4=0,h5=0,h6=0,h7=0,h8=0,h9=0,ia=0,ib=0,ic=0,id=0,ie=0,ig=0,ih=0,ii=0,ij=0,ik=0,il=0,im=0,io=0,ip=0,iq=0,ir=0,is=0,it=0,iu=0,iv=0,iw=0,ix=0,iy=0,iz=0,iA=0,iB=0,iC=0,iD=0,iE=0,iF=0,iG=0,iH=0,iI=0,iJ=0,iK=0,iL=0,iM=0,iN=0,iO=0,iP=0,iQ=0,iR=0,iS=0,iT=0,iU=0,iV=0,iW=0,iX=0,iY=0,iZ=0,i_=0,i$=0,i0=0,i1=0,i2=0,i3=0,i4=0,i5=0,i6=0,i7=0,i8=0,i9=0,ja=0,jb=0,jc=0,jd=0,je=0,jf=0,jg=0,jh=0,ji=0,jj=0,jk=0,jl=0,jm=0,jn=0,jo=0,jp=0,jq=0,jr=0,js=0,jt=0,ju=0,jv=0,jw=0,jx=0,jy=0,jz=0,jA=0,jB=0,jC=0,jD=0,jE=0,jF=0,jG=0,jH=0,jI=0,jJ=0,jK=0,jL=0,jM=0,jN=0,jO=0,jP=0,jQ=0,jR=0,jS=0,jT=0,jU=0,jV=0,jW=0,jX=0,jY=0,jZ=0,j_=0,j$=0,j0=0,j1=0,j2=0,j3=0,j4=0,j5=0,j6=0,j7=0,j8=0,j9=0,ka=0,kb=0,kc=0,kd=0,ke=0,kf=0,kg=0,kh=0,ki=0,kj=0,kk=0,kl=0,km=0,kn=0,ko=0,kp=0,kq=0,kr=0,ks=0,kt=0,ku=0,kv=0,kw=0,kx=0,ky=0,kz=0,kA=0,kB=0,kC=0,kD=0,kE=0,kF=0,kG=0,kH=0,kI=0,kJ=0,kK=0,kL=0,kM=0,kN=0,kO=0,kP=0,kQ=0,kR=0,kS=0,kT=0,kU=0,kV=0,kW=0,kX=0,kY=0,kZ=0,k_=0,k$=0,k0=0,k1=0,k2=0,k3=0,k4=0,k5=0,k6=0,k7=0,k8=0,k9=0,la=0,lb=0,lc=0,ld=0,le=0,lf=0,lg=0,lh=0,li=0,lj=0,lk=0,ll=0,lm=0,ln=0,lo=0,lp=0,lq=0,lr=0,ls=0,lt=0,lu=0,lv=0,lw=0,lx=0,ly=0,lz=0,lA=0,lB=0,lC=0,lD=0,lE=0,lF=0,lG=0,lH=0,lI=0,lJ=0,lK=0,lL=0,lM=0,lN=0,lO=0,lP=0,lQ=0,lR=0,lS=0,lT=0,lU=0,lV=0,lW=0,lX=0,lY=0,lZ=0,l_=0,l$=0,l0=0,l1=0,l2=0,l3=0,l4=0,l5=0,l6=0,l7=0,l8=0,l9=0,ma=0,mb=0,mc=0,md=0,me=0,mf=0,mg=0,mh=0,mi=0,mj=0,mk=0,ml=0,mm=0,mn=0,mo=0,mp=0,mq=0,mr=0,ms=0,mt=0,mu=0,mv=0,mw=0,mx=0,my=0,mz=0,mA=0,mB=0,mC=0,mD=0,mE=0,mF=0,mG=0,mH=0,mI=0,mJ=0,mK=0,mL=0,mM=0,mN=0,mO=0,mP=0,mQ=0,mR=0,mS=0,mT=0,mU=0,mV=0,mW=0,mX=0,mY=0,mZ=0,m_=0,m$=0,m0=0,m1=0,m2=0,m3=0,m4=0,m5=0;m=i;i=i+136|0;n=m|0;o=m+72|0;p=c[g>>2]|0;q=f+p|0;r=c[k>>2]|0;s=j+r|0;t=(l&4|0)!=0;if(t){u=-1}else{u=j+~h+r|0}r=u+1|0;if((r&u|0)!=0|j>>>0<h>>>0){c[k>>2]=0;c[g>>2]=0;v=-3;i=m;return v|0}w=e+4|0;x=c[w>>2]|0;y=e+56|0;z=c[y>>2]|0;A=e+32|0;B=c[A>>2]|0;D=e+36|0;E=c[D>>2]|0;F=e+40|0;G=c[F>>2]|0;H=e+60|0;I=c[H>>2]|0;J=e|0;L1302:do{switch(c[J>>2]|0){case 0:{c[e+12>>2]=0;K=e+8|0;c[K>>2]=0;c[e+28>>2]=1;c[e+16>>2]=1;if((l&1|0)==0){L=0;M=0;N=0;O=0;P=0;Q=I;R=f;S=j;T=928;break L1302}if((p|0)<1){U=0;V=0;W=0;X=0;Y=0;T=907;break L1302}c[K>>2]=d[f]|0;Z=0;_=0;$=0;aa=0;ab=0;ac=f+1|0;T=913;break};case 1:{if((p|0)<=0){U=x;V=B;W=E;X=G;Y=z;T=907;break L1302}c[e+8>>2]=d[f]|0;Z=x;_=B;$=E;aa=G;ab=z;ac=f+1|0;T=913;break};case 2:{if((p|0)<=0){ad=x;ae=B;af=E;ag=G;ah=z;ai=f;T=914;break L1302}K=d[f]|0;c[e+12>>2]=K;aj=x;ak=B;al=G;am=z;an=f+1|0;ao=K;T=920;break};case 36:{ap=x;aq=B;ar=E;as=G;at=z;au=f;T=927;break};case 3:{if((p|0)<=0){av=x;aw=B;ax=E;ay=G;az=z;aA=I;aB=f;aC=j;T=930;break L1302}aD=x;aE=B;aF=E;aG=G;aH=z;aI=d[f]|0;aJ=I;aK=f+1|0;aL=j;T=935;break};case 5:{if((p|0)<=0){aM=x;aN=B;aO=E;aP=G;aQ=z;aR=I;aS=f;aT=j;T=939;break L1302}aU=x;aV=B;aW=E;aX=G;aY=z;aZ=d[f]|0;a_=I;a$=f+1|0;a0=j;T=944;break};case 6:{if((p|0)<=0){a1=x;a2=B;a3=E;a4=G;a5=z;a6=I;a7=f;a8=j;T=950;break L1302}a9=x;ba=B;bb=E;bc=G;bd=z;be=d[f]|0;bf=I;bg=f+1|0;bh=j;T=955;break};case 7:{if((p|0)<=0){bi=x;bj=B;bk=E;bl=G;bm=z;bn=I;bo=f;bp=j;T=958;break L1302}a[e+10528+E|0]=a[f]|0;bq=x;br=B;bs=E;bt=G;bu=z;bv=I;bw=f+1|0;bx=j;T=964;break};case 39:{by=x;bz=B;bA=E;bB=G;bC=z;bD=I;bE=f;bF=j;T=966;break};case 51:{if((p|0)<=0){bG=x;bH=B;bI=E;bJ=G;bK=z;bL=I;bM=f;bN=j;T=970;break L1302}bO=x;bP=B;bQ=E;bR=G;bS=z;bT=d[f]|0;bU=I;bV=f+1|0;bW=j;T=975;break};case 52:{bX=x;bY=B;bZ=E;b_=G;b$=z;b0=I;b1=f;b2=j;T=977;break};case 9:{b3=x;b4=B;b5=E;b6=G;b7=z;b8=I;b9=f;ca=j;T=981;break};case 38:{cb=x;cc=B;cd=E;ce=G;cf=z;cg=I;ch=f;ci=j;T=983;break};case 40:{cj=x;ck=B;cl=E;cm=G;cn=z;co=I;cp=f;cq=j;T=986;break};case 10:{cr=x;cs=B;ct=E;cu=G;cv=z;cw=I;cx=f;cy=j;T=988;break};case 11:{if((p|0)<=0){cz=x;cA=B;cB=E;cC=G;cD=z;cE=I;cF=f;cG=j;T=992;break L1302}cH=x;cI=B;cJ=E;cK=G;cL=d[f]|0;cM=z;cN=I;cO=f+1|0;cP=j;T=997;break};case 14:{if((p|0)<=0){cQ=x;cR=B;cS=E;cT=G;cU=z;cV=I;cW=f;cX=j;T=1003;break L1302}cY=x;cZ=B;c_=E;c$=d[f]|0;c0=G;c1=z;c2=I;c3=f+1|0;c4=j;T=1008;break};case 35:{c5=x;c6=B;c7=E;c8=G;c9=z;da=I;db=f;dc=j;T=1018;break};case 16:{if((p|0)<=0){dd=x;de=B;df=E;dg=G;dh=z;di=I;dj=f;dk=j;T=1048;break L1302}dl=d[f]|0;dm=x;dn=B;dp=E;dq=G;dr=z;ds=I;dt=f+1|0;du=j;T=1053;break};case 17:{dv=x;dw=B;dx=E;dy=G;dz=z;dA=I;dB=f;dC=j;T=1061;break};case 18:{if((p|0)<=0){dD=x;dE=B;dF=E;dG=G;dH=z;dI=I;dJ=f;dK=j;T=1064;break L1302}dL=d[f]|0;dM=x;dN=B;dO=E;dP=G;dQ=z;dR=I;dS=f+1|0;dT=j;T=1069;break};case 21:{dU=x;dV=B;dW=E;dX=G;dY=z;dZ=I;d_=f;d$=j;T=1074;break};case 23:{if((p|0)<=0){d0=x;d1=B;d2=E;d3=G;d4=z;d5=I;d6=f;d7=j;T=1087;break L1302}d8=d[f]|0;d9=x;ea=B;eb=E;ec=G;ed=z;ee=I;ef=f+1|0;eg=j;T=1092;break};case 24:{eh=x;ei=B;ej=E;ek=G;el=z;em=I;en=f;eo=j;T=1098;break};case 25:{if((p|0)<=0){ep=x;eq=B;er=E;es=G;et=z;eu=I;ev=f;ew=j;T=1121;break L1302}ex=d[f]|0;ey=x;ez=B;eA=E;eB=G;eC=z;eD=I;eE=f+1|0;eF=j;T=1126;break};case 26:{if((p|0)<=0){eG=x;eH=B;eI=E;eJ=G;eK=z;eL=I;eM=f;eN=j;T=1137;break L1302}eO=d[f]|0;eP=x;eQ=B;eR=E;eS=G;eT=z;eU=I;eV=f+1|0;eW=j;T=1142;break};case 27:{if((p|0)<=0){eX=x;eY=B;eZ=E;e_=G;e$=z;e0=I;e1=f;e2=j;T=1150;break L1302}e3=d[f]|0;e4=x;e5=B;e6=E;e7=G;e8=z;e9=I;fa=f+1|0;fb=j;T=1155;break};case 37:{fc=x;fd=B;fe=E;ff=G;fg=z;fh=I;fi=f;fj=j;T=1158;break};case 53:{fk=x;fl=B;fm=E;fn=G;fo=z;fp=I;fq=f;fr=j;T=1161;break};case 32:{if((p|0)<=0){fs=x;ft=B;fu=E;fv=G;fw=z;fx=I;fy=f;fz=j;T=1173;break L1302}fA=d[f]|0;fB=x;fC=B;fD=E;fE=G;fF=z;fG=I;fH=f+1|0;fI=j;T=1178;break};case 41:{if((p|0)<=0){fJ=x;fK=B;fL=E;fM=G;fN=z;fO=I;fP=f;fQ=j;T=1184;break L1302}fR=d[f]|0;fS=x;fT=B;fU=E;fV=G;fW=z;fX=I;fY=f+1|0;fZ=j;T=1189;break};case 42:{if((p|0)<=0){f_=x;f$=B;f0=E;f1=G;f2=z;f3=I;f4=f;f5=j;T=1192;break L1302}f6=d[f]|0;f7=x;f8=B;f9=E;ga=G;gb=z;gc=I;gd=f+1|0;ge=j;T=1197;break};case 34:{gf=x;gg=B;gh=E;gi=G;gj=z;gk=I;gl=f;gm=j;T=1198;break};default:{gn=-1;go=x;gp=B;gq=E;gr=G;gs=z;gt=I;gu=f;gv=j;T=1199}}}while(0);do{if((T|0)==907){if((l&2|0)==0){c[e+8>>2]=0;Z=U;_=V;$=W;aa=X;ab=Y;ac=f;T=913;break}else{c[J>>2]=1;gn=1;go=U;gp=V;gq=W;gr=X;gs=Y;gt=I;gu=f;gv=j;T=1199;break}}}while(0);do{if((T|0)==913){if(ac>>>0>=q>>>0){ad=Z;ae=_;af=$;ag=aa;ah=ab;ai=ac;T=914;break}Y=d[ac]|0;c[e+12>>2]=Y;aj=Z;ak=_;al=aa;am=ab;an=ac+1|0;ao=Y;T=920}}while(0);do{if((T|0)==914){if((l&2|0)==0){c[e+12>>2]=0;aj=ad;ak=ae;al=ag;am=ah;an=ai;ao=0;T=920;break}else{c[J>>2]=2;gn=1;go=ad;gp=ae;gq=af;gr=ag;gs=ah;gt=I;gu=ai;gv=j;T=1199;break}}}while(0);if((T|0)==920){ai=c[e+8>>2]|0;if((((ai<<8|ao)>>>0)%31|0|ao&32|0)==0){gw=(ai&15|0)!=8|0}else{gw=1}if(t){gx=gw}else{ao=1<<(ai>>>4)+8;if(ao>>>0>32768){gy=1}else{gy=r>>>0<ao>>>0|0}gx=gy|gw}if((gx|0)==0){L=aj;M=ak;N=0;O=al;P=am;Q=I;R=an;S=j;T=928}else{ap=aj;aq=ak;ar=gx;as=al;at=am;au=an;T=927}}if((T|0)==927){c[J>>2]=36;gn=-1;go=ap;gp=aq;gq=ar;gr=as;gs=at;gt=I;gu=au;gv=j;T=1199}L1368:while(1){do{if((T|0)==928){T=0;if(L>>>0<3){gz=L;gA=M;gB=N;gC=O;gD=P;gE=Q;gF=R;gG=S;T=929}else{gH=L;gI=M;gJ=N;gK=O;gL=P;gM=Q;gN=R;gO=S;T=936}}else if((T|0)==930){T=0;if((l&2|0)==0){aD=av;aE=aw;aF=ax;aG=ay;aH=az;aI=0;aJ=aA;aK=aB;aL=aC;T=935;continue L1368}c[J>>2]=3;gn=1;go=av;gp=aw;gq=ax;gr=ay;gs=az;gt=aA;gu=aB;gv=aC;T=1199;continue L1368}else if((T|0)==935){T=0;au=aI<<aD|aH;I=aD+8|0;if(I>>>0<3){gz=I;gA=aE;gB=aF;gC=aG;gD=au;gE=aJ;gF=aK;gG=aL;T=929}else{gH=I;gI=aE;gJ=aF;gK=aG;gL=au;gM=aJ;gN=aK;gO=aL;T=936}}else if((T|0)==939){T=0;if((l&2|0)==0){aU=aM;aV=aN;aW=aO;aX=aP;aY=aQ;aZ=0;a_=aR;a$=aS;a0=aT;T=944;continue L1368}c[J>>2]=5;gn=1;go=aM;gp=aN;gq=aO;gr=aP;gs=aQ;gt=aR;gu=aS;gv=aT;T=1199;continue L1368}else if((T|0)==944){T=0;au=aZ<<aU|aY;I=aU+8|0;if(I>>>0<(I&7)>>>0){gP=I;gQ=aV;gR=aW;gS=aX;gT=au;gU=a_;gV=a$;gW=a0;T=938}else{gX=I;gY=aV;gZ=aX;g_=au;g$=a_;g0=a$;g1=a0;T=945}}else if((T|0)==950){T=0;if((l&2|0)==0){a9=a1;ba=a2;bb=a3;bc=a4;bd=a5;be=0;bf=a6;bg=a7;bh=a8;T=955;continue L1368}c[J>>2]=6;gn=1;go=a1;gp=a2;gq=a3;gr=a4;gs=a5;gt=a6;gu=a7;gv=a8;T=1199;continue L1368}else if((T|0)==955){T=0;au=be<<a9|bd;I=a9+8|0;if(a9>>>0>4294967287){g2=I;g3=ba;g4=bb;g5=bc;g6=au;g7=bf;g8=bg;g9=bh;T=949}else{ha=I;hb=ba;hc=bb;hd=bc;he=au;hf=bf;hg=bg;hh=bh;T=956}}else if((T|0)==958){T=0;if((l&2|0)==0){a[e+10528+bk|0]=0;bq=bi;br=bj;bs=bk;bt=bl;bu=bm;bv=bn;bw=bo;bx=bp;T=964;continue L1368}else{c[J>>2]=7;gn=1;go=bi;gp=bj;gq=bk;gr=bl;gs=bm;gt=bn;gu=bo;gv=bp;T=1199;continue L1368}}else if((T|0)==964){T=0;hi=bq;hj=br;hk=bs+1|0;hl=bt;hm=bu;hn=bv;ho=bw;hp=bx;T=946}else if((T|0)==966){T=0;c[J>>2]=39;gn=-1;go=by;gp=bz;gq=bA;gr=bB;gs=bC;gt=bD;gu=bE;gv=bF;T=1199;continue L1368}else if((T|0)==970){T=0;if((l&2|0)==0){bO=bG;bP=bH;bQ=bI;bR=bJ;bS=bK;bT=0;bU=bL;bV=bM;bW=bN;T=975;continue L1368}c[J>>2]=51;gn=1;go=bG;gp=bH;gq=bI;gr=bJ;gs=bK;gt=bL;gu=bM;gv=bN;T=1199;continue L1368}else if((T|0)==975){T=0;au=bT<<bO|bS;I=bO+8|0;if(bO>>>0>4294967287){hq=I;hr=bP;hs=bQ;ht=bR;hu=au;hv=bU;hw=bV;hx=bW;T=969}else{hy=I;hz=bQ;hA=bR;hB=au;hC=bU;hD=bV;hE=bW;T=976}}else if((T|0)==977){T=0;if(b2>>>0<s>>>0){a[b2]=bY&255;hF=bX;hG=bY;hH=bZ-1|0;hI=b_;hJ=b$;hK=b0;hL=b1;hM=b2+1|0;T=967;break}else{c[J>>2]=52;gn=2;go=bX;gp=bY;gq=bZ;gr=b_;gs=b$;gt=b0;gu=b1;gv=b2;T=1199;continue L1368}}else if((T|0)==981){T=0;if(ca>>>0<s>>>0){cb=b3;cc=b4;cd=b5;ce=b6;cf=b7;cg=b8;ch=b9;ci=ca;T=983;continue L1368}c[J>>2]=9;gn=2;go=b3;gp=b4;gq=b5;gr=b6;gs=b7;gt=b8;gu=b9;gv=ca;T=1199;continue L1368}else if((T|0)==983){T=0;if(ch>>>0<q>>>0){au=s-ci|0;I=q-ch|0;at=au>>>0<I>>>0?au:I;I=at>>>0<cd>>>0?at:cd;s1(ci|0,ch|0,I)|0;hN=cb;hO=cc;hP=cd-I|0;hQ=ce;hR=cf;hS=cg;hT=ch+I|0;hU=ci+I|0;T=980;break}if((l&2|0)==0){cj=cb;ck=cc;cl=cd;cm=ce;cn=cf;co=cg;cp=ch;cq=ci;T=986;continue L1368}c[J>>2]=38;gn=1;go=cb;gp=cc;gq=cd;gr=ce;gs=cf;gt=cg;gu=ch;gv=ci;T=1199;continue L1368}else if((T|0)==986){T=0;c[J>>2]=40;gn=-1;go=cj;gp=ck;gq=cl;gr=cm;gs=cn;gt=co;gu=cp;gv=cq;T=1199;continue L1368}else if((T|0)==988){T=0;c[J>>2]=10;gn=-1;go=cr;gp=cs;gq=ct;gr=cu;gs=cv;gt=cw;gu=cx;gv=cy;T=1199;continue L1368}else if((T|0)==992){T=0;if((l&2|0)==0){cH=cz;cI=cA;cJ=cB;cK=cC;cL=0;cM=cD;cN=cE;cO=cF;cP=cG;T=997;continue L1368}c[J>>2]=11;gn=1;go=cz;gp=cA;gq=cB;gr=cC;gs=cD;gt=cE;gu=cF;gv=cG;T=1199;continue L1368}else if((T|0)==997){T=0;I=cL<<cH|cM;at=cH+8|0;au=a[49624+cJ|0]|0;if(at>>>0<au<<24>>24>>>0){hV=at;hW=cI;hX=cJ;hY=cK;hZ=I;h_=cN;h$=cO;h0=cP;T=991}else{h1=at;h2=cI;h3=cJ;h4=cK;h5=I;h6=cN;h7=cO;h8=cP;h9=au;T=998}}else if((T|0)==1003){T=0;if((l&2|0)==0){cY=cQ;cZ=cR;c_=cS;c$=0;c0=cT;c1=cU;c2=cV;c3=cW;c4=cX;T=1008;continue L1368}c[J>>2]=14;gn=1;go=cQ;gp=cR;gq=cS;gr=cT;gs=cU;gt=cV;gu=cW;gv=cX;T=1199;continue L1368}else if((T|0)==1008){T=0;au=c$<<cY|c1;I=cY+8|0;if(I>>>0<3){ia=I;ib=cZ;ic=c_;id=c0;ie=au;ig=c2;ih=c3;ii=c4;T=1002}else{ij=I;ik=cZ;il=c_;im=c0;io=au;ip=c2;iq=c3;ir=c4;T=1009}}else if((T|0)==1018){T=0;c[J>>2]=35;gn=-1;go=c5;gp=c6;gq=c7;gr=c8;gs=c9;gt=da;gu=db;gv=dc;T=1199;continue L1368}else if((T|0)==1048){T=0;if((l&2|0)==0){dl=0;dm=dd;dn=de;dp=df;dq=dg;dr=dh;ds=di;dt=dj;du=dk;T=1053;continue L1368}c[J>>2]=16;gn=1;go=dd;gp=de;gq=df;gr=dg;gs=dh;gt=di;gu=dj;gv=dk;T=1199;continue L1368}else if((T|0)==1053){T=0;au=dl<<dm|dr;I=dm+8|0;if(I>>>0<15){is=I;it=dn;iu=dp;iv=dq;iw=au;ix=ds;iy=dt;iz=du;T=1041}else{iA=I;iB=dp;iC=dq;iD=au;iE=ds;iF=dt;iG=du;T=1055}}else if((T|0)==1061){T=0;c[J>>2]=17;gn=-1;go=dv;gp=dw;gq=dx;gr=dy;gs=dz;gt=dA;gu=dB;gv=dC;T=1199;continue L1368}else if((T|0)==1064){T=0;if((l&2|0)==0){dL=0;dM=dD;dN=dE;dO=dF;dP=dG;dQ=dH;dR=dI;dS=dJ;dT=dK;T=1069;continue L1368}c[J>>2]=18;gn=1;go=dD;gp=dE;gq=dF;gr=dG;gs=dH;gt=dI;gu=dJ;gv=dK;T=1199;continue L1368}else if((T|0)==1069){T=0;au=dL<<dM|dQ;I=dM+8|0;if(I>>>0<dP>>>0){iH=I;iI=dN;iJ=dO;iK=dP;iL=au;iM=dR;iN=dS;iO=dT;T=1063}else{iP=I;iQ=dN;iR=dO;iS=dP;iT=au;iU=dR;iV=dS;iW=dT;T=1070}}else if((T|0)==1074){T=0;c[J>>2]=21;gn=-1;go=dU;gp=dV;gq=dW;gr=dX;gs=dY;gt=dZ;gu=d_;gv=d$;T=1199;continue L1368}else if((T|0)==1087){T=0;if((l&2|0)==0){d8=0;d9=d0;ea=d1;eb=d2;ec=d3;ed=d4;ee=d5;ef=d6;eg=d7;T=1092;continue L1368}c[J>>2]=23;gn=1;go=d0;gp=d1;gq=d2;gr=d3;gs=d4;gt=d5;gu=d6;gv=d7;T=1199;continue L1368}else if((T|0)==1092){T=0;au=d8<<d9|ed;I=d9+8|0;if(I>>>0<15){iX=I;iY=ea;iZ=eb;i_=ec;i$=au;i0=ee;i1=ef;i2=eg;T=1080}else{i3=I;i4=ea;i5=ec;i6=au;i7=ee;i8=ef;i9=eg;T=1094}}else if((T|0)==1098){T=0;if(eo>>>0<s>>>0){a[eo]=ej&255;ja=eh;jb=ei;jc=ej;jd=ek;je=el;jf=em;jg=en;jh=eo+1|0;T=1101;break}else{c[J>>2]=24;gn=2;go=eh;gp=ei;gq=ej;gr=ek;gs=el;gt=em;gu=en;gv=eo;T=1199;continue L1368}}else if((T|0)==1121){T=0;if((l&2|0)==0){ex=0;ey=ep;ez=eq;eA=er;eB=es;eC=et;eD=eu;eE=ev;eF=ew;T=1126;continue L1368}c[J>>2]=25;gn=1;go=ep;gp=eq;gq=er;gr=es;gs=et;gt=eu;gu=ev;gv=ew;T=1199;continue L1368}else if((T|0)==1126){T=0;au=ex<<ey|eC;I=ey+8|0;if(I>>>0<eB>>>0){ji=I;jj=ez;jk=eA;jl=eB;jm=au;jn=eD;jo=eE;jp=eF;T=1120}else{jq=I;jr=ez;js=eA;jt=eB;ju=au;jv=eD;jw=eE;jx=eF;T=1127}}else if((T|0)==1137){T=0;if((l&2|0)==0){eO=0;eP=eG;eQ=eH;eR=eI;eS=eJ;eT=eK;eU=eL;eV=eM;eW=eN;T=1142;continue L1368}c[J>>2]=26;gn=1;go=eG;gp=eH;gq=eI;gr=eJ;gs=eK;gt=eL;gu=eM;gv=eN;T=1199;continue L1368}else if((T|0)==1142){T=0;au=eO<<eP|eT;I=eP+8|0;if(I>>>0<15){jy=I;jz=eQ;jA=eR;jB=eS;jC=au;jD=eU;jE=eV;jF=eW;T=1130}else{jG=I;jH=eR;jI=au;jJ=eU;jK=eV;jL=eW;T=1144}}else if((T|0)==1150){T=0;if((l&2|0)==0){e3=0;e4=eX;e5=eY;e6=eZ;e7=e_;e8=e$;e9=e0;fa=e1;fb=e2;T=1155;continue L1368}c[J>>2]=27;gn=1;go=eX;gp=eY;gq=eZ;gr=e_;gs=e$;gt=e0;gu=e1;gv=e2;T=1199;continue L1368}else if((T|0)==1155){T=0;au=e3<<e4|e8;I=e4+8|0;if(I>>>0<e7>>>0){jM=I;jN=e5;jO=e6;jP=e7;jQ=au;jR=e9;jS=fa;jT=fb;T=1149}else{jU=I;jV=e5;jW=e6;jX=e7;jY=au;jZ=fa;j_=fb;T=1156}}else if((T|0)==1158){T=0;c[J>>2]=37;gn=-1;go=fc;gp=fd;gq=fe;gr=ff;gs=fg;gt=fh;gu=fi;gv=fj;T=1199;continue L1368}else if((T|0)==1161){T=0;if(fr>>>0<s>>>0){a[fr]=a[h+(fp-fl&u)|0]|0;j$=fk;j0=fl;j1=fm;j2=fn;j3=fo;j4=fp+1|0;j5=fq;j6=fr+1|0;T=1160;break}else{c[J>>2]=53;gn=2;go=fk;gp=fl;gq=fm;gr=fn;gs=fo;gt=fp;gu=fq;gv=fr;T=1199;continue L1368}}else if((T|0)==1173){T=0;if((l&2|0)==0){fA=0;fB=fs;fC=ft;fD=fu;fE=fv;fF=fw;fG=fx;fH=fy;fI=fz;T=1178;continue L1368}c[J>>2]=32;gn=1;go=fs;gp=ft;gq=fu;gr=fv;gs=fw;gt=fx;gu=fy;gv=fz;T=1199;continue L1368}else if((T|0)==1178){T=0;au=fA<<fB|fF;I=fB+8|0;if(I>>>0<(I&7)>>>0){j7=I;j8=fC;j9=fD;ka=fE;kb=au;kc=fG;kd=fH;ke=fI;T=1172}else{kf=I;kg=fC;kh=fE;ki=au;kj=fG;kk=fH;kl=fI;T=1179}}else if((T|0)==1184){T=0;if((l&2|0)==0){fR=0;fS=fJ;fT=fK;fU=fL;fV=fM;fW=fN;fX=fO;fY=fP;fZ=fQ;T=1189;continue L1368}c[J>>2]=41;gn=1;go=fJ;gp=fK;gq=fL;gr=fM;gs=fN;gt=fO;gu=fP;gv=fQ;T=1199;continue L1368}else if((T|0)==1189){T=0;au=fR<<fS|fW;I=fS+8|0;if(fS>>>0>4294967287){km=I;kn=fT;ko=fU;kp=fV;kq=au;kr=fX;ks=fY;kt=fZ;T=1183}else{ku=I;kv=fT;kw=fU;kx=fV;ky=au;kz=fX;kA=fY;kB=fZ;T=1190}}else if((T|0)==1192){T=0;if((l&2|0)==0){f6=0;f7=f_;f8=f$;f9=f0;ga=f1;gb=f2;gc=f3;gd=f4;ge=f5;T=1197;continue L1368}c[J>>2]=42;gn=1;go=f_;gp=f$;gq=f0;gr=f1;gs=f2;gt=f3;gu=f4;gv=f5;T=1199;continue L1368}else if((T|0)==1197){T=0;au=e+16|0;c[au>>2]=c[au>>2]<<8|f6;kC=f7;kD=f8;kE=f9+1|0;kF=ga;kG=gb;kH=gc;kI=gd;kJ=ge;T=1180}else if((T|0)==1198){T=0;c[J>>2]=34;gn=0;go=gf;gp=gg;gq=gh;gr=gi;gs=gj;gt=gk;gu=gl;gv=gm;T=1199;continue L1368}else if((T|0)==1199){T=0;c[w>>2]=go;c[y>>2]=gs;c[A>>2]=gp;c[D>>2]=gq;c[F>>2]=gr;c[H>>2]=gt;c[g>>2]=gu-f;kK=gv-j|0;c[k>>2]=kK;if((l&9|0)!=0&(gn|0)>-1){break L1368}else{v=gn;T=1213;break L1368}}}while(0);if((T|0)==929){T=0;if(gF>>>0>=q>>>0){av=gz;aw=gA;ax=gB;ay=gC;az=gD;aA=gE;aB=gF;aC=gG;T=930;continue}aD=gz;aE=gA;aF=gB;aG=gC;aH=gD;aI=d[gF]|0;aJ=gE;aK=gF+1|0;aL=gG;T=935;continue}do{if((T|0)==936){T=0;au=gL&7;c[e+20>>2]=au;I=gL>>>3;at=gH-3|0;as=au>>>1;au=e+24|0;c[au>>2]=as;if((as|0)==0){if(at>>>0<(at&7)>>>0){gP=at;gQ=gI;gR=gJ;gS=gK;gT=I;gU=gM;gV=gN;gW=gO;T=938;break}else{gX=at;gY=gI;gZ=gK;g_=I;g$=gM;g0=gN;g1=gO;T=945;break}}else if((as|0)==3){cr=at;cs=gI;ct=gJ;cu=gK;cv=I;cw=gM;cx=gN;cy=gO;T=988;continue L1368}else if((as|0)==1){c[e+44>>2]=288;c[e+48>>2]=32;s_(e+3552|0,5,32);s_(e+64|0,8,144);s_(e+208|0,9,112);s_(e+320|0,7,24);as=e+344|0;ar=as|0;C=134744072;a[ar]=C&255;C=C>>8;a[ar+1|0]=C&255;C=C>>8;a[ar+2|0]=C&255;C=C>>8;a[ar+3|0]=C&255;ar=as+4|0;C=134744072;a[ar]=C&255;C=C>>8;a[ar+1|0]=C&255;C=C>>8;a[ar+2|0]=C&255;C=C>>8;a[ar+3|0]=C&255;kL=at;kM=gI;kN=gJ;kO=gK;kP=I;kQ=gM;kR=gN;kS=gO;kT=au;kU=1;T=1012;break}else{kV=at;kW=gI;kX=0;kY=gK;kZ=I;k_=gM;k$=gN;k0=gO;T=989;break}}}while(0);if((T|0)==938){T=0;if(gV>>>0>=q>>>0){aM=gP;aN=gQ;aO=gR;aP=gS;aQ=gT;aR=gU;aS=gV;aT=gW;T=939;continue}aU=gP;aV=gQ;aW=gR;aX=gS;aY=gT;aZ=d[gV]|0;a_=gU;a$=gV+1|0;a0=gW;T=944;continue}else if((T|0)==945){T=0;I=gX&7;hi=gX-I|0;hj=gY;hk=0;hl=gZ;hm=g_>>>(I>>>0);hn=g$;ho=g0;hp=g1;T=946}do{if((T|0)==946){T=0;if(hk>>>0>=4){I=d[e+10529|0]<<8|d[e+10528|0];if((I|0)==((d[e+10531|0]<<8|d[e+10530|0])^65535|0)){hF=hi;hG=hj;hH=I;hI=hl;hJ=hm;hK=hn;hL=ho;hM=hp;T=967;break}else{by=hi;bz=hj;bA=I;bB=hl;bC=hm;bD=hn;bE=ho;bF=hp;T=966;continue L1368}}if((hi|0)!=0){if(hi>>>0<8){g2=hi;g3=hj;g4=hk;g5=hl;g6=hm;g7=hn;g8=ho;g9=hp;T=949;break}else{ha=hi;hb=hj;hc=hk;hd=hl;he=hm;hf=hn;hg=ho;hh=hp;T=956;break}}if(ho>>>0>=q>>>0){bi=0;bj=hj;bk=hk;bl=hl;bm=hm;bn=hn;bo=ho;bp=hp;T=958;continue L1368}a[e+10528+hk|0]=a[ho]|0;bq=0;br=hj;bs=hk;bt=hl;bu=hm;bv=hn;bw=ho+1|0;bx=hp;T=964;continue L1368}}while(0);do{if((T|0)==949){T=0;if(g8>>>0>=q>>>0){a1=g2;a2=g3;a3=g4;a4=g5;a5=g6;a6=g7;a7=g8;a8=g9;T=950;continue L1368}a9=g2;ba=g3;bb=g4;bc=g5;bd=g6;be=d[g8]|0;bf=g7;bg=g8+1|0;bh=g9;T=955;continue L1368}else if((T|0)==956){T=0;a[e+10528+hc|0]=he&255;bq=ha-8|0;br=hb;bs=hc;bt=hd;bu=he>>>8;bv=hf;bw=hg;bx=hh;T=964;continue L1368}else if((T|0)==967){T=0;if((hH|0)==0|(hF|0)==0){hN=hF;hO=hG;hP=hH;hQ=hI;hR=hJ;hS=hK;hT=hL;hU=hM;T=980;break}if(hF>>>0<8){hq=hF;hr=hG;hs=hH;ht=hI;hu=hJ;hv=hK;hw=hL;hx=hM;T=969}else{hy=hF;hz=hH;hA=hI;hB=hJ;hC=hK;hD=hL;hE=hM;T=976}}}while(0);if((T|0)==969){T=0;if(hw>>>0>=q>>>0){bG=hq;bH=hr;bI=hs;bJ=ht;bK=hu;bL=hv;bM=hw;bN=hx;T=970;continue}bO=hq;bP=hr;bQ=hs;bR=ht;bS=hu;bT=d[hw]|0;bU=hv;bV=hw+1|0;bW=hx;T=975;continue}else if((T|0)==976){T=0;bX=hy-8|0;bY=hB&255;bZ=hz;b_=hA;b$=hB>>>8;b0=hC;b1=hD;b2=hE;T=977;continue}else if((T|0)==980){T=0;if((hP|0)==0){k1=hN;k2=hO;k3=0;k4=hQ;k5=hR;k6=hS;k7=hT;k8=hU;T=1169}else{b3=hN;b4=hO;b5=hP;b6=hQ;b7=hR;b8=hS;b9=hT;ca=hU;T=981;continue}}L1481:while(1){L1482:do{if((T|0)==989){T=0;if(kX>>>0<3){I=a[49624+kX|0]|0;if(kV>>>0<I<<24>>24>>>0){hV=kV;hW=kW;hX=kX;hY=kY;hZ=kZ;h_=k_;h$=k$;h0=k0;T=991;continue L1481}else{h1=kV;h2=kW;h3=kX;h4=kY;h5=kZ;h6=k_;h7=k$;h8=k0;h9=I;T=998;continue L1481}}else{s_(e+7040|0,0,288);k9=kV;la=kW;lb=0;lc=kY;ld=kZ;le=k_;lf=k$;lg=k0;T=1e3;break}}else if((T|0)==991){T=0;if(h$>>>0<q>>>0){T=996;break L1481}else{cz=hV;cA=hW;cB=hX;cC=hY;cD=hZ;cE=h_;cF=h$;cG=h0;T=992;continue L1368}}else if((T|0)==998){T=0;I=h9<<24>>24;c[e+44+(h3<<2)>>2]=(c[256+(h3<<2)>>2]|0)+(h5&(1<<I)-1);kV=h1-I|0;kW=h2;kX=h3+1|0;kY=h4;kZ=h5>>>(I>>>0);k_=h6;k$=h7;k0=h8;T=989;continue L1481}else if((T|0)==1002){T=0;if(ih>>>0<q>>>0){T=1007;break L1481}else{cQ=ia;cR=ib;cS=ic;cT=id;cU=ie;cV=ig;cW=ih;cX=ii;T=1003;continue L1368}}else if((T|0)==1009){T=0;a[(d[400+il|0]|0)+(e+7040)|0]=io&7;k9=ij-3|0;la=ik;lb=il+1|0;lc=im;ld=io>>>3;le=ip;lf=iq;lg=ir;T=1e3}else if((T|0)==1012){T=0;if((kU|0)<=-1){ja=kL;jb=kM;jc=kN;jd=kO;je=kP;jf=kQ;jg=kR;jh=kS;T=1101;continue L1481}s_(o|0,0,64);s_(e+64+(kU*3488|0)+288|0,0,3200);I=c[kT>>2]|0;at=c[e+44+(I<<2)>>2]|0;if((at|0)==0){lh=0;li=0;lj=0;lk=0;ll=0;lm=0;ln=0;lo=0;lp=0;lq=0;lr=0;ls=0;lt=0;lu=0;lv=0;lw=0}else{au=0;do{ar=o+(d[e+64+(kU*3488|0)+au|0]<<2)|0;c[ar>>2]=(c[ar>>2]|0)+1;au=au+1|0;}while(au>>>0<at>>>0);lh=c[o+4>>2]|0;li=c[o+8>>2]|0;lj=c[o+12>>2]|0;lk=c[o+16>>2]|0;ll=c[o+20>>2]|0;lm=c[o+24>>2]|0;ln=c[o+28>>2]|0;lo=c[o+32>>2]|0;lp=c[o+36>>2]|0;lq=c[o+40>>2]|0;lr=c[o+44>>2]|0;ls=c[o+48>>2]|0;lt=c[o+52>>2]|0;lu=c[o+56>>2]|0;lv=c[o+60>>2]|0;lw=at}c[n+4>>2]=0;c[n>>2]=0;au=lh<<1;c[n+8>>2]=au;ar=au+li<<1;c[n+12>>2]=ar;au=ar+lj<<1;c[n+16>>2]=au;ar=au+lk<<1;c[n+20>>2]=ar;au=ar+ll<<1;c[n+24>>2]=au;ar=au+lm<<1;c[n+28>>2]=ar;au=ar+ln<<1;c[n+32>>2]=au;ar=au+lo<<1;c[n+36>>2]=ar;au=ar+lp<<1;c[n+40>>2]=au;ar=au+lq<<1;c[n+44>>2]=ar;au=ar+lr<<1;c[n+48>>2]=au;ar=au+ls<<1;c[n+52>>2]=ar;au=ar+lt<<1;c[n+56>>2]=au;ar=au+lu<<1;c[n+60>>2]=ar;au=ar+lv<<1;c[n+64>>2]=au;if((au|0)!=65536&(lu+lv+lt+ls+lr+lq+lp+lo+ln+lm+ll+lk+lj+li+lh|0)>>>0>1){c5=kL;c6=kM;c7=kN;c8=kO;c9=kP;da=kQ;db=kR;dc=kS;T=1018;continue L1368}if((lw|0)==0){lx=I}else{au=-1;ar=0;while(1){as=a[e+64+(kU*3488|0)+ar|0]|0;aq=as&255;L1502:do{if(as<<24>>24==0){ly=au}else{ap=n+(aq<<2)|0;an=c[ap>>2]|0;c[ap>>2]=an+1;ap=0;am=aq;al=an;while(1){lz=ap<<1|al&1;an=am-1|0;if((an|0)==0){break}else{ap=lz;am=an;al=al>>>1}}if((as&255)<11){al=(aq<<9|ar)&65535;if(lz>>>0>=1024){ly=au;break}am=1<<aq;an=lz;while(1){b[e+64+(kU*3488|0)+288+(an<<1)>>1]=al;gx=an+am|0;if(gx>>>0<1024){an=gx}else{ly=au;break L1502}}}an=e+64+(kU*3488|0)+288+((lz&1023)<<1)|0;am=b[an>>1]|0;if(am<<16>>16==0){b[an>>1]=au&65535;lA=au;lB=au-2|0}else{lA=am<<16>>16;lB=au}am=ap>>>9;an=lA-(am&1)|0;if((as&255)>11){al=lB;gx=aq;ak=am&4194303;am=an;while(1){aj=e+64+(kU*3488|0)+2336+(~am<<1)|0;gw=b[aj>>1]|0;if(gw<<16>>16==0){b[aj>>1]=al&65535;lC=al;lD=al-2|0}else{lC=gw<<16>>16;lD=al}gw=gx-1|0;aj=ak>>>1;gy=lC-(aj&1)|0;if(gw>>>0>11){al=lD;gx=gw;ak=aj;am=gy}else{lE=lD;lF=gy;break}}}else{lE=lB;lF=an}b[e+64+(kU*3488|0)+2336+(~lF<<1)>>1]=ar&65535;ly=lE}}while(0);aq=ar+1|0;as=c[kT>>2]|0;if(aq>>>0<(c[e+44+(as<<2)>>2]|0)>>>0){au=ly;ar=aq}else{lx=as;break}}}if((lx|0)==2){lG=kL;lH=kM;lI=0;lJ=kO;lK=kP;lL=kQ;lM=kR;lN=kS;T=1038;break}lO=kL;lP=kM;lQ=kN;lR=kO;lS=kP;lT=kQ;lU=kR;lV=kS;lW=lx;lX=e+24|0;T=1076}else if((T|0)==1041){T=0;ar=b[e+7328+((iw&1023)<<1)>>1]|0;au=ar<<16>>16;if(ar<<16>>16>-1){ar=au>>9;if((ar|0)==0|is>>>0<ar>>>0){T=1047;break L1481}else{iA=is;iB=iu;iC=iv;iD=iw;iE=ix;iF=iy;iG=iz;T=1055;continue L1481}}if(is>>>0>10){lY=10;lZ=au}else{T=1047;break L1481}while(1){l_=b[e+9376+((iw>>>(lY>>>0)&1)+~lZ<<1)>>1]|0;if(l_<<16>>16>=0){iA=is;iB=iu;iC=iv;iD=iw;iE=ix;iF=iy;iG=iz;T=1055;continue L1481}if(is>>>0<(lY+2|0)>>>0){break}else{lY=lY+1|0;lZ=l_<<16>>16}}if(l_<<16>>16>-1){iA=is;iB=iu;iC=iv;iD=iw;iE=ix;iF=iy;iG=iz;T=1055;continue L1481}else{T=1047;break L1481}}else if((T|0)==1055){T=0;au=b[e+7328+((iD&1023)<<1)>>1]|0;ar=au<<16>>16;if(au<<16>>16>-1){l$=ar>>9;l0=ar&511}else{au=10;I=ar;while(1){ar=au+1|0;at=b[e+9376+((iD>>>(au>>>0)&1)+~I<<1)>>1]|0;as=at<<16>>16;if(at<<16>>16<0){au=ar;I=as}else{l$=ar;l0=as;break}}}I=iD>>>(l$>>>0);au=iA-l$|0;if(l0>>>0<16){a[e+10532+iB|0]=l0&255;lG=au;lH=l0;lI=iB+1|0;lJ=iC;lK=I;lL=iE;lM=iF;lN=iG;T=1038;break}if((l0|0)==16&(iB|0)==0){dv=au;dw=16;dx=0;dy=iC;dz=I;dA=iE;dB=iF;dC=iG;T=1061;continue L1368}as=a[47384+(l0-16)|0]|0;if(au>>>0<as>>>0){iH=au;iI=l0;iJ=iB;iK=as;iL=I;iM=iE;iN=iF;iO=iG;T=1063;continue L1481}else{iP=au;iQ=l0;iR=iB;iS=as;iT=I;iU=iE;iV=iF;iW=iG;T=1070;continue L1481}}else if((T|0)==1063){T=0;if(iN>>>0<q>>>0){T=1068;break L1481}else{dD=iH;dE=iI;dF=iJ;dG=iK;dH=iL;dI=iM;dJ=iN;dK=iO;T=1064;continue L1368}}else if((T|0)==1070){T=0;I=(a[45928+(iQ-16)|0]|0)+((1<<iS)-1&iT)|0;if((iQ|0)==16){l1=a[iR-1+(e+10532)|0]|0}else{l1=0}s_(e+10532+iR|0,l1|0,I|0);lG=iP-iS|0;lH=iQ;lI=I+iR|0;lJ=iS;lK=iT>>>(iS>>>0);lL=iU;lM=iV;lN=iW;T=1038}else if((T|0)==1080){T=0;I=b[e+352+((i$&1023)<<1)>>1]|0;as=I<<16>>16;if(I<<16>>16>-1){I=as>>9;if((I|0)==0|iX>>>0<I>>>0){T=1086;break L1481}else{i3=iX;i4=iY;i5=i_;i6=i$;i7=i0;i8=i1;i9=i2;T=1094;continue L1481}}if(iX>>>0>10){l2=10;l3=as}else{T=1086;break L1481}while(1){l4=b[e+2400+((i$>>>(l2>>>0)&1)+~l3<<1)>>1]|0;if(l4<<16>>16>=0){i3=iX;i4=iY;i5=i_;i6=i$;i7=i0;i8=i1;i9=i2;T=1094;continue L1481}if(iX>>>0<(l2+2|0)>>>0){break}else{l2=l2+1|0;l3=l4<<16>>16}}if(l4<<16>>16>-1){i3=iX;i4=iY;i5=i_;i6=i$;i7=i0;i8=i1;i9=i2;T=1094;continue L1481}else{T=1086;break L1481}}else if((T|0)==1094){T=0;as=b[e+352+((i6&1023)<<1)>>1]|0;I=as<<16>>16;if(as<<16>>16>-1){l5=I>>9;l6=I&511}else{as=10;au=I;while(1){I=as+1|0;ar=b[e+2400+((i6>>>(as>>>0)&1)+~au<<1)>>1]|0;at=ar<<16>>16;if(ar<<16>>16<0){as=I;au=at}else{l5=I;l6=at;break}}}au=i6>>>(l5>>>0);as=i3-l5|0;if(l6>>>0>255){l7=as;l8=i4;l9=l6;ma=i5;mb=au;mc=i7;md=i8;me=i9;T=1117}else{eh=as;ei=i4;ej=l6;ek=i5;el=au;em=i7;en=i8;eo=i9;T=1098;continue L1368}}else if((T|0)==1101){T=0;au=q;as=au-jg|0;L1566:do{if((as|0)<4){mf=jh;mg=jg;mh=je;mi=jc;mj=ja;mk=as}else{at=s;I=jh;ar=jg;aq=je;am=jc;ak=ja;gx=as;while(1){if((at-I|0)<2){mf=I;mg=ar;mh=aq;mi=am;mj=ak;mk=gx;break L1566}if(ak>>>0<15){ml=ak+16|0;mm=(d[ar+1|0]<<8|d[ar])<<ak|aq;mn=ar+2|0}else{ml=ak;mm=aq;mn=ar}al=b[e+352+((mm&1023)<<1)>>1]|0;ap=al<<16>>16;if(al<<16>>16>-1){mo=ap>>9;mp=ap}else{al=10;gy=ap;while(1){ap=al+1|0;aj=b[e+2400+((mm>>>(al>>>0)&1)+~gy<<1)>>1]|0;gw=aj<<16>>16;if(aj<<16>>16<0){al=ap;gy=gw}else{mo=ap;mp=gw;break}}}gy=mm>>>(mo>>>0);al=ml-mo|0;if((mp&256|0)!=0){l7=al;l8=jb;l9=mp;ma=jd;mb=gy;mc=jf;md=mn;me=I;T=1117;break L1482}if(al>>>0<15){mq=al+16|0;mr=(d[mn+1|0]<<8|d[mn])<<al|gy;ms=mn+2|0}else{mq=al;mr=gy;ms=mn}gy=b[e+352+((mr&1023)<<1)>>1]|0;al=gy<<16>>16;if(gy<<16>>16>-1){mt=al>>9;mu=al}else{gy=10;an=al;while(1){al=gy+1|0;gw=b[e+2400+((mr>>>(gy>>>0)&1)+~an<<1)>>1]|0;ap=gw<<16>>16;if(gw<<16>>16<0){gy=al;an=ap}else{mt=al;mu=ap;break}}}mv=mr>>>(mt>>>0);mw=mq-mt|0;a[I]=mp&255;if((mu&256|0)!=0){break}a[I+1|0]=mu&255;an=I+2|0;gy=au-ms|0;if((gy|0)<4){mf=an;mg=ms;mh=mv;mi=mp;mj=mw;mk=gy;break L1566}else{I=an;ar=ms;aq=mv;am=mp;ak=mw;gx=gy}}l7=mw;l8=jb;l9=mu;ma=jd;mb=mv;mc=jf;md=ms;me=I+1|0;T=1117;break L1482}}while(0);if(mj>>>0>=15){i3=mj;i4=jb;i5=jd;i6=mh;i7=jf;i8=mg;i9=mf;T=1094;continue L1481}if((mk|0)<2){iX=mj;iY=jb;iZ=mi;i_=jd;i$=mh;i0=jf;i1=mg;i2=mf;T=1080;continue L1481}i3=mj+16|0;i4=jb;i5=jd;i6=d[mg]<<mj|mh|d[mg+1|0]<<mj+8;i7=jf;i8=mg+2|0;i9=mf;T=1094;continue L1481}else if((T|0)==1120){T=0;if(jo>>>0<q>>>0){T=1125;break L1481}else{ep=ji;eq=jj;er=jk;es=jl;et=jm;eu=jn;ev=jo;ew=jp;T=1121;continue L1368}}else if((T|0)==1127){T=0;mx=jq-jt|0;my=jr;mz=((1<<jt)-1&ju)+js|0;mA=jt;mB=ju>>>(jt>>>0);mC=jv;mD=jw;mE=jx}else if((T|0)==1130){T=0;au=b[e+3840+((jC&1023)<<1)>>1]|0;as=au<<16>>16;if(au<<16>>16>-1){au=as>>9;if((au|0)==0|jy>>>0<au>>>0){T=1136;break L1481}else{jG=jy;jH=jA;jI=jC;jJ=jD;jK=jE;jL=jF;T=1144;continue L1481}}if(jy>>>0>10){mF=10;mG=as}else{T=1136;break L1481}while(1){mH=b[e+5888+((jC>>>(mF>>>0)&1)+~mG<<1)>>1]|0;if(mH<<16>>16>=0){jG=jy;jH=jA;jI=jC;jJ=jD;jK=jE;jL=jF;T=1144;continue L1481}if(jy>>>0<(mF+2|0)>>>0){break}else{mF=mF+1|0;mG=mH<<16>>16}}if(mH<<16>>16>-1){jG=jy;jH=jA;jI=jC;jJ=jD;jK=jE;jL=jF;T=1144;continue L1481}else{T=1136;break L1481}}else if((T|0)==1144){T=0;as=b[e+3840+((jI&1023)<<1)>>1]|0;au=as<<16>>16;if(as<<16>>16>-1){mI=au>>9;mJ=au&511}else{as=10;gx=au;while(1){au=as+1|0;ak=b[e+5888+((jI>>>(as>>>0)&1)+~gx<<1)>>1]|0;am=ak<<16>>16;if(ak<<16>>16<0){as=au;gx=am}else{mI=au;mJ=am;break}}}gx=jI>>>(mI>>>0);as=jG-mI|0;am=c[552+(mJ<<2)>>2]|0;au=c[680+(mJ<<2)>>2]|0;if((mJ-4|0)>>>0>=26){mK=as;mL=au;mM=jH;mN=am;mO=gx;mP=jK;mQ=jL;T=1157;break}if(as>>>0<am>>>0){jM=as;jN=au;jO=jH;jP=am;jQ=gx;jR=jJ;jS=jK;jT=jL;T=1149;continue L1481}else{jU=as;jV=au;jW=jH;jX=am;jY=gx;jZ=jK;j_=jL;T=1156;continue L1481}}else if((T|0)==1149){T=0;if(jS>>>0<q>>>0){T=1154;break L1481}else{eX=jM;eY=jN;eZ=jO;e_=jP;e$=jQ;e0=jR;e1=jS;e2=jT;T=1150;continue L1368}}else if((T|0)==1156){T=0;mK=jU-jX|0;mL=((1<<jX)-1&jY)+jV|0;mM=jW;mN=jX;mO=jY>>>(jX>>>0);mP=jZ;mQ=j_;T=1157}else if((T|0)==1160){T=0;gx=j1-1|0;if((j1|0)==0){ja=j$;jb=j0;jc=gx;jd=j2;je=j3;jf=j4;jg=j5;jh=j6;T=1101;continue L1481}else{fk=j$;fl=j0;fm=gx;fn=j2;fo=j3;fp=j4;fq=j5;fr=j6;T=1161;continue L1368}}else if((T|0)==1169){T=0;if((c[e+20>>2]&1|0)==0){L=k1;M=k2;N=k3;O=k4;P=k5;Q=k6;R=k7;S=k8;T=928;continue L1368}if((l&1|0)==0){gf=k1;gg=k2;gh=k3;gi=k4;gj=k5;gk=k6;gl=k7;gm=k8;T=1198;continue L1368}if(k1>>>0<(k1&7)>>>0){j7=k1;j8=k2;j9=k3;ka=k4;kb=k5;kc=k6;kd=k7;ke=k8;T=1172;continue L1481}else{kf=k1;kg=k2;kh=k4;ki=k5;kj=k6;kk=k7;kl=k8;T=1179;continue L1481}}else if((T|0)==1172){T=0;if(kd>>>0<q>>>0){T=1177;break L1481}else{fs=j7;ft=j8;fu=j9;fv=ka;fw=kb;fx=kc;fy=kd;fz=ke;T=1173;continue L1368}}else if((T|0)==1179){T=0;gx=kf&7;kC=kf-gx|0;kD=kg;kE=0;kF=kh;kG=ki>>>(gx>>>0);kH=kj;kI=kk;kJ=kl;T=1180;continue L1481}else if((T|0)==1180){T=0;if(kE>>>0>=4){gf=kC;gg=kD;gh=kE;gi=kF;gj=kG;gk=kH;gl=kI;gm=kJ;T=1198;continue L1368}if((kC|0)==0){T=1191;break L1481}if(kC>>>0<8){km=kC;kn=kD;ko=kE;kp=kF;kq=kG;kr=kH;ks=kI;kt=kJ;T=1183;continue L1481}else{ku=kC;kv=kD;kw=kE;kx=kF;ky=kG;kz=kH;kA=kI;kB=kJ;T=1190;continue L1481}}else if((T|0)==1183){T=0;if(ks>>>0<q>>>0){T=1188;break L1481}else{fJ=km;fK=kn;fL=ko;fM=kp;fN=kq;fO=kr;fP=ks;fQ=kt;T=1184;continue L1368}}else if((T|0)==1190){T=0;f6=ky&255;f7=ku-8|0;f8=kv;f9=kw;ga=kx;gb=ky>>>8;gc=kz;gd=kA;ge=kB;T=1197;continue L1368}}while(0);do{if((T|0)==1e3){T=0;gx=e+52|0;if(lb>>>0<(c[gx>>2]|0)>>>0){if(k9>>>0<3){ia=k9;ib=la;ic=lb;id=lc;ie=ld;ig=le;ih=lf;ii=lg;T=1002;continue L1481}else{ij=k9;ik=la;il=lb;im=lc;io=ld;ip=le;iq=lf;ir=lg;T=1009;continue L1481}}else{c[gx>>2]=19;gx=e+24|0;kL=k9;kM=la;kN=lb;kO=lc;kP=ld;kQ=le;kR=lf;kS=lg;kT=gx;kU=c[gx>>2]|0;T=1012;continue L1481}}else if((T|0)==1038){T=0;gx=c[e+44>>2]|0;am=c[e+48>>2]|0;au=am+gx|0;if(lI>>>0>=au>>>0){if((au|0)!=(lI|0)){dU=lG;dV=lH;dW=lI;dX=lJ;dY=lK;dZ=lL;d_=lM;d$=lN;T=1074;continue L1368}au=e+64|0;as=e+10532|0;s1(au|0,as|0,gx)|0;as=e+3552|0;au=e+10532+gx|0;s1(as|0,au|0,am)|0;am=e+24|0;lO=lG;lP=lH;lQ=lI;lR=lJ;lS=lK;lT=lL;lU=lM;lV=lN;lW=c[am>>2]|0;lX=am;T=1076;break}if(lG>>>0>=15){iA=lG;iB=lI;iC=lJ;iD=lK;iE=lL;iF=lM;iG=lN;T=1055;continue L1481}if((q-lM|0)<2){is=lG;it=lH;iu=lI;iv=lJ;iw=lK;ix=lL;iy=lM;iz=lN;T=1041;continue L1481}iA=lG+16|0;iB=lI;iC=lJ;iD=d[lM]<<lG|lK|d[lM+1|0]<<lG+8;iE=lL;iF=lM+2|0;iG=lN;T=1055;continue L1481}else if((T|0)==1117){T=0;am=l9&511;if((am|0)==256){k1=l7;k2=l8;k3=256;k4=ma;k5=mb;k6=mc;k7=md;k8=me;T=1169;continue L1481}au=am-257|0;as=c[272+(au<<2)>>2]|0;gx=c[424+(au<<2)>>2]|0;if((am-265|0)>>>0>=20){mx=l7;my=l8;mz=gx;mA=as;mB=mb;mC=mc;mD=md;mE=me;break}if(l7>>>0<as>>>0){ji=l7;jj=l8;jk=gx;jl=as;jm=mb;jn=mc;jo=md;jp=me;T=1120;continue L1481}else{jq=l7;jr=l8;js=gx;jt=as;ju=mb;jv=mc;jw=md;jx=me;T=1127;continue L1481}}else if((T|0)==1157){T=0;as=mQ-h|0;if(!(mL>>>0<=as>>>0|t^1)){fc=mK;fd=mL;fe=mM;ff=mN;fg=mO;fh=as;fi=mP;fj=mQ;T=1158;continue L1368}gx=h+(as-mL&u)|0;if(((mQ>>>0>gx>>>0?mQ:gx)+mM|0)>>>0>s>>>0){j$=mK;j0=mL;j1=mM;j2=mN;j3=mO;j4=as;j5=mP;j6=mQ;T=1160;continue L1481}else{mR=gx;mS=mM;mT=mQ}while(1){a[mT]=a[mR]|0;a[mT+1|0]=a[mR+1|0]|0;a[mT+2|0]=a[mR+2|0]|0;mU=mT+3|0;mV=mR+3|0;mW=mS-3|0;if((mW|0)>2){mR=mV;mS=mW;mT=mU}else{break}}if((mW|0)<=0){ja=mK;jb=mL;jc=mW;jd=mN;je=mO;jf=as;jg=mP;jh=mU;T=1101;continue L1481}a[mU]=a[mV]|0;if((mW|0)>1){a[mT+4|0]=a[mR+4|0]|0}ja=mK;jb=mL;jc=mW;jd=mN;je=mO;jf=as;jg=mP;jh=mT+mS|0;T=1101;continue L1481}}while(0);if((T|0)==1076){T=0;gx=lW-1|0;c[lX>>2]=gx;kL=lO;kM=lP;kN=lQ;kO=lR;kP=lS;kQ=lT;kR=lU;kS=lV;kT=lX;kU=gx;T=1012;continue}if(mx>>>0>=15){jG=mx;jH=mz;jI=mB;jJ=mC;jK=mD;jL=mE;T=1144;continue}if((q-mD|0)<2){jy=mx;jz=my;jA=mz;jB=mA;jC=mB;jD=mC;jE=mD;jF=mE;T=1130;continue}jG=mx+16|0;jH=mz;jI=d[mD]<<mx|mB|d[mD+1|0]<<mx+8;jJ=mC;jK=mD+2|0;jL=mE;T=1144}if((T|0)==996){T=0;cH=hV;cI=hW;cJ=hX;cK=hY;cL=d[h$]|0;cM=hZ;cN=h_;cO=h$+1|0;cP=h0;T=997;continue}else if((T|0)==1007){T=0;cY=ia;cZ=ib;c_=ic;c$=d[ih]|0;c0=id;c1=ie;c2=ig;c3=ih+1|0;c4=ii;T=1008;continue}else if((T|0)==1047){T=0;if(iy>>>0>=q>>>0){dd=is;de=it;df=iu;dg=iv;dh=iw;di=ix;dj=iy;dk=iz;T=1048;continue}dl=d[iy]|0;dm=is;dn=it;dp=iu;dq=iv;dr=iw;ds=ix;dt=iy+1|0;du=iz;T=1053;continue}else if((T|0)==1068){T=0;dL=d[iN]|0;dM=iH;dN=iI;dO=iJ;dP=iK;dQ=iL;dR=iM;dS=iN+1|0;dT=iO;T=1069;continue}else if((T|0)==1086){T=0;if(i1>>>0>=q>>>0){d0=iX;d1=iY;d2=iZ;d3=i_;d4=i$;d5=i0;d6=i1;d7=i2;T=1087;continue}d8=d[i1]|0;d9=iX;ea=iY;eb=iZ;ec=i_;ed=i$;ee=i0;ef=i1+1|0;eg=i2;T=1092;continue}else if((T|0)==1125){T=0;ex=d[jo]|0;ey=ji;ez=jj;eA=jk;eB=jl;eC=jm;eD=jn;eE=jo+1|0;eF=jp;T=1126;continue}else if((T|0)==1136){T=0;if(jE>>>0>=q>>>0){eG=jy;eH=jz;eI=jA;eJ=jB;eK=jC;eL=jD;eM=jE;eN=jF;T=1137;continue}eO=d[jE]|0;eP=jy;eQ=jz;eR=jA;eS=jB;eT=jC;eU=jD;eV=jE+1|0;eW=jF;T=1142;continue}else if((T|0)==1154){T=0;e3=d[jS]|0;e4=jM;e5=jN;e6=jO;e7=jP;e8=jQ;e9=jR;fa=jS+1|0;fb=jT;T=1155;continue}else if((T|0)==1177){T=0;fA=d[kd]|0;fB=j7;fC=j8;fD=j9;fE=ka;fF=kb;fG=kc;fH=kd+1|0;fI=ke;T=1178;continue}else if((T|0)==1188){T=0;fR=d[ks]|0;fS=km;fT=kn;fU=ko;fV=kp;fW=kq;fX=kr;fY=ks+1|0;fZ=kt;T=1189;continue}else if((T|0)==1191){T=0;if(kI>>>0>=q>>>0){f_=0;f$=kD;f0=kE;f1=kF;f2=kG;f3=kH;f4=kI;f5=kJ;T=1192;continue}f6=d[kI]|0;f7=0;f8=kD;f9=kE;ga=kF;gb=kG;gc=kH;gd=kI+1|0;ge=kJ;T=1197;continue}}if((T|0)==1213){i=m;return v|0}T=e+28|0;kJ=c[T>>2]|0;ge=kJ&65535;kI=kJ>>>16;if((gv|0)==(j|0)){mX=ge;mY=kI}else{gv=j;j=kK;kJ=ge;ge=kI;kI=(kK>>>0)%5552|0;while(1){if(kI>>>0>7){kK=gv;gd=0;kH=kJ;gc=ge;while(1){kG=(d[kK]|0)+kH|0;gb=kG+(d[kK+1|0]|0)|0;kF=gb+(d[kK+2|0]|0)|0;ga=kF+(d[kK+3|0]|0)|0;kE=ga+(d[kK+4|0]|0)|0;f9=kE+(d[kK+5|0]|0)|0;kD=f9+(d[kK+6|0]|0)|0;f8=kD+(d[kK+7|0]|0)|0;f7=kG+gc+gb+kF+ga+kE+f9+kD+f8|0;kD=gd+8|0;f9=kK+8|0;if((kD|7)>>>0<kI>>>0){kK=f9;gd=kD;kH=f8;gc=f7}else{mZ=f9;m_=kD;m$=f8;m0=f7;break}}}else{mZ=gv;m_=0;m$=kJ;m0=ge}if(m_>>>0<kI>>>0){gc=mZ;kH=m_;gd=m$;kK=m0;while(1){m1=(d[gc]|0)+gd|0;m2=m1+kK|0;f7=kH+1|0;if(f7>>>0<kI>>>0){gc=gc+1|0;kH=f7;gd=m1;kK=m2}else{break}}m3=mZ+(kI-m_)|0;m4=m1;m5=m2}else{m3=mZ;m4=m$;m5=m0}kK=(m4>>>0)%65521|0;gd=(m5>>>0)%65521|0;if((j|0)==(kI|0)){mX=kK;mY=gd;break}else{gv=m3;j=j-kI|0;kJ=kK;ge=gd;kI=5552}}}kI=mY<<16|mX;c[T>>2]=kI;if((gn|0)!=0){v=gn;i=m;return v|0}if((l&1|0)==0){v=0;i=m;return v|0}else{i=m;return((kI|0)==(c[e+16>>2]|0)?0:-2)|0}return 0}function ku(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;s_(b|0,0,51);g=0;do{h=0;i=a[f+g|0]|0;while(1){j=0;k=51;while(1){l=k-1|0;m=b+l|0;n=((d[m]|0)<<1)+j|0;a[m]=n&255;if((l|0)>0){j=n>>8;k=l}else{break}}k=i<<1;do{if(i<<24>>24<0){j=0;l=51;while(1){n=l-1|0;m=b+n|0;o=(d[m]|0)+j+(d[e+n|0]|0)|0;a[m]=o&255;if((n|0)>0){j=(o|0)>255|0;l=n}else{break}}l=sR(51)|0;do{if((l|0)==0){p=0;q=51}else{if((c[l-4>>2]&3|0)==0){p=0;q=51;break}s_(l|0,0,51);p=0;q=51}}while(0);do{q=q-1|0;j=(d[b+q|0]|0)-(d[62224+q|0]|0)+p|0;a[l+q|0]=j&255;p=j>>8;}while((q|0)>0);if((p|0)<=-1){sS(l);break}s1(b|0,l|0,51)|0;sS(l);j=sR(51)|0;do{if((j|0)==0){r=0;s=51}else{if((c[j-4>>2]&3|0)==0){r=0;s=51;break}s_(j|0,0,51);r=0;s=51}}while(0);do{s=s-1|0;l=(d[b+s|0]|0)-(d[62224+s|0]|0)+r|0;a[j+s|0]=l&255;r=l>>8;}while((s|0)>0);if((r|0)>-1){s1(b|0,j|0,51)|0;sS(j);break}else{sS(j);break}}else{l=sR(51)|0;do{if((l|0)==0){t=0;u=51}else{if((c[l-4>>2]&3|0)==0){t=0;u=51;break}s_(l|0,0,51);t=0;u=51}}while(0);do{u=u-1|0;j=(d[b+u|0]|0)-(d[62224+u|0]|0)+t|0;a[l+u|0]=j&255;t=j>>8;}while((u|0)>0);if((t|0)>-1){s1(b|0,l|0,51)|0;sS(l);break}else{sS(l);break}}}while(0);j=h+1|0;if((j|0)<8){h=j;i=k}else{break}}g=g+1|0;}while((g|0)<51);return}function kv(a){a=a|0;var b=0;c[a>>2]=56968;b=c[a+28>>2]|0;if((b|0)!=0){sS(b)}b=c[a+32>>2]|0;if((b|0)!=0){sS(b)}if((a|0)==0){return}sS(a);return}function kw(a){a=a|0;var b=0;c[a>>2]=56968;b=c[a+28>>2]|0;if((b|0)!=0){sS(b)}b=c[a+32>>2]|0;if((b|0)==0){return}sS(b);return}function kx(a){a=a|0;s_(a+96|0,0,16);return}function ky(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;be(35648,18,1,b|0)|0;if((be(a+96|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(a+100|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(a+104|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(a+108|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(a+112|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(a+116|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(a+120|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(a+124|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(a+24|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(a+4|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(a+8|0,4,1,b|0)|0)==0){d=0;return d|0}e=a+12|0;if((be(e|0,4,1,b|0)|0)==0){d=0;return d|0}do{if((c[e>>2]|0)!=0){f=a+20|0;if((be(f|0,4,1,b|0)|0)==0){d=0;return d|0}if((be(c[a+32>>2]|0,1,(c[f>>2]|0)+1|0,b|0)|0)==0){d=0}else{break}return d|0}}while(0);d=1;return d|0}function kz(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;i=i+64|0;k=j|0;c[f>>2]=56968;c[f+4>>2]=0;l=f+8|0;c[l>>2]=0;m=f+12|0;c[m>>2]=0;n=f+92|0;c[n>>2]=0;o=f+128|0;c[o>>2]=0;do{if((g|0)==0){p=0;q=1299}else{if((h|0)==0){c[o>>2]=0;q=1308;break}else{r=h;s=g;u=-1}while(1){v=r-1|0;w=d[s]|0;x=c[8192+(((w^u)&15)<<2)>>2]^u>>>4;y=x>>>4^c[8192+((x&15^w>>>4)<<2)>>2];if((v|0)==0){break}else{r=v;s=s+1|0;u=y}}p=~y;q=1299}}while(0);do{if((q|0)==1299){c[o>>2]=p;if((h|0)==0){q=1308;break}y=k|0;s1(y|0,g|0,64)|0;do{if((a[y]|0)==76){if((a[k+1|0]|0)!=89){q=1305;break}if((a[k+2|0]|0)!=78){q=1305;break}if((a[k+3|0]|0)!=88){q=1305;break}if((b[k+8>>1]|0)!=1){q=1305}}else{q=1305}}while(0);if((q|0)==1305){y=c[t>>2]|0;be(45912,14,1,y|0)|0}y=f+36|0;u=k+10|0;s7(y|0,u|0,32)|0;u=f+69|0;y=k+42|0;s7(u|0,y|0,16)|0;y=a[k+58|0]|0;u=f+88|0;c[u>>2]=y&255;if((y&255)<3){z=1;break}c[u>>2]=0;z=1}}while(0);if((q|0)==1308){b[k+4>>1]=0;b[k+6>>1]=0;p=f+36|0;s1(p|0,47968,17)|0;p=f+69|0;s1(p|0,47968,17)|0;c[f+88>>2]=0;z=0}switch(e[k+4>>1]|0){case 0:{c[f+16>>2]=0;c[f+112>>2]=0;c[f+116>>2]=0;break};case 256:{c[f+16>>2]=65535;c[f+112>>2]=8;c[f+116>>2]=255;break};case 512:{c[f+16>>2]=131071;c[f+112>>2]=9;c[f+116>>2]=511;break};case 1024:{c[f+16>>2]=262143;c[f+112>>2]=10;c[f+116>>2]=1023;break};case 2048:{c[f+16>>2]=524287;c[f+112>>2]=11;c[f+116>>2]=2047;break};default:{be(45912,14,1,c[t>>2]|0)|0}}switch(e[k+6>>1]|0){case 0:{k=f+20|0;c[k>>2]=0;c[f+120>>2]=0;c[f+124>>2]=0;A=0;B=k;break};case 256:{k=f+20|0;c[k>>2]=65535;c[f+120>>2]=8;c[f+124>>2]=255;A=1;B=k;break};case 512:{k=f+20|0;c[k>>2]=131071;c[f+120>>2]=9;c[f+124>>2]=511;A=2;B=k;break};case 1024:{k=f+20|0;c[k>>2]=262143;c[f+120>>2]=10;c[f+124>>2]=1023;A=3;B=k;break};case 2048:{k=f+20|0;c[k>>2]=524287;c[f+120>>2]=11;c[f+124>>2]=2047;A=4;B=k;break};default:{be(45912,14,1,c[t>>2]|0)|0;A=0;B=f+20|0}}k=f+16|0;p=(c[k>>2]|0)+1|0;o=(p|0)==0?1:p;while(1){C=sR(o)|0;if((C|0)!=0){break}p=(I=c[138018]|0,c[138018]=I+0,I);if((p|0)==0){q=1332;break}gp[p&63]()}if((q|0)==1332){o=fc(4)|0;c[o>>2]=53880;dq(o|0,60400,240)}o=f+28|0;c[o>>2]=C;C=(c[B>>2]|0)+1|0;p=(C|0)==0?1:C;while(1){D=sR(p)|0;if((D|0)!=0){break}C=(I=c[138018]|0,c[138018]=I+0,I);if((C|0)==0){q=1347;break}gp[C&63]()}if((q|0)==1347){p=fc(4)|0;c[p>>2]=53880;dq(p|0,60400,240)}p=f+32|0;c[p>>2]=D;c[f+24>>2]=0;D=h-64|0;h=(D|0)<0?0:D;D=(c[k>>2]|0)+1|0;C=(h|0)>(D|0)?D:h;D=(c[B>>2]|0)+1|0;u=(h|0)>(D|0)?D:h;h=c[o>>2]|0;D=g+64|0;s1(h|0,D|0,C)|0;s_((c[o>>2]|0)+C|0,17,1-C+(c[k>>2]|0)|0);h=c[p>>2]|0;s1(h|0,D|0,u)|0;s_((c[p>>2]|0)+C|0,17,1-u+(c[B>>2]|0)|0);if(z){c[135462]=0;c[n>>2]=1;z=c[k>>2]|0;k=c[o>>2]|0;o=0;do{if((a[k+(z&o)|0]|0)!=0){c[n>>2]=0}o=o+1|0;}while((o|0)<32)}if((A|0)!=0){i=j;return}A=c[p>>2]|0;if((A|0)!=0){sS(A)}c[B>>2]=65535;c[f+120>>2]=8;c[f+124>>2]=255;while(1){E=sR(65536)|0;if((E|0)!=0){q=1376;break}f=(I=c[138018]|0,c[138018]=I+0,I);if((f|0)==0){q=1370;break}gp[f&63]()}if((q|0)==1370){f=fc(4)|0;c[f>>2]=53880;dq(f|0,60400,240)}else if((q|0)==1376){c[p>>2]=E;s_(E|0,-1|0,(c[B>>2]|0)+1|0);c[l>>2]=1;c[m>>2]=1;i=j;return}}function kA(a,b){a=a|0;b=b|0;return 0}function kB(a,b,c){a=a|0;b=b|0;c=c|0;return}function kC(a,b){a=a|0;b=b|0;return 0}function kD(a,b){a=a|0;b=b|0;return}function kE(b,d,e){b=b|0;d=d|0;e=e|0;if((c[b+24>>2]|0)==0){if((c[b+4>>2]|0)==0){return}a[(c[b+28>>2]|0)+(c[b+16>>2]&d)|0]=e;return}else{if((c[b+8>>2]|0)==0){return}a[(c[b+32>>2]|0)+(c[b+20>>2]&d)|0]=e;return}}function kF(b,d){b=b|0;d=d|0;var e=0,f=0;if((c[b+24>>2]|0)==0){e=(c[b+28>>2]|0)+(c[b+16>>2]&d)|0;f=a[e]|0;return f|0}else{e=(c[b+32>>2]|0)+(c[b+20>>2]&d)|0;f=a[e]|0;return f|0}return 0}function kG(a,b){a=a|0;b=b|0;c[a+24>>2]=b;return}function kH(a){a=a|0;return(c[((c[a+24>>2]|0)==0?a+16|0:a+20|0)>>2]|0)+1|0}function kI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+20|0;d=c[b>>2]|0;e=0;f=d;g=c[d+262164>>2]|0;do{c[f+8+(e<<2)>>2]=g;e=e+1|0;f=c[b>>2]|0;g=c[f+262164>>2]|0}while((e|0)<65536);c[f+262120>>2]=g;g=c[b>>2]|0;c[g+262124>>2]=c[g+262160>>2];s_(a+4|0,-1|0,16);go[c[(c[a>>2]|0)+20>>2]&127](a,0,0);return}function kJ(a,b){a=a|0;b=b|0;var c=0;be(20864,20,1,b|0)|0;if((be(a+4|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+8|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+12|0,4,1,b|0)|0)==0){c=0;return c|0}c=(be(a+16|0,4,1,b|0)|0)!=0;return c|0}function kK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+104|0;e=d|0;s1(e|0,53608,100)|0;f=b+4|0;g=c[f>>2]|0;h=b+8|0;j=c[h>>2]|0;k=(g+18|0)>>>0>j>>>0?j-g|0:18;l=b|0;b=c[l>>2]|0;m=b+g|0;s1(e|0,m|0,k)|0;m=g+k|0;c[f>>2]=m;if((k|0)==0){n=0;i=d;return n|0}if((da(e|0,35648)|0)!=0){n=0;i=d;return n|0}e=a+96|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=b+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+100|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+104|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+108|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+112|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+116|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+120|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+124|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+24|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+4|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+8|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+12|0;m=j;e=c[h>>2]|0;b=(k+4|0)>>>0>e>>>0?e-k|0:4;e=(c[l>>2]|0)+k|0;s1(m|0,e|0,b)|0;e=(c[f>>2]|0)+b|0;c[f>>2]=e;if((b|0)==0){n=0;i=d;return n|0}do{if((c[j>>2]|0)!=0){b=a+20|0;m=b;k=c[h>>2]|0;g=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,g)|0;c[f>>2]=(c[f>>2]|0)+g;if((g|0)==0){n=0;i=d;return n|0}g=a+32|0;k=c[g>>2]|0;if((k|0)!=0){sS(k)}k=(c[b>>2]|0)+1|0;m=(k|0)==0?1:k;while(1){o=sR(m)|0;if((o|0)!=0){p=1447;break}k=(I=c[138018]|0,c[138018]=I+0,I);if((k|0)==0){p=1441;break}gp[k&63]()}if((p|0)==1441){m=fc(4)|0;c[m>>2]=53880;dq(m|0,60400,240);return 0}else if((p|0)==1447){c[g>>2]=o;m=(c[b>>2]|0)+1|0;k=c[f>>2]|0;q=c[h>>2]|0;r=(k+m|0)>>>0>q>>>0?q-k|0:m;m=(c[l>>2]|0)+k|0;s1(o|0,m|0,r)|0;c[f>>2]=k+r;if((r|0)==0){n=0}else{break}i=d;return n|0}}}while(0);n=1;i=d;return n|0}function kL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+104|0;e=d|0;f=a+36|0;s1(f|0,28512,14)|0;f=a+69|0;s1(f|0,23944,17)|0;f=e|0;s1(f|0,53608,100)|0;e=b+4|0;g=c[e>>2]|0;h=b+8|0;j=c[h>>2]|0;k=(g+18|0)>>>0>j>>>0?j-g|0:18;l=b|0;b=c[l>>2]|0;m=b+g|0;s1(f|0,m|0,k)|0;m=g+k|0;c[e>>2]=m;if((k|0)==0){n=0;i=d;return n|0}if((da(f|0,35648)|0)!=0){n=0;i=d;return n|0}f=a+88|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=b+m|0;s1(f|0,j|0,k)|0;j=(c[e>>2]|0)+k|0;c[e>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+92|0;f=c[h>>2]|0;m=(j+4|0)>>>0>f>>>0?f-j|0:4;f=(c[l>>2]|0)+j|0;s1(k|0,f|0,m)|0;f=(c[e>>2]|0)+m|0;c[e>>2]=f;if((m|0)==0){n=0;i=d;return n|0}m=a+96|0;k=c[h>>2]|0;j=(f+4|0)>>>0>k>>>0?k-f|0:4;k=(c[l>>2]|0)+f|0;s1(m|0,k|0,j)|0;k=(c[e>>2]|0)+j|0;c[e>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+100|0;m=c[h>>2]|0;f=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,f)|0;m=(c[e>>2]|0)+f|0;c[e>>2]=m;if((f|0)==0){n=0;i=d;return n|0}f=a+104|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(f|0,j|0,k)|0;j=(c[e>>2]|0)+k|0;c[e>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+108|0;f=c[h>>2]|0;m=(j+4|0)>>>0>f>>>0?f-j|0:4;f=(c[l>>2]|0)+j|0;s1(k|0,f|0,m)|0;f=(c[e>>2]|0)+m|0;c[e>>2]=f;if((m|0)==0){n=0;i=d;return n|0}m=a+112|0;k=c[h>>2]|0;j=(f+4|0)>>>0>k>>>0?k-f|0:4;k=(c[l>>2]|0)+f|0;s1(m|0,k|0,j)|0;k=(c[e>>2]|0)+j|0;c[e>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+116|0;m=c[h>>2]|0;f=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,f)|0;m=(c[e>>2]|0)+f|0;c[e>>2]=m;if((f|0)==0){n=0;i=d;return n|0}f=a+120|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(f|0,j|0,k)|0;j=(c[e>>2]|0)+k|0;c[e>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+124|0;f=c[h>>2]|0;m=(j+4|0)>>>0>f>>>0?f-j|0:4;f=(c[l>>2]|0)+j|0;s1(k|0,f|0,m)|0;f=(c[e>>2]|0)+m|0;c[e>>2]=f;if((m|0)==0){n=0;i=d;return n|0}m=a+24|0;k=c[h>>2]|0;j=(f+4|0)>>>0>k>>>0?k-f|0:4;k=(c[l>>2]|0)+f|0;s1(m|0,k|0,j)|0;k=(c[e>>2]|0)+j|0;c[e>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16|0;m=j;f=c[h>>2]|0;b=(k+4|0)>>>0>f>>>0?f-k|0:4;f=(c[l>>2]|0)+k|0;s1(m|0,f|0,b)|0;f=(c[e>>2]|0)+b|0;c[e>>2]=f;if((b|0)==0){n=0;i=d;return n|0}b=a+20|0;m=b;k=c[h>>2]|0;g=(f+4|0)>>>0>k>>>0?k-f|0:4;k=(c[l>>2]|0)+f|0;s1(m|0,k|0,g)|0;c[e>>2]=(c[e>>2]|0)+g;if((g|0)==0){n=0;i=d;return n|0}g=a+28|0;k=c[g>>2]|0;if((k|0)!=0){sS(k)}k=a+32|0;a=c[k>>2]|0;if((a|0)!=0){sS(a)}a=(c[j>>2]|0)+1|0;m=(a|0)==0?1:a;while(1){o=sR(m)|0;if((o|0)!=0){break}a=(I=c[138018]|0,c[138018]=I+0,I);if((a|0)==0){p=1495;break}gp[a&63]()}if((p|0)==1495){m=fc(4)|0;c[m>>2]=53880;dq(m|0,60400,240);return 0}c[g>>2]=o;o=(c[b>>2]|0)+1|0;m=(o|0)==0?1:o;while(1){q=sR(m)|0;if((q|0)!=0){break}o=(I=c[138018]|0,c[138018]=I+0,I);if((o|0)==0){p=1510;break}gp[o&63]()}if((p|0)==1510){p=fc(4)|0;c[p>>2]=53880;dq(p|0,60400,240);return 0}c[k>>2]=q;q=c[g>>2]|0;g=(c[j>>2]|0)+1|0;j=c[e>>2]|0;p=c[h>>2]|0;m=(j+g|0)>>>0>p>>>0?p-j|0:g;g=(c[l>>2]|0)+j|0;s1(q|0,g|0,m)|0;g=(c[e>>2]|0)+m|0;c[e>>2]=g;if((m|0)==0){n=0;i=d;return n|0}m=c[k>>2]|0;k=(c[b>>2]|0)+1|0;b=c[h>>2]|0;h=(k+g|0)>>>0>b>>>0?b-g|0:k;k=(c[l>>2]|0)+g|0;s1(m|0,k|0,h)|0;c[e>>2]=(c[e>>2]|0)+h;n=(h|0)!=0;i=d;return n|0}function kM(a){a=a|0;return}function kN(a){a=a|0;return 1}function kO(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=a>>>12;if((b&1|0)==0){c=0}else{c=a>>>7&1}if((b&2|0)==0){d=c}else{d=a&1^c}if((b&4|0)==0){e=d}else{e=a>>>1&1^d}if((b&8|0)==0){f=e}else{f=a>>>2&1^e}if((b&16|0)==0){g=f}else{g=a>>>3&1^f}if((b&32|0)==0){h=g}else{h=a>>>4&1^g}if((b&64|0)==0){i=h}else{i=a>>>5&1^h}if((b&128|0)==0){j=i}else{j=a>>>10&1^i}if((b&256|0)==0){k=j;l=(k|0)==0;m=l&1;n=b<<12;o=a<<1;p=o&4094;q=m|n;r=q|p;return r|0}k=a>>>11&1^j;l=(k|0)==0;m=l&1;n=b<<12;o=a<<1;p=o&4094;q=m|n;r=q|p;return r|0}function kP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=d&255;d=b&1;e=d^1;f=a+8|0;if((e|0)!=(c[f>>2]|0)){c[f>>2]=e;e=a+20|0;if((d|0)==0){d=64512;do{f=c[e>>2]|0;c[f+8+(d<<2)>>2]=c[f+262176>>2];d=d+1|0;}while((d|0)<64768)}else{d=64512;do{f=c[e>>2]|0;c[f+8+(d<<2)>>2]=c[f+262164>>2];d=d+1|0;}while((d|0)<64768)}}d=b&2;e=d>>>1^1;f=a+4|0;if((e|0)!=(c[f>>2]|0)){c[f>>2]=e;e=a+20|0;if((d|0)==0){d=64768;do{f=c[e>>2]|0;c[f+8+(d<<2)>>2]=c[f+262172>>2];d=d+1|0;}while((d|0)<65024)}else{d=64768;do{f=c[e>>2]|0;c[f+8+(d<<2)>>2]=c[f+262164>>2];d=d+1|0;}while((d|0)<65024)}}d=b&4;e=d>>>2^1;f=a+12|0;if((e|0)!=(c[f>>2]|0)){c[f>>2]=e;e=a+20|0;if((d|0)==0){d=65024;do{f=c[e>>2]|0;c[f+8+(d<<2)>>2]=c[f+262156>>2];d=d+1|0;}while((d|0)<65528)}else{d=65024;do{f=c[e>>2]|0;c[f+8+(d<<2)>>2]=c[f+262164>>2];d=d+1|0;}while((d|0)<65528)}}d=b&8;b=d>>>3^1;e=a+16|0;if((b|0)==(c[e>>2]|0)){return}c[e>>2]=b;b=a+20|0;a=c[b>>2]|0;if((d|0)==0){c[a+262128>>2]=c[a+262156>>2];d=c[b>>2]|0;c[d+262132>>2]=c[d+262156>>2];d=c[b>>2]|0;c[d+262136>>2]=c[d+262156>>2];d=c[b>>2]|0;c[d+262140>>2]=c[d+262156>>2];d=c[b>>2]|0;c[d+262144>>2]=c[d+262156>>2];d=c[b>>2]|0;c[d+262148>>2]=c[d+262156>>2];return}else{c[a+262128>>2]=c[a+262164>>2];a=c[b>>2]|0;c[a+262132>>2]=c[a+262164>>2];a=c[b>>2]|0;c[a+262136>>2]=c[a+262164>>2];a=c[b>>2]|0;c[a+262140>>2]=c[a+262164>>2];a=c[b>>2]|0;c[a+262144>>2]=c[a+262164>>2];a=c[b>>2]|0;c[a+262148>>2]=c[a+262164>>2];return}}function kQ(a,b){a=a|0;b=b|0;return((c[a+4>>2]|0)!=0?0:2)|(c[a+8>>2]|0)==0|((c[a+12>>2]|0)!=0?0:4)|((c[a+16>>2]|0)!=0?0:8)|0}function kR(a){a=a|0;c[a>>2]=56904;return}function kS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+104|0;e=d|0;s1(e|0,53360,100)|0;f$[c[(c[a>>2]|0)+8>>2]&511](a);f=b+4|0;g=c[f>>2]|0;h=b+8|0;j=c[h>>2]|0;k=(g+20|0)>>>0>j>>>0?j-g|0:20;l=b|0;b=c[l>>2]|0;m=b+g|0;s1(e|0,m|0,k)|0;m=g+k|0;c[f>>2]=m;if((k|0)==0){n=0;i=d;return n|0}if((da(e|0,20864)|0)!=0){n=0;i=d;return n|0}e=a+4|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=b+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+8|0;m=c[h>>2]|0;b=(j+4|0)>>>0>m>>>0?m-j|0:4;m=(c[l>>2]|0)+j|0;s1(k|0,m|0,b)|0;m=(c[f>>2]|0)+b|0;c[f>>2]=m;if((b|0)==0){n=0;i=d;return n|0}b=a+12|0;k=c[h>>2]|0;j=(m+4|0)>>>0>k>>>0?k-m|0:4;k=(c[l>>2]|0)+m|0;s1(b|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16|0;b=c[h>>2]|0;h=(k+4|0)>>>0>b>>>0?b-k|0:4;b=(c[l>>2]|0)+k|0;s1(j|0,b|0,h)|0;c[f>>2]=(c[f>>2]|0)+h;if((h|0)==0){n=0;i=d;return n|0}h=gj[c[(c[a>>2]|0)+24>>2]&127](a,0)|0;s_(e|0,-1|0,16);go[c[(c[a>>2]|0)+20>>2]&127](a,0,h);n=1;i=d;return n|0}function kT(a){a=a|0;if((a|0)==0){return}sS(a);return}function kU(a){a=a|0;c[a>>2]=56904;if((a|0)==0){return}sS(a);return}function kV(a){a=a|0;var b=0;c[a+17292>>2]=0;c[a+17296>>2]=0;c[a+17300>>2]=0;s_(a+8|0,0,16);b=c[a+4>>2]|0;c[a+17288>>2]=f2[c[(c[b>>2]|0)+44>>2]&255](b)|0;c[a+17068>>2]=0;c[a+17072>>2]=0;s_(a+16500|0,0,398);s_(a+16900|0,0,54);s_(a+16956|0,0,54);s_(a+17012|0,0,54);c[a+17076>>2]=255;c[a+24>>2]=0;c[a+28>>2]=1;c[a+32>>2]=2;c[a+36>>2]=3;c[a+40>>2]=4;c[a+44>>2]=5;c[a+48>>2]=6;c[a+52>>2]=7;c[a+56>>2]=8;c[a+60>>2]=9;c[a+64>>2]=10;c[a+68>>2]=11;c[a+72>>2]=12;c[a+76>>2]=13;c[a+80>>2]=14;c[a+84>>2]=15;c[a+17080>>2]=0;c[a+17084>>2]=0;s_(a+16472|0,0,28);c[a+17092>>2]=-2147483648;c[a+17088>>2]=-2147483648;s_(a+17096|0,0,24);s_(a+17260|0,0,20);return}function kW(a,b){a=a|0;b=b|0;var c=0;be(41120,19,1,b|0)|0;if((be(a+8|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+12|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+20|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+24|0,4,16,b|0)|0)==0){c=0;return c|0}if((be(a+88|0,4,4096,b|0)|0)==0){c=0;return c|0}if((be(a+16472|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16480|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16476|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16484|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16488|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16492|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16496|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16500|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16504|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16508|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16512|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16516|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16520|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16524|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16528|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16532|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16536|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16540|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16544|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16548|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16552|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16556|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16560|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16564|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16568|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16572|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16576|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16580|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16584|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16588|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16592|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16596|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16600|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16604|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16608|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16612|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16616|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16620|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16624|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16628|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16632|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16636|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16640|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16644|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16648|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16652|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16656|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16660|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16664|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16668|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16672|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16676|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16680|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16684|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16688|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16692|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16696|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16700|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16704|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16708|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16712|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16716|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16720|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16724|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16728|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16732|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16736|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16740|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16744|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16748|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16752|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16756|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16760|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16764|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16768|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16772|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16776|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16780|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16784|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16788|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16792|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16796|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16800|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16804|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16808|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16812|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16816|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16820|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16824|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16828|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16832|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16836|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16840|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16844|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16848|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16852|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16856|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16860|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16864|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16868|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16872|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16876|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16880|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16884|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16888|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16892|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16896|0,1,1,b|0)|0)==0){c=0;return c|0}if((be(a+16897|0,1,1,b|0)|0)==0){c=0;return c|0}if((be(a+16900|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16904|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16908|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16912|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16916|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16920|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16924|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16928|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16932|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16936|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16940|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16944|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16948|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16952|0,1,1,b|0)|0)==0){c=0;return c|0}if((be(a+16953|0,1,1,b|0)|0)==0){c=0;return c|0}if((be(a+16956|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16960|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16964|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16968|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16972|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16976|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16980|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16984|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16988|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16992|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+16996|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17e3|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17004|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17008|0,1,1,b|0)|0)==0){c=0;return c|0}if((be(a+17009|0,1,1,b|0)|0)==0){c=0;return c|0}if((be(a+17012|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17016|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17020|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17024|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17028|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17032|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17036|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17040|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17044|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17048|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17052|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17056|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17060|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17064|0,1,1,b|0)|0)==0){c=0;return c|0}if((be(a+17065|0,1,1,b|0)|0)==0){c=0;return c|0}if((be(a+17068|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17072|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17076|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17080|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17084|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17092|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17088|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17096|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17100|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17104|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17108|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+17112|0,4,1,b|0)|0)==0){c=0;return c|0}c=(be(a+17116|0,4,1,b|0)|0)!=0;return c|0}function kX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+104|0;e=d|0;s1(e|0,53504,100)|0;f=b+4|0;g=c[f>>2]|0;h=b+8|0;j=c[h>>2]|0;k=(g+19|0)>>>0>j>>>0?j-g|0:19;l=b|0;b=c[l>>2]|0;m=b+g|0;s1(e|0,m|0,k)|0;m=g+k|0;c[f>>2]=m;if((k|0)==0){n=0;i=d;return n|0}if((da(e|0,41120)|0)!=0){n=0;i=d;return n|0}e=a+8|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=b+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+12|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+20|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+24|0;j=c[h>>2]|0;k=(m+64|0)>>>0>j>>>0?j-m|0:64;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+88|0;e=c[h>>2]|0;m=(j+16384|0)>>>0>e>>>0?e-j|0:16384;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16472|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16480|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16476|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16484|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16488|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16492|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16496|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16500|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16504|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16508|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16512|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16516|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16520|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16524|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16528|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16532|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16536|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16540|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16544|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16548|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16552|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16556|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16560|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16564|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16568|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16572|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16576|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16580|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16584|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16588|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16592|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16596|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16600|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16604|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16608|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16612|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16616|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16620|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16624|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16628|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16632|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16636|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16640|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16644|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16648|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16652|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16656|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16660|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16664|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16668|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16672|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16676|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16680|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16684|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16688|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16692|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16696|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16700|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16704|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16708|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16712|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16716|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16720|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16724|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16728|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16732|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16736|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16740|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16744|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16748|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16752|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16756|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16760|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16764|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16768|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16772|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16776|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16780|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16784|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16788|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16792|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16796|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16800|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16804|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16808|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16812|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16816|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16820|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16824|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16828|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16832|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16836|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16840|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16844|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16848|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16852|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16856|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16860|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16864|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16868|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16872|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16876|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16880|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16884|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16888|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16892|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16896|0;j=c[h>>2]|0;k=(m+1|0)>>>0>j>>>0?j-m|0:1;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16897|0;e=c[h>>2]|0;m=(j+1|0)>>>0>e>>>0?e-j|0:1;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16900|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16904|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16908|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16912|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16916|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16920|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16924|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16928|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16932|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16936|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16940|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16944|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16948|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16952|0;m=c[h>>2]|0;e=(k+1|0)>>>0>m>>>0?m-k|0:1;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16953|0;j=c[h>>2]|0;k=(m+1|0)>>>0>j>>>0?j-m|0:1;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16956|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16960|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16964|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16968|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16972|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16976|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16980|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16984|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+16988|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+16992|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+16996|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+17e3|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+17004|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+17008|0;k=c[h>>2]|0;j=(e+1|0)>>>0>k>>>0?k-e|0:1;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+17009|0;m=c[h>>2]|0;e=(k+1|0)>>>0>m>>>0?m-k|0:1;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+17012|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+17016|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+17020|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+17024|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+17028|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+17032|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+17036|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+17040|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+17044|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+17048|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+17052|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+17056|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+17060|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+17064|0;e=c[h>>2]|0;m=(j+1|0)>>>0>e>>>0?e-j|0:1;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+17065|0;k=c[h>>2]|0;j=(e+1|0)>>>0>k>>>0?k-e|0:1;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+17068|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+17072|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+17076|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+17080|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+17084|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+17092|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+17088|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+17096|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+17100|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+17104|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+17108|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+17112|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+17116|0;a=c[h>>2]|0;h=(k+4|0)>>>0>a>>>0?a-k|0:4;a=(c[l>>2]|0)+k|0;s1(j|0,a|0,h)|0;c[f>>2]=(c[f>>2]|0)+h;n=(h|0)!=0;i=d;return n|0}function kY(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0;j=i;i=i+256|0;k=j|0;switch(g&255|0){case 145:{l=c[(c[f+4>>2]|0)+262176>>2]|0;do{if((c[l+184>>2]|0)==0){m=0}else{n=l+192|0;if((c[n>>2]|0)==0){m=0;break}c[136916]=0;o=l+24|0;p=l+164|0;q=l+8|0;r=l+54|0;s=l+244|0;t=l+88|0;u=l+92|0;v=l+96|0;w=l+100|0;x=l+104|0;y=l+108|0;z=l+112|0;A=l+116|0;B=l+120|0;C=l+124|0;D=l+128|0;E=l+132|0;F=l+136|0;G=l+240|0;H=l+26|0;I=l+28|0;J=l+30|0;K=l+12|0;L=l+14|0;M=l+224|0;N=l+220|0;O=l+216|0;P=l+236|0;Q=O;R=l+16|0;S=l+248|0;T=l+18|0;U=l+252|0;V=l+40|0;W=l+228|0;X=l+10|0;Y=X|0;Z=l+52|0;_=l+46|0;$=l+34|0;aa=l+46|0;ab=aa|0;ac=aa+1|0;aa=l+148|0;ad=l+36|0;ae=X+1|0;X=l+50|0;af=l+48|0;ai=l+32|0;aj=l+48|0;ak=aj|0;al=aj+1|0;aj=l+38|0;am=l+152|0;an=l+44|0;ao=l+196|0;ap=l+200|0;aq=l+201|0;ar=l+202|0;as=l+203|0;at=l+204|0;au=l+205|0;av=l+206|0;aw=l+207|0;ax=l+208|0;ay=l+209|0;az=l+210|0;aA=l+211|0;aB=l+212|0;aC=l+213|0;aD=l+214|0;aE=l+215|0;aF=1;aG=0;while(1){aH=b[o>>1]|0;if((aH&65535)<=255){aI=2445;break}c[p>>2]=1;b[q>>1]=aH;b[r>>1]=aH;aJ=c[s>>2]|0;aK=d[aJ+(aH&65535)|0]|0;c[t>>2]=aK&7;c[u>>2]=aK&16;c[v>>2]=aK&32;c[w>>2]=(aK>>>6)+1;aK=aH+1&65535;b[q>>1]=aK;aL=d[aJ+(aK&65535)|0]|0;aK=aL&1;c[x>>2]=aK;aM=aL&2;c[y>>2]=aM;aN=aL&4;c[z>>2]=aN;aO=aL&8;c[A>>2]=aO;aP=aL>>>4&3;c[B>>2]=aP;c[C>>2]=aL&64;aQ=aL&128;c[D>>2]=aQ;aL=aH+2&65535;b[q>>1]=aL;aR=d[aJ+(aL&65535)|0]|0;c[E>>2]=aR&15;c[F>>2]=aR&32;aR=aH+3&65535;b[q>>1]=aR;aL=aR&65535;b[o>>1]=d[aJ+(aL+1)|0]<<8|d[aJ+aL|0];aL=aH+5&65535;b[q>>1]=aL;aR=aG+15|0;c[136916]=aR;c[G>>2]=0;do{if((aN|0)==0){aS=aL&65535;aT=d[aJ+(aS+1)|0]<<8|d[aJ+aS|0];b[H>>1]=aT;aS=aH+7&65535;b[q>>1]=aS;aU=aS&65535;aS=d[aJ+(aU+1)|0]<<8|d[aJ+aU|0];b[I>>1]=aS;aU=aH+9&65535;b[q>>1]=aU;aV=aU&65535;aU=d[aJ+(aV+1)|0]<<8|d[aJ+aV|0];b[J>>1]=aU;aV=aH+11&65535;b[q>>1]=aV;aW=aG+33|0;c[136916]=aW;if((aP|0)==1){aX=aV&65535;b[ai>>1]=d[aJ+(aX+1)|0]<<8|d[aJ+aX|0];aX=aH+13&65535;b[q>>1]=aX;aY=aX&65535;b[$>>1]=d[aJ+(aY+1)|0]<<8|d[aJ+aY|0];aY=aH+15&65535;b[q>>1]=aY;aX=aG+45|0;c[136916]=aX;aZ=0;a_=0;a$=aY;a0=aX}else if((aP|0)==2){aX=aV&65535;b[ai>>1]=d[aJ+(aX+1)|0]<<8|d[aJ+aX|0];aX=aH+13&65535;b[q>>1]=aX;aY=aX&65535;b[$>>1]=d[aJ+(aY+1)|0]<<8|d[aJ+aY|0];aY=aH+15&65535;b[q>>1]=aY;aX=aY&65535;b[ad>>1]=d[aJ+(aX+1)|0]<<8|d[aJ+aX|0];aX=aH+17&65535;b[q>>1]=aX;aY=aG+51|0;c[136916]=aY;aZ=1;a_=0;a$=aX;a0=aY}else if((aP|0)==3){aY=aV&65535;b[ai>>1]=d[aJ+(aY+1)|0]<<8|d[aJ+aY|0];aY=aH+13&65535;b[q>>1]=aY;aX=aY&65535;b[$>>1]=d[aJ+(aX+1)|0]<<8|d[aJ+aX|0];aX=aH+15&65535;b[q>>1]=aX;aY=aX&65535;b[ad>>1]=d[aJ+(aY+1)|0]<<8|d[aJ+aY|0];aY=aH+17&65535;b[q>>1]=aY;aX=aY&65535;b[aj>>1]=d[aJ+(aX+1)|0]<<8|d[aJ+aX|0];aX=aH+19&65535;b[q>>1]=aX;aY=aG+57|0;c[136916]=aY;aZ=1;a_=1;a$=aX;a0=aY}else{aZ=0;a_=0;a$=aV;a0=aW}if((aO|0)==0){aW=a$+1&65535;b[q>>1]=aW;aV=a[aJ+(a$&65535)|0]|0;a[ap]=(aV&255)>>>4;a[aq]=aV&15;aV=a$+2&65535;b[q>>1]=aV;aY=a[aJ+(aW&65535)|0]|0;a[ar]=(aY&255)>>>4;a[as]=aY&15;aY=a$+3&65535;b[q>>1]=aY;aW=a[aJ+(aV&65535)|0]|0;a[at]=(aW&255)>>>4;a[au]=aW&15;aW=a$+4&65535;b[q>>1]=aW;aV=a[aJ+(aY&65535)|0]|0;a[av]=(aV&255)>>>4;a[aw]=aV&15;aV=a$+5&65535;b[q>>1]=aV;aY=a[aJ+(aW&65535)|0]|0;a[ax]=(aY&255)>>>4;a[ay]=aY&15;aY=a$+6&65535;b[q>>1]=aY;aW=a[aJ+(aV&65535)|0]|0;a[az]=(aW&255)>>>4;a[aA]=aW&15;aW=a$+7&65535;b[q>>1]=aW;aV=a[aJ+(aY&65535)|0]|0;a[aB]=(aV&255)>>>4;a[aC]=aV&15;b[q>>1]=a$+8&65535;aV=a[aJ+(aW&65535)|0]|0;a[aD]=(aV&255)>>>4;a[aE]=aV&15;aV=a0+24|0;c[136916]=aV;a1=aV}else{a1=a0}aV=b[K>>1]|0;aW=aV<<16>>16;aY=aW+160|0;aX=b[L>>1]|0;a2=aX<<16>>16;a3=a2+102|0;a4=aW+32848|0;a5=a2+32819|0;a6=aM>>>1;a7=(aK|0)==0?a6:a6^3;if(aS<<16>>16>=aV<<16>>16&(aS<<16>>16|0)<(aY|0)){if(aU<<16>>16>=aX<<16>>16&(aU<<16>>16|0)<(a3|0)){a8=0}else{aI=2455}}else{aI=2455}if((aI|0)==2455){aI=0;a8=1}aX=a7;a7=0;aV=0;a6=aS;aS=aU;aU=aT;aT=a1;a9=aJ;ba=aQ;bb=aJ;bc=aQ;L3207:while(1){bd=aS&65535;be=a6&65535;if((aX|0)==0){bf=1;bg=1}else{bf=(aX|0)==3?1:-1;bg=(aX|0)==1?1:-1}bh=(c[u>>2]|0)==0;bi=bh?bf:-bf|0;bj=(c[v>>2]|0)==0;bk=bj?bg:-bg|0;L3212:do{if(a8){if(bh){bl=aX}else{bl=c[53464+(aX<<2)>>2]|0}if(bj){bm=bl}else{bm=c[53480+(bl<<2)>>2]|0}do{if((bm|0)==3){if(!((be|0)>=(aW|0)|(be|0)<(a4|0))){bn=aU;bo=aT;break}if((bd|0)<(a3|0)|(bd|0)>(a5|0)){aI=2473;break L3212}else{bn=aU;bo=aT}}else if((bm|0)==2){if(!((be|0)>=(aW|0)|(be|0)<(a4|0))){bn=aU;bo=aT;break}if((bd|0)>=(a2|0)|(bd|0)<(a5|0)){aI=2473;break L3212}else{bn=aU;bo=aT}}else if((bm|0)==1){if(!((be|0)<(aY|0)|(be|0)>(a4|0))){bn=aU;bo=aT;break}if((bd|0)>=(a2|0)|(bd|0)<(a5|0)){aI=2473;break L3212}else{bn=aU;bo=aT}}else{if(!((be|0)<(aY|0)|(be|0)>(a4|0))){bn=aU;bo=aT;break}if((bd|0)<(a3|0)|(bd|0)>(a5|0)){aI=2473;break L3212}else{bn=aU;bo=aT}}}while(0);while(1){s_(Q|0,0,20);c[P>>2]=65535;c[M>>2]=0;bp=bn+1&65535;b[q>>1]=bp;bq=bn&65535;br=a[a9+bq|0]|0;bs=br&255;bt=bs<<16;c[M>>2]=bt;bu=bn+2&65535;b[q>>1]=bu;bv=d[a9+(bp&65535)|0]<<8|bt;c[M>>2]=bv;b[q>>1]=bn+3&65535;c[M>>2]=bv|d[a9+(bu&65535)|0];bw=bo+9|0;c[N>>2]=16;bu=(bs<<3)-8|0;c[P>>2]=bu;if((ba|0)!=0){c[O>>2]=1;c[W>>2]=(bu>>>0)/((c[w>>2]|0)>>>0)|0}c[S>>2]=e[R>>1]|0;c[U>>2]=e[T>>1]|0;bu=br&255;b[V>>1]=bu;bx=bq+bs&65535;b[H>>1]=bx;if((bu<<16>>16|0)==1){break}else if((bu<<16>>16|0)==0){aI=2606;break L3207}else{bn=bx;bo=bw}}c[136916]=bw;by=aV;bz=bw;bA=bx;bB=a9;bC=ba;bD=bb;bE=bc}else{aI=2473}}while(0);if((aI|0)==2473){aI=0;bd=(aS<<16>>16)-a2|0;c[137670]=bd;b[Y>>1]=0;be=(bi|0)==1;if(be){bF=b[Z>>1]|0}else{bF=0}b[_>>1]=bF;bj=(a7|0)==0;if(bj){c[137660]=bi;bG=bi}else{bG=c[137660]|0}if((bi|0)==(bG|0)){bH=bd}else{bh=bd+bi|0;c[137670]=bh;bH=bh}bh=(bi|0)==-1;bd=(bk|0)==1;bu=aV;bs=bF;bq=aU;br=bb;bv=aT;bt=bc;bp=bH;while(1){bI=bs+(b[$>>1]|0)&65535;b[ab>>1]=bI;bJ=(bI&65535)>>>8;bI=bJ&65535;c[137674]=bI;a[ac]=0;s_(Q|0,0,20);c[P>>2]=65535;c[M>>2]=0;bK=bq+1&65535;b[q>>1]=bK;bL=a[br+(bq&65535)|0]|0;bM=bL&255;bN=bM<<16;c[M>>2]=bN;bO=bq+2&65535;b[q>>1]=bO;bP=d[br+(bK&65535)|0]<<8|bN;c[M>>2]=bP;b[q>>1]=bq+3&65535;c[M>>2]=bP|d[br+(bO&65535)|0];bQ=bv+9|0;c[136916]=bQ;c[N>>2]=16;bO=(bM<<3)-8|0;c[P>>2]=bO;if((bt|0)!=0){c[O>>2]=1;c[W>>2]=(bO>>>0)/((c[w>>2]|0)>>>0)|0}c[S>>2]=e[R>>1]|0;c[U>>2]=e[T>>1]|0;b[V>>1]=bL&255;if((bM|0)==1){break}else if((bM|0)==0){bR=bu;bS=bQ;bT=br;break L3207}c[137664]=0;L3253:do{if(bJ<<16>>16==0){bU=bu;bV=bI;bW=bp}else{bM=bu;bL=bI;bO=bp;while(1){if(be&(bO|0)>101|bh&(bO|0)<0){bU=bM;bV=bL;bW=bO;break L3253}if(bO>>>0<102){bP=(e[I>>1]|0)+((b[Y>>1]|0)>>>8)&65535;b[I>>1]=bP;a[ae]=0;bN=(bP<<16>>16)-aW|0;c[137672]=bN;if(bd){bX=b[X>>1]|0}else{bX=0}b[af>>1]=bX;if(bj){c[137662]=bk;bY=bk}else{bY=c[137662]|0}if((bk|0)!=(bY|0)){c[137672]=bN+bk}s_(Q|0,0,20);c[P>>2]=65535;bN=b[H>>1]|0;c[M>>2]=0;bP=bN+1&65535;b[q>>1]=bP;bZ=c[s>>2]|0;b_=d[bZ+(bN&65535)|0]|0;b$=b_<<16;c[M>>2]=b$;b0=bN+2&65535;b[q>>1]=b0;b1=d[bZ+(bP&65535)|0]<<8|b$;c[M>>2]=b1;b[q>>1]=bN+3&65535;c[M>>2]=b1|d[bZ+(b0&65535)|0];c[136916]=(c[136916]|0)+9;c[N>>2]=16;b0=(b_<<3)-8|0;c[P>>2]=b0;if((c[D>>2]|0)!=0){c[O>>2]=1;c[W>>2]=(b0>>>0)/((c[w>>2]|0)>>>0)|0}if(bO>>>0>101){ah(8);gj[b2&127](0,28304)|0;b3=0}else{b3=bO}b0=b3*80|0;c[S>>2]=(e[R>>1]|0)+b0;c[U>>2]=(e[T>>1]|0)+b0;a[53496]=0;b0=lj(l)|0;c[137666]=b0;if((b0|0)==128){b4=bM}else{b_=bM;bZ=b0;b0=0;while(1){b1=(b[ak>>1]|0)+(b[ai>>1]|0)&65535;b[ak>>1]=b1;bN=(b1&65535)>>>8;b5=bN&65535;a[al]=0;L3278:do{if(bN<<16>>16==0){b6=b_;b7=0;b8=b0}else{b1=bZ<<4;b$=(bZ|0)==14;bP=(bZ|0)==0;b9=b_;ca=c[137672]|0;cb=0;cc=b0;while(1){if(ca>>>0<160){L3284:do{switch(c[t>>2]|0){case 0:{cd=ca>>>1;ce=(c[s>>2]|0)+((c[S>>2]|0)+cd)|0;cf=a[ce]|0;cg=(ca&1|0)==0;if(cg){ch=cf&15|b1}else{ch=cf&-16&255|bZ}a[ce]=ch&255;ce=c[136916]|0;c[136916]=ce+6;if((c[F>>2]|0)!=0){break L3284}if((c[am>>2]|0)!=0|b$){break L3284}cf=c[E>>2]|0;ci=(c[s>>2]|0)+((c[U>>2]|0)+cd)|0;cd=a[ci]|0;if(cg){cj=cd&15|cf<<4}else{cj=cd&-16&255|cf}a[ci]=cj&255;c[136916]=ce+12;break};case 1:{ce=(c[s>>2]|0)+((c[S>>2]|0)+(ca>>>1))|0;ci=a[ce]|0;if((ca&1|0)==0){ck=ci&15|b1}else{ck=ci&-16&255|bZ}a[ce]=ck&255;c[136916]=(c[136916]|0)+6;break};case 5:{if(bP){break L3284}ce=(c[s>>2]|0)+((c[S>>2]|0)+(ca>>>1))|0;ci=a[ce]|0;if((ca&1|0)==0){cl=ci&15|b1}else{cl=ci&-16&255|bZ}a[ce]=cl&255;c[136916]=(c[136916]|0)+6;break};case 3:{if((bZ|0)==0){break L3284}else if((bZ|0)!=15){ce=(c[s>>2]|0)+((c[S>>2]|0)+(ca>>>1))|0;ci=a[ce]|0;if((ca&1|0)==0){cm=ci&15|b1}else{cm=ci&-16&255|bZ}a[ce]=cm&255;c[136916]=(c[136916]|0)+6}if((c[F>>2]|0)!=0){break L3284}if((c[am>>2]|0)!=0){break L3284}ce=(c[s>>2]|0)+((c[U>>2]|0)+(ca>>>1))|0;ci=a[ce]|0;cf=ci&255;cd=(ca&1|0)==0;cg=cd?cf>>>4:cf&15;cf=c[136916]|0;c[136916]=cf+3;if((cg|0)>(c[G>>2]|0)){c[G>>2]=cg;cn=a[ce]|0}else{cn=ci}ci=c[E>>2]|0;if(cd){co=cn&15|ci<<4}else{co=cn&-16&255|ci}a[ce]=co&255;c[136916]=cf+9;break};case 4:{if(bP){break L3284}cf=ca>>>1;ce=(c[s>>2]|0)+((c[S>>2]|0)+cf)|0;ci=a[ce]|0;cd=(ca&1|0)==0;if(cd){cp=ci&15|b1}else{cp=ci&-16&255|bZ}a[ce]=cp&255;ce=c[136916]|0;c[136916]=ce+6;if((c[F>>2]|0)!=0){break L3284}if((c[am>>2]|0)!=0){break L3284}ci=(c[s>>2]|0)+((c[U>>2]|0)+cf)|0;cf=a[ci]|0;cg=cf&255;cq=cd?cg>>>4:cg&15;c[136916]=ce+9;if((cq|0)>(c[G>>2]|0)){c[G>>2]=cq;cr=a[ci]|0}else{cr=cf}cf=c[E>>2]|0;if(cd){cs=cr&15|cf<<4}else{cs=cr&-16&255|cf}a[ci]=cs&255;c[136916]=ce+15;break};case 2:{if((bZ|0)==14|(bZ|0)==0){break L3284}else if((bZ|0)!=15){ce=(c[s>>2]|0)+((c[S>>2]|0)+(ca>>>1))|0;ci=a[ce]|0;if((ca&1|0)==0){ct=ci&15|b1}else{ct=ci&-16&255|bZ}a[ce]=ct&255;c[136916]=(c[136916]|0)+6}if((c[F>>2]|0)!=0){break L3284}if((c[am>>2]|0)!=0){break L3284}ce=(c[s>>2]|0)+((c[U>>2]|0)+(ca>>>1))|0;ci=a[ce]|0;cf=ci&255;cd=(ca&1|0)==0;cq=cd?cf>>>4:cf&15;cf=c[136916]|0;c[136916]=cf+3;if((cq|0)>(c[G>>2]|0)){c[G>>2]=cq;cu=a[ce]|0}else{cu=ci}ci=c[E>>2]|0;if(cd){cv=cu&15|ci<<4}else{cv=cu&-16&255|ci}a[ce]=cv&255;c[136916]=cf+9;break};case 7:{if(bP){break L3284}cf=ca>>>1;ce=(c[s>>2]|0)+((c[S>>2]|0)+cf)|0;ci=a[ce]|0;cd=(ca&1|0)==0;if(cd){cw=ci&15|b1}else{cw=ci&-16&255|bZ}a[ce]=cw&255;ce=c[136916]|0;c[136916]=ce+6;if(b$){break L3284}if((c[F>>2]|0)!=0){break L3284}if((c[am>>2]|0)!=0){break L3284}ci=(c[s>>2]|0)+((c[U>>2]|0)+cf)|0;cf=a[ci]|0;cq=cf&255;cg=cd?cq>>>4:cq&15;c[136916]=ce+9;if((cg|0)>(c[G>>2]|0)){c[G>>2]=cg;cx=a[ci]|0}else{cx=cf}cf=c[E>>2]|0;if(cd){cy=cx&15|cf<<4}else{cy=cx&-16&255|cf}a[ci]=cy&255;c[136916]=ce+15;break};case 6:{if(bP){break L3284}ce=ca>>>1;ci=(c[s>>2]|0)+((c[S>>2]|0)+ce)|0;cf=a[ci]|0;cd=cf&255;cg=(ca&1|0)==0;cq=c[136916]|0;c[136916]=cq+3;cz=(cg?cd>>>4:cd&15)^bZ;if(cg){cB=cf&15|cz<<4}else{cB=cf&-16&255|cz}a[ci]=cB&255;c[136916]=cq+9;if((bZ|0)==14|(bZ|0)==0){break L3284}if((c[F>>2]|0)!=0){break L3284}if((c[am>>2]|0)!=0|b$){break L3284}ci=(c[s>>2]|0)+((c[U>>2]|0)+ce)|0;ce=a[ci]|0;cz=ce&255;cf=cg?cz>>>4:cz&15;c[136916]=cq+12;if((cf|0)>(c[G>>2]|0)){c[G>>2]=cf;cC=a[ci]|0}else{cC=ce}ce=c[E>>2]|0;if(cg){cD=cC&15|ce<<4}else{cD=cC&-16&255|ce}a[ci]=cD&255;c[136916]=cq+18;break};default:{}}}while(0);a[53496]=1;cE=1;cF=1}else{if(cc){b6=b9;b7=cb;b8=1;break L3278}else{cE=b9;cF=0}}cq=ca+bk|0;c[137672]=cq;ci=cb+1|0;if((ci|0)<(b5|0)){b9=cE;ca=cq;cb=ci;cc=cF}else{b6=cE;b7=ci;b8=cF;break}}}}while(0);bN=lj(l)|0;if((bN|0)==128){break}else{b_=b6;bZ=bN;b0=b8}}c[137666]=128;c[137668]=b7;c[137676]=b5;b4=b6}cG=b4;cH=c[137670]|0}else{cG=bM;cH=bO}b0=cH+bi|0;c[137670]=b0;if(aZ){b[ai>>1]=(b[ai>>1]|0)+(b[ad>>1]|0)&65535}if(a_){b[Y>>1]=(b[Y>>1]|0)+(b[aj>>1]|0)&65535}bZ=(c[137664]|0)+1|0;c[137664]=bZ;b_=c[137674]|0;if((bZ|0)<(b_|0)){bM=cG;bL=b_;bO=b0}else{bU=cG;bV=b_;bW=b0;break}}}}while(0);if((c[aa>>2]|0)!=0){bI=ag(e[ad>>1]|0,bV)|0;b[$>>1]=(e[$>>1]|0)+bI&65535}bI=(b[H>>1]|0)+(b[V>>1]|0)&65535;b[H>>1]=bI;bu=bU;bs=b[ab>>1]|0;bq=bI;br=c[s>>2]|0;bv=c[136916]|0;bt=c[D>>2]|0;bp=bW}b[H>>1]=bK;by=bu;bz=bQ;bA=bK;bB=br;bC=bt;bD=br;bE=bt}bp=a7+1|0;if((bp|0)>=4){bR=by;bS=bz;bT=bD;break}aX=aX+1&3;a7=bp;aV=by;a6=b[I>>1]|0;aS=b[J>>1]|0;aU=bA;aT=bz;a9=bB;ba=bC;bb=bD;bc=bE}if((aI|0)==2606){aI=0;c[136916]=bw;bR=aV;bS=bw;bT=bb}L3411:do{if((c[F>>2]|0)==0){if((c[am>>2]|0)!=0){break}switch(c[t>>2]|0){case 6:case 3:case 4:case 2:case 7:{break};default:{break L3411}}a[bT+((b[an>>1]|0)+(b[r>>1]|0)&65535)|0]=c[G>>2]&255}}while(0);if((c[ao>>2]|0)==0){cI=bS;break}bb=(c[s>>2]|0)+((b[an>>1]|0)+(b[r>>1]|0)&65535)|0;aV=a[bb]|0;a[bb]=(bR|0)==0?aV|-128:aV&127;cI=bS}else{cI=aR}}while(0);if((aF|0)>4096){aI=2615;break}aF=aF+1|0;aG=cI}if((aI|0)==2445){c[p>>2]=0;c[n>>2]=0;m=aG;break}else if((aI|0)==2615){c[135446]=1;ah(8);gj[cJ&127](0,35184)|0;m=0;break}}}while(0);c[135460]=(c[135448]|0)+m;c[135452]=1;i=j;return};case 28:{c[f+16808>>2]=h&255;i=j;return};case 1:{m=f+20|0;cJ=h&255;c[m>>2]=c[m>>2]&254|cJ>>>7;c[f+16504>>2]=cJ&16;c[f+16508>>2]=cJ&8;c[f+16512>>2]=cJ&7;if((cJ&64|0)!=0){c[f+16520>>2]=0}if((cJ&72|0)==0){i=j;return}c[f+16540>>2]=c[135448];c[135456]=c[135448];i=j;return};case 14:{c[f+16648>>2]=h&255;c[135456]=c[135448];i=j;return};case 18:{c[f+16692>>2]=h&255;c[135456]=c[135448];i=j;return};case 22:{c[f+16736>>2]=h&255;c[135456]=c[135448];i=j;return};case 13:{cJ=f+20|0;m=h&255;c[cJ>>2]=c[cJ>>2]&247|m>>>4&8;c[f+16636>>2]=m&16;c[f+16640>>2]=m&8;c[f+16644>>2]=m&7;if((m&64|0)!=0){c[f+16652>>2]=0}if((m&72|0)==0){i=j;return}c[f+16672>>2]=c[135448];c[135456]=c[135448];i=j;return};case 54:{c[f+16980>>2]=h&255;i=j;return};case 55:{m=f+17016|0;cJ=h&255;c[m>>2]=c[m>>2]&2093311|cJ<<4&3840;c[f+16992>>2]=cJ&2;c[f+16996>>2]=cJ&1;c[f+16988>>2]=cJ&4;i=j;return};case 56:{cJ=f+17064|0;if(!((a[cJ]|0)!=0|h<<24>>24==0)){c[f+17060>>2]=c[135448];c[135456]=c[135448]}a[cJ]=h;i=j;return};case 57:{cJ=f+17072|0;c[cJ>>2]=c[cJ>>2]&8191|(h&255)<<13;i=j;return};case 58:{a[f+17065|0]=h;i=j;return};case 59:{cJ=f+17072|0;c[cJ>>2]=c[cJ>>2]&2096896|h&255;i=j;return};case 60:{cJ=f+17020|0;if(!((c[cJ>>2]|0)!=0|h<<24>>24==0)){c[f+17060>>2]=c[135448];c[135456]=c[135448]}c[cJ>>2]=h&255;i=j;return};case 33:{cJ=f+16904|0;c[cJ>>2]=c[cJ>>2]&8191|(h&255)<<13;i=j;return};case 34:{a[f+16897|0]=h;i=j;return};case 35:{cJ=f+16904|0;c[cJ>>2]=c[cJ>>2]&2096896|h&255;i=j;return};case 36:{cJ=f+16852|0;if(!((c[cJ>>2]|0)!=0|h<<24>>24==0)){c[f+16892>>2]=c[135448];c[135456]=c[135448]}c[cJ>>2]=h&255;i=j;return};case 2:{c[f+16516>>2]=h&255;c[135456]=c[135448];i=j;return};case 10:{c[f+16604>>2]=h&255;c[135456]=c[135448];i=j;return};case 45:{cJ=h&255;c[f+16912>>2]=cJ&16;c[f+16916>>2]=cJ&8;c[f+16920>>2]=cJ&7;c[f+16956>>2]=cJ&32;if((cJ&64|0)!=0){c[f+16928>>2]=0}m=f+16960|0;c[m>>2]=c[m>>2]&2093055|cJ<<5&4096;if((cJ&72|0)==0){i=j;return}c[f+16948>>2]=c[135448];c[135456]=c[135448];i=j;return};case 46:{c[f+16924>>2]=h&255;i=j;return};case 47:{cJ=f+16960|0;m=h&255;c[cJ>>2]=c[cJ>>2]&2093311|m<<4&3840;c[f+16936>>2]=m&2;c[f+16940>>2]=m&1;c[f+16932>>2]=m&4;i=j;return};case 48:{m=f+17008|0;if(!((a[m]|0)!=0|h<<24>>24==0)){c[f+17004>>2]=c[135448];c[135456]=c[135448]}a[m]=h;i=j;return};case 25:{m=f+20|0;cJ=h&255;c[m>>2]=c[m>>2]&191|cJ>>>1&64;c[f+16768>>2]=cJ&16;c[f+16772>>2]=cJ&8;c[f+16776>>2]=cJ&7;if((cJ&64|0)!=0){c[f+16784>>2]=0}if((cJ&72|0)==0){i=j;return}c[f+16804>>2]=c[135448];c[135456]=c[135448];i=j;return};case 37:{cJ=h&255;c[f+16856>>2]=cJ&16;c[f+16860>>2]=cJ&8;c[f+16864>>2]=cJ&7;c[f+16900>>2]=cJ&32;if((cJ&64|0)!=0){c[f+16872>>2]=0}m=f+16904|0;c[m>>2]=c[m>>2]&2093055|cJ<<5&4096;if((cJ&72|0)==0){i=j;return}c[f+16892>>2]=c[135448];c[135456]=c[135448];i=j;return};case 38:{c[f+16868>>2]=h&255;i=j;return};case 62:{c[f+17036>>2]=h&255;i=j;return};case 63:{cJ=f+17072|0;m=h&255;c[cJ>>2]=c[cJ>>2]&2093311|m<<4&3840;c[f+17048>>2]=m&2;c[f+17052>>2]=m&1;c[f+17044>>2]=m&4;i=j;return};case 80:{c[f+17076>>2]=~h&255;i=j;return};case 128:{m=f+16|0;c[m>>2]=c[m>>2]&(~h&255);c[135456]=c[135448];c[135444]=(c[f+20>>2]&c[m>>2]|0)!=0;i=j;return};case 129:{m=f+16|0;cJ=c[m>>2]|h&255;c[m>>2]=cJ;c[135444]=(cJ&c[f+20>>2]|0)!=0;c[135456]=c[135448];i=j;return};case 135:{cJ=h&255;m=f+4|0;if((cJ&2|0)==0){aI=c[(c[(c[m>>2]|0)+262168>>2]|0)+28>>2]|0;cI=k|0;cA(cI|0,21552,(k=i,i=i+8|0,c[k>>2]=aI,k)|0)|0;i=k;ah(8);gj[cK&127](0,cI)|0;cI=c[m>>2]|0;f$[c[(c[cI>>2]|0)+8>>2]&511](cI);c[135446]=1}cI=cJ&1;cJ=c[(c[m>>2]|0)+262152>>2]|0;c[cJ+108>>2]=cI;do{if((cI|0)!=0){c[cJ+96>>2]=0;if((c[137678]|0)!=0){break}m=cJ+100|0;c[m>>2]=(c[cJ+104>>2]|0)!=0|c[m>>2]<<1&254}}while(0);c[137678]=cI;i=j;return};case 16:{c[f+16676>>2]=h&255;i=j;return};case 30:{c[f+16824>>2]=h&255;c[135456]=c[135448];i=j;return};case 3:{cI=h&255;c[f+16520>>2]=cI&8;c[f+16524>>2]=cI&4;c[f+16528>>2]=cI&2;c[f+16532>>2]=cI&1;i=j;return};case 7:{cI=h&255;c[f+16564>>2]=cI&8;c[f+16568>>2]=cI&4;c[f+16572>>2]=cI&2;c[f+16576>>2]=cI&1;i=j;return};case 11:{cI=h&255;c[f+16608>>2]=cI&8;c[f+16612>>2]=cI&4;c[f+16616>>2]=cI&2;c[f+16620>>2]=cI&1;i=j;return};case 15:{cI=h&255;c[f+16652>>2]=cI&8;c[f+16656>>2]=cI&4;c[f+16660>>2]=cI&2;c[f+16664>>2]=cI&1;i=j;return};case 24:{c[f+16764>>2]=h&255;i=j;return};case 138:{c[f+16476>>2]=h&255;i=j;return};case 139:{cI=h&255;cJ=f+16472|0;c[cJ>>2]=cI;m=f+4|0;c[(c[(c[m>>2]|0)+262152>>2]|0)+104>>2]=cI>>>1&1;if((c[f+16476>>2]&16|0)==0){i=j;return}c[(c[(c[m>>2]|0)+262152>>2]|0)+8>>2]=(c[cJ>>2]|0)>>>4&1;i=j;return};case 140:{cJ=h&255;c[f+17084>>2]=cJ>>>7;c[f+17080>>2]=cJ>>>6&1;c[f+17112>>2]=cJ>>>4&1;m=cJ&2;c[f+17096>>2]=m;c[f+17116>>2]=cJ&1;if((cJ&8|0)!=0){c[f+17276>>2]=0;c[f+17272>>2]=0}if((m|0)==0){i=j;return}c[f+17092>>2]=11;m=f+17268|0;cJ=c[m>>2]|0;if((cJ|0)>=32){i=j;return}if((cJ|0)==0){c[f+17088>>2]=11}cJ=f+17264|0;cI=(c[cJ>>2]|0)+31&31;c[cJ>>2]=cI;c[f+17132+(cI<<2)>>2]=32768;c[m>>2]=(c[m>>2]|0)+1;i=j;return};case 17:{m=h&255;c[f+16680>>2]=m&16;c[f+16684>>2]=m&8;c[f+16688>>2]=m&7;if((m&64|0)!=0){c[f+16696>>2]=0}if((m&72|0)==0){i=j;return}c[f+16716>>2]=c[135448];c[135456]=c[135448];i=j;return};case 12:{c[f+16632>>2]=h&255;i=j;return};case 20:{c[f+16720>>2]=h&255;i=j;return};case 41:{m=f+16960|0;c[m>>2]=c[m>>2]&8191|(h&255)<<13;i=j;return};case 42:{a[f+16953|0]=h;i=j;return};case 43:{m=f+16960|0;c[m>>2]=c[m>>2]&2096896|h&255;i=j;return};case 44:{m=f+16908|0;if(!((c[m>>2]|0)!=0|h<<24>>24==0)){c[f+16948>>2]=c[135448];c[135456]=c[135448]}c[m>>2]=h&255;i=j;return};case 39:{m=f+16904|0;cI=h&255;c[m>>2]=c[m>>2]&2093311|cI<<4&3840;c[f+16880>>2]=cI&2;c[f+16884>>2]=cI&1;c[f+16876>>2]=cI&4;i=j;return};case 32:{cI=f+16896|0;if(!((a[cI]|0)!=0|h<<24>>24==0)){c[f+16892>>2]=c[135448];c[135456]=c[135448]}a[cI]=h;i=j;return};case 40:{cI=f+16952|0;if(!((a[cI]|0)!=0|h<<24>>24==0)){c[f+16948>>2]=c[135448];c[135456]=c[135448]}a[cI]=h;i=j;return};case 21:{cI=f+20|0;m=h&255;c[cI>>2]=c[cI>>2]&223|m>>>2&32;c[f+16724>>2]=m&16;c[f+16728>>2]=m&8;c[f+16732>>2]=m&7;if((m&64|0)!=0){c[f+16740>>2]=0}if((m&72|0)==0){i=j;return}c[f+16760>>2]=c[135448];c[135456]=c[135448];i=j;return};case 31:{m=h&255;c[f+16828>>2]=m&8;c[f+16832>>2]=m&4;c[f+16836>>2]=m&2;c[f+16840>>2]=m&1;i=j;return};case 27:{m=h&255;c[f+16784>>2]=m&8;c[f+16788>>2]=m&4;c[f+16792>>2]=m&2;c[f+16796>>2]=m&1;i=j;return};case 19:{m=h&255;c[f+16696>>2]=m&8;c[f+16700>>2]=m&4;c[f+16704>>2]=m&2;c[f+16708>>2]=m&1;i=j;return};case 23:{m=h&255;c[f+16740>>2]=m&8;c[f+16744>>2]=m&4;c[f+16748>>2]=m&2;c[f+16752>>2]=m&1;i=j;return};case 9:{m=f+20|0;cI=h&255;c[m>>2]=c[m>>2]&251|cI>>>5&4;c[f+16592>>2]=cI&16;c[f+16596>>2]=cI&8;c[f+16600>>2]=cI&7;if((cI&64|0)!=0){c[f+16608>>2]=0}if((cI&72|0)==0){i=j;return}c[f+16628>>2]=c[135448];c[135456]=c[135448];i=j;return};case 26:{c[f+16780>>2]=h&255;c[135456]=c[135448];i=j;return};case 5:{cI=f+20|0;m=h&255;c[cI>>2]=c[cI>>2]&253|m>>>6&2;c[f+16548>>2]=m&16;c[f+16552>>2]=m&8;c[f+16556>>2]=m&7;if((m&64|0)!=0){c[f+16564>>2]=0}if((m&72|0)==0){i=j;return}c[f+16584>>2]=c[135448];c[135456]=c[135448];i=j;return};case 29:{m=f+20|0;cI=h&255;c[m>>2]=c[m>>2]&127|cI&128;c[f+16812>>2]=cI&16;c[f+16816>>2]=cI&8;c[f+16820>>2]=cI&7;if((cI&64|0)!=0){c[f+16828>>2]=0}if((cI&72|0)==0){i=j;return}c[f+16848>>2]=c[135448];c[135456]=c[135448];i=j;return};case 61:{cI=h&255;c[f+17024>>2]=cI&16;c[f+17028>>2]=cI&8;c[f+17032>>2]=cI&7;c[f+17068>>2]=cI&32;if((cI&64|0)!=0){c[f+17040>>2]=0}m=f+17072|0;c[m>>2]=c[m>>2]&2093055|cI<<5&4096;if((cI&72|0)==0){i=j;return}c[f+17060>>2]=c[135448];c[135456]=c[135448];i=j;return};case 141:{cI=h&255;c[f+17100>>2]=cI;c[f+17092>>2]=11;m=f+17268|0;cJ=c[m>>2]|0;if((cJ|0)>=32){i=j;return}if((cJ|0)==0){c[f+17088>>2]=11}cJ=f+17264|0;cK=(c[cJ>>2]|0)+31&31;c[cJ>>2]=cK;c[f+17132+(cK<<2)>>2]=cI;c[m>>2]=(c[m>>2]|0)+1;i=j;return};case 6:{c[f+16560>>2]=h&255;c[135456]=c[135448];i=j;return};case 8:{c[f+16588>>2]=h&255;i=j;return};case 0:{c[f+16500>>2]=h&255;i=j;return};case 4:{c[f+16544>>2]=h&255;i=j;return};case 49:{m=f+17016|0;c[m>>2]=c[m>>2]&8191|(h&255)<<13;i=j;return};case 50:{a[f+17009|0]=h;i=j;return};case 51:{m=f+17016|0;c[m>>2]=c[m>>2]&2096896|h&255;i=j;return};case 52:{m=f+16964|0;if(!((c[m>>2]|0)!=0|h<<24>>24==0)){c[f+17004>>2]=c[135448];c[135456]=c[135448]}c[m>>2]=h&255;i=j;return};case 53:{m=h&255;c[f+16968>>2]=m&16;c[f+16972>>2]=m&8;c[f+16976>>2]=m&7;c[f+17012>>2]=m&32;if((m&64|0)!=0){c[f+16984>>2]=0}cI=f+17016|0;c[cI>>2]=c[cI>>2]&2093055|m<<5&4096;if((m&72|0)==0){i=j;return}c[f+17004>>2]=c[135448];c[135456]=c[135448];i=j;return};case 146:{c[f+16484>>2]=h&1;c[f+16488>>2]=(h&255)>>>1&1;c[f+16492>>2]=(h&255)>>>2&1;c[f+16496>>2]=(h&255)>>>3&1;i=j;return};case 148:{m=f+8|0;c[m>>2]=c[m>>2]&65280|h&255;i=j;return};case 149:{m=f+8|0;c[m>>2]=c[m>>2]&255|(h&255)<<8;i=j;return};case 156:case 157:case 158:{ah(8);gj[cL&127](0,18896)|0;i=j;return};case 160:case 161:case 162:case 163:case 164:case 165:case 166:case 167:case 168:case 169:case 170:case 171:case 172:case 173:case 174:case 175:{cL=f+24+((g&15)<<2)|0;a[cL]=a[cL]&-16|h&15;i=j;return};case 191:case 190:case 189:case 188:case 187:case 186:case 185:case 184:case 176:case 177:case 178:case 179:case 180:case 181:case 182:case 183:{cL=f+24+((g&15)<<2)|0;g=cL+1|0;a[g]=a[g]&-16|(h&255)>>>4;a[cL]=a[cL]&15|h<<4;i=j;return};default:{i=j;return}}}function kZ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;switch(e&255|0){case 1:{f=(((c[b+16504>>2]|0)!=0?16:0)|c[b+20>>2]<<7|c[b+16512>>2]|((c[b+16508>>2]|0)!=0?8:0))&255;return f|0};case 28:{f=c[b+16808>>2]&255;return f|0};case 191:case 190:case 176:case 177:case 178:case 179:case 180:case 181:case 182:case 183:case 184:case 185:case 186:case 187:case 188:case 189:{g=b+24+((e&15)<<2)|0;f=a[g+1|0]<<4|(d[g]|0)>>>4;return f|0};case 151:{f=66;return f|0};case 140:{g=c[b+17104>>2]|0;f=(((c[b+17108>>2]|0)!=0?64:0)|c[b+17092>>2]>>31&160|((c[b+17276>>2]|0)!=0?8:0)|((c[b+17272>>2]|0)!=0?4:0)|g>>>14&2|g>>>8&1)&255;return f|0};case 141:{c[b+17108>>2]=0;f=c[b+17104>>2]&255;return f|0};case 139:{g=c[b+16476>>2]|0;if((g&16|0)==0){h=16}else{h=c[b+16472>>2]&16}do{if((g&8|0)==0){i=0}else{if((c[b+16472>>2]&8|0)==0){i=8;break}i=(c[b+16480>>2]|0)!=0?0:8}}while(0);if((g&4|0)==0){j=(c[b+17120>>2]|0)!=0?4:0}else{j=c[b+16472>>2]&4}if((g&2|0)==0){k=0}else{k=c[b+16472>>2]&2}if((g&1|0)==0){l=1}else{l=c[b+16472>>2]&1}f=(i|h|j|k|l)&255;return f|0};case 58:{f=a[b+17065|0]|0;return f|0};case 59:{f=c[b+17072>>2]&255;return f|0};case 132:case 133:{f=0;return f|0};case 13:{f=(((c[b+16636>>2]|0)!=0?16:0)|c[b+20>>2]<<4&128|c[b+16644>>2]|((c[b+16640>>2]|0)!=0?8:0))&255;return f|0};case 19:{f=((c[b+16700>>2]|0)!=0?4:0)|((c[b+16696>>2]|0)!=0?8:0)|((c[b+16704>>2]|0)!=0?2:0)|(c[b+16708>>2]|0)!=0;return f|0};case 5:{f=(((c[b+16548>>2]|0)!=0?16:0)|c[b+20>>2]<<6&128|c[b+16556>>2]|((c[b+16552>>2]|0)!=0?8:0))&255;return f|0};case 17:{f=(((c[b+16680>>2]|0)!=0?16:0)|c[b+20>>2]<<3&128|c[b+16688>>2]|((c[b+16684>>2]|0)!=0?8:0))&255;return f|0};case 9:{f=(((c[b+16592>>2]|0)!=0?16:0)|c[b+20>>2]<<5&128|c[b+16600>>2]|((c[b+16596>>2]|0)!=0?8:0))&255;return f|0};case 25:{f=(((c[b+16768>>2]|0)!=0?16:0)|c[b+20>>2]<<1&128|c[b+16776>>2]|((c[b+16772>>2]|0)!=0?8:0))&255;return f|0};case 136:{f=1;return f|0};case 134:{f=-128;return f|0};case 60:{f=c[b+17020>>2]&255;return f|0};case 48:{f=a[b+17008|0]|0;return f|0};case 11:{f=((c[b+16612>>2]|0)!=0?4:0)|((c[b+16608>>2]|0)!=0?8:0)|((c[b+16616>>2]|0)!=0?2:0)|(c[b+16620>>2]|0)!=0;return f|0};case 61:{f=((c[b+17072>>2]|0)>>>5&128|c[b+17032>>2]|(((c[b+17024>>2]|0)!=0?16:0)|((c[b+17068>>2]|0)!=0?32:0)|((c[b+17028>>2]|0)!=0?8:0))&255)&255;return f|0};case 40:{f=a[b+16952|0]|0;return f|0};case 62:{f=c[b+17036>>2]&255;return f|0};case 44:{f=c[b+16908>>2]&255;return f|0};case 54:{f=c[b+16980>>2]&255;return f|0};case 55:{f=((((c[b+16992>>2]|0)!=0?2:0)|(c[b+16996>>2]|0)!=0|((c[b+16988>>2]|0)!=0?8:0))&255|(c[b+17016>>2]|0)>>>4&240)&255;return f|0};case 49:{f=(c[b+17016>>2]|0)>>>13&255;return f|0};case 51:{f=c[b+17016>>2]&255;return f|0};case 12:{f=c[b+16632>>2]&255;return f|0};case 46:{f=c[b+16924>>2]&255;return f|0};case 41:{f=(c[b+16960>>2]|0)>>>13&255;return f|0};case 8:{f=c[b+16588>>2]&255;return f|0};case 10:{k_(b);f=c[b+16604>>2]&255;return f|0};case 2:{k_(b);f=c[b+16516>>2]&255;return f|0};case 14:{k_(b);f=c[b+16648>>2]&255;return f|0};case 22:{k_(b);f=c[b+16736>>2]&255;return f|0};case 39:{f=((((c[b+16880>>2]|0)!=0?2:0)|(c[b+16884>>2]|0)!=0|((c[b+16876>>2]|0)!=0?8:0))&255|(c[b+16904>>2]|0)>>>4&240)&255;return f|0};case 20:{f=c[b+16720>>2]&255;return f|0};case 24:{f=c[b+16764>>2]&255;return f|0};case 35:{f=c[b+16904>>2]&255;return f|0};case 16:{f=c[b+16676>>2]&255;return f|0};case 31:{f=((c[b+16832>>2]|0)!=0?4:0)|((c[b+16828>>2]|0)!=0?8:0)|((c[b+16836>>2]|0)!=0?2:0)|(c[b+16840>>2]|0)!=0;return f|0};case 23:{f=((c[b+16744>>2]|0)!=0?4:0)|((c[b+16740>>2]|0)!=0?8:0)|((c[b+16748>>2]|0)!=0?2:0)|(c[b+16752>>2]|0)!=0;return f|0};case 148:{f=c[b+8>>2]&255;return f|0};case 149:{f=(c[b+8>>2]|0)>>>8&255;return f|0};case 21:{f=(((c[b+16724>>2]|0)!=0?16:0)|c[b+20>>2]<<2&128|c[b+16732>>2]|((c[b+16728>>2]|0)!=0?8:0))&255;return f|0};case 6:{k_(b);f=c[b+16560>>2]&255;return f|0};case 29:{f=(((c[b+16812>>2]|0)!=0?16:0)|c[b+20>>2]&128|c[b+16820>>2]|((c[b+16816>>2]|0)!=0?8:0))&255;return f|0};case 80:{f=(c[b+17076>>2]^255)&255;return f|0};case 43:{f=c[b+16960>>2]&255;return f|0};case 32:{f=a[b+16896|0]|0;return f|0};case 45:{f=((c[b+16960>>2]|0)>>>5&128|c[b+16920>>2]|(((c[b+16912>>2]|0)!=0?16:0)|((c[b+16956>>2]|0)!=0?32:0)|((c[b+16916>>2]|0)!=0?8:0))&255)&255;return f|0};case 52:{f=c[b+16964>>2]&255;return f|0};case 37:{f=((c[b+16904>>2]|0)>>>5&128|c[b+16864>>2]|(((c[b+16856>>2]|0)!=0?16:0)|((c[b+16900>>2]|0)!=0?32:0)|((c[b+16860>>2]|0)!=0?8:0))&255)&255;return f|0};case 42:{f=a[b+16953|0]|0;return f|0};case 0:{f=c[b+16500>>2]&255;return f|0};case 26:{k_(b);f=c[b+16780>>2]&255;return f|0};case 7:{f=((c[b+16568>>2]|0)!=0?4:0)|((c[b+16564>>2]|0)!=0?8:0)|((c[b+16572>>2]|0)!=0?2:0)|(c[b+16576>>2]|0)!=0;return f|0};case 34:{f=a[b+16897|0]|0;return f|0};case 27:{f=((c[b+16788>>2]|0)!=0?4:0)|((c[b+16784>>2]|0)!=0?8:0)|((c[b+16792>>2]|0)!=0?2:0)|(c[b+16796>>2]|0)!=0;return f|0};case 33:{f=(c[b+16904>>2]|0)>>>13&255;return f|0};case 56:{f=a[b+17064|0]|0;return f|0};case 15:{f=((c[b+16656>>2]|0)!=0?4:0)|((c[b+16652>>2]|0)!=0?8:0)|((c[b+16660>>2]|0)!=0?2:0)|(c[b+16664>>2]|0)!=0;return f|0};case 128:case 129:{f=c[b+16>>2]&255;return f|0};case 63:{f=((((c[b+17048>>2]|0)!=0?2:0)|(c[b+17052>>2]|0)!=0|((c[b+17044>>2]|0)!=0?8:0))&255|(c[b+17072>>2]|0)>>>4&240)&255;return f|0};case 47:{f=((((c[b+16936>>2]|0)!=0?2:0)|(c[b+16940>>2]|0)!=0|((c[b+16932>>2]|0)!=0?8:0))&255|(c[b+16960>>2]|0)>>>4&240)&255;return f|0};case 57:{f=(c[b+17072>>2]|0)>>>13&255;return f|0};case 4:{f=c[b+16544>>2]&255;return f|0};case 160:case 161:case 162:case 163:case 164:case 165:case 166:case 167:case 168:case 169:case 170:case 171:case 172:case 173:case 174:case 175:{f=a[b+24+((e&15)<<2)|0]&15;return f|0};case 53:{f=((c[b+17016>>2]|0)>>>5&128|c[b+16976>>2]|(((c[b+16968>>2]|0)!=0?16:0)|((c[b+17012>>2]|0)!=0?32:0)|((c[b+16972>>2]|0)!=0?8:0))&255)&255;return f|0};case 3:{f=((c[b+16524>>2]|0)!=0?4:0)|((c[b+16520>>2]|0)!=0?8:0)|((c[b+16528>>2]|0)!=0?2:0)|(c[b+16532>>2]|0)!=0;return f|0};case 38:{f=c[b+16868>>2]&255;return f|0};case 50:{f=a[b+17009|0]|0;return f|0};case 30:{k_(b);f=c[b+16824>>2]&255;return f|0};case 36:{f=c[b+16852>>2]&255;return f|0};case 18:{k_(b);f=c[b+16692>>2]&255;return f|0};default:{f=-1;return f|0}}return 0}function k_(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0;f=c[135448]|0;do{if(f>>>0>4026531840){c[135448]=f^-2147483648;c[135438]=c[135438]^-2147483648;c[135466]=c[135466]^-2147483648;g=e+16540|0;c[g>>2]=c[g>>2]^-2147483648;g=e+16584|0;c[g>>2]=c[g>>2]^-2147483648;g=e+16628|0;c[g>>2]=c[g>>2]^-2147483648;g=e+16672|0;c[g>>2]=c[g>>2]^-2147483648;g=e+16716|0;c[g>>2]=c[g>>2]^-2147483648;g=e+16760|0;c[g>>2]=c[g>>2]^-2147483648;g=e+16804|0;c[g>>2]=c[g>>2]^-2147483648;g=e+16848|0;c[g>>2]=c[g>>2]^-2147483648;g=e+16892|0;c[g>>2]=c[g>>2]^-2147483648;g=e+16948|0;c[g>>2]=c[g>>2]^-2147483648;g=e+17004|0;c[g>>2]=c[g>>2]^-2147483648;g=e+17060|0;c[g>>2]=c[g>>2]^-2147483648;g=c[135460]|0;if((g|0)==0){c[135456]=-1;break}else{h=g^-2147483648;c[135460]=h;c[135458]=c[135458]^-2147483648;i=h;j=2894;break}}else{i=c[135460]|0;j=2894}}while(0);do{if((j|0)==2894){c[135456]=-1;if((i|0)==0){break}if((c[135448]|0)>>>0<i>>>0){c[135456]=i;break}else{c[135452]=0;c[135450]=0;c[135460]=0;break}}}while(0);do{if((c[e+16508>>2]|0)==0){k=0;l=0}else{i=(c[e+16512>>2]|0)+4|0;f=e+16540|0;h=c[f>>2]|0;g=((c[135448]|0)-h|0)>>>(i>>>0);if((g|0)==0){c[e+16528>>2]=0;c[e+16532>>2]=0;m=0;n=e+16516|0}else{c[f>>2]=(g<<i)+h;h=e+16516|0;f=(c[h>>2]|0)-g|0;c[h>>2]=f;g=e+16532|0;L3898:do{if((f|0)<0){c[g>>2]=1;c[h>>2]=(c[e+16500>>2]|0)+1+f;c[e+16520>>2]=1;if((c[e+17280>>2]|0)==0){o=0;break}p=e+17284|0;if((c[p>>2]|0)==0){o=0;break}if((c[e+16484>>2]|0)==0){o=0;break}if((c[e+20>>2]&1|0)!=0){q=e+16|0;c[q>>2]=c[q>>2]|1;c[135444]=1}q=e+17292|0;r=c[q>>2]|0;s=c[e+16588>>2]|0;t=(r|0)==(s-3|0);c[e+16480>>2]=((r|0)==(s-2|0)|t|(r|0)==(s-4|0))&1;if(t){t=c[e+8>>2]&65532;c[e+17300>>2]=(c[e+16488>>2]|0)==0?t:t|3;c[e+17296>>2]=102}if((r|0)!=0){c[q>>2]=r-1}r=e+17296|0;q=c[r>>2]|0;if((q|0)==0){o=0;break}c[r>>2]=q-1;q=c[p>>2]|0;r=c[e+17304>>2]|0;if((r|0)==2){switch(c[e+17308>>2]|0){case 0:{t=e+17300|0;s=e+17288|0;u=e+16488|0;v=e+17312|0;w=q;x=1;while(1){y=c[t>>2]|0;z=d[(c[s>>2]|0)+y|0]|0;if((c[u>>2]|0)==0){c[t>>2]=y+1;a[w]=c[e+88+(c[e+24+(z>>>4<<2)>>2]<<2)>>2]&255;A=c[v>>2]|0;a[w+A|0]=c[e+88+(c[e+24+((z&15)<<2)>>2]<<2)>>2]&255;B=(c[v>>2]|0)+A|0}else{c[t>>2]=y-1;a[w]=c[e+88+(c[e+24+((z&15)<<2)>>2]<<2)>>2]&255;y=c[v>>2]|0;a[w+y|0]=c[e+88+(c[e+24+(z>>>4<<2)>>2]<<2)>>2]&255;B=(c[v>>2]|0)+y|0}if(x>>>0>=80){break}w=w+B|0;x=x+1|0}c[p>>2]=(c[p>>2]|0)-1;o=320;break L3898;break};case 3:{x=e+17300|0;w=e+17288|0;v=e+16488|0;t=e+17312|0;u=q;s=1;while(1){y=c[x>>2]|0;z=d[(c[w>>2]|0)+y|0]|0;if((c[v>>2]|0)==0){c[x>>2]=y+1;A=c[e+88+(c[e+24+(z>>>4<<2)>>2]<<2)>>2]|0;a[u]=A&255;a[u+1|0]=A>>>8&255;a[u+2|0]=A>>>16&255;A=c[t>>2]|0;C=c[e+88+(c[e+24+((z&15)<<2)>>2]<<2)>>2]|0;a[u+A|0]=C&255;a[u+(A+1)|0]=C>>>8&255;a[u+(A+2)|0]=C>>>16&255;D=(c[t>>2]|0)+A|0}else{c[x>>2]=y-1;y=c[e+88+(c[e+24+((z&15)<<2)>>2]<<2)>>2]|0;a[u]=y&255;a[u+1|0]=y>>>8&255;a[u+2|0]=y>>>16&255;y=c[t>>2]|0;A=c[e+88+(c[e+24+(z>>>4<<2)>>2]<<2)>>2]|0;a[u+y|0]=A&255;a[u+(y+1)|0]=A>>>8&255;a[u+(y+2)|0]=A>>>16&255;D=(c[t>>2]|0)+y|0}if(s>>>0>=80){break}u=u+D|0;s=s+1|0}c[p>>2]=(c[p>>2]|0)-3;o=320;break L3898;break};case 4:{s=e+17300|0;u=e+17288|0;t=e+16488|0;x=e+17312|0;v=q;w=1;while(1){y=c[s>>2]|0;A=d[(c[u>>2]|0)+y|0]|0;if((c[t>>2]|0)==0){c[s>>2]=y+1;c[v>>2]=c[e+88+(c[e+24+(A>>>4<<2)>>2]<<2)>>2];z=c[x>>2]|0;c[v+z>>2]=c[e+88+(c[e+24+((A&15)<<2)>>2]<<2)>>2];E=(c[x>>2]|0)+z|0}else{c[s>>2]=y-1;c[v>>2]=c[e+88+(c[e+24+((A&15)<<2)>>2]<<2)>>2];y=c[x>>2]|0;c[v+y>>2]=c[e+88+(c[e+24+(A>>>4<<2)>>2]<<2)>>2];E=(c[x>>2]|0)+y|0}if(w>>>0>=80){break}v=v+E|0;w=w+1|0}c[p>>2]=(c[p>>2]|0)-4;o=320;break L3898;break};case 1:case 2:{w=e+17300|0;v=e+17288|0;x=e+16488|0;s=e+17312|0;t=q;u=1;while(1){y=c[w>>2]|0;A=d[(c[v>>2]|0)+y|0]|0;if((c[x>>2]|0)==0){c[w>>2]=y+1;b[t>>1]=c[e+88+(c[e+24+(A>>>4<<2)>>2]<<2)>>2]&65535;z=c[s>>2]|0;b[t+z>>1]=c[e+88+(c[e+24+((A&15)<<2)>>2]<<2)>>2]&65535;F=(c[s>>2]|0)+z|0}else{c[w>>2]=y-1;b[t>>1]=c[e+88+(c[e+24+((A&15)<<2)>>2]<<2)>>2]&65535;y=c[s>>2]|0;b[t+y>>1]=c[e+88+(c[e+24+(A>>>4<<2)>>2]<<2)>>2]&65535;F=(c[s>>2]|0)+y|0}if(u>>>0>=80){break}t=t+F|0;u=u+1|0}c[p>>2]=(c[p>>2]|0)-2;o=320;break L3898;break};default:{o=320;break L3898}}}else if((r|0)==1){L3953:do{switch(c[e+17308>>2]|0){case 3:{u=e+17300|0;t=e+17288|0;s=e+16488|0;w=q;x=1;while(1){v=c[u>>2]|0;y=d[(c[t>>2]|0)+v|0]|0;if((c[s>>2]|0)==0){c[u>>2]=v+1;A=c[e+88+(c[e+24+(y>>>4<<2)>>2]<<2)>>2]|0;a[w]=A&255;a[w+1|0]=A>>>8&255;a[w+2|0]=A>>>16&255;A=c[e+88+(c[e+24+((y&15)<<2)>>2]<<2)>>2]|0;a[w+3|0]=A&255;a[w+4|0]=A>>>8&255;a[w+5|0]=A>>>16&255}else{c[u>>2]=v-1;v=c[e+88+(c[e+24+((y&15)<<2)>>2]<<2)>>2]|0;a[w]=v&255;a[w+1|0]=v>>>8&255;a[w+2|0]=v>>>16&255;v=c[e+88+(c[e+24+(y>>>4<<2)>>2]<<2)>>2]|0;a[w+3|0]=v&255;a[w+4|0]=v>>>8&255;a[w+5|0]=v>>>16&255}if(x>>>0>=80){break L3953}w=w+6|0;x=x+1|0}break};case 0:{x=e+17300|0;w=e+17288|0;u=e+16488|0;s=q;t=1;while(1){v=c[x>>2]|0;y=d[(c[w>>2]|0)+v|0]|0;if((c[u>>2]|0)==0){c[x>>2]=v+1;a[s]=c[e+88+(c[e+24+(y>>>4<<2)>>2]<<2)>>2]&255;a[s+1|0]=c[e+88+(c[e+24+((y&15)<<2)>>2]<<2)>>2]&255}else{c[x>>2]=v-1;a[s]=c[e+88+(c[e+24+((y&15)<<2)>>2]<<2)>>2]&255;a[s+1|0]=c[e+88+(c[e+24+(y>>>4<<2)>>2]<<2)>>2]&255}if(t>>>0>=80){break L3953}s=s+2|0;t=t+1|0}break};case 1:case 2:{t=e+17300|0;s=e+17288|0;x=e+16488|0;u=q;w=1;while(1){y=c[t>>2]|0;v=d[(c[s>>2]|0)+y|0]|0;if((c[x>>2]|0)==0){c[t>>2]=y+1;b[u>>1]=c[e+88+(c[e+24+(v>>>4<<2)>>2]<<2)>>2]&65535;b[u+2>>1]=c[e+88+(c[e+24+((v&15)<<2)>>2]<<2)>>2]&65535}else{c[t>>2]=y-1;b[u>>1]=c[e+88+(c[e+24+((v&15)<<2)>>2]<<2)>>2]&65535;b[u+2>>1]=c[e+88+(c[e+24+(v>>>4<<2)>>2]<<2)>>2]&65535}if(w>>>0>=80){break L3953}u=u+4|0;w=w+1|0}break};case 4:{w=e+17300|0;u=e+17288|0;t=e+16488|0;x=q;s=1;while(1){v=c[w>>2]|0;y=d[(c[u>>2]|0)+v|0]|0;if((c[t>>2]|0)==0){c[w>>2]=v+1;c[x>>2]=c[e+88+(c[e+24+(y>>>4<<2)>>2]<<2)>>2];c[x+4>>2]=c[e+88+(c[e+24+((y&15)<<2)>>2]<<2)>>2]}else{c[w>>2]=v-1;c[x>>2]=c[e+88+(c[e+24+((y&15)<<2)>>2]<<2)>>2];c[x+4>>2]=c[e+88+(c[e+24+(y>>>4<<2)>>2]<<2)>>2]}if(s>>>0>=80){break L3953}x=x+8|0;s=s+1|0}break};default:{}}}while(0);c[p>>2]=(c[p>>2]|0)+(c[e+17312>>2]|0);o=320;break}else if((r|0)==3){switch(c[e+17308>>2]|0){case 3:{s=e+17300|0;x=e+17288|0;w=e+16488|0;t=e+17312|0;u=q;y=1;while(1){v=c[s>>2]|0;A=d[(c[x>>2]|0)+v|0]|0;if((c[w>>2]|0)==0){c[s>>2]=v+1;z=c[e+88+(c[e+24+(A>>>4<<2)>>2]<<2)>>2]|0;a[u]=z&255;a[u+1|0]=z>>>8&255;a[u+2|0]=z>>>16&255;z=c[t>>2]|0;C=c[e+88+(c[e+24+((A&15)<<2)>>2]<<2)>>2]|0;a[u+(-z|0)|0]=C&255;a[u+(1-z)|0]=C>>>8&255;a[u+(2-z)|0]=C>>>16&255;G=(c[t>>2]|0)+z|0}else{c[s>>2]=v-1;v=c[e+88+(c[e+24+((A&15)<<2)>>2]<<2)>>2]|0;a[u]=v&255;a[u+1|0]=v>>>8&255;a[u+2|0]=v>>>16&255;v=c[t>>2]|0;z=c[e+88+(c[e+24+(A>>>4<<2)>>2]<<2)>>2]|0;a[u+(-v|0)|0]=z&255;a[u+(1-v)|0]=z>>>8&255;a[u+(2-v)|0]=z>>>16&255;G=(c[t>>2]|0)+v|0}if(y>>>0>=80){break}u=u+(-G|0)|0;y=y+1|0}c[p>>2]=(c[p>>2]|0)+3;o=320;break L3898;break};case 1:case 2:{y=e+17300|0;u=e+17288|0;t=e+16488|0;s=e+17312|0;w=q;x=1;while(1){r=c[y>>2]|0;v=d[(c[u>>2]|0)+r|0]|0;if((c[t>>2]|0)==0){c[y>>2]=r+1;b[w>>1]=c[e+88+(c[e+24+(v>>>4<<2)>>2]<<2)>>2]&65535;z=c[s>>2]|0;b[w+(-z|0)>>1]=c[e+88+(c[e+24+((v&15)<<2)>>2]<<2)>>2]&65535;H=(c[s>>2]|0)+z|0}else{c[y>>2]=r-1;b[w>>1]=c[e+88+(c[e+24+((v&15)<<2)>>2]<<2)>>2]&65535;r=c[s>>2]|0;b[w+(-r|0)>>1]=c[e+88+(c[e+24+(v>>>4<<2)>>2]<<2)>>2]&65535;H=(c[s>>2]|0)+r|0}if(x>>>0>=80){break}w=w+(-H|0)|0;x=x+1|0}c[p>>2]=(c[p>>2]|0)+2;o=320;break L3898;break};case 0:{x=e+17300|0;w=e+17288|0;s=e+16488|0;y=e+17312|0;t=q;u=1;while(1){r=c[x>>2]|0;v=d[(c[w>>2]|0)+r|0]|0;if((c[s>>2]|0)==0){c[x>>2]=r+1;a[t]=c[e+88+(c[e+24+(v>>>4<<2)>>2]<<2)>>2]&255;z=c[y>>2]|0;a[t+(-z|0)|0]=c[e+88+(c[e+24+((v&15)<<2)>>2]<<2)>>2]&255;I=(c[y>>2]|0)+z|0}else{c[x>>2]=r-1;a[t]=c[e+88+(c[e+24+((v&15)<<2)>>2]<<2)>>2]&255;r=c[y>>2]|0;a[t+(-r|0)|0]=c[e+88+(c[e+24+(v>>>4<<2)>>2]<<2)>>2]&255;I=(c[y>>2]|0)+r|0}if(u>>>0>=80){break}t=t+(-I|0)|0;u=u+1|0}c[p>>2]=(c[p>>2]|0)+1;o=320;break L3898;break};case 4:{u=e+17300|0;t=e+17288|0;y=e+16488|0;x=e+17312|0;s=q;w=1;while(1){r=c[u>>2]|0;v=d[(c[t>>2]|0)+r|0]|0;if((c[y>>2]|0)==0){c[u>>2]=r+1;c[s>>2]=c[e+88+(c[e+24+(v>>>4<<2)>>2]<<2)>>2];z=c[x>>2]|0;c[s+(-z|0)>>2]=c[e+88+(c[e+24+((v&15)<<2)>>2]<<2)>>2];J=(c[x>>2]|0)+z|0}else{c[u>>2]=r-1;c[s>>2]=c[e+88+(c[e+24+((v&15)<<2)>>2]<<2)>>2];r=c[x>>2]|0;c[s+(-r|0)>>2]=c[e+88+(c[e+24+(v>>>4<<2)>>2]<<2)>>2];J=(c[x>>2]|0)+r|0}if(w>>>0>=80){break}s=s+(-J|0)|0;w=w+1|0}c[p>>2]=(c[p>>2]|0)+4;o=320;break L3898;break};default:{o=320;break L3898}}}else{o=320;break}}else{c[g>>2]=0;o=0}}while(0);c[e+16528>>2]=1;m=o;n=h}g=c[n>>2]|0;if((g|0)<0){K=1}else{K=g+1<<i}g=(c[135448]|0)+K|0;if(g>>>0>=(c[135456]|0)>>>0){k=m;l=i;break}c[135456]=g;k=m;l=i}}while(0);do{if((c[e+16596>>2]|0)!=0){m=c[e+16532>>2]|0;c[e+16624>>2]=m;if((m|0)==0){c[e+16616>>2]=0;c[e+16620>>2]=0;break}m=e+16604|0;K=c[m>>2]|0;n=K-1|0;c[m>>2]=n;o=e+16620|0;L4038:do{if((n|0)<0){c[o>>2]=1;J=c[e+16588>>2]|0;c[m>>2]=J+K;c[e+16608>>2]=1;c[e+17296>>2]=0;c[e+17292>>2]=J;if((c[e+20>>2]&4|0)!=0){J=e+16|0;c[J>>2]=c[J>>2]|4;c[135444]=1}J=c[e+17316>>2]|0;if((J|0)!=0){c[e+17280>>2]=f2[J&255](c[e+17320>>2]|0)|0}J=c[e+17304>>2]|0;if((J|0)==2){I=c[e+17280>>2]|0;H=e+17284|0;c[H>>2]=I;switch(c[e+17308>>2]|0){case 0:{c[H>>2]=I+101;break L4038;break};case 1:case 2:{c[H>>2]=I+202;break L4038;break};case 3:{c[H>>2]=I+303;break L4038;break};case 4:{c[H>>2]=I+404;break L4038;break};default:{break L4038}}}else if((J|0)==3){c[e+17284>>2]=(c[e+17280>>2]|0)+((c[e+17312>>2]|0)*159|0);break}else{c[e+17284>>2]=c[e+17280>>2];break}}else{c[o>>2]=0}}while(0);c[e+16616>>2]=1}}while(0);do{if((c[e+16684>>2]|0)==0){L=l}else{o=(c[e+16688>>2]|0)+7|0;K=e+16716|0;m=c[K>>2]|0;n=((c[135448]|0)-m|0)>>>(o>>>0);do{if((n|0)==0){M=c[e+16692>>2]|0;j=3046}else{c[K>>2]=(n<<o)+m;i=e+16692|0;h=(c[i>>2]|0)-n|0;c[i>>2]=h;if((h|0)>=0){N=h;j=3047;break}c[e+16708>>2]=1;h=e+17088|0;J=c[h>>2]|0;do{if((J|0)==0){I=e+17268|0;H=c[I>>2]|0;if((H|0)>0){G=e+17264|0;F=c[G>>2]|0;c[e+17104>>2]=c[e+17132+(F<<2)>>2];c[G>>2]=F+1&31;F=H-1|0;c[I>>2]=F;O=F}else{O=H}c[h>>2]=(O|0)>0?55:-2147483648;H=e+17108|0;if((c[H>>2]|0)!=0){c[e+17276>>2]=1}c[H>>2]=1}else{if((J|0)<0){break}c[h>>2]=J-1}}while(0);J=e+17092|0;p=c[J>>2]|0;do{if((p|0)==0){do{if((c[e+17096>>2]|0)==0){c[J>>2]=-2147483648}else{c[e+17100>>2]=32768;c[J>>2]=11;H=e+17268|0;F=c[H>>2]|0;if((F|0)>=32){break}if((F|0)==0){c[h>>2]=11}F=e+17264|0;I=(c[F>>2]|0)+31&31;c[F>>2]=I;c[e+17132+(I<<2)>>2]=32768;c[H>>2]=(c[H>>2]|0)+1}}while(0);H=c[e+17124>>2]|0;if((H|0)==0){break}f0[H&255](c[e+17100>>2]|0,c[e+17128>>2]|0)}else{if((p|0)<0){break}c[J>>2]=p-1}}while(0);p=c[e+16676>>2]|0;J=p+1+(c[i>>2]|0)|0;c[i>>2]=J;if((J|0)>=0){N=J;j=3047;break}c[i>>2]=p;c[K>>2]=c[135448];M=p;j=3046}}while(0);if((j|0)==3046){if((M|0)<0){P=1}else{N=M;j=3047}}if((j|0)==3047){P=N+1<<o}K=(c[135448]|0)+P|0;if(K>>>0>=(c[135456]|0)>>>0){L=o;break}c[135456]=K;L=o}}while(0);do{if((c[e+17092>>2]|0)<0){if((c[e+17084>>2]|0)==0){break}P=e+16|0;c[P>>2]=c[P>>2]|16;c[135444]=1}}while(0);do{if((c[e+17108>>2]|0)!=0){if((c[e+17080>>2]|0)==0){break}P=e+16|0;c[P>>2]=c[P>>2]|16;c[135444]=1}}while(0);do{if((c[e+16552>>2]|0)==0){Q=L}else{P=e+16548|0;N=c[P>>2]|0;if((N|0)==0){if((c[e+16564>>2]|0)!=0){Q=L;break}}j=e+16556|0;M=c[j>>2]|0;if((M|0)==7){Q=L;break}O=M+4|0;l=e+16584|0;K=c[l>>2]|0;n=((c[135448]|0)-K|0)>>>(O>>>0);if((n|0)==0){c[e+16572>>2]=0;c[e+16576>>2]=0;R=c[e+16560>>2]|0}else{c[l>>2]=(n<<O)+K;K=e+16560|0;l=(c[K>>2]|0)-n|0;c[K>>2]=l;n=e+16576|0;if((l|0)<0){c[n>>2]=1;if((c[e+20>>2]&2|0)==0){S=N}else{N=e+16|0;c[N>>2]=c[N>>2]|2;c[135444]=1;S=c[P>>2]|0}if((S|0)==0){T=0}else{T=(c[e+16544>>2]|0)+1+(c[K>>2]|0)|0}c[K>>2]=T;c[e+16564>>2]=1;U=c[j>>2]|0;V=T}else{c[n>>2]=0;U=M;V=l}c[e+16572>>2]=1;if((U|0)==7){Q=O;break}else{R=V}}if((R|0)<0){W=1}else{W=R+1<<O}l=(c[135448]|0)+W|0;if(l>>>0>=(c[135456]|0)>>>0){Q=O;break}c[135456]=l;Q=O}}while(0);do{if((c[e+16640>>2]|0)==0){X=Q}else{W=e+16636|0;R=c[W>>2]|0;if((R|0)==0){if((c[e+16652>>2]|0)!=0){X=Q;break}}V=e+16644|0;U=c[V>>2]|0;if((U|0)==7){T=c[e+16576>>2]|0;c[e+16668>>2]=T;Y=(T|0)!=0|0;Z=Q}else{T=U+4|0;Y=((c[135448]|0)-(c[e+16672>>2]|0)|0)>>>(T>>>0);Z=T}if((Y|0)==0){c[e+16660>>2]=0;c[e+16664>>2]=0;_=U}else{T=e+16672|0;c[T>>2]=(c[T>>2]|0)+(Y<<Z);T=e+16648|0;S=(c[T>>2]|0)-Y|0;c[T>>2]=S;L=e+16664|0;if((S|0)<0){c[L>>2]=1;if((c[e+20>>2]&8|0)==0){$=R}else{R=e+16|0;c[R>>2]=c[R>>2]|8;c[135444]=1;$=c[W>>2]|0}if(($|0)==0){aa=0}else{aa=(c[e+16632>>2]|0)+1+(c[T>>2]|0)|0}c[T>>2]=aa;c[e+16652>>2]=1;ab=c[V>>2]|0}else{c[L>>2]=0;ab=U}c[e+16660>>2]=1;_=ab}if((_|0)==7){X=Z;break}U=c[e+16648>>2]|0;if((U|0)<0){ac=1}else{ac=U+1<<Z}U=(c[135448]|0)+ac|0;if(U>>>0>=(c[135456]|0)>>>0){X=Z;break}c[135456]=U;X=Z}}while(0);do{if((c[e+16728>>2]|0)==0){ad=X}else{Z=e+16724|0;ac=c[Z>>2]|0;if((ac|0)==0){if((c[e+16740>>2]|0)!=0){ad=X;break}}_=e+16732|0;ab=c[_>>2]|0;if((ab|0)==7){aa=c[e+16664>>2]|0;c[e+16756>>2]=aa;ae=(aa|0)!=0|0;af=X}else{aa=ab+4|0;ae=((c[135448]|0)-(c[e+16760>>2]|0)|0)>>>(aa>>>0);af=aa}if((ae|0)==0){c[e+16748>>2]=0;c[e+16752>>2]=0;ag=ab}else{aa=e+16760|0;c[aa>>2]=(c[aa>>2]|0)+(ae<<af);aa=e+16736|0;$=(c[aa>>2]|0)-ae|0;c[aa>>2]=$;Y=e+16752|0;if(($|0)<0){c[Y>>2]=1;if((c[e+20>>2]&32|0)==0){ah=ac}else{ac=e+16|0;c[ac>>2]=c[ac>>2]|32;c[135444]=1;ah=c[Z>>2]|0}if((ah|0)==0){ai=0}else{ai=(c[e+16720>>2]|0)+1+(c[aa>>2]|0)|0}c[aa>>2]=ai;c[e+16740>>2]=1;aj=c[_>>2]|0}else{c[Y>>2]=0;aj=ab}c[e+16748>>2]=1;ag=aj}if((ag|0)==7){ad=af;break}ab=c[e+16736>>2]|0;if((ab|0)<0){ak=1}else{ak=ab+1<<af}ab=(c[135448]|0)+ak|0;if(ab>>>0>=(c[135456]|0)>>>0){ad=af;break}c[135456]=ab;ad=af}}while(0);do{if((c[e+16816>>2]|0)==0){al=ad}else{af=e+16812|0;ak=c[af>>2]|0;if((ak|0)==0){if((c[e+16828>>2]|0)!=0){al=ad;break}}ag=e+16820|0;aj=c[ag>>2]|0;if((aj|0)==7){ai=c[e+16752>>2]|0;c[e+16844>>2]=ai;am=(ai|0)!=0|0;an=ad}else{ai=aj+4|0;am=((c[135448]|0)-(c[e+16848>>2]|0)|0)>>>(ai>>>0);an=ai}if((am|0)==0){c[e+16836>>2]=0;c[e+16840>>2]=0;ao=aj}else{ai=e+16848|0;c[ai>>2]=(c[ai>>2]|0)+(am<<an);ai=e+16824|0;ah=(c[ai>>2]|0)-am|0;c[ai>>2]=ah;ae=e+16840|0;if((ah|0)<0){c[ae>>2]=1;if((c[e+20>>2]&128|0)==0){ap=ak}else{ak=e+16|0;c[ak>>2]=c[ak>>2]|128;c[135444]=1;ap=c[af>>2]|0}if((ap|0)==0){aq=0}else{aq=(c[e+16808>>2]|0)+1+(c[ai>>2]|0)|0}c[ai>>2]=aq;c[e+16828>>2]=1;ar=c[ag>>2]|0}else{c[ae>>2]=0;ar=aj}c[e+16836>>2]=1;ao=ar}if((ao|0)==7){al=an;break}aj=c[e+16824>>2]|0;if((aj|0)<0){as=1}else{as=aj+1<<an}aj=(c[135448]|0)+as|0;if(aj>>>0>=(c[135456]|0)>>>0){al=an;break}c[135456]=aj;al=an}}while(0);do{if((c[e+16772>>2]|0)==0){at=al}else{an=e+16768|0;as=c[an>>2]|0;if((as|0)==0){if((c[e+16784>>2]|0)!=0){at=al;break}}ao=(c[e+16776>>2]|0)+4|0;ar=e+16804|0;aq=c[ar>>2]|0;ap=((c[135448]|0)-aq|0)>>>(ao>>>0);if((ap|0)==0){c[e+16792>>2]=0;c[e+16796>>2]=0;au=c[e+16780>>2]|0}else{c[ar>>2]=(ap<<ao)+aq;aq=e+16780|0;ar=(c[aq>>2]|0)-ap|0;c[aq>>2]=ar;ap=e+16796|0;if((ar|0)<0){c[ap>>2]=1;if((c[e+20>>2]&64|0)==0){av=as}else{as=e+16|0;c[as>>2]=c[as>>2]|64;c[135444]=1;av=c[an>>2]|0}if((av|0)==0){aw=0}else{aw=(c[e+16764>>2]|0)+1+(c[aq>>2]|0)|0}c[aq>>2]=aw;c[e+16784>>2]=1;ax=aw}else{c[ap>>2]=0;ax=ar}c[e+16792>>2]=1;au=ax}if((au|0)<0){ay=1}else{ay=au+1<<ao}ar=(c[135448]|0)+ay|0;if(ar>>>0>=(c[135456]|0)>>>0){at=ao;break}c[135456]=ar;at=ao}}while(0);if(!(a[8168]|0)){az=c[135448]|0;aA=az+k|0;c[135448]=aA;return}ay=c[e+17076>>2]|0;if((ay&17|0)==0){aB=0;aC=0}else{aB=1;aC=a[e+16897|0]|0}if((ay&34|0)==0){aD=aB;aE=aC}else{aD=aB+1|0;aE=aC+(a[e+16953|0]|0)|0}if((ay&68|0)==0){aF=aD;aG=aE}else{aF=aD+1|0;aG=aE+(a[e+17009|0]|0)|0}if((ay&136|0)==0){aH=aF;aI=aG}else{aH=aF+1|0;aI=aG+(a[e+17065|0]|0)|0}if((aH|0)==0){aJ=-128}else{aJ=(((aI+(aH<<7)|0)>>>0)/(aH>>>0)|0)&255}aH=c[135466]|0;aI=c[135448]|0;if((aH+725|0)>>>0<aI>>>0){aG=c[135468]|0;aF=aH;while(1){a[541880+aG|0]=aJ;aK=((aG+1|0)>>>0)%5512|0;aL=aF+725|0;if((aF+1450|0)>>>0<aI>>>0){aG=aK;aF=aL}else{break}}c[135468]=aK;c[135466]=aL}do{if((c[e+16860>>2]|0)==0){aM=at}else{aL=(c[e+16856>>2]|0)==0;if(aL){if((c[e+16872>>2]|0)!=0){aM=at;break}}aK=a[e+16896|0]|0;if(aK<<24>>24==0){aM=at;break}aF=c[e+16852>>2]|0;if((aF|0)==0){aM=at;break}aG=c[e+16864>>2]|0;aJ=(aG|0)==7;if(aJ){aH=c[e+16840>>2]|0;c[e+16888>>2]=aH;aN=(aH|0)!=0|0;aO=at}else{aH=aG+4|0;aN=(aI-(c[e+16892>>2]|0)|0)>>>(aH>>>0);aO=aH}if((aN|0)==0){c[e+16880>>2]=0;c[e+16884>>2]=0}else{aH=e+16892|0;c[aH>>2]=(c[aH>>2]|0)+(aN<<aO);aH=e+16868|0;aG=(c[aH>>2]|0)-aN|0;c[aH>>2]=aG;ay=e+16884|0;do{if((aG|0)<0){c[ay>>2]=1;do{if(aL){c[e+16872>>2]=1;c[aH>>2]=0}else{aE=aF+1+aG|0;c[aH>>2]=aE;if((aE|0)>=0){break}c[aH>>2]=0}}while(0);i=e+16904|0;aE=kO(c[i>>2]|0)|0;c[i>>2]=aE;if((c[e+16900>>2]|0)!=0){i=e+16897|0;aD=aK<<24>>24;aC=((aE&1|0)==0?-aD|0:aD)+(a[i]|0)|0;aD=(aC|0)>127?127:aC;a[i]=(aD|0)<-128?-128:aD&255;break}if((aE&1|0)==0){a[e+16897|0]=-aK&255;break}else{a[e+16897|0]=aK;break}}else{c[ay>>2]=0}}while(0);c[e+16880>>2]=1}if(aJ){aM=aO;break}ay=c[e+16868>>2]|0;if((ay|0)<0){aP=1}else{aP=ay+1<<aO}ay=(c[135448]|0)+aP|0;if(ay>>>0>=(c[135456]|0)>>>0){aM=aO;break}c[135456]=ay;aM=aO}}while(0);do{if((c[e+16916>>2]|0)==0){aQ=aM}else{aO=(c[e+16912>>2]|0)==0;if(aO){if((c[e+16928>>2]|0)!=0){aQ=aM;break}}aP=a[e+16952|0]|0;if(aP<<24>>24==0){aQ=aM;break}aN=c[e+16908>>2]|0;if((aN|0)==0){aQ=aM;break}aI=c[e+16920>>2]|0;at=(aI|0)==7;if(at){ay=c[e+16884>>2]|0;c[e+16944>>2]=ay;aR=(ay|0)!=0|0;aS=aM}else{ay=aI+4|0;aR=((c[135448]|0)-(c[e+16948>>2]|0)|0)>>>(ay>>>0);aS=ay}if((aR|0)==0){c[e+16936>>2]=0;c[e+16940>>2]=0}else{ay=e+16948|0;c[ay>>2]=(c[ay>>2]|0)+(aR<<aS);ay=e+16924|0;aI=(c[ay>>2]|0)-aR|0;c[ay>>2]=aI;aK=e+16940|0;do{if((aI|0)<0){c[aK>>2]=1;do{if(aO){c[e+16928>>2]=1;c[ay>>2]=0}else{aH=aN+1+aI|0;c[ay>>2]=aH;if((aH|0)>=0){break}c[ay>>2]=0}}while(0);aH=e+16960|0;aG=kO(c[aH>>2]|0)|0;c[aH>>2]=aG;if((c[e+16956>>2]|0)!=0){aH=e+16953|0;aF=aP<<24>>24;aL=((aG&1|0)==0?-aF|0:aF)+(a[aH]|0)|0;aF=(aL|0)>127?127:aL;a[aH]=(aF|0)<-128?-128:aF&255;break}if((aG&1|0)==0){a[e+16953|0]=-aP&255;break}else{a[e+16953|0]=aP;break}}else{c[aK>>2]=0}}while(0);c[e+16936>>2]=1}if(at){aQ=aS;break}aK=c[e+16924>>2]|0;if((aK|0)<0){aT=1}else{aT=aK+1<<aS}aK=(c[135448]|0)+aT|0;if(aK>>>0>=(c[135456]|0)>>>0){aQ=aS;break}c[135456]=aK;aQ=aS}}while(0);do{if((c[e+16972>>2]|0)==0){aU=aQ}else{aS=(c[e+16968>>2]|0)==0;if(aS){if((c[e+16984>>2]|0)!=0){aU=aQ;break}}aT=a[e+17008|0]|0;if(aT<<24>>24==0){aU=aQ;break}aR=c[e+16964>>2]|0;if((aR|0)==0){aU=aQ;break}aM=c[e+16976>>2]|0;aK=(aM|0)==7;if(aK){aP=c[e+16940>>2]|0;c[e+17e3>>2]=aP;aV=(aP|0)!=0|0;aW=aQ}else{aP=aM+4|0;aV=((c[135448]|0)-(c[e+17004>>2]|0)|0)>>>(aP>>>0);aW=aP}if((aV|0)==0){c[e+16992>>2]=0;c[e+16996>>2]=0}else{aP=e+17004|0;c[aP>>2]=(c[aP>>2]|0)+(aV<<aW);aP=e+16980|0;aM=(c[aP>>2]|0)-aV|0;c[aP>>2]=aM;ay=e+16996|0;do{if((aM|0)<0){c[ay>>2]=1;do{if(aS){c[e+16984>>2]=1;c[aP>>2]=0}else{aI=aR+1+aM|0;c[aP>>2]=aI;if((aI|0)>=0){break}c[aP>>2]=0}}while(0);aI=e+17016|0;aN=kO(c[aI>>2]|0)|0;c[aI>>2]=aN;if((c[e+17012>>2]|0)!=0){aI=e+17009|0;aO=aT<<24>>24;aJ=((aN&1|0)==0?-aO|0:aO)+(a[aI]|0)|0;aO=(aJ|0)>127?127:aJ;a[aI]=(aO|0)<-128?-128:aO&255;break}if((aN&1|0)==0){a[e+17009|0]=-aT&255;break}else{a[e+17009|0]=aT;break}}else{c[ay>>2]=0}}while(0);c[e+16992>>2]=1}if(aK){aU=aW;break}ay=c[e+16980>>2]|0;if((ay|0)<0){aX=1}else{aX=ay+1<<aW}ay=(c[135448]|0)+aX|0;if(ay>>>0>=(c[135456]|0)>>>0){aU=aW;break}c[135456]=ay;aU=aW}}while(0);if((c[e+17028>>2]|0)==0){az=c[135448]|0;aA=az+k|0;c[135448]=aA;return}aW=(c[e+17024>>2]|0)==0;do{if(aW){if((c[e+17040>>2]|0)==0){break}az=c[135448]|0;aA=az+k|0;c[135448]=aA;return}}while(0);aX=a[e+17064|0]|0;if(aX<<24>>24==0){az=c[135448]|0;aA=az+k|0;c[135448]=aA;return}aV=c[e+17020>>2]|0;if((aV|0)==0){az=c[135448]|0;aA=az+k|0;c[135448]=aA;return}aQ=c[e+17032>>2]|0;ay=(aQ|0)==7;if(ay){aT=c[e+16996>>2]|0;c[e+17056>>2]=aT;aY=(aT|0)!=0|0;aZ=aU}else{aU=aQ+4|0;aY=((c[135448]|0)-(c[e+17060>>2]|0)|0)>>>(aU>>>0);aZ=aU}if((aY|0)==0){c[e+17048>>2]=0;c[e+17052>>2]=0}else{aU=e+17060|0;c[aU>>2]=(c[aU>>2]|0)+(aY<<aZ);aU=e+17036|0;aQ=(c[aU>>2]|0)-aY|0;c[aU>>2]=aQ;aY=e+17052|0;do{if((aQ|0)<0){c[aY>>2]=1;do{if(aW){c[e+17040>>2]=1;c[aU>>2]=0}else{aT=aV+1+aQ|0;c[aU>>2]=aT;if((aT|0)>=0){break}c[aU>>2]=0}}while(0);aK=e+17072|0;aT=kO(c[aK>>2]|0)|0;c[aK>>2]=aT;if((c[e+17068>>2]|0)!=0){aK=e+17065|0;aP=aX<<24>>24;aM=((aT&1|0)==0?-aP|0:aP)+(a[aK]|0)|0;aP=(aM|0)>127?127:aM;a[aK]=(aP|0)<-128?-128:aP&255;break}if((aT&1|0)==0){a[e+17065|0]=-aX&255;break}else{a[e+17065|0]=aX;break}}else{c[aY>>2]=0}}while(0);c[e+17048>>2]=1}if(ay){az=c[135448]|0;aA=az+k|0;c[135448]=aA;return}ay=c[e+17036>>2]|0;if((ay|0)<0){a_=1}else{a_=ay+1<<aZ}aZ=(c[135448]|0)+a_|0;if(aZ>>>0>=(c[135456]|0)>>>0){az=c[135448]|0;aA=az+k|0;c[135448]=aA;return}c[135456]=aZ;az=c[135448]|0;aA=az+k|0;c[135448]=aA;return}function k$(a){a=a|0;return 256}function k0(a){a=a|0;return 65536}function k1(a){a=a|0;return}function k2(a){a=a|0;return}function k3(a){a=a|0;return 512}function k4(b,c,d){b=b|0;c=c|0;d=d|0;a[b+4+c|0]=d;return}function k5(b,c){b=b|0;c=c|0;return a[b+4+c|0]|0}function k6(b,c,d){b=b|0;c=c|0;d=d|0;if((a[b+4|0]&1)==0){return}a[(c&511)+(b+6)|0]=d;return}function k7(b,c){b=b|0;c=c|0;return a[(c&511)+(b+6)|0]|0}function k8(a){a=a|0;c[a>>2]=56840;return}function k9(a){a=a|0;var b=0,d=0;c[a>>2]=57096;do{if((c[a+65544>>2]|0)!=0){b=a+65540|0;d=c[b>>2]|0;if((d|0)!=0){sS(d)}c[b>>2]=0;if((a|0)!=0){break}return}}while(0);sS(a);return}function la(a){a=a|0;var b=0;c[a>>2]=57096;if((c[a+65544>>2]|0)==0){return}b=a+65540|0;a=c[b>>2]|0;if((a|0)!=0){sS(a)}c[b>>2]=0;return}function lb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[a+65544>>2]|0;if(b>>>0>9){e=a+65540|0;f=c[e>>2]|0;g=f+2|0;h=(B=d[g]|d[g+1|0]<<8,B<<16>>16);g=f+4|0;f=(B=d[g]|d[g+1|0]<<8,B<<16>>16);g=cn(h|0)|0;h=(cn(f|0)|0)&65535;f=(h|0)>(b|0)?b:h;h=g-10&65535;s_(a+4|0,0,h|0);g=a+4+h|0;b=c[e>>2]|0;s1(g|0,b|0,f)|0;s_(f+h+(a+4)|0,0,65536-h-f|0);c[135462]=h;return}else{s_(a+4|0,-1|0,65536);return}}function lc(a,b){a=a|0;b=b|0;be(48920,17,1,b|0)|0;return(be(a+4|0,1,65536,b|0)|0)!=0|0}function ld(a,b){a=a|0;b=b|0;be(28584,17,1,b|0)|0;return(be(a+6|0,1,512,b|0)|0)!=0|0}function le(a){a=a|0;if((a|0)==0){return}sS(a);return}function lf(a){a=a|0;c[a>>2]=56840;if((a|0)==0){return}sS(a);return}function lg(d){d=d|0;var e=0;e=c[d+4>>2]|0;c[d+244>>2]=f2[c[(c[e>>2]|0)+44>>2]&255](e)|0;s_(d+8|0,0,42);b[d+50>>1]=127;b[d+52>>1]=127;b[d+54>>1]=0;b[d+56>>1]=0;c[d+60>>2]=-1;c[d+64>>2]=-1;c[d+68>>2]=-1;c[d+72>>2]=65535;c[d+76>>2]=1;c[d+80>>2]=1;c[d+84>>2]=1;c[d+192>>2]=0;c[d+196>>2]=0;a[d+200|0]=0;s_(d+88|0,0,101);a[d+201|0]=1;a[d+202|0]=2;a[d+203|0]=3;a[d+204|0]=4;a[d+205|0]=5;a[d+206|0]=6;a[d+207|0]=7;a[d+208|0]=8;a[d+209|0]=9;a[d+210|0]=10;a[d+211|0]=11;a[d+212|0]=12;a[d+213|0]=13;a[d+214|0]=14;a[d+215|0]=15;a[d+256|0]=0;a[d+257|0]=0;return}function lh(a,b){a=a|0;b=b|0;var c=0;be(39208,19,1,b|0)|0;if((be(a+8|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+10|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+12|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+14|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+16|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+18|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+20|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+22|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+24|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+26|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+28|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+30|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+32|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+34|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+36|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+38|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+40|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+42|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+44|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+46|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+48|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+50|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+52|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+54|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+56|0,2,1,b|0)|0)==0){c=0;return c|0}if((be(a+60|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+64|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+68|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+72|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+88|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+92|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+96|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+100|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+104|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+108|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+112|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+116|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+120|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+124|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+128|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+132|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+136|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+140|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+144|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+148|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+152|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+156|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+160|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+164|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+168|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+172|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+176|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+180|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+184|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+188|0,1,1,b|0)|0)==0){c=0;return c|0}if((be(a+192|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+196|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+200|0,1,16,b|0)|0)==0){c=0;return c|0}if((be(a+216|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+220|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+224|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+228|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+232|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+236|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+240|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+248|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+252|0,4,1,b|0)|0)==0){c=0;return c|0}if((be(a+256|0,1,1,b|0)|0)==0){c=0;return c|0}c=(be(a+257|0,1,1,b|0)|0)!=0;return c|0}function li(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+104|0;e=d|0;s1(e|0,53504,100)|0;f=b+4|0;g=c[f>>2]|0;h=b+8|0;j=c[h>>2]|0;k=(g+19|0)>>>0>j>>>0?j-g|0:19;l=b|0;b=c[l>>2]|0;m=b+g|0;s1(e|0,m|0,k)|0;m=g+k|0;c[f>>2]=m;if((k|0)==0){n=0;i=d;return n|0}if((da(e|0,39208)|0)!=0){n=0;i=d;return n|0}e=a+8|0;k=(m+2|0)>>>0>j>>>0?j-m|0:2;j=b+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+10|0;e=c[h>>2]|0;m=(j+2|0)>>>0>e>>>0?e-j|0:2;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+12|0;k=c[h>>2]|0;j=(e+2|0)>>>0>k>>>0?k-e|0:2;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+14|0;m=c[h>>2]|0;e=(k+2|0)>>>0>m>>>0?m-k|0:2;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+16|0;j=c[h>>2]|0;k=(m+2|0)>>>0>j>>>0?j-m|0:2;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+18|0;e=c[h>>2]|0;m=(j+2|0)>>>0>e>>>0?e-j|0:2;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+20|0;k=c[h>>2]|0;j=(e+2|0)>>>0>k>>>0?k-e|0:2;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+22|0;m=c[h>>2]|0;e=(k+2|0)>>>0>m>>>0?m-k|0:2;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+24|0;j=c[h>>2]|0;k=(m+2|0)>>>0>j>>>0?j-m|0:2;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+26|0;e=c[h>>2]|0;m=(j+2|0)>>>0>e>>>0?e-j|0:2;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+28|0;k=c[h>>2]|0;j=(e+2|0)>>>0>k>>>0?k-e|0:2;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+30|0;m=c[h>>2]|0;e=(k+2|0)>>>0>m>>>0?m-k|0:2;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+32|0;j=c[h>>2]|0;k=(m+2|0)>>>0>j>>>0?j-m|0:2;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+34|0;e=c[h>>2]|0;m=(j+2|0)>>>0>e>>>0?e-j|0:2;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+36|0;k=c[h>>2]|0;j=(e+2|0)>>>0>k>>>0?k-e|0:2;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+38|0;m=c[h>>2]|0;e=(k+2|0)>>>0>m>>>0?m-k|0:2;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+40|0;j=c[h>>2]|0;k=(m+2|0)>>>0>j>>>0?j-m|0:2;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+42|0;e=c[h>>2]|0;m=(j+2|0)>>>0>e>>>0?e-j|0:2;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+44|0;k=c[h>>2]|0;j=(e+2|0)>>>0>k>>>0?k-e|0:2;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+46|0;m=c[h>>2]|0;e=(k+2|0)>>>0>m>>>0?m-k|0:2;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+48|0;j=c[h>>2]|0;k=(m+2|0)>>>0>j>>>0?j-m|0:2;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+50|0;e=c[h>>2]|0;m=(j+2|0)>>>0>e>>>0?e-j|0:2;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+52|0;k=c[h>>2]|0;j=(e+2|0)>>>0>k>>>0?k-e|0:2;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+54|0;m=c[h>>2]|0;e=(k+2|0)>>>0>m>>>0?m-k|0:2;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+56|0;j=c[h>>2]|0;k=(m+2|0)>>>0>j>>>0?j-m|0:2;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+60|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+64|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+68|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+72|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+88|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+92|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+96|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+100|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+104|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+108|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+112|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+116|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+120|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+124|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+128|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+132|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+136|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+140|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+144|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+148|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+152|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+156|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+160|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+164|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+168|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+172|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+176|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+180|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+184|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+188|0;k=c[h>>2]|0;j=(e+1|0)>>>0>k>>>0?k-e|0:1;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+192|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+196|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+200|0;e=c[h>>2]|0;m=(j+16|0)>>>0>e>>>0?e-j|0:16;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+216|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+220|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+224|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+228|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+232|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+236|0;m=c[h>>2]|0;e=(k+4|0)>>>0>m>>>0?m-k|0:4;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+240|0;j=c[h>>2]|0;k=(m+4|0)>>>0>j>>>0?j-m|0:4;j=(c[l>>2]|0)+m|0;s1(e|0,j|0,k)|0;j=(c[f>>2]|0)+k|0;c[f>>2]=j;if((k|0)==0){n=0;i=d;return n|0}k=a+248|0;e=c[h>>2]|0;m=(j+4|0)>>>0>e>>>0?e-j|0:4;e=(c[l>>2]|0)+j|0;s1(k|0,e|0,m)|0;e=(c[f>>2]|0)+m|0;c[f>>2]=e;if((m|0)==0){n=0;i=d;return n|0}m=a+252|0;k=c[h>>2]|0;j=(e+4|0)>>>0>k>>>0?k-e|0:4;k=(c[l>>2]|0)+e|0;s1(m|0,k|0,j)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if((j|0)==0){n=0;i=d;return n|0}j=a+256|0;m=c[h>>2]|0;e=(k+1|0)>>>0>m>>>0?m-k|0:1;m=(c[l>>2]|0)+k|0;s1(j|0,m|0,e)|0;m=(c[f>>2]|0)+e|0;c[f>>2]=m;if((e|0)==0){n=0;i=d;return n|0}e=a+257|0;a=c[h>>2]|0;h=(m+1|0)>>>0>a>>>0?a-m|0:1;a=(c[l>>2]|0)+m|0;s1(e|0,a|0,h)|0;c[f>>2]=(c[f>>2]|0)+h;n=(h|0)!=0;i=d;return n|0}function lj(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=a+228|0;f=c[e>>2]|0;L4888:do{if((f|0)==0){g=a+216|0;if((c[g>>2]|0)==1){c[a+232>>2]=128;h=128;return h|0}i=a+236|0;j=c[i>>2]|0;do{if(j>>>0>1){k=a+220|0;l=c[k>>2]|0;m=a+224|0;n=c[m>>2]|0;if((l|0)==0){o=n<<24;c[m>>2]=o;p=a+8|0;q=b[p>>1]|0;r=q+1&65535;b[p>>1]=r;s=c[a+244>>2]|0;t=(d[s+(q&65535)|0]|0)<<16|o;c[m>>2]=t;o=q+2&65535;b[p>>1]=o;u=(d[s+(r&65535)|0]|0)<<8|t;c[m>>2]=u;b[p>>1]=q+3&65535;q=u|(d[s+(o&65535)|0]|0);c[m>>2]=q;c[k>>2]=24;c[136916]=(c[136916]|0)+9;v=24;w=q}else{v=l;w=n}n=v-1|0;c[k>>2]=n;l=j-1|0;c[i>>2]=l;if((1<<n&w|0)!=0){c[g>>2]=2;if(l>>>0>4){if(n>>>0<4){q=w<<24;c[m>>2]=q;o=a+8|0;s=b[o>>1]|0;u=s+1&65535;b[o>>1]=u;p=c[a+244>>2]|0;t=(d[p+(s&65535)|0]|0)<<16|q;c[m>>2]=t;q=s+2&65535;b[o>>1]=q;r=(d[p+(u&65535)|0]|0)<<8|t;c[m>>2]=r;b[o>>1]=s+3&65535;s=r|(d[p+(q&65535)|0]|0);c[m>>2]=s;q=v+23|0;c[k>>2]=q;c[136916]=(c[136916]|0)+9;x=q;y=s}else{x=n;y=w}s=x-4|0;c[k>>2]=s;c[i>>2]=j-5;z=(y>>>(s>>>0)&15)+1|0}else{z=1}c[e>>2]=z;A=z;break L4888}c[g>>2]=3;if(l>>>0<=4){B=3630;break}if(n>>>0<4){l=w<<24;c[m>>2]=l;s=a+8|0;q=b[s>>1]|0;p=q+1&65535;b[s>>1]=p;r=c[a+244>>2]|0;o=(d[r+(q&65535)|0]|0)<<16|l;c[m>>2]=o;l=q+2&65535;b[s>>1]=l;t=(d[r+(p&65535)|0]|0)<<8|o;c[m>>2]=t;b[s>>1]=q+3&65535;q=t|(d[r+(l&65535)|0]|0);c[m>>2]=q;l=v+23|0;c[k>>2]=l;c[136916]=(c[136916]|0)+9;C=l;D=q}else{C=n;D=w}n=C-4|0;q=D>>>(n>>>0)&15;c[k>>2]=n;l=j-5|0;c[i>>2]=l;c[e>>2]=q;if((q|0)==0){B=3634;break}r=c[a+100>>2]|0;if(l>>>0>r>>>0){if(n>>>0<r>>>0){t=D<<24;c[m>>2]=t;s=a+8|0;o=b[s>>1]|0;p=o+1&65535;b[s>>1]=p;u=c[a+244>>2]|0;E=(d[u+(o&65535)|0]|0)<<16|t;c[m>>2]=E;t=o+2&65535;b[s>>1]=t;F=(d[u+(p&65535)|0]|0)<<8|E;c[m>>2]=F;b[s>>1]=o+3&65535;o=F|(d[u+(t&65535)|0]|0);c[m>>2]=o;m=C+20|0;c[k>>2]=m;c[136916]=(c[136916]|0)+9;G=m;H=o}else{G=n;H=D}n=G-r|0;c[k>>2]=n;c[i>>2]=l-r;I=H>>>(n>>>0)&(1<<r)-1}else{I=0}c[a+232>>2]=d[a+200+I|0]|0;J=q+1|0}else{c[g>>2]=3;B=3630}}while(0);if((B|0)==3630){c[e>>2]=0;B=3634}if((B|0)==3634){c[a+232>>2]=128;J=1}c[e>>2]=J;A=J}else{A=f}}while(0);f=a+232|0;J=c[f>>2]|0;do{if((J|0)==128){K=128}else{B=A-1|0;c[e>>2]=B;I=c[a+216>>2]|0;if((I|0)==3){K=J;break}else if((I|0)==1){H=c[a+100>>2]|0;G=a+236|0;D=c[G>>2]|0;if(D>>>0>H>>>0){C=a+220|0;w=c[C>>2]|0;v=a+224|0;z=c[v>>2]|0;if(w>>>0<H>>>0){y=z<<24;c[v>>2]=y;x=a+8|0;g=b[x>>1]|0;i=g+1&65535;b[x>>1]=i;j=c[a+244>>2]|0;q=(d[j+(g&65535)|0]|0)<<16|y;c[v>>2]=q;y=g+2&65535;b[x>>1]=y;r=(d[j+(i&65535)|0]|0)<<8|q;c[v>>2]=r;b[x>>1]=g+3&65535;g=r|(d[j+(y&65535)|0]|0);c[v>>2]=g;v=w+24|0;c[C>>2]=v;c[136916]=(c[136916]|0)+9;L=v;M=g}else{L=w;M=z}z=L-H|0;c[C>>2]=z;c[G>>2]=D-H;N=M>>>(z>>>0)&(1<<H)-1}else{N=0}c[f>>2]=N;if((B|N|0)==0){c[f>>2]=128;K=128;break}else{B=d[a+200+N|0]|0;c[f>>2]=B;K=B;break}}else if((I|0)==2){I=c[a+100>>2]|0;B=a+236|0;H=c[B>>2]|0;if(H>>>0>I>>>0){z=a+220|0;D=c[z>>2]|0;G=a+224|0;C=c[G>>2]|0;if(D>>>0<I>>>0){w=C<<24;c[G>>2]=w;g=a+8|0;v=b[g>>1]|0;y=v+1&65535;b[g>>1]=y;j=c[a+244>>2]|0;r=(d[j+(v&65535)|0]|0)<<16|w;c[G>>2]=r;w=v+2&65535;b[g>>1]=w;x=(d[j+(y&65535)|0]|0)<<8|r;c[G>>2]=x;b[g>>1]=v+3&65535;v=x|(d[j+(w&65535)|0]|0);c[G>>2]=v;G=D+24|0;c[z>>2]=G;c[136916]=(c[136916]|0)+9;O=G;P=v}else{O=D;P=C}C=O-I|0;c[z>>2]=C;c[B>>2]=H-I;Q=P>>>(C>>>0)&(1<<I)-1}else{Q=0}I=d[a+200+Q|0]|0;c[f>>2]=I;K=I;break}else{h=0;return h|0}}}while(0);h=K;return h|0}
function lk(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;switch(f&255|0){case 24:{f=d+32|0;a[f]=g;a[f+1|0]=0;return};case 11:{a[d+19|0]=g;return};case 111:{a[d+71|0]=g;return};case 128:{f=g&255;c[d+88>>2]=f&7;c[d+92>>2]=f&16;c[d+96>>2]=f&32;c[d+100>>2]=(f>>>6)+1;return};case 129:{f=g&255;c[d+104>>2]=f&1;c[d+108>>2]=f&2;c[d+112>>2]=f&4;c[d+116>>2]=f&8;c[d+120>>2]=f>>>4&3;c[d+124>>2]=f&64;c[d+128>>2]=f&128;return};case 38:{f=d+46|0;a[f]=g;a[f+1|0]=0;return};case 9:{a[d+17|0]=g;return};case 10:{f=d+18|0;a[f]=g;a[f+1|0]=0;return};case 179:{f=c[(c[d+4>>2]|0)+262152>>2]|0;if((c[f+8>>2]|0)!=0){a[(c[f+32>>2]|0)+((c[f+124>>2]&c[f+96>>2])+(c[f+100>>2]<<c[f+120>>2])&c[f+20>>2])|0]=g}if((c[f+108>>2]|0)!=0){return}h=f+96|0;c[h>>2]=(c[h>>2]|0)+1&2047;return};case 131:{a[d+188|0]=g;return};case 144:{c[d+184>>2]=g&1;return};case 8:{h=d+16|0;a[h]=g;a[h+1|0]=0;return};case 4:{h=d+12|0;a[h]=g;a[h+1|0]=0;return};case 130:{h=g&255;c[d+132>>2]=h&15;c[d+136>>2]=h&32;return};case 30:{h=d+38|0;a[h]=g;a[h+1|0]=0;return};case 110:{h=d+68|0;a[h+2|0]=g;a[h+3|0]=0;return};case 178:{h=c[(c[d+4>>2]|0)+262152>>2]|0;if((c[h+4>>2]|0)!=0){a[(c[h+28>>2]|0)+((c[h+116>>2]&c[h+96>>2])+(c[h+100>>2]<<c[h+112>>2])&c[h+16>>2])|0]=g}if((c[h+108>>2]|0)!=0){return}f=h+96|0;c[f>>2]=(c[f>>2]|0)+1&2047;return};case 47:{a[d+57|0]=g;return};case 18:{f=d+26|0;a[f]=g;a[f+1|0]=0;return};case 25:{a[d+33|0]=g;return};case 45:{a[d+55|0]=g;return};case 3:{a[d+11|0]=g;return};case 7:{a[d+15|0]=g;return};case 109:{a[d+69|0]=g;return};case 46:{f=d+56|0;a[f]=g;a[f+1|0]=0;return};case 23:{a[d+31|0]=g;return};case 44:{f=d+54|0;a[f]=g;a[f+1|0]=0;return};case 99:{a[d+67|0]=g;f=d+176|0;c[f>>2]=0;h=c[d+72>>2]|0;if((h|0)==0){c[d+60>>2]=-1;c[d+68>>2]=0;c[f>>2]=1;return}else{f=c[d+64>>2]|0;c[d+60>>2]=(f>>>0)/(h>>>0)|0;c[d+68>>2]=(f>>>0)%(h>>>0)|0;return}break};case 27:{a[d+35|0]=g;return};case 34:{h=d+42|0;a[h]=g;a[h+1|0]=0;return};case 29:{a[d+37|0]=g;return};case 13:{a[d+21|0]=g;return};case 43:{a[d+53|0]=g;return};case 41:{a[d+51|0]=g;return};case 40:{h=d+50|0;a[h]=g;a[h+1|0]=0;return};case 98:{h=d+64|0;a[h+2|0]=g;a[h+3|0]=0;return};case 36:{h=d+44|0;a[h]=g;a[h+1|0]=0;return};case 39:{a[d+47|0]=g;return};case 22:{h=d+30|0;a[h]=g;a[h+1|0]=0;return};case 12:{h=d+20|0;a[h]=g;a[h+1|0]=0;return};case 19:{a[d+27|0]=g;return};case 17:{a[d+25|0]=g;return};case 14:{h=d+22|0;a[h]=g;a[h+1|0]=0;return};case 97:{a[d+65|0]=g;return};case 16:{h=d+24|0;a[h]=g;a[h+1|0]=0;return};case 32:{h=d+40|0;a[h]=g;a[h+1|0]=0;return};case 37:{a[d+45|0]=g;return};case 6:{h=d+14|0;a[h]=g;a[h+1|0]=0;return};case 5:{a[d+13|0]=g;return};case 146:{h=g&255;c[d+140>>2]=h&2;if((h&4|0)!=0){c[d+168>>2]=0}c[d+144>>2]=h&8;c[d+148>>2]=h&16;c[d+152>>2]=h&32;c[d+156>>2]=h&64;c[d+160>>2]=h&128;return};case 82:{a[d+60|0]=g;go[c[(c[d>>2]|0)+20>>2]&127](d,64595,0);return};case 83:{h=d+60|0;a[h+1|0]=g;if((c[d+160>>2]|0)==0){return}f=h;h=b[f>>1]|0;if(((h&65535)+65535&32768|0)==0){c[d+80>>2]=1;return}else{c[d+80>>2]=-1;b[f>>1]=-h&65535;return}break};case 84:{h=d+60|0;a[h+2|0]=g;a[h+3|0]=0;return};case 85:{h=d+60|0;a[h+3|0]=g;f=(c[d+160>>2]|0)==0;i=h+2|0;j=b[i>>1]|0;do{if(f){k=j}else{if(((j&65535)+65535&32768|0)==0){c[d+76>>2]=1;k=j;break}else{l=-j&65535;c[d+76>>2]=-1;b[i>>1]=l;k=l;break}}}while(0);c[d+176>>2]=0;i=ag(e[h>>1]|0,k&65535)|0;k=d+64|0;c[k>>2]=i;do{if(f){m=i}else{h=(c[d+80>>2]|0)+(c[d+76>>2]|0)|0;c[d+84>>2]=h;if((h|0)!=0){m=i;break}h=-i|0;c[k>>2]=h;m=h}}while(0);if((c[d+156>>2]|0)==0){return}k=d+68|0;c[k>>2]=(c[k>>2]|0)+m;return};case 86:{m=d+72|0;a[m]=g;a[m+1|0]=0;return};case 87:{a[d+73|0]=g;return};case 96:{m=d+64|0;a[m]=g;a[m+1|0]=0;return};case 26:{m=d+34|0;a[m]=g;a[m+1|0]=0;return};case 31:{a[d+39|0]=g;return};case 35:{a[d+43|0]=g;return};case 21:{a[d+29|0]=g;return};case 2:{m=d+10|0;a[m]=g;a[m+1|0]=0;return};case 0:{m=d+8|0;a[m]=g;a[m+1|0]=0;return};case 33:{a[d+41|0]=g;return};case 1:{a[d+9|0]=g;return};case 108:{m=d+68|0;a[m]=g;a[m+1|0]=0;c[d+176>>2]=0;return};case 42:{m=d+52|0;a[m]=g;a[m+1|0]=0;return};case 20:{m=d+28|0;a[m]=g;a[m+1|0]=0;return};case 28:{m=d+36|0;a[m]=g;a[m+1|0]=0;return};case 15:{a[d+23|0]=g;return};case 145:{m=g&255;c[d+192>>2]=m&1;c[d+196>>2]=m&4;return};default:{return}}}function ll(a){a=a|0;return 256}function lm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;L5135:do{switch(d&255|0){case 28:{e=a[b+36|0]|0;break};case 7:{e=a[b+15|0]|0;break};case 30:{e=a[b+38|0]|0;break};case 29:{e=a[b+37|0]|0;break};case 31:{e=a[b+39|0]|0;break};case 35:{e=a[b+43|0]|0;break};case 0:{e=a[b+8|0]|0;break};case 21:{e=a[b+29|0]|0;break};case 16:{e=a[b+24|0]|0;break};case 36:{e=a[b+44|0]|0;break};case 40:{e=a[b+50|0]|0;break};case 32:{e=a[b+40|0]|0;break};case 1:{e=a[b+9|0]|0;break};case 17:{e=a[b+25|0]|0;break};case 2:{e=a[b+10|0]|0;break};case 10:{e=a[b+18|0]|0;break};case 13:{e=a[b+21|0]|0;break};case 26:{e=a[b+34|0]|0;break};case 3:{e=a[b+11|0]|0;break};case 5:{e=a[b+13|0]|0;break};case 6:{e=a[b+14|0]|0;break};case 18:{e=a[b+26|0]|0;break};case 27:{e=a[b+35|0]|0;break};case 20:{e=a[b+28|0]|0;break};case 22:{e=a[b+30|0]|0;break};case 25:{e=a[b+33|0]|0;break};case 23:{e=a[b+31|0]|0;break};case 11:{e=a[b+19|0]|0;break};case 8:{e=a[b+16|0]|0;break};case 33:{e=a[b+41|0]|0;break};case 34:{e=a[b+42|0]|0;break};case 15:{e=a[b+23|0]|0;break};case 12:{e=a[b+20|0]|0;break};case 9:{e=a[b+17|0]|0;break};case 37:{e=a[b+45|0]|0;break};case 39:{e=a[b+47|0]|0;break};case 38:{e=a[b+46|0]|0;break};case 41:{e=a[b+51|0]|0;break};case 42:{e=a[b+52|0]|0;break};case 43:{e=a[b+53|0]|0;break};case 44:{e=a[b+54|0]|0;break};case 45:{e=a[b+55|0]|0;break};case 46:{e=a[b+56|0]|0;break};case 47:{e=a[b+57|0]|0;break};case 82:{e=a[b+60|0]|0;break};case 83:{e=a[b+61|0]|0;break};case 84:{e=a[b+62|0]|0;break};case 85:{e=a[b+63|0]|0;break};case 86:{e=a[b+72|0]|0;break};case 87:{e=a[b+73|0]|0;break};case 96:{e=a[b+64|0]|0;break};case 97:{e=a[b+65|0]|0;break};case 98:{e=a[b+66|0]|0;break};case 99:{e=a[b+67|0]|0;break};case 108:{e=a[b+68|0]|0;break};case 109:{e=a[b+69|0]|0;break};case 110:{e=a[b+70|0]|0;break};case 111:{e=a[b+71|0]|0;break};case 146:{e=(((c[b+140>>2]|0)!=0?2:0)|(c[135452]|0)!=0|((c[b+168>>2]|0)!=0?4:0)|((c[b+144>>2]|0)!=0?8:0)|((c[b+148>>2]|0)!=0?16:0)|((c[b+172>>2]|0)!=0?32:0)|((c[b+176>>2]|0)!=0?64:0))+((c[b+180>>2]|0)!=0?-128:0)&255;break};case 176:{f=a[b+256|0]|0;if((c[b+144>>2]|0)!=0){e=f;break L5135}e=(f&255)>>>7<<6|f&15|(f&255)>>>6<<7|(f&255)>>>4<<5&32|(f&255)>>>5<<4&16;break};case 177:{e=a[b+257|0]|0;break};case 178:{f=c[(c[b+4>>2]|0)+262152>>2]|0;g=f+96|0;h=c[g>>2]|0;i=a[(c[f+28>>2]|0)+((c[f+116>>2]&h)+(c[f+100>>2]<<c[f+112>>2])&c[f+16>>2])|0]|0;if((c[f+108>>2]|0)!=0){e=i;break L5135}c[g>>2]=h+1&2047;e=i;break};case 179:{i=c[(c[b+4>>2]|0)+262152>>2]|0;h=i+96|0;g=c[h>>2]|0;f=a[(c[i+32>>2]|0)+((c[i+124>>2]&g)+(c[i+100>>2]<<c[i+120>>2])&c[i+20>>2])|0]|0;if((c[i+108>>2]|0)!=0){e=f;break L5135}c[h>>2]=g+1&2047;e=f;break};case 136:{e=1;break};case 4:{e=a[b+12|0]|0;break};case 19:{e=a[b+27|0]|0;break};case 14:{e=a[b+22|0]|0;break};case 24:{e=a[b+32|0]|0;break};default:{e=-1}}}while(0);return e|0}function ln(a){a=a|0;lo(a);if((a|0)==0){return}sS(a);return}function lo(a){a=a|0;var b=0;c[a>>2]=56712;b=c[a+262152>>2]|0;if((b|0)!=0){f$[c[(c[b>>2]|0)+4>>2]&511](b)}b=c[a+262156>>2]|0;if((b|0)!=0){f$[c[(c[b>>2]|0)+4>>2]&511](b)}b=c[a+262164>>2]|0;if((b|0)!=0){f$[c[(c[b>>2]|0)+4>>2]&511](b)}b=c[a+262168>>2]|0;if((b|0)!=0){sS(b)}b=c[a+262172>>2]|0;if((b|0)!=0){f$[c[(c[b>>2]|0)+4>>2]&511](b)}b=c[a+262176>>2]|0;if((b|0)!=0){f$[c[(c[b>>2]|0)+4>>2]&511](b)}b=c[a+262160>>2]|0;if((b|0)==0){return}f$[c[(c[b>>2]|0)+4>>2]&511](b);return}function lp(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=i;i=i+208|0;f=e|0;g=e+104|0;c[135448]=0;c[135456]=0;c[135462]=0;c[135464]=0;c[135454]=0;c[135444]=0;c[135442]=0;c[135452]=0;c[135446]=0;c[135440]=0;c[135438]=0;c[135436]=0;c[135468]=0;c[135466]=0;s_(541880,-128|0,5512);h=c[b+262160>>2]|0;f$[c[(c[h>>2]|0)+8>>2]&511](h);h=b+262152|0;j=c[h>>2]|0;f$[c[(c[j>>2]|0)+8>>2]&511](j);j=b+262156|0;k=c[j>>2]|0;f$[c[(c[k>>2]|0)+8>>2]&511](k);k=c[b+262164>>2]|0;f$[c[(c[k>>2]|0)+8>>2]&511](k);k=b+262172|0;l=c[k>>2]|0;f$[c[(c[l>>2]|0)+8>>2]&511](l);l=c[b+262176>>2]|0;f$[c[(c[l>>2]|0)+8>>2]&511](l);l=b+262168|0;m=c[l>>2]|0;n=m|0;o=c[n>>2]|0;c[m+64>>2]=f2[c[(c[o>>2]|0)+44>>2]&255](o)|0;c[m+4>>2]=0;c[m+8>>2]=0;c[m+12>>2]=0;c[m+16>>2]=255;c[m+20>>2]=0;c[m+24>>2]=0;o=c[n>>2]|0;c[m+28>>2]=(gj[c[(c[o>>2]|0)+24>>2]&127](o,65532)|0)&65535;s_(m+32|0,0,16);c[m+48>>2]=1;c[m+52>>2]=1;c[m+56>>2]=0;c[m+60>>2]=0;c[135442]=0;c[135444]=0;c[135452]=0;c[135450]=0;if((a[(c[j>>2]|0)+5|0]&1)==0){j=f|0;m=g|0;o=c[t>>2]|0;be(12056,23,1,o|0)|0;o=c[h>>2]|0;n=c[o+16>>2]|0;p=256-((gj[c[(c[o>>2]|0)+24>>2]&127](o,0)|0)&255)|0;o=p*51|0;do{if((p|0)==1){q=0;do{r=c[h>>2]|0;s=r+96|0;u=c[s>>2]|0;v=a[(c[r+28>>2]|0)+((c[r+116>>2]&u)+(c[r+100>>2]<<c[r+112>>2])&c[r+16>>2])|0]|0;if((c[r+108>>2]|0)==0){c[s>>2]=u+1&2047}a[f+q|0]=v;q=q+1|0;}while((q|0)<52);q=256-(d[j]|0)|0;v=0;u=0;s=m;r=f+1|0;while(1){w=sR(51)|0;do{if((w|0)!=0){if((c[w-4>>2]&3|0)==0){break}s_(w|0,0,51)}}while(0);x=sR(51)|0;do{if((x|0)!=0){if((c[x-4>>2]&3|0)==0){break}s_(x|0,0,51)}}while(0);y=sR(51)|0;do{if((y|0)==0){z=r;A=50}else{if((c[y-4>>2]&3|0)==0){z=r;A=50;break}s_(y|0,0,51);z=r;A=50}}while(0);while(1){a[x+A|0]=a[z]|0;if((A|0)>0){z=z+1|0;A=A-1|0}else{break}}ku(w,x,x);s1(y|0,w|0,51)|0;ku(w,x,y);B=s;C=50;D=u;while(1){E=(d[w+C|0]|0)+D|0;F=E&255;a[B]=E&255;E=C-1|0;if((E|0)>0){B=B+1|0;C=E;D=F}else{break}}sS(w);sS(x);sS(y);D=v+1|0;if((D|0)<(q|0)){v=D;u=F;s=s+50|0;r=r+51|0}else{break}}r=b;s=0;while(1){go[c[(c[r>>2]|0)+12>>2]&127](b,s+512|0,a[g+s|0]|0);u=s+1|0;if((u|0)<100){s=u}else{G=512;break}}}else{s=c[h>>2]|0;r=o+10+((256-((gj[c[(c[s>>2]|0)+24>>2]&127](s,o+1|0)|0)&255)|0)*51|0)|0;s=c[h>>2]|0;u=gj[c[(c[s>>2]|0)+24>>2]&127](s,r)|0;s=c[h>>2]|0;v=gj[c[(c[s>>2]|0)+24>>2]&127](s,r+1|0)|0;s=c[h>>2]|0;q=gj[c[(c[s>>2]|0)+24>>2]&127](s,r+2|0)|0;s=c[h>>2]|0;gj[c[(c[s>>2]|0)+24>>2]&127](s,r+3|0)|0;s=c[h>>2]|0;D=gj[c[(c[s>>2]|0)+24>>2]&127](s,r+4|0)|0;s=c[h>>2]|0;C=gj[c[(c[s>>2]|0)+24>>2]&127](s,r+5|0)|0;s=c[h>>2]|0;B=gj[c[(c[s>>2]|0)+24>>2]&127](s,r+6|0)|0;s=c[h>>2]|0;E=gj[c[(c[s>>2]|0)+24>>2]&127](s,r+7|0)|0;r=((q&255)<<8)+(ag(u&255,(n+1|0)>>>8)|0)+(v&255)|0;v=(C&255)<<8|D&255;D=(E&255)<<8|B&255;if((D|0)==0){G=v;break}B=b;E=0;while(1){C=c[(c[B>>2]|0)+12>>2]|0;u=c[h>>2]|0;q=gj[c[(c[u>>2]|0)+24>>2]&127](u,r+E|0)|0;go[C&127](b,E+v|0,q);q=E+1|0;if((q|0)<(D|0)){E=q}else{G=v;break}}}}while(0);h=c[l>>2]|0;n=h+32|0;o=(c[n>>2]|0)==0?32:-96;g=h+36|0;F=(c[g>>2]|0)==0?o:o|64;o=h+40|0;A=(c[o>>2]|0)==0?F:F|16;F=h+44|0;z=(c[F>>2]|0)==0?A:A|8;A=h+48|0;f=(c[A>>2]|0)==0?z:z|4;z=h+52|0;m=h+56|0;j=(((c[z>>2]|0)==0?f:f|2)|(c[m>>2]|0)!=0)&255;f=h+4|0;p=c[f>>2]|0;v=h+8|0;E=c[v>>2]|0;D=h+12|0;r=c[D>>2]|0;B=h+16|0;q=c[B>>2]|0;C=h+20|0;u=c[C>>2]|0;s=h+24|0;H=c[s>>2]|0;I=(c[135452]|0)!=0;J=(c[135442]|0)!=0;K=(c[135444]|0)!=0;c[n>>2]=j&128;c[g>>2]=j&64;c[o>>2]=j&16;c[F>>2]=j&8;c[A>>2]=j&4;c[z>>2]=j&2;c[m>>2]=j&1;c[f>>2]=p;c[v>>2]=E;c[D>>2]=r;c[B>>2]=q;c[C>>2]=u;c[s>>2]=H;c[h+28>>2]=G;c[135452]=I&1;c[135442]=J&1;c[135444]=K&1}if((c[b+262180>>2]|0)!=1){i=e;return}b=c[k>>2]|0;c[b+16500>>2]=158;c[b+16504>>2]=1;c[b+16508>>2]=1;c[b+16588>>2]=104;c[b+16592>>2]=1;c[b+16596>>2]=1;c[b+16600>>2]=7;c[b+16484>>2]=1;c[b+16488>>2]=0;c[b+16492>>2]=0;c[b+16496>>2]=1;b=c[l>>2]|0;l=b+32|0;k=(c[l>>2]|0)==0?32:-96;K=b+36|0;J=(c[K>>2]|0)==0?k:k|64;k=b+40|0;I=(c[k>>2]|0)==0?J:J|16;J=b+44|0;G=(c[J>>2]|0)==0?I:I|8;I=b+48|0;h=(c[I>>2]|0)==0?G:G|4;G=b+52|0;H=b+56|0;s=(((c[G>>2]|0)==0?h:h|2)|(c[H>>2]|0)!=0)&255;h=b+4|0;u=c[h>>2]|0;C=b+8|0;q=c[C>>2]|0;B=b+12|0;r=c[B>>2]|0;D=b+16|0;E=c[D>>2]|0;v=b+20|0;p=c[v>>2]|0;f=b+24|0;j=c[f>>2]|0;m=(c[135452]|0)!=0;z=(c[135442]|0)!=0;A=(c[135444]|0)!=0;F=c[135462]&65535;c[l>>2]=s&128;c[K>>2]=s&64;c[k>>2]=s&16;c[J>>2]=s&8;c[I>>2]=s&4;c[G>>2]=s&2;c[H>>2]=s&1;c[h>>2]=u;c[C>>2]=q;c[B>>2]=r;c[D>>2]=E;c[v>>2]=p;c[f>>2]=j;c[b+28>>2]=F;c[135452]=m&1;c[135442]=z&1;c[135444]=A&1;i=e;return}function lq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=dz(b|0,52080)|0;if((j|0)==0){k=0;i=e;return k|0}be(49616,4,1,j|0)|0;l=a+262152|0;c[g>>2]=c[(c[l>>2]|0)+128>>2];m=(be(g|0,4,1,j|0)|0)!=0;be(47360,20,1,j|0)|0;g=m&(be(a+4|0,4,1,j|0)|0)!=0;m=g&(be(541792,4,1,j|0)|0)!=0;g=m&(be(541824,4,1,j|0)|0)!=0;m=g&(be(541840,4,1,j|0)|0)!=0;g=m&(be(541848,4,1,j|0)|0)!=0;m=g&(be(541832,4,1,j|0)|0)!=0;g=m&(be(541856,4,1,j|0)|0)!=0;m=g&(be(541816,4,1,j|0)|0)!=0;g=m&(be(541776,4,1,j|0)|0)!=0;m=g&(be(541768,4,1,j|0)|0)!=0;g=m&(be(541808,4,1,j|0)|0)!=0;m=g&(be(541800,4,1,j|0)|0)!=0;g=m&(be(541784,4,1,j|0)|0)!=0;m=g&(be(8160,4,1,j|0)|0)!=0;g=m&(be(541760,4,1,j|0)|0)!=0;m=g&(be(541752,4,1,j|0)|0)!=0;c[h>>2]=c[135436];g=m&(be(h|0,4,1,j|0)|0)!=0;h=g&(be(541880,1,5512,j|0)|0)!=0;g=h&(be(541872,4,1,j|0)|0)!=0;h=g&(be(541864,4,1,j|0)|0)!=0;g=c[a+262160>>2]|0;m=(gj[c[(c[g>>2]|0)+16>>2]&127](g,j)|0)&h;h=c[l>>2]|0;l=(gj[c[(c[h>>2]|0)+16>>2]&127](h,j)|0)&m;m=c[a+262164>>2]|0;h=(gj[c[(c[m>>2]|0)+16>>2]&127](m,j)|0)&l;l=c[a+262172>>2]|0;m=(gj[c[(c[l>>2]|0)+16>>2]&127](l,j)|0)&h;h=c[a+262176>>2]|0;l=(gj[c[(c[h>>2]|0)+16>>2]&127](h,j)|0)&m;m=c[a+262168>>2]|0;a=f;h=(c[m+32>>2]|0)==0?32:-96;g=(c[m+36>>2]|0)==0?h:h|64;h=(c[m+40>>2]|0)==0?g:g|16;g=(c[m+44>>2]|0)==0?h:h|8;h=(c[m+48>>2]|0)==0?g:g|4;c[f>>2]=(((c[m+52>>2]|0)==0?h:h|2)|(c[m+56>>2]|0)!=0)&255;be(42112,18,1,j|0)|0;do{if((be(m+4|0,4,1,j|0)|0)==0){n=0}else{if((be(m+8|0,4,1,j|0)|0)==0){n=0;break}if((be(m+12|0,4,1,j|0)|0)==0){n=0;break}if((be(m+16|0,4,1,j|0)|0)==0){n=0;break}if((be(a|0,4,1,j|0)|0)==0){n=0;break}if((be(m+28|0,4,1,j|0)|0)==0){n=0;break}n=(be(m+60|0,4,1,j|0)|0)!=0}}while(0);a_(j|0)|0;if(!(n&l)){k=0;i=e;return k|0}l=dz(b|0,42504)|0;if((l|0)==0){k=0;i=e;return k|0}e3(l|0,0,2)|0;n=cx(l|0)|0;e3(l|0,0,0)|0;j=(d|0)==0;L5297:do{if(j){m=(n|0)==0?1:n;while(1){a=sR(m)|0;if((a|0)!=0){o=a;break L5297}a=(I=c[138018]|0,c[138018]=I+0,I);if((a|0)==0){break}gp[a&63]()}m=fc(4)|0;c[m>>2]=53880;dq(m|0,60400,240);return 0}else{o=d}}while(0);d=(eK(o|0,1,n|0,l|0)|0)==(n|0)?n:0;a_(l|0)|0;if(!((o|0)==0|j^1)){sS(o)}bP(b|0)|0;k=d;i=e;return k|0}function lr(){return 1}function ls(a){a=a|0;c[138006]=a;return}function lt(a){a=a|0;c[138014]=a;return}function lu(a){a=a|0;c[138016]=a;return}function lv(a){a=a|0;c[138012]=a;return}function lw(a){a=a|0;c[138004]=a;return}function lx(a,b){a=a|0;b=b|0;return}function ly(a){a=a|0;return(c[a+262164>>2]|0)+4|0}function lz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+112|0;e=d|0;f=d+8|0;s1(f|0,53608,100)|0;g=b+4|0;h=c[g>>2]|0;j=b+8|0;k=c[j>>2]|0;l=(h+18|0)>>>0>k>>>0?k-h|0:18;m=b|0;b=c[m>>2]|0;n=b+h|0;s1(f|0,n|0,l)|0;n=h+l|0;c[g>>2]=n;if((l|0)==0){o=0;i=d;return o|0}if((da(f|0,42112)|0)!=0){o=0;i=d;return o|0}f=a+4|0;l=(n+4|0)>>>0>k>>>0?k-n|0:4;k=b+n|0;s1(f|0,k|0,l)|0;k=(c[g>>2]|0)+l|0;c[g>>2]=k;if((l|0)==0){o=0;i=d;return o|0}l=a+8|0;f=c[j>>2]|0;n=(k+4|0)>>>0>f>>>0?f-k|0:4;f=(c[m>>2]|0)+k|0;s1(l|0,f|0,n)|0;f=(c[g>>2]|0)+n|0;c[g>>2]=f;if((n|0)==0){o=0;i=d;return o|0}n=a+12|0;l=c[j>>2]|0;k=(f+4|0)>>>0>l>>>0?l-f|0:4;l=(c[m>>2]|0)+f|0;s1(n|0,l|0,k)|0;l=(c[g>>2]|0)+k|0;c[g>>2]=l;if((k|0)==0){o=0;i=d;return o|0}k=a+16|0;n=c[j>>2]|0;f=(l+4|0)>>>0>n>>>0?n-l|0:4;n=(c[m>>2]|0)+l|0;s1(k|0,n|0,f)|0;n=(c[g>>2]|0)+f|0;c[g>>2]=n;if((f|0)==0){o=0;i=d;return o|0}f=c[j>>2]|0;k=(n+4|0)>>>0>f>>>0?f-n|0:4;l=c[m>>2]|0;b=l+n|0;h=e;s1(h|0,b|0,k)|0;b=n+k|0;c[g>>2]=b;if((k|0)==0){o=0;i=d;return o|0}k=a+28|0;n=(b+4|0)>>>0>f>>>0?f-b|0:4;f=l+b|0;s1(k|0,f|0,n)|0;f=(c[g>>2]|0)+n|0;c[g>>2]=f;if((n|0)==0){o=0;i=d;return o|0}n=a+60|0;k=c[j>>2]|0;j=(f+4|0)>>>0>k>>>0?k-f|0:4;k=(c[m>>2]|0)+f|0;s1(n|0,k|0,j)|0;c[g>>2]=(c[g>>2]|0)+j;if((j|0)==0){o=0;i=d;return o|0}j=c[e>>2]|0;c[a+32>>2]=j&128;c[a+36>>2]=j&64;c[a+40>>2]=j&16;c[a+44>>2]=j&8;c[a+48>>2]=j&4;c[a+52>>2]=j&2;c[a+56>>2]=j&1;o=1;i=d;return o|0}function lA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+8+(b<<2)>>2]|0;go[c[(c[e>>2]|0)+20>>2]&127](e,b,d);return}function lB(a,b){a=a|0;b=b|0;var d=0;d=c[a+8+(b<<2)>>2]|0;return gj[c[(c[d>>2]|0)+24>>2]&127](d,b)|0}function lC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+8+(b<<2)>>2]|0;go[c[(c[e>>2]|0)+20>>2]&127](e,b,d&255);e=b+1|0;b=c[a+8+(e<<2)>>2]|0;go[c[(c[b>>2]|0)+20>>2]&127](b,e,(d&65535)>>>8&255);return}function lD(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+8+(b<<2)|0;a=c[d>>2]|0;e=(gj[c[(c[a>>2]|0)+24>>2]&127](a,b)|0)&255;a=c[d>>2]|0;return((gj[c[(c[a>>2]|0)+24>>2]&127](a,b+1|0)|0)&255)<<8|e|0}function lE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+262164>>2]|0;go[c[(c[e>>2]|0)+20>>2]&127](e,b,d);return}function lF(a,b){a=a|0;b=b|0;var d=0;d=c[a+262164>>2]|0;return gj[c[(c[d>>2]|0)+24>>2]&127](d,b)|0}function lG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+262164|0;a=c[e>>2]|0;go[c[(c[a>>2]|0)+20>>2]&127](a,b,d&255);a=c[e>>2]|0;go[c[(c[a>>2]|0)+20>>2]&127](a,b+1|0,(d&65535)>>>8&255);return}function lH(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+262164|0;a=c[d>>2]|0;e=(gj[c[(c[a>>2]|0)+24>>2]&127](a,b)|0)&255;a=c[d>>2]|0;return((gj[c[(c[a>>2]|0)+24>>2]&127](a,b+1|0)|0)&255)<<8|e|0}function lI(){var a=0,b=0;a=i;i=i+8|0;b=a|0;c[138008]=62424;c[b>>2]=2;if(gj[c[170726]&127](10,b)|0){i=a;return}be(16960,23,1,c[t>>2]|0)|0;i=a;return}function lJ(){var a=0;a=c[138010]|0;if((a|0)==0){return}f$[c[(c[a>>2]|0)+8>>2]&511](a);return}function lK(){var b=0;b=c[138010]|0;if((b|0)==0){a[62504]=0;return}f$[c[(c[b>>2]|0)+8>>2]&511](b);b=c[138010]|0;a[62504]=0;if((b|0)==0){return}f$[c[(c[b>>2]|0)+4>>2]&511](b);return}function lL(a){a=a|0;gj[a&127](16,53856)|0;c[170726]=a;return}function lM(b){b=b|0;s_(b|0,0,16);c[b>>2]=26328;c[b+4>>2]=22608;a[b+12|0]=1;c[b+8>>2]=19608;a[b+13|0]=0;return}function lN(b){b=b|0;var d=0,e=0;d=a[62512]|0?102:160;e=a[62496]|0?160:102;c[b>>2]=d;c[b+4>>2]=e;c[b+8>>2]=d;c[b+12>>2]=e;g[b+16>>2]=0.0;e=b+24|0;c[e>>2]=c[13460];c[e+4>>2]=c[13461];c[e+8>>2]=c[13462];c[e+12>>2]=c[13463];return}function lO(){var b=0,d=0,e=0,f=0;gp[c[138016]&63]();b=c[138010]|0;d=0;e=0;do{if((gn[c[138012]&31](0,1,0,c[(c[138008]|0)+(e<<3)>>2]|0)|0)<<16>>16==0){f=0}else{f=c[(c[138008]|0)+(e<<3)+4>>2]|0}d=f|d;e=e+1|0;}while(e>>>0<9);e=c[b+262176>>2]|0;a[e+256|0]=d&255;a[e+257|0]=d>>>8&255;if(a[62216]|0){a[62216]=0;return}do{d=c[138010]|0;if((c[135448]|0)>>>0>=(c[135456]|0)>>>0){k_(c[d+262172>>2]|0)}me(c[d+262168>>2]|0);if((c[135452]|0)!=0){c[135448]=c[135456]}}while(!(a[62216]|0));a[62216]=0;return}function lP(){var a=0,b=0,d=0,e=0,f=0;a=i;i=i+1032|0;b=a|0;if((c[138010]|0)==0){d=0;i=a;return d|0}e=a+8|0;c[b>>2]=0;gj[c[170726]&127](9,b)|0;cA(e|0,48136,(f=i,i=i+16|0,c[f>>2]=c[b>>2],c[f+8>>2]=47,f)|0)|0;i=f;d=lq(c[138010]|0,e,0)|0;i=a;return d|0}function lQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;b=i;i=i+1032|0;d=b|0;if((c[138010]|0)==0){e=0;i=b;return e|0}f=b+8|0;c[d>>2]=0;gj[c[170726]&127](9,d)|0;cA(f|0,48136,(g=i,i=i+16|0,c[g>>2]=c[d>>2],c[g+8>>2]=47,g)|0)|0;i=g;e=(lq(c[138010]|0,f,a)|0)!=0;i=b;return e|0}function lR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;e=i;i=i+224|0;f=e|0;g=e+104|0;h=e+208|0;j=e+216|0;k=c[138010]|0;if((k|0)==0){l=0;i=e;return l|0}m=g|0;n=h;o=j;while(1){p=sR(12)|0;if((p|0)!=0){break}q=(I=c[138018]|0,c[138018]=I+0,I);if((q|0)==0){r=4086;break}gp[q&63]()}if((r|0)==4086){q=fc(4)|0;c[q>>2]=53880;dq(q|0,60400,240);return 0}q=p;s=p;c[s>>2]=b;u=p+4|0;v=p+8|0;c[v>>2]=d;w=d>>>0<4?d:4;s1(m|0,b|0,w)|0;c[u>>2]=w;x=(w|0)!=0;a[g+4|0]=0;do{if((da(m|0,49616)|0)==0){r=4091}else{if((da(m|0,19760)|0)==0){r=4091;break}y=c[t>>2]|0;be(44840,33,1,y|0)|0;z=x}}while(0);if((r|0)==4091){do{if((da(m|0,19760)|0)==0){A=1;B=w;C=k+262152|0}else{r=(w+4|0)>>>0>d>>>0?d-w|0:4;y=b+w|0;s1(n|0,y|0,r)|0;y=w+r|0;c[u>>2]=y;r=k+262152|0;if((c[(c[r>>2]|0)+128>>2]|0)==(c[h>>2]|0)){A=0;B=y;C=r;break}sS(p);r=c[t>>2]|0;be(45496,82,1,r|0)|0;l=0;i=e;return l|0}}while(0);h=(B+20|0)>>>0>d>>>0?d-B|0:20;w=b+B|0;s1(m|0,w|0,h)|0;w=B+h|0;c[u>>2]=w;a[g+20|0]=0;g=(da(m|0,47360)|0)==0&(x&(h|0)!=0);h=k+4|0;x=(w+4|0)>>>0>d>>>0?d-w|0:4;m=b+w|0;s1(h|0,m|0,x)|0;m=w+x|0;w=g&(x|0)!=0;x=(m+4|0)>>>0>d>>>0?d-m|0:4;g=b+m|0;s1(541792,g|0,x)|0;g=m+x|0;m=w&(x|0)!=0;x=(g+4|0)>>>0>d>>>0?d-g|0:4;w=b+g|0;s1(541824,w|0,x)|0;w=g+x|0;g=m&(x|0)!=0;x=(w+4|0)>>>0>d>>>0?d-w|0:4;m=b+w|0;s1(541840,m|0,x)|0;m=w+x|0;w=g&(x|0)!=0;x=(m+4|0)>>>0>d>>>0?d-m|0:4;g=b+m|0;s1(541848,g|0,x)|0;g=m+x|0;m=w&(x|0)!=0;x=(g+4|0)>>>0>d>>>0?d-g|0:4;w=b+g|0;s1(541832,w|0,x)|0;w=g+x|0;g=m&(x|0)!=0;x=(w+4|0)>>>0>d>>>0?d-w|0:4;m=b+w|0;s1(541856,m|0,x)|0;m=w+x|0;w=g&(x|0)!=0;x=(m+4|0)>>>0>d>>>0?d-m|0:4;g=b+m|0;s1(541816,g|0,x)|0;g=m+x|0;m=w&(x|0)!=0;x=(g+4|0)>>>0>d>>>0?d-g|0:4;w=b+g|0;s1(541776,w|0,x)|0;w=g+x|0;g=m&(x|0)!=0;x=(w+4|0)>>>0>d>>>0?d-w|0:4;m=b+w|0;s1(541768,m|0,x)|0;m=w+x|0;w=g&(x|0)!=0;x=(m+4|0)>>>0>d>>>0?d-m|0:4;g=b+m|0;s1(541808,g|0,x)|0;g=m+x|0;m=w&(x|0)!=0;x=(g+4|0)>>>0>d>>>0?d-g|0:4;w=b+g|0;s1(541800,w|0,x)|0;w=g+x|0;g=m&(x|0)!=0;x=(w+4|0)>>>0>d>>>0?d-w|0:4;m=b+w|0;s1(541784,m|0,x)|0;m=w+x|0;w=g&(x|0)!=0;x=(m+4|0)>>>0>d>>>0?d-m|0:4;g=b+m|0;s1(8160,g|0,x)|0;g=m+x|0;m=w&(x|0)!=0;x=(g+4|0)>>>0>d>>>0?d-g|0:4;w=b+g|0;s1(541760,w|0,x)|0;w=g+x|0;g=m&(x|0)!=0;x=(w+4|0)>>>0>d>>>0?d-w|0:4;m=b+w|0;s1(541752,m|0,x)|0;m=w+x|0;w=g&(x|0)!=0;x=(m+4|0)>>>0>d>>>0?d-m|0:4;d=b+m|0;s1(o|0,d|0,x)|0;c[u>>2]=m+x;m=w&(x|0)!=0;c[135436]=c[j>>2];j=c[u>>2]|0;x=c[v>>2]|0;w=(j+5512|0)>>>0>x>>>0?x-j|0:5512;d=c[s>>2]|0;o=d+j|0;s1(541880,o|0,w)|0;o=j+w|0;c[u>>2]=o;j=m&(w|0)!=0;w=(o+4|0)>>>0>x>>>0?x-o|0:4;m=d+o|0;s1(541872,m|0,w)|0;m=o+w|0;c[u>>2]=m;o=j&(w|0)!=0;w=(m+4|0)>>>0>x>>>0?x-m|0:4;x=d+m|0;s1(541864,x|0,w)|0;c[u>>2]=m+w;m=(kS(c[k+262160>>2]|0,q)|0)&(o&(w|0)!=0);w=c[C>>2]|0;if(A){A=(kL(w,q)|0)&m;C=c[k+262156>>2]|0;o=f|0;s1(o|0,53736,100)|0;x=c[u>>2]|0;d=c[v>>2]|0;j=(x+17|0)>>>0>d>>>0?d-x|0:17;b=c[s>>2]|0;g=b+x|0;s1(o|0,g|0,j)|0;g=j+x|0;c[u>>2]=g;do{if((j|0)==0){D=0;E=g}else{if((da(o|0,28584)|0)!=0){D=0;E=g;break}x=C+6|0;h=(g+512|0)>>>0>d>>>0?d-g|0:512;B=b+g|0;s1(x|0,B|0,h)|0;B=(c[u>>2]|0)+h|0;c[u>>2]=B;D=(h|0)!=0;E=B}}while(0);F=D&A;G=E;H=o}else{o=(kK(w,q)|0)&m;F=o;G=c[u>>2]|0;H=f|0}f=c[k+262164>>2]|0;s1(H|0,53736,100)|0;o=c[v>>2]|0;v=(G+17|0)>>>0>o>>>0?o-G|0:17;m=c[s>>2]|0;s=m+G|0;s1(H|0,s|0,v)|0;s=v+G|0;c[u>>2]=s;do{if((v|0)==0){J=0}else{if((da(H|0,48920)|0)!=0){J=0;break}G=f+4|0;w=(s+65536|0)>>>0>o>>>0?o-s|0:65536;E=m+s|0;s1(G|0,E|0,w)|0;c[u>>2]=(c[u>>2]|0)+w;if((w|0)==0){J=0;break}c[f+65544>>2]=0;J=1}}while(0);f=(kX(c[k+262172>>2]|0,q)|0)&(J&F);F=(li(c[k+262176>>2]|0,q)|0)&f;z=(lz(c[k+262168>>2]|0,q)|0)&F}sS(p);l=z;i=e;return l|0}function lS(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0;f=i;i=i+2024|0;g=f|0;h=f+104|0;j=f+208|0;k=f+216|0;l=f+224|0;m=f+240|0;n=f+248|0;o=f+504|0;p=f+760|0;q=f+776|0;r=f+792|0;s=f+800|0;u=f+992|0;v=f+2016|0;w=c[e>>2]|0;e=u|0;x=v;y=v;z=c[138010]|0;if((z|0)!=0){f$[c[(c[z>>2]|0)+4>>2]&511](z)}z=s;c[r>>2]=0;gj[c[170726]&127](9,r)|0;cA(e|0,17584,(A=i,i=i+24|0,c[A>>2]=c[r>>2],c[A+8>>2]=47,c[A+16>>2]=15296,A)|0)|0;i=A;r=s|0;B=s+8|0;C=s;c[r>>2]=62132;D=s+108|0;c[D>>2]=62152;c[s+4>>2]=0;c[s+132>>2]=B;c[s+124>>2]=0;c[s+128>>2]=0;c[s+112>>2]=4098;c[s+120>>2]=0;c[s+116>>2]=6;E=s+140|0;s_(E|0,0,40);F=s+136|0;G=c[(q$()|0)>>2]|0;c[F>>2]=G;H=G+4|0;I=c[H>>2]|0,c[H>>2]=I+1,I;c[s+180>>2]=0;c[s+184>>2]=-1;c[r>>2]=55780;c[s+108>>2]=55800;H=B|0;c[H>>2]=55704;G=s+12|0;J=c[(q$()|0)>>2]|0;c[G>>2]=J;K=J+4|0;I=c[K>>2]|0,c[K>>2]=I+1,I;s_(s+16|0,0,24);c[H>>2]=56016;c[s+40>>2]=0;c[s+44>>2]=0;c[s+48>>2]=0;H=s+76|0;K=s+106|0;s_(s+60|0,0,47);J=c[G>>2]|0;L=J+4|0;I=c[L>>2]|0,c[L>>2]=I+1,I;if((c[137806]|0)!=-1){c[q>>2]=551224;c[q+4>>2]=16;c[q+8>>2]=0;mU(551224,q)}q=(c[137807]|0)-1|0;M=c[J+8>>2]|0;if((c[J+12>>2]|0)-M>>2>>>0>q>>>0){N=(c[M+(q<<2)>>2]|0)!=0}else{N=0}if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f$[c[(c[J>>2]|0)+8>>2]&511](J|0)}L5458:do{if(N){J=c[G>>2]|0;L=J+4|0;I=c[L>>2]|0,c[L>>2]=I+1,I;if((c[137806]|0)!=-1){c[p>>2]=551224;c[p+4>>2]=16;c[p+8>>2]=0;mU(551224,p)}q=(c[137807]|0)-1|0;M=c[J+8>>2]|0;do{if((c[J+12>>2]|0)-M>>2>>>0>q>>>0){O=c[M+(q<<2)>>2]|0;if((O|0)==0){break}c[H>>2]=O;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f$[c[(c[J>>2]|0)+8>>2]&511](J|0)}O=c[H>>2]|0;a[K]=(f2[c[(c[O>>2]|0)+28>>2]&255](O)|0)&1;break L5458}}while(0);J=fc(4)|0;c[J>>2]=53912;dq(J|0,60416,316);return 0}}while(0);f7[c[(c[B>>2]|0)+12>>2]&127](B,0,4096)|0;K=s+72|0;do{if((c[K>>2]|0)==0){H=dz(e|0,11144)|0;c[K>>2]=H;if((H|0)==0){P=4144;break}c[s+96>>2]=8}else{P=4144}}while(0);if((P|0)==4144){K=c[(c[C>>2]|0)-12>>2]|0;ns(z+K|0,c[z+(K+16)>>2]|4)}if((c[z+((c[(c[C>>2]|0)-12>>2]|0)+16)>>2]&5|0)!=0){C=c[t>>2]|0;eQ(C|0,13104,(A=i,i=i+8|0,c[A>>2]=e,A)|0)|0;i=A}c[r>>2]=55780;c[D>>2]=55800;l3(B);B=s+108|0;c[B>>2]=54632;D=c[s+148>>2]|0;r=s+144|0;if((D|0)!=0){A=D;do{A=A-1|0;go[c[(c[E>>2]|0)+(A<<2)>>2]&127](0,B,c[(c[r>>2]|0)+(A<<2)>>2]|0);}while((A|0)!=0)}A=c[F>>2]|0;F=A+4|0;if(((I=c[F>>2]|0,c[F>>2]=I+ -1,I)|0)==0){f$[c[(c[A>>2]|0)+8>>2]&511](A)}sS(c[E>>2]|0);sS(c[r>>2]|0);sS(c[s+156>>2]|0);sS(c[s+168>>2]|0);while(1){Q=sR(262184)|0;if((Q|0)!=0){break}s=(I=c[138018]|0,c[138018]=I+0,I);if((s|0)==0){P=4178;break}gp[s&63]()}if((P|0)==4178){s=fc(4)|0;c[s>>2]=53880;dq(s|0,60400,240);return 0}s=Q;r=l|0;E=m|0;A=n|0;F=o|0;B=Q;c[Q>>2]=56712;D=Q+262152|0;C=D;z=Q+262156|0;K=Q+262160|0;H=Q+262164|0;p=Q+262168|0;G=Q+262172|0;N=Q+262176|0;J=Q+262180|0;s_(D|0,0,32);do{if((a[w]|0)==0){R=0;S=0;T=1}else{D=dz(w|0,42504)|0;if((D|0)==0){L=c[t>>2]|0;be(31464,14,1,L|0)|0}e3(D|0,0,2)|0;L=cx(D|0)|0;e3(D|0,0,0)|0;q=(L|0)==0;M=q?1:L;while(1){U=sR(M)|0;if((U|0)!=0){break}O=(I=c[138018]|0,c[138018]=I+0,I);if((O|0)==0){P=4195;break}gp[O&63]()}if((P|0)==4195){M=fc(4)|0;c[M>>2]=53880;dq(M|0,60400,240);return 0}if((eK(U|0,1,L|0,D|0)|0)!=(L|0)){M=c[t>>2]|0;be(31464,14,1,M|0)|0;sS(U)}a_(D|0)|0;if(q){R=0;S=U;T=1;break}s1(r|0,U|0,10)|0;a[l+4|0]=0;a[l+10|0]=0;if((da(l+6|0,26776)|0)==0){c[J>>2]=1;R=L;S=U;T=0;break}if((da(r|0,22864)|0)==0){c[J>>2]=0;R=L;S=U;T=0;break}if((da(r|0,19760)|0)==0){c[J>>2]=2;R=L;S=U;T=0;break}else{M=c[t>>2]|0;be(31464,14,1,M|0)|0;sS(U);R=L;S=U;T=0;break}}}while(0);U=Q+4|0;c[U>>2]=-1;while(1){V=sR(1544)|0;if((V|0)!=0){break}r=(I=c[138018]|0,c[138018]=I+0,I);if((r|0)==0){P=4220;break}gp[r&63]()}if((P|0)==4220){r=fc(4)|0;c[r>>2]=53880;dq(r|0,60400,240);return 0}r=V;c[V>>2]=57032;a[V+4|0]=0;l=V+5|0;a[l]=0;M=V+518|0;s7(M|0,e|0,1024)|0;f$[c[(c[V>>2]|0)+8>>2]&511](r);O=V+6|0;s_(O|0,-120|0,512);V=dz(M|0,42504)|0;L5535:do{if((V|0)==0){M=c[t>>2]|0;be(48576,13,1,M|0)|0}else{if((eK(O|0,1,512,V|0)|0)!=512){M=c[t>>2]|0;be(48576,13,1,M|0)|0;a_(V|0)|0;break}a_(V|0)|0;L5541:do{if(!(a[53728]|0)){a[53728]=1;M=0;while(1){if(M>>>0>=16){break L5541}if((a[53712+M|0]|0)==(a[r+6+M|0]|0)){M=M+1|0}else{break}}ah(8);gj[W&127](0,35936)|0;break L5535}}while(0);a[l]=1}}while(0);c[z>>2]=r;r=c[J>>2]|0;do{if((r|0)==1){while(1){X=sR(132)|0;if((X|0)!=0){break}l=(I=c[138018]|0,c[138018]=I+0,I);if((l|0)==0){P=4339;break}gp[l&63]()}if((P|0)==4339){l=fc(4)|0;c[l>>2]=53880;dq(l|0,60400,240);return 0}l=X;kz(l,0,0);c[C>>2]=l;while(1){Y=sR(65548)|0;if((Y|0)!=0){break}l=(I=c[138018]|0,c[138018]=I+0,I);if((l|0)==0){P=4351;break}gp[l&63]()}if((P|0)==4351){l=fc(4)|0;c[l>>2]=53880;dq(l|0,60400,240);return 0}l=Y;c[Y>>2]=57096;W=Y+65544|0;c[W>>2]=R;do{if((R|0)!=0){while(1){Z=sR(R)|0;if((Z|0)!=0){break}V=(I=c[138018]|0,c[138018]=I+0,I);if((V|0)==0){P=4362;break}gp[V&63]()}if((P|0)==4362){V=fc(4)|0;c[V>>2]=53880;dq(V|0,60400,240);return 0}c[Y+65540>>2]=Z;V=c[W>>2]|0;s1(Z|0,S|0,V)|0;if((a[Z+6|0]|0)==66){if((a[Z+7|0]|0)==83&(a[Z+8|0]|0)==57&(a[Z+9|0]|0)==51){break}}be(45912,14,1,c[t>>2]|0)|0}}while(0);f$[c[(c[Y>>2]|0)+8>>2]&511](l);c[H>>2]=l;_=0;$=0}else if((r|0)==0){while(1){aa=sR(132)|0;if((aa|0)!=0){break}W=(I=c[138018]|0,c[138018]=I+0,I);if((W|0)==0){P=4245;break}gp[W&63]()}if((P|0)==4245){l=fc(4)|0;c[l>>2]=53880;dq(l|0,60400,240);return 0}l=aa;kz(l,S,R);c[C>>2]=l;if((c[aa+92>>2]|0)==0){while(1){ab=sR(65548)|0;if((ab|0)!=0){P=4330;break}l=(I=c[138018]|0,c[138018]=I+0,I);if((l|0)==0){break}gp[l&63]()}if((P|0)==4330){c[ab>>2]=57096;c[ab+65544>>2]=0;s_(ab+4|0,-1|0,65536);c[H>>2]=ab;_=0;$=0;break}l=fc(4)|0;c[l>>2]=53880;dq(l|0,60400,240);return 0}c[J>>2]=1;l=a[e]|0;do{if(l<<24>>24==0){P=4252}else{if((a[u+1|0]|0)!=58){P=4252;break}a[E]=l;a[m+1|0]=58;a[m+2|0]=0;ac=u+2|0}}while(0);if((P|0)==4252){a[E]=0;ac=e}l=ac;W=ac;while(1){V=a[W]|0;if((V<<24>>24|0)==58|(V<<24>>24|0)==0){ad=W;break}W=W+1|0}while(1){if(ad>>>0<=ac>>>0){ae=W;break}af=ad-1|0;V=a[af]|0;if((V<<24>>24|0)==46){P=4258;break}else if((V<<24>>24|0)==92|(V<<24>>24|0)==47){ae=W;break}else{ad=af}}if((P|0)==4258){ae=af}while(1){if(ae>>>0<=ac>>>0){ag=A;break}W=ae-1|0;V=a[W]|0;if((V<<24>>24|0)==92|(V<<24>>24|0)==47){P=4261;break}else{ae=W}}if((P|0)==4261){W=ac+1|0;V=ae>>>0>W>>>0?ae:W;W=A;O=ac;while(1){L=O+1|0;a[W]=a[O]|0;if(L>>>0>=ae>>>0){break}W=W+1|0;O=L}ag=n+(V-l)|0}a[ag]=0;s8(F|0,E|0)|0;s9(F|0,A|0)|0;O=o+(sZ(F|0)|0)|0;s1(O|0,17824,9)|0;O=dz(F|0,42504)|0;do{if((O|0)==0){W=c[t>>2]|0;be(31464,14,1,W|0)|0;if((S|0)==0){break}sS(S)}}while(0);e3(O|0,0,2)|0;l=cx(O|0)|0;e3(O|0,0,0)|0;V=(R|0)==0?1:R;while(1){ai=sR(V)|0;if((ai|0)!=0){break}W=(I=c[138018]|0,c[138018]=I+0,I);if((W|0)==0){P=4278;break}gp[W&63]()}if((P|0)==4278){V=fc(4)|0;c[V>>2]=53880;dq(V|0,60400,240);return 0}do{if((eK(ai|0,1,l|0,O|0)|0)!=(l|0)){sS(ai);V=c[t>>2]|0;be(31464,14,1,V|0)|0;if((S|0)==0){break}sS(S)}}while(0);a_(O|0)|0;while(1){aj=sR(65548)|0;if((aj|0)!=0){break}V=(I=c[138018]|0,c[138018]=I+0,I);if((V|0)==0){P=4296;break}gp[V&63]()}if((P|0)==4296){O=fc(4)|0;c[O>>2]=53880;dq(O|0,60400,240);return 0}O=aj;c[aj>>2]=57096;V=aj+65544|0;c[V>>2]=l;do{if((l|0)!=0){while(1){ak=sR(l)|0;if((ak|0)!=0){break}W=(I=c[138018]|0,c[138018]=I+0,I);if((W|0)==0){P=4307;break}gp[W&63]()}if((P|0)==4307){W=fc(4)|0;c[W>>2]=53880;dq(W|0,60400,240);return 0}c[aj+65540>>2]=ak;W=c[V>>2]|0;s1(ak|0,ai|0,W)|0;if((a[ak+6|0]|0)==66){if((a[ak+7|0]|0)==83&(a[ak+8|0]|0)==57&(a[ak+9|0]|0)==51){break}}be(45912,14,1,c[t>>2]|0)|0}}while(0);f$[c[(c[aj>>2]|0)+8>>2]&511](O);c[H>>2]=O;_=ai;$=l}else{while(1){al=sR(132)|0;if((al|0)!=0){break}V=(I=c[138018]|0,c[138018]=I+0,I);if((V|0)==0){P=4384;break}gp[V&63]()}if((P|0)==4384){l=fc(4)|0;c[l>>2]=53880;dq(l|0,60400,240);return 0}l=al;kz(l,0,0);c[C>>2]=l;while(1){am=sR(65548)|0;if((am|0)!=0){P=4398;break}l=(I=c[138018]|0,c[138018]=I+0,I);if((l|0)==0){break}gp[l&63]()}if((P|0)==4398){c[am>>2]=57096;c[am+65544>>2]=0;s_(am+4|0,-1|0,65536);c[H>>2]=am;_=0;$=0;break}l=fc(4)|0;c[l>>2]=53880;dq(l|0,60400,240);return 0}}while(0);while(1){an=sR(17324)|0;if((an|0)!=0){break}am=(I=c[138018]|0,c[138018]=I+0,I);if((am|0)==0){P=4409;break}gp[am&63]()}if((P|0)==4409){am=fc(4)|0;c[am>>2]=53880;dq(am|0,60400,240);return 0}c[an>>2]=56904;c[an+4>>2]=s;c[an+17280>>2]=0;c[an+17284>>2]=0;am=an+17288|0;c[am>>2]=0;c[an+17304>>2]=0;c[an+17308>>2]=1;c[an+17316>>2]=0;c[an+17320>>2]=0;c[an+17120>>2]=0;c[an+17124>>2]=0;al=an+24|0;c[al>>2]=0;ai=an+28|0;c[ai>>2]=1;aj=an+32|0;c[aj>>2]=2;ak=an+36|0;c[ak>>2]=3;R=an+40|0;c[R>>2]=4;F=an+44|0;c[F>>2]=5;o=an+48|0;c[o>>2]=6;A=an+52|0;c[A>>2]=7;E=an+56|0;c[E>>2]=8;ag=an+60|0;c[ag>>2]=9;n=an+64|0;c[n>>2]=10;ae=an+68|0;c[ae>>2]=11;ac=an+72|0;c[ac>>2]=12;af=an+76|0;c[af>>2]=13;ad=an+80|0;c[ad>>2]=14;e=an+84|0;c[e>>2]=15;s_(an+88|0,0,16384);c[an+17292>>2]=0;c[an+17296>>2]=0;c[an+17300>>2]=0;s_(an+8|0,0,16);u=Q;c[am>>2]=f2[c[(c[u>>2]|0)+44>>2]&255](s)|0;c[an+17068>>2]=0;c[an+17072>>2]=0;s_(an+16500|0,0,398);s_(an+16900|0,0,54);s_(an+16956|0,0,54);s_(an+17012|0,0,54);c[an+17076>>2]=255;c[al>>2]=0;c[ai>>2]=1;c[aj>>2]=2;c[ak>>2]=3;c[R>>2]=4;c[F>>2]=5;c[o>>2]=6;c[A>>2]=7;c[E>>2]=8;c[ag>>2]=9;c[n>>2]=10;c[ae>>2]=11;c[ac>>2]=12;c[af>>2]=13;c[ad>>2]=14;c[e>>2]=15;c[an+17080>>2]=0;c[an+17084>>2]=0;s_(an+16472|0,0,28);c[an+17092>>2]=-2147483648;c[an+17088>>2]=-2147483648;s_(an+17096|0,0,24);s_(an+17260|0,0,20);c[G>>2]=an;while(1){ao=sR(260)|0;if((ao|0)!=0){break}an=(I=c[138018]|0,c[138018]=I+0,I);if((an|0)==0){P=4421;break}gp[an&63]()}if((P|0)==4421){an=fc(4)|0;c[an>>2]=53880;dq(an|0,60400,240);return 0}c[ao>>2]=56840;c[ao+4>>2]=s;c[ao+244>>2]=f2[c[(c[u>>2]|0)+44>>2]&255](s)|0;s_(ao+8|0,0,42);b[ao+50>>1]=127;b[ao+52>>1]=127;b[ao+54>>1]=0;b[ao+56>>1]=0;c[ao+60>>2]=-1;c[ao+64>>2]=-1;c[ao+68>>2]=-1;c[ao+72>>2]=65535;c[ao+76>>2]=1;c[ao+80>>2]=1;c[ao+84>>2]=1;c[ao+192>>2]=0;c[ao+196>>2]=0;a[ao+200|0]=0;s_(ao+88|0,0,101);a[ao+201|0]=1;a[ao+202|0]=2;a[ao+203|0]=3;a[ao+204|0]=4;a[ao+205|0]=5;a[ao+206|0]=6;a[ao+207|0]=7;a[ao+208|0]=8;a[ao+209|0]=9;a[ao+210|0]=10;a[ao+211|0]=11;a[ao+212|0]=12;a[ao+213|0]=13;a[ao+214|0]=14;a[ao+215|0]=15;a[ao+256|0]=0;a[ao+257|0]=0;c[N>>2]=ao;while(1){ap=sR(24)|0;if((ap|0)!=0){break}ao=(I=c[138018]|0,c[138018]=I+0,I);if((ao|0)==0){P=4433;break}gp[ao&63]()}if((P|0)==4433){ao=fc(4)|0;c[ao>>2]=53880;dq(ao|0,60400,240);return 0}c[ap>>2]=56776;ao=ap+20|0;c[ao>>2]=s;u=0;an=s;e=c[H>>2]|0;do{c[an+8+(u<<2)>>2]=e;u=u+1|0;an=c[ao>>2]|0;e=c[an+262164>>2]|0}while((u|0)<65536);u=ap;c[an+262120>>2]=e;e=c[ao>>2]|0;c[e+262124>>2]=c[e+262160>>2];s_(ap+4|0,-1|0,16);go[c[(c[ap>>2]|0)+20>>2]&127](u,0,0);c[K>>2]=u;while(1){aq=sR(2116)|0;if((aq|0)!=0){break}u=(I=c[138018]|0,c[138018]=I+0,I);if((u|0)==0){P=4447;break}gp[u&63]()}if((P|0)==4447){u=fc(4)|0;c[u>>2]=53880;dq(u|0,60400,240);return 0}u=aq;ap=aq;c[ap>>2]=B;B=0;e=0;while(1){c[u+68+(e<<2)>>2]=((e>>>4)*10|0)+(e&15);c[u+1092+(e<<2)>>2]=(((((B&65535)%100|0)&65535)/10|0)&65535)<<4|((B&65535)%10|0)&65535;ao=B+1&65535;if((ao&65535)<256){B=ao;e=ao&65535}else{break}}e=c[ap>>2]|0;c[aq+64>>2]=f2[c[(c[e>>2]|0)+44>>2]&255](e)|0;c[aq+4>>2]=0;c[aq+8>>2]=0;c[aq+12>>2]=0;c[aq+16>>2]=255;c[aq+20>>2]=0;c[aq+24>>2]=0;e=c[ap>>2]|0;c[aq+28>>2]=(gj[c[(c[e>>2]|0)+24>>2]&127](e,65532)|0)&65535;s_(aq+32|0,0,16);c[aq+48>>2]=1;c[aq+52>>2]=1;c[aq+56>>2]=0;c[aq+60>>2]=0;c[135442]=0;c[135444]=0;c[135452]=0;c[135450]=0;c[p>>2]=u;u=Q;f$[c[(c[u>>2]|0)+8>>2]&511](s);do{if((c[J>>2]|0)==2){Q=h|0;aq=j;e=k;ap=dz(w|0,42504)|0;e3(ap|0,0,2)|0;B=cx(ap|0)|0;e3(ap|0,0,0)|0;ao=(B|0)==0?1:B;while(1){ar=sR(ao)|0;if((ar|0)!=0){break}an=(I=c[138018]|0,c[138018]=I+0,I);if((an|0)==0){P=4464;break}gp[an&63]()}if((P|0)==4464){ao=fc(4)|0;c[ao>>2]=53880;dq(ao|0,60400,240);return 0}ao=(eK(ar|0,1,B|0,ap|0)|0)==(B|0);a_(ap|0)|0;if(!ao){break}ao=(ap|0)!=0;while(1){as=sR(12)|0;if((as|0)!=0){break}an=(I=c[138018]|0,c[138018]=I+0,I);if((an|0)==0){P=4480;break}gp[an&63]()}if((P|0)==4480){ap=fc(4)|0;c[ap>>2]=53880;dq(ap|0,60400,240);return 0}ap=as;an=as;c[an>>2]=ar;ad=as+4|0;af=as+8|0;c[af>>2]=B;ac=B>>>0<4?B:4;s1(Q|0,ar|0,ac)|0;c[ad>>2]=ac;ae=ao&(ac|0)!=0;a[h+4|0]=0;do{if((da(Q|0,49616)|0)==0){P=4484}else{if((da(Q|0,19760)|0)==0){P=4484;break}ah(8);gj[at&127](0,42704)|0;au=ae;P=4502}}while(0);L5746:do{if((P|0)==4484){do{if((da(Q|0,19760)|0)==0){av=1;aw=ac}else{ao=(ac+4|0)>>>0>B>>>0?B-ac|0:4;n=ar+ac|0;s1(aq|0,n|0,ao)|0;n=ac+ao|0;c[ad>>2]=n;if((c[(c[C>>2]|0)+128>>2]|0)==(c[j>>2]|0)){av=0;aw=n;break}sS(as);sS(ar);n=c[t>>2]|0;be(45496,82,1,n|0)|0;break L5746}}while(0);n=(aw+20|0)>>>0>B>>>0?B-aw|0:20;ao=ar+aw|0;s1(Q|0,ao|0,n)|0;ao=aw+n|0;c[ad>>2]=ao;a[h+20|0]=0;ag=da(Q|0,47360)|0;E=(ao+4|0)>>>0>B>>>0?B-ao|0:4;A=ar+ao|0;s1(U|0,A|0,E)|0;A=ao+E|0;ao=(A+4|0)>>>0>B>>>0?B-A|0:4;o=ar+A|0;s1(541792,o|0,ao)|0;o=A+ao|0;A=(o+4|0)>>>0>B>>>0?B-o|0:4;F=ar+o|0;s1(541824,F|0,A)|0;F=o+A|0;o=(F+4|0)>>>0>B>>>0?B-F|0:4;R=ar+F|0;s1(541840,R|0,o)|0;R=F+o|0;F=(R+4|0)>>>0>B>>>0?B-R|0:4;ak=ar+R|0;s1(541848,ak|0,F)|0;ak=R+F|0;R=(ak+4|0)>>>0>B>>>0?B-ak|0:4;aj=ar+ak|0;s1(541832,aj|0,R)|0;aj=ak+R|0;ak=(aj+4|0)>>>0>B>>>0?B-aj|0:4;ai=ar+aj|0;s1(541856,ai|0,ak)|0;ai=aj+ak|0;aj=(ai+4|0)>>>0>B>>>0?B-ai|0:4;al=ar+ai|0;s1(541816,al|0,aj)|0;al=ai+aj|0;ai=(al+4|0)>>>0>B>>>0?B-al|0:4;am=ar+al|0;s1(541776,am|0,ai)|0;am=al+ai|0;al=(am+4|0)>>>0>B>>>0?B-am|0:4;m=ar+am|0;s1(541768,m|0,al)|0;m=am+al|0;am=(m+4|0)>>>0>B>>>0?B-m|0:4;ab=ar+m|0;s1(541808,ab|0,am)|0;ab=m+am|0;m=(ab+4|0)>>>0>B>>>0?B-ab|0:4;aa=ar+ab|0;s1(541800,aa|0,m)|0;aa=ab+m|0;ab=(aa+4|0)>>>0>B>>>0?B-aa|0:4;r=ar+aa|0;s1(541784,r|0,ab)|0;r=aa+ab|0;aa=(r+4|0)>>>0>B>>>0?B-r|0:4;Y=ar+r|0;s1(8160,Y|0,aa)|0;Y=r+aa|0;r=(Y+4|0)>>>0>B>>>0?B-Y|0:4;Z=ar+Y|0;s1(541760,Z|0,r)|0;Z=Y+r|0;Y=(Z+4|0)>>>0>B>>>0?B-Z|0:4;X=ar+Z|0;s1(541752,X|0,Y)|0;X=Z+Y|0;Z=(X+4|0)>>>0>B>>>0?B-X|0:4;l=ar+X|0;s1(e|0,l|0,Z)|0;c[ad>>2]=X+Z;c[135436]=c[k>>2];X=c[ad>>2]|0;l=c[af>>2]|0;O=(X+5512|0)>>>0>l>>>0?l-X|0:5512;V=c[an>>2]|0;W=V+X|0;s1(541880,W|0,O)|0;W=X+O|0;c[ad>>2]=W;X=(W+4|0)>>>0>l>>>0?l-W|0:4;L=V+W|0;s1(541872,L|0,X)|0;L=W+X|0;c[ad>>2]=L;W=(L+4|0)>>>0>l>>>0?l-L|0:4;l=V+L|0;s1(541864,l|0,W)|0;c[ad>>2]=L+W;L=(kS(c[K>>2]|0,ap)|0)&((ag|0)==0&(ae&(n|0)!=0)&(E|0)!=0&(ao|0)!=0&(A|0)!=0&(o|0)!=0&(F|0)!=0&(R|0)!=0&(ak|0)!=0&(aj|0)!=0&(ai|0)!=0&(al|0)!=0&(am|0)!=0&(m|0)!=0&(ab|0)!=0&(aa|0)!=0&(r|0)!=0&(Y|0)!=0&(Z|0)!=0&(O|0)!=0&(X|0)!=0&(W|0)!=0);W=c[C>>2]|0;if(av){X=(kL(W,ap)|0)&L;O=c[z>>2]|0;Z=g|0;s1(Z|0,53736,100)|0;Y=c[ad>>2]|0;r=c[af>>2]|0;aa=(Y+17|0)>>>0>r>>>0?r-Y|0:17;ab=c[an>>2]|0;m=ab+Y|0;s1(Z|0,m|0,aa)|0;m=aa+Y|0;c[ad>>2]=m;do{if((aa|0)==0){ax=0;ay=m}else{if((da(Z|0,28584)|0)!=0){ax=0;ay=m;break}Y=O+6|0;am=(m+512|0)>>>0>r>>>0?r-m|0:512;al=ab+m|0;s1(Y|0,al|0,am)|0;al=(c[ad>>2]|0)+am|0;c[ad>>2]=al;ax=(am|0)!=0;ay=al}}while(0);az=ax&X;aA=ay;aB=Z}else{m=(kK(W,ap)|0)&L;az=m;aA=c[ad>>2]|0;aB=g|0}m=c[H>>2]|0;s1(aB|0,53736,100)|0;ab=c[af>>2]|0;r=(aA+17|0)>>>0>ab>>>0?ab-aA|0:17;O=c[an>>2]|0;aa=O+aA|0;s1(aB|0,aa|0,r)|0;aa=r+aA|0;c[ad>>2]=aa;do{if((r|0)==0){aC=0}else{if((da(aB|0,48920)|0)!=0){aC=0;break}al=m+4|0;am=(aa+65536|0)>>>0>ab>>>0?ab-aa|0:65536;Y=O+aa|0;s1(al|0,Y|0,am)|0;c[ad>>2]=(c[ad>>2]|0)+am;if((am|0)==0){aC=0;break}c[m+65544>>2]=0;aC=1}}while(0);m=(kX(c[G>>2]|0,ap)|0)&(aC&az);aa=(li(c[N>>2]|0,ap)|0)&m;au=(lz(c[p>>2]|0,ap)|0)&aa;P=4502}}while(0);if((P|0)==4502){sS(as);sS(ar);if(au){break}}f$[c[(c[u>>2]|0)+8>>2]&511](s);be(16456,18,1,c[t>>2]|0)|0}}while(0);if(!((S|0)==0|T)){sS(S)}if(!(($|0)==0|(_|0)==0)){sS(_)}c[138010]=s;a[62512]=0;a[62496]=0;c[138008]=62424;c[v>>2]=0;c[v+4>>2]=0;c[v>>2]=41304;do{if(gj[c[170726]&127](15,x)|0){v=c[y+4>>2]|0;if((v|0)==0){aD=1;break}if((da(v|0,11112)|0)==0){a[62512]=1;a[62496]=1;c[138008]=62352;aD=3;break}if((da(v|0,51112)|0)!=0){aD=1;break}a[62512]=1;a[62496]=1;c[138008]=62280;aD=2}else{aD=1}}while(0);y=c[(c[138010]|0)+262172>>2]|0;be(30304,25,1,c[t>>2]|0)|0;c[y+17304>>2]=aD;aD=y+17308|0;c[aD>>2]=2;c[y+17312>>2]=320;c[y+17316>>2]=52;c[y+17320>>2]=0;c[y+17284>>2]=0;if(a[62504]|0){gr[c[138004]&127](617624,a[62512]|0?102:160,a[62496]|0?160:102,320);x=c[135468]|0;if((x|0)!=0){if((x|0)>0){v=c[154404]|0;s=552080;_=0;while(1){$=d[v+_|0]<<8^-32768;b[s>>1]=$;b[s+2>>1]=$;$=_+1|0;if(($|0)<(x|0)){s=s+4|0;_=$}else{break}}}c[135468]=0;_=c[138014]|0;gj[_&127](552080,x)|0}a[62216]=1}c[y+17280>>2]=617624;be(25672,25,1,c[t>>2]|0)|0;switch(c[aD>>2]|0){case 0:{aD=0;x=0;_=0;s=0;while(1){c[y+88+(s<<2)>>2]=(aD&12)>>>2&3|_<<1&28|((x&255)>>>4&255)<<4&224;v=s+1|0;$=v>>>8;S=v&255;T=$<<8&65280|v&-65536|S;if(T>>>0<4096){aD=$&255;x=v&255;_=S;s=T}else{break}}aE=y+16516|0;c[aE>>2]=0;aF=y+16604|0;c[aF>>2]=0;aG=y+16512|0;aH=c[aG>>2]|0;aI=aH+4|0;aJ=y+16540|0;aK=c[aJ>>2]|0;aL=-1<<aI;aM=aK-1|0;aN=aM+aL|0;c[aJ>>2]=aN;aO=y+16600|0;aP=c[aO>>2]|0;aQ=aP+4|0;aR=y+16628|0;aS=c[aR>>2]|0;aT=-1<<aQ;aU=aS-1|0;aV=aU+aT|0;c[aR>>2]=aV;aW=c[135448]|0;c[135456]=aW;a[8168]=1;c[154404]=541880;a[62504]=1;i=f;return 1};case 1:{s=0;_=0;x=0;aD=0;while(1){c[y+88+(aD<<2)>>2]=x<<6&960|s<<1&30|((_&255)>>>4&255)<<11;T=aD+1|0;S=T>>>8&255;v=T&255;$=S<<8|T&-65536|v;if($>>>0<4096){s=S;_=T&255;x=v;aD=$}else{break}}aE=y+16516|0;c[aE>>2]=0;aF=y+16604|0;c[aF>>2]=0;aG=y+16512|0;aH=c[aG>>2]|0;aI=aH+4|0;aJ=y+16540|0;aK=c[aJ>>2]|0;aL=-1<<aI;aM=aK-1|0;aN=aM+aL|0;c[aJ>>2]=aN;aO=y+16600|0;aP=c[aO>>2]|0;aQ=aP+4|0;aR=y+16628|0;aS=c[aR>>2]|0;aT=-1<<aQ;aU=aS-1|0;aV=aU+aT|0;c[aR>>2]=aV;aW=c[135448]|0;c[135456]=aW;a[8168]=1;c[154404]=541880;a[62504]=1;i=f;return 1};case 2:{aD=0;x=0;_=0;s=0;while(1){c[y+88+(s<<2)>>2]=_<<7&1920|aD<<1&30|((x&255)>>>4&255)<<12;$=s+1|0;v=$>>>8&255;T=$&255;S=v<<8|$&-65536|T;if(S>>>0<4096){aD=v;x=$&255;_=T;s=S}else{break}}aE=y+16516|0;c[aE>>2]=0;aF=y+16604|0;c[aF>>2]=0;aG=y+16512|0;aH=c[aG>>2]|0;aI=aH+4|0;aJ=y+16540|0;aK=c[aJ>>2]|0;aL=-1<<aI;aM=aK-1|0;aN=aM+aL|0;c[aJ>>2]=aN;aO=y+16600|0;aP=c[aO>>2]|0;aQ=aP+4|0;aR=y+16628|0;aS=c[aR>>2]|0;aT=-1<<aQ;aU=aS-1|0;aV=aU+aT|0;c[aR>>2]=aV;aW=c[135448]|0;c[135456]=aW;a[8168]=1;c[154404]=541880;a[62504]=1;i=f;return 1};case 3:case 4:{s=0;_=0;x=0;aD=0;while(1){c[y+88+(aD<<2)>>2]=x<<12&61440|s<<4&240|((_&255)>>>4&255)<<20;S=aD+1|0;T=S>>>8&255;$=S&255;v=T<<8|S&-65536|$;if(v>>>0<4096){s=T;_=S&255;x=$;aD=v}else{break}}aE=y+16516|0;c[aE>>2]=0;aF=y+16604|0;c[aF>>2]=0;aG=y+16512|0;aH=c[aG>>2]|0;aI=aH+4|0;aJ=y+16540|0;aK=c[aJ>>2]|0;aL=-1<<aI;aM=aK-1|0;aN=aM+aL|0;c[aJ>>2]=aN;aO=y+16600|0;aP=c[aO>>2]|0;aQ=aP+4|0;aR=y+16628|0;aS=c[aR>>2]|0;aT=-1<<aQ;aU=aS-1|0;aV=aU+aT|0;c[aR>>2]=aV;aW=c[135448]|0;c[135456]=aW;a[8168]=1;c[154404]=541880;a[62504]=1;i=f;return 1};default:{ah(8);gj[aX&127](0,24936)|0;s_(y+88|0,0,16384);aE=y+16516|0;c[aE>>2]=0;aF=y+16604|0;c[aF>>2]=0;aG=y+16512|0;aH=c[aG>>2]|0;aI=aH+4|0;aJ=y+16540|0;aK=c[aJ>>2]|0;aL=-1<<aI;aM=aK-1|0;aN=aM+aL|0;c[aJ>>2]=aN;aO=y+16600|0;aP=c[aO>>2]|0;aQ=aP+4|0;aR=y+16628|0;aS=c[aR>>2]|0;aT=-1<<aQ;aU=aS-1|0;aV=aU+aT|0;c[aR>>2]=aV;aW=c[135448]|0;c[135456]=aW;a[8168]=1;c[154404]=541880;a[62504]=1;i=f;return 1}}return 0}function lT(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function lU(){return}function lV(){return}function lW(a,b,c){a=a|0;b=b|0;c=c|0;return}function lX(){return 0}function lY(a){a=a|0;return 65536}function lZ(e){e=e|0;var f=0,g=0,h=0,i=0;if(!(a[62504]|0)){return 617624}gr[c[138004]&127](617624,a[62512]|0?102:160,a[62496]|0?160:102,320);e=c[135468]|0;if((e|0)!=0){if((e|0)>0){f=c[154404]|0;g=552080;h=0;while(1){i=(d[f+h|0]|0)<<8^-32768;b[g>>1]=i;b[g+2>>1]=i;i=h+1|0;if((i|0)<(e|0)){g=g+4|0;h=i}else{break}}}c[135468]=0;h=c[138014]|0;gj[h&127](552080,e)|0}a[62216]=1;return 617624}function l_(a){a=a|0;c[a>>2]=55780;c[a+108>>2]=55800;l3(a+8|0);nt(a+108|0);return}function l$(a){a=a|0;l3(a);return}function l0(a){a=a|0;c[a>>2]=55780;c[a+108>>2]=55800;l3(a+8|0);nt(a+108|0);sS(a);return}function l1(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;c[b+d>>2]=55780;a=b+(d+108)|0;c[a>>2]=55800;l3(b+(d+8)|0);nt(a);return}function l2(a){a=a|0;var b=0,d=0,e=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;c[a>>2]=55780;e=b+(d+108)|0;c[e>>2]=55800;l3(b+(d+8)|0);nt(e);if((a|0)==0){return}sS(a);return}function l3(b){b=b|0;var d=0,e=0,f=0;d=b|0;c[d>>2]=56016;e=b+64|0;f=c[e>>2]|0;do{if((f|0)!=0){mb(b)|0;if((a_(f|0)|0)!=0){break}c[e>>2]=0}}while(0);do{if((a[b+96|0]&1)!=0){e=c[b+32>>2]|0;if((e|0)==0){break}sS(e)}}while(0);do{if((a[b+97|0]&1)!=0){e=c[b+56>>2]|0;if((e|0)==0){break}sS(e)}}while(0);c[d>>2]=55704;d=c[b+4>>2]|0;b=d+4|0;if(((I=c[b>>2]|0,c[b>>2]=I+ -1,I)|0)!=0){return}f$[c[(c[d>>2]|0)+8>>2]&511](d|0);return}function l4(a){a=a|0;l3(a);if((a|0)==0){return}sS(a);return}function l5(a){a=a|0;a=c[138010]|0;if((a|0)==0){ee();return 0}else{return f2[c[(c[a>>2]|0)+44>>2]&255](a)|0}return 0}function l6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e|0;f2[c[(c[b>>2]|0)+24>>2]&255](b)|0;g=c[d>>2]|0;if((c[137806]|0)!=-1){c[f>>2]=551224;c[f+4>>2]=16;c[f+8>>2]=0;mU(551224,f)}f=(c[137807]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=fc(4)|0;j=h;c[j>>2]=53912;dq(h|0,60416,316)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=fc(4)|0;j=h;c[j>>2]=53912;dq(h|0,60416,316)}h=g;c[b+68>>2]=h;j=b+98|0;f=a[j]&1;d=f2[c[(c[g>>2]|0)+28>>2]&255](h)|0;a[j]=d&1;if((f&255|0)==(d&1|0)){i=e;return}f=b+96|0;s_(b+8|0,0,24);j=(a[f]&1)!=0;if(d){d=b+32|0;do{if(j){h=c[d>>2]|0;if((h|0)==0){break}sS(h)}}while(0);h=b+97|0;a[f]=a[h]&1;g=b+60|0;c[b+52>>2]=c[g>>2];k=b+56|0;c[d>>2]=c[k>>2];c[g>>2]=0;c[k>>2]=0;a[h]=0;i=e;return}do{if(!j){h=b+32|0;k=c[h>>2]|0;if((k|0)==(b+44|0)){break}g=c[b+52>>2]|0;c[b+60>>2]=g;c[b+56>>2]=k;a[b+97|0]=0;k=(g|0)==0?1:g;while(1){l=sR(k)|0;if((l|0)!=0){m=4633;break}g=(I=c[138018]|0,c[138018]=I+0,I);if((g|0)==0){m=4627;break}gp[g&63]()}if((m|0)==4633){c[h>>2]=l;a[f]=1;i=e;return}else if((m|0)==4627){k=fc(4)|0;c[k>>2]=53880;dq(k|0,60400,240)}}}while(0);f=c[b+52>>2]|0;c[b+60>>2]=f;l=(f|0)==0?1:f;while(1){n=sR(l)|0;if((n|0)!=0){m=4649;break}f=(I=c[138018]|0,c[138018]=I+0,I);if((f|0)==0){m=4643;break}gp[f&63]()}if((m|0)==4643){l=fc(4)|0;c[l>>2]=53880;dq(l|0,60400,240)}else if((m|0)==4649){c[b+56>>2]=n;a[b+97|0]=1;i=e;return}}function l7(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b|0;g=b+96|0;s_(b+8|0,0,24);do{if((a[g]&1)!=0){h=c[b+32>>2]|0;if((h|0)==0){break}sS(h)}}while(0);h=b+97|0;do{if((a[h]&1)!=0){i=c[b+56>>2]|0;if((i|0)==0){break}sS(i)}}while(0);i=b+52|0;c[i>>2]=e;do{if(e>>>0>8){j=b+98|0;if(!((a[j]&1)==0|(d|0)==0)){c[b+32>>2]=d;a[g]=0;k=j;break}l=(e|0)==0?1:e;while(1){m=sR(l)|0;if((m|0)!=0){n=4681;break}o=(I=c[138018]|0,c[138018]=I+0,I);if((o|0)==0){break}gp[o&63]()}if((n|0)==4681){c[b+32>>2]=m;a[g]=1;k=j;break}l=fc(4)|0;c[l>>2]=53880;dq(l|0,60400,240);return 0}else{c[b+32>>2]=b+44;c[i>>2]=8;a[g]=0;k=b+98|0}}while(0);if((a[k]&1)!=0){c[b+60>>2]=0;c[b+56>>2]=0;a[h]=0;return f|0}k=(e|0)<8?8:e;c[b+60>>2]=k;if((d|0)!=0&k>>>0>7){c[b+56>>2]=d;a[h]=0;return f|0}d=(k|0)==0?1:k;while(1){p=sR(d)|0;if((p|0)!=0){n=4701;break}k=(I=c[138018]|0,c[138018]=I+0,I);if((k|0)==0){n=4695;break}gp[k&63]()}if((n|0)==4701){c[b+56>>2]=p;a[h]=1;return f|0}else if((n|0)==4695){n=fc(4)|0;c[n>>2]=53880;dq(n|0,60400,240);return 0}return 0}function l8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((c[b+64>>2]|0)==0){e=-1;return e|0}f=b+12|0;g=c[f>>2]|0;if((c[b+8>>2]|0)>>>0>=g>>>0){e=-1;return e|0}if((d|0)==-1){c[f>>2]=g-1;e=0;return e|0}h=g-1|0;do{if((c[b+88>>2]&16|0)==0){if((d<<24>>24|0)==(a[h]|0)){break}else{e=-1}return e|0}}while(0);c[f>>2]=h;a[h]=d&255;e=d;return e|0}function l9(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=b+64|0;do{if((c[f>>2]|0)!=0){if((f2[c[(c[b>>2]|0)+24>>2]&255](b)|0)!=0){break}if((e3(c[f>>2]|0,c[d+8>>2]|0,0)|0)==0){g=d;h=c[g+4>>2]|0;j=b+72|0;c[j>>2]=c[g>>2];c[j+4>>2]=h;h=a;j=d;c[h>>2]=c[j>>2];c[h+4>>2]=c[j+4>>2];c[h+8>>2]=c[j+8>>2];c[h+12>>2]=c[j+12>>2];i=e;return}else{j=a;c[j>>2]=0;c[j+4>>2]=0;j=a+8|0;c[j>>2]=-1;c[j+4>>2]=-1;i=e;return}}}while(0);d=a;c[d>>2]=0;c[d+4>>2]=0;d=a+8|0;c[d>>2]=-1;c[d+4>>2]=-1;i=e;return}function ma(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;g=c[b+68>>2]|0;if((g|0)==0){h=fc(4)|0;c[h>>2]=53912;dq(h|0,60416,316)}h=f2[c[(c[g>>2]|0)+24>>2]&255](g)|0;g=b+64|0;do{if((c[g>>2]|0)!=0){i=(h|0)>0;if(!(i|(d|0)==0&(e|0)==0)){break}if((f2[c[(c[b>>2]|0)+24>>2]&255](b)|0)!=0){break}if(f>>>0>=3){j=a;c[j>>2]=0;c[j+4>>2]=0;j=a+8|0;c[j>>2]=-1;c[j+4>>2]=-1;return}j=c[g>>2]|0;if(i){i=tk(h,(h|0)<0?-1:0,d,e)|0;k=i}else{k=0}if((e3(j|0,k|0,f|0)|0)==0){j=cx(c[g>>2]|0)|0;i=b+72|0;l=c[i+4>>2]|0;m=a;c[m>>2]=c[i>>2];c[m+4>>2]=l;l=a+8|0;c[l>>2]=j;c[l+4>>2]=(j|0)<0?-1:0;return}else{j=a;c[j>>2]=0;c[j+4>>2]=0;j=a+8|0;c[j>>2]=-1;c[j+4>>2]=-1;return}}}while(0);b=a;c[b>>2]=0;c[b+4>>2]=0;b=a+8|0;c[b>>2]=-1;c[b+4>>2]=-1;return}function mb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=f;h=b+64|0;if((c[h>>2]|0)==0){j=0;i=d;return j|0}k=b+68|0;l=c[k>>2]|0;if((l|0)==0){m=fc(4)|0;c[m>>2]=53912;dq(m|0,60416,316);return 0}m=b+92|0;n=c[m>>2]|0;do{if((n&16|0)==0){if((n&8|0)==0){break}o=b+80|0;p=c[o+4>>2]|0;c[f>>2]=c[o>>2];c[f+4>>2]=p;do{if((a[b+98|0]&1)==0){p=f2[c[(c[l>>2]|0)+24>>2]&255](l)|0;o=b+36|0;q=c[o>>2]|0;r=(c[b+40>>2]|0)-q|0;if((p|0)>0){s=(ag((c[b+16>>2]|0)-(c[b+12>>2]|0)|0,p)|0)+r|0;t=0;break}p=c[b+12>>2]|0;if((p|0)==(c[b+16>>2]|0)){s=r;t=0;break}u=c[k>>2]|0;v=b+32|0;w=f6[c[(c[u>>2]|0)+32>>2]&31](u,g,c[v>>2]|0,q,p-(c[b+8>>2]|0)|0)|0;s=r-w+(c[o>>2]|0)-(c[v>>2]|0)|0;t=1}else{s=(c[b+16>>2]|0)-(c[b+12>>2]|0)|0;t=0}}while(0);if((e3(c[h>>2]|0,-s|0,1)|0)!=0){j=-1;i=d;return j|0}if(t){v=b+72|0;o=c[f+4>>2]|0;c[v>>2]=c[f>>2];c[v+4>>2]=o}o=c[b+32>>2]|0;c[b+40>>2]=o;c[b+36>>2]=o;c[b+8>>2]=0;c[b+12>>2]=0;c[b+16>>2]=0;c[m>>2]=0}else{do{if((c[b+24>>2]|0)!=(c[b+20>>2]|0)){if((gj[c[(c[b>>2]|0)+52>>2]&127](b,-1)|0)==-1){j=-1}else{break}i=d;return j|0}}while(0);o=b+72|0;v=b+32|0;w=b+52|0;while(1){r=c[k>>2]|0;p=c[v>>2]|0;q=f6[c[(c[r>>2]|0)+20>>2]&31](r,o,p,p+(c[w>>2]|0)|0,e)|0;p=c[v>>2]|0;r=(c[e>>2]|0)-p|0;if((be(p|0,1,r|0,c[h>>2]|0)|0)!=(r|0)){j=-1;x=4771;break}if((q|0)==2){j=-1;x=4777;break}else if((q|0)!=1){x=4757;break}}if((x|0)==4771){i=d;return j|0}else if((x|0)==4777){i=d;return j|0}else if((x|0)==4757){if((a7(c[h>>2]|0)|0)==0){break}else{j=-1}i=d;return j|0}}}while(0);j=0;i=d;return j|0}function mc(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=b+64|0;if((c[h>>2]|0)==0){j=-1;i=e;return j|0}k=b+92|0;if((c[k>>2]&8|0)==0){c[b+24>>2]=0;c[b+20>>2]=0;c[b+28>>2]=0;if((a[b+98|0]&1)==0){l=c[b+56>>2]|0;m=l+(c[b+60>>2]|0)|0;c[b+8>>2]=l;c[b+12>>2]=m;c[b+16>>2]=m;n=m}else{m=c[b+32>>2]|0;l=m+(c[b+52>>2]|0)|0;c[b+8>>2]=m;c[b+12>>2]=l;c[b+16>>2]=l;n=l}c[k>>2]=8;o=1;p=n;q=b+12|0}else{n=b+12|0;o=0;p=c[n>>2]|0;q=n}if((p|0)==0){n=f+1|0;c[b+8>>2]=f;c[q>>2]=n;c[b+16>>2]=n;r=n;s=n}else{r=p;s=c[b+16>>2]|0}p=b+16|0;if(o){t=0}else{o=(s-(c[b+8>>2]|0)|0)/2|0;t=o>>>0>4?4:o}do{if((r|0)==(s|0)){o=b+8|0;s5(c[o>>2]|0,s+(-t|0)|0,t|0);if((a[b+98|0]&1)!=0){n=c[o>>2]|0;k=eK(n+t|0,1,(c[p>>2]|0)-t-n|0,c[h>>2]|0)|0;if((k|0)==0){u=-1;v=o;break}n=c[o>>2]|0;l=n+t|0;c[q>>2]=l;c[p>>2]=n+(k+t);u=d[l]|0;v=o;break}l=b+32|0;k=b+36|0;n=c[k>>2]|0;m=b+40|0;s5(c[l>>2]|0,n|0,(c[m>>2]|0)-n|0);n=c[l>>2]|0;w=n+((c[m>>2]|0)-(c[k>>2]|0))|0;c[k>>2]=w;if((n|0)==(b+44|0)){x=8}else{x=c[b+52>>2]|0}y=n+x|0;c[m>>2]=y;n=b+60|0;z=(c[n>>2]|0)-t|0;A=y-w|0;y=b+72|0;B=y;C=b+80|0;D=c[B+4>>2]|0;c[C>>2]=c[B>>2];c[C+4>>2]=D;D=eK(w|0,1,(A>>>0<z>>>0?A:z)|0,c[h>>2]|0)|0;if((D|0)==0){u=-1;v=o;break}z=c[b+68>>2]|0;if((z|0)==0){A=fc(4)|0;c[A>>2]=53912;dq(A|0,60416,316);return 0}A=(c[k>>2]|0)+D|0;c[m>>2]=A;D=c[o>>2]|0;if((gq[c[(c[z>>2]|0)+16>>2]&31](z,y,c[l>>2]|0,A,k,D+t|0,D+(c[n>>2]|0)|0,g)|0)==3){n=c[l>>2]|0;l=c[m>>2]|0;c[o>>2]=n;c[q>>2]=n;c[p>>2]=l;u=d[n]|0;v=o;break}n=c[g>>2]|0;l=c[o>>2]|0;m=l+t|0;if((n|0)==(m|0)){u=-1;v=o;break}c[o>>2]=l;c[q>>2]=m;c[p>>2]=n;u=d[m]|0;v=o}else{u=d[r]|0;v=b+8|0}}while(0);if((c[v>>2]|0)!=(f|0)){j=u;i=e;return j|0}c[v>>2]=0;c[q>>2]=0;c[p>>2]=0;j=u;i=e;return j|0}function md(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b+64|0;if((c[j>>2]|0)==0){k=-1;i=e;return k|0}l=b+92|0;if((c[l>>2]&16|0)==0){c[b+8>>2]=0;c[b+12>>2]=0;c[b+16>>2]=0;m=c[b+52>>2]|0;do{if(m>>>0>8){if((a[b+98|0]&1)==0){n=c[b+56>>2]|0;o=n+((c[b+60>>2]|0)-1)|0;c[b+24>>2]=n;c[b+20>>2]=n;c[b+28>>2]=o;p=n;q=o;break}else{o=c[b+32>>2]|0;n=o+(m-1)|0;c[b+24>>2]=o;c[b+20>>2]=o;c[b+28>>2]=n;p=o;q=n;break}}else{c[b+24>>2]=0;c[b+20>>2]=0;c[b+28>>2]=0;p=0;q=0}}while(0);c[l>>2]=16;r=p;s=q;t=b+20|0;u=b+28|0;v=p;w=b+24|0}else{p=b+20|0;q=b+28|0;l=b+24|0;r=c[p>>2]|0;s=c[q>>2]|0;t=p;u=q;v=c[l>>2]|0;w=l}l=(d|0)==-1;if(l){x=r;y=v}else{if((v|0)==0){c[w>>2]=f;c[t>>2]=f;c[u>>2]=f+1;z=f}else{z=v}a[z]=d&255;z=(c[w>>2]|0)+1|0;c[w>>2]=z;x=c[t>>2]|0;y=z}if((y|0)!=(x|0)){L6110:do{if((a[b+98|0]&1)==0){z=b+32|0;v=c[z>>2]|0;c[g>>2]=v;f=b+68|0;q=c[f>>2]|0;if((q|0)==0){A=fc(4)|0;B=A;c[B>>2]=53912;dq(A|0,60416,316);return 0}p=b+72|0;m=b+52|0;n=q;q=x;o=y;C=v;while(1){v=gq[c[(c[n>>2]|0)+12>>2]&31](n,p,q,o,h,C,C+(c[m>>2]|0)|0,g)|0;D=c[t>>2]|0;if((c[h>>2]|0)==(D|0)){k=-1;E=4845;break}if((v|0)==3){E=4831;break}if(v>>>0>=2){k=-1;E=4848;break}F=c[z>>2]|0;G=(c[g>>2]|0)-F|0;if((be(F|0,1,G|0,c[j>>2]|0)|0)!=(G|0)){k=-1;E=4842;break}if((v|0)!=1){break L6110}v=c[h>>2]|0;G=c[w>>2]|0;c[t>>2]=v;c[u>>2]=G;F=v+(G-v)|0;c[w>>2]=F;G=c[f>>2]|0;if((G|0)==0){E=4840;break}n=G;q=v;o=F;C=c[z>>2]|0}if((E|0)==4840){A=fc(4)|0;B=A;c[B>>2]=53912;dq(A|0,60416,316);return 0}else if((E|0)==4831){z=(c[w>>2]|0)-D|0;if((be(D|0,1,z|0,c[j>>2]|0)|0)==(z|0)){break}else{k=-1}i=e;return k|0}else if((E|0)==4848){i=e;return k|0}else if((E|0)==4845){i=e;return k|0}else if((E|0)==4842){i=e;return k|0}}else{z=y-x|0;if((be(x|0,1,z|0,c[j>>2]|0)|0)==(z|0)){break}else{k=-1}i=e;return k|0}}while(0);c[w>>2]=r;c[t>>2]=r;c[u>>2]=s}k=l?0:d;i=e;return k|0}function me(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gk=0,gl=0,gm=0,gn=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0;e=i;i=i+1024|0;f=e|0;do{if((c[135444]|0)==0){g=4855}else{h=b+48|0;if((c[h>>2]|0)!=0){g=4855;break}j=b+16|0;k=(c[j>>2]|0)+256|0;if((k|0)<64512){l=b+64|0;a[(c[l>>2]|0)+k|0]=(c[b+28>>2]|0)>>>8&255;m=l;n=b|0}else{l=b|0;o=c[l>>2]|0;go[c[(c[o>>2]|0)+12>>2]&127](o,k,(c[b+28>>2]|0)>>>8&255);m=b+64|0;n=l}l=(c[j>>2]|0)+255&255;c[j>>2]=l;k=b+28|0;a[(c[m>>2]|0)+(l|256)|0]=c[k>>2]&255;l=(c[j>>2]|0)+255&255;c[j>>2]=l;o=(c[b+32>>2]|0)==0?32:-96;p=(c[b+36>>2]|0)==0?o:o|64;o=(c[b+40>>2]|0)==0?p:p|16;p=b+44|0;q=(c[p>>2]|0)==0?o:o|8;o=(c[h>>2]|0)==0?q:q|4;a[(c[m>>2]|0)+(l|256)|0]=((c[b+52>>2]|0)==0?o:o|2)&-17|(c[b+56>>2]|0)!=0;c[j>>2]=(c[j>>2]|0)+255&255;c[h>>2]=1;c[p>>2]=0;p=c[n>>2]|0;c[k>>2]=(gj[c[(c[p>>2]|0)+24>>2]&127](p,65534)|0)&65535;c[135450]=c[135452];c[135452]=0;c[135458]=c[135448];c[135444]=0;r=k}}while(0);do{if((g|0)==4855){if((c[135452]|0)==0){r=b+28|0;break}else{i=e;return}}}while(0);g=c[r>>2]|0;if((g|0)<64512){s=a[(c[b+64>>2]|0)+g|0]|0;u=g}else{n=c[b>>2]|0;m=gj[c[(c[n>>2]|0)+16>>2]&127](n,g)|0;s=m;u=c[r>>2]|0}m=s&255;s=b+20|0;c[s>>2]=m;c[r>>2]=u+1;switch(m|0){case 42:{c[135448]=(c[135448]|0)+6;m=b+56|0;u=c[m>>2]|0;g=b+4|0;n=c[g>>2]|0;c[m>>2]=n&128;m=n<<1;n=m&254|(u|0)!=0;c[g>>2]=n;c[b+52>>2]=(n|0)==0;c[b+32>>2]=m&128;i=e;return};case 43:{c[135448]=(c[135448]|0)+6;m=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=m,v)|0)|0;i=v;m=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=m,v)|0)|0;i=v;i=e;return};case 25:{c[135448]=(c[135448]|0)+16;m=c[r>>2]|0;if((m|0)<64512){n=c[b+64>>2]|0;w=(d[n+(m+1)|0]|0)<<8|(d[n+m|0]|0);x=m}else{n=c[b>>2]|0;g=(gj[c[(c[n>>2]|0)+24>>2]&127](n,m)|0)&65535;w=g;x=c[r>>2]|0}c[r>>2]=x+2;x=w+(c[b+12>>2]|0)&65535;c[b+24>>2]=x;if(x>>>0<64512){y=a[(c[b+64>>2]|0)+x|0]|0}else{w=c[b>>2]|0;y=gj[c[(c[w>>2]|0)+16>>2]&127](w,x)|0}x=b+4|0;w=c[x>>2]|y&255;c[x>>2]=w;c[b+52>>2]=(w|0)==0;c[b+32>>2]=w&128;i=e;return};case 23:{c[135448]=(c[135448]|0)+21;w=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=w,v)|0)|0;i=v;w=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=w,v)|0)|0;i=v;i=e;return};case 24:{c[135448]=(c[135448]|0)+6;c[b+56>>2]=0;i=e;return};case 21:{c[135448]=(c[135448]|0)+16;w=c[r>>2]|0;if((w|0)<64512){x=c[b+64>>2]|0;z=a[x+w|0]|0;A=w;B=x}else{x=c[b>>2]|0;y=gj[c[(c[x>>2]|0)+16>>2]&127](x,w)|0;z=y;A=c[r>>2]|0;B=c[b+64>>2]|0}y=(z&255)+(c[b+8>>2]|0)|0;c[r>>2]=A+1;A=y&255;c[b+24>>2]=A;y=b+4|0;z=c[y>>2]|(d[B+A|0]|0);c[y>>2]=z;c[b+52>>2]=(z|0)==0;c[b+32>>2]=z&128;i=e;return};case 34:{c[135448]=(c[135448]|0)+6;z=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=z,v)|0)|0;i=v;z=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=z,v)|0)|0;i=v;i=e;return};case 35:{c[135448]=(c[135448]|0)+6;z=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=z,v)|0)|0;i=v;z=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=z,v)|0)|0;i=v;i=e;return};case 36:{c[135448]=(c[135448]|0)+11;z=c[r>>2]|0;if((z|0)<64512){y=b+64|0;C=a[(c[y>>2]|0)+z|0]|0;D=z;E=y}else{y=c[b>>2]|0;A=gj[c[(c[y>>2]|0)+16>>2]&127](y,z)|0;C=A;D=c[r>>2]|0;E=b+64|0}A=C&255;c[b+24>>2]=A;c[r>>2]=D+1;D=d[(c[E>>2]|0)+A|0]|0;c[b+52>>2]=(c[b+4>>2]&D|0)==0;if((c[s>>2]|0)==137){i=e;return}c[b+32>>2]=D&128;c[b+36>>2]=D&64;i=e;return};case 4:{c[135448]=(c[135448]|0)+21;D=c[r>>2]|0;if((D|0)<64512){A=b+64|0;F=a[(c[A>>2]|0)+D|0]|0;G=D;H=A}else{A=c[b>>2]|0;E=gj[c[(c[A>>2]|0)+16>>2]&127](A,D)|0;F=E;G=c[r>>2]|0;H=b+64|0}E=F&255;c[b+24>>2]=E;c[r>>2]=G+1;G=(c[H>>2]|0)+E|0;E=d[G]|0;H=c[b+4>>2]|0;c[b+52>>2]=(H&E|0)==0;a[G]=(H|E)&255;i=e;return};case 13:{c[135448]=(c[135448]|0)+16;E=c[r>>2]|0;if((E|0)<64512){H=c[b+64>>2]|0;I=(d[H+(E+1)|0]|0)<<8|(d[H+E|0]|0);J=E}else{H=c[b>>2]|0;G=(gj[c[(c[H>>2]|0)+24>>2]&127](H,E)|0)&65535;I=G;J=c[r>>2]|0}c[b+24>>2]=I;c[r>>2]=J+2;if((I|0)<64512){K=a[(c[b+64>>2]|0)+I|0]|0}else{J=c[b>>2]|0;K=gj[c[(c[J>>2]|0)+16>>2]&127](J,I)|0}I=b+4|0;J=c[I>>2]|K&255;c[I>>2]=J;c[b+52>>2]=(J|0)==0;c[b+32>>2]=J&128;i=e;return};case 64:{c[135448]=(c[135448]|0)+26;J=b+16|0;I=c[J>>2]|0;K=I+1&255;c[J>>2]=K;G=b+64|0;E=a[(c[G>>2]|0)+(K|256)|0]|0;c[J>>2]=I&255;do{if((E&16)==0){I=c[135450]|0;c[135452]=I;if((I|0)==0){break}c[135460]=(c[135448]|0)-(c[135458]|0)+(c[135460]|0)}}while(0);E=c[J>>2]|0;I=E+1&255;c[J>>2]=I;K=c[G>>2]|0;G=d[K+(I|256)|0]|0;c[b+32>>2]=G&128;c[b+36>>2]=G&64;c[b+40>>2]=G&16;c[b+44>>2]=G&8;c[b+48>>2]=G&4;c[b+52>>2]=G&2;c[b+56>>2]=G&1;G=E+2&255;c[J>>2]=G;I=d[K+(G|256)|0]|0;c[r>>2]=I;G=E+3&255;c[J>>2]=G;c[r>>2]=(d[K+(G|256)|0]|0)<<8|I;i=e;return};case 65:{c[135448]=(c[135448]|0)+26;I=c[r>>2]|0;if((I|0)<64512){G=c[b+64>>2]|0;L=a[G+I|0]|0;M=I;N=G}else{G=c[b>>2]|0;K=gj[c[(c[G>>2]|0)+16>>2]&127](G,I)|0;L=K;M=c[r>>2]|0;N=c[b+64>>2]|0}K=b+24|0;c[r>>2]=M+1;M=(c[b+8>>2]|0)+(L&255)&255;c[K>>2]=M;L=(d[N+(M+1)|0]|0)<<8|(d[N+M|0]|0);c[K>>2]=L;if(L>>>0<64512){O=a[(c[b+64>>2]|0)+L|0]|0}else{K=c[b>>2]|0;O=gj[c[(c[K>>2]|0)+16>>2]&127](K,L)|0}L=O&255;O=b+4|0;K=c[O>>2]|0;M=K^L;c[O>>2]=M;c[b+52>>2]=(K|0)==(L|0);c[b+32>>2]=M&128;i=e;return};case 66:{c[135448]=(c[135448]|0)+6;M=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=M,v)|0)|0;i=v;M=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=M,v)|0)|0;i=v;i=e;return};case 67:{c[135448]=(c[135448]|0)+6;M=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=M,v)|0)|0;i=v;M=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=M,v)|0)|0;i=v;i=e;return};case 68:{c[135448]=(c[135448]|0)+11;M=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=M,v)|0)|0;i=v;M=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=M,v)|0)|0;i=v;i=e;return};case 69:{c[135448]=(c[135448]|0)+11;M=c[r>>2]|0;if((M|0)<64512){L=b+64|0;P=a[(c[L>>2]|0)+M|0]|0;Q=M;R=L}else{L=c[b>>2]|0;K=gj[c[(c[L>>2]|0)+16>>2]&127](L,M)|0;P=K;Q=c[r>>2]|0;R=b+64|0}K=P&255;c[b+24>>2]=K;c[r>>2]=Q+1;Q=d[(c[R>>2]|0)+K|0]|0;K=b+4|0;R=c[K>>2]|0;P=R^Q;c[K>>2]=P;c[b+52>>2]=(R|0)==(Q|0);c[b+32>>2]=P&128;i=e;return};case 0:{c[135448]=(c[135448]|0)+31;P=(c[r>>2]|0)+1|0;c[r>>2]=P;Q=b+16|0;R=(c[Q>>2]|0)+256|0;if((R|0)<64512){K=b+64|0;a[(c[K>>2]|0)+R|0]=P>>>8&255;S=K;T=b|0}else{K=b|0;M=c[K>>2]|0;go[c[(c[M>>2]|0)+12>>2]&127](M,R,P>>>8&255);S=b+64|0;T=K}K=(c[Q>>2]|0)+255&255;c[Q>>2]=K;a[(c[S>>2]|0)+(K|256)|0]=c[r>>2]&255;K=(c[Q>>2]|0)+255&255;c[Q>>2]=K;P=(c[b+32>>2]|0)==0?32:-96;R=(c[b+36>>2]|0)==0?P:P|64;P=(c[b+40>>2]|0)==0?R:R|16;R=b+44|0;M=(c[R>>2]|0)==0?P:P|8;P=b+48|0;L=(c[P>>2]|0)==0?M:M|4;a[(c[S>>2]|0)+(K|256)|0]=(c[b+56>>2]|0)!=0|((c[b+52>>2]|0)==0?L:L|2)|16;c[Q>>2]=(c[Q>>2]|0)+255&255;c[R>>2]=0;c[P>>2]=1;P=c[T>>2]|0;c[r>>2]=(gj[c[(c[P>>2]|0)+24>>2]&127](P,65534)|0)&65535;i=e;return};case 39:{c[135448]=(c[135448]|0)+21;P=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=P,v)|0)|0;i=v;P=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=P,v)|0)|0;i=v;i=e;return};case 70:{c[135448]=(c[135448]|0)+21;P=c[r>>2]|0;if((P|0)<64512){T=b+64|0;U=a[(c[T>>2]|0)+P|0]|0;V=P;W=T}else{T=c[b>>2]|0;R=gj[c[(c[T>>2]|0)+16>>2]&127](T,P)|0;U=R;V=c[r>>2]|0;W=b+64|0}R=U&255;c[b+24>>2]=R;c[r>>2]=V+1;V=(c[W>>2]|0)+R|0;R=d[V]|0;c[b+56>>2]=R&1;W=R>>>1;a[V]=W&255;c[b+52>>2]=(W|0)==0;c[b+32>>2]=0;i=e;return};case 71:{c[135448]=(c[135448]|0)+21;W=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=W,v)|0)|0;i=v;W=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=W,v)|0)|0;i=v;i=e;return};case 72:{c[135448]=(c[135448]|0)+11;W=b+16|0;V=(c[W>>2]|0)+256|0;if((V|0)<64512){a[(c[b+64>>2]|0)+V|0]=c[b+4>>2]&255}else{R=c[b>>2]|0;go[c[(c[R>>2]|0)+12>>2]&127](R,V,c[b+4>>2]&255)}c[W>>2]=(c[W>>2]|0)+255&255;i=e;return};case 73:{c[135448]=(c[135448]|0)+6;W=c[r>>2]|0;c[b+24>>2]=W;c[r>>2]=W+1;if((W|0)<64512){X=a[(c[b+64>>2]|0)+W|0]|0}else{V=c[b>>2]|0;X=gj[c[(c[V>>2]|0)+16>>2]&127](V,W)|0}W=X&255;X=b+4|0;V=c[X>>2]|0;R=V^W;c[X>>2]=R;c[b+52>>2]=(V|0)==(W|0);c[b+32>>2]=R&128;i=e;return};case 74:{c[135448]=(c[135448]|0)+6;R=b+4|0;W=c[R>>2]|0;c[b+56>>2]=W&1;V=W>>>1&127;c[R>>2]=V;c[b+52>>2]=(V|0)==0;c[b+32>>2]=0;i=e;return};case 75:{c[135448]=(c[135448]|0)+6;V=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=V,v)|0)|0;i=v;V=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=V,v)|0)|0;i=v;i=e;return};case 76:{c[135448]=(c[135448]|0)+11;V=c[r>>2]|0;if((V|0)<64512){R=c[b+64>>2]|0;Y=(d[R+(V+1)|0]|0)<<8|(d[R+V|0]|0)}else{R=c[b>>2]|0;Y=(gj[c[(c[R>>2]|0)+24>>2]&127](R,V)|0)&65535}c[b+24>>2]=Y;c[r>>2]=Y;i=e;return};case 77:{c[135448]=(c[135448]|0)+16;Y=c[r>>2]|0;if((Y|0)<64512){V=c[b+64>>2]|0;Z=(d[V+(Y+1)|0]|0)<<8|(d[V+Y|0]|0);_=Y}else{V=c[b>>2]|0;R=(gj[c[(c[V>>2]|0)+24>>2]&127](V,Y)|0)&65535;Z=R;_=c[r>>2]|0}c[b+24>>2]=Z;c[r>>2]=_+2;if((Z|0)<64512){$=a[(c[b+64>>2]|0)+Z|0]|0}else{_=c[b>>2]|0;$=gj[c[(c[_>>2]|0)+16>>2]&127](_,Z)|0}Z=$&255;$=b+4|0;_=c[$>>2]|0;R=_^Z;c[$>>2]=R;c[b+52>>2]=(_|0)==(Z|0);c[b+32>>2]=R&128;i=e;return};case 78:{c[135448]=(c[135448]|0)+26;R=c[r>>2]|0;if((R|0)<64512){Z=c[b+64>>2]|0;aa=(d[Z+(R+1)|0]|0)<<8|(d[Z+R|0]|0);ab=R}else{Z=c[b>>2]|0;_=(gj[c[(c[Z>>2]|0)+24>>2]&127](Z,R)|0)&65535;aa=_;ab=c[r>>2]|0}_=b+24|0;c[_>>2]=aa;c[r>>2]=ab+2;if((aa|0)<64512){ac=a[(c[b+64>>2]|0)+aa|0]|0;ad=aa}else{ab=c[b>>2]|0;R=gj[c[(c[ab>>2]|0)+16>>2]&127](ab,aa)|0;ac=R;ad=c[_>>2]|0}_=ac&255;c[b+56>>2]=_&1;ac=_>>>1;if((ad|0)<64512){a[(c[b+64>>2]|0)+ad|0]=ac&255}else{_=c[b>>2]|0;go[c[(c[_>>2]|0)+12>>2]&127](_,ad,ac&255)}c[b+52>>2]=(ac|0)==0;c[b+32>>2]=0;i=e;return};case 11:{c[135448]=(c[135448]|0)+6;ac=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ac,v)|0)|0;i=v;ac=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ac,v)|0)|0;i=v;i=e;return};case 2:{c[135448]=(c[135448]|0)+6;ac=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ac,v)|0)|0;i=v;ac=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ac,v)|0)|0;i=v;i=e;return};case 3:{c[135448]=(c[135448]|0)+6;ac=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ac,v)|0)|0;i=v;ac=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ac,v)|0)|0;i=v;i=e;return};case 44:{c[135448]=(c[135448]|0)+16;ac=c[r>>2]|0;if((ac|0)<64512){ad=c[b+64>>2]|0;ae=(d[ad+(ac+1)|0]|0)<<8|(d[ad+ac|0]|0);af=ac}else{ad=c[b>>2]|0;_=(gj[c[(c[ad>>2]|0)+24>>2]&127](ad,ac)|0)&65535;ae=_;af=c[r>>2]|0}c[b+24>>2]=ae;c[r>>2]=af+2;if((ae|0)<64512){ag=a[(c[b+64>>2]|0)+ae|0]|0}else{af=c[b>>2]|0;ag=gj[c[(c[af>>2]|0)+16>>2]&127](af,ae)|0}ae=ag&255;c[b+52>>2]=(c[b+4>>2]&ae|0)==0;if((c[s>>2]|0)==137){i=e;return}c[b+32>>2]=ae&128;c[b+36>>2]=ae&64;i=e;return};case 6:{c[135448]=(c[135448]|0)+21;ae=c[r>>2]|0;if((ae|0)<64512){ag=b+64|0;ah=a[(c[ag>>2]|0)+ae|0]|0;ai=ae;aj=ag}else{ag=c[b>>2]|0;af=gj[c[(c[ag>>2]|0)+16>>2]&127](ag,ae)|0;ah=af;ai=c[r>>2]|0;aj=b+64|0}af=ah&255;c[b+24>>2]=af;c[r>>2]=ai+1;ai=(c[aj>>2]|0)+af|0;af=d[ai]|0;c[b+56>>2]=af&128;aj=af<<1;c[b+52>>2]=(aj&254|0)==0;c[b+32>>2]=aj&128;a[ai]=aj&255;i=e;return};case 12:{c[135448]=(c[135448]|0)+26;aj=c[r>>2]|0;if((aj|0)<64512){ai=c[b+64>>2]|0;ak=(d[ai+(aj+1)|0]|0)<<8|(d[ai+aj|0]|0);al=aj}else{ai=c[b>>2]|0;af=(gj[c[(c[ai>>2]|0)+24>>2]&127](ai,aj)|0)&65535;ak=af;al=c[r>>2]|0}af=b+24|0;c[af>>2]=ak;c[r>>2]=al+2;if((ak|0)<64512){am=a[(c[b+64>>2]|0)+ak|0]|0;an=ak}else{al=c[b>>2]|0;aj=gj[c[(c[al>>2]|0)+16>>2]&127](al,ak)|0;am=aj;an=c[af>>2]|0}af=am&255;am=c[b+4>>2]|0;c[b+52>>2]=(am&af|0)==0;aj=am|af;if((an|0)<64512){a[(c[b+64>>2]|0)+an|0]=aj&255;i=e;return}else{af=c[b>>2]|0;go[c[(c[af>>2]|0)+12>>2]&127](af,an,aj&255);i=e;return}break};case 8:{c[135448]=(c[135448]|0)+11;aj=b+16|0;an=(c[aj>>2]|0)+256|0;if((an|0)<64512){af=(c[b+32>>2]|0)==0?32:-96;am=(c[b+36>>2]|0)==0?af:af|64;af=(c[b+40>>2]|0)==0?am:am|16;am=(c[b+44>>2]|0)==0?af:af|8;af=(c[b+48>>2]|0)==0?am:am|4;a[(c[b+64>>2]|0)+an|0]=((c[b+52>>2]|0)==0?af:af|2)|(c[b+56>>2]|0)!=0}else{af=c[b>>2]|0;am=(c[b+32>>2]|0)==0?32:-96;ak=(c[b+36>>2]|0)==0?am:am|64;am=(c[b+40>>2]|0)==0?ak:ak|16;ak=(c[b+44>>2]|0)==0?am:am|8;am=(c[b+48>>2]|0)==0?ak:ak|4;go[c[(c[af>>2]|0)+12>>2]&127](af,an,((c[b+52>>2]|0)==0?am:am|2)|(c[b+56>>2]|0)!=0)}c[aj>>2]=(c[aj>>2]|0)+255&255;i=e;return};case 7:{c[135448]=(c[135448]|0)+6;aj=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=aj,v)|0)|0;i=v;aj=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=aj,v)|0)|0;i=v;i=e;return};case 53:{c[135448]=(c[135448]|0)+16;aj=c[r>>2]|0;if((aj|0)<64512){am=c[b+64>>2]|0;ao=a[am+aj|0]|0;ap=aj;aq=am}else{am=c[b>>2]|0;an=gj[c[(c[am>>2]|0)+16>>2]&127](am,aj)|0;ao=an;ap=c[r>>2]|0;aq=c[b+64>>2]|0}an=(ao&255)+(c[b+8>>2]|0)|0;c[r>>2]=ap+1;ap=an&255;c[b+24>>2]=ap;an=b+4|0;ao=c[an>>2]&(d[aq+ap|0]|0);c[an>>2]=ao;c[b+52>>2]=(ao|0)==0;c[b+32>>2]=ao&128;i=e;return};case 54:{c[135448]=(c[135448]|0)+26;ao=c[r>>2]|0;if((ao|0)<64512){an=c[b+64>>2]|0;ar=a[an+ao|0]|0;as=ao;at=an}else{an=c[b>>2]|0;ap=gj[c[(c[an>>2]|0)+16>>2]&127](an,ao)|0;ar=ap;as=c[r>>2]|0;at=c[b+64>>2]|0}ap=(ar&255)+(c[b+8>>2]|0)|0;c[r>>2]=as+1;as=ap&255;c[b+24>>2]=as;ap=d[at+as|0]|0;at=b+56|0;ar=c[at>>2]|0;c[at>>2]=ap&128;at=ap<<1;ap=at&254|(ar|0)!=0;a[(c[b+64>>2]|0)+as|0]=ap&255;c[b+52>>2]=(ap|0)==0;c[b+32>>2]=at&128;i=e;return};case 55:{c[135448]=(c[135448]|0)+21;at=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=at,v)|0)|0;i=v;at=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=at,v)|0)|0;i=v;i=e;return};case 56:{c[135448]=(c[135448]|0)+6;c[b+56>>2]=1;i=e;return};case 57:{c[135448]=(c[135448]|0)+16;at=c[r>>2]|0;if((at|0)<64512){ap=c[b+64>>2]|0;au=(d[ap+(at+1)|0]|0)<<8|(d[ap+at|0]|0);av=at}else{ap=c[b>>2]|0;as=(gj[c[(c[ap>>2]|0)+24>>2]&127](ap,at)|0)&65535;au=as;av=c[r>>2]|0}c[r>>2]=av+2;av=au+(c[b+12>>2]|0)&65535;c[b+24>>2]=av;if(av>>>0<64512){aw=a[(c[b+64>>2]|0)+av|0]|0}else{au=c[b>>2]|0;aw=gj[c[(c[au>>2]|0)+16>>2]&127](au,av)|0}av=b+4|0;au=c[av>>2]&(aw&255);c[av>>2]=au;c[b+52>>2]=(au|0)==0;c[b+32>>2]=au&128;i=e;return};case 58:{c[135448]=(c[135448]|0)+6;au=b+4|0;av=(c[au>>2]|0)+255|0;aw=av&255;c[au>>2]=aw;c[b+52>>2]=(aw|0)==0;c[b+32>>2]=av&128;i=e;return};case 59:{c[135448]=(c[135448]|0)+6;av=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=av,v)|0)|0;i=v;av=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=av,v)|0)|0;i=v;i=e;return};case 60:{c[135448]=(c[135448]|0)+16;av=c[r>>2]|0;if((av|0)<64512){aw=c[b+64>>2]|0;ax=(d[aw+(av+1)|0]|0)<<8|(d[aw+av|0]|0);ay=av}else{aw=c[b>>2]|0;au=(gj[c[(c[aw>>2]|0)+24>>2]&127](aw,av)|0)&65535;ax=au;ay=c[r>>2]|0}c[r>>2]=ay+2;ay=ax+(c[b+8>>2]|0)&65535;c[b+24>>2]=ay;if(ay>>>0<64512){az=a[(c[b+64>>2]|0)+ay|0]|0}else{ax=c[b>>2]|0;az=gj[c[(c[ax>>2]|0)+16>>2]&127](ax,ay)|0}ay=az&255;c[b+52>>2]=(c[b+4>>2]&ay|0)==0;if((c[s>>2]|0)==137){i=e;return}c[b+32>>2]=ay&128;c[b+36>>2]=ay&64;i=e;return};case 10:{c[135448]=(c[135448]|0)+6;ay=b+4|0;az=c[ay>>2]|0;c[b+56>>2]=az&128;ax=az<<1;az=ax&254;c[ay>>2]=az;c[b+52>>2]=(az|0)==0;c[b+32>>2]=ax&128;i=e;return};case 61:{c[135448]=(c[135448]|0)+16;ax=c[r>>2]|0;if((ax|0)<64512){az=c[b+64>>2]|0;aA=(d[az+(ax+1)|0]|0)<<8|(d[az+ax|0]|0);aB=ax}else{az=c[b>>2]|0;ay=(gj[c[(c[az>>2]|0)+24>>2]&127](az,ax)|0)&65535;aA=ay;aB=c[r>>2]|0}c[r>>2]=aB+2;aB=aA+(c[b+8>>2]|0)&65535;c[b+24>>2]=aB;if(aB>>>0<64512){aC=a[(c[b+64>>2]|0)+aB|0]|0}else{aA=c[b>>2]|0;aC=gj[c[(c[aA>>2]|0)+16>>2]&127](aA,aB)|0}aB=b+4|0;aA=c[aB>>2]&(aC&255);c[aB>>2]=aA;c[b+52>>2]=(aA|0)==0;c[b+32>>2]=aA&128;i=e;return};case 62:{c[135448]=(c[135448]|0)+31;aA=c[r>>2]|0;if((aA|0)<64512){aB=c[b+64>>2]|0;aD=(d[aB+(aA+1)|0]|0)<<8|(d[aB+aA|0]|0);aE=aA}else{aB=c[b>>2]|0;aC=(gj[c[(c[aB>>2]|0)+24>>2]&127](aB,aA)|0)&65535;aD=aC;aE=c[r>>2]|0}aC=b+24|0;c[r>>2]=aE+2;aE=aD+(c[b+8>>2]|0)&65535;c[aC>>2]=aE;if(aE>>>0<64512){aF=a[(c[b+64>>2]|0)+aE|0]|0;aG=aE}else{aD=c[b>>2]|0;aA=gj[c[(c[aD>>2]|0)+16>>2]&127](aD,aE)|0;aF=aA;aG=c[aC>>2]|0}aC=aF&255;aF=b+56|0;aA=c[aF>>2]|0;c[aF>>2]=aC&128;aF=aC<<1;aC=aF&254|(aA|0)!=0;if((aG|0)<64512){a[(c[b+64>>2]|0)+aG|0]=aC&255}else{aA=c[b>>2]|0;go[c[(c[aA>>2]|0)+12>>2]&127](aA,aG,aC&255)}c[b+52>>2]=(aC|0)==0;c[b+32>>2]=aF&128;i=e;return};case 63:{c[135448]=(c[135448]|0)+21;aF=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=aF,v)|0)|0;i=v;aF=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=aF,v)|0)|0;i=v;i=e;return};case 9:{c[135448]=(c[135448]|0)+11;aF=c[r>>2]|0;c[b+24>>2]=aF;c[r>>2]=aF+1;if((aF|0)<64512){aH=a[(c[b+64>>2]|0)+aF|0]|0}else{aC=c[b>>2]|0;aH=gj[c[(c[aC>>2]|0)+16>>2]&127](aC,aF)|0}aF=b+4|0;aC=c[aF>>2]|aH&255;c[aF>>2]=aC;c[b+52>>2]=(aC|0)==0;c[b+32>>2]=aC&128;i=e;return};case 19:{c[135448]=(c[135448]|0)+6;aC=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=aC,v)|0)|0;i=v;aC=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=aC,v)|0)|0;i=v;i=e;return};case 20:{c[135448]=(c[135448]|0)+21;aC=c[r>>2]|0;if((aC|0)<64512){aF=b+64|0;aI=a[(c[aF>>2]|0)+aC|0]|0;aJ=aC;aK=aF}else{aF=c[b>>2]|0;aH=gj[c[(c[aF>>2]|0)+16>>2]&127](aF,aC)|0;aI=aH;aJ=c[r>>2]|0;aK=b+64|0}aH=aI&255;c[b+24>>2]=aH;c[r>>2]=aJ+1;aJ=(c[aK>>2]|0)+aH|0;aH=d[aJ]|0;aK=c[b+4>>2]|0;c[b+52>>2]=(aK&aH|0)==0;a[aJ]=(aK^255)&aH&255;i=e;return};case 50:{c[135448]=(c[135448]|0)+21;aH=c[r>>2]|0;if((aH|0)<64512){aK=b+64|0;aL=a[(c[aK>>2]|0)+aH|0]|0;aM=aH;aN=aK}else{aK=c[b>>2]|0;aJ=gj[c[(c[aK>>2]|0)+16>>2]&127](aK,aH)|0;aL=aJ;aM=c[r>>2]|0;aN=b+64|0}aJ=aL&255;aL=b+24|0;c[aL>>2]=aJ;c[r>>2]=aM+1;aM=c[aN>>2]|0;aN=(d[aM+(aJ+1)|0]|0)<<8|(d[aM+aJ|0]|0);c[aL>>2]=aN;if(aN>>>0<64512){aO=a[aM+aN|0]|0}else{aM=c[b>>2]|0;aO=gj[c[(c[aM>>2]|0)+16>>2]&127](aM,aN)|0}aN=b+4|0;aM=c[aN>>2]&(aO&255);c[aN>>2]=aM;c[b+52>>2]=(aM|0)==0;c[b+32>>2]=aM&128;i=e;return};case 51:{c[135448]=(c[135448]|0)+6;aM=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=aM,v)|0)|0;i=v;aM=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=aM,v)|0)|0;i=v;i=e;return};case 52:{c[135448]=(c[135448]|0)+16;aM=c[r>>2]|0;if((aM|0)<64512){aN=c[b+64>>2]|0;aP=a[aN+aM|0]|0;aQ=aM;aR=aN}else{aN=c[b>>2]|0;aO=gj[c[(c[aN>>2]|0)+16>>2]&127](aN,aM)|0;aP=aO;aQ=c[r>>2]|0;aR=c[b+64>>2]|0}aO=(aP&255)+(c[b+8>>2]|0)|0;c[r>>2]=aQ+1;aQ=aO&255;c[b+24>>2]=aQ;aO=d[aR+aQ|0]|0;c[b+52>>2]=(c[b+4>>2]&aO|0)==0;if((c[s>>2]|0)==137){i=e;return}c[b+32>>2]=aO&128;c[b+36>>2]=aO&64;i=e;return};case 40:{c[135448]=(c[135448]|0)+16;aO=b+16|0;aQ=(c[aO>>2]|0)+1&255;c[aO>>2]=aQ;aO=d[(c[b+64>>2]|0)+(aQ|256)|0]|0;c[b+32>>2]=aO&128;c[b+36>>2]=aO&64;c[b+40>>2]=aO&16;c[b+44>>2]=aO&8;c[b+48>>2]=aO&4;c[b+52>>2]=aO&2;c[b+56>>2]=aO&1;i=e;return};case 41:{c[135448]=(c[135448]|0)+6;aO=c[r>>2]|0;c[b+24>>2]=aO;c[r>>2]=aO+1;if((aO|0)<64512){aS=a[(c[b+64>>2]|0)+aO|0]|0}else{aQ=c[b>>2]|0;aS=gj[c[(c[aQ>>2]|0)+16>>2]&127](aQ,aO)|0}aO=b+4|0;aQ=c[aO>>2]&(aS&255);c[aO>>2]=aQ;c[b+52>>2]=(aQ|0)==0;c[b+32>>2]=aQ&128;i=e;return};case 5:{c[135448]=(c[135448]|0)+11;aQ=c[r>>2]|0;if((aQ|0)<64512){aO=b+64|0;aT=a[(c[aO>>2]|0)+aQ|0]|0;aU=aQ;aV=aO}else{aO=c[b>>2]|0;aS=gj[c[(c[aO>>2]|0)+16>>2]&127](aO,aQ)|0;aT=aS;aU=c[r>>2]|0;aV=b+64|0}aS=aT&255;c[b+24>>2]=aS;c[r>>2]=aU+1;aU=b+4|0;aT=c[aU>>2]|(d[(c[aV>>2]|0)+aS|0]|0);c[aU>>2]=aT;c[b+52>>2]=(aT|0)==0;c[b+32>>2]=aT&128;i=e;return};case 15:{c[135448]=(c[135448]|0)+21;aT=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=aT,v)|0)|0;i=v;aT=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=aT,v)|0)|0;i=v;i=e;return};case 29:{c[135448]=(c[135448]|0)+16;aT=c[r>>2]|0;if((aT|0)<64512){aU=c[b+64>>2]|0;aW=(d[aU+(aT+1)|0]|0)<<8|(d[aU+aT|0]|0);aX=aT}else{aU=c[b>>2]|0;aS=(gj[c[(c[aU>>2]|0)+24>>2]&127](aU,aT)|0)&65535;aW=aS;aX=c[r>>2]|0}c[r>>2]=aX+2;aX=aW+(c[b+8>>2]|0)&65535;c[b+24>>2]=aX;if(aX>>>0<64512){aY=a[(c[b+64>>2]|0)+aX|0]|0}else{aW=c[b>>2]|0;aY=gj[c[(c[aW>>2]|0)+16>>2]&127](aW,aX)|0}aX=b+4|0;aW=c[aX>>2]|aY&255;c[aX>>2]=aW;c[b+52>>2]=(aW|0)==0;c[b+32>>2]=aW&128;i=e;return};case 45:{c[135448]=(c[135448]|0)+16;aW=c[r>>2]|0;if((aW|0)<64512){aX=c[b+64>>2]|0;aZ=(d[aX+(aW+1)|0]|0)<<8|(d[aX+aW|0]|0);a_=aW}else{aX=c[b>>2]|0;aY=(gj[c[(c[aX>>2]|0)+24>>2]&127](aX,aW)|0)&65535;aZ=aY;a_=c[r>>2]|0}c[b+24>>2]=aZ;c[r>>2]=a_+2;if((aZ|0)<64512){a$=a[(c[b+64>>2]|0)+aZ|0]|0}else{a_=c[b>>2]|0;a$=gj[c[(c[a_>>2]|0)+16>>2]&127](a_,aZ)|0}aZ=b+4|0;a_=c[aZ>>2]&(a$&255);c[aZ>>2]=a_;c[b+52>>2]=(a_|0)==0;c[b+32>>2]=a_&128;i=e;return};case 46:{c[135448]=(c[135448]|0)+26;a_=c[r>>2]|0;if((a_|0)<64512){aZ=c[b+64>>2]|0;a0=(d[aZ+(a_+1)|0]|0)<<8|(d[aZ+a_|0]|0);a1=a_}else{aZ=c[b>>2]|0;a$=(gj[c[(c[aZ>>2]|0)+24>>2]&127](aZ,a_)|0)&65535;a0=a$;a1=c[r>>2]|0}a$=b+24|0;c[a$>>2]=a0;c[r>>2]=a1+2;if((a0|0)<64512){a2=a[(c[b+64>>2]|0)+a0|0]|0;a3=a0}else{a1=c[b>>2]|0;a_=gj[c[(c[a1>>2]|0)+16>>2]&127](a1,a0)|0;a2=a_;a3=c[a$>>2]|0}a$=a2&255;a2=b+56|0;a_=c[a2>>2]|0;c[a2>>2]=a$&128;a2=a$<<1;a$=a2&254|(a_|0)!=0;if((a3|0)<64512){a[(c[b+64>>2]|0)+a3|0]=a$&255}else{a_=c[b>>2]|0;go[c[(c[a_>>2]|0)+12>>2]&127](a_,a3,a$&255)}c[b+52>>2]=(a$|0)==0;c[b+32>>2]=a2&128;i=e;return};case 47:{c[135448]=(c[135448]|0)+21;a2=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=a2,v)|0)|0;i=v;a2=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=a2,v)|0)|0;i=v;i=e;return};case 48:{c[135448]=(c[135448]|0)+6;a2=c[r>>2]|0;if((c[b+32>>2]|0)==0){c[r>>2]=a2+1&65535;i=e;return}if((a2|0)<64512){a4=a[(c[b+64>>2]|0)+a2|0]|0;a5=a2}else{a$=c[b>>2]|0;a3=gj[c[(c[a$>>2]|0)+16>>2]&127](a$,a2)|0;a4=a3;a5=c[r>>2]|0}c[r>>2]=a5+1+(a4<<24>>24)&65535;i=e;return};case 49:{c[135448]=(c[135448]|0)+21;a4=c[r>>2]|0;if((a4|0)<64512){a5=b+64|0;a6=a[(c[a5>>2]|0)+a4|0]|0;a7=a4;a8=a5}else{a5=c[b>>2]|0;a3=gj[c[(c[a5>>2]|0)+16>>2]&127](a5,a4)|0;a6=a3;a7=c[r>>2]|0;a8=b+64|0}a3=a6&255;a6=b+24|0;c[a6>>2]=a3;c[r>>2]=a7+1;a7=c[a8>>2]|0;a8=(c[b+12>>2]|0)+((d[a7+(a3+1)|0]|0)<<8|(d[a7+a3|0]|0))&65535;c[a6>>2]=a8;if(a8>>>0<64512){a9=a[a7+a8|0]|0}else{a7=c[b>>2]|0;a9=gj[c[(c[a7>>2]|0)+16>>2]&127](a7,a8)|0}a8=b+4|0;a7=c[a8>>2]&(a9&255);c[a8>>2]=a7;c[b+52>>2]=(a7|0)==0;c[b+32>>2]=a7&128;i=e;return};case 18:{c[135448]=(c[135448]|0)+21;a7=c[r>>2]|0;if((a7|0)<64512){a8=b+64|0;ba=a[(c[a8>>2]|0)+a7|0]|0;bb=a7;bc=a8}else{a8=c[b>>2]|0;a9=gj[c[(c[a8>>2]|0)+16>>2]&127](a8,a7)|0;ba=a9;bb=c[r>>2]|0;bc=b+64|0}a9=ba&255;ba=b+24|0;c[ba>>2]=a9;c[r>>2]=bb+1;bb=c[bc>>2]|0;bc=(d[bb+(a9+1)|0]|0)<<8|(d[bb+a9|0]|0);c[ba>>2]=bc;if(bc>>>0<64512){bd=a[bb+bc|0]|0}else{bb=c[b>>2]|0;bd=gj[c[(c[bb>>2]|0)+16>>2]&127](bb,bc)|0}bc=b+4|0;bb=c[bc>>2]|bd&255;c[bc>>2]=bb;c[b+52>>2]=(bb|0)==0;c[b+32>>2]=bb&128;i=e;return};case 26:{c[135448]=(c[135448]|0)+6;bb=b+4|0;bc=(c[bb>>2]|0)+1|0;bd=bc&255;c[bb>>2]=bd;c[b+52>>2]=(bd|0)==0;c[b+32>>2]=bc&128;i=e;return};case 27:{c[135448]=(c[135448]|0)+6;bc=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=bc,v)|0)|0;i=v;bc=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=bc,v)|0)|0;i=v;i=e;return};case 28:{c[135448]=(c[135448]|0)+26;bc=c[r>>2]|0;if((bc|0)<64512){bd=c[b+64>>2]|0;be=(d[bd+(bc+1)|0]|0)<<8|(d[bd+bc|0]|0);bf=bc}else{bd=c[b>>2]|0;bb=(gj[c[(c[bd>>2]|0)+24>>2]&127](bd,bc)|0)&65535;be=bb;bf=c[r>>2]|0}bb=b+24|0;c[bb>>2]=be;c[r>>2]=bf+2;if((be|0)<64512){bg=a[(c[b+64>>2]|0)+be|0]|0;bh=be}else{bf=c[b>>2]|0;bc=gj[c[(c[bf>>2]|0)+16>>2]&127](bf,be)|0;bg=bc;bh=c[bb>>2]|0}bb=bg&255;bg=c[b+4>>2]|0;c[b+52>>2]=(bg&bb|0)==0;bc=(bg^255)&bb;if((bh|0)<64512){a[(c[b+64>>2]|0)+bh|0]=bc&255;i=e;return}else{bb=c[b>>2]|0;go[c[(c[bb>>2]|0)+12>>2]&127](bb,bh,bc&255);i=e;return}break};case 22:{c[135448]=(c[135448]|0)+26;bc=c[r>>2]|0;if((bc|0)<64512){bh=c[b+64>>2]|0;bi=a[bh+bc|0]|0;bj=bc;bk=bh}else{bh=c[b>>2]|0;bb=gj[c[(c[bh>>2]|0)+16>>2]&127](bh,bc)|0;bi=bb;bj=c[r>>2]|0;bk=c[b+64>>2]|0}bb=(bi&255)+(c[b+8>>2]|0)|0;c[r>>2]=bj+1;bj=bb&255;c[b+24>>2]=bj;bb=d[bk+bj|0]|0;c[b+56>>2]=bb&128;bk=bb<<1;c[b+52>>2]=(bk&254|0)==0;c[b+32>>2]=bk&128;a[(c[b+64>>2]|0)+bj|0]=bk&255;i=e;return};case 30:{c[135448]=(c[135448]|0)+31;bk=c[r>>2]|0;if((bk|0)<64512){bj=c[b+64>>2]|0;bl=(d[bj+(bk+1)|0]|0)<<8|(d[bj+bk|0]|0);bm=bk}else{bj=c[b>>2]|0;bb=(gj[c[(c[bj>>2]|0)+24>>2]&127](bj,bk)|0)&65535;bl=bb;bm=c[r>>2]|0}bb=b+24|0;c[r>>2]=bm+2;bm=bl+(c[b+8>>2]|0)&65535;c[bb>>2]=bm;if(bm>>>0<64512){bn=a[(c[b+64>>2]|0)+bm|0]|0;bo=bm}else{bl=c[b>>2]|0;bk=gj[c[(c[bl>>2]|0)+16>>2]&127](bl,bm)|0;bn=bk;bo=c[bb>>2]|0}bb=bn&255;c[b+56>>2]=bb&128;bn=bb<<1;c[b+52>>2]=(bn&254|0)==0;c[b+32>>2]=bn&128;if((bo|0)<64512){a[(c[b+64>>2]|0)+bo|0]=bn&255;i=e;return}else{bb=c[b>>2]|0;go[c[(c[bb>>2]|0)+12>>2]&127](bb,bo,bn&255);i=e;return}break};case 17:{c[135448]=(c[135448]|0)+21;bn=c[r>>2]|0;if((bn|0)<64512){bo=b+64|0;bp=a[(c[bo>>2]|0)+bn|0]|0;bq=bn;br=bo}else{bo=c[b>>2]|0;bb=gj[c[(c[bo>>2]|0)+16>>2]&127](bo,bn)|0;bp=bb;bq=c[r>>2]|0;br=b+64|0}bb=bp&255;bp=b+24|0;c[bp>>2]=bb;c[r>>2]=bq+1;bq=c[br>>2]|0;br=(c[b+12>>2]|0)+((d[bq+(bb+1)|0]|0)<<8|(d[bq+bb|0]|0))&65535;c[bp>>2]=br;if(br>>>0<64512){bs=a[bq+br|0]|0}else{bq=c[b>>2]|0;bs=gj[c[(c[bq>>2]|0)+16>>2]&127](bq,br)|0}br=b+4|0;bq=c[br>>2]|bs&255;c[br>>2]=bq;c[b+52>>2]=(bq|0)==0;c[b+32>>2]=bq&128;i=e;return};case 1:{c[135448]=(c[135448]|0)+26;bq=c[r>>2]|0;if((bq|0)<64512){br=c[b+64>>2]|0;bt=a[br+bq|0]|0;bu=bq;bv=br}else{br=c[b>>2]|0;bs=gj[c[(c[br>>2]|0)+16>>2]&127](br,bq)|0;bt=bs;bu=c[r>>2]|0;bv=c[b+64>>2]|0}bs=b+24|0;c[r>>2]=bu+1;bu=(c[b+8>>2]|0)+(bt&255)&255;c[bs>>2]=bu;bt=(d[bv+(bu+1)|0]|0)<<8|(d[bv+bu|0]|0);c[bs>>2]=bt;if(bt>>>0<64512){bw=a[(c[b+64>>2]|0)+bt|0]|0}else{bs=c[b>>2]|0;bw=gj[c[(c[bs>>2]|0)+16>>2]&127](bs,bt)|0}bt=b+4|0;bs=c[bt>>2]|bw&255;c[bt>>2]=bs;c[b+52>>2]=(bs|0)==0;c[b+32>>2]=bs&128;i=e;return};case 31:{c[135448]=(c[135448]|0)+21;bs=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=bs,v)|0)|0;i=v;bs=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=bs,v)|0)|0;i=v;i=e;return};case 32:{c[135448]=(c[135448]|0)+26;bs=c[r>>2]|0;if((bs|0)<64512){bt=c[b+64>>2]|0;bx=(d[bt+(bs+1)|0]|0)<<8|(d[bt+bs|0]|0);by=bs}else{bt=c[b>>2]|0;bw=(gj[c[(c[bt>>2]|0)+24>>2]&127](bt,bs)|0)&65535;bx=bw;by=c[r>>2]|0}bw=b+24|0;c[bw>>2]=bx;c[r>>2]=by+2;bx=b+16|0;bs=(c[bx>>2]|0)+256|0;if((bs|0)<64512){bt=b+64|0;a[(c[bt>>2]|0)+bs|0]=(by+1|0)>>>8&255;bz=bt}else{bt=c[b>>2]|0;go[c[(c[bt>>2]|0)+12>>2]&127](bt,bs,(by+1|0)>>>8&255);bz=b+64|0}by=(c[bx>>2]|0)+255&255;c[bx>>2]=by;a[(c[bz>>2]|0)+(by|256)|0]=(c[r>>2]|0)+255&255;c[bx>>2]=(c[bx>>2]|0)+255&255;c[r>>2]=c[bw>>2];i=e;return};case 16:{c[135448]=(c[135448]|0)+6;bw=c[r>>2]|0;if((c[b+32>>2]|0)!=0){c[r>>2]=bw+1&65535;i=e;return}if((bw|0)<64512){bA=a[(c[b+64>>2]|0)+bw|0]|0;bB=bw}else{bx=c[b>>2]|0;by=gj[c[(c[bx>>2]|0)+16>>2]&127](bx,bw)|0;bA=by;bB=c[r>>2]|0}c[r>>2]=bB+1+(bA<<24>>24)&65535;i=e;return};case 14:{c[135448]=(c[135448]|0)+26;bA=c[r>>2]|0;if((bA|0)<64512){bB=c[b+64>>2]|0;bC=(d[bB+(bA+1)|0]|0)<<8|(d[bB+bA|0]|0);bD=bA}else{bB=c[b>>2]|0;by=(gj[c[(c[bB>>2]|0)+24>>2]&127](bB,bA)|0)&65535;bC=by;bD=c[r>>2]|0}by=b+24|0;c[by>>2]=bC;c[r>>2]=bD+2;if((bC|0)<64512){bE=a[(c[b+64>>2]|0)+bC|0]|0;bF=bC}else{bD=c[b>>2]|0;bA=gj[c[(c[bD>>2]|0)+16>>2]&127](bD,bC)|0;bE=bA;bF=c[by>>2]|0}by=bE&255;c[b+56>>2]=by&128;bE=by<<1;c[b+52>>2]=(bE&254|0)==0;c[b+32>>2]=bE&128;if((bF|0)<64512){a[(c[b+64>>2]|0)+bF|0]=bE&255;i=e;return}else{by=c[b>>2]|0;go[c[(c[by>>2]|0)+12>>2]&127](by,bF,bE&255);i=e;return}break};case 33:{c[135448]=(c[135448]|0)+26;bE=c[r>>2]|0;if((bE|0)<64512){bF=c[b+64>>2]|0;bG=a[bF+bE|0]|0;bH=bE;bI=bF}else{bF=c[b>>2]|0;by=gj[c[(c[bF>>2]|0)+16>>2]&127](bF,bE)|0;bG=by;bH=c[r>>2]|0;bI=c[b+64>>2]|0}by=b+24|0;c[r>>2]=bH+1;bH=(c[b+8>>2]|0)+(bG&255)&255;c[by>>2]=bH;bG=(d[bI+(bH+1)|0]|0)<<8|(d[bI+bH|0]|0);c[by>>2]=bG;if(bG>>>0<64512){bJ=a[(c[b+64>>2]|0)+bG|0]|0}else{by=c[b>>2]|0;bJ=gj[c[(c[by>>2]|0)+16>>2]&127](by,bG)|0}bG=b+4|0;by=c[bG>>2]&(bJ&255);c[bG>>2]=by;c[b+52>>2]=(by|0)==0;c[b+32>>2]=by&128;i=e;return};case 37:{c[135448]=(c[135448]|0)+11;by=c[r>>2]|0;if((by|0)<64512){bG=b+64|0;bK=a[(c[bG>>2]|0)+by|0]|0;bL=by;bM=bG}else{bG=c[b>>2]|0;bJ=gj[c[(c[bG>>2]|0)+16>>2]&127](bG,by)|0;bK=bJ;bL=c[r>>2]|0;bM=b+64|0}bJ=bK&255;c[b+24>>2]=bJ;c[r>>2]=bL+1;bL=b+4|0;bK=c[bL>>2]&(d[(c[bM>>2]|0)+bJ|0]|0);c[bL>>2]=bK;c[b+52>>2]=(bK|0)==0;c[b+32>>2]=bK&128;i=e;return};case 38:{c[135448]=(c[135448]|0)+21;bK=c[r>>2]|0;if((bK|0)<64512){bL=b+64|0;bN=a[(c[bL>>2]|0)+bK|0]|0;bO=bK;bP=bL}else{bL=c[b>>2]|0;bJ=gj[c[(c[bL>>2]|0)+16>>2]&127](bL,bK)|0;bN=bJ;bO=c[r>>2]|0;bP=b+64|0}bJ=bN&255;c[b+24>>2]=bJ;c[r>>2]=bO+1;bO=(c[bP>>2]|0)+bJ|0;bJ=d[bO]|0;bP=b+56|0;bN=c[bP>>2]|0;c[bP>>2]=bJ&128;bP=bJ<<1;bJ=bP&254|(bN|0)!=0;a[bO]=bJ&255;c[b+52>>2]=(bJ|0)==0;c[b+32>>2]=bP&128;i=e;return};case 79:{c[135448]=(c[135448]|0)+21;bP=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=bP,v)|0)|0;i=v;bP=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=bP,v)|0)|0;i=v;i=e;return};case 80:{c[135448]=(c[135448]|0)+6;bP=c[r>>2]|0;if((c[b+36>>2]|0)!=0){c[r>>2]=bP+1&65535;i=e;return}if((bP|0)<64512){bQ=a[(c[b+64>>2]|0)+bP|0]|0;bR=bP}else{bJ=c[b>>2]|0;bO=gj[c[(c[bJ>>2]|0)+16>>2]&127](bJ,bP)|0;bQ=bO;bR=c[r>>2]|0}c[r>>2]=bR+1+(bQ<<24>>24)&65535;i=e;return};case 81:{c[135448]=(c[135448]|0)+21;bQ=c[r>>2]|0;if((bQ|0)<64512){bR=b+64|0;bS=a[(c[bR>>2]|0)+bQ|0]|0;bT=bQ;bU=bR}else{bR=c[b>>2]|0;bO=gj[c[(c[bR>>2]|0)+16>>2]&127](bR,bQ)|0;bS=bO;bT=c[r>>2]|0;bU=b+64|0}bO=bS&255;bS=b+24|0;c[bS>>2]=bO;c[r>>2]=bT+1;bT=c[bU>>2]|0;bU=(c[b+12>>2]|0)+((d[bT+(bO+1)|0]|0)<<8|(d[bT+bO|0]|0))&65535;c[bS>>2]=bU;if(bU>>>0<64512){bV=a[bT+bU|0]|0}else{bT=c[b>>2]|0;bV=gj[c[(c[bT>>2]|0)+16>>2]&127](bT,bU)|0}bU=bV&255;bV=b+4|0;bT=c[bV>>2]|0;bS=bT^bU;c[bV>>2]=bS;c[b+52>>2]=(bT|0)==(bU|0);c[b+32>>2]=bS&128;i=e;return};case 82:{c[135448]=(c[135448]|0)+21;bS=c[r>>2]|0;if((bS|0)<64512){bU=b+64|0;bW=a[(c[bU>>2]|0)+bS|0]|0;bX=bS;bY=bU}else{bU=c[b>>2]|0;bT=gj[c[(c[bU>>2]|0)+16>>2]&127](bU,bS)|0;bW=bT;bX=c[r>>2]|0;bY=b+64|0}bT=bW&255;bW=b+24|0;c[bW>>2]=bT;c[r>>2]=bX+1;bX=c[bY>>2]|0;bY=(d[bX+(bT+1)|0]|0)<<8|(d[bX+bT|0]|0);c[bW>>2]=bY;if(bY>>>0<64512){bZ=a[bX+bY|0]|0}else{bX=c[b>>2]|0;bZ=gj[c[(c[bX>>2]|0)+16>>2]&127](bX,bY)|0}bY=bZ&255;bZ=b+4|0;bX=c[bZ>>2]|0;bW=bX^bY;c[bZ>>2]=bW;c[b+52>>2]=(bX|0)==(bY|0);c[b+32>>2]=bW&128;i=e;return};case 83:{c[135448]=(c[135448]|0)+6;bW=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=bW,v)|0)|0;i=v;bW=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=bW,v)|0)|0;i=v;i=e;return};case 84:{c[135448]=(c[135448]|0)+16;bW=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=bW,v)|0)|0;i=v;bW=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=bW,v)|0)|0;i=v;i=e;return};case 85:{c[135448]=(c[135448]|0)+16;bW=c[r>>2]|0;if((bW|0)<64512){bY=c[b+64>>2]|0;b_=a[bY+bW|0]|0;b$=bW;b0=bY}else{bY=c[b>>2]|0;bX=gj[c[(c[bY>>2]|0)+16>>2]&127](bY,bW)|0;b_=bX;b$=c[r>>2]|0;b0=c[b+64>>2]|0}bX=(b_&255)+(c[b+8>>2]|0)|0;c[r>>2]=b$+1;b$=bX&255;c[b+24>>2]=b$;bX=d[b0+b$|0]|0;b$=b+4|0;b0=c[b$>>2]|0;b_=b0^bX;c[b$>>2]=b_;c[b+52>>2]=(b0|0)==(bX|0);c[b+32>>2]=b_&128;i=e;return};case 86:{c[135448]=(c[135448]|0)+26;b_=c[r>>2]|0;if((b_|0)<64512){bX=c[b+64>>2]|0;b1=a[bX+b_|0]|0;b2=b_;b3=bX}else{bX=c[b>>2]|0;b0=gj[c[(c[bX>>2]|0)+16>>2]&127](bX,b_)|0;b1=b0;b2=c[r>>2]|0;b3=c[b+64>>2]|0}b0=(b1&255)+(c[b+8>>2]|0)|0;c[r>>2]=b2+1;b2=b0&255;c[b+24>>2]=b2;b0=d[b3+b2|0]|0;c[b+56>>2]=b0&1;b3=b0>>>1;a[(c[b+64>>2]|0)+b2|0]=b3&255;c[b+52>>2]=(b3|0)==0;c[b+32>>2]=0;i=e;return};case 87:{c[135448]=(c[135448]|0)+21;b3=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=b3,v)|0)|0;i=v;b3=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=b3,v)|0)|0;i=v;i=e;return};case 88:{c[135448]=(c[135448]|0)+6;c[b+48>>2]=0;i=e;return};case 89:{c[135448]=(c[135448]|0)+16;b3=c[r>>2]|0;if((b3|0)<64512){b2=c[b+64>>2]|0;b4=(d[b2+(b3+1)|0]|0)<<8|(d[b2+b3|0]|0);b5=b3}else{b2=c[b>>2]|0;b0=(gj[c[(c[b2>>2]|0)+24>>2]&127](b2,b3)|0)&65535;b4=b0;b5=c[r>>2]|0}c[r>>2]=b5+2;b5=b4+(c[b+12>>2]|0)&65535;c[b+24>>2]=b5;if(b5>>>0<64512){b6=a[(c[b+64>>2]|0)+b5|0]|0}else{b4=c[b>>2]|0;b6=gj[c[(c[b4>>2]|0)+16>>2]&127](b4,b5)|0}b5=b6&255;b6=b+4|0;b4=c[b6>>2]|0;b0=b4^b5;c[b6>>2]=b0;c[b+52>>2]=(b4|0)==(b5|0);c[b+32>>2]=b0&128;i=e;return};case 90:{c[135448]=(c[135448]|0)+11;b0=b+16|0;b5=(c[b0>>2]|0)+256|0;if((b5|0)<64512){a[(c[b+64>>2]|0)+b5|0]=c[b+12>>2]&255}else{b4=c[b>>2]|0;go[c[(c[b4>>2]|0)+12>>2]&127](b4,b5,c[b+12>>2]&255)}c[b0>>2]=(c[b0>>2]|0)+255&255;i=e;return};case 91:{c[135448]=(c[135448]|0)+6;b0=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=b0,v)|0)|0;i=v;b0=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=b0,v)|0)|0;i=v;i=e;return};case 92:{c[135448]=(c[135448]|0)+36;b0=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=b0,v)|0)|0;i=v;b0=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=b0,v)|0)|0;i=v;i=e;return};case 93:{c[135448]=(c[135448]|0)+16;b0=c[r>>2]|0;if((b0|0)<64512){b5=c[b+64>>2]|0;b7=(d[b5+(b0+1)|0]|0)<<8|(d[b5+b0|0]|0);b8=b0}else{b5=c[b>>2]|0;b4=(gj[c[(c[b5>>2]|0)+24>>2]&127](b5,b0)|0)&65535;b7=b4;b8=c[r>>2]|0}c[r>>2]=b8+2;b8=b7+(c[b+8>>2]|0)&65535;c[b+24>>2]=b8;if(b8>>>0<64512){b9=a[(c[b+64>>2]|0)+b8|0]|0}else{b7=c[b>>2]|0;b9=gj[c[(c[b7>>2]|0)+16>>2]&127](b7,b8)|0}b8=b9&255;b9=b+4|0;b7=c[b9>>2]|0;b4=b7^b8;c[b9>>2]=b4;c[b+52>>2]=(b7|0)==(b8|0);c[b+32>>2]=b4&128;i=e;return};case 94:{c[135448]=(c[135448]|0)+31;b4=c[r>>2]|0;if((b4|0)<64512){b8=c[b+64>>2]|0;ca=(d[b8+(b4+1)|0]|0)<<8|(d[b8+b4|0]|0);cb=b4}else{b8=c[b>>2]|0;b7=(gj[c[(c[b8>>2]|0)+24>>2]&127](b8,b4)|0)&65535;ca=b7;cb=c[r>>2]|0}b7=b+24|0;c[r>>2]=cb+2;cb=ca+(c[b+8>>2]|0)&65535;c[b7>>2]=cb;if(cb>>>0<64512){cc=a[(c[b+64>>2]|0)+cb|0]|0;cd=cb}else{ca=c[b>>2]|0;b4=gj[c[(c[ca>>2]|0)+16>>2]&127](ca,cb)|0;cc=b4;cd=c[b7>>2]|0}b7=cc&255;c[b+56>>2]=b7&1;cc=b7>>>1;if((cd|0)<64512){a[(c[b+64>>2]|0)+cd|0]=cc&255}else{b7=c[b>>2]|0;go[c[(c[b7>>2]|0)+12>>2]&127](b7,cd,cc&255)}c[b+52>>2]=(cc|0)==0;c[b+32>>2]=0;i=e;return};case 95:{c[135448]=(c[135448]|0)+21;cc=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=cc,v)|0)|0;i=v;cc=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=cc,v)|0)|0;i=v;i=e;return};case 96:{c[135448]=(c[135448]|0)+26;cc=b+16|0;cd=c[cc>>2]|0;b7=cd+1&255;c[cc>>2]=b7;b4=c[b+64>>2]|0;cb=d[b4+(b7|256)|0]|0;c[r>>2]=cb;b7=cd+2&255;c[cc>>2]=b7;c[r>>2]=((d[b4+(b7|256)|0]|0)<<8|cb)+1;i=e;return};case 97:{c[135448]=(c[135448]|0)+26;cb=c[r>>2]|0;if((cb|0)<64512){b7=c[b+64>>2]|0;ce=a[b7+cb|0]|0;cf=cb;cg=b7}else{b7=c[b>>2]|0;b4=gj[c[(c[b7>>2]|0)+16>>2]&127](b7,cb)|0;ce=b4;cf=c[r>>2]|0;cg=c[b+64>>2]|0}b4=b+24|0;c[r>>2]=cf+1;cf=(c[b+8>>2]|0)+(ce&255)&255;c[b4>>2]=cf;ce=(d[cg+(cf+1)|0]|0)<<8|(d[cg+cf|0]|0);c[b4>>2]=ce;if(ce>>>0<64512){ch=a[(c[b+64>>2]|0)+ce|0]|0}else{b4=c[b>>2]|0;ch=gj[c[(c[b4>>2]|0)+16>>2]&127](b4,ce)|0}ce=ch&255;ch=b+56|0;b4=(c[ch>>2]|0)!=0|0;cf=b+4|0;cg=c[cf>>2]|0;if((c[b+44>>2]|0)==0){cb=cg+ce+b4|0;b7=b+36|0;c[b7>>2]=0;c[ch>>2]=0;if(((ce^128^cg)&128&(cg^cb)|0)!=0){c[b7>>2]=1}if((cb&65280|0)!=0){c[ch>>2]=1}ci=cb&255}else{cb=(cg&15)+(ce&15)+b4|0;b4=(cg&240)+(ce&240)|0;b7=b+36|0;c[b7>>2]=0;c[ch>>2]=0;if((cb|0)>9){cj=cb+6|0;ck=b4+16|0}else{cj=cb;ck=b4}if(((ce^128^cg)&128&(cg^ck)|0)!=0){c[b7>>2]=1}b7=(ck|0)>144?ck+96|0:ck;if((b7&65280|0)!=0){c[ch>>2]=1}ci=b7&240|cj&15}c[cf>>2]=ci;c[b+52>>2]=(ci|0)==0;c[b+32>>2]=ci&128;i=e;return};case 98:{c[135448]=(c[135448]|0)+6;ci=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ci,v)|0)|0;i=v;ci=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ci,v)|0)|0;i=v;i=e;return};case 99:{c[135448]=(c[135448]|0)+6;ci=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ci,v)|0)|0;i=v;ci=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ci,v)|0)|0;i=v;i=e;return};case 100:{c[135448]=(c[135448]|0)+11;ci=c[r>>2]|0;if((ci|0)<64512){cf=b+64|0;cl=a[(c[cf>>2]|0)+ci|0]|0;cm=ci;cn=cf}else{cf=c[b>>2]|0;cj=gj[c[(c[cf>>2]|0)+16>>2]&127](cf,ci)|0;cl=cj;cm=c[r>>2]|0;cn=b+64|0}cj=cl&255;c[b+24>>2]=cj;c[r>>2]=cm+1;a[(c[cn>>2]|0)+cj|0]=0;i=e;return};case 101:{c[135448]=(c[135448]|0)+11;cj=c[r>>2]|0;if((cj|0)<64512){cn=b+64|0;co=a[(c[cn>>2]|0)+cj|0]|0;cp=cj;cq=cn}else{cn=c[b>>2]|0;cm=gj[c[(c[cn>>2]|0)+16>>2]&127](cn,cj)|0;co=cm;cp=c[r>>2]|0;cq=b+64|0}cm=co&255;c[b+24>>2]=cm;c[r>>2]=cp+1;cp=d[(c[cq>>2]|0)+cm|0]|0;cm=b+56|0;cq=(c[cm>>2]|0)!=0|0;co=b+4|0;cj=c[co>>2]|0;if((c[b+44>>2]|0)==0){cn=cj+cp+cq|0;cl=b+36|0;c[cl>>2]=0;c[cm>>2]=0;if(((cp^128^cj)&128&(cj^cn)|0)!=0){c[cl>>2]=1}if((cn&65280|0)!=0){c[cm>>2]=1}cr=cn&255}else{cn=(cj&15)+(cp&15)+cq|0;cq=(cj&240)+(cp&240)|0;cl=b+36|0;c[cl>>2]=0;c[cm>>2]=0;if((cn|0)>9){cs=cn+6|0;ct=cq+16|0}else{cs=cn;ct=cq}if(((cp^128^cj)&128&(cj^ct)|0)!=0){c[cl>>2]=1}cl=(ct|0)>144?ct+96|0:ct;if((cl&65280|0)!=0){c[cm>>2]=1}cr=cl&240|cs&15}c[co>>2]=cr;c[b+52>>2]=(cr|0)==0;c[b+32>>2]=cr&128;i=e;return};case 102:{c[135448]=(c[135448]|0)+21;cr=c[r>>2]|0;if((cr|0)<64512){co=b+64|0;cu=a[(c[co>>2]|0)+cr|0]|0;cv=cr;cw=co}else{co=c[b>>2]|0;cs=gj[c[(c[co>>2]|0)+16>>2]&127](co,cr)|0;cu=cs;cv=c[r>>2]|0;cw=b+64|0}cs=cu&255;c[b+24>>2]=cs;c[r>>2]=cv+1;cv=(c[cw>>2]|0)+cs|0;cs=d[cv]|0;cw=b+56|0;cu=c[cw>>2]|0;c[cw>>2]=cs&1;cw=(cu|0)!=0?128:0;cu=cw|cs>>>1;a[cv]=cu&255;c[b+52>>2]=(cu|0)==0;c[b+32>>2]=cw;i=e;return};case 103:{c[135448]=(c[135448]|0)+21;cw=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=cw,v)|0)|0;i=v;cw=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=cw,v)|0)|0;i=v;i=e;return};case 104:{c[135448]=(c[135448]|0)+16;cw=b+16|0;cu=(c[cw>>2]|0)+1&255;c[cw>>2]=cu;cw=a[(c[b+64>>2]|0)+(cu|256)|0]|0;cu=cw&255;c[b+4>>2]=cu;c[b+52>>2]=cw<<24>>24==0;c[b+32>>2]=cu&128;i=e;return};case 105:{c[135448]=(c[135448]|0)+6;cu=c[r>>2]|0;c[b+24>>2]=cu;c[r>>2]=cu+1;if((cu|0)<64512){cx=a[(c[b+64>>2]|0)+cu|0]|0}else{cw=c[b>>2]|0;cx=gj[c[(c[cw>>2]|0)+16>>2]&127](cw,cu)|0}cu=cx&255;cx=b+56|0;cw=(c[cx>>2]|0)!=0|0;cv=b+4|0;cs=c[cv>>2]|0;if((c[b+44>>2]|0)==0){cr=cs+cu+cw|0;co=b+36|0;c[co>>2]=0;c[cx>>2]=0;if(((cu^128^cs)&128&(cs^cr)|0)!=0){c[co>>2]=1}if((cr&65280|0)!=0){c[cx>>2]=1}cy=cr&255}else{cr=(cs&15)+(cu&15)+cw|0;cw=(cs&240)+(cu&240)|0;co=b+36|0;c[co>>2]=0;c[cx>>2]=0;if((cr|0)>9){cz=cr+6|0;cB=cw+16|0}else{cz=cr;cB=cw}if(((cu^128^cs)&128&(cs^cB)|0)!=0){c[co>>2]=1}co=(cB|0)>144?cB+96|0:cB;if((co&65280|0)!=0){c[cx>>2]=1}cy=co&240|cz&15}c[cv>>2]=cy;c[b+52>>2]=(cy|0)==0;c[b+32>>2]=cy&128;i=e;return};case 106:{c[135448]=(c[135448]|0)+6;cy=b+56|0;cv=c[cy>>2]|0;cz=b+4|0;co=c[cz>>2]|0;c[cy>>2]=co&1;cy=(cv|0)!=0?128:0;cv=co>>>1&127|cy;c[cz>>2]=cv;c[b+52>>2]=(cv|0)==0;c[b+32>>2]=cy;i=e;return};case 107:{c[135448]=(c[135448]|0)+6;cy=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=cy,v)|0)|0;i=v;cy=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=cy,v)|0)|0;i=v;i=e;return};case 108:{c[135448]=(c[135448]|0)+26;cy=c[r>>2]|0;if((cy|0)<64512){cv=c[b+64>>2]|0;cC=(d[cv+(cy+1)|0]|0)<<8|(d[cv+cy|0]|0);cD=cy}else{cv=c[b>>2]|0;cz=(gj[c[(c[cv>>2]|0)+24>>2]&127](cv,cy)|0)&65535;cC=cz;cD=c[r>>2]|0}cz=b+24|0;c[cz>>2]=cC;c[r>>2]=cD+2;if((cC|0)<64512){cD=c[b+64>>2]|0;cE=(d[cD+(cC+1)|0]|0)<<8|(d[cD+cC|0]|0)}else{cD=c[b>>2]|0;cE=(gj[c[(c[cD>>2]|0)+24>>2]&127](cD,cC)|0)&65535}c[cz>>2]=cE;c[r>>2]=cE;i=e;return};case 109:{c[135448]=(c[135448]|0)+16;cE=c[r>>2]|0;if((cE|0)<64512){cz=c[b+64>>2]|0;cF=(d[cz+(cE+1)|0]|0)<<8|(d[cz+cE|0]|0);cG=cE}else{cz=c[b>>2]|0;cC=(gj[c[(c[cz>>2]|0)+24>>2]&127](cz,cE)|0)&65535;cF=cC;cG=c[r>>2]|0}c[b+24>>2]=cF;c[r>>2]=cG+2;if((cF|0)<64512){cH=a[(c[b+64>>2]|0)+cF|0]|0}else{cG=c[b>>2]|0;cH=gj[c[(c[cG>>2]|0)+16>>2]&127](cG,cF)|0}cF=cH&255;cH=b+56|0;cG=(c[cH>>2]|0)!=0|0;cC=b+4|0;cE=c[cC>>2]|0;if((c[b+44>>2]|0)==0){cz=cE+cF+cG|0;cD=b+36|0;c[cD>>2]=0;c[cH>>2]=0;if(((cF^128^cE)&128&(cE^cz)|0)!=0){c[cD>>2]=1}if((cz&65280|0)!=0){c[cH>>2]=1}cI=cz&255}else{cz=(cE&15)+(cF&15)+cG|0;cG=(cE&240)+(cF&240)|0;cD=b+36|0;c[cD>>2]=0;c[cH>>2]=0;if((cz|0)>9){cJ=cz+6|0;cK=cG+16|0}else{cJ=cz;cK=cG}if(((cF^128^cE)&128&(cE^cK)|0)!=0){c[cD>>2]=1}cD=(cK|0)>144?cK+96|0:cK;if((cD&65280|0)!=0){c[cH>>2]=1}cI=cD&240|cJ&15}c[cC>>2]=cI;c[b+52>>2]=(cI|0)==0;c[b+32>>2]=cI&128;i=e;return};case 110:{c[135448]=(c[135448]|0)+26;cI=c[r>>2]|0;if((cI|0)<64512){cC=c[b+64>>2]|0;cL=(d[cC+(cI+1)|0]|0)<<8|(d[cC+cI|0]|0);cM=cI}else{cC=c[b>>2]|0;cJ=(gj[c[(c[cC>>2]|0)+24>>2]&127](cC,cI)|0)&65535;cL=cJ;cM=c[r>>2]|0}cJ=b+24|0;c[cJ>>2]=cL;c[r>>2]=cM+2;if((cL|0)<64512){cN=a[(c[b+64>>2]|0)+cL|0]|0;cO=cL}else{cM=c[b>>2]|0;cI=gj[c[(c[cM>>2]|0)+16>>2]&127](cM,cL)|0;cN=cI;cO=c[cJ>>2]|0}cJ=cN&255;cN=b+56|0;cI=c[cN>>2]|0;c[cN>>2]=cJ&1;cN=(cI|0)!=0?128:0;cI=cN|cJ>>>1;if((cO|0)<64512){a[(c[b+64>>2]|0)+cO|0]=cI&255}else{cJ=c[b>>2]|0;go[c[(c[cJ>>2]|0)+12>>2]&127](cJ,cO,cI&255)}c[b+52>>2]=(cI|0)==0;c[b+32>>2]=cN;i=e;return};case 111:{c[135448]=(c[135448]|0)+21;cN=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=cN,v)|0)|0;i=v;cN=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=cN,v)|0)|0;i=v;i=e;return};case 112:{c[135448]=(c[135448]|0)+6;cN=c[r>>2]|0;if((c[b+36>>2]|0)==0){c[r>>2]=cN+1&65535;i=e;return}if((cN|0)<64512){cP=a[(c[b+64>>2]|0)+cN|0]|0;cQ=cN}else{cI=c[b>>2]|0;cO=gj[c[(c[cI>>2]|0)+16>>2]&127](cI,cN)|0;cP=cO;cQ=c[r>>2]|0}c[r>>2]=cQ+1+(cP<<24>>24)&65535;i=e;return};case 113:{c[135448]=(c[135448]|0)+21;cP=c[r>>2]|0;if((cP|0)<64512){cQ=b+64|0;cR=a[(c[cQ>>2]|0)+cP|0]|0;cS=cP;cT=cQ}else{cQ=c[b>>2]|0;cO=gj[c[(c[cQ>>2]|0)+16>>2]&127](cQ,cP)|0;cR=cO;cS=c[r>>2]|0;cT=b+64|0}cO=cR&255;cR=b+24|0;c[cR>>2]=cO;c[r>>2]=cS+1;cS=c[cT>>2]|0;cT=(c[b+12>>2]|0)+((d[cS+(cO+1)|0]|0)<<8|(d[cS+cO|0]|0))&65535;c[cR>>2]=cT;if(cT>>>0<64512){cU=a[cS+cT|0]|0}else{cS=c[b>>2]|0;cU=gj[c[(c[cS>>2]|0)+16>>2]&127](cS,cT)|0}cT=cU&255;cU=b+56|0;cS=(c[cU>>2]|0)!=0|0;cR=b+4|0;cO=c[cR>>2]|0;if((c[b+44>>2]|0)==0){cP=cO+cT+cS|0;cQ=b+36|0;c[cQ>>2]=0;c[cU>>2]=0;if(((cT^128^cO)&128&(cO^cP)|0)!=0){c[cQ>>2]=1}if((cP&65280|0)!=0){c[cU>>2]=1}cV=cP&255}else{cP=(cO&15)+(cT&15)+cS|0;cS=(cO&240)+(cT&240)|0;cQ=b+36|0;c[cQ>>2]=0;c[cU>>2]=0;if((cP|0)>9){cW=cP+6|0;cX=cS+16|0}else{cW=cP;cX=cS}if(((cT^128^cO)&128&(cO^cX)|0)!=0){c[cQ>>2]=1}cQ=(cX|0)>144?cX+96|0:cX;if((cQ&65280|0)!=0){c[cU>>2]=1}cV=cQ&240|cW&15}c[cR>>2]=cV;c[b+52>>2]=(cV|0)==0;c[b+32>>2]=cV&128;i=e;return};case 114:{c[135448]=(c[135448]|0)+21;cV=c[r>>2]|0;if((cV|0)<64512){cR=b+64|0;cY=a[(c[cR>>2]|0)+cV|0]|0;cZ=cV;c_=cR}else{cR=c[b>>2]|0;cW=gj[c[(c[cR>>2]|0)+16>>2]&127](cR,cV)|0;cY=cW;cZ=c[r>>2]|0;c_=b+64|0}cW=cY&255;cY=b+24|0;c[cY>>2]=cW;c[r>>2]=cZ+1;cZ=c[c_>>2]|0;c_=(d[cZ+(cW+1)|0]|0)<<8|(d[cZ+cW|0]|0);c[cY>>2]=c_;if(c_>>>0<64512){c$=a[cZ+c_|0]|0}else{cZ=c[b>>2]|0;c$=gj[c[(c[cZ>>2]|0)+16>>2]&127](cZ,c_)|0}c_=c$&255;c$=b+56|0;cZ=(c[c$>>2]|0)!=0|0;cY=b+4|0;cW=c[cY>>2]|0;if((c[b+44>>2]|0)==0){cV=cW+c_+cZ|0;cR=b+36|0;c[cR>>2]=0;c[c$>>2]=0;if(((c_^128^cW)&128&(cW^cV)|0)!=0){c[cR>>2]=1}if((cV&65280|0)!=0){c[c$>>2]=1}c0=cV&255}else{cV=(cW&15)+(c_&15)+cZ|0;cZ=(cW&240)+(c_&240)|0;cR=b+36|0;c[cR>>2]=0;c[c$>>2]=0;if((cV|0)>9){c1=cV+6|0;c2=cZ+16|0}else{c1=cV;c2=cZ}if(((c_^128^cW)&128&(cW^c2)|0)!=0){c[cR>>2]=1}cR=(c2|0)>144?c2+96|0:c2;if((cR&65280|0)!=0){c[c$>>2]=1}c0=cR&240|c1&15}c[cY>>2]=c0;c[b+52>>2]=(c0|0)==0;c[b+32>>2]=c0&128;i=e;return};case 115:{c[135448]=(c[135448]|0)+6;c0=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=c0,v)|0)|0;i=v;c0=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=c0,v)|0)|0;i=v;i=e;return};case 116:{c[135448]=(c[135448]|0)+16;c0=c[r>>2]|0;if((c0|0)<64512){cY=c[b+64>>2]|0;c3=a[cY+c0|0]|0;c4=c0;c5=cY}else{cY=c[b>>2]|0;c1=gj[c[(c[cY>>2]|0)+16>>2]&127](cY,c0)|0;c3=c1;c4=c[r>>2]|0;c5=c[b+64>>2]|0}c1=(c3&255)+(c[b+8>>2]|0)|0;c[r>>2]=c4+1;c4=c1&255;c[b+24>>2]=c4;a[c5+c4|0]=0;i=e;return};case 117:{c[135448]=(c[135448]|0)+16;c4=c[r>>2]|0;if((c4|0)<64512){c5=c[b+64>>2]|0;c6=a[c5+c4|0]|0;c7=c4;c8=c5}else{c5=c[b>>2]|0;c1=gj[c[(c[c5>>2]|0)+16>>2]&127](c5,c4)|0;c6=c1;c7=c[r>>2]|0;c8=c[b+64>>2]|0}c1=(c6&255)+(c[b+8>>2]|0)|0;c[r>>2]=c7+1;c7=c1&255;c[b+24>>2]=c7;c1=d[c8+c7|0]|0;c7=b+56|0;c8=(c[c7>>2]|0)!=0|0;c6=b+4|0;c4=c[c6>>2]|0;if((c[b+44>>2]|0)==0){c5=c4+c1+c8|0;c3=b+36|0;c[c3>>2]=0;c[c7>>2]=0;if(((c1^128^c4)&128&(c4^c5)|0)!=0){c[c3>>2]=1}if((c5&65280|0)!=0){c[c7>>2]=1}c9=c5&255}else{c5=(c4&15)+(c1&15)+c8|0;c8=(c4&240)+(c1&240)|0;c3=b+36|0;c[c3>>2]=0;c[c7>>2]=0;if((c5|0)>9){da=c5+6|0;db=c8+16|0}else{da=c5;db=c8}if(((c1^128^c4)&128&(c4^db)|0)!=0){c[c3>>2]=1}c3=(db|0)>144?db+96|0:db;if((c3&65280|0)!=0){c[c7>>2]=1}c9=c3&240|da&15}c[c6>>2]=c9;c[b+52>>2]=(c9|0)==0;c[b+32>>2]=c9&128;i=e;return};case 118:{c[135448]=(c[135448]|0)+26;c9=c[r>>2]|0;if((c9|0)<64512){c6=c[b+64>>2]|0;dc=a[c6+c9|0]|0;dd=c9;de=c6}else{c6=c[b>>2]|0;da=gj[c[(c[c6>>2]|0)+16>>2]&127](c6,c9)|0;dc=da;dd=c[r>>2]|0;de=c[b+64>>2]|0}da=(dc&255)+(c[b+8>>2]|0)|0;c[r>>2]=dd+1;dd=da&255;c[b+24>>2]=dd;da=d[de+dd|0]|0;de=b+56|0;dc=c[de>>2]|0;c[de>>2]=da&1;de=(dc|0)!=0?128:0;dc=de|da>>>1;a[(c[b+64>>2]|0)+dd|0]=dc&255;c[b+52>>2]=(dc|0)==0;c[b+32>>2]=de;i=e;return};case 119:{c[135448]=(c[135448]|0)+21;de=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=de,v)|0)|0;i=v;de=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=de,v)|0)|0;i=v;i=e;return};case 120:{c[135448]=(c[135448]|0)+6;c[b+48>>2]=1;i=e;return};case 121:{c[135448]=(c[135448]|0)+16;de=c[r>>2]|0;if((de|0)<64512){dc=c[b+64>>2]|0;df=(d[dc+(de+1)|0]|0)<<8|(d[dc+de|0]|0);dg=de}else{dc=c[b>>2]|0;dd=(gj[c[(c[dc>>2]|0)+24>>2]&127](dc,de)|0)&65535;df=dd;dg=c[r>>2]|0}c[r>>2]=dg+2;dg=df+(c[b+12>>2]|0)&65535;c[b+24>>2]=dg;if(dg>>>0<64512){dh=a[(c[b+64>>2]|0)+dg|0]|0}else{df=c[b>>2]|0;dh=gj[c[(c[df>>2]|0)+16>>2]&127](df,dg)|0}dg=dh&255;dh=b+56|0;df=(c[dh>>2]|0)!=0|0;dd=b+4|0;de=c[dd>>2]|0;if((c[b+44>>2]|0)==0){dc=de+dg+df|0;da=b+36|0;c[da>>2]=0;c[dh>>2]=0;if(((dg^128^de)&128&(de^dc)|0)!=0){c[da>>2]=1}if((dc&65280|0)!=0){c[dh>>2]=1}di=dc&255}else{dc=(de&15)+(dg&15)+df|0;df=(de&240)+(dg&240)|0;da=b+36|0;c[da>>2]=0;c[dh>>2]=0;if((dc|0)>9){dj=dc+6|0;dk=df+16|0}else{dj=dc;dk=df}if(((dg^128^de)&128&(de^dk)|0)!=0){c[da>>2]=1}da=(dk|0)>144?dk+96|0:dk;if((da&65280|0)!=0){c[dh>>2]=1}di=da&240|dj&15}c[dd>>2]=di;c[b+52>>2]=(di|0)==0;c[b+32>>2]=di&128;i=e;return};case 122:{c[135448]=(c[135448]|0)+16;di=b+16|0;dd=(c[di>>2]|0)+1&255;c[di>>2]=dd;di=a[(c[b+64>>2]|0)+(dd|256)|0]|0;dd=di&255;c[b+12>>2]=dd;c[b+52>>2]=di<<24>>24==0;c[b+32>>2]=dd&128;i=e;return};case 123:{c[135448]=(c[135448]|0)+6;dd=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dd,v)|0)|0;i=v;dd=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dd,v)|0)|0;i=v;i=e;return};case 124:{c[135448]=(c[135448]|0)+26;dd=c[r>>2]|0;if((dd|0)<64512){di=c[b+64>>2]|0;dl=(d[di+(dd+1)|0]|0)<<8|(d[di+dd|0]|0);dm=dd}else{di=c[b>>2]|0;dj=(gj[c[(c[di>>2]|0)+24>>2]&127](di,dd)|0)&65535;dl=dj;dm=c[r>>2]|0}dj=b+24|0;c[r>>2]=dm+2;dm=dl+(c[b+8>>2]|0)&65535;c[dj>>2]=dm;if(dm>>>0<64512){dl=c[b+64>>2]|0;dn=(d[dl+(dm+1)|0]|0)<<8|(d[dl+dm|0]|0)}else{dl=c[b>>2]|0;dn=(gj[c[(c[dl>>2]|0)+24>>2]&127](dl,dm)|0)&65535}c[dj>>2]=dn;c[r>>2]=dn;i=e;return};case 125:{c[135448]=(c[135448]|0)+16;dn=c[r>>2]|0;if((dn|0)<64512){dj=c[b+64>>2]|0;dp=(d[dj+(dn+1)|0]|0)<<8|(d[dj+dn|0]|0);dq=dn}else{dj=c[b>>2]|0;dm=(gj[c[(c[dj>>2]|0)+24>>2]&127](dj,dn)|0)&65535;dp=dm;dq=c[r>>2]|0}c[r>>2]=dq+2;dq=dp+(c[b+8>>2]|0)&65535;c[b+24>>2]=dq;if(dq>>>0<64512){dr=a[(c[b+64>>2]|0)+dq|0]|0}else{dp=c[b>>2]|0;dr=gj[c[(c[dp>>2]|0)+16>>2]&127](dp,dq)|0}dq=dr&255;dr=b+56|0;dp=(c[dr>>2]|0)!=0|0;dm=b+4|0;dn=c[dm>>2]|0;if((c[b+44>>2]|0)==0){dj=dn+dq+dp|0;dl=b+36|0;c[dl>>2]=0;c[dr>>2]=0;if(((dq^128^dn)&128&(dn^dj)|0)!=0){c[dl>>2]=1}if((dj&65280|0)!=0){c[dr>>2]=1}ds=dj&255}else{dj=(dn&15)+(dq&15)+dp|0;dp=(dn&240)+(dq&240)|0;dl=b+36|0;c[dl>>2]=0;c[dr>>2]=0;if((dj|0)>9){dt=dj+6|0;du=dp+16|0}else{dt=dj;du=dp}if(((dq^128^dn)&128&(dn^du)|0)!=0){c[dl>>2]=1}dl=(du|0)>144?du+96|0:du;if((dl&65280|0)!=0){c[dr>>2]=1}ds=dl&240|dt&15}c[dm>>2]=ds;c[b+52>>2]=(ds|0)==0;c[b+32>>2]=ds&128;i=e;return};case 126:{c[135448]=(c[135448]|0)+31;ds=c[r>>2]|0;if((ds|0)<64512){dm=c[b+64>>2]|0;dv=(d[dm+(ds+1)|0]|0)<<8|(d[dm+ds|0]|0);dw=ds}else{dm=c[b>>2]|0;dt=(gj[c[(c[dm>>2]|0)+24>>2]&127](dm,ds)|0)&65535;dv=dt;dw=c[r>>2]|0}dt=b+24|0;c[r>>2]=dw+2;dw=dv+(c[b+8>>2]|0)&65535;c[dt>>2]=dw;if(dw>>>0<64512){dx=a[(c[b+64>>2]|0)+dw|0]|0;dy=dw}else{dv=c[b>>2]|0;ds=gj[c[(c[dv>>2]|0)+16>>2]&127](dv,dw)|0;dx=ds;dy=c[dt>>2]|0}dt=dx&255;dx=b+56|0;ds=c[dx>>2]|0;c[dx>>2]=dt&1;dx=(ds|0)!=0?128:0;ds=dx|dt>>>1;if((dy|0)<64512){a[(c[b+64>>2]|0)+dy|0]=ds&255}else{dt=c[b>>2]|0;go[c[(c[dt>>2]|0)+12>>2]&127](dt,dy,ds&255)}c[b+52>>2]=(ds|0)==0;c[b+32>>2]=dx;i=e;return};case 127:{c[135448]=(c[135448]|0)+21;dx=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dx,v)|0)|0;i=v;dx=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dx,v)|0)|0;i=v;i=e;return};case 128:{c[135448]=(c[135448]|0)+11;dx=c[r>>2]|0;if((dx|0)<64512){dz=a[(c[b+64>>2]|0)+dx|0]|0;dA=dx}else{ds=c[b>>2]|0;dy=gj[c[(c[ds>>2]|0)+16>>2]&127](ds,dx)|0;dz=dy;dA=c[r>>2]|0}c[r>>2]=dA+1+(dz<<24>>24)&65535;i=e;return};case 129:{c[135448]=(c[135448]|0)+26;dz=c[r>>2]|0;if((dz|0)<64512){dA=c[b+64>>2]|0;dB=a[dA+dz|0]|0;dC=dz;dD=dA}else{dA=c[b>>2]|0;dy=gj[c[(c[dA>>2]|0)+16>>2]&127](dA,dz)|0;dB=dy;dC=c[r>>2]|0;dD=c[b+64>>2]|0}dy=b+24|0;c[r>>2]=dC+1;dC=(c[b+8>>2]|0)+(dB&255)&255;c[dy>>2]=dC;dB=(d[dD+(dC+1)|0]|0)<<8|(d[dD+dC|0]|0);c[dy>>2]=dB;if(dB>>>0<64512){a[(c[b+64>>2]|0)+dB|0]=c[b+4>>2]&255;i=e;return}else{dy=c[b>>2]|0;go[c[(c[dy>>2]|0)+12>>2]&127](dy,dB,c[b+4>>2]&255);i=e;return}break};case 130:{c[135448]=(c[135448]|0)+6;dB=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dB,v)|0)|0;i=v;dB=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dB,v)|0)|0;i=v;i=e;return};case 131:{c[135448]=(c[135448]|0)+6;dB=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dB,v)|0)|0;i=v;dB=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dB,v)|0)|0;i=v;i=e;return};case 132:{c[135448]=(c[135448]|0)+11;dB=c[r>>2]|0;if((dB|0)<64512){dy=b+64|0;dE=a[(c[dy>>2]|0)+dB|0]|0;dF=dB;dG=dy}else{dy=c[b>>2]|0;dC=gj[c[(c[dy>>2]|0)+16>>2]&127](dy,dB)|0;dE=dC;dF=c[r>>2]|0;dG=b+64|0}dC=dE&255;c[b+24>>2]=dC;c[r>>2]=dF+1;a[(c[dG>>2]|0)+dC|0]=c[b+12>>2]&255;i=e;return};case 133:{c[135448]=(c[135448]|0)+11;dC=c[r>>2]|0;if((dC|0)<64512){dG=b+64|0;dH=a[(c[dG>>2]|0)+dC|0]|0;dI=dC;dJ=dG}else{dG=c[b>>2]|0;dF=gj[c[(c[dG>>2]|0)+16>>2]&127](dG,dC)|0;dH=dF;dI=c[r>>2]|0;dJ=b+64|0}dF=dH&255;c[b+24>>2]=dF;c[r>>2]=dI+1;a[(c[dJ>>2]|0)+dF|0]=c[b+4>>2]&255;i=e;return};case 134:{c[135448]=(c[135448]|0)+11;dF=c[r>>2]|0;if((dF|0)<64512){dJ=b+64|0;dK=a[(c[dJ>>2]|0)+dF|0]|0;dL=dF;dM=dJ}else{dJ=c[b>>2]|0;dI=gj[c[(c[dJ>>2]|0)+16>>2]&127](dJ,dF)|0;dK=dI;dL=c[r>>2]|0;dM=b+64|0}dI=dK&255;c[b+24>>2]=dI;c[r>>2]=dL+1;a[(c[dM>>2]|0)+dI|0]=c[b+8>>2]&255;i=e;return};case 135:{c[135448]=(c[135448]|0)+21;dI=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dI,v)|0)|0;i=v;dI=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dI,v)|0)|0;i=v;i=e;return};case 136:{c[135448]=(c[135448]|0)+6;dI=b+12|0;dM=(c[dI>>2]|0)+255|0;dL=dM&255;c[dI>>2]=dL;c[b+52>>2]=(dL|0)==0;c[b+32>>2]=dM&128;i=e;return};case 137:{c[135448]=(c[135448]|0)+6;dM=c[r>>2]|0;c[b+24>>2]=dM;c[r>>2]=dM+1;if((dM|0)<64512){dN=a[(c[b+64>>2]|0)+dM|0]|0}else{dL=c[b>>2]|0;dN=gj[c[(c[dL>>2]|0)+16>>2]&127](dL,dM)|0}dM=dN&255;c[b+52>>2]=(c[b+4>>2]&dM|0)==0;if((c[s>>2]|0)==137){i=e;return}c[b+32>>2]=dM&128;c[b+36>>2]=dM&64;i=e;return};case 138:{c[135448]=(c[135448]|0)+6;dM=c[b+8>>2]|0;c[b+4>>2]=dM;c[b+52>>2]=(dM|0)==0;c[b+32>>2]=dM&128;i=e;return};case 139:{c[135448]=(c[135448]|0)+6;dM=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dM,v)|0)|0;i=v;dM=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dM,v)|0)|0;i=v;i=e;return};case 140:{c[135448]=(c[135448]|0)+16;dM=c[r>>2]|0;if((dM|0)<64512){dN=c[b+64>>2]|0;dO=(d[dN+(dM+1)|0]|0)<<8|(d[dN+dM|0]|0);dP=dM}else{dN=c[b>>2]|0;dL=(gj[c[(c[dN>>2]|0)+24>>2]&127](dN,dM)|0)&65535;dO=dL;dP=c[r>>2]|0}c[b+24>>2]=dO;c[r>>2]=dP+2;if((dO|0)<64512){a[(c[b+64>>2]|0)+dO|0]=c[b+12>>2]&255;i=e;return}else{dP=c[b>>2]|0;go[c[(c[dP>>2]|0)+12>>2]&127](dP,dO,c[b+12>>2]&255);i=e;return}break};case 141:{c[135448]=(c[135448]|0)+16;dO=c[r>>2]|0;if((dO|0)<64512){dP=c[b+64>>2]|0;dQ=(d[dP+(dO+1)|0]|0)<<8|(d[dP+dO|0]|0);dR=dO}else{dP=c[b>>2]|0;dL=(gj[c[(c[dP>>2]|0)+24>>2]&127](dP,dO)|0)&65535;dQ=dL;dR=c[r>>2]|0}c[b+24>>2]=dQ;c[r>>2]=dR+2;if((dQ|0)<64512){a[(c[b+64>>2]|0)+dQ|0]=c[b+4>>2]&255;i=e;return}else{dR=c[b>>2]|0;go[c[(c[dR>>2]|0)+12>>2]&127](dR,dQ,c[b+4>>2]&255);i=e;return}break};case 142:{c[135448]=(c[135448]|0)+16;dQ=c[r>>2]|0;if((dQ|0)<64512){dR=c[b+64>>2]|0;dS=(d[dR+(dQ+1)|0]|0)<<8|(d[dR+dQ|0]|0);dT=dQ}else{dR=c[b>>2]|0;dL=(gj[c[(c[dR>>2]|0)+24>>2]&127](dR,dQ)|0)&65535;dS=dL;dT=c[r>>2]|0}c[b+24>>2]=dS;c[r>>2]=dT+2;if((dS|0)<64512){a[(c[b+64>>2]|0)+dS|0]=c[b+8>>2]&255;i=e;return}else{dT=c[b>>2]|0;go[c[(c[dT>>2]|0)+12>>2]&127](dT,dS,c[b+8>>2]&255);i=e;return}break};case 143:{c[135448]=(c[135448]|0)+21;dS=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dS,v)|0)|0;i=v;dS=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=dS,v)|0)|0;i=v;i=e;return};case 144:{c[135448]=(c[135448]|0)+6;dS=c[r>>2]|0;if((c[b+56>>2]|0)!=0){c[r>>2]=dS+1&65535;i=e;return}if((dS|0)<64512){dU=a[(c[b+64>>2]|0)+dS|0]|0;dV=dS}else{dT=c[b>>2]|0;dL=gj[c[(c[dT>>2]|0)+16>>2]&127](dT,dS)|0;dU=dL;dV=c[r>>2]|0}c[r>>2]=dV+1+(dU<<24>>24)&65535;i=e;return};case 145:{c[135448]=(c[135448]|0)+26;dU=c[r>>2]|0;if((dU|0)<64512){dV=b+64|0;dW=a[(c[dV>>2]|0)+dU|0]|0;dX=dU;dY=dV}else{dV=c[b>>2]|0;dL=gj[c[(c[dV>>2]|0)+16>>2]&127](dV,dU)|0;dW=dL;dX=c[r>>2]|0;dY=b+64|0}dL=dW&255;dW=b+24|0;c[dW>>2]=dL;c[r>>2]=dX+1;dX=c[dY>>2]|0;dY=(c[b+12>>2]|0)+((d[dX+(dL+1)|0]|0)<<8|(d[dX+dL|0]|0))&65535;c[dW>>2]=dY;if(dY>>>0<64512){a[dX+dY|0]=c[b+4>>2]&255;i=e;return}else{dX=c[b>>2]|0;go[c[(c[dX>>2]|0)+12>>2]&127](dX,dY,c[b+4>>2]&255);i=e;return}break};case 146:{c[135448]=(c[135448]|0)+21;dY=c[r>>2]|0;if((dY|0)<64512){dX=b+64|0;dZ=a[(c[dX>>2]|0)+dY|0]|0;d_=dY;d$=dX}else{dX=c[b>>2]|0;dW=gj[c[(c[dX>>2]|0)+16>>2]&127](dX,dY)|0;dZ=dW;d_=c[r>>2]|0;d$=b+64|0}dW=dZ&255;dZ=b+24|0;c[dZ>>2]=dW;c[r>>2]=d_+1;d_=c[d$>>2]|0;d$=(d[d_+(dW+1)|0]|0)<<8|(d[d_+dW|0]|0);c[dZ>>2]=d$;if(d$>>>0<64512){a[d_+d$|0]=c[b+4>>2]&255;i=e;return}else{d_=c[b>>2]|0;go[c[(c[d_>>2]|0)+12>>2]&127](d_,d$,c[b+4>>2]&255);i=e;return}break};case 147:{c[135448]=(c[135448]|0)+6;d$=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=d$,v)|0)|0;i=v;d$=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=d$,v)|0)|0;i=v;i=e;return};case 148:{c[135448]=(c[135448]|0)+16;d$=c[r>>2]|0;if((d$|0)<64512){d_=c[b+64>>2]|0;d0=a[d_+d$|0]|0;d1=d$;d2=d_}else{d_=c[b>>2]|0;dZ=gj[c[(c[d_>>2]|0)+16>>2]&127](d_,d$)|0;d0=dZ;d1=c[r>>2]|0;d2=c[b+64>>2]|0}dZ=(d0&255)+(c[b+8>>2]|0)|0;c[r>>2]=d1+1;d1=dZ&255;c[b+24>>2]=d1;a[d2+d1|0]=c[b+12>>2]&255;i=e;return};case 149:{c[135448]=(c[135448]|0)+16;d1=c[r>>2]|0;if((d1|0)<64512){d2=c[b+64>>2]|0;d3=a[d2+d1|0]|0;d4=d1;d5=d2}else{d2=c[b>>2]|0;dZ=gj[c[(c[d2>>2]|0)+16>>2]&127](d2,d1)|0;d3=dZ;d4=c[r>>2]|0;d5=c[b+64>>2]|0}dZ=(d3&255)+(c[b+8>>2]|0)|0;c[r>>2]=d4+1;d4=dZ&255;c[b+24>>2]=d4;a[d5+d4|0]=c[b+4>>2]&255;i=e;return};case 150:{c[135448]=(c[135448]|0)+16;d4=c[r>>2]|0;if((d4|0)<64512){d5=c[b+64>>2]|0;d6=a[d5+d4|0]|0;d7=d4;d8=d5}else{d5=c[b>>2]|0;dZ=gj[c[(c[d5>>2]|0)+16>>2]&127](d5,d4)|0;d6=dZ;d7=c[r>>2]|0;d8=c[b+64>>2]|0}dZ=(d6&255)+(c[b+12>>2]|0)|0;c[r>>2]=d7+1;d7=dZ&255;c[b+24>>2]=d7;a[d8+d7|0]=c[b+8>>2]&255;i=e;return};case 151:{c[135448]=(c[135448]|0)+21;d7=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=d7,v)|0)|0;i=v;d7=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=d7,v)|0)|0;i=v;i=e;return};case 152:{c[135448]=(c[135448]|0)+6;d7=c[b+12>>2]|0;c[b+4>>2]=d7;c[b+52>>2]=(d7|0)==0;c[b+32>>2]=d7&128;i=e;return};case 153:{c[135448]=(c[135448]|0)+21;d7=c[r>>2]|0;if((d7|0)<64512){d8=c[b+64>>2]|0;d9=(d[d8+(d7+1)|0]|0)<<8|(d[d8+d7|0]|0);ea=d7}else{d8=c[b>>2]|0;dZ=(gj[c[(c[d8>>2]|0)+24>>2]&127](d8,d7)|0)&65535;d9=dZ;ea=c[r>>2]|0}c[r>>2]=ea+2;ea=d9+(c[b+12>>2]|0)&65535;c[b+24>>2]=ea;if(ea>>>0<64512){a[(c[b+64>>2]|0)+ea|0]=c[b+4>>2]&255;i=e;return}else{d9=c[b>>2]|0;go[c[(c[d9>>2]|0)+12>>2]&127](d9,ea,c[b+4>>2]&255);i=e;return}break};case 154:{c[135448]=(c[135448]|0)+6;c[b+16>>2]=c[b+8>>2];i=e;return};case 155:{c[135448]=(c[135448]|0)+6;ea=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ea,v)|0)|0;i=v;ea=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ea,v)|0)|0;i=v;i=e;return};case 156:{c[135448]=(c[135448]|0)+16;ea=c[r>>2]|0;if((ea|0)<64512){d9=c[b+64>>2]|0;eb=(d[d9+(ea+1)|0]|0)<<8|(d[d9+ea|0]|0);ec=ea}else{d9=c[b>>2]|0;dZ=(gj[c[(c[d9>>2]|0)+24>>2]&127](d9,ea)|0)&65535;eb=dZ;ec=c[r>>2]|0}c[b+24>>2]=eb;c[r>>2]=ec+2;if((eb|0)<64512){a[(c[b+64>>2]|0)+eb|0]=0;i=e;return}else{ec=c[b>>2]|0;go[c[(c[ec>>2]|0)+12>>2]&127](ec,eb,0);i=e;return}break};case 157:{c[135448]=(c[135448]|0)+21;eb=c[r>>2]|0;if((eb|0)<64512){ec=c[b+64>>2]|0;ed=(d[ec+(eb+1)|0]|0)<<8|(d[ec+eb|0]|0);ee=eb}else{ec=c[b>>2]|0;dZ=(gj[c[(c[ec>>2]|0)+24>>2]&127](ec,eb)|0)&65535;ed=dZ;ee=c[r>>2]|0}c[r>>2]=ee+2;ee=ed+(c[b+8>>2]|0)&65535;c[b+24>>2]=ee;if(ee>>>0<64512){a[(c[b+64>>2]|0)+ee|0]=c[b+4>>2]&255;i=e;return}else{ed=c[b>>2]|0;go[c[(c[ed>>2]|0)+12>>2]&127](ed,ee,c[b+4>>2]&255);i=e;return}break};case 158:{c[135448]=(c[135448]|0)+21;ee=c[r>>2]|0;if((ee|0)<64512){ed=c[b+64>>2]|0;ef=(d[ed+(ee+1)|0]|0)<<8|(d[ed+ee|0]|0);eg=ee}else{ed=c[b>>2]|0;dZ=(gj[c[(c[ed>>2]|0)+24>>2]&127](ed,ee)|0)&65535;ef=dZ;eg=c[r>>2]|0}c[r>>2]=eg+2;eg=ef+(c[b+8>>2]|0)&65535;c[b+24>>2]=eg;if(eg>>>0<64512){a[(c[b+64>>2]|0)+eg|0]=0;i=e;return}else{ef=c[b>>2]|0;go[c[(c[ef>>2]|0)+12>>2]&127](ef,eg,0);i=e;return}break};case 159:{c[135448]=(c[135448]|0)+21;eg=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=eg,v)|0)|0;i=v;eg=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=eg,v)|0)|0;i=v;i=e;return};case 160:{c[135448]=(c[135448]|0)+6;eg=c[r>>2]|0;c[b+24>>2]=eg;c[r>>2]=eg+1;if((eg|0)<64512){eh=a[(c[b+64>>2]|0)+eg|0]|0}else{ef=c[b>>2]|0;eh=gj[c[(c[ef>>2]|0)+16>>2]&127](ef,eg)|0}eg=eh&255;c[b+12>>2]=eg;c[b+52>>2]=eh<<24>>24==0;c[b+32>>2]=eg&128;i=e;return};case 161:{c[135448]=(c[135448]|0)+26;eg=c[r>>2]|0;if((eg|0)<64512){eh=c[b+64>>2]|0;ei=a[eh+eg|0]|0;ej=eg;ek=eh}else{eh=c[b>>2]|0;ef=gj[c[(c[eh>>2]|0)+16>>2]&127](eh,eg)|0;ei=ef;ej=c[r>>2]|0;ek=c[b+64>>2]|0}ef=b+24|0;c[r>>2]=ej+1;ej=(c[b+8>>2]|0)+(ei&255)&255;c[ef>>2]=ej;ei=(d[ek+(ej+1)|0]|0)<<8|(d[ek+ej|0]|0);c[ef>>2]=ei;if(ei>>>0<64512){el=a[(c[b+64>>2]|0)+ei|0]|0}else{ef=c[b>>2]|0;el=gj[c[(c[ef>>2]|0)+16>>2]&127](ef,ei)|0}ei=el&255;c[b+4>>2]=ei;c[b+52>>2]=el<<24>>24==0;c[b+32>>2]=ei&128;i=e;return};case 162:{c[135448]=(c[135448]|0)+6;ei=c[r>>2]|0;c[b+24>>2]=ei;c[r>>2]=ei+1;if((ei|0)<64512){em=a[(c[b+64>>2]|0)+ei|0]|0}else{el=c[b>>2]|0;em=gj[c[(c[el>>2]|0)+16>>2]&127](el,ei)|0}ei=em&255;c[b+8>>2]=ei;c[b+52>>2]=em<<24>>24==0;c[b+32>>2]=ei&128;i=e;return};case 163:{c[135448]=(c[135448]|0)+6;ei=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ei,v)|0)|0;i=v;ei=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ei,v)|0)|0;i=v;i=e;return};case 164:{c[135448]=(c[135448]|0)+11;ei=c[r>>2]|0;if((ei|0)<64512){em=b+64|0;en=a[(c[em>>2]|0)+ei|0]|0;eo=ei;ep=em}else{em=c[b>>2]|0;el=gj[c[(c[em>>2]|0)+16>>2]&127](em,ei)|0;en=el;eo=c[r>>2]|0;ep=b+64|0}el=en&255;c[b+24>>2]=el;c[r>>2]=eo+1;eo=a[(c[ep>>2]|0)+el|0]|0;el=eo&255;c[b+12>>2]=el;c[b+52>>2]=eo<<24>>24==0;c[b+32>>2]=el&128;i=e;return};case 165:{c[135448]=(c[135448]|0)+11;el=c[r>>2]|0;if((el|0)<64512){eo=b+64|0;eq=a[(c[eo>>2]|0)+el|0]|0;er=el;es=eo}else{eo=c[b>>2]|0;ep=gj[c[(c[eo>>2]|0)+16>>2]&127](eo,el)|0;eq=ep;er=c[r>>2]|0;es=b+64|0}ep=eq&255;c[b+24>>2]=ep;c[r>>2]=er+1;er=a[(c[es>>2]|0)+ep|0]|0;ep=er&255;c[b+4>>2]=ep;c[b+52>>2]=er<<24>>24==0;c[b+32>>2]=ep&128;i=e;return};case 166:{c[135448]=(c[135448]|0)+11;ep=c[r>>2]|0;if((ep|0)<64512){er=b+64|0;et=a[(c[er>>2]|0)+ep|0]|0;eu=ep;ev=er}else{er=c[b>>2]|0;es=gj[c[(c[er>>2]|0)+16>>2]&127](er,ep)|0;et=es;eu=c[r>>2]|0;ev=b+64|0}es=et&255;c[b+24>>2]=es;c[r>>2]=eu+1;eu=a[(c[ev>>2]|0)+es|0]|0;es=eu&255;c[b+8>>2]=es;c[b+52>>2]=eu<<24>>24==0;c[b+32>>2]=es&128;i=e;return};case 167:{c[135448]=(c[135448]|0)+21;es=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=es,v)|0)|0;i=v;es=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=es,v)|0)|0;i=v;i=e;return};case 168:{c[135448]=(c[135448]|0)+6;es=c[b+4>>2]|0;c[b+12>>2]=es;c[b+52>>2]=(es|0)==0;c[b+32>>2]=es&128;i=e;return};case 169:{c[135448]=(c[135448]|0)+6;es=c[r>>2]|0;c[b+24>>2]=es;c[r>>2]=es+1;if((es|0)<64512){ew=a[(c[b+64>>2]|0)+es|0]|0}else{eu=c[b>>2]|0;ew=gj[c[(c[eu>>2]|0)+16>>2]&127](eu,es)|0}es=ew&255;c[b+4>>2]=es;c[b+52>>2]=ew<<24>>24==0;c[b+32>>2]=es&128;i=e;return};case 170:{c[135448]=(c[135448]|0)+6;es=c[b+4>>2]|0;c[b+8>>2]=es;c[b+52>>2]=(es|0)==0;c[b+32>>2]=es&128;i=e;return};case 171:{c[135448]=(c[135448]|0)+6;es=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=es,v)|0)|0;i=v;es=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=es,v)|0)|0;i=v;i=e;return};case 172:{c[135448]=(c[135448]|0)+16;es=c[r>>2]|0;if((es|0)<64512){ew=c[b+64>>2]|0;ex=(d[ew+(es+1)|0]|0)<<8|(d[ew+es|0]|0);ey=es}else{ew=c[b>>2]|0;eu=(gj[c[(c[ew>>2]|0)+24>>2]&127](ew,es)|0)&65535;ex=eu;ey=c[r>>2]|0}c[b+24>>2]=ex;c[r>>2]=ey+2;if((ex|0)<64512){ez=a[(c[b+64>>2]|0)+ex|0]|0}else{ey=c[b>>2]|0;ez=gj[c[(c[ey>>2]|0)+16>>2]&127](ey,ex)|0}ex=ez&255;c[b+12>>2]=ex;c[b+52>>2]=ez<<24>>24==0;c[b+32>>2]=ex&128;i=e;return};case 173:{c[135448]=(c[135448]|0)+16;ex=c[r>>2]|0;if((ex|0)<64512){ez=c[b+64>>2]|0;eA=(d[ez+(ex+1)|0]|0)<<8|(d[ez+ex|0]|0);eB=ex}else{ez=c[b>>2]|0;ey=(gj[c[(c[ez>>2]|0)+24>>2]&127](ez,ex)|0)&65535;eA=ey;eB=c[r>>2]|0}c[b+24>>2]=eA;c[r>>2]=eB+2;if((eA|0)<64512){eC=a[(c[b+64>>2]|0)+eA|0]|0}else{eB=c[b>>2]|0;eC=gj[c[(c[eB>>2]|0)+16>>2]&127](eB,eA)|0}eA=eC&255;c[b+4>>2]=eA;c[b+52>>2]=eC<<24>>24==0;c[b+32>>2]=eA&128;i=e;return};case 174:{c[135448]=(c[135448]|0)+16;eA=c[r>>2]|0;if((eA|0)<64512){eC=c[b+64>>2]|0;eD=(d[eC+(eA+1)|0]|0)<<8|(d[eC+eA|0]|0);eE=eA}else{eC=c[b>>2]|0;eB=(gj[c[(c[eC>>2]|0)+24>>2]&127](eC,eA)|0)&65535;eD=eB;eE=c[r>>2]|0}c[b+24>>2]=eD;c[r>>2]=eE+2;if((eD|0)<64512){eF=a[(c[b+64>>2]|0)+eD|0]|0}else{eE=c[b>>2]|0;eF=gj[c[(c[eE>>2]|0)+16>>2]&127](eE,eD)|0}eD=eF&255;c[b+8>>2]=eD;c[b+52>>2]=eF<<24>>24==0;c[b+32>>2]=eD&128;i=e;return};case 175:{c[135448]=(c[135448]|0)+21;eD=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=eD,v)|0)|0;i=v;eD=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=eD,v)|0)|0;i=v;i=e;return};case 176:{c[135448]=(c[135448]|0)+6;eD=c[r>>2]|0;if((c[b+56>>2]|0)==0){c[r>>2]=eD+1&65535;i=e;return}if((eD|0)<64512){eG=a[(c[b+64>>2]|0)+eD|0]|0;eH=eD}else{eF=c[b>>2]|0;eE=gj[c[(c[eF>>2]|0)+16>>2]&127](eF,eD)|0;eG=eE;eH=c[r>>2]|0}c[r>>2]=eH+1+(eG<<24>>24)&65535;i=e;return};case 177:{c[135448]=(c[135448]|0)+21;eG=c[r>>2]|0;if((eG|0)<64512){eH=b+64|0;eI=a[(c[eH>>2]|0)+eG|0]|0;eJ=eG;eK=eH}else{eH=c[b>>2]|0;eE=gj[c[(c[eH>>2]|0)+16>>2]&127](eH,eG)|0;eI=eE;eJ=c[r>>2]|0;eK=b+64|0}eE=eI&255;eI=b+24|0;c[eI>>2]=eE;c[r>>2]=eJ+1;eJ=c[eK>>2]|0;eK=(c[b+12>>2]|0)+((d[eJ+(eE+1)|0]|0)<<8|(d[eJ+eE|0]|0))&65535;c[eI>>2]=eK;if(eK>>>0<64512){eL=a[eJ+eK|0]|0}else{eJ=c[b>>2]|0;eL=gj[c[(c[eJ>>2]|0)+16>>2]&127](eJ,eK)|0}eK=eL&255;c[b+4>>2]=eK;c[b+52>>2]=eL<<24>>24==0;c[b+32>>2]=eK&128;i=e;return};case 178:{c[135448]=(c[135448]|0)+21;eK=c[r>>2]|0;if((eK|0)<64512){eL=b+64|0;eM=a[(c[eL>>2]|0)+eK|0]|0;eN=eK;eO=eL}else{eL=c[b>>2]|0;eJ=gj[c[(c[eL>>2]|0)+16>>2]&127](eL,eK)|0;eM=eJ;eN=c[r>>2]|0;eO=b+64|0}eJ=eM&255;eM=b+24|0;c[eM>>2]=eJ;c[r>>2]=eN+1;eN=c[eO>>2]|0;eO=(d[eN+(eJ+1)|0]|0)<<8|(d[eN+eJ|0]|0);c[eM>>2]=eO;if(eO>>>0<64512){eP=a[eN+eO|0]|0}else{eN=c[b>>2]|0;eP=gj[c[(c[eN>>2]|0)+16>>2]&127](eN,eO)|0}eO=eP&255;c[b+4>>2]=eO;c[b+52>>2]=eP<<24>>24==0;c[b+32>>2]=eO&128;i=e;return};case 179:{c[135448]=(c[135448]|0)+6;eO=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=eO,v)|0)|0;i=v;eO=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=eO,v)|0)|0;i=v;i=e;return};case 180:{c[135448]=(c[135448]|0)+16;eO=c[r>>2]|0;if((eO|0)<64512){eP=c[b+64>>2]|0;eR=a[eP+eO|0]|0;eS=eO;eT=eP}else{eP=c[b>>2]|0;eN=gj[c[(c[eP>>2]|0)+16>>2]&127](eP,eO)|0;eR=eN;eS=c[r>>2]|0;eT=c[b+64>>2]|0}eN=(eR&255)+(c[b+8>>2]|0)|0;c[r>>2]=eS+1;eS=eN&255;c[b+24>>2]=eS;eN=a[eT+eS|0]|0;eS=eN&255;c[b+12>>2]=eS;c[b+52>>2]=eN<<24>>24==0;c[b+32>>2]=eS&128;i=e;return};case 181:{c[135448]=(c[135448]|0)+16;eS=c[r>>2]|0;if((eS|0)<64512){eN=c[b+64>>2]|0;eU=a[eN+eS|0]|0;eV=eS;eW=eN}else{eN=c[b>>2]|0;eT=gj[c[(c[eN>>2]|0)+16>>2]&127](eN,eS)|0;eU=eT;eV=c[r>>2]|0;eW=c[b+64>>2]|0}eT=(eU&255)+(c[b+8>>2]|0)|0;c[r>>2]=eV+1;eV=eT&255;c[b+24>>2]=eV;eT=a[eW+eV|0]|0;eV=eT&255;c[b+4>>2]=eV;c[b+52>>2]=eT<<24>>24==0;c[b+32>>2]=eV&128;i=e;return};case 182:{c[135448]=(c[135448]|0)+16;eV=c[r>>2]|0;if((eV|0)<64512){eT=c[b+64>>2]|0;eX=a[eT+eV|0]|0;eY=eV;eZ=eT}else{eT=c[b>>2]|0;eW=gj[c[(c[eT>>2]|0)+16>>2]&127](eT,eV)|0;eX=eW;eY=c[r>>2]|0;eZ=c[b+64>>2]|0}eW=(eX&255)+(c[b+12>>2]|0)|0;c[r>>2]=eY+1;eY=eW&255;c[b+24>>2]=eY;eW=a[eZ+eY|0]|0;eY=eW&255;c[b+8>>2]=eY;c[b+52>>2]=eW<<24>>24==0;c[b+32>>2]=eY&128;i=e;return};case 183:{c[135448]=(c[135448]|0)+21;eY=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=eY,v)|0)|0;i=v;eY=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=eY,v)|0)|0;i=v;i=e;return};case 184:{c[135448]=(c[135448]|0)+6;c[b+36>>2]=0;i=e;return};case 185:{c[135448]=(c[135448]|0)+16;eY=c[r>>2]|0;if((eY|0)<64512){eW=c[b+64>>2]|0;e_=(d[eW+(eY+1)|0]|0)<<8|(d[eW+eY|0]|0);e$=eY}else{eW=c[b>>2]|0;eZ=(gj[c[(c[eW>>2]|0)+24>>2]&127](eW,eY)|0)&65535;e_=eZ;e$=c[r>>2]|0}c[r>>2]=e$+2;e$=e_+(c[b+12>>2]|0)&65535;c[b+24>>2]=e$;if(e$>>>0<64512){e0=a[(c[b+64>>2]|0)+e$|0]|0}else{e_=c[b>>2]|0;e0=gj[c[(c[e_>>2]|0)+16>>2]&127](e_,e$)|0}e$=e0&255;c[b+4>>2]=e$;c[b+52>>2]=e0<<24>>24==0;c[b+32>>2]=e$&128;i=e;return};case 186:{c[135448]=(c[135448]|0)+6;e$=c[b+16>>2]|0;c[b+8>>2]=e$;c[b+52>>2]=(e$|0)==0;c[b+32>>2]=e$&128;i=e;return};case 187:{c[135448]=(c[135448]|0)+6;e$=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=e$,v)|0)|0;i=v;e$=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=e$,v)|0)|0;i=v;i=e;return};case 188:{c[135448]=(c[135448]|0)+16;e$=c[r>>2]|0;if((e$|0)<64512){e0=c[b+64>>2]|0;e1=(d[e0+(e$+1)|0]|0)<<8|(d[e0+e$|0]|0);e2=e$}else{e0=c[b>>2]|0;e_=(gj[c[(c[e0>>2]|0)+24>>2]&127](e0,e$)|0)&65535;e1=e_;e2=c[r>>2]|0}c[r>>2]=e2+2;e2=e1+(c[b+8>>2]|0)&65535;c[b+24>>2]=e2;if(e2>>>0<64512){e3=a[(c[b+64>>2]|0)+e2|0]|0}else{e1=c[b>>2]|0;e3=gj[c[(c[e1>>2]|0)+16>>2]&127](e1,e2)|0}e2=e3&255;c[b+12>>2]=e2;c[b+52>>2]=e3<<24>>24==0;c[b+32>>2]=e2&128;i=e;return};case 189:{c[135448]=(c[135448]|0)+16;e2=c[r>>2]|0;if((e2|0)<64512){e3=c[b+64>>2]|0;e4=(d[e3+(e2+1)|0]|0)<<8|(d[e3+e2|0]|0);e5=e2}else{e3=c[b>>2]|0;e1=(gj[c[(c[e3>>2]|0)+24>>2]&127](e3,e2)|0)&65535;e4=e1;e5=c[r>>2]|0}c[r>>2]=e5+2;e5=e4+(c[b+8>>2]|0)&65535;c[b+24>>2]=e5;if(e5>>>0<64512){e6=a[(c[b+64>>2]|0)+e5|0]|0}else{e4=c[b>>2]|0;e6=gj[c[(c[e4>>2]|0)+16>>2]&127](e4,e5)|0}e5=e6&255;c[b+4>>2]=e5;c[b+52>>2]=e6<<24>>24==0;c[b+32>>2]=e5&128;i=e;return};case 190:{c[135448]=(c[135448]|0)+16;e5=c[r>>2]|0;if((e5|0)<64512){e6=c[b+64>>2]|0;e7=(d[e6+(e5+1)|0]|0)<<8|(d[e6+e5|0]|0);e8=e5}else{e6=c[b>>2]|0;e4=(gj[c[(c[e6>>2]|0)+24>>2]&127](e6,e5)|0)&65535;e7=e4;e8=c[r>>2]|0}c[r>>2]=e8+2;e8=e7+(c[b+12>>2]|0)&65535;c[b+24>>2]=e8;if(e8>>>0<64512){e9=a[(c[b+64>>2]|0)+e8|0]|0}else{e7=c[b>>2]|0;e9=gj[c[(c[e7>>2]|0)+16>>2]&127](e7,e8)|0}e8=e9&255;c[b+8>>2]=e8;c[b+52>>2]=e9<<24>>24==0;c[b+32>>2]=e8&128;i=e;return};case 191:{c[135448]=(c[135448]|0)+16;e8=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=e8,v)|0)|0;i=v;e8=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=e8,v)|0)|0;i=v;i=e;return};case 192:{c[135448]=(c[135448]|0)+6;e8=c[r>>2]|0;c[b+24>>2]=e8;c[r>>2]=e8+1;if((e8|0)<64512){fa=a[(c[b+64>>2]|0)+e8|0]|0}else{e9=c[b>>2]|0;fa=gj[c[(c[e9>>2]|0)+16>>2]&127](e9,e8)|0}e8=fa&255;fa=b+56|0;c[fa>>2]=0;e9=c[b+12>>2]|0;if((e9|0)>=(e8|0)){c[fa>>2]=1}fa=e9-e8|0;c[b+52>>2]=(fa&255)<<24>>24==0;c[b+32>>2]=fa&128;i=e;return};case 193:{c[135448]=(c[135448]|0)+26;fa=c[r>>2]|0;if((fa|0)<64512){e8=c[b+64>>2]|0;fb=a[e8+fa|0]|0;fc=fa;fd=e8}else{e8=c[b>>2]|0;e9=gj[c[(c[e8>>2]|0)+16>>2]&127](e8,fa)|0;fb=e9;fc=c[r>>2]|0;fd=c[b+64>>2]|0}e9=b+24|0;c[r>>2]=fc+1;fc=(c[b+8>>2]|0)+(fb&255)&255;c[e9>>2]=fc;fb=(d[fd+(fc+1)|0]|0)<<8|(d[fd+fc|0]|0);c[e9>>2]=fb;if(fb>>>0<64512){fe=a[(c[b+64>>2]|0)+fb|0]|0}else{e9=c[b>>2]|0;fe=gj[c[(c[e9>>2]|0)+16>>2]&127](e9,fb)|0}fb=fe&255;fe=b+56|0;c[fe>>2]=0;e9=c[b+4>>2]|0;if((e9|0)>=(fb|0)){c[fe>>2]=1}fe=e9-fb|0;c[b+52>>2]=(fe&255)<<24>>24==0;c[b+32>>2]=fe&128;i=e;return};case 194:{c[135448]=(c[135448]|0)+6;fe=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fe,v)|0)|0;i=v;fe=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fe,v)|0)|0;i=v;i=e;return};case 195:{c[135448]=(c[135448]|0)+6;fe=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fe,v)|0)|0;i=v;fe=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fe,v)|0)|0;i=v;i=e;return};case 196:{c[135448]=(c[135448]|0)+11;fe=c[r>>2]|0;if((fe|0)<64512){fb=b+64|0;ff=a[(c[fb>>2]|0)+fe|0]|0;fg=fe;fh=fb}else{fb=c[b>>2]|0;e9=gj[c[(c[fb>>2]|0)+16>>2]&127](fb,fe)|0;ff=e9;fg=c[r>>2]|0;fh=b+64|0}e9=ff&255;c[b+24>>2]=e9;c[r>>2]=fg+1;fg=d[(c[fh>>2]|0)+e9|0]|0;e9=b+56|0;c[e9>>2]=0;fh=c[b+12>>2]|0;if((fh|0)>=(fg|0)){c[e9>>2]=1}e9=fh-fg|0;c[b+52>>2]=(e9&255)<<24>>24==0;c[b+32>>2]=e9&128;i=e;return};case 197:{c[135448]=(c[135448]|0)+11;e9=c[r>>2]|0;if((e9|0)<64512){fg=b+64|0;fi=a[(c[fg>>2]|0)+e9|0]|0;fj=e9;fk=fg}else{fg=c[b>>2]|0;fh=gj[c[(c[fg>>2]|0)+16>>2]&127](fg,e9)|0;fi=fh;fj=c[r>>2]|0;fk=b+64|0}fh=fi&255;c[b+24>>2]=fh;c[r>>2]=fj+1;fj=d[(c[fk>>2]|0)+fh|0]|0;fh=b+56|0;c[fh>>2]=0;fk=c[b+4>>2]|0;if((fk|0)>=(fj|0)){c[fh>>2]=1}fh=fk-fj|0;c[b+52>>2]=(fh&255)<<24>>24==0;c[b+32>>2]=fh&128;i=e;return};case 198:{c[135448]=(c[135448]|0)+21;fh=c[r>>2]|0;if((fh|0)<64512){fj=b+64|0;fl=a[(c[fj>>2]|0)+fh|0]|0;fm=fh;fn=fj}else{fj=c[b>>2]|0;fk=gj[c[(c[fj>>2]|0)+16>>2]&127](fj,fh)|0;fl=fk;fm=c[r>>2]|0;fn=b+64|0}fk=fl&255;c[b+24>>2]=fk;c[r>>2]=fm+1;fm=(c[fn>>2]|0)+fk|0;fk=(d[fm]|0)+255|0;a[fm]=fk&255;c[b+52>>2]=(fk&255|0)==0;c[b+32>>2]=fk&128;i=e;return};case 199:{c[135448]=(c[135448]|0)+21;fk=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fk,v)|0)|0;i=v;fk=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fk,v)|0)|0;i=v;i=e;return};case 200:{c[135448]=(c[135448]|0)+6;fk=b+12|0;fm=(c[fk>>2]|0)+1|0;fn=fm&255;c[fk>>2]=fn;c[b+52>>2]=(fn|0)==0;c[b+32>>2]=fm&128;i=e;return};case 201:{c[135448]=(c[135448]|0)+6;fm=c[r>>2]|0;c[b+24>>2]=fm;c[r>>2]=fm+1;if((fm|0)<64512){fo=a[(c[b+64>>2]|0)+fm|0]|0}else{fn=c[b>>2]|0;fo=gj[c[(c[fn>>2]|0)+16>>2]&127](fn,fm)|0}fm=fo&255;fo=b+56|0;c[fo>>2]=0;fn=c[b+4>>2]|0;if((fn|0)>=(fm|0)){c[fo>>2]=1}fo=fn-fm|0;c[b+52>>2]=(fo&255)<<24>>24==0;c[b+32>>2]=fo&128;i=e;return};case 202:{c[135448]=(c[135448]|0)+6;fo=b+8|0;fm=(c[fo>>2]|0)+255|0;fn=fm&255;c[fo>>2]=fn;c[b+52>>2]=(fn|0)==0;c[b+32>>2]=fm&128;i=e;return};case 203:{c[135448]=(c[135448]|0)+6;c[135452]=1;i=e;return};case 204:{c[135448]=(c[135448]|0)+16;fm=c[r>>2]|0;if((fm|0)<64512){fn=c[b+64>>2]|0;fp=(d[fn+(fm+1)|0]|0)<<8|(d[fn+fm|0]|0);fq=fm}else{fn=c[b>>2]|0;fo=(gj[c[(c[fn>>2]|0)+24>>2]&127](fn,fm)|0)&65535;fp=fo;fq=c[r>>2]|0}c[b+24>>2]=fp;c[r>>2]=fq+2;if((fp|0)<64512){fr=a[(c[b+64>>2]|0)+fp|0]|0}else{fq=c[b>>2]|0;fr=gj[c[(c[fq>>2]|0)+16>>2]&127](fq,fp)|0}fp=fr&255;fr=b+56|0;c[fr>>2]=0;fq=c[b+12>>2]|0;if((fq|0)>=(fp|0)){c[fr>>2]=1}fr=fq-fp|0;c[b+52>>2]=(fr&255)<<24>>24==0;c[b+32>>2]=fr&128;i=e;return};case 205:{c[135448]=(c[135448]|0)+16;fr=c[r>>2]|0;if((fr|0)<64512){fp=c[b+64>>2]|0;fs=(d[fp+(fr+1)|0]|0)<<8|(d[fp+fr|0]|0);ft=fr}else{fp=c[b>>2]|0;fq=(gj[c[(c[fp>>2]|0)+24>>2]&127](fp,fr)|0)&65535;fs=fq;ft=c[r>>2]|0}c[b+24>>2]=fs;c[r>>2]=ft+2;if((fs|0)<64512){fu=a[(c[b+64>>2]|0)+fs|0]|0}else{ft=c[b>>2]|0;fu=gj[c[(c[ft>>2]|0)+16>>2]&127](ft,fs)|0}fs=fu&255;fu=b+56|0;c[fu>>2]=0;ft=c[b+4>>2]|0;if((ft|0)>=(fs|0)){c[fu>>2]=1}fu=ft-fs|0;c[b+52>>2]=(fu&255)<<24>>24==0;c[b+32>>2]=fu&128;i=e;return};case 206:{c[135448]=(c[135448]|0)+26;fu=c[r>>2]|0;if((fu|0)<64512){fs=c[b+64>>2]|0;fv=(d[fs+(fu+1)|0]|0)<<8|(d[fs+fu|0]|0);fw=fu}else{fs=c[b>>2]|0;ft=(gj[c[(c[fs>>2]|0)+24>>2]&127](fs,fu)|0)&65535;fv=ft;fw=c[r>>2]|0}ft=b+24|0;c[ft>>2]=fv;c[r>>2]=fw+2;if((fv|0)<64512){fx=a[(c[b+64>>2]|0)+fv|0]|0;fy=fv}else{fw=c[b>>2]|0;fu=gj[c[(c[fw>>2]|0)+16>>2]&127](fw,fv)|0;fx=fu;fy=c[ft>>2]|0}ft=(fx&255)+255|0;if((fy|0)<64512){a[(c[b+64>>2]|0)+fy|0]=ft&255}else{fx=c[b>>2]|0;go[c[(c[fx>>2]|0)+12>>2]&127](fx,fy,ft&255)}c[b+52>>2]=(ft&255|0)==0;c[b+32>>2]=ft&128;i=e;return};case 207:{c[135448]=(c[135448]|0)+21;ft=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ft,v)|0)|0;i=v;ft=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ft,v)|0)|0;i=v;i=e;return};case 208:{c[135448]=(c[135448]|0)+6;ft=c[r>>2]|0;if((c[b+52>>2]|0)!=0){c[r>>2]=ft+1&65535;i=e;return}if((ft|0)<64512){fz=a[(c[b+64>>2]|0)+ft|0]|0;fA=ft}else{fy=c[b>>2]|0;fx=gj[c[(c[fy>>2]|0)+16>>2]&127](fy,ft)|0;fz=fx;fA=c[r>>2]|0}c[r>>2]=fA+1+(fz<<24>>24)&65535;i=e;return};case 209:{c[135448]=(c[135448]|0)+21;fz=c[r>>2]|0;if((fz|0)<64512){fA=b+64|0;fB=a[(c[fA>>2]|0)+fz|0]|0;fC=fz;fD=fA}else{fA=c[b>>2]|0;fx=gj[c[(c[fA>>2]|0)+16>>2]&127](fA,fz)|0;fB=fx;fC=c[r>>2]|0;fD=b+64|0}fx=fB&255;fB=b+24|0;c[fB>>2]=fx;c[r>>2]=fC+1;fC=c[fD>>2]|0;fD=(c[b+12>>2]|0)+((d[fC+(fx+1)|0]|0)<<8|(d[fC+fx|0]|0))&65535;c[fB>>2]=fD;if(fD>>>0<64512){fE=a[fC+fD|0]|0}else{fC=c[b>>2]|0;fE=gj[c[(c[fC>>2]|0)+16>>2]&127](fC,fD)|0}fD=fE&255;fE=b+56|0;c[fE>>2]=0;fC=c[b+4>>2]|0;if((fC|0)>=(fD|0)){c[fE>>2]=1}fE=fC-fD|0;c[b+52>>2]=(fE&255)<<24>>24==0;c[b+32>>2]=fE&128;i=e;return};case 210:{c[135448]=(c[135448]|0)+21;fE=c[r>>2]|0;if((fE|0)<64512){fD=b+64|0;fF=a[(c[fD>>2]|0)+fE|0]|0;fG=fE;fH=fD}else{fD=c[b>>2]|0;fC=gj[c[(c[fD>>2]|0)+16>>2]&127](fD,fE)|0;fF=fC;fG=c[r>>2]|0;fH=b+64|0}fC=fF&255;fF=b+24|0;c[fF>>2]=fC;c[r>>2]=fG+1;fG=c[fH>>2]|0;fH=(d[fG+(fC+1)|0]|0)<<8|(d[fG+fC|0]|0);c[fF>>2]=fH;if(fH>>>0<64512){fI=a[fG+fH|0]|0}else{fG=c[b>>2]|0;fI=gj[c[(c[fG>>2]|0)+16>>2]&127](fG,fH)|0}fH=fI&255;fI=b+56|0;c[fI>>2]=0;fG=c[b+4>>2]|0;if((fG|0)>=(fH|0)){c[fI>>2]=1}fI=fG-fH|0;c[b+52>>2]=(fI&255)<<24>>24==0;c[b+32>>2]=fI&128;i=e;return};case 211:{c[135448]=(c[135448]|0)+6;fI=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fI,v)|0)|0;i=v;fI=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fI,v)|0)|0;i=v;i=e;return};case 212:{c[135448]=(c[135448]|0)+16;fI=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fI,v)|0)|0;i=v;fI=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fI,v)|0)|0;i=v;i=e;return};case 213:{c[135448]=(c[135448]|0)+16;fI=c[r>>2]|0;if((fI|0)<64512){fH=c[b+64>>2]|0;fJ=a[fH+fI|0]|0;fK=fI;fL=fH}else{fH=c[b>>2]|0;fG=gj[c[(c[fH>>2]|0)+16>>2]&127](fH,fI)|0;fJ=fG;fK=c[r>>2]|0;fL=c[b+64>>2]|0}fG=(fJ&255)+(c[b+8>>2]|0)|0;c[r>>2]=fK+1;fK=fG&255;c[b+24>>2]=fK;fG=d[fL+fK|0]|0;fK=b+56|0;c[fK>>2]=0;fL=c[b+4>>2]|0;if((fL|0)>=(fG|0)){c[fK>>2]=1}fK=fL-fG|0;c[b+52>>2]=(fK&255)<<24>>24==0;c[b+32>>2]=fK&128;i=e;return};case 214:{c[135448]=(c[135448]|0)+26;fK=c[r>>2]|0;if((fK|0)<64512){fG=c[b+64>>2]|0;fM=a[fG+fK|0]|0;fN=fK;fO=fG}else{fG=c[b>>2]|0;fL=gj[c[(c[fG>>2]|0)+16>>2]&127](fG,fK)|0;fM=fL;fN=c[r>>2]|0;fO=c[b+64>>2]|0}fL=(fM&255)+(c[b+8>>2]|0)|0;c[r>>2]=fN+1;fN=fL&255;c[b+24>>2]=fN;fL=fO+fN|0;fN=(d[fL]|0)+255|0;a[fL]=fN&255;c[b+52>>2]=(fN&255|0)==0;c[b+32>>2]=fN&128;i=e;return};case 215:{c[135448]=(c[135448]|0)+21;fN=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fN,v)|0)|0;i=v;fN=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fN,v)|0)|0;i=v;i=e;return};case 216:{c[135448]=(c[135448]|0)+6;c[b+44>>2]=0;i=e;return};case 217:{c[135448]=(c[135448]|0)+16;fN=c[r>>2]|0;if((fN|0)<64512){fL=c[b+64>>2]|0;fP=(d[fL+(fN+1)|0]|0)<<8|(d[fL+fN|0]|0);fQ=fN}else{fL=c[b>>2]|0;fO=(gj[c[(c[fL>>2]|0)+24>>2]&127](fL,fN)|0)&65535;fP=fO;fQ=c[r>>2]|0}c[r>>2]=fQ+2;fQ=fP+(c[b+12>>2]|0)&65535;c[b+24>>2]=fQ;if(fQ>>>0<64512){fR=a[(c[b+64>>2]|0)+fQ|0]|0}else{fP=c[b>>2]|0;fR=gj[c[(c[fP>>2]|0)+16>>2]&127](fP,fQ)|0}fQ=fR&255;fR=b+56|0;c[fR>>2]=0;fP=c[b+4>>2]|0;if((fP|0)>=(fQ|0)){c[fR>>2]=1}fR=fP-fQ|0;c[b+52>>2]=(fR&255)<<24>>24==0;c[b+32>>2]=fR&128;i=e;return};case 218:{c[135448]=(c[135448]|0)+11;fR=b+16|0;fQ=(c[fR>>2]|0)+256|0;if((fQ|0)<64512){a[(c[b+64>>2]|0)+fQ|0]=c[b+8>>2]&255}else{fP=c[b>>2]|0;go[c[(c[fP>>2]|0)+12>>2]&127](fP,fQ,c[b+8>>2]&255)}c[fR>>2]=(c[fR>>2]|0)+255&255;i=e;return};case 219:{c[135448]=(c[135448]|0)+6;c[135452]=1;i=e;return};case 220:{c[135448]=(c[135448]|0)+16;fR=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fR,v)|0)|0;i=v;fR=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fR,v)|0)|0;i=v;i=e;return};case 221:{c[135448]=(c[135448]|0)+16;fR=c[r>>2]|0;if((fR|0)<64512){fQ=c[b+64>>2]|0;fS=(d[fQ+(fR+1)|0]|0)<<8|(d[fQ+fR|0]|0);fT=fR}else{fQ=c[b>>2]|0;fP=(gj[c[(c[fQ>>2]|0)+24>>2]&127](fQ,fR)|0)&65535;fS=fP;fT=c[r>>2]|0}c[r>>2]=fT+2;fT=fS+(c[b+8>>2]|0)&65535;c[b+24>>2]=fT;if(fT>>>0<64512){fU=a[(c[b+64>>2]|0)+fT|0]|0}else{fS=c[b>>2]|0;fU=gj[c[(c[fS>>2]|0)+16>>2]&127](fS,fT)|0}fT=fU&255;fU=b+56|0;c[fU>>2]=0;fS=c[b+4>>2]|0;if((fS|0)>=(fT|0)){c[fU>>2]=1}fU=fS-fT|0;c[b+52>>2]=(fU&255)<<24>>24==0;c[b+32>>2]=fU&128;i=e;return};case 222:{c[135448]=(c[135448]|0)+31;fU=c[r>>2]|0;if((fU|0)<64512){fT=c[b+64>>2]|0;fV=(d[fT+(fU+1)|0]|0)<<8|(d[fT+fU|0]|0);fW=fU}else{fT=c[b>>2]|0;fS=(gj[c[(c[fT>>2]|0)+24>>2]&127](fT,fU)|0)&65535;fV=fS;fW=c[r>>2]|0}fS=b+24|0;c[r>>2]=fW+2;fW=fV+(c[b+8>>2]|0)&65535;c[fS>>2]=fW;if(fW>>>0<64512){fX=a[(c[b+64>>2]|0)+fW|0]|0;fY=fW}else{fV=c[b>>2]|0;fU=gj[c[(c[fV>>2]|0)+16>>2]&127](fV,fW)|0;fX=fU;fY=c[fS>>2]|0}fS=(fX&255)+255|0;if((fY|0)<64512){a[(c[b+64>>2]|0)+fY|0]=fS&255}else{fX=c[b>>2]|0;go[c[(c[fX>>2]|0)+12>>2]&127](fX,fY,fS&255)}c[b+52>>2]=(fS&255|0)==0;c[b+32>>2]=fS&128;i=e;return};case 223:{c[135448]=(c[135448]|0)+21;fS=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fS,v)|0)|0;i=v;fS=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=fS,v)|0)|0;i=v;i=e;return};case 224:{c[135448]=(c[135448]|0)+6;fS=c[r>>2]|0;c[b+24>>2]=fS;c[r>>2]=fS+1;if((fS|0)<64512){fZ=a[(c[b+64>>2]|0)+fS|0]|0}else{fY=c[b>>2]|0;fZ=gj[c[(c[fY>>2]|0)+16>>2]&127](fY,fS)|0}fS=fZ&255;fZ=b+56|0;c[fZ>>2]=0;fY=c[b+8>>2]|0;if((fY|0)>=(fS|0)){c[fZ>>2]=1}fZ=fY-fS|0;c[b+52>>2]=(fZ&255)<<24>>24==0;c[b+32>>2]=fZ&128;i=e;return};case 225:{c[135448]=(c[135448]|0)+26;fZ=c[r>>2]|0;if((fZ|0)<64512){fS=c[b+64>>2]|0;f_=a[fS+fZ|0]|0;f$=fZ;f0=fS}else{fS=c[b>>2]|0;fY=gj[c[(c[fS>>2]|0)+16>>2]&127](fS,fZ)|0;f_=fY;f$=c[r>>2]|0;f0=c[b+64>>2]|0}fY=b+24|0;c[r>>2]=f$+1;f$=(c[b+8>>2]|0)+(f_&255)&255;c[fY>>2]=f$;f_=(d[f0+(f$+1)|0]|0)<<8|(d[f0+f$|0]|0);c[fY>>2]=f_;if(f_>>>0<64512){f1=a[(c[b+64>>2]|0)+f_|0]|0}else{fY=c[b>>2]|0;f1=gj[c[(c[fY>>2]|0)+16>>2]&127](fY,f_)|0}f_=f1&255;f1=b+56|0;fY=(c[f1>>2]|0)==0|0;f$=b+4|0;f0=c[f$>>2]|0;fZ=f0-f_-fY|0;if((c[b+44>>2]|0)==0){fS=b+36|0;c[fS>>2]=0;c[f1>>2]=0;if(((f0^fZ)&128&(f0^f_)|0)!=0){c[fS>>2]=1}if((fZ&65280|0)==0){c[f1>>2]=1}f2=fZ&255}else{fS=(f0&15)-(f_&15)-fY|0;fY=(f0&240)-(f_&240)|0;fX=b+36|0;c[fX>>2]=0;c[f1>>2]=0;if(((f0^fZ)&128&(f0^f_)|0)!=0){c[fX>>2]=1}fX=(fS&240|0)==0?fS:fS-6|0;fS=(fX&128|0)==0?fY:fY-16|0;if((fZ&65280|0)==0){c[f1>>2]=1}f2=((fS&3840|0)==0?fS:fS+160|0)&240|fX&15}c[f$>>2]=f2;c[b+52>>2]=(f2|0)==0;c[b+32>>2]=f2&128;i=e;return};case 226:{c[135448]=(c[135448]|0)+6;f2=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=f2,v)|0)|0;i=v;f2=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=f2,v)|0)|0;i=v;i=e;return};case 227:{c[135448]=(c[135448]|0)+6;f2=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=f2,v)|0)|0;i=v;f2=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=f2,v)|0)|0;i=v;i=e;return};case 228:{c[135448]=(c[135448]|0)+11;f2=c[r>>2]|0;if((f2|0)<64512){f$=b+64|0;f3=a[(c[f$>>2]|0)+f2|0]|0;f4=f2;f5=f$}else{f$=c[b>>2]|0;fX=gj[c[(c[f$>>2]|0)+16>>2]&127](f$,f2)|0;f3=fX;f4=c[r>>2]|0;f5=b+64|0}fX=f3&255;c[b+24>>2]=fX;c[r>>2]=f4+1;f4=d[(c[f5>>2]|0)+fX|0]|0;fX=b+56|0;c[fX>>2]=0;f5=c[b+8>>2]|0;if((f5|0)>=(f4|0)){c[fX>>2]=1}fX=f5-f4|0;c[b+52>>2]=(fX&255)<<24>>24==0;c[b+32>>2]=fX&128;i=e;return};case 229:{c[135448]=(c[135448]|0)+11;fX=c[r>>2]|0;if((fX|0)<64512){f4=b+64|0;f6=a[(c[f4>>2]|0)+fX|0]|0;f7=fX;f8=f4}else{f4=c[b>>2]|0;f5=gj[c[(c[f4>>2]|0)+16>>2]&127](f4,fX)|0;f6=f5;f7=c[r>>2]|0;f8=b+64|0}f5=f6&255;c[b+24>>2]=f5;c[r>>2]=f7+1;f7=d[(c[f8>>2]|0)+f5|0]|0;f5=b+56|0;f8=(c[f5>>2]|0)==0|0;f6=b+4|0;fX=c[f6>>2]|0;f4=fX-f7-f8|0;if((c[b+44>>2]|0)==0){f3=b+36|0;c[f3>>2]=0;c[f5>>2]=0;if(((fX^f4)&128&(fX^f7)|0)!=0){c[f3>>2]=1}if((f4&65280|0)==0){c[f5>>2]=1}f9=f4&255}else{f3=(fX&15)-(f7&15)-f8|0;f8=(fX&240)-(f7&240)|0;f2=b+36|0;c[f2>>2]=0;c[f5>>2]=0;if(((fX^f4)&128&(fX^f7)|0)!=0){c[f2>>2]=1}f2=(f3&240|0)==0?f3:f3-6|0;f3=(f2&128|0)==0?f8:f8-16|0;if((f4&65280|0)==0){c[f5>>2]=1}f9=((f3&3840|0)==0?f3:f3+160|0)&240|f2&15}c[f6>>2]=f9;c[b+52>>2]=(f9|0)==0;c[b+32>>2]=f9&128;i=e;return};case 230:{c[135448]=(c[135448]|0)+21;f9=c[r>>2]|0;if((f9|0)<64512){f6=b+64|0;ga=a[(c[f6>>2]|0)+f9|0]|0;gb=f9;gc=f6}else{f6=c[b>>2]|0;f2=gj[c[(c[f6>>2]|0)+16>>2]&127](f6,f9)|0;ga=f2;gb=c[r>>2]|0;gc=b+64|0}f2=ga&255;c[b+24>>2]=f2;c[r>>2]=gb+1;gb=(c[gc>>2]|0)+f2|0;f2=(d[gb]|0)+1|0;a[gb]=f2&255;c[b+52>>2]=(f2&255|0)==0;c[b+32>>2]=f2&128;i=e;return};case 231:{c[135448]=(c[135448]|0)+21;f2=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=f2,v)|0)|0;i=v;f2=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=f2,v)|0)|0;i=v;i=e;return};case 232:{c[135448]=(c[135448]|0)+6;f2=b+8|0;gb=(c[f2>>2]|0)+1|0;gc=gb&255;c[f2>>2]=gc;c[b+52>>2]=(gc|0)==0;c[b+32>>2]=gb&128;i=e;return};case 233:{c[135448]=(c[135448]|0)+6;gb=c[r>>2]|0;c[b+24>>2]=gb;c[r>>2]=gb+1;if((gb|0)<64512){gd=a[(c[b+64>>2]|0)+gb|0]|0}else{gc=c[b>>2]|0;gd=gj[c[(c[gc>>2]|0)+16>>2]&127](gc,gb)|0}gb=gd&255;gd=b+56|0;gc=(c[gd>>2]|0)==0|0;f2=b+4|0;ga=c[f2>>2]|0;f9=ga-gb-gc|0;if((c[b+44>>2]|0)==0){f6=b+36|0;c[f6>>2]=0;c[gd>>2]=0;if(((ga^f9)&128&(ga^gb)|0)!=0){c[f6>>2]=1}if((f9&65280|0)==0){c[gd>>2]=1}ge=f9&255}else{f6=(ga&15)-(gb&15)-gc|0;gc=(ga&240)-(gb&240)|0;f3=b+36|0;c[f3>>2]=0;c[gd>>2]=0;if(((ga^f9)&128&(ga^gb)|0)!=0){c[f3>>2]=1}f3=(f6&240|0)==0?f6:f6-6|0;f6=(f3&128|0)==0?gc:gc-16|0;if((f9&65280|0)==0){c[gd>>2]=1}ge=((f6&3840|0)==0?f6:f6+160|0)&240|f3&15}c[f2>>2]=ge;c[b+52>>2]=(ge|0)==0;c[b+32>>2]=ge&128;i=e;return};case 234:{c[135448]=(c[135448]|0)+6;i=e;return};case 235:{c[135448]=(c[135448]|0)+6;ge=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ge,v)|0)|0;i=v;ge=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ge,v)|0)|0;i=v;i=e;return};case 236:{c[135448]=(c[135448]|0)+16;ge=c[r>>2]|0;if((ge|0)<64512){f2=c[b+64>>2]|0;gf=(d[f2+(ge+1)|0]|0)<<8|(d[f2+ge|0]|0);gg=ge}else{f2=c[b>>2]|0;f3=(gj[c[(c[f2>>2]|0)+24>>2]&127](f2,ge)|0)&65535;gf=f3;gg=c[r>>2]|0}c[b+24>>2]=gf;c[r>>2]=gg+2;if((gf|0)<64512){gh=a[(c[b+64>>2]|0)+gf|0]|0}else{gg=c[b>>2]|0;gh=gj[c[(c[gg>>2]|0)+16>>2]&127](gg,gf)|0}gf=gh&255;gh=b+56|0;c[gh>>2]=0;gg=c[b+8>>2]|0;if((gg|0)>=(gf|0)){c[gh>>2]=1}gh=gg-gf|0;c[b+52>>2]=(gh&255)<<24>>24==0;c[b+32>>2]=gh&128;i=e;return};case 237:{c[135448]=(c[135448]|0)+16;gh=c[r>>2]|0;if((gh|0)<64512){gf=c[b+64>>2]|0;gi=(d[gf+(gh+1)|0]|0)<<8|(d[gf+gh|0]|0);gk=gh}else{gf=c[b>>2]|0;gg=(gj[c[(c[gf>>2]|0)+24>>2]&127](gf,gh)|0)&65535;gi=gg;gk=c[r>>2]|0}c[b+24>>2]=gi;c[r>>2]=gk+2;if((gi|0)<64512){gl=a[(c[b+64>>2]|0)+gi|0]|0}else{gk=c[b>>2]|0;gl=gj[c[(c[gk>>2]|0)+16>>2]&127](gk,gi)|0}gi=gl&255;gl=b+56|0;gk=(c[gl>>2]|0)==0|0;gg=b+4|0;gh=c[gg>>2]|0;gf=gh-gi-gk|0;if((c[b+44>>2]|0)==0){f3=b+36|0;c[f3>>2]=0;c[gl>>2]=0;if(((gh^gf)&128&(gh^gi)|0)!=0){c[f3>>2]=1}if((gf&65280|0)==0){c[gl>>2]=1}gm=gf&255}else{f3=(gh&15)-(gi&15)-gk|0;gk=(gh&240)-(gi&240)|0;ge=b+36|0;c[ge>>2]=0;c[gl>>2]=0;if(((gh^gf)&128&(gh^gi)|0)!=0){c[ge>>2]=1}ge=(f3&240|0)==0?f3:f3-6|0;f3=(ge&128|0)==0?gk:gk-16|0;if((gf&65280|0)==0){c[gl>>2]=1}gm=((f3&3840|0)==0?f3:f3+160|0)&240|ge&15}c[gg>>2]=gm;c[b+52>>2]=(gm|0)==0;c[b+32>>2]=gm&128;i=e;return};case 238:{c[135448]=(c[135448]|0)+26;gm=c[r>>2]|0;if((gm|0)<64512){gg=c[b+64>>2]|0;gn=(d[gg+(gm+1)|0]|0)<<8|(d[gg+gm|0]|0);gp=gm}else{gg=c[b>>2]|0;ge=(gj[c[(c[gg>>2]|0)+24>>2]&127](gg,gm)|0)&65535;gn=ge;gp=c[r>>2]|0}ge=b+24|0;c[ge>>2]=gn;c[r>>2]=gp+2;if((gn|0)<64512){gq=a[(c[b+64>>2]|0)+gn|0]|0;gr=gn}else{gp=c[b>>2]|0;gm=gj[c[(c[gp>>2]|0)+16>>2]&127](gp,gn)|0;gq=gm;gr=c[ge>>2]|0}ge=(gq&255)+1|0;if((gr|0)<64512){a[(c[b+64>>2]|0)+gr|0]=ge&255}else{gq=c[b>>2]|0;go[c[(c[gq>>2]|0)+12>>2]&127](gq,gr,ge&255)}c[b+52>>2]=(ge&255|0)==0;c[b+32>>2]=ge&128;i=e;return};case 239:{c[135448]=(c[135448]|0)+21;ge=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ge,v)|0)|0;i=v;ge=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=ge,v)|0)|0;i=v;i=e;return};case 240:{c[135448]=(c[135448]|0)+6;ge=c[r>>2]|0;if((c[b+52>>2]|0)==0){c[r>>2]=ge+1&65535;i=e;return}if((ge|0)<64512){gs=a[(c[b+64>>2]|0)+ge|0]|0;gt=ge}else{gr=c[b>>2]|0;gq=gj[c[(c[gr>>2]|0)+16>>2]&127](gr,ge)|0;gs=gq;gt=c[r>>2]|0}c[r>>2]=gt+1+(gs<<24>>24)&65535;i=e;return};case 241:{c[135448]=(c[135448]|0)+21;gs=c[r>>2]|0;if((gs|0)<64512){gt=b+64|0;gu=a[(c[gt>>2]|0)+gs|0]|0;gv=gs;gw=gt}else{gt=c[b>>2]|0;gq=gj[c[(c[gt>>2]|0)+16>>2]&127](gt,gs)|0;gu=gq;gv=c[r>>2]|0;gw=b+64|0}gq=gu&255;gu=b+24|0;c[gu>>2]=gq;c[r>>2]=gv+1;gv=c[gw>>2]|0;gw=(c[b+12>>2]|0)+((d[gv+(gq+1)|0]|0)<<8|(d[gv+gq|0]|0))&65535;c[gu>>2]=gw;if(gw>>>0<64512){gx=a[gv+gw|0]|0}else{gv=c[b>>2]|0;gx=gj[c[(c[gv>>2]|0)+16>>2]&127](gv,gw)|0}gw=gx&255;gx=b+56|0;gv=(c[gx>>2]|0)==0|0;gu=b+4|0;gq=c[gu>>2]|0;gs=gq-gw-gv|0;if((c[b+44>>2]|0)==0){gt=b+36|0;c[gt>>2]=0;c[gx>>2]=0;if(((gq^gs)&128&(gq^gw)|0)!=0){c[gt>>2]=1}if((gs&65280|0)==0){c[gx>>2]=1}gy=gs&255}else{gt=(gq&15)-(gw&15)-gv|0;gv=(gq&240)-(gw&240)|0;ge=b+36|0;c[ge>>2]=0;c[gx>>2]=0;if(((gq^gs)&128&(gq^gw)|0)!=0){c[ge>>2]=1}ge=(gt&240|0)==0?gt:gt-6|0;gt=(ge&128|0)==0?gv:gv-16|0;if((gs&65280|0)==0){c[gx>>2]=1}gy=((gt&3840|0)==0?gt:gt+160|0)&240|ge&15}c[gu>>2]=gy;c[b+52>>2]=(gy|0)==0;c[b+32>>2]=gy&128;i=e;return};case 242:{c[135448]=(c[135448]|0)+21;gy=c[r>>2]|0;if((gy|0)<64512){gu=b+64|0;gz=a[(c[gu>>2]|0)+gy|0]|0;gA=gy;gB=gu}else{gu=c[b>>2]|0;ge=gj[c[(c[gu>>2]|0)+16>>2]&127](gu,gy)|0;gz=ge;gA=c[r>>2]|0;gB=b+64|0}ge=gz&255;gz=b+24|0;c[gz>>2]=ge;c[r>>2]=gA+1;gA=c[gB>>2]|0;gB=(d[gA+(ge+1)|0]|0)<<8|(d[gA+ge|0]|0);c[gz>>2]=gB;if(gB>>>0<64512){gC=a[gA+gB|0]|0}else{gA=c[b>>2]|0;gC=gj[c[(c[gA>>2]|0)+16>>2]&127](gA,gB)|0}gB=gC&255;gC=b+56|0;gA=(c[gC>>2]|0)==0|0;gz=b+4|0;ge=c[gz>>2]|0;gy=ge-gB-gA|0;if((c[b+44>>2]|0)==0){gu=b+36|0;c[gu>>2]=0;c[gC>>2]=0;if(((ge^gy)&128&(ge^gB)|0)!=0){c[gu>>2]=1}if((gy&65280|0)==0){c[gC>>2]=1}gD=gy&255}else{gu=(ge&15)-(gB&15)-gA|0;gA=(ge&240)-(gB&240)|0;gt=b+36|0;c[gt>>2]=0;c[gC>>2]=0;if(((ge^gy)&128&(ge^gB)|0)!=0){c[gt>>2]=1}gt=(gu&240|0)==0?gu:gu-6|0;gu=(gt&128|0)==0?gA:gA-16|0;if((gy&65280|0)==0){c[gC>>2]=1}gD=((gu&3840|0)==0?gu:gu+160|0)&240|gt&15}c[gz>>2]=gD;c[b+52>>2]=(gD|0)==0;c[b+32>>2]=gD&128;i=e;return};case 243:{c[135448]=(c[135448]|0)+6;gD=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gD,v)|0)|0;i=v;gD=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gD,v)|0)|0;i=v;i=e;return};case 244:{c[135448]=(c[135448]|0)+16;gD=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gD,v)|0)|0;i=v;gD=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gD,v)|0)|0;i=v;i=e;return};case 245:{c[135448]=(c[135448]|0)+16;gD=c[r>>2]|0;if((gD|0)<64512){gz=c[b+64>>2]|0;gE=a[gz+gD|0]|0;gF=gD;gG=gz}else{gz=c[b>>2]|0;gt=gj[c[(c[gz>>2]|0)+16>>2]&127](gz,gD)|0;gE=gt;gF=c[r>>2]|0;gG=c[b+64>>2]|0}gt=(gE&255)+(c[b+8>>2]|0)|0;c[r>>2]=gF+1;gF=gt&255;c[b+24>>2]=gF;gt=d[gG+gF|0]|0;gF=b+56|0;gG=(c[gF>>2]|0)==0|0;gE=b+4|0;gD=c[gE>>2]|0;gz=gD-gt-gG|0;if((c[b+44>>2]|0)==0){gu=b+36|0;c[gu>>2]=0;c[gF>>2]=0;if(((gD^gz)&128&(gD^gt)|0)!=0){c[gu>>2]=1}if((gz&65280|0)==0){c[gF>>2]=1}gH=gz&255}else{gu=(gD&15)-(gt&15)-gG|0;gG=(gD&240)-(gt&240)|0;gC=b+36|0;c[gC>>2]=0;c[gF>>2]=0;if(((gD^gz)&128&(gD^gt)|0)!=0){c[gC>>2]=1}gC=(gu&240|0)==0?gu:gu-6|0;gu=(gC&128|0)==0?gG:gG-16|0;if((gz&65280|0)==0){c[gF>>2]=1}gH=((gu&3840|0)==0?gu:gu+160|0)&240|gC&15}c[gE>>2]=gH;c[b+52>>2]=(gH|0)==0;c[b+32>>2]=gH&128;i=e;return};case 246:{c[135448]=(c[135448]|0)+26;gH=c[r>>2]|0;if((gH|0)<64512){gE=c[b+64>>2]|0;gI=a[gE+gH|0]|0;gJ=gH;gK=gE}else{gE=c[b>>2]|0;gC=gj[c[(c[gE>>2]|0)+16>>2]&127](gE,gH)|0;gI=gC;gJ=c[r>>2]|0;gK=c[b+64>>2]|0}gC=(gI&255)+(c[b+8>>2]|0)|0;c[r>>2]=gJ+1;gJ=gC&255;c[b+24>>2]=gJ;gC=gK+gJ|0;gJ=(d[gC]|0)+1|0;a[gC]=gJ&255;c[b+52>>2]=(gJ&255|0)==0;c[b+32>>2]=gJ&128;i=e;return};case 247:{c[135448]=(c[135448]|0)+21;gJ=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gJ,v)|0)|0;i=v;gJ=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gJ,v)|0)|0;i=v;i=e;return};case 248:{c[135448]=(c[135448]|0)+6;c[b+44>>2]=1;i=e;return};case 249:{c[135448]=(c[135448]|0)+16;gJ=c[r>>2]|0;if((gJ|0)<64512){gC=c[b+64>>2]|0;gL=(d[gC+(gJ+1)|0]|0)<<8|(d[gC+gJ|0]|0);gM=gJ}else{gC=c[b>>2]|0;gK=(gj[c[(c[gC>>2]|0)+24>>2]&127](gC,gJ)|0)&65535;gL=gK;gM=c[r>>2]|0}c[r>>2]=gM+2;gM=gL+(c[b+12>>2]|0)&65535;c[b+24>>2]=gM;if(gM>>>0<64512){gN=a[(c[b+64>>2]|0)+gM|0]|0}else{gL=c[b>>2]|0;gN=gj[c[(c[gL>>2]|0)+16>>2]&127](gL,gM)|0}gM=gN&255;gN=b+56|0;gL=(c[gN>>2]|0)==0|0;gK=b+4|0;gJ=c[gK>>2]|0;gC=gJ-gM-gL|0;if((c[b+44>>2]|0)==0){gI=b+36|0;c[gI>>2]=0;c[gN>>2]=0;if(((gJ^gC)&128&(gJ^gM)|0)!=0){c[gI>>2]=1}if((gC&65280|0)==0){c[gN>>2]=1}gO=gC&255}else{gI=(gJ&15)-(gM&15)-gL|0;gL=(gJ&240)-(gM&240)|0;gH=b+36|0;c[gH>>2]=0;c[gN>>2]=0;if(((gJ^gC)&128&(gJ^gM)|0)!=0){c[gH>>2]=1}gH=(gI&240|0)==0?gI:gI-6|0;gI=(gH&128|0)==0?gL:gL-16|0;if((gC&65280|0)==0){c[gN>>2]=1}gO=((gI&3840|0)==0?gI:gI+160|0)&240|gH&15}c[gK>>2]=gO;c[b+52>>2]=(gO|0)==0;c[b+32>>2]=gO&128;i=e;return};case 250:{c[135448]=(c[135448]|0)+16;gO=b+16|0;gK=(c[gO>>2]|0)+1&255;c[gO>>2]=gK;gO=a[(c[b+64>>2]|0)+(gK|256)|0]|0;gK=gO&255;c[b+8>>2]=gK;c[b+52>>2]=gO<<24>>24==0;c[b+32>>2]=gK&128;i=e;return};case 251:{c[135448]=(c[135448]|0)+6;gK=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gK,v)|0)|0;i=v;gK=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gK,v)|0)|0;i=v;i=e;return};case 252:{c[135448]=(c[135448]|0)+16;gK=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gK,v)|0)|0;i=v;gK=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gK,v)|0)|0;i=v;i=e;return};case 253:{c[135448]=(c[135448]|0)+16;gK=c[r>>2]|0;if((gK|0)<64512){gO=c[b+64>>2]|0;gP=(d[gO+(gK+1)|0]|0)<<8|(d[gO+gK|0]|0);gQ=gK}else{gO=c[b>>2]|0;gH=(gj[c[(c[gO>>2]|0)+24>>2]&127](gO,gK)|0)&65535;gP=gH;gQ=c[r>>2]|0}c[r>>2]=gQ+2;gQ=gP+(c[b+8>>2]|0)&65535;c[b+24>>2]=gQ;if(gQ>>>0<64512){gR=a[(c[b+64>>2]|0)+gQ|0]|0}else{gP=c[b>>2]|0;gR=gj[c[(c[gP>>2]|0)+16>>2]&127](gP,gQ)|0}gQ=gR&255;gR=b+56|0;gP=(c[gR>>2]|0)==0|0;gH=b+4|0;gK=c[gH>>2]|0;gO=gK-gQ-gP|0;if((c[b+44>>2]|0)==0){gI=b+36|0;c[gI>>2]=0;c[gR>>2]=0;if(((gK^gO)&128&(gK^gQ)|0)!=0){c[gI>>2]=1}if((gO&65280|0)==0){c[gR>>2]=1}gS=gO&255}else{gI=(gK&15)-(gQ&15)-gP|0;gP=(gK&240)-(gQ&240)|0;gN=b+36|0;c[gN>>2]=0;c[gR>>2]=0;if(((gK^gO)&128&(gK^gQ)|0)!=0){c[gN>>2]=1}gN=(gI&240|0)==0?gI:gI-6|0;gI=(gN&128|0)==0?gP:gP-16|0;if((gO&65280|0)==0){c[gR>>2]=1}gS=((gI&3840|0)==0?gI:gI+160|0)&240|gN&15}c[gH>>2]=gS;c[b+52>>2]=(gS|0)==0;c[b+32>>2]=gS&128;i=e;return};case 254:{c[135448]=(c[135448]|0)+31;gS=c[r>>2]|0;if((gS|0)<64512){gH=c[b+64>>2]|0;gT=(d[gH+(gS+1)|0]|0)<<8|(d[gH+gS|0]|0);gU=gS}else{gH=c[b>>2]|0;gN=(gj[c[(c[gH>>2]|0)+24>>2]&127](gH,gS)|0)&65535;gT=gN;gU=c[r>>2]|0}gN=b+24|0;c[r>>2]=gU+2;gU=gT+(c[b+8>>2]|0)&65535;c[gN>>2]=gU;if(gU>>>0<64512){gV=a[(c[b+64>>2]|0)+gU|0]|0;gW=gU}else{gT=c[b>>2]|0;gS=gj[c[(c[gT>>2]|0)+16>>2]&127](gT,gU)|0;gV=gS;gW=c[gN>>2]|0}gN=(gV&255)+1|0;if((gW|0)<64512){a[(c[b+64>>2]|0)+gW|0]=gN&255}else{gV=c[b>>2]|0;go[c[(c[gV>>2]|0)+12>>2]&127](gV,gW,gN&255)}c[b+52>>2]=(gN&255|0)==0;c[b+32>>2]=gN&128;i=e;return};case 255:{c[135448]=(c[135448]|0)+21;gN=c[r>>2]|0;cA(f|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gN,v)|0)|0;i=v;gN=c[r>>2]|0;eQ(c[t>>2]|0,32656,(v=i,i=i+16|0,c[v>>2]=c[s>>2],c[v+8>>2]=gN,v)|0)|0;i=v;i=e;return};default:{i=e;return}}}function mf(a){a=a|0;var b=0;c[a>>2]=55632;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);return}function mg(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=55632;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;sS(e);return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);e=a;sS(e);return}function mh(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a+36|0;g=a+40|0;h=d|0;j=d+8|0;k=d;d=a+32|0;while(1){a=c[f>>2]|0;l=f6[c[(c[a>>2]|0)+20>>2]&31](a,c[g>>2]|0,h,j,e)|0;a=(c[e>>2]|0)-k|0;if((be(h|0,1,a|0,c[d>>2]|0)|0)!=(a|0)){m=-1;n=6391;break}if((l|0)==2){m=-1;n=6393;break}else if((l|0)!=1){n=6389;break}}if((n|0)==6389){m=((a7(c[d>>2]|0)|0)!=0)<<31>>31;i=b;return m|0}else if((n|0)==6391){i=b;return m|0}else if((n|0)==6393){i=b;return m|0}return 0}function mi(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=(d|0)==-1;L8054:do{if(!k){c[g>>2]=d;if((a[b+44|0]&1)!=0){if((be(g|0,4,1,c[b+32>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}m=f|0;c[h>>2]=m;n=g+4|0;o=b+36|0;p=b+40|0;q=f+8|0;r=f;s=b+32|0;t=g;while(1){u=c[o>>2]|0;v=gq[c[(c[u>>2]|0)+12>>2]&31](u,c[p>>2]|0,t,n,j,m,q,h)|0;if((c[j>>2]|0)==(t|0)){l=-1;w=6408;break}if((v|0)==3){w=6400;break}u=(v|0)==1;if(v>>>0>=2){l=-1;w=6411;break}v=(c[h>>2]|0)-r|0;if((be(m|0,1,v|0,c[s>>2]|0)|0)!=(v|0)){l=-1;w=6409;break}if(u){t=u?c[j>>2]|0:t}else{break L8054}}if((w|0)==6400){if((be(t|0,1,1,c[s>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}else if((w|0)==6408){i=e;return l|0}else if((w|0)==6409){i=e;return l|0}else if((w|0)==6411){i=e;return l|0}}}while(0);l=k?0:d;i=e;return l|0}function mj(a){a=a|0;var b=0;c[a>>2]=55632;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);return}function mk(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=55632;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;sS(e);return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);e=a;sS(e);return}function ml(a){a=a|0;return mo(a,0)|0}function mm(a){a=a|0;return mo(a,1)|0}function mn(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=b+52|0;l=(a[k]&1)!=0;if((d|0)==-1){if(l){m=-1;i=e;return m|0}n=c[b+48>>2]|0;a[k]=(n|0)!=-1|0;m=n;i=e;return m|0}n=b+48|0;L8094:do{if(l){c[h>>2]=c[n>>2];o=c[b+36>>2]|0;p=f|0;q=gq[c[(c[o>>2]|0)+12>>2]&31](o,c[b+40>>2]|0,h,h+4|0,j,p,f+8|0,g)|0;if((q|0)==2|(q|0)==1){m=-1;i=e;return m|0}else if((q|0)==3){a[p]=c[n>>2]&255;c[g>>2]=f+1}q=b+32|0;while(1){o=c[g>>2]|0;if(o>>>0<=p>>>0){break L8094}r=o-1|0;c[g>>2]=r;if((ez(a[r]|0,c[q>>2]|0)|0)==-1){m=-1;break}}i=e;return m|0}}while(0);c[n>>2]=d;a[k]=1;m=d;i=e;return m|0}function mo(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=b+52|0;if((a[k]&1)!=0){l=b+48|0;m=c[l>>2]|0;if(!d){n=m;i=e;return n|0}c[l>>2]=-1;a[k]=0;n=m;i=e;return n|0}m=c[b+44>>2]|0;k=(m|0)>1?m:1;L8114:do{if((k|0)>0){m=b+32|0;l=0;while(1){o=b7(c[m>>2]|0)|0;if((o|0)==-1){n=-1;break}a[f+l|0]=o&255;l=l+1|0;if((l|0)>=(k|0)){break L8114}}i=e;return n|0}}while(0);L8121:do{if((a[b+53|0]&1)==0){l=b+40|0;m=b+36|0;o=f|0;p=g+4|0;q=b+32|0;r=k;while(1){s=c[l>>2]|0;t=s;u=c[t>>2]|0;v=c[t+4>>2]|0;t=c[m>>2]|0;w=f+r|0;x=gq[c[(c[t>>2]|0)+16>>2]&31](t,s,o,w,h,g,p,j)|0;if((x|0)==2){n=-1;y=6467;break}else if((x|0)==3){y=6453;break}else if((x|0)!=1){z=r;break L8121}x=c[l>>2]|0;c[x>>2]=u;c[x+4>>2]=v;if((r|0)==8){n=-1;y=6468;break}v=b7(c[q>>2]|0)|0;if((v|0)==-1){n=-1;y=6463;break}a[w]=v&255;r=r+1|0}if((y|0)==6467){i=e;return n|0}else if((y|0)==6453){c[g>>2]=a[o]|0;z=r;break}else if((y|0)==6468){i=e;return n|0}else if((y|0)==6463){i=e;return n|0}}else{c[g>>2]=a[f|0]|0;z=k}}while(0);if(d){d=c[g>>2]|0;c[b+48>>2]=d;n=d;i=e;return n|0}d=b+32|0;b=z;while(1){if((b|0)<=0){break}z=b-1|0;if((ez(a[f+z|0]|0,c[d>>2]|0)|0)==-1){n=-1;y=6470;break}else{b=z}}if((y|0)==6470){i=e;return n|0}n=c[g>>2]|0;i=e;return n|0}function mp(a){a=a|0;var b=0;c[a>>2]=55704;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);return}function mq(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=55704;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;sS(e);return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);e=a;sS(e);return}function mr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a+36|0;g=a+40|0;h=d|0;j=d+8|0;k=d;d=a+32|0;while(1){a=c[f>>2]|0;l=f6[c[(c[a>>2]|0)+20>>2]&31](a,c[g>>2]|0,h,j,e)|0;a=(c[e>>2]|0)-k|0;if((be(h|0,1,a|0,c[d>>2]|0)|0)!=(a|0)){m=-1;n=6488;break}if((l|0)==2){m=-1;n=6487;break}else if((l|0)!=1){n=6484;break}}if((n|0)==6488){i=b;return m|0}else if((n|0)==6484){m=((a7(c[d>>2]|0)|0)!=0)<<31>>31;i=b;return m|0}else if((n|0)==6487){i=b;return m|0}return 0}function ms(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=(d|0)==-1;L8166:do{if(!k){a[g]=d&255;if((a[b+44|0]&1)!=0){if((be(g|0,1,1,c[b+32>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}m=f|0;c[h>>2]=m;n=g+1|0;o=b+36|0;p=b+40|0;q=f+8|0;r=f;s=b+32|0;t=g;while(1){u=c[o>>2]|0;v=gq[c[(c[u>>2]|0)+12>>2]&31](u,c[p>>2]|0,t,n,j,m,q,h)|0;if((c[j>>2]|0)==(t|0)){l=-1;w=6502;break}if((v|0)==3){w=6495;break}u=(v|0)==1;if(v>>>0>=2){l=-1;w=6503;break}v=(c[h>>2]|0)-r|0;if((be(m|0,1,v|0,c[s>>2]|0)|0)!=(v|0)){l=-1;w=6505;break}if(u){t=u?c[j>>2]|0:t}else{break L8166}}if((w|0)==6502){i=e;return l|0}else if((w|0)==6495){if((be(t|0,1,1,c[s>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}else if((w|0)==6505){i=e;return l|0}else if((w|0)==6503){i=e;return l|0}}}while(0);l=k?0:d;i=e;return l|0}function mt(a){a=a|0;var b=0;c[a>>2]=55704;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);return}function mu(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=55704;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;sS(e);return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);e=a;sS(e);return}function mv(a){a=a|0;nR(551624);nR(551712);nS(551256);nS(551344);return}function mw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;f2[c[(c[b>>2]|0)+24>>2]&255](b)|0;g=c[d>>2]|0;if((c[137804]|0)!=-1){c[f>>2]=551216;c[f+4>>2]=16;c[f+8>>2]=0;mU(551216,f)}f=(c[137805]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=fc(4)|0;j=h;c[j>>2]=53912;dq(h|0,60416,316)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=fc(4)|0;j=h;c[j>>2]=53912;dq(h|0,60416,316)}else{h=g;c[b+36>>2]=h;a[b+44|0]=(f2[c[(c[g>>2]|0)+28>>2]&255](h)|0)&1;i=e;return}}function mx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;g=c[d>>2]|0;if((c[137804]|0)!=-1){c[f>>2]=551216;c[f+4>>2]=16;c[f+8>>2]=0;mU(551216,f)}f=(c[137805]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=fc(4)|0;j=h;c[j>>2]=53912;dq(h|0,60416,316)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=fc(4)|0;j=h;c[j>>2]=53912;dq(h|0,60416,316)}h=g;j=b+36|0;c[j>>2]=h;f=b+44|0;c[f>>2]=f2[c[(c[g>>2]|0)+24>>2]&255](h)|0;h=c[j>>2]|0;a[b+53|0]=(f2[c[(c[h>>2]|0)+28>>2]&255](h)|0)&1;if((c[f>>2]|0)>8){qw(12016)}else{i=e;return}}function my(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;f2[c[(c[b>>2]|0)+24>>2]&255](b)|0;g=c[d>>2]|0;if((c[137806]|0)!=-1){c[f>>2]=551224;c[f+4>>2]=16;c[f+8>>2]=0;mU(551224,f)}f=(c[137807]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=fc(4)|0;j=h;c[j>>2]=53912;dq(h|0,60416,316)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=fc(4)|0;j=h;c[j>>2]=53912;dq(h|0,60416,316)}else{h=g;c[b+36>>2]=h;a[b+44|0]=(f2[c[(c[g>>2]|0)+28>>2]&255](h)|0)&1;i=e;return}}function mz(a){a=a|0;return mC(a,0)|0}function mA(a){a=a|0;return mC(a,1)|0}function mB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=b+52|0;l=(a[k]&1)!=0;if((d|0)==-1){if(l){m=-1;i=e;return m|0}n=c[b+48>>2]|0;a[k]=(n|0)!=-1|0;m=n;i=e;return m|0}n=b+48|0;L8244:do{if(l){a[h]=c[n>>2]&255;o=c[b+36>>2]|0;p=f|0;q=gq[c[(c[o>>2]|0)+12>>2]&31](o,c[b+40>>2]|0,h,h+1|0,j,p,f+8|0,g)|0;if((q|0)==2|(q|0)==1){m=-1;i=e;return m|0}else if((q|0)==3){a[p]=c[n>>2]&255;c[g>>2]=f+1}q=b+32|0;while(1){o=c[g>>2]|0;if(o>>>0<=p>>>0){break L8244}r=o-1|0;c[g>>2]=r;if((ez(a[r]|0,c[q>>2]|0)|0)==-1){m=-1;break}}i=e;return m|0}}while(0);c[n>>2]=d;a[k]=1;m=d;i=e;return m|0}function mC(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+32|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=b+52|0;if((a[l]&1)!=0){m=b+48|0;n=c[m>>2]|0;if(!e){o=n;i=f;return o|0}c[m>>2]=-1;a[l]=0;o=n;i=f;return o|0}n=c[b+44>>2]|0;l=(n|0)>1?n:1;L8264:do{if((l|0)>0){n=b+32|0;m=0;while(1){p=b7(c[n>>2]|0)|0;if((p|0)==-1){o=-1;break}a[g+m|0]=p&255;m=m+1|0;if((m|0)>=(l|0)){break L8264}}i=f;return o|0}}while(0);L8271:do{if((a[b+53|0]&1)==0){m=b+40|0;n=b+36|0;p=g|0;q=h+1|0;r=b+32|0;s=l;while(1){t=c[m>>2]|0;u=t;v=c[u>>2]|0;w=c[u+4>>2]|0;u=c[n>>2]|0;x=g+s|0;y=gq[c[(c[u>>2]|0)+16>>2]&31](u,t,p,x,j,h,q,k)|0;if((y|0)==3){z=6580;break}else if((y|0)==2){o=-1;z=6590;break}else if((y|0)!=1){A=s;break L8271}y=c[m>>2]|0;c[y>>2]=v;c[y+4>>2]=w;if((s|0)==8){o=-1;z=6596;break}w=b7(c[r>>2]|0)|0;if((w|0)==-1){o=-1;z=6597;break}a[x]=w&255;s=s+1|0}if((z|0)==6597){i=f;return o|0}else if((z|0)==6580){a[h]=a[p]|0;A=s;break}else if((z|0)==6590){i=f;return o|0}else if((z|0)==6596){i=f;return o|0}}else{a[h]=a[g|0]|0;A=l}}while(0);do{if(e){l=a[h]|0;c[b+48>>2]=l&255;B=l}else{l=b+32|0;k=A;while(1){if((k|0)<=0){z=6587;break}j=k-1|0;if((ez(d[g+j|0]|0|0,c[l>>2]|0)|0)==-1){o=-1;z=6594;break}else{k=j}}if((z|0)==6594){i=f;return o|0}else if((z|0)==6587){B=a[h]|0;break}}}while(0);o=B&255;i=f;return o|0}function mD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;g=c[d>>2]|0;if((c[137806]|0)!=-1){c[f>>2]=551224;c[f+4>>2]=16;c[f+8>>2]=0;mU(551224,f)}f=(c[137807]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=fc(4)|0;j=h;c[j>>2]=53912;dq(h|0,60416,316)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=fc(4)|0;j=h;c[j>>2]=53912;dq(h|0,60416,316)}h=g;j=b+36|0;c[j>>2]=h;f=b+44|0;c[f>>2]=f2[c[(c[g>>2]|0)+24>>2]&255](h)|0;h=c[j>>2]|0;a[b+53|0]=(f2[c[(c[h>>2]|0)+28>>2]&255](h)|0)&1;if((c[f>>2]|0)>8){qw(12016)}else{i=e;return}}function mE(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+96|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=c[s>>2]|0;c[137742]=55704;l=c[(q$()|0)>>2]|0;c[137743]=l;m=l+4|0;I=c[m>>2]|0,c[m>>2]=I+1,I;s_(550976,0,24);c[137742]=56592;c[137750]=k;c[137752]=551024;c[137754]=-1;a[551020]=0;k=c[137743]|0;m=k+4|0;I=c[m>>2]|0,c[m>>2]=I+1,I;if((c[137806]|0)!=-1){c[e>>2]=551224;c[e+4>>2]=16;c[e+8>>2]=0;mU(551224,e)}e=(c[137807]|0)-1|0;l=c[k+8>>2]|0;do{if((c[k+12>>2]|0)-l>>2>>>0>e>>>0){n=c[l+(e<<2)>>2]|0;if((n|0)==0){break}o=n;c[137751]=o;c[137753]=f2[c[(c[n>>2]|0)+24>>2]&255](o)|0;o=c[137751]|0;a[551021]=(f2[c[(c[o>>2]|0)+28>>2]&255](o)|0)&1;if((c[137753]|0)>8){o=fc(8)|0;c[o>>2]=53944;n=o+4|0;p=n;do{if((n|0)!=0){while(1){u=sR(50)|0;if((u|0)!=0){v=6628;break}w=(I=c[138018]|0,c[138018]=I+0,I);if((w|0)==0){break}gp[w&63]()}if((v|0)==6628){c[u+4>>2]=37;c[u>>2]=37;w=u+12|0;c[p>>2]=w;c[u+8>>2]=0;s1(w|0,12016,38)|0;break}w=fc(4)|0;c[w>>2]=53880;dq(w|0,60400,240)}}while(0);dq(o|0,60432,122)}if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)==0){f$[c[(c[k>>2]|0)+8>>2]&511](k|0)}c[137972]=55972;c[137974]=55992;c[137973]=0;c[137980]=550968;c[137978]=0;c[137979]=0;c[137975]=4098;c[137977]=0;c[137976]=6;s_(551928,0,40);p=c[(q$()|0)>>2]|0;c[137981]=p;n=p+4|0;I=c[n>>2]|0,c[n>>2]=I+1,I;c[137992]=0;c[137993]=-1;n=c[q>>2]|0;c[137718]=55704;p=c[(q$()|0)>>2]|0;c[137719]=p;w=p+4|0;I=c[w>>2]|0,c[w>>2]=I+1,I;s_(550880,0,24);c[137718]=56192;c[137726]=n;n=c[137719]|0;w=n+4|0;I=c[w>>2]|0,c[w>>2]=I+1,I;if((c[137806]|0)!=-1){c[j>>2]=551224;c[j+4>>2]=16;c[j+8>>2]=0;mU(551224,j)}p=(c[137807]|0)-1|0;x=c[n+8>>2]|0;do{if((c[n+12>>2]|0)-x>>2>>>0>p>>>0){y=c[x+(p<<2)>>2]|0;if((y|0)==0){break}z=y;if(((I=c[w>>2]|0,c[w>>2]=I+ -1,I)|0)==0){f$[c[(c[n>>2]|0)+8>>2]&511](n|0)}c[137727]=z;c[137728]=551032;a[550916]=(f2[c[(c[y>>2]|0)+28>>2]&255](z)|0)&1;c[137906]=55876;c[137907]=55896;c[137913]=550872;c[137911]=0;c[137912]=0;c[137908]=4098;c[137910]=0;c[137909]=6;s_(551660,0,40);z=c[(q$()|0)>>2]|0;c[137914]=z;y=z+4|0;I=c[y>>2]|0,c[y>>2]=I+1,I;c[137925]=0;c[137926]=-1;y=c[t>>2]|0;c[137730]=55704;z=c[(q$()|0)>>2]|0;c[137731]=z;A=z+4|0;I=c[A>>2]|0,c[A>>2]=I+1,I;s_(550928,0,24);c[137730]=56192;c[137738]=y;y=c[137731]|0;A=y+4|0;I=c[A>>2]|0,c[A>>2]=I+1,I;if((c[137806]|0)!=-1){c[h>>2]=551224;c[h+4>>2]=16;c[h+8>>2]=0;mU(551224,h)}z=(c[137807]|0)-1|0;B=c[y+8>>2]|0;do{if((c[y+12>>2]|0)-B>>2>>>0>z>>>0){C=c[B+(z<<2)>>2]|0;if((C|0)==0){break}D=C;if(((I=c[A>>2]|0,c[A>>2]=I+ -1,I)|0)==0){f$[c[(c[y>>2]|0)+8>>2]&511](y|0)}c[137739]=D;c[137740]=551040;a[550964]=(f2[c[(c[C>>2]|0)+28>>2]&255](D)|0)&1;c[137950]=55876;c[137951]=55896;c[137957]=550920;c[137955]=0;c[137956]=0;c[137952]=4098;c[137954]=0;c[137953]=6;s_(551836,0,40);D=c[(q$()|0)>>2]|0;c[137958]=D;C=D+4|0;I=c[C>>2]|0,c[C>>2]=I+1,I;c[137969]=0;c[137970]=-1;C=c[(c[(c[137950]|0)-12>>2]|0)+551824>>2]|0;c[137928]=55876;c[137929]=55896;c[137935]=C;c[137933]=(C|0)==0;c[137934]=0;c[137930]=4098;c[137932]=0;c[137931]=6;s_(551748,0,40);C=c[(q$()|0)>>2]|0;c[137936]=C;D=C+4|0;I=c[D>>2]|0,c[D>>2]=I+1,I;c[137947]=0;c[137948]=-1;c[(c[(c[137972]|0)-12>>2]|0)+551960>>2]=551624;D=(c[(c[137950]|0)-12>>2]|0)+551804|0;c[D>>2]=c[D>>2]|8192;c[(c[(c[137950]|0)-12>>2]|0)+551872>>2]=551624;D=c[s>>2]|0;c[137704]=55632;C=c[(q$()|0)>>2]|0;c[137705]=C;E=C+4|0;I=c[E>>2]|0,c[E>>2]=I+1,I;s_(550824,0,24);c[137704]=56520;c[137712]=D;c[137714]=551048;c[137716]=-1;a[550868]=0;D=c[137705]|0;E=D+4|0;I=c[E>>2]|0,c[E>>2]=I+1,I;if((c[137804]|0)!=-1){c[d>>2]=551216;c[d+4>>2]=16;c[d+8>>2]=0;mU(551216,d)}C=(c[137805]|0)-1|0;F=c[D+8>>2]|0;do{if((c[D+12>>2]|0)-F>>2>>>0>C>>>0){G=c[F+(C<<2)>>2]|0;if((G|0)==0){break}H=G;c[137713]=H;c[137715]=f2[c[(c[G>>2]|0)+24>>2]&255](H)|0;H=c[137713]|0;a[550869]=(f2[c[(c[H>>2]|0)+28>>2]&255](H)|0)&1;if((c[137715]|0)>8){H=fc(8)|0;c[H>>2]=53944;G=H+4|0;J=G;do{if((G|0)!=0){while(1){K=sR(50)|0;if((K|0)!=0){v=6703;break}L=(I=c[138018]|0,c[138018]=I+0,I);if((L|0)==0){break}gp[L&63]()}if((v|0)==6703){c[K+4>>2]=37;c[K>>2]=37;L=K+12|0;c[J>>2]=L;c[K+8>>2]=0;s1(L|0,12016,38)|0;break}L=fc(4)|0;c[L>>2]=53880;dq(L|0,60400,240)}}while(0);dq(H|0,60432,122)}if(((I=c[E>>2]|0,c[E>>2]=I+ -1,I)|0)==0){f$[c[(c[D>>2]|0)+8>>2]&511](D|0)}c[137884]=55924;c[137886]=55944;c[137885]=0;c[137892]=550816;c[137890]=0;c[137891]=0;c[137887]=4098;c[137889]=0;c[137888]=6;s_(551576,0,40);J=c[(q$()|0)>>2]|0;c[137893]=J;G=J+4|0;I=c[G>>2]|0,c[G>>2]=I+1,I;c[137904]=0;c[137905]=-1;G=c[q>>2]|0;c[137680]=55632;J=c[(q$()|0)>>2]|0;c[137681]=J;L=J+4|0;I=c[L>>2]|0,c[L>>2]=I+1,I;s_(550728,0,24);c[137680]=56120;c[137688]=G;G=c[137681]|0;L=G+4|0;I=c[L>>2]|0,c[L>>2]=I+1,I;if((c[137804]|0)!=-1){c[g>>2]=551216;c[g+4>>2]=16;c[g+8>>2]=0;mU(551216,g)}J=(c[137805]|0)-1|0;M=c[G+8>>2]|0;do{if((c[G+12>>2]|0)-M>>2>>>0>J>>>0){N=c[M+(J<<2)>>2]|0;if((N|0)==0){break}O=N;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f$[c[(c[G>>2]|0)+8>>2]&511](G|0)}c[137689]=O;c[137690]=551056;a[550764]=(f2[c[(c[N>>2]|0)+28>>2]&255](O)|0)&1;c[137814]=55828;c[137815]=55848;c[137821]=550720;c[137819]=0;c[137820]=0;c[137816]=4098;c[137818]=0;c[137817]=6;s_(551292,0,40);O=c[(q$()|0)>>2]|0;c[137822]=O;N=O+4|0;I=c[N>>2]|0,c[N>>2]=I+1,I;c[137833]=0;c[137834]=-1;N=c[t>>2]|0;c[137692]=55632;O=c[(q$()|0)>>2]|0;c[137693]=O;P=O+4|0;I=c[P>>2]|0,c[P>>2]=I+1,I;s_(550776,0,24);c[137692]=56120;c[137700]=N;N=c[137693]|0;P=N+4|0;I=c[P>>2]|0,c[P>>2]=I+1,I;if((c[137804]|0)!=-1){c[f>>2]=551216;c[f+4>>2]=16;c[f+8>>2]=0;mU(551216,f)}O=(c[137805]|0)-1|0;Q=c[N+8>>2]|0;do{if((c[N+12>>2]|0)-Q>>2>>>0>O>>>0){R=c[Q+(O<<2)>>2]|0;if((R|0)==0){break}S=R;if(((I=c[P>>2]|0,c[P>>2]=I+ -1,I)|0)==0){f$[c[(c[N>>2]|0)+8>>2]&511](N|0)}c[137701]=S;c[137702]=551064;a[550812]=(f2[c[(c[R>>2]|0)+28>>2]&255](S)|0)&1;c[137858]=55828;c[137859]=55848;c[137865]=550768;c[137863]=0;c[137864]=0;c[137860]=4098;c[137862]=0;c[137861]=6;s_(551468,0,40);S=c[(q$()|0)>>2]|0;c[137866]=S;R=S+4|0;I=c[R>>2]|0,c[R>>2]=I+1,I;c[137877]=0;c[137878]=-1;R=c[(c[(c[137858]|0)-12>>2]|0)+551456>>2]|0;c[137836]=55828;c[137837]=55848;c[137843]=R;c[137841]=(R|0)==0;c[137842]=0;c[137838]=4098;c[137840]=0;c[137839]=6;s_(551380,0,40);R=c[(q$()|0)>>2]|0;c[137844]=R;S=R+4|0;I=c[S>>2]|0,c[S>>2]=I+1,I;c[137855]=0;c[137856]=-1;c[(c[(c[137884]|0)-12>>2]|0)+551608>>2]=551256;S=(c[(c[137858]|0)-12>>2]|0)+551436|0;c[S>>2]=c[S>>2]|8192;c[(c[(c[137858]|0)-12>>2]|0)+551504>>2]=551256;en(232,551976,r|0)|0;i=b;return}}while(0);N=fc(4)|0;c[N>>2]=53912;dq(N|0,60416,316)}}while(0);G=fc(4)|0;c[G>>2]=53912;dq(G|0,60416,316)}}while(0);D=fc(4)|0;c[D>>2]=53912;dq(D|0,60416,316)}}while(0);y=fc(4)|0;c[y>>2]=53912;dq(y|0,60416,316)}}while(0);n=fc(4)|0;c[n>>2]=53912;dq(n|0,60416,316)}}while(0);b=fc(4)|0;c[b>>2]=53912;dq(b|0,60416,316)}function mF(a){a=a|0;return c[a+4>>2]|0}function mG(a){a=a|0;return c[a+4>>2]|0}function mH(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=d;c[a+4>>2]=b;return}function mI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((c[b+4>>2]|0)!=(a|0)){e=0;return e|0}e=(c[b>>2]|0)==(d|0);return e|0}function mJ(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=54008;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){sS(e)}if((a|0)!=0){break}return}}while(0);sS(a);return}function mK(a){a=a|0;var b=0;c[a>>2]=54008;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}sS(a);return}function mL(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=53944;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){sS(e)}if((a|0)!=0){break}return}}while(0);sS(a);return}function mM(a){a=a|0;var b=0;c[a>>2]=53944;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}sS(a);return}function mN(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=54008;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){sS(e)}if((a|0)!=0){break}return}}while(0);sS(a);return}function mO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=e|0;go[c[(c[a>>2]|0)+12>>2]&127](f,a,b);if((c[f+4>>2]|0)!=(c[d+4>>2]|0)){g=0;i=e;return g|0}g=(c[f>>2]|0)==(c[d>>2]|0);i=e;return g|0}function mP(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=53944;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){sS(e)}if((a|0)!=0){break}return}}while(0);sS(a);return}function mQ(a){a=a|0;var b=0;c[a>>2]=53944;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}sS(a);return}function mR(b){b=b|0;var d=0;if((a[b]&1)==0){return}d=c[b+8>>2]|0;if((d|0)==0){return}sS(d);return}function mS(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=sZ(d|0)|0;f=b;g=b;h=a[g]|0;if((h&1)==0){i=10;j=h}else{h=c[b>>2]|0;i=(h&-2)-1|0;j=h&255}if(i>>>0<e>>>0){h=j&255;if((h&1|0)==0){k=h>>>1}else{k=c[b+4>>2]|0}mZ(b,i,e-i|0,k,0,k,e,d);return}if((j&1)==0){l=f+1|0}else{l=c[b+8>>2]|0}s5(l|0,d|0,e|0);a[l+e|0]=0;if((a[g]&1)==0){a[g]=e<<1&255;return}else{c[b+4>>2]=e;return}}function mT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)==0){return}e=b;f=a[e]|0;if((f&1)==0){g=10;h=f}else{f=c[b>>2]|0;g=(f&-2)-1|0;h=f&255}f=h&255;if((f&1|0)==0){i=f>>>1}else{i=c[b+4>>2]|0}if((g-i|0)>>>0<d>>>0){m_(b,g,d-g+i|0,i,i,0);j=a[e]|0}else{j=h}if((j&1)==0){k=b+1|0}else{k=c[b+8>>2]|0}s_(k+i|0,0,d|0);j=i+d|0;if((a[e]&1)==0){a[e]=j<<1&255}else{c[b+4>>2]=j}a[k+j|0]=0;return}function mU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d;if((c[a>>2]|0)==1){do{bR(62168,62160)|0;}while((c[a>>2]|0)==1)}if((c[a>>2]|0)!=0){e;return}c[a>>2]=1;f;f=b+4|0;e=(c[b>>2]|0)+(c[f+4>>2]|0)|0;b=c[f>>2]|0;if((b&1|0)==0){g=b}else{g=c[(c[e>>2]|0)+(b-1)>>2]|0}f$[g&511](e);h;c[a>>2]=-1;i;d6(62168)|0;return}function mV(){var a=0,b=0,d=0,e=0,f=0,g=0;a=fc(8)|0;c[a>>2]=54008;b=a+4|0;d=b;if((b|0)==0){e=a;c[e>>2]=53976;dq(a|0,60448,162)}while(1){f=sR(25)|0;if((f|0)!=0){g=6905;break}b=(I=c[138018]|0,c[138018]=I+0,I);if((b|0)==0){g=6899;break}gp[b&63]()}if((g|0)==6899){b=fc(4)|0;c[b>>2]=53880;dq(b|0,60400,240)}else if((g|0)==6905){c[f+4>>2]=12;c[f>>2]=12;g=f+12|0;c[d>>2]=g;c[f+8>>2]=0;s1(g|0,15352,13)|0;e=a;c[e>>2]=53976;dq(a|0,60448,162)}}function mW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=b;e=b;f=a[e]|0;if((f&1)==0){g=10;h=f}else{f=c[b>>2]|0;g=(f&-2)-1|0;h=f&255}f=h&255;i=(f&1|0)==0;if(i){j=f>>>1}else{j=c[b+4>>2]|0}if(j>>>0<11){k=11}else{k=j+16&-16}l=k-1|0;if((l|0)==(g|0)){return}if((l|0)==10){m=d+1|0;n=c[b+8>>2]|0;o=1;p=0}else{q=(k|0)==0?1:k;L8590:do{if(l>>>0>g>>>0){while(1){r=sR(q)|0;if((r|0)!=0){s=r;break L8590}r=(I=c[138018]|0,c[138018]=I+0,I);if((r|0)==0){break}gp[r&63]()}r=fc(4)|0;c[r>>2]=53880;dq(r|0,60400,240)}else{while(1){r=sR(q)|0;if((r|0)!=0){s=r;break L8590}r=(I=c[138018]|0,c[138018]=I+0,I);if((r|0)==0){break}gp[r&63]()}r=fc(4)|0;c[r>>2]=53880;dq(r|0,60400,240)}}while(0);q=h&1;if(q<<24>>24==0){t=d+1|0}else{t=c[b+8>>2]|0}m=s;n=t;o=q<<24>>24!=0;p=1}if(i){u=f>>>1}else{u=c[b+4>>2]|0}f=u+1|0;s1(m|0,n|0,f)|0;if(!(o^1|(n|0)==0)){sS(n)}if(p){c[b>>2]=k|1;c[b+4>>2]=j;c[b+8>>2]=m;return}else{a[e]=j<<1&255;return}}function mX(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b;g=a[f]|0;if((g&1)==0){h=10;i=g}else{g=c[b>>2]|0;h=(g&-2)-1|0;i=g&255}g=i&255;if((g&1|0)==0){j=g>>>1}else{j=c[b+4>>2]|0}if((h-j|0)>>>0<e>>>0){mZ(b,h,e-h+j|0,j,j,0,e,d);return}if((e|0)==0){return}if((i&1)==0){k=b+1|0}else{k=c[b+8>>2]|0}i=k+j|0;s1(i|0,d|0,e)|0;d=j+e|0;if((a[f]&1)==0){a[f]=d<<1&255}else{c[b+4>>2]=d}a[k+d|0]=0;return}function mY(b){b=b|0;var d=0;if((a[b]&1)==0){return}d=c[b+8>>2]|0;if((d|0)==0){return}sS(d);return}function mZ(b,d,e,f,g,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((-3-d|0)>>>0<e>>>0){mV()}if((a[b]&1)==0){k=b+1|0}else{k=c[b+8>>2]|0}do{if(d>>>0<2147483631){l=e+d|0;m=d<<1;n=l>>>0<m>>>0?m:l;if(n>>>0<11){o=11;break}o=n+16&-16}else{o=-2}}while(0);e=(o|0)==0?1:o;while(1){p=sR(e)|0;if((p|0)!=0){break}n=(I=c[138018]|0,c[138018]=I+0,I);if((n|0)==0){q=7002;break}gp[n&63]()}if((q|0)==7002){q=fc(4)|0;c[q>>2]=53880;dq(q|0,60400,240)}if((g|0)!=0){s1(p|0,k|0,g)|0}if((i|0)!=0){q=p+g|0;s1(q|0,j|0,i)|0}j=f-h|0;if((j|0)!=(g|0)){f=j-g|0;q=p+(i+g)|0;e=k+(h+g)|0;s1(q|0,e|0,f)|0}if((d|0)==10|(k|0)==0){r=b+8|0;c[r>>2]=p;s=o|1;t=b|0;c[t>>2]=s;u=j+i|0;v=b+4|0;c[v>>2]=u;w=p+u|0;a[w]=0;return}sS(k);r=b+8|0;c[r>>2]=p;s=o|1;t=b|0;c[t>>2]=s;u=j+i|0;v=b+4|0;c[v>>2]=u;w=p+u|0;a[w]=0;return}function m_(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((-3-d|0)>>>0<e>>>0){mV()}if((a[b]&1)==0){i=b+1|0}else{i=c[b+8>>2]|0}do{if(d>>>0<2147483631){j=e+d|0;k=d<<1;l=j>>>0<k>>>0?k:j;if(l>>>0<11){m=11;break}m=l+16&-16}else{m=-2}}while(0);e=(m|0)==0?1:m;while(1){n=sR(e)|0;if((n|0)!=0){break}l=(I=c[138018]|0,c[138018]=I+0,I);if((l|0)==0){o=7032;break}gp[l&63]()}if((o|0)==7032){o=fc(4)|0;c[o>>2]=53880;dq(o|0,60400,240)}if((g|0)!=0){s1(n|0,i|0,g)|0}if((f|0)!=(g|0)){o=f-g|0;f=n+(h+g)|0;h=i+g|0;s1(f|0,h|0,o)|0}if((d|0)==10|(i|0)==0){p=b+8|0;c[p>>2]=n;q=m|1;r=b|0;c[r>>2]=q;return}sS(i);p=b+8|0;c[p>>2]=n;q=m|1;r=b|0;c[r>>2]=q;return}function m$(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b;g=a[f]|0;if((g&1)==0){h=1;i=g}else{g=c[b>>2]|0;h=(g&-2)-1|0;i=g&255}if(h>>>0>=e>>>0){if((i&1)==0){j=b+4|0}else{j=c[b+8>>2]|0}g=(e|0)==0;do{if(j-d>>2>>>0<e>>>0){if(g){break}else{k=e}do{k=k-1|0;c[j+(k<<2)>>2]=c[d+(k<<2)>>2];}while((k|0)!=0)}else{if(g){break}else{l=d;m=e;n=j}while(1){o=m-1|0;c[n>>2]=c[l>>2];if((o|0)==0){break}else{l=l+4|0;m=o;n=n+4|0}}}}while(0);c[j+(e<<2)>>2]=0;if((a[f]&1)==0){a[f]=e<<1&255;return}else{c[b+4>>2]=e;return}}if((1073741821-h|0)>>>0<(e-h|0)>>>0){mV()}if((i&1)==0){p=b+4|0}else{p=c[b+8>>2]|0}do{if(h>>>0<536870895){i=h<<1;f=i>>>0>e>>>0?i:e;if(f>>>0<2){q=2;break}q=f+4&-4}else{q=1073741822}}while(0);f=q<<2;i=(f|0)==0?1:f;while(1){r=sR(i)|0;if((r|0)!=0){break}f=(I=c[138018]|0,c[138018]=I+0,I);if((f|0)==0){s=7074;break}gp[f&63]()}if((s|0)==7074){s=fc(4)|0;c[s>>2]=53880;dq(s|0,60400,240)}s=r;if((e|0)!=0){r=d;d=e;i=s;while(1){f=d-1|0;c[i>>2]=c[r>>2];if((f|0)==0){break}else{r=r+4|0;d=f;i=i+4|0}}}if(!((h|0)==1|(p|0)==0)){sS(p)}c[b+8>>2]=s;c[b>>2]=q|1;c[b+4>>2]=e;c[s+(e<<2)>>2]=0;return}function m0(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b;e=a[d]|0;if((e&1)==0){f=1;g=e}else{e=c[b>>2]|0;f=(e&-2)-1|0;g=e&255}e=g&255;h=(e&1|0)==0;if(h){i=e>>>1}else{i=c[b+4>>2]|0}if(i>>>0<2){j=2}else{j=i+4&-4}k=j-1|0;if((k|0)==(f|0)){return}if((k|0)==1){l=b+4|0;m=c[b+8>>2]|0;n=1;o=0}else{p=j<<2;q=(p|0)==0?1:p;L8784:do{if(k>>>0>f>>>0){while(1){p=sR(q)|0;if((p|0)!=0){r=p;break L8784}p=(I=c[138018]|0,c[138018]=I+0,I);if((p|0)==0){break}gp[p&63]()}p=fc(4)|0;c[p>>2]=53880;dq(p|0,60400,240)}else{while(1){p=sR(q)|0;if((p|0)!=0){r=p;break L8784}p=(I=c[138018]|0,c[138018]=I+0,I);if((p|0)==0){break}gp[p&63]()}p=fc(4)|0;c[p>>2]=53880;dq(p|0,60400,240)}}while(0);q=g&1;if(q<<24>>24==0){s=b+4|0}else{s=c[b+8>>2]|0}l=r;m=s;n=q<<24>>24!=0;o=1}q=l;if(h){t=e>>>1}else{t=c[b+4>>2]|0}e=t+1|0;if((e|0)!=0){t=m;h=e;e=q;while(1){l=h-1|0;c[e>>2]=c[t>>2];if((l|0)==0){break}else{t=t+4|0;h=l;e=e+4|0}}}if(!(n^1|(m|0)==0)){sS(m)}if(o){c[b>>2]=j|1;c[b+4>>2]=i;c[b+8>>2]=q;return}else{a[d]=i<<1&255;return}}function m1(a,b){a=a|0;b=b|0;return}function m2(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function m3(a){a=a|0;return 0}function m4(a){a=a|0;return 0}function m5(a){a=a|0;return-1|0}function m6(a,b){a=a|0;b=b|0;return-1|0}function m7(a,b){a=a|0;b=b|0;return-1|0}function m8(a,b){a=a|0;b=b|0;return}function m9(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function na(a){a=a|0;return 0}function nb(a){a=a|0;return 0}function nc(a){a=a|0;return-1|0}function nd(a,b){a=a|0;b=b|0;return-1|0}function ne(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=a;c[g>>2]=0;c[g+4>>2]=0;g=a+8|0;c[g>>2]=-1;c[g+4>>2]=-1;return}function nf(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=i;b=d;d=i;i=i+16|0;c[d>>2]=c[b>>2];c[d+4>>2]=c[b+4>>2];c[d+8>>2]=c[b+8>>2];c[d+12>>2]=c[b+12>>2];b=a;c[b>>2]=0;c[b+4>>2]=0;b=a+8|0;c[b>>2]=-1;c[b+4>>2]=-1;i=e;return}function ng(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=a;c[g>>2]=0;c[g+4>>2]=0;g=a+8|0;c[g>>2]=-1;c[g+4>>2]=-1;return}function nh(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=i;b=d;d=i;i=i+16|0;c[d>>2]=c[b>>2];c[d+4>>2]=c[b+4>>2];c[d+8>>2]=c[b+8>>2];c[d+12>>2]=c[b+12>>2];b=a;c[b>>2]=0;c[b+4>>2]=0;b=a+8|0;c[b>>2]=-1;c[b+4>>2]=-1;i=e;return}function ni(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=55704;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;sS(e);return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);e=a;sS(e);return}function nj(a){a=a|0;var b=0;c[a>>2]=55704;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);return}function nk(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;if((e|0)<=0){g=0;return g|0}h=b+12|0;i=b+16|0;j=d;d=0;while(1){k=c[h>>2]|0;if(k>>>0<(c[i>>2]|0)>>>0){c[h>>2]=k+1;l=a[k]|0}else{k=f2[c[(c[f>>2]|0)+40>>2]&255](b)|0;if((k|0)==-1){g=d;m=7173;break}l=k&255}a[j]=l;k=d+1|0;if((k|0)<(e|0)){j=j+1|0;d=k}else{g=k;m=7172;break}}if((m|0)==7172){return g|0}else if((m|0)==7173){return g|0}return 0}function nl(a){a=a|0;var b=0,e=0;if((f2[c[(c[a>>2]|0)+36>>2]&255](a)|0)==-1){b=-1;return b|0}e=a+12|0;a=c[e>>2]|0;c[e>>2]=a+1;b=d[a]|0;return b|0}function nm(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;if((f|0)<=0){h=0;return h|0}i=b+24|0;j=b+28|0;k=0;l=e;while(1){e=c[i>>2]|0;if(e>>>0<(c[j>>2]|0)>>>0){m=a[l]|0;c[i>>2]=e+1;a[e]=m}else{if((gj[c[(c[g>>2]|0)+52>>2]&127](b,d[l]|0)|0)==-1){h=k;n=7189;break}}m=k+1|0;if((m|0)<(f|0)){k=m;l=l+1|0}else{h=m;n=7188;break}}if((n|0)==7189){return h|0}else if((n|0)==7188){return h|0}return 0}function nn(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=55632;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;sS(e);return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);e=a;sS(e);return}function no(a){a=a|0;var b=0;c[a>>2]=55632;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}f$[c[(c[b>>2]|0)+8>>2]&511](b|0);return}function np(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a;if((d|0)<=0){f=0;return f|0}g=a+12|0;h=a+16|0;i=b;b=0;while(1){j=c[g>>2]|0;if(j>>>0<(c[h>>2]|0)>>>0){c[g>>2]=j+4;k=c[j>>2]|0}else{j=f2[c[(c[e>>2]|0)+40>>2]&255](a)|0;if((j|0)==-1){f=b;l=7207;break}else{k=j}}c[i>>2]=k;j=b+1|0;if((j|0)<(d|0)){i=i+4|0;b=j}else{f=j;l=7209;break}}if((l|0)==7209){return f|0}else if((l|0)==7207){return f|0}return 0}function nq(a){a=a|0;var b=0,d=0;if((f2[c[(c[a>>2]|0)+36>>2]&255](a)|0)==-1){b=-1;return b|0}d=a+12|0;a=c[d>>2]|0;c[d>>2]=a+4;b=c[a>>2]|0;return b|0}function nr(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((1073741821-d|0)>>>0<e>>>0){mV()}if((a[b]&1)==0){j=b+4|0}else{j=c[b+8>>2]|0}do{if(d>>>0<536870895){k=e+d|0;l=d<<1;m=k>>>0<l>>>0?l:k;if(m>>>0<2){n=2;break}n=m+4&-4}else{n=1073741822}}while(0);e=n<<2;m=(e|0)==0?1:e;while(1){o=sR(m)|0;if((o|0)!=0){break}e=(I=c[138018]|0,c[138018]=I+0,I);if((e|0)==0){p=7231;break}gp[e&63]()}if((p|0)==7231){p=fc(4)|0;c[p>>2]=53880;dq(p|0,60400,240)}p=o;if((g|0)!=0){o=j;m=g;e=p;while(1){k=m-1|0;c[e>>2]=c[o>>2];if((k|0)==0){break}else{o=o+4|0;m=k;e=e+4|0}}}e=f-h|0;if((e|0)!=(g|0)){f=j+(h+g<<2)|0;h=e-g|0;e=p+(i+g<<2)|0;while(1){g=h-1|0;c[e>>2]=c[f>>2];if((g|0)==0){break}else{f=f+4|0;h=g;e=e+4|0}}}if((d|0)==1|(j|0)==0){q=b+8|0;c[q>>2]=p;r=n|1;s=b|0;c[s>>2]=r;return}sS(j);q=b+8|0;c[q>>2]=p;r=n|1;s=b|0;c[s>>2]=r;return}function ns(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+48|0;g=f|0;h=f+16|0;j=f+32|0;k=(c[b+24>>2]|0)==0;if(k){c[b+16>>2]=e|1}else{c[b+16>>2]=e}if((c[b+20>>2]&(k&1|e)|0)==0){i=f;return}f=fc(16)|0;do{if((a[682984]|0)==0){if((cQ(682984)|0)==0){break}c[137524]=55472}}while(0);e=h;k=j;while(1){l=sR(16)|0;if((l|0)!=0){break}b=(I=c[138018]|0,c[138018]=I+0,I);if((b|0)==0){m=7260;break}gp[b&63]()}if((m|0)==7260){b=fc(4)|0;c[b>>2]=53880;dq(b|0,60400,240)}b=j+8|0;c[b>>2]=l;c[j>>2]=17;n=j+4|0;c[n>>2]=15;s1(l|0,36816,15)|0;a[l+15|0]=0;l=g;o=d[k]|0;if((((o&1|0)==0?o>>>1:c[n>>2]|0)|0)!=0){mX(j,47864,2)}go[c[(c[137524]|0)+24>>2]&127](g,550096,1);n=a[l]|0;if((n&1)==0){p=g+1|0}else{p=c[g+8>>2]|0}o=n&255;if((o&1|0)==0){q=o>>>1}else{q=c[g+4>>2]|0}mX(j,p,q);do{if((a[l]&1)!=0){q=c[g+8>>2]|0;if((q|0)==0){break}sS(q)}}while(0);c[e>>2]=c[k>>2];c[e+4>>2]=c[k+4>>2];c[e+8>>2]=c[k+8>>2];s_(k|0,0,12);g=f;c[g>>2]=53944;l=f+4|0;q=l;p=a[e]&1;do{if((l|0)==0){r=p}else{if(p<<24>>24==0){s=h+1|0}else{s=c[h+8>>2]|0}e=sZ(s|0)|0;j=e+13|0;o=(j|0)==0?1:j;while(1){t=sR(o)|0;if((t|0)!=0){m=7293;break}j=(I=c[138018]|0,c[138018]=I+0,I);if((j|0)==0){break}gp[j&63]()}if((m|0)==7293){o=e+1|0;c[t+4>>2]=e;c[t>>2]=e;j=t+12|0;c[q>>2]=j;c[t+8>>2]=0;s1(j|0,s|0,o)|0;r=p;break}o=fc(4)|0;c[o>>2]=53880;dq(o|0,60400,240)}}while(0);do{if(r<<24>>24!=0){p=c[h+8>>2]|0;if((p|0)==0){break}sS(p)}}while(0);do{if((a[k]&1)!=0){h=c[b>>2]|0;if((h|0)==0){break}sS(h)}}while(0);c[g>>2]=56088;b=f+8|0;k=tc(550096,0,32)|0;h=K;c[b>>2]=k&0|1;c[b+4>>2]=h|0;c[g>>2]=54656;dq(f|0,60992,40)}function nt(a){a=a|0;var b=0,d=0,e=0,f=0;c[a>>2]=54632;b=c[a+40>>2]|0;d=a+32|0;e=a+36|0;if((b|0)!=0){f=b;do{f=f-1|0;go[c[(c[d>>2]|0)+(f<<2)>>2]&127](0,a,c[(c[e>>2]|0)+(f<<2)>>2]|0);}while((f|0)!=0)}f=c[a+28>>2]|0;b=f+4|0;if(((I=c[b>>2]|0,c[b>>2]=I+ -1,I)|0)==0){f$[c[(c[f>>2]|0)+8>>2]&511](f)}sS(c[d>>2]|0);sS(c[e>>2]|0);sS(c[a+48>>2]|0);sS(c[a+60>>2]|0);return}function nu(a,b){a=a|0;b=b|0;return-1|0}function nv(a){a=a|0;return 45856|0}function nw(a){a=a|0;return}function nx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a;if((d|0)<=0){f=0;return f|0}g=a+24|0;h=a+28|0;i=0;j=b;while(1){b=c[g>>2]|0;if(b>>>0<(c[h>>2]|0)>>>0){k=c[j>>2]|0;c[g>>2]=b+4;c[b>>2]=k}else{if((gj[c[(c[e>>2]|0)+52>>2]&127](a,c[j>>2]|0)|0)==-1){f=i;l=7337;break}}k=i+1|0;if((k|0)<(d|0)){i=k;j=j+4|0}else{f=k;l=7335;break}}if((l|0)==7337){return f|0}else if((l|0)==7335){return f|0}return 0}function ny(a){a=a|0;nt(a+8|0);if((a|0)==0){return}sS(a);return}function nz(a){a=a|0;nt(a+8|0);return}function nA(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;nt(b+(d+8)|0);if((a|0)==0){return}sS(a);return}function nB(a){a=a|0;nt(a+((c[(c[a>>2]|0)-12>>2]|0)+8)|0);return}function nC(a){a=a|0;nt(a+8|0);if((a|0)==0){return}sS(a);return}function nD(a){a=a|0;nt(a+8|0);return}function nE(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;nt(b+(d+8)|0);if((a|0)==0){return}sS(a);return}function nF(a){a=a|0;nt(a+((c[(c[a>>2]|0)-12>>2]|0)+8)|0);return}function nG(a){a=a|0;nt(a+4|0);if((a|0)==0){return}sS(a);return}function nH(a){a=a|0;nt(a+4|0);return}function nI(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;nt(b+(d+4)|0);if((a|0)==0){return}sS(a);return}function nJ(a){a=a|0;nt(a+((c[(c[a>>2]|0)-12>>2]|0)+4)|0);return}function nK(a){a=a|0;nt(a+4|0);if((a|0)==0){return}sS(a);return}function nL(a){a=a|0;nt(a+4|0);return}function nM(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;nt(b+(d+4)|0);if((a|0)==0){return}sS(a);return}function nN(a){a=a|0;nt(a+((c[(c[a>>2]|0)-12>>2]|0)+4)|0);return}function nO(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=53944;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){sS(e)}if((a|0)!=0){break}return}}while(0);sS(a);return}function nP(a){a=a|0;var b=0;c[a>>2]=53944;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}sS(a);return}function nQ(a){a=a|0;nt(a);if((a|0)==0){return}sS(a);return}function nR(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=b;g=c[(c[f>>2]|0)-12>>2]|0;h=b;if((c[h+(g+24)>>2]|0)==0){i=d;return}j=e|0;a[j]=0;c[e+4>>2]=b;do{if((c[h+(g+16)>>2]|0)==0){b=c[h+(g+72)>>2]|0;if((b|0)==0){k=g}else{nR(b);k=c[(c[f>>2]|0)-12>>2]|0}a[j]=1;b=c[h+(k+24)>>2]|0;if((f2[c[(c[b>>2]|0)+24>>2]&255](b)|0)!=-1){break}b=c[(c[f>>2]|0)-12>>2]|0;ns(h+b|0,c[h+(b+16)>>2]|1)}}while(0);nT(e);i=d;return}function nS(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=b;g=c[(c[f>>2]|0)-12>>2]|0;h=b;if((c[h+(g+24)>>2]|0)==0){i=d;return}j=e|0;a[j]=0;c[e+4>>2]=b;do{if((c[h+(g+16)>>2]|0)==0){b=c[h+(g+72)>>2]|0;if((b|0)==0){k=g}else{nS(b);k=c[(c[f>>2]|0)-12>>2]|0}a[j]=1;b=c[h+(k+24)>>2]|0;if((f2[c[(c[b>>2]|0)+24>>2]&255](b)|0)!=-1){break}b=c[(c[f>>2]|0)-12>>2]|0;ns(h+b|0,c[h+(b+16)>>2]|1)}}while(0);nU(e);i=d;return}function nT(a){a=a|0;var b=0,d=0,e=0;b=a+4|0;a=c[b>>2]|0;d=c[(c[a>>2]|0)-12>>2]|0;e=a;if((c[e+(d+24)>>2]|0)==0){return}if((c[e+(d+16)>>2]|0)!=0){return}if((c[e+(d+4)>>2]&8192|0)==0){return}if(c3()|0){return}d=c[b>>2]|0;e=c[d+((c[(c[d>>2]|0)-12>>2]|0)+24)>>2]|0;if((f2[c[(c[e>>2]|0)+24>>2]&255](e)|0)!=-1){return}e=c[b>>2]|0;b=c[(c[e>>2]|0)-12>>2]|0;d=e;ns(d+b|0,c[d+(b+16)>>2]|1);return}function nU(a){a=a|0;var b=0,d=0,e=0;b=a+4|0;a=c[b>>2]|0;d=c[(c[a>>2]|0)-12>>2]|0;e=a;if((c[e+(d+24)>>2]|0)==0){return}if((c[e+(d+16)>>2]|0)!=0){return}if((c[e+(d+4)>>2]&8192|0)==0){return}if(c3()|0){return}d=c[b>>2]|0;e=c[d+((c[(c[d>>2]|0)-12>>2]|0)+24)>>2]|0;if((f2[c[(c[e>>2]|0)+24>>2]&255](e)|0)!=-1){return}e=c[b>>2]|0;b=c[(c[e>>2]|0)-12>>2]|0;d=e;ns(d+b|0,c[d+(b+16)>>2]|1);return}function nV(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==1){while(1){f=sR(48)|0;if((f|0)!=0){g=7508;break}d=(I=c[138018]|0,c[138018]=I+0,I);if((d|0)==0){g=7505;break}gp[d&63]()}if((g|0)==7508){c[b+8>>2]=f;c[b>>2]=49;c[b+4>>2]=35;s1(f|0,49168,35)|0;a[f+35|0]=0;return}else if((g|0)==7505){f=fc(4)|0;c[f>>2]=53880;dq(f|0,60400,240)}}f=eq(e|0)|0;e=sZ(f|0)|0;if((e|0)==-1){mV()}do{if(e>>>0<11){a[b]=e<<1&255;h=b+1|0}else{d=e+16&-16;i=(d|0)==0?1:d;while(1){j=sR(i)|0;if((j|0)!=0){g=7496;break}k=(I=c[138018]|0,c[138018]=I+0,I);if((k|0)==0){break}gp[k&63]()}if((g|0)==7496){c[b+8>>2]=j;c[b>>2]=d|1;c[b+4>>2]=e;h=j;break}i=fc(4)|0;c[i>>2]=53880;dq(i|0,60400,240)}}while(0);s1(h|0,f|0,e)|0;a[h+e|0]=0;return}function nW(a){a=a|0;return}function nX(a){a=a|0;return}function nY(a){a=a|0;return}function nZ(a){a=a|0;return}function n_(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;L9191:do{if((e|0)==(f|0)){g=c}else{b=c;h=e;while(1){if((b|0)==(d|0)){i=-1;j=7526;break}k=a[b]|0;l=a[h]|0;if(k<<24>>24<l<<24>>24){i=-1;j=7525;break}if(l<<24>>24<k<<24>>24){i=1;j=7523;break}k=b+1|0;l=h+1|0;if((l|0)==(f|0)){g=k;break L9191}else{b=k;h=l}}if((j|0)==7525){return i|0}else if((j|0)==7526){return i|0}else if((j|0)==7523){return i|0}}}while(0);i=(g|0)!=(d|0)|0;return i|0}function n$(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((c|0)==(d|0)){e=0;return e|0}else{f=c;g=0}while(1){c=(a[f]|0)+(g<<4)|0;b=c&-268435456;h=(b>>>24|b)^c;c=f+1|0;if((c|0)==(d|0)){e=h;break}else{f=c;g=h}}return e|0}function n0(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;L9210:do{if((e|0)==(f|0)){g=b}else{a=b;h=e;while(1){if((a|0)==(d|0)){i=-1;j=7539;break}k=c[a>>2]|0;l=c[h>>2]|0;if((k|0)<(l|0)){i=-1;j=7540;break}if((l|0)<(k|0)){i=1;j=7541;break}k=a+4|0;l=h+4|0;if((l|0)==(f|0)){g=k;break L9210}else{a=k;h=l}}if((j|0)==7540){return i|0}else if((j|0)==7541){return i|0}else if((j|0)==7539){return i|0}}}while(0);i=(g|0)!=(d|0)|0;return i|0}function n1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b|0)==(d|0)){e=0;return e|0}else{f=b;g=0}while(1){b=(c[f>>2]|0)+(g<<4)|0;a=b&-268435456;h=(a>>>24|a)^b;b=f+4|0;if((b|0)==(d|0)){e=h;break}else{f=b;g=h}}return e|0}function n2(a){a=a|0;if((a|0)==0){return}sS(a);return}function n3(a){a=a|0;if((a|0)==0){return}sS(a);return}function n4(a){a=a|0;if((a|0)==0){return}sS(a);return}function n5(a){a=a|0;if((a|0)==0){return}sS(a);return}function n6(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=e;g=f-d|0;if((g|0)==-1){mV()}do{if(g>>>0<11){a[b]=g<<1&255;h=b+1|0}else{i=g+16&-16;j=(i|0)==0?1:i;while(1){k=sR(j)|0;if((k|0)!=0){l=7583;break}m=(I=c[138018]|0,c[138018]=I+0,I);if((m|0)==0){break}gp[m&63]()}if((l|0)==7583){c[b+8>>2]=k;c[b>>2]=i|1;c[b+4>>2]=g;h=k;break}j=fc(4)|0;c[j>>2]=53880;dq(j|0,60400,240)}}while(0);if((e|0)==(f|0)){n=h;a[n]=0;return}k=-d|0;d=h;g=e;while(1){a[d]=a[g]|0;e=g+1|0;if((e|0)==(f|0)){break}else{d=d+1|0;g=e}}n=h+(f+k)|0;a[n]=0;return}function n7(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=e;g=f-d|0;h=g>>2;if(h>>>0>1073741822){mV()}do{if(h>>>0<2){a[b]=g>>>1&255;i=b+4|0}else{j=h+4&-4;k=j<<2;l=(k|0)==0?1:k;while(1){m=sR(l)|0;if((m|0)!=0){n=7606;break}k=(I=c[138018]|0,c[138018]=I+0,I);if((k|0)==0){break}gp[k&63]()}if((n|0)==7606){l=m;c[b+8>>2]=l;c[b>>2]=j|1;c[b+4>>2]=h;i=l;break}l=fc(4)|0;c[l>>2]=53880;dq(l|0,60400,240)}}while(0);if((e|0)==(f|0)){o=i;c[o>>2]=0;return}h=f-4+(-d|0)|0;d=i;b=e;while(1){c[d>>2]=c[b>>2];e=b+4|0;if((e|0)==(f|0)){break}else{d=d+4|0;b=e}}o=i+((h>>>2)+1<<2)|0;c[o>>2]=0;return}function n8(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+88|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=k|0;m=k+16|0;n=k+32|0;o=k+40|0;p=k+48|0;q=k+56|0;r=k+64|0;if((c[g+4>>2]&1|0)==0){c[n>>2]=-1;s=c[(c[d>>2]|0)+16>>2]|0;t=e|0;c[p>>2]=c[t>>2];c[q>>2]=c[f>>2];gf[s&127](o,d,p,q,g,h,n);q=c[o>>2]|0;c[t>>2]=q;t=c[n>>2]|0;if((t|0)==1){a[j]=1}else if((t|0)==0){a[j]=0}else{a[j]=1;c[h>>2]=4}c[b>>2]=q;i=k;return}q=g+28|0;g=c[q>>2]|0;t=g+4|0;I=c[t>>2]|0,c[t>>2]=I+1,I;if((c[137882]|0)!=-1){c[m>>2]=551528;c[m+4>>2]=16;c[m+8>>2]=0;mU(551528,m)}m=(c[137883]|0)-1|0;n=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-n>>2>>>0>m>>>0){o=c[n+(m<<2)>>2]|0;if((o|0)==0){break}p=o;if(((I=c[t>>2]|0,c[t>>2]=I+ -1,I)|0)==0){f$[c[(c[g>>2]|0)+8>>2]&511](g)}o=c[q>>2]|0;d=o+4|0;I=c[d>>2]|0,c[d>>2]=I+1,I;if((c[137786]|0)!=-1){c[l>>2]=551144;c[l+4>>2]=16;c[l+8>>2]=0;mU(551144,l)}s=(c[137787]|0)-1|0;u=c[o+8>>2]|0;do{if((c[o+12>>2]|0)-u>>2>>>0>s>>>0){v=c[u+(s<<2)>>2]|0;if((v|0)==0){break}w=v;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)==0){f$[c[(c[o>>2]|0)+8>>2]&511](o)}x=r|0;y=v;f0[c[(c[y>>2]|0)+24>>2]&255](x,w);v=r+12|0;f0[c[(c[y>>2]|0)+28>>2]&255](v,w);a[j]=(n9(e,c[f>>2]|0,x,r+24|0,p,h,1)|0)==(x|0)|0;c[b>>2]=c[e>>2];do{if((a[v]&1)!=0){x=c[r+20>>2]|0;if((x|0)==0){break}sS(x)}}while(0);if((a[r]&1)==0){i=k;return}v=c[r+8>>2]|0;if((v|0)==0){i=k;return}sS(v);i=k;return}}while(0);p=fc(4)|0;c[p>>2]=53912;dq(p|0,60416,316)}}while(0);k=fc(4)|0;c[k>>2]=53912;dq(k|0,60416,316)}function n9(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;l=i;i=i+104|0;m=(g-f|0)/12|0;n=l|0;do{if(m>>>0>100){o=sR(m)|0;if((o|0)!=0){p=o;q=o;break}o=fc(4)|0;c[o>>2]=53880;dq(o|0,60400,240);return 0}else{p=n;q=0}}while(0);n=(f|0)==(g|0);if(n){r=m;s=0}else{o=m;m=0;t=p;u=f;while(1){v=d[u]|0;if((v&1|0)==0){w=v>>>1}else{w=c[u+4>>2]|0}if((w|0)==0){a[t]=2;x=m+1|0;y=o-1|0}else{a[t]=1;x=m;y=o}v=u+12|0;if((v|0)==(g|0)){r=y;s=x;break}else{o=y;m=x;t=t+1|0;u=v}}}u=b|0;b=h;t=0;x=s;s=r;r=e;L9358:while(1){e=(s|0)!=0;m=t;y=r;while(1){o=c[u>>2]|0;do{if((o|0)==0){z=0}else{if((c[o+12>>2]|0)!=(c[o+16>>2]|0)){z=o;break}if((f2[c[(c[o>>2]|0)+36>>2]&255](o)|0)==-1){c[u>>2]=0;z=0;break}else{z=c[u>>2]|0;break}}}while(0);o=(z|0)==0;if((y|0)==0){A=z;B=0}else{if((c[y+12>>2]|0)==(c[y+16>>2]|0)){C=(f2[c[(c[y>>2]|0)+36>>2]&255](y)|0)==-1?0:y}else{C=y}A=c[u>>2]|0;B=C}D=(B|0)==0;if(!((o^D)&e)){break L9358}o=c[A+12>>2]|0;if((o|0)==(c[A+16>>2]|0)){E=(f2[c[(c[A>>2]|0)+36>>2]&255](A)|0)&255}else{E=a[o]|0}if(k){F=E}else{F=gj[c[(c[b>>2]|0)+12>>2]&127](h,E)|0}G=m+1|0;if(n){m=G;y=B}else{break}}L9387:do{if(k){y=s;e=x;o=p;w=0;v=f;while(1){do{if((a[o]|0)==1){H=a[v]|0;if((H&1)==0){I=v+1|0}else{I=c[v+8>>2]|0}if(F<<24>>24!=(a[I+m|0]|0)){a[o]=0;J=w;K=e;L=y-1|0;break}M=H&255;if((M&1|0)==0){N=M>>>1}else{N=c[v+4>>2]|0}if((N|0)!=(G|0)){J=1;K=e;L=y;break}a[o]=2;J=1;K=e+1|0;L=y-1|0}else{J=w;K=e;L=y}}while(0);M=v+12|0;if((M|0)==(g|0)){O=L;P=K;Q=J;break L9387}y=L;e=K;o=o+1|0;w=J;v=M}}else{v=s;w=x;o=p;e=0;y=f;while(1){do{if((a[o]|0)==1){M=y;if((a[M]&1)==0){R=y+1|0}else{R=c[y+8>>2]|0}if(F<<24>>24!=(gj[c[(c[b>>2]|0)+12>>2]&127](h,a[R+m|0]|0)|0)<<24>>24){a[o]=0;S=e;T=w;U=v-1|0;break}H=d[M]|0;if((H&1|0)==0){V=H>>>1}else{V=c[y+4>>2]|0}if((V|0)!=(G|0)){S=1;T=w;U=v;break}a[o]=2;S=1;T=w+1|0;U=v-1|0}else{S=e;T=w;U=v}}while(0);H=y+12|0;if((H|0)==(g|0)){O=U;P=T;Q=S;break L9387}v=U;w=T;o=o+1|0;e=S;y=H}}}while(0);if(!Q){t=G;x=P;s=O;r=B;continue}m=c[u>>2]|0;y=m+12|0;e=c[y>>2]|0;if((e|0)==(c[m+16>>2]|0)){o=c[(c[m>>2]|0)+40>>2]|0;f2[o&255](m)|0}else{c[y>>2]=e+1}if((O+P|0)>>>0<2){t=G;x=P;s=O;r=B;continue}else{W=P;X=p;Y=f}while(1){do{if((a[X]|0)==2){e=d[Y]|0;if((e&1|0)==0){Z=e>>>1}else{Z=c[Y+4>>2]|0}if((Z|0)==(G|0)){_=W;break}a[X]=0;_=W-1|0}else{_=W}}while(0);e=Y+12|0;if((e|0)==(g|0)){t=G;x=_;s=O;r=B;continue L9358}else{W=_;X=X+1|0;Y=e}}}do{if((A|0)==0){$=0}else{if((c[A+12>>2]|0)!=(c[A+16>>2]|0)){$=A;break}if((f2[c[(c[A>>2]|0)+36>>2]&255](A)|0)==-1){c[u>>2]=0;$=0;break}else{$=c[u>>2]|0;break}}}while(0);u=($|0)==0;do{if(D){aa=7758}else{if((c[B+12>>2]|0)!=(c[B+16>>2]|0)){if(u){break}else{aa=7760;break}}if((f2[c[(c[B>>2]|0)+36>>2]&255](B)|0)==-1){aa=7758;break}if(!u){aa=7760}}}while(0);if((aa|0)==7758){if(u){aa=7760}}if((aa|0)==7760){c[j>>2]=c[j>>2]|2}L9462:do{if(n){aa=7765}else{u=f;B=p;while(1){if((a[B]|0)==2){ab=u;break L9462}D=u+12|0;if((D|0)==(g|0)){aa=7765;break L9462}u=D;B=B+1|0}}}while(0);if((aa|0)==7765){c[j>>2]=c[j>>2]|4;ab=g}if((q|0)==0){i=l;return ab|0}sS(q);i=l;return ab|0}function oa(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0;n=c[g>>2]|0;o=(n|0)==(f|0);do{if(o){p=(a[m+24|0]|0)==b<<24>>24;if(!p){if((a[m+25|0]|0)!=b<<24>>24){break}}c[g>>2]=f+1;a[f]=p?43:45;c[h>>2]=0;q=0;return q|0}}while(0);p=d[j]|0;if((p&1|0)==0){r=p>>>1}else{r=c[j+4>>2]|0}if((r|0)!=0&b<<24>>24==i<<24>>24){i=c[l>>2]|0;if((i-k|0)>=160){q=0;return q|0}k=c[h>>2]|0;c[l>>2]=i+4;c[i>>2]=k;c[h>>2]=0;q=0;return q|0}k=m+26|0;i=m;while(1){if((i|0)==(k|0)){s=k;break}if((a[i]|0)==b<<24>>24){s=i;break}else{i=i+1|0}}i=s-m|0;if((i|0)>23){q=-1;return q|0}do{if((e|0)==8|(e|0)==10){if((i|0)<(e|0)){break}else{q=-1}return q|0}else if((e|0)==16){if((i|0)<22){break}if(o){q=-1;return q|0}if((n-f|0)>=3){q=-1;return q|0}if((a[n-1|0]|0)!=48){q=-1;return q|0}c[h>>2]=0;m=a[62176+i|0]|0;s=c[g>>2]|0;c[g>>2]=s+1;a[s]=m;q=0;return q|0}}while(0);f=a[62176+i|0]|0;c[g>>2]=n+1;a[n]=f;c[h>>2]=(c[h>>2]|0)+1;q=0;return q|0}function ob(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+72|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+32|0;n=e+40|0;o=e+56|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==0){v=0}else if((u|0)==64){v=8}else if((u|0)==8){v=16}else{v=10}u=l|0;od(n,c[h+28>>2]|0,u,m);s_(p|0,0,12);h=o;mT(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=a[m]|0;m=o+8|0;C=w;w=c[z>>2]|0;L9528:while(1){do{if((w|0)==0){D=0}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){D=w;break}if((f2[c[(c[w>>2]|0)+36>>2]&255](w)|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;F=c[f>>2]|0;do{if((F|0)==0){G=7825}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L9528}}if((f2[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[f>>2]=0;G=7825;break}else{if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L9528}}}}while(0);if((G|0)==7825){G=0;if(E){J=C;K=0;L=1;M=0;N=1;break}else{H=0;I=1}}F=(c[q>>2]|0)-C|0;O=a[p]|0;P=O&255;if((F|0)==(((P&1|0)==0?P>>>1:c[A>>2]|0)|0)){P=F<<1;do{if(F>>>0<P>>>0){mT(o,F)}else{if((O&1)==0){a[h+1+P|0]=0;a[p]=F<<2&255;break}else{a[(c[m>>2]|0)+P|0]=0;c[A>>2]=P;break}}}while(0);P=a[p]|0;if((P&1)==0){Q=10;R=P}else{P=c[g>>2]|0;Q=(P&-2)-1|0;R=P&255}P=R&255;O=(P&1|0)==0?P>>>1:c[A>>2]|0;do{if(O>>>0<Q>>>0){mT(o,Q-O|0)}else{if((R&1)==0){a[h+1+Q|0]=0;a[p]=Q<<1&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[A>>2]=Q;break}}}while(0);if((a[p]&1)==0){S=x}else{S=c[y>>2]|0}c[q>>2]=S+F;T=S}else{T=C}O=D+12|0;P=c[O>>2]|0;U=D+16|0;if((P|0)==(c[U>>2]|0)){V=(f2[c[(c[D>>2]|0)+36>>2]&255](D)|0)&255}else{V=a[P]|0}if((oa(V,v,T,q,t,B,n,l,s,u)|0)!=0){J=T;K=H;L=I;M=D;N=E;break}P=c[O>>2]|0;if((P|0)==(c[U>>2]|0)){U=c[(c[D>>2]|0)+40>>2]|0;f2[U&255](D)|0;C=T;w=D;continue}else{c[O>>2]=P+1;C=T;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){W=w>>>1}else{W=c[n+4>>2]|0}do{if((W|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}T=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=T}}while(0);c[k>>2]=oc(J,c[q>>2]|0,j,v)|0;oe(n,l,c[s>>2]|0,j);do{if(N){X=0}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){X=M;break}if((f2[c[(c[M>>2]|0)+36>>2]&255](M)|0)!=-1){X=M;break}c[z>>2]=0;X=0}}while(0);z=(X|0)==0;L9596:do{if(L){G=7877}else{do{if((c[K+12>>2]|0)==(c[K+16>>2]|0)){if((f2[c[(c[K>>2]|0)+36>>2]&255](K)|0)!=-1){break}c[f>>2]=0;G=7877;break L9596}}while(0);if(!(z^(K|0)==0)){G=7879}}}while(0);if((G|0)==7877){if(z){G=7879}}if((G|0)==7879){c[j>>2]=c[j>>2]|2}c[b>>2]=X;do{if((a[p]&1)!=0){X=c[m>>2]|0;if((X|0)==0){break}sS(X)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}sS(D);i=e;return}function oc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}k=c[(ep()|0)>>2]|0;c[(ep()|0)>>2]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=eT(b|0,h|0,f|0,c[137522]|0)|0;f=K;b=c[(ep()|0)>>2]|0;if((b|0)==0){c[(ep()|0)>>2]=k}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=-1;h=0;if((b|0)==34|((f|0)<(d|0)|(f|0)==(d|0)&l>>>0<-2147483648>>>0)|((f|0)>(h|0)|(f|0)==(h|0)&l>>>0>2147483647>>>0)){c[e>>2]=4;e=0;j=(f|0)>(e|0)|(f|0)==(e|0)&l>>>0>0>>>0?2147483647:-2147483648;i=g;return j|0}else{j=l;i=g;return j|0}return 0}function od(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=d+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;if((c[137882]|0)!=-1){c[j>>2]=551528;c[j+4>>2]=16;c[j+8>>2]=0;mU(551528,j)}j=(c[137883]|0)-1|0;l=d+12|0;m=d+8|0;n=c[m>>2]|0;do{if((c[l>>2]|0)-n>>2>>>0>j>>>0){o=c[n+(j<<2)>>2]|0;if((o|0)==0){break}p=o;q=c[(c[o>>2]|0)+32>>2]|0;gn[q&31](p,62176,62202,e)|0;if((c[137786]|0)!=-1){c[h>>2]=551144;c[h+4>>2]=16;c[h+8>>2]=0;mU(551144,h)}p=(c[137787]|0)-1|0;q=c[m>>2]|0;do{if((c[l>>2]|0)-q>>2>>>0>p>>>0){o=c[q+(p<<2)>>2]|0;if((o|0)==0){break}r=o;a[f]=f2[c[(c[o>>2]|0)+16>>2]&255](r)|0;f0[c[(c[o>>2]|0)+20>>2]&255](b,r);if(((I=c[k>>2]|0,c[k>>2]=I+ -1,I)|0)!=0){i=g;return}f$[c[(c[d>>2]|0)+8>>2]&511](d);i=g;return}}while(0);p=fc(4)|0;c[p>>2]=53912;dq(p|0,60416,316)}}while(0);g=fc(4)|0;c[g>>2]=53912;dq(g|0,60416,316)}function oe(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=b;h=b;i=a[h]|0;j=i&255;if((j&1|0)==0){k=j>>>1}else{k=c[b+4>>2]|0}if((k|0)==0){return}do{if((d|0)==(e|0)){l=i}else{k=e-4|0;if(k>>>0>d>>>0){m=d;n=k}else{l=i;break}do{k=c[m>>2]|0;c[m>>2]=c[n>>2];c[n>>2]=k;m=m+4|0;n=n-4|0;}while(m>>>0<n>>>0);l=a[h]|0}}while(0);if((l&1)==0){o=g+1|0}else{o=c[b+8>>2]|0}g=l&255;if((g&1|0)==0){p=g>>>1}else{p=c[b+4>>2]|0}b=e-4|0;e=a[o]|0;g=e<<24>>24;l=e<<24>>24<1|e<<24>>24==127;L9687:do{if(b>>>0>d>>>0){e=o+p|0;h=o;n=d;m=g;i=l;while(1){if(!i){if((m|0)!=(c[n>>2]|0)){break}}k=(e-h|0)>1?h+1|0:h;j=n+4|0;q=a[k]|0;r=q<<24>>24;s=q<<24>>24<1|q<<24>>24==127;if(j>>>0<b>>>0){h=k;n=j;m=r;i=s}else{t=r;u=s;break L9687}}c[f>>2]=4;return}else{t=g;u=l}}while(0);if(u){return}u=c[b>>2]|0;if(!(t>>>0<u>>>0|(u|0)==0)){return}c[f>>2]=4;return}function of(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+72|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+32|0;n=e+40|0;o=e+56|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==0){v=0}else if((u|0)==64){v=8}else if((u|0)==8){v=16}else{v=10}u=l|0;od(n,c[h+28>>2]|0,u,m);s_(p|0,0,12);h=o;mT(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=a[m]|0;m=o+8|0;C=w;w=c[z>>2]|0;L9715:while(1){do{if((w|0)==0){D=0}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){D=w;break}if((f2[c[(c[w>>2]|0)+36>>2]&255](w)|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;F=c[f>>2]|0;do{if((F|0)==0){G=7981}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){if(E){H=F;I=0;break}else{J=C;L=F;M=0;N=D;O=0;break L9715}}if((f2[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[f>>2]=0;G=7981;break}else{if(E){H=F;I=0;break}else{J=C;L=F;M=0;N=D;O=0;break L9715}}}}while(0);if((G|0)==7981){G=0;if(E){J=C;L=0;M=1;N=0;O=1;break}else{H=0;I=1}}F=(c[q>>2]|0)-C|0;P=a[p]|0;Q=P&255;if((F|0)==(((Q&1|0)==0?Q>>>1:c[A>>2]|0)|0)){Q=F<<1;do{if(F>>>0<Q>>>0){mT(o,F)}else{if((P&1)==0){a[h+1+Q|0]=0;a[p]=F<<2&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[A>>2]=Q;break}}}while(0);Q=a[p]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[g>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[A>>2]|0;do{if(P>>>0<R>>>0){mT(o,R-P|0)}else{if((S&1)==0){a[h+1+R|0]=0;a[p]=R<<1&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[A>>2]=R;break}}}while(0);if((a[p]&1)==0){T=x}else{T=c[y>>2]|0}c[q>>2]=T+F;U=T}else{U=C}P=D+12|0;Q=c[P>>2]|0;V=D+16|0;if((Q|0)==(c[V>>2]|0)){W=(f2[c[(c[D>>2]|0)+36>>2]&255](D)|0)&255}else{W=a[Q]|0}if((oa(W,v,U,q,t,B,n,l,s,u)|0)!=0){J=U;L=H;M=I;N=D;O=E;break}Q=c[P>>2]|0;if((Q|0)==(c[V>>2]|0)){V=c[(c[D>>2]|0)+40>>2]|0;f2[V&255](D)|0;C=U;w=D;continue}else{c[P>>2]=Q+1;C=U;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){X=w>>>1}else{X=c[n+4>>2]|0}do{if((X|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}U=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=U}}while(0);t=og(J,c[q>>2]|0,j,v)|0;c[k>>2]=t;c[k+4>>2]=K;oe(n,l,c[s>>2]|0,j);do{if(O){Y=0}else{if((c[N+12>>2]|0)!=(c[N+16>>2]|0)){Y=N;break}if((f2[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){Y=N;break}c[z>>2]=0;Y=0}}while(0);z=(Y|0)==0;L9783:do{if(M){G=8033}else{do{if((c[L+12>>2]|0)==(c[L+16>>2]|0)){if((f2[c[(c[L>>2]|0)+36>>2]&255](L)|0)!=-1){break}c[f>>2]=0;G=8033;break L9783}}while(0);if(!(z^(L|0)==0)){G=8035}}}while(0);if((G|0)==8033){if(z){G=8035}}if((G|0)==8035){c[j>>2]=c[j>>2]|2}c[b>>2]=Y;do{if((a[p]&1)!=0){Y=c[m>>2]|0;if((Y|0)==0){break}sS(Y)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}sS(D);i=e;return}function og(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;k=0;i=g;return(K=j,k)|0}l=c[(ep()|0)>>2]|0;c[(ep()|0)>>2]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);m=eT(b|0,h|0,f|0,c[137522]|0)|0;f=K;b=c[(ep()|0)>>2]|0;if((b|0)==0){c[(ep()|0)>>2]=l}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;k=0;i=g;return(K=j,k)|0}if((b|0)!=34){j=f;k=m;i=g;return(K=j,k)|0}c[e>>2]=4;e=0;b=(f|0)>(e|0)|(f|0)==(e|0)&m>>>0>0>>>0;j=b?2147483647:-2147483648;k=b?-1:0;i=g;return(K=j,k)|0}function oh(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;i=i+72|0;m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7>>3<<3;c[h>>2]=c[m>>2];m=f|0;n=f+32|0;o=f+40|0;p=f+56|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=c[j+4>>2]&74;if((v|0)==8){w=16}else if((v|0)==0){w=0}else if((v|0)==64){w=8}else{w=10}v=m|0;od(o,c[j+28>>2]|0,v,n);s_(q|0,0,12);j=p;mT(p,10);if((a[q]&1)==0){m=j+1|0;x=m;y=m;z=p+8|0}else{m=p+8|0;x=c[m>>2]|0;y=j+1|0;z=m}c[r>>2]=x;m=s|0;c[t>>2]=m;c[u>>2]=0;A=g|0;g=h|0;h=p|0;B=p+4|0;C=a[n]|0;n=p+8|0;D=x;x=c[A>>2]|0;L9838:while(1){do{if((x|0)==0){E=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){E=x;break}if((f2[c[(c[x>>2]|0)+36>>2]&255](x)|0)!=-1){E=x;break}c[A>>2]=0;E=0}}while(0);F=(E|0)==0;G=c[g>>2]|0;do{if((G|0)==0){H=8084}else{if((c[G+12>>2]|0)!=(c[G+16>>2]|0)){if(F){I=G;J=0;break}else{K=D;L=G;M=0;N=E;O=0;break L9838}}if((f2[c[(c[G>>2]|0)+36>>2]&255](G)|0)==-1){c[g>>2]=0;H=8084;break}else{if(F){I=G;J=0;break}else{K=D;L=G;M=0;N=E;O=0;break L9838}}}}while(0);if((H|0)==8084){H=0;if(F){K=D;L=0;M=1;N=0;O=1;break}else{I=0;J=1}}G=(c[r>>2]|0)-D|0;P=a[q]|0;Q=P&255;if((G|0)==(((Q&1|0)==0?Q>>>1:c[B>>2]|0)|0)){Q=G<<1;do{if(G>>>0<Q>>>0){mT(p,G)}else{if((P&1)==0){a[j+1+Q|0]=0;a[q]=G<<2&255;break}else{a[(c[n>>2]|0)+Q|0]=0;c[B>>2]=Q;break}}}while(0);Q=a[q]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[h>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[B>>2]|0;do{if(P>>>0<R>>>0){mT(p,R-P|0)}else{if((S&1)==0){a[j+1+R|0]=0;a[q]=R<<1&255;break}else{a[(c[n>>2]|0)+R|0]=0;c[B>>2]=R;break}}}while(0);if((a[q]&1)==0){T=y}else{T=c[z>>2]|0}c[r>>2]=T+G;U=T}else{U=D}P=E+12|0;Q=c[P>>2]|0;V=E+16|0;if((Q|0)==(c[V>>2]|0)){W=(f2[c[(c[E>>2]|0)+36>>2]&255](E)|0)&255}else{W=a[Q]|0}if((oa(W,w,U,r,u,C,o,m,t,v)|0)!=0){K=U;L=I;M=J;N=E;O=F;break}Q=c[P>>2]|0;if((Q|0)==(c[V>>2]|0)){V=c[(c[E>>2]|0)+40>>2]|0;f2[V&255](E)|0;D=U;x=E;continue}else{c[P>>2]=Q+1;D=U;x=E;continue}}E=o;x=d[E]|0;if((x&1|0)==0){X=x>>>1}else{X=c[o+4>>2]|0}do{if((X|0)!=0){x=c[t>>2]|0;if((x-s|0)>=160){break}U=c[u>>2]|0;c[t>>2]=x+4;c[x>>2]=U}}while(0);b[l>>1]=oi(K,c[r>>2]|0,k,w)|0;oe(o,m,c[t>>2]|0,k);do{if(O){Y=0}else{if((c[N+12>>2]|0)!=(c[N+16>>2]|0)){Y=N;break}if((f2[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){Y=N;break}c[A>>2]=0;Y=0}}while(0);A=(Y|0)==0;L9906:do{if(M){H=8136}else{do{if((c[L+12>>2]|0)==(c[L+16>>2]|0)){if((f2[c[(c[L>>2]|0)+36>>2]&255](L)|0)!=-1){break}c[g>>2]=0;H=8136;break L9906}}while(0);if(!(A^(L|0)==0)){H=8138}}}while(0);if((H|0)==8136){if(A){H=8138}}if((H|0)==8138){c[k>>2]=c[k>>2]|2}c[e>>2]=Y;do{if((a[q]&1)!=0){Y=c[n>>2]|0;if((Y|0)==0){break}sS(Y)}}while(0);if((a[E]&1)==0){i=f;return}E=c[o+8>>2]|0;if((E|0)==0){i=f;return}sS(E);i=f;return}function oi(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}if((a[b]|0)==45){c[e>>2]=4;j=0;i=g;return j|0}k=c[(ep()|0)>>2]|0;c[(ep()|0)>>2]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=a5(b|0,h|0,f|0,c[137522]|0)|0;f=K;b=c[(ep()|0)>>2]|0;if((b|0)==0){c[(ep()|0)>>2]=k}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=0;if((b|0)==34|(f>>>0>d>>>0|f>>>0==d>>>0&l>>>0>65535>>>0)){c[e>>2]=4;j=-1;i=g;return j|0}else{j=l&65535;i=g;return j|0}return 0}function oj(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+72|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+32|0;n=e+40|0;o=e+56|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==64){v=8}else if((u|0)==0){v=0}else if((u|0)==8){v=16}else{v=10}u=l|0;od(n,c[h+28>>2]|0,u,m);s_(p|0,0,12);h=o;mT(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=a[m]|0;m=o+8|0;C=w;w=c[z>>2]|0;L9966:while(1){do{if((w|0)==0){D=0}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){D=w;break}if((f2[c[(c[w>>2]|0)+36>>2]&255](w)|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;F=c[f>>2]|0;do{if((F|0)==0){G=8191}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L9966}}if((f2[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[f>>2]=0;G=8191;break}else{if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L9966}}}}while(0);if((G|0)==8191){G=0;if(E){J=C;K=0;L=1;M=0;N=1;break}else{H=0;I=1}}F=(c[q>>2]|0)-C|0;O=a[p]|0;P=O&255;if((F|0)==(((P&1|0)==0?P>>>1:c[A>>2]|0)|0)){P=F<<1;do{if(F>>>0<P>>>0){mT(o,F)}else{if((O&1)==0){a[h+1+P|0]=0;a[p]=F<<2&255;break}else{a[(c[m>>2]|0)+P|0]=0;c[A>>2]=P;break}}}while(0);P=a[p]|0;if((P&1)==0){Q=10;R=P}else{P=c[g>>2]|0;Q=(P&-2)-1|0;R=P&255}P=R&255;O=(P&1|0)==0?P>>>1:c[A>>2]|0;do{if(O>>>0<Q>>>0){mT(o,Q-O|0)}else{if((R&1)==0){a[h+1+Q|0]=0;a[p]=Q<<1&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[A>>2]=Q;break}}}while(0);if((a[p]&1)==0){S=x}else{S=c[y>>2]|0}c[q>>2]=S+F;T=S}else{T=C}O=D+12|0;P=c[O>>2]|0;U=D+16|0;if((P|0)==(c[U>>2]|0)){V=(f2[c[(c[D>>2]|0)+36>>2]&255](D)|0)&255}else{V=a[P]|0}if((oa(V,v,T,q,t,B,n,l,s,u)|0)!=0){J=T;K=H;L=I;M=D;N=E;break}P=c[O>>2]|0;if((P|0)==(c[U>>2]|0)){U=c[(c[D>>2]|0)+40>>2]|0;f2[U&255](D)|0;C=T;w=D;continue}else{c[O>>2]=P+1;C=T;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){W=w>>>1}else{W=c[n+4>>2]|0}do{if((W|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}T=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=T}}while(0);c[k>>2]=ok(J,c[q>>2]|0,j,v)|0;oe(n,l,c[s>>2]|0,j);do{if(N){X=0}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){X=M;break}if((f2[c[(c[M>>2]|0)+36>>2]&255](M)|0)!=-1){X=M;break}c[z>>2]=0;X=0}}while(0);z=(X|0)==0;L10034:do{if(L){G=8243}else{do{if((c[K+12>>2]|0)==(c[K+16>>2]|0)){if((f2[c[(c[K>>2]|0)+36>>2]&255](K)|0)!=-1){break}c[f>>2]=0;G=8243;break L10034}}while(0);if(!(z^(K|0)==0)){G=8245}}}while(0);if((G|0)==8243){if(z){G=8245}}if((G|0)==8245){c[j>>2]=c[j>>2]|2}c[b>>2]=X;do{if((a[p]&1)!=0){X=c[m>>2]|0;if((X|0)==0){break}sS(X)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}sS(D);i=e;return}function ok(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}if((a[b]|0)==45){c[e>>2]=4;j=0;i=g;return j|0}k=c[(ep()|0)>>2]|0;c[(ep()|0)>>2]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=a5(b|0,h|0,f|0,c[137522]|0)|0;f=K;b=c[(ep()|0)>>2]|0;if((b|0)==0){c[(ep()|0)>>2]=k}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=0;if((b|0)==34|(f>>>0>d>>>0|f>>>0==d>>>0&l>>>0>-1>>>0)){c[e>>2]=4;j=-1;i=g;return j|0}else{j=l;i=g;return j|0}return 0}function ol(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+72|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+32|0;n=e+40|0;o=e+56|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==0){v=0}else if((u|0)==64){v=8}else{v=10}u=l|0;od(n,c[h+28>>2]|0,u,m);s_(p|0,0,12);h=o;mT(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=a[m]|0;m=o+8|0;C=w;w=c[z>>2]|0;L10094:while(1){do{if((w|0)==0){D=0}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){D=w;break}if((f2[c[(c[w>>2]|0)+36>>2]&255](w)|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;F=c[f>>2]|0;do{if((F|0)==0){G=8298}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L10094}}if((f2[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[f>>2]=0;G=8298;break}else{if(E){H=F;I=0;break}else{J=C;K=F;L=0;M=D;N=0;break L10094}}}}while(0);if((G|0)==8298){G=0;if(E){J=C;K=0;L=1;M=0;N=1;break}else{H=0;I=1}}F=(c[q>>2]|0)-C|0;O=a[p]|0;P=O&255;if((F|0)==(((P&1|0)==0?P>>>1:c[A>>2]|0)|0)){P=F<<1;do{if(F>>>0<P>>>0){mT(o,F)}else{if((O&1)==0){a[h+1+P|0]=0;a[p]=F<<2&255;break}else{a[(c[m>>2]|0)+P|0]=0;c[A>>2]=P;break}}}while(0);P=a[p]|0;if((P&1)==0){Q=10;R=P}else{P=c[g>>2]|0;Q=(P&-2)-1|0;R=P&255}P=R&255;O=(P&1|0)==0?P>>>1:c[A>>2]|0;do{if(O>>>0<Q>>>0){mT(o,Q-O|0)}else{if((R&1)==0){a[h+1+Q|0]=0;a[p]=Q<<1&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[A>>2]=Q;break}}}while(0);if((a[p]&1)==0){S=x}else{S=c[y>>2]|0}c[q>>2]=S+F;T=S}else{T=C}O=D+12|0;P=c[O>>2]|0;U=D+16|0;if((P|0)==(c[U>>2]|0)){V=(f2[c[(c[D>>2]|0)+36>>2]&255](D)|0)&255}else{V=a[P]|0}if((oa(V,v,T,q,t,B,n,l,s,u)|0)!=0){J=T;K=H;L=I;M=D;N=E;break}P=c[O>>2]|0;if((P|0)==(c[U>>2]|0)){U=c[(c[D>>2]|0)+40>>2]|0;f2[U&255](D)|0;C=T;w=D;continue}else{c[O>>2]=P+1;C=T;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){W=w>>>1}else{W=c[n+4>>2]|0}do{if((W|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}T=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=T}}while(0);c[k>>2]=om(J,c[q>>2]|0,j,v)|0;oe(n,l,c[s>>2]|0,j);do{if(N){X=0}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){X=M;break}if((f2[c[(c[M>>2]|0)+36>>2]&255](M)|0)!=-1){X=M;break}c[z>>2]=0;X=0}}while(0);z=(X|0)==0;L10162:do{if(L){G=8350}else{do{if((c[K+12>>2]|0)==(c[K+16>>2]|0)){if((f2[c[(c[K>>2]|0)+36>>2]&255](K)|0)!=-1){break}c[f>>2]=0;G=8350;break L10162}}while(0);if(!(z^(K|0)==0)){G=8352}}}while(0);if((G|0)==8350){if(z){G=8352}}if((G|0)==8352){c[j>>2]=c[j>>2]|2}c[b>>2]=X;do{if((a[p]&1)!=0){X=c[m>>2]|0;if((X|0)==0){break}sS(X)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}sS(D);i=e;return}function om(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}if((a[b]|0)==45){c[e>>2]=4;j=0;i=g;return j|0}k=c[(ep()|0)>>2]|0;c[(ep()|0)>>2]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=a5(b|0,h|0,f|0,c[137522]|0)|0;f=K;b=c[(ep()|0)>>2]|0;if((b|0)==0){c[(ep()|0)>>2]=k}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=0;if((b|0)==34|(f>>>0>d>>>0|f>>>0==d>>>0&l>>>0>-1>>>0)){c[e>>2]=4;j=-1;i=g;return j|0}else{j=l;i=g;return j|0}return 0}function on(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+72|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+32|0;n=e+40|0;o=e+56|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==0){v=0}else if((u|0)==64){v=8}else{v=10}u=l|0;od(n,c[h+28>>2]|0,u,m);s_(p|0,0,12);h=o;mT(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=a[m]|0;m=o+8|0;C=w;w=c[z>>2]|0;L11:while(1){do{if((w|0)==0){D=0}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){D=w;break}if((f2[c[(c[w>>2]|0)+36>>2]&255](w)|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;F=c[f>>2]|0;do{if((F|0)==0){G=21}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){if(E){H=F;I=0;break}else{J=C;L=F;M=0;N=D;O=0;break L11}}if((f2[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[f>>2]=0;G=21;break}else{if(E){H=F;I=0;break}else{J=C;L=F;M=0;N=D;O=0;break L11}}}}while(0);if((G|0)==21){G=0;if(E){J=C;L=0;M=1;N=0;O=1;break}else{H=0;I=1}}F=(c[q>>2]|0)-C|0;P=a[p]|0;Q=P&255;if((F|0)==(((Q&1|0)==0?Q>>>1:c[A>>2]|0)|0)){Q=F<<1;do{if(F>>>0<Q>>>0){mT(o,F)}else{if((P&1)==0){a[h+1+Q|0]=0;a[p]=F<<2&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[A>>2]=Q;break}}}while(0);Q=a[p]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[g>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[A>>2]|0;do{if(P>>>0<R>>>0){mT(o,R-P|0)}else{if((S&1)==0){a[h+1+R|0]=0;a[p]=R<<1&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[A>>2]=R;break}}}while(0);if((a[p]&1)==0){T=x}else{T=c[y>>2]|0}c[q>>2]=T+F;U=T}else{U=C}P=D+12|0;Q=c[P>>2]|0;V=D+16|0;if((Q|0)==(c[V>>2]|0)){W=(f2[c[(c[D>>2]|0)+36>>2]&255](D)|0)&255}else{W=a[Q]|0}if((oa(W,v,U,q,t,B,n,l,s,u)|0)!=0){J=U;L=H;M=I;N=D;O=E;break}Q=c[P>>2]|0;if((Q|0)==(c[V>>2]|0)){V=c[(c[D>>2]|0)+40>>2]|0;f2[V&255](D)|0;C=U;w=D;continue}else{c[P>>2]=Q+1;C=U;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){X=w>>>1}else{X=c[n+4>>2]|0}do{if((X|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}U=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=U}}while(0);t=oo(J,c[q>>2]|0,j,v)|0;c[k>>2]=t;c[k+4>>2]=K;oe(n,l,c[s>>2]|0,j);do{if(O){Y=0}else{if((c[N+12>>2]|0)!=(c[N+16>>2]|0)){Y=N;break}if((f2[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){Y=N;break}c[z>>2]=0;Y=0}}while(0);z=(Y|0)==0;L79:do{if(M){G=73}else{do{if((c[L+12>>2]|0)==(c[L+16>>2]|0)){if((f2[c[(c[L>>2]|0)+36>>2]&255](L)|0)!=-1){break}c[f>>2]=0;G=73;break L79}}while(0);if(!(z^(L|0)==0)){G=75}}}while(0);if((G|0)==73){if(z){G=75}}if((G|0)==75){c[j>>2]=c[j>>2]|2}c[b>>2]=Y;do{if((a[p]&1)!=0){Y=c[m>>2]|0;if((Y|0)==0){break}sS(Y)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}sS(D);i=e;return}function oo(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+8|0;h=g|0;do{if((b|0)==(d|0)){c[e>>2]=4;j=0;k=0}else{if((a[b]|0)==45){c[e>>2]=4;j=0;k=0;break}l=c[(ep()|0)>>2]|0;c[(ep()|0)>>2]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);m=a5(b|0,h|0,f|0,c[137522]|0)|0;n=K;o=c[(ep()|0)>>2]|0;if((o|0)==0){c[(ep()|0)>>2]=l}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;k=0;break}if((o|0)!=34){j=n;k=m;break}c[e>>2]=4;j=-1;k=-1}}while(0);i=g;return(K=j,k)|0}function op(b,e,f,g,h,i,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0;if(b<<24>>24==i<<24>>24){if((a[e]&1)==0){p=-1;return p|0}a[e]=0;i=c[h>>2]|0;c[h>>2]=i+1;a[i]=46;i=d[k]|0;if((i&1|0)==0){q=i>>>1}else{q=c[k+4>>2]|0}if((q|0)==0){p=0;return p|0}q=c[m>>2]|0;if((q-l|0)>=160){p=0;return p|0}i=c[n>>2]|0;c[m>>2]=q+4;c[q>>2]=i;p=0;return p|0}do{if(b<<24>>24==j<<24>>24){i=d[k]|0;if((i&1|0)==0){r=i>>>1}else{r=c[k+4>>2]|0}if((r|0)==0){break}if((a[e]&1)==0){p=-1;return p|0}i=c[m>>2]|0;if((i-l|0)>=160){p=0;return p|0}q=c[n>>2]|0;c[m>>2]=i+4;c[i>>2]=q;c[n>>2]=0;p=0;return p|0}}while(0);r=o+32|0;j=o;while(1){if((j|0)==(r|0)){s=r;break}if((a[j]|0)==b<<24>>24){s=j;break}else{j=j+1|0}}j=s-o|0;if((j|0)>31){p=-1;return p|0}o=a[62176+j|0]|0;if((j|0)==25|(j|0)==24){s=c[h>>2]|0;do{if((s|0)!=(g|0)){if((a[s-1|0]&95|0)==(a[f]&127|0)){break}else{p=-1}return p|0}}while(0);c[h>>2]=s+1;a[s]=o;p=0;return p|0}else if((j|0)==22|(j|0)==23){a[f]=80;s=c[h>>2]|0;c[h>>2]=s+1;a[s]=o;p=0;return p|0}else{s=a[f]|0;do{if((o&95|0)==(s<<24>>24|0)){a[f]=s|-128;if((a[e]&1)==0){break}a[e]=0;g=d[k]|0;if((g&1|0)==0){t=g>>>1}else{t=c[k+4>>2]|0}if((t|0)==0){break}g=c[m>>2]|0;if((g-l|0)>=160){break}b=c[n>>2]|0;c[m>>2]=g+4;c[g>>2]=b}}while(0);m=c[h>>2]|0;c[h>>2]=m+1;a[m]=o;if((j|0)>21){p=0;return p|0}c[n>>2]=(c[n>>2]|0)+1;p=0;return p|0}return 0}function oq(b,e,f,h,j,k,l){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+80|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7>>3<<3;c[h>>2]=c[m>>2];m=e+32|0;n=e+40|0;o=e+48|0;p=e+64|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;os(o,c[j+28>>2]|0,x,m,n);s_(q|0,0,12);j=p;mT(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=h|0;h=p|0;D=p+4|0;E=a[m]|0;m=a[n]|0;n=p+8|0;F=z;z=c[C>>2]|0;L192:while(1){do{if((z|0)==0){G=0}else{if((c[z+12>>2]|0)!=(c[z+16>>2]|0)){G=z;break}if((f2[c[(c[z>>2]|0)+36>>2]&255](z)|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;I=c[f>>2]|0;do{if((I|0)==0){J=167}else{if((c[I+12>>2]|0)!=(c[I+16>>2]|0)){if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L192}}if((f2[c[(c[I>>2]|0)+36>>2]&255](I)|0)==-1){c[f>>2]=0;J=167;break}else{if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L192}}}}while(0);if((J|0)==167){J=0;if(H){M=F;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}I=(c[r>>2]|0)-F|0;R=a[q]|0;S=R&255;if((I|0)==(((S&1|0)==0?S>>>1:c[D>>2]|0)|0)){S=I<<1;do{if(I>>>0<S>>>0){mT(p,I)}else{if((R&1)==0){a[j+1+S|0]=0;a[q]=I<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[D>>2]=S;break}}}while(0);S=a[q]|0;if((S&1)==0){T=10;U=S}else{S=c[h>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[D>>2]|0;do{if(R>>>0<T>>>0){mT(p,T-R|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[q]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[D>>2]=T;break}}}while(0);if((a[q]&1)==0){V=A}else{V=c[B>>2]|0}c[r>>2]=V+I;W=V}else{W=F}R=G+12|0;S=c[R>>2]|0;X=G+16|0;if((S|0)==(c[X>>2]|0)){Y=(f2[c[(c[G>>2]|0)+36>>2]&255](G)|0)&255}else{Y=a[S]|0}if((op(Y,v,w,W,r,E,m,o,y,t,u,x)|0)!=0){M=W;N=K;O=L;P=G;Q=H;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[G>>2]|0)+40>>2]|0;f2[X&255](G)|0;F=W;z=G;continue}else{c[R>>2]=S+1;F=W;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){Z=z>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}W=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=W}}while(0);g[l>>2]=+or(M,c[r>>2]|0,k);oe(o,y,c[t>>2]|0,k);do{if(Q){_=0}else{if((c[P+12>>2]|0)!=(c[P+16>>2]|0)){_=P;break}if((f2[c[(c[P>>2]|0)+36>>2]&255](P)|0)!=-1){_=P;break}c[C>>2]=0;_=0}}while(0);C=(_|0)==0;L261:do{if(O){J=220}else{do{if((c[N+12>>2]|0)==(c[N+16>>2]|0)){if((f2[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){break}c[f>>2]=0;J=220;break L261}}while(0);if(!(C^(N|0)==0)){J=222}}}while(0);if((J|0)==220){if(C){J=222}}if((J|0)==222){c[k>>2]=c[k>>2]|2}c[b>>2]=_;do{if((a[q]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}sS(_)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}sS(G);i=e;return}function or(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0.0;f=i;i=i+8|0;g=f|0;if((b|0)==(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}j=c[(ep()|0)>>2]|0;c[(ep()|0)>>2]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);k=+sY(b,g);b=c[(ep()|0)>>2]|0;if((b|0)==0){c[(ep()|0)>>2]=j}if((c[g>>2]|0)!=(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}if((b|0)==34){c[e>>2]=4}h=k;i=f;return+h}function os(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+32|0;j=h|0;k=h+16|0;l=d+4|0;I=c[l>>2]|0,c[l>>2]=I+1,I;if((c[137882]|0)!=-1){c[k>>2]=551528;c[k+4>>2]=16;c[k+8>>2]=0;mU(551528,k)}k=(c[137883]|0)-1|0;m=d+12|0;n=d+8|0;o=c[n>>2]|0;do{if((c[m>>2]|0)-o>>2>>>0>k>>>0){p=c[o+(k<<2)>>2]|0;if((p|0)==0){break}q=p;r=c[(c[p>>2]|0)+32>>2]|0;gn[r&31](q,62176,62208,e)|0;if((c[137786]|0)!=-1){c[j>>2]=551144;c[j+4>>2]=16;c[j+8>>2]=0;mU(551144,j)}q=(c[137787]|0)-1|0;r=c[n>>2]|0;do{if((c[m>>2]|0)-r>>2>>>0>q>>>0){p=c[r+(q<<2)>>2]|0;if((p|0)==0){break}s=p;t=p;a[f]=f2[c[(c[t>>2]|0)+12>>2]&255](s)|0;a[g]=f2[c[(c[t>>2]|0)+16>>2]&255](s)|0;f0[c[(c[p>>2]|0)+20>>2]&255](b,s);if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){i=h;return}f$[c[(c[d>>2]|0)+8>>2]&511](d);i=h;return}}while(0);q=fc(4)|0;c[q>>2]=53912;dq(q|0,60416,316)}}while(0);h=fc(4)|0;c[h>>2]=53912;dq(h|0,60416,316)}
function ot(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+80|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=e+32|0;n=e+40|0;o=e+48|0;p=e+64|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;os(o,c[j+28>>2]|0,x,m,n);s_(q|0,0,12);j=p;mT(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=g|0;g=p|0;D=p+4|0;E=a[m]|0;m=a[n]|0;n=p+8|0;F=z;z=c[C>>2]|0;L336:while(1){do{if((z|0)==0){G=0}else{if((c[z+12>>2]|0)!=(c[z+16>>2]|0)){G=z;break}if((f2[c[(c[z>>2]|0)+36>>2]&255](z)|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;I=c[f>>2]|0;do{if((I|0)==0){J=291}else{if((c[I+12>>2]|0)!=(c[I+16>>2]|0)){if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L336}}if((f2[c[(c[I>>2]|0)+36>>2]&255](I)|0)==-1){c[f>>2]=0;J=291;break}else{if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L336}}}}while(0);if((J|0)==291){J=0;if(H){M=F;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}I=(c[r>>2]|0)-F|0;R=a[q]|0;S=R&255;if((I|0)==(((S&1|0)==0?S>>>1:c[D>>2]|0)|0)){S=I<<1;do{if(I>>>0<S>>>0){mT(p,I)}else{if((R&1)==0){a[j+1+S|0]=0;a[q]=I<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[D>>2]=S;break}}}while(0);S=a[q]|0;if((S&1)==0){T=10;U=S}else{S=c[g>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[D>>2]|0;do{if(R>>>0<T>>>0){mT(p,T-R|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[q]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[D>>2]=T;break}}}while(0);if((a[q]&1)==0){V=A}else{V=c[B>>2]|0}c[r>>2]=V+I;W=V}else{W=F}R=G+12|0;S=c[R>>2]|0;X=G+16|0;if((S|0)==(c[X>>2]|0)){Y=(f2[c[(c[G>>2]|0)+36>>2]&255](G)|0)&255}else{Y=a[S]|0}if((op(Y,v,w,W,r,E,m,o,y,t,u,x)|0)!=0){M=W;N=K;O=L;P=G;Q=H;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[G>>2]|0)+40>>2]|0;f2[X&255](G)|0;F=W;z=G;continue}else{c[R>>2]=S+1;F=W;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){Z=z>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}W=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=W}}while(0);h[l>>3]=+ou(M,c[r>>2]|0,k);oe(o,y,c[t>>2]|0,k);do{if(Q){_=0}else{if((c[P+12>>2]|0)!=(c[P+16>>2]|0)){_=P;break}if((f2[c[(c[P>>2]|0)+36>>2]&255](P)|0)!=-1){_=P;break}c[C>>2]=0;_=0}}while(0);C=(_|0)==0;L405:do{if(O){J=344}else{do{if((c[N+12>>2]|0)==(c[N+16>>2]|0)){if((f2[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){break}c[f>>2]=0;J=344;break L405}}while(0);if(!(C^(N|0)==0)){J=346}}}while(0);if((J|0)==344){if(C){J=346}}if((J|0)==346){c[k>>2]=c[k>>2]|2}c[b>>2]=_;do{if((a[q]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}sS(_)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}sS(G);i=e;return}function ou(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0.0;f=i;i=i+8|0;g=f|0;if((b|0)==(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}j=c[(ep()|0)>>2]|0;c[(ep()|0)>>2]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);k=+sY(b,g);b=c[(ep()|0)>>2]|0;if((b|0)==0){c[(ep()|0)>>2]=j}if((c[g>>2]|0)!=(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}if((b|0)!=34){h=k;i=f;return+h}c[e>>2]=4;h=k;i=f;return+h}function ov(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+80|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=e+32|0;n=e+40|0;o=e+48|0;p=e+64|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;os(o,c[j+28>>2]|0,x,m,n);s_(q|0,0,12);j=p;mT(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=g|0;g=p|0;D=p+4|0;E=a[m]|0;m=a[n]|0;n=p+8|0;F=z;z=c[C>>2]|0;L455:while(1){do{if((z|0)==0){G=0}else{if((c[z+12>>2]|0)!=(c[z+16>>2]|0)){G=z;break}if((f2[c[(c[z>>2]|0)+36>>2]&255](z)|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;I=c[f>>2]|0;do{if((I|0)==0){J=391}else{if((c[I+12>>2]|0)!=(c[I+16>>2]|0)){if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L455}}if((f2[c[(c[I>>2]|0)+36>>2]&255](I)|0)==-1){c[f>>2]=0;J=391;break}else{if(H){K=I;L=0;break}else{M=F;N=I;O=0;P=G;Q=0;break L455}}}}while(0);if((J|0)==391){J=0;if(H){M=F;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}I=(c[r>>2]|0)-F|0;R=a[q]|0;S=R&255;if((I|0)==(((S&1|0)==0?S>>>1:c[D>>2]|0)|0)){S=I<<1;do{if(I>>>0<S>>>0){mT(p,I)}else{if((R&1)==0){a[j+1+S|0]=0;a[q]=I<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[D>>2]=S;break}}}while(0);S=a[q]|0;if((S&1)==0){T=10;U=S}else{S=c[g>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[D>>2]|0;do{if(R>>>0<T>>>0){mT(p,T-R|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[q]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[D>>2]=T;break}}}while(0);if((a[q]&1)==0){V=A}else{V=c[B>>2]|0}c[r>>2]=V+I;W=V}else{W=F}R=G+12|0;S=c[R>>2]|0;X=G+16|0;if((S|0)==(c[X>>2]|0)){Y=(f2[c[(c[G>>2]|0)+36>>2]&255](G)|0)&255}else{Y=a[S]|0}if((op(Y,v,w,W,r,E,m,o,y,t,u,x)|0)!=0){M=W;N=K;O=L;P=G;Q=H;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[G>>2]|0)+40>>2]|0;f2[X&255](G)|0;F=W;z=G;continue}else{c[R>>2]=S+1;F=W;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){Z=z>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}W=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=W}}while(0);h[l>>3]=+ow(M,c[r>>2]|0,k);oe(o,y,c[t>>2]|0,k);do{if(Q){_=0}else{if((c[P+12>>2]|0)!=(c[P+16>>2]|0)){_=P;break}if((f2[c[(c[P>>2]|0)+36>>2]&255](P)|0)!=-1){_=P;break}c[C>>2]=0;_=0}}while(0);C=(_|0)==0;L524:do{if(O){J=444}else{do{if((c[N+12>>2]|0)==(c[N+16>>2]|0)){if((f2[c[(c[N>>2]|0)+36>>2]&255](N)|0)!=-1){break}c[f>>2]=0;J=444;break L524}}while(0);if(!(C^(N|0)==0)){J=446}}}while(0);if((J|0)==444){if(C){J=446}}if((J|0)==446){c[k>>2]=c[k>>2]|2}c[b>>2]=_;do{if((a[q]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}sS(_)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}sS(G);i=e;return}function ow(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0.0;f=i;i=i+8|0;g=f|0;if((b|0)==(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}j=c[(ep()|0)>>2]|0;c[(ep()|0)>>2]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);k=+sY(b,g);b=c[(ep()|0)>>2]|0;if((b|0)==0){c[(ep()|0)>>2]=j}if((c[g>>2]|0)!=(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}if((b|0)!=34){h=k;i=f;return+h}c[e>>2]=4;h=k;i=f;return+h}function ox(a){a=a|0;return}function oy(a){a=a|0;if((a|0)==0){return}sS(a);return}function oz(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;d=i;i=i+64|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[k>>2];k=d|0;l=d+16|0;m=d+48|0;n=m;o=i;i=i+12|0;i=i+7>>3<<3;p=i;i=i+4|0;i=i+7>>3<<3;q=i;i=i+160|0;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+4|0;i=i+7>>3<<3;s_(n|0,0,12);t=o;u=c[g+28>>2]|0;g=u+4|0;I=c[g>>2]|0,c[g>>2]=I+1,I;if((c[137882]|0)!=-1){c[k>>2]=551528;c[k+4>>2]=16;c[k+8>>2]=0;mU(551528,k)}k=(c[137883]|0)-1|0;v=c[u+8>>2]|0;do{if((c[u+12>>2]|0)-v>>2>>>0>k>>>0){w=c[v+(k<<2)>>2]|0;if((w|0)==0){break}x=w;y=l|0;z=c[(c[w>>2]|0)+32>>2]|0;gn[z&31](x,62176,62202,y)|0;if(((I=c[g>>2]|0,c[g>>2]=I+ -1,I)|0)==0){f$[c[(c[u>>2]|0)+8>>2]&511](u)}s_(t|0,0,12);x=o;mT(o,10);if((a[t]&1)==0){z=x+1|0;A=z;B=z;C=o+8|0}else{z=o+8|0;A=c[z>>2]|0;B=x+1|0;C=z}c[p>>2]=A;z=q|0;c[r>>2]=z;c[s>>2]=0;w=e|0;D=f|0;E=o|0;F=o+4|0;G=o+8|0;H=A;J=c[w>>2]|0;L590:while(1){do{if((J|0)==0){K=0}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){K=J;break}if((f2[c[(c[J>>2]|0)+36>>2]&255](J)|0)!=-1){K=J;break}c[w>>2]=0;K=0}}while(0);L=(K|0)==0;M=c[D>>2]|0;do{if((M|0)==0){N=506}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){if(L){break}else{O=H;break L590}}if((f2[c[(c[M>>2]|0)+36>>2]&255](M)|0)==-1){c[D>>2]=0;N=506;break}else{if(L){break}else{O=H;break L590}}}}while(0);if((N|0)==506){N=0;if(L){O=H;break}}M=(c[p>>2]|0)-H|0;P=a[t]|0;Q=P&255;if((M|0)==(((Q&1|0)==0?Q>>>1:c[F>>2]|0)|0)){Q=M<<1;do{if(M>>>0<Q>>>0){mT(o,M)}else{if((P&1)==0){a[x+1+Q|0]=0;a[t]=M<<2&255;break}else{a[(c[G>>2]|0)+Q|0]=0;c[F>>2]=Q;break}}}while(0);Q=a[t]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[E>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[F>>2]|0;do{if(P>>>0<R>>>0){mT(o,R-P|0)}else{if((S&1)==0){a[x+1+R|0]=0;a[t]=R<<1&255;break}else{a[(c[G>>2]|0)+R|0]=0;c[F>>2]=R;break}}}while(0);if((a[t]&1)==0){T=B}else{T=c[C>>2]|0}c[p>>2]=T+M;U=T}else{U=H}P=K+12|0;Q=c[P>>2]|0;L=K+16|0;if((Q|0)==(c[L>>2]|0)){V=(f2[c[(c[K>>2]|0)+36>>2]&255](K)|0)&255}else{V=a[Q]|0}if((oa(V,16,U,p,s,0,m,z,r,y)|0)!=0){O=U;break}Q=c[P>>2]|0;if((Q|0)==(c[L>>2]|0)){L=c[(c[K>>2]|0)+40>>2]|0;f2[L&255](K)|0;H=U;J=K;continue}else{c[P>>2]=Q+1;H=U;J=K;continue}}a[O+3|0]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);J=oA(O,c[137522]|0,(H=i,i=i+8|0,c[H>>2]=j,H)|0)|0;i=H;if((J|0)!=1){c[h>>2]=4}J=c[w>>2]|0;do{if((J|0)==0){W=0}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){W=J;break}if((f2[c[(c[J>>2]|0)+36>>2]&255](J)|0)!=-1){W=J;break}c[w>>2]=0;W=0}}while(0);w=(W|0)==0;J=c[D>>2]|0;do{if((J|0)==0){N=558}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){if(w){break}else{N=560;break}}if((f2[c[(c[J>>2]|0)+36>>2]&255](J)|0)==-1){c[D>>2]=0;N=558;break}else{if(w){break}else{N=560;break}}}}while(0);if((N|0)==558){if(w){N=560}}if((N|0)==560){c[h>>2]=c[h>>2]|2}c[b>>2]=W;do{if((a[t]&1)!=0){D=c[G>>2]|0;if((D|0)==0){break}sS(D)}}while(0);if((a[n]&1)==0){i=d;return}G=c[m+8>>2]|0;if((G|0)==0){i=d;return}sS(G);i=d;return}}while(0);d=fc(4)|0;c[d>>2]=53912;dq(d|0,60416,316)}function oA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;g=eC(b|0)|0;b=b2(a|0,38144,f|0)|0;if((g|0)==0){i=e;return b|0}eC(g|0)|0;i=e;return b|0}function oB(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+88|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=k|0;m=k+16|0;n=k+32|0;o=k+40|0;p=k+48|0;q=k+56|0;r=k+64|0;if((c[g+4>>2]&1|0)==0){c[n>>2]=-1;s=c[(c[d>>2]|0)+16>>2]|0;t=e|0;c[p>>2]=c[t>>2];c[q>>2]=c[f>>2];gf[s&127](o,d,p,q,g,h,n);q=c[o>>2]|0;c[t>>2]=q;t=c[n>>2]|0;if((t|0)==0){a[j]=0}else if((t|0)==1){a[j]=1}else{a[j]=1;c[h>>2]=4}c[b>>2]=q;i=k;return}q=g+28|0;g=c[q>>2]|0;t=g+4|0;I=c[t>>2]|0,c[t>>2]=I+1,I;if((c[137880]|0)!=-1){c[m>>2]=551520;c[m+4>>2]=16;c[m+8>>2]=0;mU(551520,m)}m=(c[137881]|0)-1|0;n=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-n>>2>>>0>m>>>0){o=c[n+(m<<2)>>2]|0;if((o|0)==0){break}p=o;if(((I=c[t>>2]|0,c[t>>2]=I+ -1,I)|0)==0){f$[c[(c[g>>2]|0)+8>>2]&511](g)}o=c[q>>2]|0;d=o+4|0;I=c[d>>2]|0,c[d>>2]=I+1,I;if((c[137784]|0)!=-1){c[l>>2]=551136;c[l+4>>2]=16;c[l+8>>2]=0;mU(551136,l)}s=(c[137785]|0)-1|0;u=c[o+8>>2]|0;do{if((c[o+12>>2]|0)-u>>2>>>0>s>>>0){v=c[u+(s<<2)>>2]|0;if((v|0)==0){break}w=v;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)==0){f$[c[(c[o>>2]|0)+8>>2]&511](o)}x=r|0;y=v;f0[c[(c[y>>2]|0)+24>>2]&255](x,w);v=r+12|0;f0[c[(c[y>>2]|0)+28>>2]&255](v,w);a[j]=(oC(e,c[f>>2]|0,x,r+24|0,p,h,1)|0)==(x|0)|0;c[b>>2]=c[e>>2];do{if((a[v]&1)!=0){x=c[r+20>>2]|0;if((x|0)==0){break}sS(x)}}while(0);if((a[r]&1)==0){i=k;return}v=c[r+8>>2]|0;if((v|0)==0){i=k;return}sS(v);i=k;return}}while(0);p=fc(4)|0;c[p>>2]=53912;dq(p|0,60416,316)}}while(0);k=fc(4)|0;c[k>>2]=53912;dq(k|0,60416,316)}function oC(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;l=i;i=i+104|0;m=(g-f|0)/12|0;n=l|0;do{if(m>>>0>100){o=sR(m)|0;if((o|0)!=0){p=o;q=o;break}o=fc(4)|0;c[o>>2]=53880;dq(o|0,60400,240);return 0}else{p=n;q=0}}while(0);n=(f|0)==(g|0);if(n){r=m;s=0}else{o=m;m=0;t=p;u=f;while(1){v=d[u]|0;if((v&1|0)==0){w=v>>>1}else{w=c[u+4>>2]|0}if((w|0)==0){a[t]=2;x=m+1|0;y=o-1|0}else{a[t]=1;x=m;y=o}v=u+12|0;if((v|0)==(g|0)){r=y;s=x;break}else{o=y;m=x;t=t+1|0;u=v}}}u=b|0;b=h;t=0;x=s;s=r;r=e;L754:while(1){e=(s|0)!=0;m=t;y=r;while(1){o=c[u>>2]|0;do{if((o|0)==0){z=0}else{w=c[o+12>>2]|0;if((w|0)==(c[o+16>>2]|0)){A=f2[c[(c[o>>2]|0)+36>>2]&255](o)|0}else{A=c[w>>2]|0}if((A|0)==-1){c[u>>2]=0;z=0;break}else{z=c[u>>2]|0;break}}}while(0);o=(z|0)==0;if((y|0)==0){B=z;C=0}else{w=c[y+12>>2]|0;if((w|0)==(c[y+16>>2]|0)){D=f2[c[(c[y>>2]|0)+36>>2]&255](y)|0}else{D=c[w>>2]|0}B=c[u>>2]|0;C=(D|0)==-1?0:y}E=(C|0)==0;if(!((o^E)&e)){break L754}o=c[B+12>>2]|0;if((o|0)==(c[B+16>>2]|0)){F=f2[c[(c[B>>2]|0)+36>>2]&255](B)|0}else{F=c[o>>2]|0}if(k){G=F}else{G=gj[c[(c[b>>2]|0)+28>>2]&127](h,F)|0}H=m+1|0;if(n){m=H;y=C}else{break}}L784:do{if(k){y=s;e=x;o=p;w=0;v=f;while(1){do{if((a[o]|0)==1){I=a[v]|0;if((I&1)==0){J=v+4|0}else{J=c[v+8>>2]|0}if((G|0)!=(c[J+(m<<2)>>2]|0)){a[o]=0;K=w;L=e;M=y-1|0;break}N=I&255;if((N&1|0)==0){O=N>>>1}else{O=c[v+4>>2]|0}if((O|0)!=(H|0)){K=1;L=e;M=y;break}a[o]=2;K=1;L=e+1|0;M=y-1|0}else{K=w;L=e;M=y}}while(0);N=v+12|0;if((N|0)==(g|0)){P=M;Q=L;R=K;break L784}y=M;e=L;o=o+1|0;w=K;v=N}}else{v=s;w=x;o=p;e=0;y=f;while(1){do{if((a[o]|0)==1){N=y;if((a[N]&1)==0){S=y+4|0}else{S=c[y+8>>2]|0}if((G|0)!=(gj[c[(c[b>>2]|0)+28>>2]&127](h,c[S+(m<<2)>>2]|0)|0)){a[o]=0;T=e;U=w;V=v-1|0;break}I=d[N]|0;if((I&1|0)==0){W=I>>>1}else{W=c[y+4>>2]|0}if((W|0)!=(H|0)){T=1;U=w;V=v;break}a[o]=2;T=1;U=w+1|0;V=v-1|0}else{T=e;U=w;V=v}}while(0);I=y+12|0;if((I|0)==(g|0)){P=V;Q=U;R=T;break L784}v=V;w=U;o=o+1|0;e=T;y=I}}}while(0);if(!R){t=H;x=Q;s=P;r=C;continue}m=c[u>>2]|0;y=m+12|0;e=c[y>>2]|0;if((e|0)==(c[m+16>>2]|0)){o=c[(c[m>>2]|0)+40>>2]|0;f2[o&255](m)|0}else{c[y>>2]=e+4}if((P+Q|0)>>>0<2){t=H;x=Q;s=P;r=C;continue}else{X=Q;Y=p;Z=f}while(1){do{if((a[Y]|0)==2){e=d[Z]|0;if((e&1|0)==0){_=e>>>1}else{_=c[Z+4>>2]|0}if((_|0)==(H|0)){$=X;break}a[Y]=0;$=X-1|0}else{$=X}}while(0);e=Z+12|0;if((e|0)==(g|0)){t=H;x=$;s=P;r=C;continue L754}else{X=$;Y=Y+1|0;Z=e}}}do{if((B|0)==0){aa=1}else{Z=c[B+12>>2]|0;if((Z|0)==(c[B+16>>2]|0)){ab=f2[c[(c[B>>2]|0)+36>>2]&255](B)|0}else{ab=c[Z>>2]|0}if((ab|0)==-1){c[u>>2]=0;aa=1;break}else{aa=(c[u>>2]|0)==0;break}}}while(0);do{if(E){ac=726}else{u=c[C+12>>2]|0;if((u|0)==(c[C+16>>2]|0)){ad=f2[c[(c[C>>2]|0)+36>>2]&255](C)|0}else{ad=c[u>>2]|0}if((ad|0)==-1){ac=726;break}if(!aa){ac=728}}}while(0);if((ac|0)==726){if(aa){ac=728}}if((ac|0)==728){c[j>>2]=c[j>>2]|2}L861:do{if(n){ac=733}else{aa=f;ad=p;while(1){if((a[ad]|0)==2){ae=aa;break L861}C=aa+12|0;if((C|0)==(g|0)){ac=733;break L861}aa=C;ad=ad+1|0}}}while(0);if((ac|0)==733){c[j>>2]=c[j>>2]|4;ae=g}if((q|0)==0){i=l;return ae|0}sS(q);i=l;return ae|0}function oD(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0;n=c[g>>2]|0;o=(n|0)==(f|0);do{if(o){p=(c[m+96>>2]|0)==(b|0);if(!p){if((c[m+100>>2]|0)!=(b|0)){break}}c[g>>2]=f+1;a[f]=p?43:45;c[h>>2]=0;q=0;return q|0}}while(0);p=d[j]|0;if((p&1|0)==0){r=p>>>1}else{r=c[j+4>>2]|0}if((r|0)!=0&(b|0)==(i|0)){i=c[l>>2]|0;if((i-k|0)>=160){q=0;return q|0}k=c[h>>2]|0;c[l>>2]=i+4;c[i>>2]=k;c[h>>2]=0;q=0;return q|0}k=m+104|0;i=m;while(1){if((i|0)==(k|0)){s=k;break}if((c[i>>2]|0)==(b|0)){s=i;break}else{i=i+4|0}}i=s-m|0;m=i>>2;if((i|0)>92){q=-1;return q|0}do{if((e|0)==8|(e|0)==10){if((m|0)<(e|0)){break}else{q=-1}return q|0}else if((e|0)==16){if((i|0)<88){break}if(o){q=-1;return q|0}if((n-f|0)>=3){q=-1;return q|0}if((a[n-1|0]|0)!=48){q=-1;return q|0}c[h>>2]=0;s=a[62176+m|0]|0;b=c[g>>2]|0;c[g>>2]=b+1;a[b]=s;q=0;return q|0}}while(0);f=a[62176+m|0]|0;c[g>>2]=n+1;a[n]=f;c[h>>2]=(c[h>>2]|0)+1;q=0;return q|0}function oE(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+144|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==0){v=0}else if((u|0)==64){v=8}else{v=10}u=l|0;oF(n,c[h+28>>2]|0,u,m);s_(p|0,0,12);h=o;mT(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=c[m>>2]|0;m=o+8|0;C=w;w=c[z>>2]|0;L927:while(1){do{if((w|0)==0){D=0}else{E=c[w+12>>2]|0;if((E|0)==(c[w+16>>2]|0)){F=f2[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{F=c[E>>2]|0}if((F|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;G=c[f>>2]|0;do{if((G|0)==0){H=794}else{I=c[G+12>>2]|0;if((I|0)==(c[G+16>>2]|0)){J=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{J=c[I>>2]|0}if((J|0)==-1){c[f>>2]=0;H=794;break}else{if(E){K=G;L=0;break}else{M=C;N=G;O=0;P=D;Q=0;break L927}}}}while(0);if((H|0)==794){H=0;if(E){M=C;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}G=(c[q>>2]|0)-C|0;I=a[p]|0;R=I&255;if((G|0)==(((R&1|0)==0?R>>>1:c[A>>2]|0)|0)){R=G<<1;do{if(G>>>0<R>>>0){mT(o,G)}else{if((I&1)==0){a[h+1+R|0]=0;a[p]=G<<2&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[A>>2]=R;break}}}while(0);R=a[p]|0;if((R&1)==0){S=10;T=R}else{R=c[g>>2]|0;S=(R&-2)-1|0;T=R&255}R=T&255;I=(R&1|0)==0?R>>>1:c[A>>2]|0;do{if(I>>>0<S>>>0){mT(o,S-I|0)}else{if((T&1)==0){a[h+1+S|0]=0;a[p]=S<<1&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[A>>2]=S;break}}}while(0);if((a[p]&1)==0){U=x}else{U=c[y>>2]|0}c[q>>2]=U+G;V=U}else{V=C}I=D+12|0;R=c[I>>2]|0;W=D+16|0;if((R|0)==(c[W>>2]|0)){X=f2[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{X=c[R>>2]|0}if((oD(X,v,V,q,t,B,n,l,s,u)|0)!=0){M=V;N=K;O=L;P=D;Q=E;break}R=c[I>>2]|0;if((R|0)==(c[W>>2]|0)){W=c[(c[D>>2]|0)+40>>2]|0;f2[W&255](D)|0;C=V;w=D;continue}else{c[I>>2]=R+4;C=V;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){Y=w>>>1}else{Y=c[n+4>>2]|0}do{if((Y|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}V=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=V}}while(0);c[k>>2]=oc(M,c[q>>2]|0,j,v)|0;oe(n,l,c[s>>2]|0,j);do{if(Q){Z=0}else{s=c[P+12>>2]|0;if((s|0)==(c[P+16>>2]|0)){_=f2[c[(c[P>>2]|0)+36>>2]&255](P)|0}else{_=c[s>>2]|0}if((_|0)!=-1){Z=P;break}c[z>>2]=0;Z=0}}while(0);z=(Z|0)==0;do{if(O){H=847}else{P=c[N+12>>2]|0;if((P|0)==(c[N+16>>2]|0)){$=f2[c[(c[N>>2]|0)+36>>2]&255](N)|0}else{$=c[P>>2]|0}if(($|0)==-1){c[f>>2]=0;H=847;break}else{if(z^(N|0)==0){break}else{H=849;break}}}}while(0);if((H|0)==847){if(z){H=849}}if((H|0)==849){c[j>>2]=c[j>>2]|2}c[b>>2]=Z;do{if((a[p]&1)!=0){Z=c[m>>2]|0;if((Z|0)==0){break}sS(Z)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}sS(D);i=e;return}function oF(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=f+16|0;j=b+4|0;I=c[j>>2]|0,c[j>>2]=I+1,I;if((c[137880]|0)!=-1){c[h>>2]=551520;c[h+4>>2]=16;c[h+8>>2]=0;mU(551520,h)}h=(c[137881]|0)-1|0;k=b+12|0;l=b+8|0;m=c[l>>2]|0;do{if((c[k>>2]|0)-m>>2>>>0>h>>>0){n=c[m+(h<<2)>>2]|0;if((n|0)==0){break}o=n;p=c[(c[n>>2]|0)+48>>2]|0;gn[p&31](o,62176,62202,d)|0;if((c[137784]|0)!=-1){c[g>>2]=551136;c[g+4>>2]=16;c[g+8>>2]=0;mU(551136,g)}o=(c[137785]|0)-1|0;p=c[l>>2]|0;do{if((c[k>>2]|0)-p>>2>>>0>o>>>0){n=c[p+(o<<2)>>2]|0;if((n|0)==0){break}q=n;c[e>>2]=f2[c[(c[n>>2]|0)+16>>2]&255](q)|0;f0[c[(c[n>>2]|0)+20>>2]&255](a,q);if(((I=c[j>>2]|0,c[j>>2]=I+ -1,I)|0)!=0){i=f;return}f$[c[(c[b>>2]|0)+8>>2]&511](b);i=f;return}}while(0);o=fc(4)|0;c[o>>2]=53912;dq(o|0,60416,316)}}while(0);f=fc(4)|0;c[f>>2]=53912;dq(f|0,60416,316)}function oG(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+144|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==0){v=0}else if((u|0)==64){v=8}else if((u|0)==8){v=16}else{v=10}u=l|0;oF(n,c[h+28>>2]|0,u,m);s_(p|0,0,12);h=o;mT(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=c[m>>2]|0;m=o+8|0;C=w;w=c[z>>2]|0;L1058:while(1){do{if((w|0)==0){D=0}else{E=c[w+12>>2]|0;if((E|0)==(c[w+16>>2]|0)){F=f2[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{F=c[E>>2]|0}if((F|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;G=c[f>>2]|0;do{if((G|0)==0){H=904}else{I=c[G+12>>2]|0;if((I|0)==(c[G+16>>2]|0)){J=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{J=c[I>>2]|0}if((J|0)==-1){c[f>>2]=0;H=904;break}else{if(E){L=G;M=0;break}else{N=C;O=G;P=0;Q=D;R=0;break L1058}}}}while(0);if((H|0)==904){H=0;if(E){N=C;O=0;P=1;Q=0;R=1;break}else{L=0;M=1}}G=(c[q>>2]|0)-C|0;I=a[p]|0;S=I&255;if((G|0)==(((S&1|0)==0?S>>>1:c[A>>2]|0)|0)){S=G<<1;do{if(G>>>0<S>>>0){mT(o,G)}else{if((I&1)==0){a[h+1+S|0]=0;a[p]=G<<2&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[A>>2]=S;break}}}while(0);S=a[p]|0;if((S&1)==0){T=10;U=S}else{S=c[g>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;I=(S&1|0)==0?S>>>1:c[A>>2]|0;do{if(I>>>0<T>>>0){mT(o,T-I|0)}else{if((U&1)==0){a[h+1+T|0]=0;a[p]=T<<1&255;break}else{a[(c[m>>2]|0)+T|0]=0;c[A>>2]=T;break}}}while(0);if((a[p]&1)==0){V=x}else{V=c[y>>2]|0}c[q>>2]=V+G;W=V}else{W=C}I=D+12|0;S=c[I>>2]|0;X=D+16|0;if((S|0)==(c[X>>2]|0)){Y=f2[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{Y=c[S>>2]|0}if((oD(Y,v,W,q,t,B,n,l,s,u)|0)!=0){N=W;O=L;P=M;Q=D;R=E;break}S=c[I>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[D>>2]|0)+40>>2]|0;f2[X&255](D)|0;C=W;w=D;continue}else{c[I>>2]=S+4;C=W;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){Z=w>>>1}else{Z=c[n+4>>2]|0}do{if((Z|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}W=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=W}}while(0);t=og(N,c[q>>2]|0,j,v)|0;c[k>>2]=t;c[k+4>>2]=K;oe(n,l,c[s>>2]|0,j);do{if(R){_=0}else{s=c[Q+12>>2]|0;if((s|0)==(c[Q+16>>2]|0)){$=f2[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{$=c[s>>2]|0}if(($|0)!=-1){_=Q;break}c[z>>2]=0;_=0}}while(0);z=(_|0)==0;do{if(P){H=957}else{Q=c[O+12>>2]|0;if((Q|0)==(c[O+16>>2]|0)){aa=f2[c[(c[O>>2]|0)+36>>2]&255](O)|0}else{aa=c[Q>>2]|0}if((aa|0)==-1){c[f>>2]=0;H=957;break}else{if(z^(O|0)==0){break}else{H=959;break}}}}while(0);if((H|0)==957){if(z){H=959}}if((H|0)==959){c[j>>2]=c[j>>2]|2}c[b>>2]=_;do{if((a[p]&1)!=0){_=c[m>>2]|0;if((_|0)==0){break}sS(_)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}sS(D);i=e;return}function oH(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=i;i=i+144|0;m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7>>3<<3;c[h>>2]=c[m>>2];m=f|0;n=f+104|0;o=f+112|0;p=f+128|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=c[j+4>>2]&74;if((v|0)==64){w=8}else if((v|0)==8){w=16}else if((v|0)==0){w=0}else{w=10}v=m|0;oF(o,c[j+28>>2]|0,v,n);s_(q|0,0,12);j=p;mT(p,10);if((a[q]&1)==0){m=j+1|0;x=m;y=m;z=p+8|0}else{m=p+8|0;x=c[m>>2]|0;y=j+1|0;z=m}c[r>>2]=x;m=s|0;c[t>>2]=m;c[u>>2]=0;A=g|0;g=h|0;h=p|0;B=p+4|0;C=c[n>>2]|0;n=p+8|0;D=x;x=c[A>>2]|0;L1165:while(1){do{if((x|0)==0){E=0}else{F=c[x+12>>2]|0;if((F|0)==(c[x+16>>2]|0)){G=f2[c[(c[x>>2]|0)+36>>2]&255](x)|0}else{G=c[F>>2]|0}if((G|0)!=-1){E=x;break}c[A>>2]=0;E=0}}while(0);F=(E|0)==0;H=c[g>>2]|0;do{if((H|0)==0){I=991}else{J=c[H+12>>2]|0;if((J|0)==(c[H+16>>2]|0)){K=f2[c[(c[H>>2]|0)+36>>2]&255](H)|0}else{K=c[J>>2]|0}if((K|0)==-1){c[g>>2]=0;I=991;break}else{if(F){L=H;M=0;break}else{N=D;O=H;P=0;Q=E;R=0;break L1165}}}}while(0);if((I|0)==991){I=0;if(F){N=D;O=0;P=1;Q=0;R=1;break}else{L=0;M=1}}H=(c[r>>2]|0)-D|0;J=a[q]|0;S=J&255;if((H|0)==(((S&1|0)==0?S>>>1:c[B>>2]|0)|0)){S=H<<1;do{if(H>>>0<S>>>0){mT(p,H)}else{if((J&1)==0){a[j+1+S|0]=0;a[q]=H<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[B>>2]=S;break}}}while(0);S=a[q]|0;if((S&1)==0){T=10;U=S}else{S=c[h>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;J=(S&1|0)==0?S>>>1:c[B>>2]|0;do{if(J>>>0<T>>>0){mT(p,T-J|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[q]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[B>>2]=T;break}}}while(0);if((a[q]&1)==0){V=y}else{V=c[z>>2]|0}c[r>>2]=V+H;W=V}else{W=D}J=E+12|0;S=c[J>>2]|0;X=E+16|0;if((S|0)==(c[X>>2]|0)){Y=f2[c[(c[E>>2]|0)+36>>2]&255](E)|0}else{Y=c[S>>2]|0}if((oD(Y,w,W,r,u,C,o,m,t,v)|0)!=0){N=W;O=L;P=M;Q=E;R=F;break}S=c[J>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[E>>2]|0)+40>>2]|0;f2[X&255](E)|0;D=W;x=E;continue}else{c[J>>2]=S+4;D=W;x=E;continue}}E=o;x=d[E]|0;if((x&1|0)==0){Z=x>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){x=c[t>>2]|0;if((x-s|0)>=160){break}W=c[u>>2]|0;c[t>>2]=x+4;c[x>>2]=W}}while(0);b[l>>1]=oi(N,c[r>>2]|0,k,w)|0;oe(o,m,c[t>>2]|0,k);do{if(R){_=0}else{t=c[Q+12>>2]|0;if((t|0)==(c[Q+16>>2]|0)){$=f2[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{$=c[t>>2]|0}if(($|0)!=-1){_=Q;break}c[A>>2]=0;_=0}}while(0);A=(_|0)==0;do{if(P){I=1044}else{Q=c[O+12>>2]|0;if((Q|0)==(c[O+16>>2]|0)){aa=f2[c[(c[O>>2]|0)+36>>2]&255](O)|0}else{aa=c[Q>>2]|0}if((aa|0)==-1){c[g>>2]=0;I=1044;break}else{if(A^(O|0)==0){break}else{I=1046;break}}}}while(0);if((I|0)==1044){if(A){I=1046}}if((I|0)==1046){c[k>>2]=c[k>>2]|2}c[e>>2]=_;do{if((a[q]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}sS(_)}}while(0);if((a[E]&1)==0){i=f;return}E=c[o+8>>2]|0;if((E|0)==0){i=f;return}sS(E);i=f;return}function oI(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+144|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==0){v=0}else if((u|0)==8){v=16}else if((u|0)==64){v=8}else{v=10}u=l|0;oF(n,c[h+28>>2]|0,u,m);s_(p|0,0,12);h=o;mT(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=c[m>>2]|0;m=o+8|0;C=w;w=c[z>>2]|0;L1272:while(1){do{if((w|0)==0){D=0}else{E=c[w+12>>2]|0;if((E|0)==(c[w+16>>2]|0)){F=f2[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{F=c[E>>2]|0}if((F|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;G=c[f>>2]|0;do{if((G|0)==0){H=1078}else{I=c[G+12>>2]|0;if((I|0)==(c[G+16>>2]|0)){J=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{J=c[I>>2]|0}if((J|0)==-1){c[f>>2]=0;H=1078;break}else{if(E){K=G;L=0;break}else{M=C;N=G;O=0;P=D;Q=0;break L1272}}}}while(0);if((H|0)==1078){H=0;if(E){M=C;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}G=(c[q>>2]|0)-C|0;I=a[p]|0;R=I&255;if((G|0)==(((R&1|0)==0?R>>>1:c[A>>2]|0)|0)){R=G<<1;do{if(G>>>0<R>>>0){mT(o,G)}else{if((I&1)==0){a[h+1+R|0]=0;a[p]=G<<2&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[A>>2]=R;break}}}while(0);R=a[p]|0;if((R&1)==0){S=10;T=R}else{R=c[g>>2]|0;S=(R&-2)-1|0;T=R&255}R=T&255;I=(R&1|0)==0?R>>>1:c[A>>2]|0;do{if(I>>>0<S>>>0){mT(o,S-I|0)}else{if((T&1)==0){a[h+1+S|0]=0;a[p]=S<<1&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[A>>2]=S;break}}}while(0);if((a[p]&1)==0){U=x}else{U=c[y>>2]|0}c[q>>2]=U+G;V=U}else{V=C}I=D+12|0;R=c[I>>2]|0;W=D+16|0;if((R|0)==(c[W>>2]|0)){X=f2[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{X=c[R>>2]|0}if((oD(X,v,V,q,t,B,n,l,s,u)|0)!=0){M=V;N=K;O=L;P=D;Q=E;break}R=c[I>>2]|0;if((R|0)==(c[W>>2]|0)){W=c[(c[D>>2]|0)+40>>2]|0;f2[W&255](D)|0;C=V;w=D;continue}else{c[I>>2]=R+4;C=V;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){Y=w>>>1}else{Y=c[n+4>>2]|0}do{if((Y|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}V=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=V}}while(0);c[k>>2]=ok(M,c[q>>2]|0,j,v)|0;oe(n,l,c[s>>2]|0,j);do{if(Q){Z=0}else{s=c[P+12>>2]|0;if((s|0)==(c[P+16>>2]|0)){_=f2[c[(c[P>>2]|0)+36>>2]&255](P)|0}else{_=c[s>>2]|0}if((_|0)!=-1){Z=P;break}c[z>>2]=0;Z=0}}while(0);z=(Z|0)==0;do{if(O){H=1131}else{P=c[N+12>>2]|0;if((P|0)==(c[N+16>>2]|0)){$=f2[c[(c[N>>2]|0)+36>>2]&255](N)|0}else{$=c[P>>2]|0}if(($|0)==-1){c[f>>2]=0;H=1131;break}else{if(z^(N|0)==0){break}else{H=1133;break}}}}while(0);if((H|0)==1131){if(z){H=1133}}if((H|0)==1133){c[j>>2]=c[j>>2]|2}c[b>>2]=Z;do{if((a[p]&1)!=0){Z=c[m>>2]|0;if((Z|0)==0){break}sS(Z)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}sS(D);i=e;return}function oJ(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+144|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==64){v=8}else if((u|0)==0){v=0}else{v=10}u=l|0;oF(n,c[h+28>>2]|0,u,m);s_(p|0,0,12);h=o;mT(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=c[m>>2]|0;m=o+8|0;C=w;w=c[z>>2]|0;L1379:while(1){do{if((w|0)==0){D=0}else{E=c[w+12>>2]|0;if((E|0)==(c[w+16>>2]|0)){F=f2[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{F=c[E>>2]|0}if((F|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;G=c[f>>2]|0;do{if((G|0)==0){H=1165}else{I=c[G+12>>2]|0;if((I|0)==(c[G+16>>2]|0)){J=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{J=c[I>>2]|0}if((J|0)==-1){c[f>>2]=0;H=1165;break}else{if(E){K=G;L=0;break}else{M=C;N=G;O=0;P=D;Q=0;break L1379}}}}while(0);if((H|0)==1165){H=0;if(E){M=C;N=0;O=1;P=0;Q=1;break}else{K=0;L=1}}G=(c[q>>2]|0)-C|0;I=a[p]|0;R=I&255;if((G|0)==(((R&1|0)==0?R>>>1:c[A>>2]|0)|0)){R=G<<1;do{if(G>>>0<R>>>0){mT(o,G)}else{if((I&1)==0){a[h+1+R|0]=0;a[p]=G<<2&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[A>>2]=R;break}}}while(0);R=a[p]|0;if((R&1)==0){S=10;T=R}else{R=c[g>>2]|0;S=(R&-2)-1|0;T=R&255}R=T&255;I=(R&1|0)==0?R>>>1:c[A>>2]|0;do{if(I>>>0<S>>>0){mT(o,S-I|0)}else{if((T&1)==0){a[h+1+S|0]=0;a[p]=S<<1&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[A>>2]=S;break}}}while(0);if((a[p]&1)==0){U=x}else{U=c[y>>2]|0}c[q>>2]=U+G;V=U}else{V=C}I=D+12|0;R=c[I>>2]|0;W=D+16|0;if((R|0)==(c[W>>2]|0)){X=f2[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{X=c[R>>2]|0}if((oD(X,v,V,q,t,B,n,l,s,u)|0)!=0){M=V;N=K;O=L;P=D;Q=E;break}R=c[I>>2]|0;if((R|0)==(c[W>>2]|0)){W=c[(c[D>>2]|0)+40>>2]|0;f2[W&255](D)|0;C=V;w=D;continue}else{c[I>>2]=R+4;C=V;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){Y=w>>>1}else{Y=c[n+4>>2]|0}do{if((Y|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}V=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=V}}while(0);c[k>>2]=om(M,c[q>>2]|0,j,v)|0;oe(n,l,c[s>>2]|0,j);do{if(Q){Z=0}else{s=c[P+12>>2]|0;if((s|0)==(c[P+16>>2]|0)){_=f2[c[(c[P>>2]|0)+36>>2]&255](P)|0}else{_=c[s>>2]|0}if((_|0)!=-1){Z=P;break}c[z>>2]=0;Z=0}}while(0);z=(Z|0)==0;do{if(O){H=1218}else{P=c[N+12>>2]|0;if((P|0)==(c[N+16>>2]|0)){$=f2[c[(c[N>>2]|0)+36>>2]&255](N)|0}else{$=c[P>>2]|0}if(($|0)==-1){c[f>>2]=0;H=1218;break}else{if(z^(N|0)==0){break}else{H=1220;break}}}}while(0);if((H|0)==1218){if(z){H=1220}}if((H|0)==1220){c[j>>2]=c[j>>2]|2}c[b>>2]=Z;do{if((a[p]&1)!=0){Z=c[m>>2]|0;if((Z|0)==0){break}sS(Z)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}sS(D);i=e;return}function oK(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+144|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=o;q=i;i=i+4|0;i=i+7>>3<<3;r=i;i=i+160|0;s=i;i=i+4|0;i=i+7>>3<<3;t=i;i=i+4|0;i=i+7>>3<<3;u=c[h+4>>2]&74;if((u|0)==8){v=16}else if((u|0)==64){v=8}else if((u|0)==0){v=0}else{v=10}u=l|0;oF(n,c[h+28>>2]|0,u,m);s_(p|0,0,12);h=o;mT(o,10);if((a[p]&1)==0){l=h+1|0;w=l;x=l;y=o+8|0}else{l=o+8|0;w=c[l>>2]|0;x=h+1|0;y=l}c[q>>2]=w;l=r|0;c[s>>2]=l;c[t>>2]=0;z=f|0;f=g|0;g=o|0;A=o+4|0;B=c[m>>2]|0;m=o+8|0;C=w;w=c[z>>2]|0;L1486:while(1){do{if((w|0)==0){D=0}else{E=c[w+12>>2]|0;if((E|0)==(c[w+16>>2]|0)){F=f2[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{F=c[E>>2]|0}if((F|0)!=-1){D=w;break}c[z>>2]=0;D=0}}while(0);E=(D|0)==0;G=c[f>>2]|0;do{if((G|0)==0){H=1252}else{I=c[G+12>>2]|0;if((I|0)==(c[G+16>>2]|0)){J=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{J=c[I>>2]|0}if((J|0)==-1){c[f>>2]=0;H=1252;break}else{if(E){L=G;M=0;break}else{N=C;O=G;P=0;Q=D;R=0;break L1486}}}}while(0);if((H|0)==1252){H=0;if(E){N=C;O=0;P=1;Q=0;R=1;break}else{L=0;M=1}}G=(c[q>>2]|0)-C|0;I=a[p]|0;S=I&255;if((G|0)==(((S&1|0)==0?S>>>1:c[A>>2]|0)|0)){S=G<<1;do{if(G>>>0<S>>>0){mT(o,G)}else{if((I&1)==0){a[h+1+S|0]=0;a[p]=G<<2&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[A>>2]=S;break}}}while(0);S=a[p]|0;if((S&1)==0){T=10;U=S}else{S=c[g>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;I=(S&1|0)==0?S>>>1:c[A>>2]|0;do{if(I>>>0<T>>>0){mT(o,T-I|0)}else{if((U&1)==0){a[h+1+T|0]=0;a[p]=T<<1&255;break}else{a[(c[m>>2]|0)+T|0]=0;c[A>>2]=T;break}}}while(0);if((a[p]&1)==0){V=x}else{V=c[y>>2]|0}c[q>>2]=V+G;W=V}else{W=C}I=D+12|0;S=c[I>>2]|0;X=D+16|0;if((S|0)==(c[X>>2]|0)){Y=f2[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{Y=c[S>>2]|0}if((oD(Y,v,W,q,t,B,n,l,s,u)|0)!=0){N=W;O=L;P=M;Q=D;R=E;break}S=c[I>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[D>>2]|0)+40>>2]|0;f2[X&255](D)|0;C=W;w=D;continue}else{c[I>>2]=S+4;C=W;w=D;continue}}D=n;w=d[D]|0;if((w&1|0)==0){Z=w>>>1}else{Z=c[n+4>>2]|0}do{if((Z|0)!=0){w=c[s>>2]|0;if((w-r|0)>=160){break}W=c[t>>2]|0;c[s>>2]=w+4;c[w>>2]=W}}while(0);t=oo(N,c[q>>2]|0,j,v)|0;c[k>>2]=t;c[k+4>>2]=K;oe(n,l,c[s>>2]|0,j);do{if(R){_=0}else{s=c[Q+12>>2]|0;if((s|0)==(c[Q+16>>2]|0)){$=f2[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{$=c[s>>2]|0}if(($|0)!=-1){_=Q;break}c[z>>2]=0;_=0}}while(0);z=(_|0)==0;do{if(P){H=1305}else{Q=c[O+12>>2]|0;if((Q|0)==(c[O+16>>2]|0)){aa=f2[c[(c[O>>2]|0)+36>>2]&255](O)|0}else{aa=c[Q>>2]|0}if((aa|0)==-1){c[f>>2]=0;H=1305;break}else{if(z^(O|0)==0){break}else{H=1307;break}}}}while(0);if((H|0)==1305){if(z){H=1307}}if((H|0)==1307){c[j>>2]=c[j>>2]|2}c[b>>2]=_;do{if((a[p]&1)!=0){_=c[m>>2]|0;if((_|0)==0){break}sS(_)}}while(0);if((a[D]&1)==0){i=e;return}D=c[n+8>>2]|0;if((D|0)==0){i=e;return}sS(D);i=e;return}function oL(b,e,f,g,h,i,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0;if((b|0)==(i|0)){if((a[e]&1)==0){p=-1;return p|0}a[e]=0;i=c[h>>2]|0;c[h>>2]=i+1;a[i]=46;i=d[k]|0;if((i&1|0)==0){q=i>>>1}else{q=c[k+4>>2]|0}if((q|0)==0){p=0;return p|0}q=c[m>>2]|0;if((q-l|0)>=160){p=0;return p|0}i=c[n>>2]|0;c[m>>2]=q+4;c[q>>2]=i;p=0;return p|0}do{if((b|0)==(j|0)){i=d[k]|0;if((i&1|0)==0){r=i>>>1}else{r=c[k+4>>2]|0}if((r|0)==0){break}if((a[e]&1)==0){p=-1;return p|0}i=c[m>>2]|0;if((i-l|0)>=160){p=0;return p|0}q=c[n>>2]|0;c[m>>2]=i+4;c[i>>2]=q;c[n>>2]=0;p=0;return p|0}}while(0);r=o+128|0;j=o;while(1){if((j|0)==(r|0)){s=r;break}if((c[j>>2]|0)==(b|0)){s=j;break}else{j=j+4|0}}j=s-o|0;o=j>>2;if((j|0)>124){p=-1;return p|0}s=a[62176+o|0]|0;do{if((o|0)==22|(o|0)==23){a[f]=80}else if((o|0)==25|(o|0)==24){b=c[h>>2]|0;do{if((b|0)!=(g|0)){if((a[b-1|0]&95|0)==(a[f]&127|0)){break}else{p=-1}return p|0}}while(0);c[h>>2]=b+1;a[b]=s;p=0;return p|0}else{r=a[f]|0;if((s&95|0)!=(r<<24>>24|0)){break}a[f]=r|-128;if((a[e]&1)==0){break}a[e]=0;r=d[k]|0;if((r&1|0)==0){t=r>>>1}else{t=c[k+4>>2]|0}if((t|0)==0){break}r=c[m>>2]|0;if((r-l|0)>=160){break}q=c[n>>2]|0;c[m>>2]=r+4;c[r>>2]=q}}while(0);m=c[h>>2]|0;c[h>>2]=m+1;a[m]=s;if((j|0)>84){p=0;return p|0}c[n>>2]=(c[n>>2]|0)+1;p=0;return p|0}function oM(b,e,f,h,j,k,l){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+176|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7>>3<<3;c[h>>2]=c[m>>2];m=e+128|0;n=e+136|0;o=e+144|0;p=e+160|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;oN(o,c[j+28>>2]|0,x,m,n);s_(q|0,0,12);j=p;mT(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=h|0;h=p|0;D=p+4|0;E=c[m>>2]|0;m=c[n>>2]|0;n=p+8|0;F=z;z=c[C>>2]|0;L1650:while(1){do{if((z|0)==0){G=0}else{H=c[z+12>>2]|0;if((H|0)==(c[z+16>>2]|0)){I=f2[c[(c[z>>2]|0)+36>>2]&255](z)|0}else{I=c[H>>2]|0}if((I|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;J=c[f>>2]|0;do{if((J|0)==0){K=1383}else{L=c[J+12>>2]|0;if((L|0)==(c[J+16>>2]|0)){M=f2[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{M=c[L>>2]|0}if((M|0)==-1){c[f>>2]=0;K=1383;break}else{if(H){N=J;O=0;break}else{P=F;Q=J;R=0;S=G;T=0;break L1650}}}}while(0);if((K|0)==1383){K=0;if(H){P=F;Q=0;R=1;S=0;T=1;break}else{N=0;O=1}}J=(c[r>>2]|0)-F|0;L=a[q]|0;U=L&255;if((J|0)==(((U&1|0)==0?U>>>1:c[D>>2]|0)|0)){U=J<<1;do{if(J>>>0<U>>>0){mT(p,J)}else{if((L&1)==0){a[j+1+U|0]=0;a[q]=J<<2&255;break}else{a[(c[n>>2]|0)+U|0]=0;c[D>>2]=U;break}}}while(0);U=a[q]|0;if((U&1)==0){V=10;W=U}else{U=c[h>>2]|0;V=(U&-2)-1|0;W=U&255}U=W&255;L=(U&1|0)==0?U>>>1:c[D>>2]|0;do{if(L>>>0<V>>>0){mT(p,V-L|0)}else{if((W&1)==0){a[j+1+V|0]=0;a[q]=V<<1&255;break}else{a[(c[n>>2]|0)+V|0]=0;c[D>>2]=V;break}}}while(0);if((a[q]&1)==0){X=A}else{X=c[B>>2]|0}c[r>>2]=X+J;Y=X}else{Y=F}L=G+12|0;U=c[L>>2]|0;Z=G+16|0;if((U|0)==(c[Z>>2]|0)){_=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{_=c[U>>2]|0}if((oL(_,v,w,Y,r,E,m,o,y,t,u,x)|0)!=0){P=Y;Q=N;R=O;S=G;T=H;break}U=c[L>>2]|0;if((U|0)==(c[Z>>2]|0)){Z=c[(c[G>>2]|0)+40>>2]|0;f2[Z&255](G)|0;F=Y;z=G;continue}else{c[L>>2]=U+4;F=Y;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){$=z>>>1}else{$=c[o+4>>2]|0}do{if(($|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}Y=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=Y}}while(0);g[l>>2]=+or(P,c[r>>2]|0,k);oe(o,y,c[t>>2]|0,k);do{if(T){aa=0}else{t=c[S+12>>2]|0;if((t|0)==(c[S+16>>2]|0)){ab=f2[c[(c[S>>2]|0)+36>>2]&255](S)|0}else{ab=c[t>>2]|0}if((ab|0)!=-1){aa=S;break}c[C>>2]=0;aa=0}}while(0);C=(aa|0)==0;do{if(R){K=1437}else{S=c[Q+12>>2]|0;if((S|0)==(c[Q+16>>2]|0)){ac=f2[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{ac=c[S>>2]|0}if((ac|0)==-1){c[f>>2]=0;K=1437;break}else{if(C^(Q|0)==0){break}else{K=1439;break}}}}while(0);if((K|0)==1437){if(C){K=1439}}if((K|0)==1439){c[k>>2]=c[k>>2]|2}c[b>>2]=aa;do{if((a[q]&1)!=0){aa=c[n>>2]|0;if((aa|0)==0){break}sS(aa)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}sS(G);i=e;return}function oN(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=b+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;if((c[137880]|0)!=-1){c[j>>2]=551520;c[j+4>>2]=16;c[j+8>>2]=0;mU(551520,j)}j=(c[137881]|0)-1|0;l=b+12|0;m=b+8|0;n=c[m>>2]|0;do{if((c[l>>2]|0)-n>>2>>>0>j>>>0){o=c[n+(j<<2)>>2]|0;if((o|0)==0){break}p=o;q=c[(c[o>>2]|0)+48>>2]|0;gn[q&31](p,62176,62208,d)|0;if((c[137784]|0)!=-1){c[h>>2]=551136;c[h+4>>2]=16;c[h+8>>2]=0;mU(551136,h)}p=(c[137785]|0)-1|0;q=c[m>>2]|0;do{if((c[l>>2]|0)-q>>2>>>0>p>>>0){o=c[q+(p<<2)>>2]|0;if((o|0)==0){break}r=o;s=o;c[e>>2]=f2[c[(c[s>>2]|0)+12>>2]&255](r)|0;c[f>>2]=f2[c[(c[s>>2]|0)+16>>2]&255](r)|0;f0[c[(c[o>>2]|0)+20>>2]&255](a,r);if(((I=c[k>>2]|0,c[k>>2]=I+ -1,I)|0)!=0){i=g;return}f$[c[(c[b>>2]|0)+8>>2]&511](b);i=g;return}}while(0);p=fc(4)|0;c[p>>2]=53912;dq(p|0,60416,316)}}while(0);g=fc(4)|0;c[g>>2]=53912;dq(g|0,60416,316)}function oO(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+176|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=e+128|0;n=e+136|0;o=e+144|0;p=e+160|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;oN(o,c[j+28>>2]|0,x,m,n);s_(q|0,0,12);j=p;mT(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=g|0;g=p|0;D=p+4|0;E=c[m>>2]|0;m=c[n>>2]|0;n=p+8|0;F=z;z=c[C>>2]|0;L1778:while(1){do{if((z|0)==0){G=0}else{H=c[z+12>>2]|0;if((H|0)==(c[z+16>>2]|0)){I=f2[c[(c[z>>2]|0)+36>>2]&255](z)|0}else{I=c[H>>2]|0}if((I|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;J=c[f>>2]|0;do{if((J|0)==0){K=1491}else{L=c[J+12>>2]|0;if((L|0)==(c[J+16>>2]|0)){M=f2[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{M=c[L>>2]|0}if((M|0)==-1){c[f>>2]=0;K=1491;break}else{if(H){N=J;O=0;break}else{P=F;Q=J;R=0;S=G;T=0;break L1778}}}}while(0);if((K|0)==1491){K=0;if(H){P=F;Q=0;R=1;S=0;T=1;break}else{N=0;O=1}}J=(c[r>>2]|0)-F|0;L=a[q]|0;U=L&255;if((J|0)==(((U&1|0)==0?U>>>1:c[D>>2]|0)|0)){U=J<<1;do{if(J>>>0<U>>>0){mT(p,J)}else{if((L&1)==0){a[j+1+U|0]=0;a[q]=J<<2&255;break}else{a[(c[n>>2]|0)+U|0]=0;c[D>>2]=U;break}}}while(0);U=a[q]|0;if((U&1)==0){V=10;W=U}else{U=c[g>>2]|0;V=(U&-2)-1|0;W=U&255}U=W&255;L=(U&1|0)==0?U>>>1:c[D>>2]|0;do{if(L>>>0<V>>>0){mT(p,V-L|0)}else{if((W&1)==0){a[j+1+V|0]=0;a[q]=V<<1&255;break}else{a[(c[n>>2]|0)+V|0]=0;c[D>>2]=V;break}}}while(0);if((a[q]&1)==0){X=A}else{X=c[B>>2]|0}c[r>>2]=X+J;Y=X}else{Y=F}L=G+12|0;U=c[L>>2]|0;Z=G+16|0;if((U|0)==(c[Z>>2]|0)){_=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{_=c[U>>2]|0}if((oL(_,v,w,Y,r,E,m,o,y,t,u,x)|0)!=0){P=Y;Q=N;R=O;S=G;T=H;break}U=c[L>>2]|0;if((U|0)==(c[Z>>2]|0)){Z=c[(c[G>>2]|0)+40>>2]|0;f2[Z&255](G)|0;F=Y;z=G;continue}else{c[L>>2]=U+4;F=Y;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){$=z>>>1}else{$=c[o+4>>2]|0}do{if(($|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}Y=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=Y}}while(0);h[l>>3]=+ou(P,c[r>>2]|0,k);oe(o,y,c[t>>2]|0,k);do{if(T){aa=0}else{t=c[S+12>>2]|0;if((t|0)==(c[S+16>>2]|0)){ab=f2[c[(c[S>>2]|0)+36>>2]&255](S)|0}else{ab=c[t>>2]|0}if((ab|0)!=-1){aa=S;break}c[C>>2]=0;aa=0}}while(0);C=(aa|0)==0;do{if(R){K=1545}else{S=c[Q+12>>2]|0;if((S|0)==(c[Q+16>>2]|0)){ac=f2[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{ac=c[S>>2]|0}if((ac|0)==-1){c[f>>2]=0;K=1545;break}else{if(C^(Q|0)==0){break}else{K=1547;break}}}}while(0);if((K|0)==1545){if(C){K=1547}}if((K|0)==1547){c[k>>2]=c[k>>2]|2}c[b>>2]=aa;do{if((a[q]&1)!=0){aa=c[n>>2]|0;if((aa|0)==0){break}sS(aa)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}sS(G);i=e;return}function oP(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+176|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[m>>2];m=e+128|0;n=e+136|0;o=e+144|0;p=e+160|0;q=p;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+160|0;t=i;i=i+4|0;i=i+7>>3<<3;u=i;i=i+4|0;i=i+7>>3<<3;v=i;i=i+1|0;i=i+7>>3<<3;w=i;i=i+1|0;i=i+7>>3<<3;x=e|0;oN(o,c[j+28>>2]|0,x,m,n);s_(q|0,0,12);j=p;mT(p,10);if((a[q]&1)==0){y=j+1|0;z=y;A=y;B=p+8|0}else{y=p+8|0;z=c[y>>2]|0;A=j+1|0;B=y}c[r>>2]=z;y=s|0;c[t>>2]=y;c[u>>2]=0;a[v]=1;a[w]=69;C=f|0;f=g|0;g=p|0;D=p+4|0;E=c[m>>2]|0;m=c[n>>2]|0;n=p+8|0;F=z;z=c[C>>2]|0;L1881:while(1){do{if((z|0)==0){G=0}else{H=c[z+12>>2]|0;if((H|0)==(c[z+16>>2]|0)){I=f2[c[(c[z>>2]|0)+36>>2]&255](z)|0}else{I=c[H>>2]|0}if((I|0)!=-1){G=z;break}c[C>>2]=0;G=0}}while(0);H=(G|0)==0;J=c[f>>2]|0;do{if((J|0)==0){K=1575}else{L=c[J+12>>2]|0;if((L|0)==(c[J+16>>2]|0)){M=f2[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{M=c[L>>2]|0}if((M|0)==-1){c[f>>2]=0;K=1575;break}else{if(H){N=J;O=0;break}else{P=F;Q=J;R=0;S=G;T=0;break L1881}}}}while(0);if((K|0)==1575){K=0;if(H){P=F;Q=0;R=1;S=0;T=1;break}else{N=0;O=1}}J=(c[r>>2]|0)-F|0;L=a[q]|0;U=L&255;if((J|0)==(((U&1|0)==0?U>>>1:c[D>>2]|0)|0)){U=J<<1;do{if(J>>>0<U>>>0){mT(p,J)}else{if((L&1)==0){a[j+1+U|0]=0;a[q]=J<<2&255;break}else{a[(c[n>>2]|0)+U|0]=0;c[D>>2]=U;break}}}while(0);U=a[q]|0;if((U&1)==0){V=10;W=U}else{U=c[g>>2]|0;V=(U&-2)-1|0;W=U&255}U=W&255;L=(U&1|0)==0?U>>>1:c[D>>2]|0;do{if(L>>>0<V>>>0){mT(p,V-L|0)}else{if((W&1)==0){a[j+1+V|0]=0;a[q]=V<<1&255;break}else{a[(c[n>>2]|0)+V|0]=0;c[D>>2]=V;break}}}while(0);if((a[q]&1)==0){X=A}else{X=c[B>>2]|0}c[r>>2]=X+J;Y=X}else{Y=F}L=G+12|0;U=c[L>>2]|0;Z=G+16|0;if((U|0)==(c[Z>>2]|0)){_=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{_=c[U>>2]|0}if((oL(_,v,w,Y,r,E,m,o,y,t,u,x)|0)!=0){P=Y;Q=N;R=O;S=G;T=H;break}U=c[L>>2]|0;if((U|0)==(c[Z>>2]|0)){Z=c[(c[G>>2]|0)+40>>2]|0;f2[Z&255](G)|0;F=Y;z=G;continue}else{c[L>>2]=U+4;F=Y;z=G;continue}}G=o;z=d[G]|0;if((z&1|0)==0){$=z>>>1}else{$=c[o+4>>2]|0}do{if(($|0)!=0){if((a[v]&1)==0){break}z=c[t>>2]|0;if((z-s|0)>=160){break}Y=c[u>>2]|0;c[t>>2]=z+4;c[z>>2]=Y}}while(0);h[l>>3]=+ow(P,c[r>>2]|0,k);oe(o,y,c[t>>2]|0,k);do{if(T){aa=0}else{t=c[S+12>>2]|0;if((t|0)==(c[S+16>>2]|0)){ab=f2[c[(c[S>>2]|0)+36>>2]&255](S)|0}else{ab=c[t>>2]|0}if((ab|0)!=-1){aa=S;break}c[C>>2]=0;aa=0}}while(0);C=(aa|0)==0;do{if(R){K=1629}else{S=c[Q+12>>2]|0;if((S|0)==(c[Q+16>>2]|0)){ac=f2[c[(c[Q>>2]|0)+36>>2]&255](Q)|0}else{ac=c[S>>2]|0}if((ac|0)==-1){c[f>>2]=0;K=1629;break}else{if(C^(Q|0)==0){break}else{K=1631;break}}}}while(0);if((K|0)==1629){if(C){K=1631}}if((K|0)==1631){c[k>>2]=c[k>>2]|2}c[b>>2]=aa;do{if((a[q]&1)!=0){aa=c[n>>2]|0;if((aa|0)==0){break}sS(aa)}}while(0);if((a[G]&1)==0){i=e;return}G=c[o+8>>2]|0;if((G|0)==0){i=e;return}sS(G);i=e;return}function oQ(a){a=a|0;return}function oR(a){a=a|0;if((a|0)==0){return}sS(a);return}function oS(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;d=i;i=i+136|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[k>>2];k=d|0;l=d+16|0;m=d+120|0;n=m;o=i;i=i+12|0;i=i+7>>3<<3;p=i;i=i+4|0;i=i+7>>3<<3;q=i;i=i+160|0;r=i;i=i+4|0;i=i+7>>3<<3;s=i;i=i+4|0;i=i+7>>3<<3;s_(n|0,0,12);t=o;u=c[g+28>>2]|0;g=u+4|0;I=c[g>>2]|0,c[g>>2]=I+1,I;if((c[137880]|0)!=-1){c[k>>2]=551520;c[k+4>>2]=16;c[k+8>>2]=0;mU(551520,k)}k=(c[137881]|0)-1|0;v=c[u+8>>2]|0;do{if((c[u+12>>2]|0)-v>>2>>>0>k>>>0){w=c[v+(k<<2)>>2]|0;if((w|0)==0){break}x=w;y=l|0;z=c[(c[w>>2]|0)+48>>2]|0;gn[z&31](x,62176,62202,y)|0;if(((I=c[g>>2]|0,c[g>>2]=I+ -1,I)|0)==0){f$[c[(c[u>>2]|0)+8>>2]&511](u)}s_(t|0,0,12);x=o;mT(o,10);if((a[t]&1)==0){z=x+1|0;A=z;B=z;C=o+8|0}else{z=o+8|0;A=c[z>>2]|0;B=x+1|0;C=z}c[p>>2]=A;z=q|0;c[r>>2]=z;c[s>>2]=0;w=e|0;D=f|0;E=o|0;F=o+4|0;G=o+8|0;H=A;J=c[w>>2]|0;L2000:while(1){do{if((J|0)==0){K=0}else{L=c[J+12>>2]|0;if((L|0)==(c[J+16>>2]|0)){M=f2[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{M=c[L>>2]|0}if((M|0)!=-1){K=J;break}c[w>>2]=0;K=0}}while(0);L=(K|0)==0;N=c[D>>2]|0;do{if((N|0)==0){O=1674}else{P=c[N+12>>2]|0;if((P|0)==(c[N+16>>2]|0)){Q=f2[c[(c[N>>2]|0)+36>>2]&255](N)|0}else{Q=c[P>>2]|0}if((Q|0)==-1){c[D>>2]=0;O=1674;break}else{if(L){break}else{R=H;break L2000}}}}while(0);if((O|0)==1674){O=0;if(L){R=H;break}}N=(c[p>>2]|0)-H|0;P=a[t]|0;S=P&255;if((N|0)==(((S&1|0)==0?S>>>1:c[F>>2]|0)|0)){S=N<<1;do{if(N>>>0<S>>>0){mT(o,N)}else{if((P&1)==0){a[x+1+S|0]=0;a[t]=N<<2&255;break}else{a[(c[G>>2]|0)+S|0]=0;c[F>>2]=S;break}}}while(0);S=a[t]|0;if((S&1)==0){T=10;U=S}else{S=c[E>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;P=(S&1|0)==0?S>>>1:c[F>>2]|0;do{if(P>>>0<T>>>0){mT(o,T-P|0)}else{if((U&1)==0){a[x+1+T|0]=0;a[t]=T<<1&255;break}else{a[(c[G>>2]|0)+T|0]=0;c[F>>2]=T;break}}}while(0);if((a[t]&1)==0){V=B}else{V=c[C>>2]|0}c[p>>2]=V+N;W=V}else{W=H}P=K+12|0;S=c[P>>2]|0;L=K+16|0;if((S|0)==(c[L>>2]|0)){X=f2[c[(c[K>>2]|0)+36>>2]&255](K)|0}else{X=c[S>>2]|0}if((oD(X,16,W,p,s,0,m,z,r,y)|0)!=0){R=W;break}S=c[P>>2]|0;if((S|0)==(c[L>>2]|0)){L=c[(c[K>>2]|0)+40>>2]|0;f2[L&255](K)|0;H=W;J=K;continue}else{c[P>>2]=S+4;H=W;J=K;continue}}a[R+3|0]=0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);J=oA(R,c[137522]|0,(H=i,i=i+8|0,c[H>>2]=j,H)|0)|0;i=H;if((J|0)!=1){c[h>>2]=4}J=c[w>>2]|0;do{if((J|0)==0){Y=0}else{H=c[J+12>>2]|0;if((H|0)==(c[J+16>>2]|0)){Z=f2[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{Z=c[H>>2]|0}if((Z|0)!=-1){Y=J;break}c[w>>2]=0;Y=0}}while(0);w=(Y|0)==0;J=c[D>>2]|0;do{if((J|0)==0){O=1726}else{H=c[J+12>>2]|0;if((H|0)==(c[J+16>>2]|0)){_=f2[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{_=c[H>>2]|0}if((_|0)==-1){c[D>>2]=0;O=1726;break}else{if(w){break}else{O=1728;break}}}}while(0);if((O|0)==1726){if(w){O=1728}}if((O|0)==1728){c[h>>2]=c[h>>2]|2}c[b>>2]=Y;do{if((a[t]&1)!=0){D=c[G>>2]|0;if((D|0)==0){break}sS(D)}}while(0);if((a[n]&1)==0){i=d;return}G=c[m+8>>2]|0;if((G|0)==0){i=d;return}sS(G);i=d;return}}while(0);d=fc(4)|0;c[d>>2]=53912;dq(d|0,60416,316)}function oT(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;i=i+40|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=j+16|0;m=j+24|0;if((c[f+4>>2]&1|0)==0){n=c[(c[d>>2]|0)+24>>2]|0;c[l>>2]=c[e>>2];gk[n&63](b,d,l,f,g,h&1);i=j;return}g=c[f+28>>2]|0;f=g+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[137786]|0)!=-1){c[k>>2]=551144;c[k+4>>2]=16;c[k+8>>2]=0;mU(551144,k)}k=(c[137787]|0)-1|0;l=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-l>>2>>>0>k>>>0){d=c[l+(k<<2)>>2]|0;if((d|0)==0){break}n=d;if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f$[c[(c[g>>2]|0)+8>>2]&511](g)}o=c[d>>2]|0;if(h){f0[c[o+24>>2]&255](m,n)}else{f0[c[o+28>>2]&255](m,n)}n=m;o=m;d=a[o]|0;if((d&1)==0){p=n+1|0;q=p;r=p;s=m+8|0}else{p=m+8|0;q=c[p>>2]|0;r=n+1|0;s=p}p=e|0;n=m+4|0;t=q;u=d;while(1){v=(u&1)==0;if(v){w=r}else{w=c[s>>2]|0}d=u&255;if((t|0)==(w+((d&1|0)==0?d>>>1:c[n>>2]|0)|0)){break}d=a[t]|0;x=c[p>>2]|0;do{if((x|0)!=0){y=x+24|0;z=c[y>>2]|0;if((z|0)!=(c[x+28>>2]|0)){c[y>>2]=z+1;a[z]=d;break}if((gj[c[(c[x>>2]|0)+52>>2]&127](x,d&255)|0)!=-1){break}c[p>>2]=0}}while(0);t=t+1|0;u=a[o]|0}c[b>>2]=c[p>>2];if(v){i=j;return}o=c[m+8>>2]|0;if((o|0)==0){i=j;return}sS(o);i=j;return}}while(0);j=fc(4)|0;c[j>>2]=53912;dq(j|0,60416,316)}function oU(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+72|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+48|0;n=d+56|0;o=d+64|0;p=j|0;a[p]=a[53344]|0;a[p+1|0]=a[53345|0]|0;a[p+2|0]=a[53346|0]|0;a[p+3|0]=a[53347|0]|0;a[p+4|0]=a[53348|0]|0;a[p+5|0]=a[53349|0]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==64){a[t]=111}else if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else{a[t]=100}}while(0);t=k|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);s=oV(t,12,c[137522]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+s|0;h=c[r>>2]&176;do{if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((s|0)>1&r<<24>>24==48)){w=1805;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=1805;break}v=k+2|0}else if((h|0)==32){v=p}else{w=1805}}while(0);if((w|0)==1805){v=t}w=l|0;l=o|0;h=c[f+28>>2]|0;c[l>>2]=h;k=h+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;oW(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;oX(b,y,w,z,A,f,g);i=d;return}f$[c[(c[o>>2]|0)+8>>2]&511](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;oX(b,y,w,z,A,f,g);i=d;return}function oV(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=h;c[j>>2]=f;c[j+4>>2]=0;j=eC(d|0)|0;d=ew(a|0,b|0,e|0,h|0)|0;if((j|0)==0){i=g;return d|0}eC(j|0)|0;i=g;return d|0}function oW(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[137882]|0)!=-1){c[n>>2]=551528;c[n+4>>2]=16;c[n+8>>2]=0;mU(551528,n)}n=(c[137883]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=fc(4)|0;s=r;c[s>>2]=53912;dq(r|0,60416,316)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=fc(4)|0;s=r;c[s>>2]=53912;dq(r|0,60416,316)}r=k;s=c[p>>2]|0;if((c[137786]|0)!=-1){c[m>>2]=551144;c[m+4>>2]=16;c[m+8>>2]=0;mU(551144,m)}m=(c[137787]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=fc(4)|0;u=t;c[u>>2]=53912;dq(t|0,60416,316)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=fc(4)|0;u=t;c[u>>2]=53912;dq(t|0,60416,316)}t=s;f0[c[(c[s>>2]|0)+20>>2]&255](o,t);u=o;m=o;p=d[m]|0;if((p&1|0)==0){v=p>>>1}else{v=c[o+4>>2]|0}do{if((v|0)==0){p=c[(c[k>>2]|0)+32>>2]|0;gn[p&31](r,b,f,g)|0;c[j>>2]=g+(f-b)}else{c[j>>2]=g;p=a[b]|0;if((p<<24>>24|0)==45|(p<<24>>24|0)==43){n=gj[c[(c[k>>2]|0)+28>>2]&127](r,p)|0;p=c[j>>2]|0;c[j>>2]=p+1;a[p]=n;w=b+1|0}else{w=b}do{if((f-w|0)>1){if((a[w]|0)!=48){x=w;break}n=w+1|0;p=a[n]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){x=w;break}p=k;q=gj[c[(c[p>>2]|0)+28>>2]&127](r,48)|0;y=c[j>>2]|0;c[j>>2]=y+1;a[y]=q;q=gj[c[(c[p>>2]|0)+28>>2]&127](r,a[n]|0)|0;n=c[j>>2]|0;c[j>>2]=n+1;a[n]=q;x=w+2|0}else{x=w}}while(0);do{if((x|0)!=(f|0)){q=f-1|0;if(x>>>0<q>>>0){z=x;A=q}else{break}do{q=a[z]|0;a[z]=a[A]|0;a[A]=q;z=z+1|0;A=A-1|0;}while(z>>>0<A>>>0)}}while(0);q=f2[c[(c[s>>2]|0)+16>>2]&255](t)|0;if(x>>>0<f>>>0){n=u+1|0;p=k;y=o+4|0;B=o+8|0;C=0;D=0;E=x;while(1){F=a[((a[m]&1)==0?n:c[B>>2]|0)+D|0]|0;if(F<<24>>24!=0&(C|0)==(F<<24>>24|0)){F=c[j>>2]|0;c[j>>2]=F+1;a[F]=q;F=d[m]|0;G=(D>>>0<(((F&1|0)==0?F>>>1:c[y>>2]|0)-1|0)>>>0)+D|0;H=0}else{G=D;H=C}F=gj[c[(c[p>>2]|0)+28>>2]&127](r,a[E]|0)|0;I=c[j>>2]|0;c[j>>2]=I+1;a[I]=F;F=E+1|0;if(F>>>0<f>>>0){C=H+1|0;D=G;E=F}else{break}}}E=g+(x-b)|0;D=c[j>>2]|0;if((E|0)==(D|0)){break}C=D-1|0;if(E>>>0<C>>>0){J=E;K=C}else{break}do{C=a[J]|0;a[J]=a[K]|0;a[K]=C;J=J+1|0;K=K-1|0;}while(J>>>0<K>>>0)}}while(0);if((e|0)==(f|0)){L=c[j>>2]|0}else{L=g+(e-b)|0}c[h>>2]=L;if((a[m]&1)==0){i=l;return}m=c[o+8>>2]|0;if((m|0)==0){i=l;return}sS(m);i=l;return}function oX(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=i;i=i+16|0;l=k|0;if((d|0)==0){c[b>>2]=0;i=k;return}m=g;g=e;n=m-g|0;o=h+12|0;h=c[o>>2]|0;p=(h|0)>(n|0)?h-n|0:0;n=f;h=n-g|0;do{if((h|0)>0){if((f7[c[(c[d>>2]|0)+48>>2]&127](d,e,h)|0)==(h|0)){break}c[b>>2]=0;i=k;return}}while(0);do{if((p|0)>0){do{if(p>>>0<11){h=p<<1&255;e=l;a[e]=h;q=l+1|0;r=h;s=e}else{e=p+16&-16;h=(e|0)==0?1:e;while(1){t=sR(h)|0;if((t|0)!=0){u=1898;break}g=(I=c[138018]|0,c[138018]=I+0,I);if((g|0)==0){break}gp[g&63]()}if((u|0)==1898){c[l+8>>2]=t;h=e|1;c[l>>2]=h;c[l+4>>2]=p;q=t;r=h&255;s=l;break}h=fc(4)|0;c[h>>2]=53880;dq(h|0,60400,240)}}while(0);s_(q|0,j|0,p|0);a[q+p|0]=0;if((r&1)==0){v=l+1|0}else{v=c[l+8>>2]|0}if((f7[c[(c[d>>2]|0)+48>>2]&127](d,v,p)|0)==(p|0)){if((a[s]&1)==0){break}h=c[l+8>>2]|0;if((h|0)==0){break}sS(h);break}c[b>>2]=0;if((a[s]&1)==0){i=k;return}h=c[l+8>>2]|0;if((h|0)==0){i=k;return}sS(h);i=k;return}}while(0);l=m-n|0;do{if((l|0)>0){if((f7[c[(c[d>>2]|0)+48>>2]&127](d,f,l)|0)==(l|0)){break}c[b>>2]=0;i=k;return}}while(0);c[o>>2]=0;c[b>>2]=d;i=k;return}function oY(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+104|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+80|0;o=d+88|0;p=d+96|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=100}}while(0);t=l|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);u=oV(t,22,c[137522]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+u|0;j=c[r>>2]&176;do{if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=1947;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=1947;break}v=l+2|0}else if((j|0)==32){v=q}else{w=1947}}while(0);if((w|0)==1947){v=t}w=m|0;m=p|0;j=c[f+28>>2]|0;c[m>>2]=j;l=j+4|0;I=c[l>>2]|0,c[l>>2]=I+1,I;oW(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;oX(b,y,w,z,A,f,g);i=d;return}f$[c[(c[p>>2]|0)+8>>2]&511](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;oX(b,y,w,z,A,f,g);i=d;return}function oZ(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+72|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+48|0;n=d+56|0;o=d+64|0;p=j|0;a[p]=a[53344]|0;a[p+1|0]=a[53345|0]|0;a[p+2|0]=a[53346|0]|0;a[p+3|0]=a[53347|0]|0;a[p+4|0]=a[53348|0]|0;a[p+5|0]=a[53349|0]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==64){a[t]=111}else if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else{a[t]=117}}while(0);t=k|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);s=oV(t,12,c[137522]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+s|0;h=c[r>>2]&176;do{if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((s|0)>1&r<<24>>24==48)){w=1978;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=1978;break}v=k+2|0}else if((h|0)==32){v=p}else{w=1978}}while(0);if((w|0)==1978){v=t}w=l|0;l=o|0;h=c[f+28>>2]|0;c[l>>2]=h;k=h+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;oW(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;oX(b,y,w,z,A,f,g);i=d;return}f$[c[(c[o>>2]|0)+8>>2]&511](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;oX(b,y,w,z,A,f,g);i=d;return}function o_(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+104|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+80|0;o=d+88|0;p=d+96|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=117}}while(0);t=l|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);u=oV(t,23,c[137522]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+u|0;j=c[r>>2]&176;do{if((j|0)==32){v=q}else if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=2009;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=2009;break}v=l+2|0}else{w=2009}}while(0);if((w|0)==2009){v=t}w=m|0;m=p|0;l=c[f+28>>2]|0;c[m>>2]=l;u=l+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;oW(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;oX(b,y,w,z,A,f,g);i=d;return}f$[c[(c[p>>2]|0)+8>>2]&511](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;oX(b,y,w,z,A,f,g);i=d;return}function o$(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+144|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+112|0;p=d+120|0;q=d+128|0;r=d+136|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){if((k&1|0)==0){a[w]=97;x=0;break}else{a[w]=65;x=0;break}}else{a[w]=46;u=w+2|0;a[w+1|0]=42;if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=c[137522]|0;if(x){v=oV(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=oV(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[682976]|0)==0;if(x){do{if(v){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=o0(m,c[137522]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);v=o0(m,c[137522]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=fc(4)|0;c[v>>2]=53880;dq(v|0,60400,240)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=2071;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=2071;break}E=D+2|0}else if((z|0)==32){E=m}else{F=2071}}while(0);if((F|0)==2071){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=sR(B<<1)|0;if((F|0)!=0){G=F;H=F;J=D;break}F=fc(4)|0;c[F>>2]=53880;dq(F|0,60400,240)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;o1(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){f$[c[(c[q>>2]|0)+8>>2]&511](q|0)}q=e|0;oX(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){sS(H)}if((C|0)==0){i=d;return}sS(C);i=d;return}function o0(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f|0;h=g;c[h>>2]=e;c[h+4>>2]=0;h=eC(b|0)|0;b=fj(a|0,d|0,g|0)|0;if((h|0)==0){i=f;return b|0}eC(h|0)|0;i=f;return b|0}function o1(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[137882]|0)!=-1){c[n>>2]=551528;c[n+4>>2]=16;c[n+8>>2]=0;mU(551528,n)}n=(c[137883]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=fc(4)|0;s=r;c[s>>2]=53912;dq(r|0,60416,316)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=fc(4)|0;s=r;c[s>>2]=53912;dq(r|0,60416,316)}r=k;s=c[p>>2]|0;if((c[137786]|0)!=-1){c[m>>2]=551144;c[m+4>>2]=16;c[m+8>>2]=0;mU(551144,m)}m=(c[137787]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=fc(4)|0;u=t;c[u>>2]=53912;dq(t|0,60416,316)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=fc(4)|0;u=t;c[u>>2]=53912;dq(t|0,60416,316)}t=s;f0[c[(c[s>>2]|0)+20>>2]&255](o,t);c[j>>2]=g;u=a[b]|0;if((u<<24>>24|0)==45|(u<<24>>24|0)==43){m=gj[c[(c[k>>2]|0)+28>>2]&127](r,u)|0;u=c[j>>2]|0;c[j>>2]=u+1;a[u]=m;v=b+1|0}else{v=b}m=f;L2517:do{if((m-v|0)>1){if((a[v]|0)!=48){w=v;x=2142;break}u=v+1|0;p=a[u]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){w=v;x=2142;break}p=k;n=gj[c[(c[p>>2]|0)+28>>2]&127](r,48)|0;q=c[j>>2]|0;c[j>>2]=q+1;a[q]=n;n=v+2|0;q=gj[c[(c[p>>2]|0)+28>>2]&127](r,a[u]|0)|0;u=c[j>>2]|0;c[j>>2]=u+1;a[u]=q;q=n;while(1){if(q>>>0>=f>>>0){y=q;z=n;break L2517}u=a[q]|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);if((a8(u<<24>>24|0,c[137522]|0)|0)==0){y=q;z=n;break}else{q=q+1|0}}}else{w=v;x=2142}}while(0);L2532:do{if((x|0)==2142){while(1){x=0;if(w>>>0>=f>>>0){y=w;z=v;break L2532}q=a[w]|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);if((eU(q<<24>>24|0,c[137522]|0)|0)==0){y=w;z=v;break}else{w=w+1|0;x=2142}}}}while(0);x=o;w=o;v=d[w]|0;if((v&1|0)==0){A=v>>>1}else{A=c[o+4>>2]|0}do{if((A|0)==0){v=c[j>>2]|0;u=c[(c[k>>2]|0)+32>>2]|0;gn[u&31](r,z,y,v)|0;c[j>>2]=(c[j>>2]|0)+(y-z)}else{do{if((z|0)!=(y|0)){v=y-1|0;if(z>>>0<v>>>0){B=z;C=v}else{break}do{v=a[B]|0;a[B]=a[C]|0;a[C]=v;B=B+1|0;C=C-1|0;}while(B>>>0<C>>>0)}}while(0);q=f2[c[(c[s>>2]|0)+16>>2]&255](t)|0;if(z>>>0<y>>>0){v=x+1|0;u=o+4|0;n=o+8|0;p=k;D=0;E=0;F=z;while(1){G=a[((a[w]&1)==0?v:c[n>>2]|0)+E|0]|0;if(G<<24>>24>0&(D|0)==(G<<24>>24|0)){G=c[j>>2]|0;c[j>>2]=G+1;a[G]=q;G=d[w]|0;H=(E>>>0<(((G&1|0)==0?G>>>1:c[u>>2]|0)-1|0)>>>0)+E|0;I=0}else{H=E;I=D}G=gj[c[(c[p>>2]|0)+28>>2]&127](r,a[F]|0)|0;J=c[j>>2]|0;c[j>>2]=J+1;a[J]=G;G=F+1|0;if(G>>>0<y>>>0){D=I+1|0;E=H;F=G}else{break}}}F=g+(z-b)|0;E=c[j>>2]|0;if((F|0)==(E|0)){break}D=E-1|0;if(F>>>0<D>>>0){K=F;L=D}else{break}do{D=a[K]|0;a[K]=a[L]|0;a[L]=D;K=K+1|0;L=L-1|0;}while(K>>>0<L>>>0)}}while(0);L2570:do{if(y>>>0<f>>>0){L=k;K=y;while(1){z=a[K]|0;if(z<<24>>24==46){break}H=gj[c[(c[L>>2]|0)+28>>2]&127](r,z)|0;z=c[j>>2]|0;c[j>>2]=z+1;a[z]=H;H=K+1|0;if(H>>>0<f>>>0){K=H}else{M=H;break L2570}}L=f2[c[(c[s>>2]|0)+12>>2]&255](t)|0;H=c[j>>2]|0;c[j>>2]=H+1;a[H]=L;M=K+1|0}else{M=y}}while(0);gn[c[(c[k>>2]|0)+32>>2]&31](r,M,f,c[j>>2]|0)|0;r=(c[j>>2]|0)+(m-M)|0;c[j>>2]=r;if((e|0)==(f|0)){N=r}else{N=g+(e-b)|0}c[h>>2]=N;if((a[w]&1)==0){i=l;return}w=c[o+8>>2]|0;if((w|0)==0){i=l;return}sS(w);i=l;return}function o2(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+144|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+112|0;p=d+120|0;q=d+128|0;r=d+136|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){a[w]=76;u=w+1|0;if((k&1|0)==0){a[u]=97;x=0;break}else{a[u]=65;x=0;break}}else{a[w]=46;a[w+1|0]=42;a[w+2|0]=76;u=w+3|0;if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=c[137522]|0;if(x){v=oV(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=oV(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[682976]|0)==0;if(x){do{if(v){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=o0(m,c[137522]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);v=o0(m,c[137522]|0,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=fc(4)|0;c[v>>2]=53880;dq(v|0,60400,240)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=2242;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=2242;break}E=D+2|0}else if((z|0)==32){E=m}else{F=2242}}while(0);if((F|0)==2242){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=sR(B<<1)|0;if((F|0)!=0){G=F;H=F;J=D;break}F=fc(4)|0;c[F>>2]=53880;dq(F|0,60400,240)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;o1(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){f$[c[(c[q>>2]|0)+8>>2]&511](q|0)}q=e|0;oX(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){sS(H)}if((C|0)==0){i=d;return}sS(C);i=d;return}function o3(a){a=a|0;return}function o4(a){a=a|0;if((a|0)==0){return}sS(a);return}function o5(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+136|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+112|0;n=d+120|0;o=d+128|0;p=j|0;a[p]=a[53344]|0;a[p+1|0]=a[53345|0]|0;a[p+2|0]=a[53346|0]|0;a[p+3|0]=a[53347|0]|0;a[p+4|0]=a[53348|0]|0;a[p+5|0]=a[53349|0]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==64){a[t]=111}else if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else{a[t]=100}}while(0);t=k|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);s=oV(t,12,c[137522]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+s|0;h=c[r>>2]&176;do{if((h|0)==32){v=p}else if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((s|0)>1&r<<24>>24==48)){w=2293;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=2293;break}v=k+2|0}else{w=2293}}while(0);if((w|0)==2293){v=t}w=l|0;l=o|0;k=c[f+28>>2]|0;c[l>>2]=k;s=k+4|0;I=c[s>>2]|0,c[s>>2]=I+1,I;o9(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;pa(b,y,w,z,A,f,g);i=d;return}f$[c[(c[o>>2]|0)+8>>2]&511](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;pa(b,y,w,z,A,f,g);i=d;return}function o6(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+88|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+24|0;l=d+48|0;m=d+16|0;a[m]=a[53352]|0;a[m+1|0]=a[53353|0]|0;a[m+2|0]=a[53354|0]|0;a[m+3|0]=a[53355|0]|0;a[m+4|0]=a[53356|0]|0;a[m+5|0]=a[53357|0]|0;n=k|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);o=oV(n,20,c[137522]|0,m,(m=i,i=i+8|0,c[m>>2]=h,m)|0)|0;i=m;m=k+o|0;h=c[f+4>>2]&176;do{if((h|0)==16){p=a[n]|0;if((p<<24>>24|0)==45|(p<<24>>24|0)==43){q=k+1|0;break}if(!((o|0)>1&p<<24>>24==48)){r=2314;break}p=a[k+1|0]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){r=2314;break}q=k+2|0}else if((h|0)==32){q=m}else{r=2314}}while(0);if((r|0)==2314){q=n}r=c[f+28>>2]|0;h=r+4|0;I=c[h>>2]|0,c[h>>2]=I+1,I;if((c[137882]|0)!=-1){c[j>>2]=551528;c[j+4>>2]=16;c[j+8>>2]=0;mU(551528,j)}j=(c[137883]|0)-1|0;p=c[r+8>>2]|0;do{if((c[r+12>>2]|0)-p>>2>>>0>j>>>0){s=c[p+(j<<2)>>2]|0;if((s|0)==0){break}t=s;if(((I=c[h>>2]|0,c[h>>2]=I+ -1,I)|0)==0){f$[c[(c[r>>2]|0)+8>>2]&511](r)}u=l|0;v=c[(c[s>>2]|0)+32>>2]|0;gn[v&31](t,n,m,u)|0;t=l+o|0;if((q|0)==(m|0)){w=t;x=e|0;y=c[x>>2]|0;oX(b,y,u,w,t,f,g);i=d;return}w=l+(q-k)|0;x=e|0;y=c[x>>2]|0;oX(b,y,u,w,t,f,g);i=d;return}}while(0);d=fc(4)|0;c[d>>2]=53912;dq(d|0,60416,316)}function o7(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;i=i+40|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=j+16|0;m=j+24|0;if((c[f+4>>2]&1|0)==0){n=c[(c[d>>2]|0)+24>>2]|0;c[l>>2]=c[e>>2];gk[n&63](b,d,l,f,g,h&1);i=j;return}g=c[f+28>>2]|0;f=g+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[137784]|0)!=-1){c[k>>2]=551136;c[k+4>>2]=16;c[k+8>>2]=0;mU(551136,k)}k=(c[137785]|0)-1|0;l=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-l>>2>>>0>k>>>0){d=c[l+(k<<2)>>2]|0;if((d|0)==0){break}n=d;if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f$[c[(c[g>>2]|0)+8>>2]&511](g)}o=c[d>>2]|0;if(h){f0[c[o+24>>2]&255](m,n)}else{f0[c[o+28>>2]&255](m,n)}n=m;o=a[n]|0;if((o&1)==0){d=m+4|0;p=d;q=d;r=m+8|0}else{d=m+8|0;p=c[d>>2]|0;q=m+4|0;r=d}d=e|0;s=p;t=o;while(1){u=(t&1)==0;if(u){v=q}else{v=c[r>>2]|0}o=t&255;if((o&1|0)==0){w=o>>>1}else{w=c[q>>2]|0}if((s|0)==(v+(w<<2)|0)){break}o=c[s>>2]|0;x=c[d>>2]|0;do{if((x|0)!=0){y=x+24|0;z=c[y>>2]|0;if((z|0)==(c[x+28>>2]|0)){A=gj[c[(c[x>>2]|0)+52>>2]&127](x,o)|0}else{c[y>>2]=z+4;c[z>>2]=o;A=o}if((A|0)!=-1){break}c[d>>2]=0}}while(0);s=s+4|0;t=a[n]|0}c[b>>2]=c[d>>2];if(u){i=j;return}n=c[m+8>>2]|0;if((n|0)==0){i=j;return}sS(n);i=j;return}}while(0);j=fc(4)|0;c[j>>2]=53912;dq(j|0,60416,316)}function o8(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+224|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+200|0;o=d+208|0;p=d+216|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==64){a[t]=111}else if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else{a[t]=100}}while(0);t=l|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);s=oV(t,22,c[137522]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+s|0;j=c[r>>2]&176;do{if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((s|0)>1&r<<24>>24==48)){w=2396;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=2396;break}v=l+2|0}else if((j|0)==32){v=q}else{w=2396}}while(0);if((w|0)==2396){v=t}w=m|0;m=p|0;j=c[f+28>>2]|0;c[m>>2]=j;l=j+4|0;I=c[l>>2]|0,c[l>>2]=I+1,I;o9(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;pa(b,y,w,z,A,f,g);i=d;return}f$[c[(c[p>>2]|0)+8>>2]&511](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;pa(b,y,w,z,A,f,g);i=d;return}function o9(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[137880]|0)!=-1){c[n>>2]=551520;c[n+4>>2]=16;c[n+8>>2]=0;mU(551520,n)}n=(c[137881]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=fc(4)|0;s=r;c[s>>2]=53912;dq(r|0,60416,316)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=fc(4)|0;s=r;c[s>>2]=53912;dq(r|0,60416,316)}r=k;s=c[p>>2]|0;if((c[137784]|0)!=-1){c[m>>2]=551136;c[m+4>>2]=16;c[m+8>>2]=0;mU(551136,m)}m=(c[137785]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=fc(4)|0;u=t;c[u>>2]=53912;dq(t|0,60416,316)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=fc(4)|0;u=t;c[u>>2]=53912;dq(t|0,60416,316)}t=s;f0[c[(c[s>>2]|0)+20>>2]&255](o,t);u=o;m=o;p=d[m]|0;if((p&1|0)==0){v=p>>>1}else{v=c[o+4>>2]|0}do{if((v|0)==0){p=c[(c[k>>2]|0)+48>>2]|0;gn[p&31](r,b,f,g)|0;c[j>>2]=g+(f-b<<2)}else{c[j>>2]=g;p=a[b]|0;if((p<<24>>24|0)==45|(p<<24>>24|0)==43){n=gj[c[(c[k>>2]|0)+44>>2]&127](r,p)|0;p=c[j>>2]|0;c[j>>2]=p+4;c[p>>2]=n;w=b+1|0}else{w=b}do{if((f-w|0)>1){if((a[w]|0)!=48){x=w;break}n=w+1|0;p=a[n]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){x=w;break}p=k;q=gj[c[(c[p>>2]|0)+44>>2]&127](r,48)|0;y=c[j>>2]|0;c[j>>2]=y+4;c[y>>2]=q;q=gj[c[(c[p>>2]|0)+44>>2]&127](r,a[n]|0)|0;n=c[j>>2]|0;c[j>>2]=n+4;c[n>>2]=q;x=w+2|0}else{x=w}}while(0);do{if((x|0)!=(f|0)){q=f-1|0;if(x>>>0<q>>>0){z=x;A=q}else{break}do{q=a[z]|0;a[z]=a[A]|0;a[A]=q;z=z+1|0;A=A-1|0;}while(z>>>0<A>>>0)}}while(0);q=f2[c[(c[s>>2]|0)+16>>2]&255](t)|0;if(x>>>0<f>>>0){n=u+1|0;p=k;y=o+4|0;B=o+8|0;C=0;D=0;E=x;while(1){F=a[((a[m]&1)==0?n:c[B>>2]|0)+D|0]|0;if(F<<24>>24!=0&(C|0)==(F<<24>>24|0)){F=c[j>>2]|0;c[j>>2]=F+4;c[F>>2]=q;F=d[m]|0;G=(D>>>0<(((F&1|0)==0?F>>>1:c[y>>2]|0)-1|0)>>>0)+D|0;H=0}else{G=D;H=C}F=gj[c[(c[p>>2]|0)+44>>2]&127](r,a[E]|0)|0;I=c[j>>2]|0;c[j>>2]=I+4;c[I>>2]=F;F=E+1|0;if(F>>>0<f>>>0){C=H+1|0;D=G;E=F}else{break}}}E=g+(x-b<<2)|0;D=c[j>>2]|0;if((E|0)==(D|0)){break}C=D-4|0;if(E>>>0<C>>>0){J=E;K=C}else{break}do{C=c[J>>2]|0;c[J>>2]=c[K>>2];c[K>>2]=C;J=J+4|0;K=K-4|0;}while(J>>>0<K>>>0)}}while(0);if((e|0)==(f|0)){L=c[j>>2]|0}else{L=g+(e-b<<2)|0}c[h>>2]=L;if((a[m]&1)==0){i=l;return}m=c[o+8>>2]|0;if((m|0)==0){i=l;return}sS(m);i=l;return}function pa(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=i;i=i+16|0;l=k|0;if((d|0)==0){c[b>>2]=0;i=k;return}m=g;g=e;n=m-g>>2;o=h+12|0;h=c[o>>2]|0;p=(h|0)>(n|0)?h-n|0:0;n=f;h=n-g|0;g=h>>2;do{if((h|0)>0){if((f7[c[(c[d>>2]|0)+48>>2]&127](d,e,g)|0)==(g|0)){break}c[b>>2]=0;i=k;return}}while(0);do{if((p|0)>0){if(p>>>0>1073741822){mV()}do{if(p>>>0<2){a[l]=p<<1&255;q=1;r=l+4|0}else{g=p+4&-4;e=g<<2;h=(e|0)==0?1:e;while(1){s=sR(h)|0;if((s|0)!=0){t=2485;break}e=(I=c[138018]|0,c[138018]=I+0,I);if((e|0)==0){break}gp[e&63]()}if((t|0)==2485){h=s;c[l+8>>2]=h;c[l>>2]=g|1;c[l+4>>2]=p;q=p;r=h;break}h=fc(4)|0;c[h>>2]=53880;dq(h|0,60400,240)}}while(0);h=q;e=r;while(1){u=h-1|0;c[e>>2]=j;if((u|0)==0){break}else{h=u;e=e+4|0}}c[r+(p<<2)>>2]=0;e=l;if((a[e]&1)==0){v=l+4|0}else{v=c[l+8>>2]|0}if((f7[c[(c[d>>2]|0)+48>>2]&127](d,v,p)|0)==(p|0)){if((a[e]&1)==0){break}h=c[l+8>>2]|0;if((h|0)==0){break}sS(h);break}c[b>>2]=0;if((a[e]&1)==0){i=k;return}e=c[l+8>>2]|0;if((e|0)==0){i=k;return}sS(e);i=k;return}}while(0);l=m-n|0;n=l>>2;do{if((l|0)>0){if((f7[c[(c[d>>2]|0)+48>>2]&127](d,f,n)|0)==(n|0)){break}c[b>>2]=0;i=k;return}}while(0);c[o>>2]=0;c[b>>2]=d;i=k;return}function pb(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+136|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+112|0;n=d+120|0;o=d+128|0;p=j|0;a[p]=a[53344]|0;a[p+1|0]=a[53345|0]|0;a[p+2|0]=a[53346|0]|0;a[p+3|0]=a[53347|0]|0;a[p+4|0]=a[53348|0]|0;a[p+5|0]=a[53349|0]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=117}}while(0);t=k|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);u=oV(t,12,c[137522]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+u|0;h=c[r>>2]&176;do{if((h|0)==32){v=p}else if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=2536;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=2536;break}v=k+2|0}else{w=2536}}while(0);if((w|0)==2536){v=t}w=l|0;l=o|0;k=c[f+28>>2]|0;c[l>>2]=k;u=k+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;o9(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;pa(b,y,w,z,A,f,g);i=d;return}f$[c[(c[o>>2]|0)+8>>2]&511](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;pa(b,y,w,z,A,f,g);i=d;return}function pc(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+232|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+208|0;o=d+216|0;p=d+224|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=117}}while(0);t=l|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);u=oV(t,23,c[137522]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+u|0;j=c[r>>2]&176;do{if((j|0)==32){v=q}else if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=2567;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=2567;break}v=l+2|0}else{w=2567}}while(0);if((w|0)==2567){v=t}w=m|0;m=p|0;l=c[f+28>>2]|0;c[m>>2]=l;u=l+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;o9(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;pa(b,y,w,z,A,f,g);i=d;return}f$[c[(c[p>>2]|0)+8>>2]&511](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;pa(b,y,w,z,A,f,g);i=d;return}function pd(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+312|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+280|0;p=d+288|0;q=d+296|0;r=d+304|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){if((k&1|0)==0){a[w]=97;x=0;break}else{a[w]=65;x=0;break}}else{a[w]=46;u=w+2|0;a[w+1|0]=42;if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=c[137522]|0;if(x){v=oV(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=oV(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[682976]|0)==0;if(x){do{if(v){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=o0(m,c[137522]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);v=o0(m,c[137522]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=fc(4)|0;c[v>>2]=53880;dq(v|0,60400,240)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=2629;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=2629;break}E=D+2|0}else if((z|0)==32){E=m}else{F=2629}}while(0);if((F|0)==2629){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=sR(B<<3)|0;z=F;if((F|0)!=0){G=z;H=z;J=D;break}z=fc(4)|0;c[z>>2]=53880;dq(z|0,60400,240)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;pe(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){f$[c[(c[q>>2]|0)+8>>2]&511](q|0)}q=e|0;pa(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){sS(H)}if((C|0)==0){i=d;return}sS(C);i=d;return}function pe(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[137880]|0)!=-1){c[n>>2]=551520;c[n+4>>2]=16;c[n+8>>2]=0;mU(551520,n)}n=(c[137881]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=fc(4)|0;s=r;c[s>>2]=53912;dq(r|0,60416,316)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=fc(4)|0;s=r;c[s>>2]=53912;dq(r|0,60416,316)}r=k;s=c[p>>2]|0;if((c[137784]|0)!=-1){c[m>>2]=551136;c[m+4>>2]=16;c[m+8>>2]=0;mU(551136,m)}m=(c[137785]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=fc(4)|0;u=t;c[u>>2]=53912;dq(t|0,60416,316)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=fc(4)|0;u=t;c[u>>2]=53912;dq(t|0,60416,316)}t=s;f0[c[(c[s>>2]|0)+20>>2]&255](o,t);c[j>>2]=g;u=a[b]|0;if((u<<24>>24|0)==45|(u<<24>>24|0)==43){m=gj[c[(c[k>>2]|0)+44>>2]&127](r,u)|0;u=c[j>>2]|0;c[j>>2]=u+4;c[u>>2]=m;v=b+1|0}else{v=b}m=f;L3128:do{if((m-v|0)>1){if((a[v]|0)!=48){w=v;x=2689;break}u=v+1|0;p=a[u]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){w=v;x=2689;break}p=k;n=gj[c[(c[p>>2]|0)+44>>2]&127](r,48)|0;q=c[j>>2]|0;c[j>>2]=q+4;c[q>>2]=n;n=v+2|0;q=gj[c[(c[p>>2]|0)+44>>2]&127](r,a[u]|0)|0;u=c[j>>2]|0;c[j>>2]=u+4;c[u>>2]=q;q=n;while(1){if(q>>>0>=f>>>0){y=q;z=n;break L3128}u=a[q]|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);if((a8(u<<24>>24|0,c[137522]|0)|0)==0){y=q;z=n;break}else{q=q+1|0}}}else{w=v;x=2689}}while(0);L3143:do{if((x|0)==2689){while(1){x=0;if(w>>>0>=f>>>0){y=w;z=v;break L3143}q=a[w]|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);if((eU(q<<24>>24|0,c[137522]|0)|0)==0){y=w;z=v;break}else{w=w+1|0;x=2689}}}}while(0);x=o;w=o;v=d[w]|0;if((v&1|0)==0){A=v>>>1}else{A=c[o+4>>2]|0}do{if((A|0)==0){v=c[j>>2]|0;u=c[(c[k>>2]|0)+48>>2]|0;gn[u&31](r,z,y,v)|0;c[j>>2]=(c[j>>2]|0)+(y-z<<2)}else{do{if((z|0)!=(y|0)){v=y-1|0;if(z>>>0<v>>>0){B=z;C=v}else{break}do{v=a[B]|0;a[B]=a[C]|0;a[C]=v;B=B+1|0;C=C-1|0;}while(B>>>0<C>>>0)}}while(0);q=f2[c[(c[s>>2]|0)+16>>2]&255](t)|0;if(z>>>0<y>>>0){v=x+1|0;u=o+4|0;n=o+8|0;p=k;D=0;E=0;F=z;while(1){G=a[((a[w]&1)==0?v:c[n>>2]|0)+E|0]|0;if(G<<24>>24>0&(D|0)==(G<<24>>24|0)){G=c[j>>2]|0;c[j>>2]=G+4;c[G>>2]=q;G=d[w]|0;H=(E>>>0<(((G&1|0)==0?G>>>1:c[u>>2]|0)-1|0)>>>0)+E|0;I=0}else{H=E;I=D}G=gj[c[(c[p>>2]|0)+44>>2]&127](r,a[F]|0)|0;J=c[j>>2]|0;c[j>>2]=J+4;c[J>>2]=G;G=F+1|0;if(G>>>0<y>>>0){D=I+1|0;E=H;F=G}else{break}}}F=g+(z-b<<2)|0;E=c[j>>2]|0;if((F|0)==(E|0)){break}D=E-4|0;if(F>>>0<D>>>0){K=F;L=D}else{break}do{D=c[K>>2]|0;c[K>>2]=c[L>>2];c[L>>2]=D;K=K+4|0;L=L-4|0;}while(K>>>0<L>>>0)}}while(0);L3181:do{if(y>>>0<f>>>0){L=k;K=y;while(1){z=a[K]|0;if(z<<24>>24==46){break}H=gj[c[(c[L>>2]|0)+44>>2]&127](r,z)|0;z=c[j>>2]|0;c[j>>2]=z+4;c[z>>2]=H;H=K+1|0;if(H>>>0<f>>>0){K=H}else{M=H;break L3181}}L=f2[c[(c[s>>2]|0)+12>>2]&255](t)|0;H=c[j>>2]|0;c[j>>2]=H+4;c[H>>2]=L;M=K+1|0}else{M=y}}while(0);gn[c[(c[k>>2]|0)+48>>2]&31](r,M,f,c[j>>2]|0)|0;r=(c[j>>2]|0)+(m-M<<2)|0;c[j>>2]=r;if((e|0)==(f|0)){N=r}else{N=g+(e-b<<2)|0}c[h>>2]=N;if((a[w]&1)==0){i=l;return}w=c[o+8>>2]|0;if((w|0)==0){i=l;return}sS(w);i=l;return}function pf(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+312|0;k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+280|0;p=d+288|0;q=d+296|0;r=d+304|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){a[w]=76;u=w+1|0;if((k&1|0)==0){a[u]=97;x=0;break}else{a[u]=65;x=0;break}}else{a[w]=46;a[w+1|0]=42;a[w+2|0]=76;u=w+3|0;if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=c[137522]|0;if(x){v=oV(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=oV(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[682976]|0)==0;if(x){do{if(v){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);l=o0(m,c[137522]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);v=o0(m,c[137522]|0,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=fc(4)|0;c[v>>2]=53880;dq(v|0,60400,240)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=2789;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=2789;break}E=D+2|0}else if((z|0)==32){E=m}else{F=2789}}while(0);if((F|0)==2789){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=sR(B<<3)|0;z=F;if((F|0)!=0){G=z;H=z;J=D;break}z=fc(4)|0;c[z>>2]=53880;dq(z|0,60400,240)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;pe(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){f$[c[(c[q>>2]|0)+8>>2]&511](q|0)}q=e|0;pa(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){sS(H)}if((C|0)==0){i=d;return}sS(C);i=d;return}function pg(a){a=a|0;return}function ph(a){a=a|0;return 2}function pi(a){a=a|0;if((a|0)==0){return}sS(a);return}function pj(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];pm(a,b,c[d>>2]|0,c[e>>2]|0,f,g,h,53336,53344);i=j;return}function pk(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d+8|0;m=f2[c[(c[l>>2]|0)+20>>2]&255](l)|0;l=a[m]|0;if((l&1)==0){n=m+1|0}else{n=c[m+8>>2]|0}o=l&255;if((o&1|0)==0){p=o>>>1}else{p=c[m+4>>2]|0}pm(b,d,c[e>>2]|0,c[f>>2]|0,g,h,j,n,n+p|0);i=k;return}function pl(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+200|0;j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=d|0;k=d+24|0;l=d+48|0;m=d+16|0;a[m]=a[53352]|0;a[m+1|0]=a[53353|0]|0;a[m+2|0]=a[53354|0]|0;a[m+3|0]=a[53355|0]|0;a[m+4|0]=a[53356|0]|0;a[m+5|0]=a[53357|0]|0;n=k|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);o=oV(n,20,c[137522]|0,m,(m=i,i=i+8|0,c[m>>2]=h,m)|0)|0;i=m;m=k+o|0;h=c[f+4>>2]&176;do{if((h|0)==32){p=m}else if((h|0)==16){q=a[n]|0;if((q<<24>>24|0)==45|(q<<24>>24|0)==43){p=k+1|0;break}if(!((o|0)>1&q<<24>>24==48)){r=2839;break}q=a[k+1|0]|0;if(!((q<<24>>24|0)==120|(q<<24>>24|0)==88)){r=2839;break}p=k+2|0}else{r=2839}}while(0);if((r|0)==2839){p=n}r=c[f+28>>2]|0;h=r+4|0;I=c[h>>2]|0,c[h>>2]=I+1,I;if((c[137880]|0)!=-1){c[j>>2]=551520;c[j+4>>2]=16;c[j+8>>2]=0;mU(551520,j)}j=(c[137881]|0)-1|0;q=c[r+8>>2]|0;do{if((c[r+12>>2]|0)-q>>2>>>0>j>>>0){s=c[q+(j<<2)>>2]|0;if((s|0)==0){break}t=s;if(((I=c[h>>2]|0,c[h>>2]=I+ -1,I)|0)==0){f$[c[(c[r>>2]|0)+8>>2]&511](r)}u=l|0;v=c[(c[s>>2]|0)+48>>2]|0;gn[v&31](t,n,m,u)|0;t=l+(o<<2)|0;if((p|0)==(m|0)){w=t;x=e|0;y=c[x>>2]|0;pa(b,y,u,w,t,f,g);i=d;return}w=l+(p-k<<2)|0;x=e|0;y=c[x>>2]|0;pa(b,y,u,w,t,f,g);i=d;return}}while(0);d=fc(4)|0;c[d>>2]=53912;dq(d|0,60416,316)}function pm(d,e,f,g,h,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;n=i;i=i+40|0;o=n|0;p=n+16|0;q=n+24|0;r=n+32|0;s=c[h+28>>2]|0;t=s+4|0;I=c[t>>2]|0,c[t>>2]=I+1,I;if((c[137882]|0)!=-1){c[o>>2]=551528;c[o+4>>2]=16;c[o+8>>2]=0;mU(551528,o)}o=(c[137883]|0)-1|0;u=c[s+8>>2]|0;do{if((c[s+12>>2]|0)-u>>2>>>0>o>>>0){v=c[u+(o<<2)>>2]|0;if((v|0)==0){break}w=v;if(((I=c[t>>2]|0,c[t>>2]=I+ -1,I)|0)==0){f$[c[(c[s>>2]|0)+8>>2]&511](s)}c[j>>2]=0;L3342:do{if((l|0)==(m|0)){x=f;y=f;z=g}else{A=v;B=v+8|0;C=v;D=e;E=q|0;F=r|0;G=p|0;H=l;J=f;K=g;L3344:while(1){do{if((J|0)==0){L=0}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){L=J;break}L=(f2[c[(c[J>>2]|0)+36>>2]&255](J)|0)==-1?0:J}}while(0);M=(L|0)==0;do{if((K|0)==0){N=2873}else{if((c[K+12>>2]|0)==(c[K+16>>2]|0)){if((f2[c[(c[K>>2]|0)+36>>2]&255](K)|0)==-1){N=2873;break}}if(M){O=K}else{P=L;Q=K;N=2874;break L3344}}}while(0);if((N|0)==2873){N=0;if(M){P=0;Q=0;N=2874;break}else{O=0}}L3358:do{if((f7[c[(c[A>>2]|0)+36>>2]&127](w,a[H]|0,0)|0)<<24>>24==37){R=H+1|0;if((R|0)==(m|0)){N=2880;break L3344}S=f7[c[(c[A>>2]|0)+36>>2]&127](w,a[R]|0,0)|0;if((S<<24>>24|0)==69|(S<<24>>24|0)==48){T=H+2|0;if((T|0)==(m|0)){N=2883;break L3344}U=S;V=f7[c[(c[A>>2]|0)+36>>2]&127](w,a[T]|0,0)|0;W=T}else{U=0;V=S;W=R}R=c[(c[D>>2]|0)+36>>2]|0;c[E>>2]=L;c[F>>2]=O;gh[R&15](p,e,q,r,h,j,k,V,U);X=W+1|0;Y=c[G>>2]|0;Z=O}else{R=a[H]|0;do{if(R<<24>>24>-1){S=c[B>>2]|0;if((b[S+(R<<24>>24<<1)>>1]&8192)==0){break}else{_=H}while(1){T=_+1|0;if((T|0)==(m|0)){$=m;break}aa=a[T]|0;if(aa<<24>>24<=-1){$=T;break}if((b[S+(aa<<24>>24<<1)>>1]&8192)==0){$=T;break}else{_=T}}S=L;T=O;aa=L;ab=O;while(1){do{if((S|0)==0){ac=0;ad=aa}else{if((c[S+12>>2]|0)!=(c[S+16>>2]|0)){ac=S;ad=aa;break}ae=(f2[c[(c[S>>2]|0)+36>>2]&255](S)|0)==-1;ac=ae?0:S;ad=ae?0:aa}}while(0);ae=(ac|0)==0;do{if((T|0)==0){af=ab;N=2901}else{if((c[T+12>>2]|0)!=(c[T+16>>2]|0)){if(ae){ag=T;ah=ab;break}else{X=$;Y=ad;Z=ab;break L3358}}if((f2[c[(c[T>>2]|0)+36>>2]&255](T)|0)==-1){af=0;N=2901;break}if(ae){ag=T;ah=ab}else{X=$;Y=ad;Z=ab;break L3358}}}while(0);if((N|0)==2901){N=0;if(ae){X=$;Y=ad;Z=af;break L3358}else{ag=0;ah=af}}ai=ac+12|0;aj=c[ai>>2]|0;ak=ac+16|0;if((aj|0)==(c[ak>>2]|0)){al=(f2[c[(c[ac>>2]|0)+36>>2]&255](ac)|0)&255}else{al=a[aj]|0}if(al<<24>>24<=-1){X=$;Y=ad;Z=ah;break L3358}if((b[(c[B>>2]|0)+(al<<24>>24<<1)>>1]&8192)==0){X=$;Y=ad;Z=ah;break L3358}aj=c[ai>>2]|0;if((aj|0)==(c[ak>>2]|0)){ak=c[(c[ac>>2]|0)+40>>2]|0;f2[ak&255](ac)|0;S=ac;T=ag;aa=ad;ab=ah;continue}else{c[ai>>2]=aj+1;S=ac;T=ag;aa=ad;ab=ah;continue}}}}while(0);R=L+12|0;ab=c[R>>2]|0;aa=L+16|0;if((ab|0)==(c[aa>>2]|0)){am=(f2[c[(c[L>>2]|0)+36>>2]&255](L)|0)&255}else{am=a[ab]|0}ab=gj[c[(c[C>>2]|0)+12>>2]&127](w,am)|0;if(ab<<24>>24!=(gj[c[(c[C>>2]|0)+12>>2]&127](w,a[H]|0)|0)<<24>>24){N=2919;break L3344}ab=c[R>>2]|0;if((ab|0)==(c[aa>>2]|0)){aa=c[(c[L>>2]|0)+40>>2]|0;f2[aa&255](L)|0}else{c[R>>2]=ab+1}X=H+1|0;Y=L;Z=O}}while(0);if((X|0)==(m|0)){x=Y;y=Y;z=Z;break L3342}if((c[j>>2]|0)==0){H=X;J=Y;K=Z}else{x=Y;y=Y;z=Z;break L3342}}if((N|0)==2874){c[j>>2]=4;x=P;y=L;z=Q;break}else if((N|0)==2883){c[j>>2]=4;x=L;y=L;z=O;break}else if((N|0)==2880){c[j>>2]=4;x=L;y=L;z=O;break}else if((N|0)==2919){c[j>>2]=4;x=L;y=L;z=O;break}}}while(0);do{if((x|0)==0){an=y}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){an=y;break}an=(f2[c[(c[x>>2]|0)+36>>2]&255](x)|0)==-1?0:y}}while(0);w=(an|0)==0;do{if((z|0)==0){N=2927}else{if((c[z+12>>2]|0)==(c[z+16>>2]|0)){if((f2[c[(c[z>>2]|0)+36>>2]&255](z)|0)==-1){N=2927;break}}if(!w){break}ao=d|0;c[ao>>2]=an;i=n;return}}while(0);do{if((N|0)==2927){if(w){break}ao=d|0;c[ao>>2]=an;i=n;return}}while(0);c[j>>2]=c[j>>2]|2;ao=d|0;c[ao>>2]=an;i=n;return}}while(0);n=fc(4)|0;c[n>>2]=53912;dq(n|0,60416,316)}function pn(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[137882]|0)!=-1){c[k>>2]=551528;c[k+4>>2]=16;c[k+8>>2]=0;mU(551528,k)}k=(c[137883]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f$[c[(c[l>>2]|0)+8>>2]&511](l)}o=c[e>>2]|0;p=b+8|0;q=f2[c[c[p>>2]>>2]&255](p)|0;p=(n9(d,o,q,q+168|0,n,g,0)|0)-q|0;if((p|0)>=168){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+24>>2]=((p|0)/12|0|0)%7|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=fc(4)|0;c[j>>2]=53912;dq(j|0,60416,316)}function po(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[137882]|0)!=-1){c[k>>2]=551528;c[k+4>>2]=16;c[k+8>>2]=0;mU(551528,k)}k=(c[137883]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f$[c[(c[l>>2]|0)+8>>2]&511](l)}o=c[e>>2]|0;p=b+8|0;q=f2[c[(c[p>>2]|0)+4>>2]&255](p)|0;p=(n9(d,o,q,q+288|0,n,g,0)|0)-q|0;if((p|0)>=288){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+16>>2]=((p|0)/12|0|0)%12|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=fc(4)|0;c[j>>2]=53912;dq(j|0,60416,316)}function pp(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+16|0;j=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[j>>2];j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=b|0;k=c[f+28>>2]|0;f=k+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[137882]|0)!=-1){c[j>>2]=551528;c[j+4>>2]=16;c[j+8>>2]=0;mU(551528,j)}j=(c[137883]|0)-1|0;l=c[k+8>>2]|0;do{if((c[k+12>>2]|0)-l>>2>>>0>j>>>0){m=c[l+(j<<2)>>2]|0;if((m|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f$[c[(c[k>>2]|0)+8>>2]&511](k)}n=pt(d,c[e>>2]|0,g,m,4)|0;if((c[g>>2]&4|0)!=0){o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}if((n|0)<69){r=n+2e3|0}else{r=(n-69|0)>>>0<31?n+1900|0:n}c[h+20>>2]=r-1900;o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}}while(0);b=fc(4)|0;c[b>>2]=53912;dq(b|0,60416,316)}function pq(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;n=i;i=i+88|0;o=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[o>>2];o=h;h=i;i=i+4|0;i=i+7>>3<<3;c[h>>2]=c[o>>2];o=n|0;p=n+16|0;q=n+24|0;r=n+32|0;s=n+40|0;t=n+48|0;u=n+56|0;v=n+64|0;w=n+72|0;x=n+80|0;c[k>>2]=0;y=c[j+28>>2]|0;z=y+4|0;I=c[z>>2]|0,c[z>>2]=I+1,I;if((c[137882]|0)!=-1){c[o>>2]=551528;c[o+4>>2]=16;c[o+8>>2]=0;mU(551528,o)}o=(c[137883]|0)-1|0;A=c[y+8>>2]|0;do{if((c[y+12>>2]|0)-A>>2>>>0>o>>>0){B=c[A+(o<<2)>>2]|0;if((B|0)==0){break}C=B;if(((I=c[z>>2]|0,c[z>>2]=I+ -1,I)|0)==0){f$[c[(c[y>>2]|0)+8>>2]&511](y)}L3494:do{switch(m<<24>>24|0){case 106:{D=pt(g,c[h>>2]|0,k,C,3)|0;E=c[k>>2]|0;if((E&4|0)==0&(D|0)<366){c[l+28>>2]=D;break L3494}else{c[k>>2]=E|4;break L3494}break};case 68:{E=g|0;pm(q,f,c[E>>2]|0,c[h>>2]|0,j,k,l,53328,53336);c[E>>2]=c[q>>2];break};case 77:{E=pt(g,c[h>>2]|0,k,C,2)|0;D=c[k>>2]|0;if((D&4|0)==0&(E|0)<60){c[l+4>>2]=E;break L3494}else{c[k>>2]=D|4;break L3494}break};case 110:case 116:{D=g|0;E=B+8|0;F=c[h>>2]|0;L3505:while(1){G=c[D>>2]|0;do{if((G|0)==0){H=0}else{if((c[G+12>>2]|0)!=(c[G+16>>2]|0)){H=G;break}if((f2[c[(c[G>>2]|0)+36>>2]&255](G)|0)==-1){c[D>>2]=0;H=0;break}else{H=c[D>>2]|0;break}}}while(0);G=(H|0)==0;do{if((F|0)==0){J=3039}else{if((c[F+12>>2]|0)==(c[F+16>>2]|0)){if((f2[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){J=3039;break}}if(G){K=0;L=F}else{M=F;N=0;break L3505}}}while(0);if((J|0)==3039){J=0;if(G){M=0;N=1;break}else{K=1;L=0}}O=c[D>>2]|0;P=c[O+12>>2]|0;if((P|0)==(c[O+16>>2]|0)){Q=(f2[c[(c[O>>2]|0)+36>>2]&255](O)|0)&255}else{Q=a[P]|0}if(Q<<24>>24<=-1){M=L;N=K;break}if((b[(c[E>>2]|0)+(Q<<24>>24<<1)>>1]&8192)==0){M=L;N=K;break}P=c[D>>2]|0;O=P+12|0;R=c[O>>2]|0;if((R|0)==(c[P+16>>2]|0)){S=c[(c[P>>2]|0)+40>>2]|0;f2[S&255](P)|0;F=L;continue}else{c[O>>2]=R+1;F=L;continue}}F=c[D>>2]|0;do{if((F|0)==0){T=0}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){T=F;break}if((f2[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){c[D>>2]=0;T=0;break}else{T=c[D>>2]|0;break}}}while(0);D=(T|0)==0;do{if(N){J=3057}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){if(D^(M|0)==0){break L3494}else{break}}if((f2[c[(c[M>>2]|0)+36>>2]&255](M)|0)==-1){J=3057;break}if(D){break L3494}}}while(0);if((J|0)==3057){if(!D){break L3494}}c[k>>2]=c[k>>2]|2;break};case 97:case 65:{F=c[h>>2]|0;E=f+8|0;R=f2[c[c[E>>2]>>2]&255](E)|0;E=(n9(g,F,R,R+168|0,C,k,0)|0)-R|0;if((E|0)>=168){break L3494}c[l+24>>2]=((E|0)/12|0|0)%7|0;break};case 70:{E=g|0;pm(r,f,c[E>>2]|0,c[h>>2]|0,j,k,l,53320,53328);c[E>>2]=c[r>>2];break};case 99:{E=f+8|0;R=f2[c[(c[E>>2]|0)+12>>2]&255](E)|0;E=g|0;F=a[R]|0;if((F&1)==0){U=R+1|0}else{U=c[R+8>>2]|0}O=F&255;if((O&1|0)==0){V=O>>>1}else{V=c[R+4>>2]|0}pm(p,f,c[E>>2]|0,c[h>>2]|0,j,k,l,U,U+V|0);c[E>>2]=c[p>>2];break};case 98:case 66:case 104:{E=c[h>>2]|0;R=f+8|0;O=f2[c[(c[R>>2]|0)+4>>2]&255](R)|0;R=(n9(g,E,O,O+288|0,C,k,0)|0)-O|0;if((R|0)>=288){break L3494}c[l+16>>2]=((R|0)/12|0|0)%12|0;break};case 109:{R=(pt(g,c[h>>2]|0,k,C,2)|0)-1|0;O=c[k>>2]|0;if((O&4|0)==0&(R|0)<12){c[l+16>>2]=R;break L3494}else{c[k>>2]=O|4;break L3494}break};case 73:{O=l+8|0;R=pt(g,c[h>>2]|0,k,C,2)|0;E=c[k>>2]|0;do{if((E&4|0)==0){if((R-1|0)>>>0>=12){break}c[O>>2]=R;break L3494}}while(0);c[k>>2]=E|4;break};case 100:case 101:{R=l+12|0;O=pt(g,c[h>>2]|0,k,C,2)|0;D=c[k>>2]|0;do{if((D&4|0)==0){if((O-1|0)>>>0>=31){break}c[R>>2]=O;break L3494}}while(0);c[k>>2]=D|4;break};case 72:{O=pt(g,c[h>>2]|0,k,C,2)|0;R=c[k>>2]|0;if((R&4|0)==0&(O|0)<24){c[l+8>>2]=O;break L3494}else{c[k>>2]=R|4;break L3494}break};case 112:{R=l+8|0;O=c[h>>2]|0;E=f+8|0;F=f2[c[(c[E>>2]|0)+8>>2]&255](E)|0;E=d[F]|0;if((E&1|0)==0){W=E>>>1}else{W=c[F+4>>2]|0}E=d[F+12|0]|0;if((E&1|0)==0){X=E>>>1}else{X=c[F+16>>2]|0}if((W|0)==(-X|0)){c[k>>2]=c[k>>2]|4;break L3494}E=n9(g,O,F,F+24|0,C,k,0)|0;O=E-F|0;do{if((E|0)==(F|0)){if((c[R>>2]|0)!=12){break}c[R>>2]=0;break L3494}}while(0);if((O|0)!=12){break L3494}F=c[R>>2]|0;if((F|0)>=12){break L3494}c[R>>2]=F+12;break};case 114:{F=g|0;pm(s,f,c[F>>2]|0,c[h>>2]|0,j,k,l,53304,53315);c[F>>2]=c[s>>2];break};case 82:{F=g|0;pm(t,f,c[F>>2]|0,c[h>>2]|0,j,k,l,53296,53301);c[F>>2]=c[t>>2];break};case 83:{F=pt(g,c[h>>2]|0,k,C,2)|0;E=c[k>>2]|0;if((E&4|0)==0&(F|0)<61){c[l>>2]=F;break L3494}else{c[k>>2]=E|4;break L3494}break};case 84:{E=g|0;pm(u,f,c[E>>2]|0,c[h>>2]|0,j,k,l,53288,53296);c[E>>2]=c[u>>2];break};case 119:{E=pt(g,c[h>>2]|0,k,C,1)|0;F=c[k>>2]|0;if((F&4|0)==0&(E|0)<7){c[l+24>>2]=E;break L3494}else{c[k>>2]=F|4;break L3494}break};case 120:{F=c[(c[f>>2]|0)+20>>2]|0;c[v>>2]=c[g>>2];c[w>>2]=c[h>>2];gf[F&127](e,f,v,w,j,k,l);i=n;return};case 88:{F=f+8|0;E=f2[c[(c[F>>2]|0)+24>>2]&255](F)|0;F=g|0;D=a[E]|0;if((D&1)==0){Y=E+1|0}else{Y=c[E+8>>2]|0}P=D&255;if((P&1|0)==0){Z=P>>>1}else{Z=c[E+4>>2]|0}pm(x,f,c[F>>2]|0,c[h>>2]|0,j,k,l,Y,Y+Z|0);c[F>>2]=c[x>>2];break};case 121:{F=pt(g,c[h>>2]|0,k,C,4)|0;if((c[k>>2]&4|0)!=0){break L3494}if((F|0)<69){_=F+2e3|0}else{_=(F-69|0)>>>0<31?F+1900|0:F}c[l+20>>2]=_-1900;break};case 89:{F=pt(g,c[h>>2]|0,k,C,4)|0;if((c[k>>2]&4|0)!=0){break L3494}c[l+20>>2]=F-1900;break};case 37:{F=c[h>>2]|0;E=g|0;P=c[E>>2]|0;do{if((P|0)==0){$=0}else{if((c[P+12>>2]|0)!=(c[P+16>>2]|0)){$=P;break}if((f2[c[(c[P>>2]|0)+36>>2]&255](P)|0)==-1){c[E>>2]=0;$=0;break}else{$=c[E>>2]|0;break}}}while(0);P=($|0)==0;do{if((F|0)==0){J=3107}else{if((c[F+12>>2]|0)==(c[F+16>>2]|0)){if((f2[c[(c[F>>2]|0)+36>>2]&255](F)|0)==-1){J=3107;break}}if(P){aa=F;ab=0}else{J=3108}}}while(0);if((J|0)==3107){if(P){J=3108}else{aa=0;ab=1}}if((J|0)==3108){c[k>>2]=c[k>>2]|6;break L3494}F=c[E>>2]|0;R=c[F+12>>2]|0;if((R|0)==(c[F+16>>2]|0)){ac=(f2[c[(c[F>>2]|0)+36>>2]&255](F)|0)&255}else{ac=a[R]|0}if((f7[c[(c[B>>2]|0)+36>>2]&127](C,ac,0)|0)<<24>>24!=37){c[k>>2]=c[k>>2]|4;break L3494}R=c[E>>2]|0;F=R+12|0;O=c[F>>2]|0;if((O|0)==(c[R+16>>2]|0)){D=c[(c[R>>2]|0)+40>>2]|0;f2[D&255](R)|0}else{c[F>>2]=O+1}O=c[E>>2]|0;do{if((O|0)==0){ad=0}else{if((c[O+12>>2]|0)!=(c[O+16>>2]|0)){ad=O;break}if((f2[c[(c[O>>2]|0)+36>>2]&255](O)|0)==-1){c[E>>2]=0;ad=0;break}else{ad=c[E>>2]|0;break}}}while(0);E=(ad|0)==0;do{if(ab){J=3126}else{if((c[aa+12>>2]|0)!=(c[aa+16>>2]|0)){if(E^(aa|0)==0){break L3494}else{break}}if((f2[c[(c[aa>>2]|0)+36>>2]&255](aa)|0)==-1){J=3126;break}if(E){break L3494}}}while(0);if((J|0)==3126){if(!E){break L3494}}c[k>>2]=c[k>>2]|2;break};default:{c[k>>2]=c[k>>2]|4}}}while(0);c[e>>2]=c[g>>2];i=n;return}}while(0);n=fc(4)|0;c[n>>2]=53912;dq(n|0,60416,316)}function pr(a){a=a|0;return}function ps(a){a=a|0;return 2}function pt(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=d|0;d=c[i>>2]|0;do{if((d|0)==0){j=0}else{if((c[d+12>>2]|0)!=(c[d+16>>2]|0)){j=d;break}if((f2[c[(c[d>>2]|0)+36>>2]&255](d)|0)==-1){c[i>>2]=0;j=0;break}else{j=c[i>>2]|0;break}}}while(0);d=(j|0)==0;do{if((e|0)==0){k=3145}else{if((c[e+12>>2]|0)==(c[e+16>>2]|0)){if((f2[c[(c[e>>2]|0)+36>>2]&255](e)|0)==-1){k=3145;break}}if(d){l=e}else{k=3146}}}while(0);if((k|0)==3145){if(d){k=3146}else{l=0}}if((k|0)==3146){c[f>>2]=c[f>>2]|6;m=0;return m|0}d=c[i>>2]|0;e=c[d+12>>2]|0;if((e|0)==(c[d+16>>2]|0)){n=(f2[c[(c[d>>2]|0)+36>>2]&255](d)|0)&255}else{n=a[e]|0}do{if(n<<24>>24>-1){e=g+8|0;if((b[(c[e>>2]|0)+(n<<24>>24<<1)>>1]&2048)==0){break}d=g;j=(f7[c[(c[d>>2]|0)+36>>2]&127](g,n,0)|0)<<24>>24;o=c[i>>2]|0;p=o+12|0;q=c[p>>2]|0;if((q|0)==(c[o+16>>2]|0)){r=c[(c[o>>2]|0)+40>>2]|0;f2[r&255](o)|0;s=j;t=h;u=l}else{c[p>>2]=q+1;s=j;t=h;u=l}while(1){v=s-48|0;j=t-1|0;q=c[i>>2]|0;do{if((q|0)==0){w=0}else{if((c[q+12>>2]|0)!=(c[q+16>>2]|0)){w=q;break}if((f2[c[(c[q>>2]|0)+36>>2]&255](q)|0)==-1){c[i>>2]=0;w=0;break}else{w=c[i>>2]|0;break}}}while(0);q=(w|0)==0;if((u|0)==0){x=w;y=0}else{if((c[u+12>>2]|0)==(c[u+16>>2]|0)){z=(f2[c[(c[u>>2]|0)+36>>2]&255](u)|0)==-1?0:u}else{z=u}x=c[i>>2]|0;y=z}A=(y|0)==0;if(!((q^A)&(j|0)>0)){k=3174;break}q=c[x+12>>2]|0;if((q|0)==(c[x+16>>2]|0)){B=(f2[c[(c[x>>2]|0)+36>>2]&255](x)|0)&255}else{B=a[q]|0}if(B<<24>>24<=-1){m=v;k=3186;break}if((b[(c[e>>2]|0)+(B<<24>>24<<1)>>1]&2048)==0){m=v;k=3188;break}q=((f7[c[(c[d>>2]|0)+36>>2]&127](g,B,0)|0)<<24>>24)+(v*10|0)|0;p=c[i>>2]|0;o=p+12|0;r=c[o>>2]|0;if((r|0)==(c[p+16>>2]|0)){C=c[(c[p>>2]|0)+40>>2]|0;f2[C&255](p)|0;s=q;t=j;u=y;continue}else{c[o>>2]=r+1;s=q;t=j;u=y;continue}}if((k|0)==3174){do{if((x|0)==0){D=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){D=x;break}if((f2[c[(c[x>>2]|0)+36>>2]&255](x)|0)==-1){c[i>>2]=0;D=0;break}else{D=c[i>>2]|0;break}}}while(0);d=(D|0)==0;do{if(A){k=3183}else{if((c[y+12>>2]|0)==(c[y+16>>2]|0)){if((f2[c[(c[y>>2]|0)+36>>2]&255](y)|0)==-1){k=3183;break}}if(d){m=v}else{break}return m|0}}while(0);do{if((k|0)==3183){if(d){break}else{m=v}return m|0}}while(0);c[f>>2]=c[f>>2]|2;m=v;return m|0}else if((k|0)==3186){return m|0}else if((k|0)==3188){return m|0}}}while(0);c[f>>2]=c[f>>2]|4;m=0;return m|0}function pu(a){a=a|0;if((a|0)==0){return}sS(a);return}function pv(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];px(a,b,c[d>>2]|0,c[e>>2]|0,f,g,h,53256,53288);i=j;return}function pw(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d+8|0;m=f2[c[(c[l>>2]|0)+20>>2]&255](l)|0;l=a[m]|0;if((l&1)==0){n=m+4|0}else{n=c[m+8>>2]|0}o=l&255;if((o&1|0)==0){p=o>>>1}else{p=c[m+4>>2]|0}px(b,d,c[e>>2]|0,c[f>>2]|0,g,h,j,n,n+(p<<2)|0);i=k;return}function px(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;l=i;i=i+40|0;m=l|0;n=l+16|0;o=l+24|0;p=l+32|0;q=c[f+28>>2]|0;r=q+4|0;I=c[r>>2]|0,c[r>>2]=I+1,I;if((c[137880]|0)!=-1){c[m>>2]=551520;c[m+4>>2]=16;c[m+8>>2]=0;mU(551520,m)}m=(c[137881]|0)-1|0;s=c[q+8>>2]|0;do{if((c[q+12>>2]|0)-s>>2>>>0>m>>>0){t=c[s+(m<<2)>>2]|0;if((t|0)==0){break}u=t;if(((I=c[r>>2]|0,c[r>>2]=I+ -1,I)|0)==0){f$[c[(c[q>>2]|0)+8>>2]&511](q)}c[g>>2]=0;L3783:do{if((j|0)==(k|0)){v=d;w=d;x=e}else{y=t;z=t;A=t;B=b;C=o|0;D=p|0;E=n|0;F=j;G=d;H=e;L3785:while(1){if((G|0)==0){J=0}else{K=c[G+12>>2]|0;if((K|0)==(c[G+16>>2]|0)){L=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{L=c[K>>2]|0}J=(L|0)==-1?0:G}K=(J|0)==0;do{if((H|0)==0){M=3226}else{N=c[H+12>>2]|0;if((N|0)==(c[H+16>>2]|0)){O=f2[c[(c[H>>2]|0)+36>>2]&255](H)|0}else{O=c[N>>2]|0}if((O|0)==-1){M=3226;break}if(K){P=H}else{Q=J;R=H;M=3228;break L3785}}}while(0);if((M|0)==3226){M=0;if(K){Q=0;R=0;M=3228;break}else{P=0}}L3804:do{if((f7[c[(c[y>>2]|0)+52>>2]&127](u,c[F>>2]|0,0)|0)<<24>>24==37){N=F+4|0;if((N|0)==(k|0)){M=3234;break L3785}S=f7[c[(c[y>>2]|0)+52>>2]&127](u,c[N>>2]|0,0)|0;if((S<<24>>24|0)==69|(S<<24>>24|0)==48){T=F+8|0;if((T|0)==(k|0)){M=3237;break L3785}U=S;V=f7[c[(c[y>>2]|0)+52>>2]&127](u,c[T>>2]|0,0)|0;W=T}else{U=0;V=S;W=N}N=c[(c[B>>2]|0)+36>>2]|0;c[C>>2]=J;c[D>>2]=P;gh[N&15](n,b,o,p,f,g,h,V,U);X=W+4|0;Y=c[E>>2]|0;Z=P}else{if(f7[c[(c[z>>2]|0)+12>>2]&127](u,8192,c[F>>2]|0)|0){_=F}else{N=J+12|0;S=c[N>>2]|0;T=J+16|0;if((S|0)==(c[T>>2]|0)){$=f2[c[(c[J>>2]|0)+36>>2]&255](J)|0}else{$=c[S>>2]|0}S=gj[c[(c[A>>2]|0)+28>>2]&127](u,$)|0;if((S|0)!=(gj[c[(c[A>>2]|0)+28>>2]&127](u,c[F>>2]|0)|0)){M=3273;break L3785}S=c[N>>2]|0;if((S|0)==(c[T>>2]|0)){T=c[(c[J>>2]|0)+40>>2]|0;f2[T&255](J)|0}else{c[N>>2]=S+4}X=F+4|0;Y=J;Z=P;break}while(1){S=_+4|0;if((S|0)==(k|0)){aa=k;break}if(f7[c[(c[z>>2]|0)+12>>2]&127](u,8192,c[S>>2]|0)|0){_=S}else{aa=S;break}}S=J;N=P;T=J;ab=P;while(1){if((S|0)==0){ac=0;ad=T}else{ae=c[S+12>>2]|0;if((ae|0)==(c[S+16>>2]|0)){af=f2[c[(c[S>>2]|0)+36>>2]&255](S)|0}else{af=c[ae>>2]|0}ae=(af|0)==-1;ac=ae?0:S;ad=ae?0:T}ae=(ac|0)==0;do{if((N|0)==0){ag=ab;M=3256}else{ah=c[N+12>>2]|0;if((ah|0)==(c[N+16>>2]|0)){ai=f2[c[(c[N>>2]|0)+36>>2]&255](N)|0}else{ai=c[ah>>2]|0}if((ai|0)==-1){ag=0;M=3256;break}if(ae){aj=N;ak=ab}else{X=aa;Y=ad;Z=ab;break L3804}}}while(0);if((M|0)==3256){M=0;if(ae){X=aa;Y=ad;Z=ag;break L3804}else{aj=0;ak=ag}}ah=ac+12|0;al=c[ah>>2]|0;am=ac+16|0;if((al|0)==(c[am>>2]|0)){an=f2[c[(c[ac>>2]|0)+36>>2]&255](ac)|0}else{an=c[al>>2]|0}if(!(f7[c[(c[z>>2]|0)+12>>2]&127](u,8192,an)|0)){X=aa;Y=ad;Z=ak;break L3804}al=c[ah>>2]|0;if((al|0)==(c[am>>2]|0)){am=c[(c[ac>>2]|0)+40>>2]|0;f2[am&255](ac)|0;S=ac;N=aj;T=ad;ab=ak;continue}else{c[ah>>2]=al+4;S=ac;N=aj;T=ad;ab=ak;continue}}}}while(0);if((X|0)==(k|0)){v=Y;w=Y;x=Z;break L3783}if((c[g>>2]|0)==0){F=X;G=Y;H=Z}else{v=Y;w=Y;x=Z;break L3783}}if((M|0)==3273){c[g>>2]=4;v=J;w=J;x=P;break}else if((M|0)==3228){c[g>>2]=4;v=Q;w=J;x=R;break}else if((M|0)==3234){c[g>>2]=4;v=J;w=J;x=P;break}else if((M|0)==3237){c[g>>2]=4;v=J;w=J;x=P;break}}}while(0);if((v|0)==0){ao=w}else{u=c[v+12>>2]|0;if((u|0)==(c[v+16>>2]|0)){ap=f2[c[(c[v>>2]|0)+36>>2]&255](v)|0}else{ap=c[u>>2]|0}ao=(ap|0)==-1?0:w}u=(ao|0)==0;do{if((x|0)==0){M=3284}else{t=c[x+12>>2]|0;if((t|0)==(c[x+16>>2]|0)){aq=f2[c[(c[x>>2]|0)+36>>2]&255](x)|0}else{aq=c[t>>2]|0}if((aq|0)==-1){M=3284;break}if(!u){break}ar=a|0;c[ar>>2]=ao;i=l;return}}while(0);do{if((M|0)==3284){if(u){break}ar=a|0;c[ar>>2]=ao;i=l;return}}while(0);c[g>>2]=c[g>>2]|2;ar=a|0;c[ar>>2]=ao;i=l;return}}while(0);l=fc(4)|0;c[l>>2]=53912;dq(l|0,60416,316)}function py(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[137880]|0)!=-1){c[k>>2]=551520;c[k+4>>2]=16;c[k+8>>2]=0;mU(551520,k)}k=(c[137881]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f$[c[(c[l>>2]|0)+8>>2]&511](l)}o=c[e>>2]|0;p=b+8|0;q=f2[c[c[p>>2]>>2]&255](p)|0;p=(oC(d,o,q,q+168|0,n,g,0)|0)-q|0;if((p|0)>=168){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+24>>2]=((p|0)/12|0|0)%7|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=fc(4)|0;c[j>>2]=53912;dq(j|0,60416,316)}function pz(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[137880]|0)!=-1){c[k>>2]=551520;c[k+4>>2]=16;c[k+8>>2]=0;mU(551520,k)}k=(c[137881]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f$[c[(c[l>>2]|0)+8>>2]&511](l)}o=c[e>>2]|0;p=b+8|0;q=f2[c[(c[p>>2]|0)+4>>2]&255](p)|0;p=(oC(d,o,q,q+288|0,n,g,0)|0)-q|0;if((p|0)>=288){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+16>>2]=((p|0)/12|0|0)%12|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=fc(4)|0;c[j>>2]=53912;dq(j|0,60416,316)}function pA(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+16|0;j=d;d=i;i=i+4|0;i=i+7>>3<<3;c[d>>2]=c[j>>2];j=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[j>>2];j=b|0;k=c[f+28>>2]|0;f=k+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[137880]|0)!=-1){c[j>>2]=551520;c[j+4>>2]=16;c[j+8>>2]=0;mU(551520,j)}j=(c[137881]|0)-1|0;l=c[k+8>>2]|0;do{if((c[k+12>>2]|0)-l>>2>>>0>j>>>0){m=c[l+(j<<2)>>2]|0;if((m|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){f$[c[(c[k>>2]|0)+8>>2]&511](k)}n=p_(d,c[e>>2]|0,g,m,4)|0;if((c[g>>2]&4|0)!=0){o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}if((n|0)<69){r=n+2e3|0}else{r=(n-69|0)>>>0<31?n+1900|0:n}c[h+20>>2]=r-1900;o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}}while(0);b=fc(4)|0;c[b>>2]=53912;dq(b|0,60416,316)}function pB(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;m=i;i=i+88|0;n=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[n>>2];n=g;g=i;i=i+4|0;i=i+7>>3<<3;c[g>>2]=c[n>>2];n=m|0;o=m+16|0;p=m+24|0;q=m+32|0;r=m+40|0;s=m+48|0;t=m+56|0;u=m+64|0;v=m+72|0;w=m+80|0;c[j>>2]=0;x=c[h+28>>2]|0;y=x+4|0;I=c[y>>2]|0,c[y>>2]=I+1,I;if((c[137880]|0)!=-1){c[n>>2]=551520;c[n+4>>2]=16;c[n+8>>2]=0;mU(551520,n)}n=(c[137881]|0)-1|0;z=c[x+8>>2]|0;do{if((c[x+12>>2]|0)-z>>2>>>0>n>>>0){A=c[z+(n<<2)>>2]|0;if((A|0)==0){break}B=A;if(((I=c[y>>2]|0,c[y>>2]=I+ -1,I)|0)==0){f$[c[(c[x>>2]|0)+8>>2]&511](x)}L3946:do{switch(l<<24>>24|0){case 100:case 101:{C=k+12|0;D=p_(f,c[g>>2]|0,j,B,2)|0;E=c[j>>2]|0;do{if((E&4|0)==0){if((D-1|0)>>>0>=31){break}c[C>>2]=D;break L3946}}while(0);c[j>>2]=E|4;break};case 89:{D=p_(f,c[g>>2]|0,j,B,4)|0;if((c[j>>2]&4|0)!=0){break L3946}c[k+20>>2]=D-1900;break};case 121:{D=p_(f,c[g>>2]|0,j,B,4)|0;if((c[j>>2]&4|0)!=0){break L3946}if((D|0)<69){F=D+2e3|0}else{F=(D-69|0)>>>0<31?D+1900|0:D}c[k+20>>2]=F-1900;break};case 97:case 65:{D=c[g>>2]|0;C=e+8|0;G=f2[c[c[C>>2]>>2]&255](C)|0;C=(oC(f,D,G,G+168|0,B,j,0)|0)-G|0;if((C|0)>=168){break L3946}c[k+24>>2]=((C|0)/12|0|0)%7|0;break};case 70:{C=f|0;px(q,e,c[C>>2]|0,c[g>>2]|0,h,j,k,53088,53120);c[C>>2]=c[q>>2];break};case 99:{C=e+8|0;G=f2[c[(c[C>>2]|0)+12>>2]&255](C)|0;C=f|0;D=a[G]|0;if((D&1)==0){H=G+4|0}else{H=c[G+8>>2]|0}J=D&255;if((J&1|0)==0){K=J>>>1}else{K=c[G+4>>2]|0}px(o,e,c[C>>2]|0,c[g>>2]|0,h,j,k,H,H+(K<<2)|0);c[C>>2]=c[o>>2];break};case 72:{C=p_(f,c[g>>2]|0,j,B,2)|0;G=c[j>>2]|0;if((G&4|0)==0&(C|0)<24){c[k+8>>2]=C;break L3946}else{c[j>>2]=G|4;break L3946}break};case 98:case 66:case 104:{G=c[g>>2]|0;C=e+8|0;J=f2[c[(c[C>>2]|0)+4>>2]&255](C)|0;C=(oC(f,G,J,J+288|0,B,j,0)|0)-J|0;if((C|0)>=288){break L3946}c[k+16>>2]=((C|0)/12|0|0)%12|0;break};case 37:{C=c[g>>2]|0;J=f|0;G=c[J>>2]|0;do{if((G|0)==0){L=1}else{D=c[G+12>>2]|0;if((D|0)==(c[G+16>>2]|0)){M=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{M=c[D>>2]|0}if((M|0)==-1){c[J>>2]=0;L=1;break}else{L=(c[J>>2]|0)==0;break}}}while(0);do{if((C|0)==0){N=3474}else{G=c[C+12>>2]|0;if((G|0)==(c[C+16>>2]|0)){O=f2[c[(c[C>>2]|0)+36>>2]&255](C)|0}else{O=c[G>>2]|0}if((O|0)==-1){N=3474;break}if(L){P=C;Q=0}else{N=3476}}}while(0);if((N|0)==3474){if(L){N=3476}else{P=0;Q=1}}if((N|0)==3476){c[j>>2]=c[j>>2]|6;break L3946}C=c[J>>2]|0;G=c[C+12>>2]|0;if((G|0)==(c[C+16>>2]|0)){R=f2[c[(c[C>>2]|0)+36>>2]&255](C)|0}else{R=c[G>>2]|0}if((f7[c[(c[A>>2]|0)+52>>2]&127](B,R,0)|0)<<24>>24!=37){c[j>>2]=c[j>>2]|4;break L3946}G=c[J>>2]|0;C=G+12|0;E=c[C>>2]|0;if((E|0)==(c[G+16>>2]|0)){D=c[(c[G>>2]|0)+40>>2]|0;f2[D&255](G)|0}else{c[C>>2]=E+4}E=c[J>>2]|0;do{if((E|0)==0){S=1}else{C=c[E+12>>2]|0;if((C|0)==(c[E+16>>2]|0)){T=f2[c[(c[E>>2]|0)+36>>2]&255](E)|0}else{T=c[C>>2]|0}if((T|0)==-1){c[J>>2]=0;S=1;break}else{S=(c[J>>2]|0)==0;break}}}while(0);do{if(Q){N=3497}else{J=c[P+12>>2]|0;if((J|0)==(c[P+16>>2]|0)){U=f2[c[(c[P>>2]|0)+36>>2]&255](P)|0}else{U=c[J>>2]|0}if((U|0)==-1){N=3497;break}if(S^(P|0)==0){break L3946}}}while(0);if((N|0)==3497){if(!S){break L3946}}c[j>>2]=c[j>>2]|2;break};case 68:{J=f|0;px(p,e,c[J>>2]|0,c[g>>2]|0,h,j,k,53224,53256);c[J>>2]=c[p>>2];break};case 73:{J=k+8|0;E=p_(f,c[g>>2]|0,j,B,2)|0;C=c[j>>2]|0;do{if((C&4|0)==0){if((E-1|0)>>>0>=12){break}c[J>>2]=E;break L3946}}while(0);c[j>>2]=C|4;break};case 106:{E=p_(f,c[g>>2]|0,j,B,3)|0;J=c[j>>2]|0;if((J&4|0)==0&(E|0)<366){c[k+28>>2]=E;break L3946}else{c[j>>2]=J|4;break L3946}break};case 109:{J=(p_(f,c[g>>2]|0,j,B,2)|0)-1|0;E=c[j>>2]|0;if((E&4|0)==0&(J|0)<12){c[k+16>>2]=J;break L3946}else{c[j>>2]=E|4;break L3946}break};case 77:{E=p_(f,c[g>>2]|0,j,B,2)|0;J=c[j>>2]|0;if((J&4|0)==0&(E|0)<60){c[k+4>>2]=E;break L3946}else{c[j>>2]=J|4;break L3946}break};case 110:case 116:{J=f|0;E=A;G=c[g>>2]|0;L4051:while(1){D=c[J>>2]|0;do{if((D|0)==0){V=1}else{W=c[D+12>>2]|0;if((W|0)==(c[D+16>>2]|0)){X=f2[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{X=c[W>>2]|0}if((X|0)==-1){c[J>>2]=0;V=1;break}else{V=(c[J>>2]|0)==0;break}}}while(0);do{if((G|0)==0){N=3400}else{D=c[G+12>>2]|0;if((D|0)==(c[G+16>>2]|0)){Y=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{Y=c[D>>2]|0}if((Y|0)==-1){N=3400;break}if(V){Z=0;_=G}else{$=G;aa=0;break L4051}}}while(0);if((N|0)==3400){N=0;if(V){$=0;aa=1;break}else{Z=1;_=0}}D=c[J>>2]|0;W=c[D+12>>2]|0;if((W|0)==(c[D+16>>2]|0)){ab=f2[c[(c[D>>2]|0)+36>>2]&255](D)|0}else{ab=c[W>>2]|0}if(!(f7[c[(c[E>>2]|0)+12>>2]&127](B,8192,ab)|0)){$=_;aa=Z;break}W=c[J>>2]|0;D=W+12|0;ac=c[D>>2]|0;if((ac|0)==(c[W+16>>2]|0)){ad=c[(c[W>>2]|0)+40>>2]|0;f2[ad&255](W)|0;G=_;continue}else{c[D>>2]=ac+4;G=_;continue}}G=c[J>>2]|0;do{if((G|0)==0){ae=1}else{E=c[G+12>>2]|0;if((E|0)==(c[G+16>>2]|0)){af=f2[c[(c[G>>2]|0)+36>>2]&255](G)|0}else{af=c[E>>2]|0}if((af|0)==-1){c[J>>2]=0;ae=1;break}else{ae=(c[J>>2]|0)==0;break}}}while(0);do{if(aa){N=3421}else{J=c[$+12>>2]|0;if((J|0)==(c[$+16>>2]|0)){ag=f2[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{ag=c[J>>2]|0}if((ag|0)==-1){N=3421;break}if(ae^($|0)==0){break L3946}}}while(0);if((N|0)==3421){if(!ae){break L3946}}c[j>>2]=c[j>>2]|2;break};case 112:{J=k+8|0;G=c[g>>2]|0;E=e+8|0;C=f2[c[(c[E>>2]|0)+8>>2]&255](E)|0;E=d[C]|0;if((E&1|0)==0){ah=E>>>1}else{ah=c[C+4>>2]|0}E=d[C+12|0]|0;if((E&1|0)==0){ai=E>>>1}else{ai=c[C+16>>2]|0}if((ah|0)==(-ai|0)){c[j>>2]=c[j>>2]|4;break L3946}E=oC(f,G,C,C+24|0,B,j,0)|0;G=E-C|0;do{if((E|0)==(C|0)){if((c[J>>2]|0)!=12){break}c[J>>2]=0;break L3946}}while(0);if((G|0)!=12){break L3946}C=c[J>>2]|0;if((C|0)>=12){break L3946}c[J>>2]=C+12;break};case 114:{C=f|0;px(r,e,c[C>>2]|0,c[g>>2]|0,h,j,k,53176,53220);c[C>>2]=c[r>>2];break};case 82:{C=f|0;px(s,e,c[C>>2]|0,c[g>>2]|0,h,j,k,53152,53172);c[C>>2]=c[s>>2];break};case 83:{C=p_(f,c[g>>2]|0,j,B,2)|0;E=c[j>>2]|0;if((E&4|0)==0&(C|0)<61){c[k>>2]=C;break L3946}else{c[j>>2]=E|4;break L3946}break};case 84:{E=f|0;px(t,e,c[E>>2]|0,c[g>>2]|0,h,j,k,53120,53152);c[E>>2]=c[t>>2];break};case 119:{E=p_(f,c[g>>2]|0,j,B,1)|0;C=c[j>>2]|0;if((C&4|0)==0&(E|0)<7){c[k+24>>2]=E;break L3946}else{c[j>>2]=C|4;break L3946}break};case 120:{C=c[(c[e>>2]|0)+20>>2]|0;c[u>>2]=c[f>>2];c[v>>2]=c[g>>2];gf[C&127](b,e,u,v,h,j,k);i=m;return};case 88:{C=e+8|0;E=f2[c[(c[C>>2]|0)+24>>2]&255](C)|0;C=f|0;ac=a[E]|0;if((ac&1)==0){aj=E+4|0}else{aj=c[E+8>>2]|0}D=ac&255;if((D&1|0)==0){ak=D>>>1}else{ak=c[E+4>>2]|0}px(w,e,c[C>>2]|0,c[g>>2]|0,h,j,k,aj,aj+(ak<<2)|0);c[C>>2]=c[w>>2];break};default:{c[j>>2]=c[j>>2]|4}}}while(0);c[b>>2]=c[f>>2];i=m;return}}while(0);m=fc(4)|0;c[m>>2]=53912;dq(m|0,60416,316)}function pC(a){a=a|0;return}function pD(a){a=a|0;return 127}function pE(a){a=a|0;return 127}function pF(a){a=a|0;return 0}function pG(a){a=a|0;return}function pH(a){a=a|0;return 127}function pI(a){a=a|0;return 127}function pJ(a){a=a|0;return 0}function pK(a){a=a|0;return}function pL(a){a=a|0;return 2147483647}function pM(a){a=a|0;return 2147483647}function pN(a){a=a|0;return 0}function pO(a){a=a|0;return}function pP(a){a=a|0;return 2147483647}function pQ(a){a=a|0;return 2147483647}function pR(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function pS(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function pT(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function pU(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function pV(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function pW(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function pX(b,c){b=b|0;c=c|0;c=b;a[b]=2;a[c+1|0]=45;a[c+2|0]=0;return}function pY(b,c){b=b|0;c=c|0;c=b;a[b]=2;a[c+1|0]=45;a[c+2|0]=0;return}function pZ(b,d){b=b|0;d=d|0;a[b]=2;d=b+4|0;c[d>>2]=45;c[d+4>>2]=0;return}function p_(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=a|0;a=c[g>>2]|0;do{if((a|0)==0){h=1}else{i=c[a+12>>2]|0;if((i|0)==(c[a+16>>2]|0)){j=f2[c[(c[a>>2]|0)+36>>2]&255](a)|0}else{j=c[i>>2]|0}if((j|0)==-1){c[g>>2]=0;h=1;break}else{h=(c[g>>2]|0)==0;break}}}while(0);do{if((b|0)==0){k=3541}else{j=c[b+12>>2]|0;if((j|0)==(c[b+16>>2]|0)){l=f2[c[(c[b>>2]|0)+36>>2]&255](b)|0}else{l=c[j>>2]|0}if((l|0)==-1){k=3541;break}if(h){m=b}else{k=3543}}}while(0);if((k|0)==3541){if(h){k=3543}else{m=0}}if((k|0)==3543){c[d>>2]=c[d>>2]|6;n=0;return n|0}h=c[g>>2]|0;b=c[h+12>>2]|0;if((b|0)==(c[h+16>>2]|0)){o=f2[c[(c[h>>2]|0)+36>>2]&255](h)|0}else{o=c[b>>2]|0}b=e;if(!(f7[c[(c[b>>2]|0)+12>>2]&127](e,2048,o)|0)){c[d>>2]=c[d>>2]|4;n=0;return n|0}h=e;l=(f7[c[(c[h>>2]|0)+52>>2]&127](e,o,0)|0)<<24>>24;o=c[g>>2]|0;j=o+12|0;a=c[j>>2]|0;if((a|0)==(c[o+16>>2]|0)){i=c[(c[o>>2]|0)+40>>2]|0;f2[i&255](o)|0;p=l;q=f;r=m}else{c[j>>2]=a+4;p=l;q=f;r=m}while(1){s=p-48|0;m=q-1|0;f=c[g>>2]|0;do{if((f|0)==0){t=0}else{l=c[f+12>>2]|0;if((l|0)==(c[f+16>>2]|0)){u=f2[c[(c[f>>2]|0)+36>>2]&255](f)|0}else{u=c[l>>2]|0}if((u|0)==-1){c[g>>2]=0;t=0;break}else{t=c[g>>2]|0;break}}}while(0);f=(t|0)==0;if((r|0)==0){v=t;w=0}else{l=c[r+12>>2]|0;if((l|0)==(c[r+16>>2]|0)){x=f2[c[(c[r>>2]|0)+36>>2]&255](r)|0}else{x=c[l>>2]|0}v=c[g>>2]|0;w=(x|0)==-1?0:r}y=(w|0)==0;if(!((f^y)&(m|0)>0)){break}f=c[v+12>>2]|0;if((f|0)==(c[v+16>>2]|0)){z=f2[c[(c[v>>2]|0)+36>>2]&255](v)|0}else{z=c[f>>2]|0}if(!(f7[c[(c[b>>2]|0)+12>>2]&127](e,2048,z)|0)){n=s;k=3593;break}f=((f7[c[(c[h>>2]|0)+52>>2]&127](e,z,0)|0)<<24>>24)+(s*10|0)|0;l=c[g>>2]|0;a=l+12|0;j=c[a>>2]|0;if((j|0)==(c[l+16>>2]|0)){o=c[(c[l>>2]|0)+40>>2]|0;f2[o&255](l)|0;p=f;q=m;r=w;continue}else{c[a>>2]=j+4;p=f;q=m;r=w;continue}}if((k|0)==3593){return n|0}do{if((v|0)==0){A=1}else{r=c[v+12>>2]|0;if((r|0)==(c[v+16>>2]|0)){B=f2[c[(c[v>>2]|0)+36>>2]&255](v)|0}else{B=c[r>>2]|0}if((B|0)==-1){c[g>>2]=0;A=1;break}else{A=(c[g>>2]|0)==0;break}}}while(0);do{if(y){k=3584}else{g=c[w+12>>2]|0;if((g|0)==(c[w+16>>2]|0)){C=f2[c[(c[w>>2]|0)+36>>2]&255](w)|0}else{C=c[g>>2]|0}if((C|0)==-1){k=3584;break}if(A){n=s}else{break}return n|0}}while(0);do{if((k|0)==3584){if(A){break}else{n=s}return n|0}}while(0);c[d>>2]=c[d>>2]|2;n=s;return n|0}function p$(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+112|0;f=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[f>>2];f=g|0;l=g+8|0;m=l|0;n=f|0;a[n]=37;o=f+1|0;a[o]=j;p=f+2|0;a[p]=k;a[f+3|0]=0;if(k<<24>>24!=0){a[o]=k;a[p]=j}j=di(m|0,100,n|0,h|0,c[d+8>>2]|0)|0;d=l+j|0;l=c[e>>2]|0;if((j|0)==0){q=l;r=b|0;c[r>>2]=q;i=g;return}else{s=l;t=m}while(1){m=a[t]|0;if((s|0)==0){u=0}else{l=s+24|0;j=c[l>>2]|0;if((j|0)==(c[s+28>>2]|0)){v=gj[c[(c[s>>2]|0)+52>>2]&127](s,m&255)|0}else{c[l>>2]=j+1;a[j]=m;v=m&255}u=(v|0)==-1?0:s}m=t+1|0;if((m|0)==(d|0)){q=u;break}else{s=u;t=m}}r=b|0;c[r>>2]=q;i=g;return}function p0(a){a=a|0;if((a|0)==0){return}sS(a);return}function p1(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function p2(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function p3(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function p4(a){a=a|0;if((a|0)==0){return}sS(a);return}function p5(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function p6(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function p7(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function p8(a){a=a|0;if((a|0)==0){return}sS(a);return}function p9(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function qa(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function qb(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function qc(a){a=a|0;if((a|0)==0){return}sS(a);return}function qd(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function qe(b){b=b|0;var d=0,e=0,f=0;d=b;e=b+8|0;f=c[e>>2]|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);if((f|0)!=(c[137522]|0)){cE(c[e>>2]|0)}if((b|0)==0){return}sS(d);return}function qf(b){b=b|0;var d=0;d=b+8|0;b=c[d>>2]|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);if((b|0)==(c[137522]|0)){return}cE(c[d>>2]|0);return}function qg(b){b=b|0;var d=0,e=0,f=0;d=b;e=b+8|0;f=c[e>>2]|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);if((f|0)!=(c[137522]|0)){cE(c[e>>2]|0)}if((b|0)==0){return}sS(d);return}function qh(b){b=b|0;var d=0;d=b+8|0;b=c[d>>2]|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);if((b|0)==(c[137522]|0)){return}cE(c[d>>2]|0);return}function qi(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+528|0;f=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[f>>2];f=g|0;l=g+112|0;m=g+120|0;n=g+128|0;o=n|0;p=g+8|0;q=f|0;a[q]=37;r=f+1|0;a[r]=j;s=f+2|0;a[s]=k;a[f+3|0]=0;if(k<<24>>24!=0){a[r]=k;a[s]=j}j=d+8|0;di(p|0,100,q|0,h|0,c[j>>2]|0)|0;c[l>>2]=0;c[l+4>>2]=0;c[m>>2]=p;p=eC(c[j>>2]|0)|0;j=sC(o,m,100,l)|0;if((p|0)!=0){eC(p|0)|0}if((j|0)==-1){qw(25648)}p=n+(j<<2)|0;n=c[e>>2]|0;if((j|0)==0){t=n;u=b|0;c[u>>2]=t;i=g;return}else{v=n;w=o}while(1){o=c[w>>2]|0;if((v|0)==0){x=0}else{n=v+24|0;j=c[n>>2]|0;if((j|0)==(c[v+28>>2]|0)){y=gj[c[(c[v>>2]|0)+52>>2]&127](v,o)|0}else{c[n>>2]=j+4;c[j>>2]=o;y=o}x=(y|0)==-1?0:v}o=w+4|0;if((o|0)==(p|0)){t=x;break}else{v=x;w=o}}u=b|0;c[u>>2]=t;i=g;return}function qj(a){a=a|0;return 0}function qk(a){a=a|0;return}function ql(a){a=a|0;return}function qm(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function qn(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function qo(b,d){b=b|0;d=d|0;a[b]=2;d=b+4|0;c[d>>2]=45;c[d+4>>2]=0;return}function qp(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function qq(a,b){a=a|0;b=b|0;s_(a|0,0,12);return}function qr(a){a=a|0;if((a|0)==0){return}sS(a);return}function qs(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=i;i=i+264|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+120|0;o=d+128|0;p=d+136|0;q=d+144|0;r=d+160|0;s=n|0;c[s>>2]=m;t=n+4|0;c[t>>2]=264;u=m+100|0;m=c[h+28>>2]|0;v=m;w=m+4|0;I=c[w>>2]|0,c[w>>2]=I+1,I;if((c[137882]|0)!=-1){c[l>>2]=551528;c[l+4>>2]=16;c[l+8>>2]=0;mU(551528,l)}l=(c[137883]|0)-1|0;w=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-w>>2>>>0>l>>>0){x=c[w+(l<<2)>>2]|0;if((x|0)==0){break}y=x;a[p]=0;z=f|0;do{if(qt(e,c[z>>2]|0,g,v,c[h+4>>2]|0,j,p,y,n,o,u)|0){A=q|0;B=c[(c[x>>2]|0)+32>>2]|0;gn[B&31](y,53072,53082,A)|0;B=r|0;C=c[o>>2]|0;D=c[s>>2]|0;E=C-D|0;do{if((E|0)>98){F=sR(E+2|0)|0;if((F|0)!=0){G=F;H=F;break}F=fc(4)|0;c[F>>2]=53880;dq(F|0,60400,240)}else{G=B;H=0}}while(0);if((a[p]&1)==0){J=G}else{a[G]=45;J=G+1|0}if(D>>>0<C>>>0){E=q+10|0;F=q;K=J;L=D;while(1){M=A;while(1){if((M|0)==(E|0)){N=E;break}if((a[M]|0)==(a[L]|0)){N=M;break}else{M=M+1|0}}a[K]=a[53072+(N-F)|0]|0;M=L+1|0;O=K+1|0;if(M>>>0<(c[o>>2]|0)>>>0){K=O;L=M}else{P=O;break}}}else{P=J}a[P]=0;L=eF(B|0,45880,(K=i,i=i+8|0,c[K>>2]=k,K)|0)|0;i=K;if((L|0)==1){if((H|0)==0){break}sS(H);break}L=fc(8)|0;c[L>>2]=53944;K=L+4|0;F=K;do{if((K|0)!=0){while(1){Q=sR(28)|0;if((Q|0)!=0){R=3759;break}E=(I=c[138018]|0,c[138018]=I+0,I);if((E|0)==0){break}gp[E&63]()}if((R|0)==3759){c[Q+4>>2]=15;c[Q>>2]=15;E=Q+12|0;c[F>>2]=E;c[Q+8>>2]=0;s1(E|0,44808,16)|0;break}E=fc(4)|0;c[E>>2]=53880;dq(E|0,60400,240)}}while(0);dq(L|0,60432,122)}}while(0);y=e|0;x=c[y>>2]|0;do{if((x|0)==0){S=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){S=x;break}if((f2[c[(c[x>>2]|0)+36>>2]&255](x)|0)!=-1){S=x;break}c[y>>2]=0;S=0}}while(0);y=(S|0)==0;x=c[z>>2]|0;do{if((x|0)==0){R=3777}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){if(y){break}else{R=3779;break}}if((f2[c[(c[x>>2]|0)+36>>2]&255](x)|0)==-1){c[z>>2]=0;R=3777;break}else{if(y){break}else{R=3779;break}}}}while(0);if((R|0)==3777){if(y){R=3779}}if((R|0)==3779){c[j>>2]=c[j>>2]|2}c[b>>2]=S;z=m+4|0;if(((I=c[z>>2]|0,c[z>>2]=I+ -1,I)|0)==0){f$[c[(c[m>>2]|0)+8>>2]&511](m)}z=c[s>>2]|0;c[s>>2]=0;if((z|0)==0){i=d;return}f$[c[t>>2]&511](z);i=d;return}}while(0);d=fc(4)|0;c[d>>2]=53912;dq(d|0,60416,316)}function qt(e,f,g,h,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0;q=i;i=i+584|0;r=q|0;s=q+16|0;t=q+32|0;u=q+40|0;v=q+56|0;w=q+72|0;x=q+88|0;y=q+104|0;z=q+112|0;A=q+128|0;B=q+144|0;C=q+160|0;D=q+176|0;E=q+576|0;F=E;G=i;i=i+12|0;i=i+7>>3<<3;H=G;J=i;i=i+12|0;i=i+7>>3<<3;K=i;i=i+12|0;i=i+7>>3<<3;L=i;i=i+12|0;i=i+7>>3<<3;M=i;i=i+12|0;i=i+7>>3<<3;N=i;i=i+4|0;i=i+7>>3<<3;O=D|0;s_(H|0,0,12);P=J;Q=K;R=L;S=M;s_(P|0,0,12);s_(Q|0,0,12);s_(R|0,0,12);s_(S|0,0,12);T=u;U=v;V=w;W=x;X=z;Y=A;Z=B;_=C;L4461:do{if(g){$=t;if((c[138e3]|0)!=-1){c[s>>2]=552e3;c[s+4>>2]=16;c[s+8>>2]=0;mU(552e3,s)}aa=(c[138001]|0)-1|0;ab=c[h+8>>2]|0;do{if((c[h+12>>2]|0)-ab>>2>>>0>aa>>>0){ac=c[ab+(aa<<2)>>2]|0;if((ac|0)==0){break}ad=ac;f0[c[(c[ac>>2]|0)+44>>2]&255]($,ad);c[E>>2]=c[t>>2];ae=ac;f0[c[(c[ae>>2]|0)+32>>2]&255](u,ad);if((a[R]&1)==0){a[L+1|0]=0;a[R]=0}else{a[c[L+8>>2]|0]=0;c[L+4>>2]=0}mW(L);c[R>>2]=c[T>>2];c[R+4>>2]=c[T+4>>2];c[R+8>>2]=c[T+8>>2];s_(T|0,0,12);f0[c[(c[ae>>2]|0)+28>>2]&255](v,ad);if((a[Q]&1)==0){a[K+1|0]=0;a[Q]=0}else{a[c[K+8>>2]|0]=0;c[K+4>>2]=0}mW(K);c[Q>>2]=c[U>>2];c[Q+4>>2]=c[U+4>>2];c[Q+8>>2]=c[U+8>>2];s_(U|0,0,12);af=ac;ag=f2[c[(c[af>>2]|0)+12>>2]&255](ad)|0;ah=f2[c[(c[af>>2]|0)+16>>2]&255](ad)|0;f0[c[(c[ae>>2]|0)+20>>2]&255](w,ad);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}mW(G);c[H>>2]=c[V>>2];c[H+4>>2]=c[V+4>>2];c[H+8>>2]=c[V+8>>2];s_(V|0,0,12);f0[c[(c[ae>>2]|0)+24>>2]&255](x,ad);if((a[P]&1)==0){a[J+1|0]=0;a[P]=0}else{a[c[J+8>>2]|0]=0;c[J+4>>2]=0}mW(J);c[P>>2]=c[W>>2];c[P+4>>2]=c[W+4>>2];c[P+8>>2]=c[W+8>>2];s_(W|0,0,12);ai=f2[c[(c[ac>>2]|0)+36>>2]&255](ad)|0;aj=ah;ak=ag;break L4461}}while(0);$=fc(4)|0;c[$>>2]=53912;dq($|0,60416,316);return 0}else{$=y;if((c[138002]|0)!=-1){c[r>>2]=552008;c[r+4>>2]=16;c[r+8>>2]=0;mU(552008,r)}aa=(c[138003]|0)-1|0;ab=c[h+8>>2]|0;do{if((c[h+12>>2]|0)-ab>>2>>>0>aa>>>0){ag=c[ab+(aa<<2)>>2]|0;if((ag|0)==0){break}ah=ag;f0[c[(c[ag>>2]|0)+44>>2]&255]($,ah);c[E>>2]=c[y>>2];ad=ag;f0[c[(c[ad>>2]|0)+32>>2]&255](z,ah);if((a[R]&1)==0){a[L+1|0]=0;a[R]=0}else{a[c[L+8>>2]|0]=0;c[L+4>>2]=0}mW(L);c[R>>2]=c[X>>2];c[R+4>>2]=c[X+4>>2];c[R+8>>2]=c[X+8>>2];s_(X|0,0,12);f0[c[(c[ad>>2]|0)+28>>2]&255](A,ah);if((a[Q]&1)==0){a[K+1|0]=0;a[Q]=0}else{a[c[K+8>>2]|0]=0;c[K+4>>2]=0}mW(K);c[Q>>2]=c[Y>>2];c[Q+4>>2]=c[Y+4>>2];c[Q+8>>2]=c[Y+8>>2];s_(Y|0,0,12);ac=ag;ae=f2[c[(c[ac>>2]|0)+12>>2]&255](ah)|0;af=f2[c[(c[ac>>2]|0)+16>>2]&255](ah)|0;f0[c[(c[ad>>2]|0)+20>>2]&255](B,ah);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}mW(G);c[H>>2]=c[Z>>2];c[H+4>>2]=c[Z+4>>2];c[H+8>>2]=c[Z+8>>2];s_(Z|0,0,12);f0[c[(c[ad>>2]|0)+24>>2]&255](C,ah);if((a[P]&1)==0){a[J+1|0]=0;a[P]=0}else{a[c[J+8>>2]|0]=0;c[J+4>>2]=0}mW(J);c[P>>2]=c[_>>2];c[P+4>>2]=c[_+4>>2];c[P+8>>2]=c[_+8>>2];s_(_|0,0,12);ai=f2[c[(c[ag>>2]|0)+36>>2]&255](ah)|0;aj=af;ak=ae;break L4461}}while(0);$=fc(4)|0;c[$>>2]=53912;dq($|0,60416,316);return 0}}while(0);_=n|0;c[o>>2]=c[_>>2];C=e|0;e=m+8|0;m=L+1|0;Z=L+4|0;B=L+8|0;Y=K+1|0;A=K+4|0;X=K+8|0;z=(j&512|0)!=0;j=J+1|0;y=J+4|0;E=J+8|0;J=M+1|0;h=M+4|0;r=M+8|0;W=F+3|0;x=n+4|0;n=G+4|0;V=M|0;M=p;p=264;w=O;U=O;O=D+400|0;D=0;v=0;T=ai;ai=f;L4535:while(1){f=c[C>>2]|0;do{if((f|0)==0){al=0}else{if((c[f+12>>2]|0)!=(c[f+16>>2]|0)){al=f;break}if((f2[c[(c[f>>2]|0)+36>>2]&255](f)|0)==-1){c[C>>2]=0;al=0;break}else{al=c[C>>2]|0;break}}}while(0);f=(al|0)==0;do{if((ai|0)==0){am=3875}else{if((c[ai+12>>2]|0)!=(c[ai+16>>2]|0)){if(f){an=ai;break}else{ao=p;ap=w;aq=U;ar=D;as=ai;am=4200;break L4535}}if((f2[c[(c[ai>>2]|0)+36>>2]&255](ai)|0)==-1){am=3875;break}if(f){an=ai}else{ao=p;ap=w;aq=U;ar=D;as=ai;am=4200;break L4535}}}while(0);if((am|0)==3875){am=0;if(f){ao=p;ap=w;aq=U;ar=D;as=0;am=4200;break}else{an=0}}L4555:do{switch(a[F+v|0]|0){case 0:{am=3949;break};case 3:{u=a[Q]|0;t=u&255;s=(t&1|0)==0?t>>>1:c[A>>2]|0;t=a[R]|0;g=t&255;$=(g&1|0)==0?g>>>1:c[Z>>2]|0;if((s|0)==(-$|0)){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L4555}g=(s|0)==0;s=c[C>>2]|0;aa=c[s+12>>2]|0;ab=c[s+16>>2]|0;ae=(aa|0)==(ab|0);if(!(g|($|0)==0)){if(ae){$=(f2[c[(c[s>>2]|0)+36>>2]&255](s)|0)&255;af=c[C>>2]|0;aB=$;aC=a[Q]|0;aD=af;aE=c[af+12>>2]|0;aF=c[af+16>>2]|0}else{aB=a[aa]|0;aC=u;aD=s;aE=aa;aF=ab}ab=aD+12|0;af=(aE|0)==(aF|0);if(aB<<24>>24==(a[(aC&1)==0?Y:c[X>>2]|0]|0)){if(af){$=c[(c[aD>>2]|0)+40>>2]|0;f2[$&255](aD)|0}else{c[ab>>2]=aE+1}ab=d[Q]|0;at=((ab&1|0)==0?ab>>>1:c[A>>2]|0)>>>0>1?K:D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L4555}if(af){aG=(f2[c[(c[aD>>2]|0)+36>>2]&255](aD)|0)&255}else{aG=a[aE]|0}if(aG<<24>>24!=(a[(a[R]&1)==0?m:c[B>>2]|0]|0)){am=4041;break L4535}af=c[C>>2]|0;ab=af+12|0;$=c[ab>>2]|0;if(($|0)==(c[af+16>>2]|0)){ah=c[(c[af>>2]|0)+40>>2]|0;f2[ah&255](af)|0}else{c[ab>>2]=$+1}a[l]=1;$=d[R]|0;at=(($&1|0)==0?$>>>1:c[Z>>2]|0)>>>0>1?L:D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L4555}if(g){if(ae){g=(f2[c[(c[s>>2]|0)+36>>2]&255](s)|0)&255;aH=g;aI=a[R]|0}else{aH=a[aa]|0;aI=t}if(aH<<24>>24!=(a[(aI&1)==0?m:c[B>>2]|0]|0)){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L4555}t=c[C>>2]|0;g=t+12|0;$=c[g>>2]|0;if(($|0)==(c[t+16>>2]|0)){ab=c[(c[t>>2]|0)+40>>2]|0;f2[ab&255](t)|0}else{c[g>>2]=$+1}a[l]=1;$=d[R]|0;at=(($&1|0)==0?$>>>1:c[Z>>2]|0)>>>0>1?L:D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L4555}if(ae){ae=(f2[c[(c[s>>2]|0)+36>>2]&255](s)|0)&255;aJ=ae;aK=a[Q]|0}else{aJ=a[aa]|0;aK=u}if(aJ<<24>>24!=(a[(aK&1)==0?Y:c[X>>2]|0]|0)){a[l]=1;at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L4555}u=c[C>>2]|0;aa=u+12|0;ae=c[aa>>2]|0;if((ae|0)==(c[u+16>>2]|0)){s=c[(c[u>>2]|0)+40>>2]|0;f2[s&255](u)|0}else{c[aa>>2]=ae+1}ae=d[Q]|0;at=((ae&1|0)==0?ae>>>1:c[A>>2]|0)>>>0>1?K:D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break};case 1:{if((v|0)==3){ao=p;ap=w;aq=U;ar=D;as=an;am=4200;break L4535}ae=c[C>>2]|0;aa=c[ae+12>>2]|0;if((aa|0)==(c[ae+16>>2]|0)){aL=(f2[c[(c[ae>>2]|0)+36>>2]&255](ae)|0)&255}else{aL=a[aa]|0}if(aL<<24>>24<=-1){am=3948;break L4535}if((b[(c[e>>2]|0)+(aL<<24>>24<<1)>>1]&8192)==0){am=3948;break L4535}aa=c[C>>2]|0;ae=aa+12|0;u=c[ae>>2]|0;if((u|0)==(c[aa+16>>2]|0)){aM=(f2[c[(c[aa>>2]|0)+40>>2]&255](aa)|0)&255}else{c[ae>>2]=u+1;aM=a[u]|0}u=a[S]|0;if((u&1)==0){aN=(u&255)>>>1;aO=10;aP=u}else{ae=c[V>>2]|0;aN=c[h>>2]|0;aO=(ae&-2)-1|0;aP=ae&255}if((aN|0)==(aO|0)){if((aO|0)==-3){am=3925;break L4535}ae=(aP&1)==0?J:c[r>>2]|0;do{if(aO>>>0<2147483631){aa=aO+1|0;s=aO<<1;$=aa>>>0<s>>>0?s:aa;if($>>>0<11){aQ=11;break}aQ=$+16&-16}else{aQ=-2}}while(0);$=(aQ|0)==0?1:aQ;while(1){aR=sR($)|0;if((aR|0)!=0){break}aa=(I=c[138018]|0,c[138018]=I+0,I);if((aa|0)==0){am=3939;break L4535}gp[aa&63]()}s1(aR|0,ae|0,aO)|0;if(!((aO|0)==10|(ae|0)==0)){sS(ae)}c[r>>2]=aR;$=aQ|1;c[V>>2]=$;aS=$&255}else{aS=u}if((aS&1)==0){a[S]=(aN<<1)+2&255;aT=J;aU=aN+1|0}else{$=c[r>>2]|0;aa=aN+1|0;c[h>>2]=aa;aT=$;aU=aa}a[aT+aN|0]=aM;a[aT+aU|0]=0;am=3949;break};case 2:{if(!((D|0)!=0|v>>>0<2)){if((v|0)==2){aV=(a[W]|0)!=0}else{aV=0}if(!(z|aV)){at=0;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an;break L4555}}aa=a[P]|0;$=(aa&1)==0?j:c[E>>2]|0;L4653:do{if((v|0)==0){aW=$}else{if((d[F+(v-1)|0]|0)>=2){aW=$;break}s=aa&255;g=$+((s&1|0)==0?s>>>1:c[y>>2]|0)|0;s=$;while(1){if((s|0)==(g|0)){aX=g;break}t=a[s]|0;if(t<<24>>24<=-1){aX=s;break}if((b[(c[e>>2]|0)+(t<<24>>24<<1)>>1]&8192)==0){aX=s;break}else{s=s+1|0}}s=aX-$|0;g=a[S]|0;t=g&255;ab=(t&1|0)==0?t>>>1:c[h>>2]|0;if(s>>>0>ab>>>0){aW=$;break}t=(g&1)==0?J:c[r>>2]|0;g=t+ab|0;if((aX|0)==($|0)){aW=$;break}af=$;ah=t+(ab-s)|0;while(1){if((a[ah]|0)!=(a[af]|0)){aW=$;break L4653}s=ah+1|0;if((s|0)==(g|0)){aW=aX;break}else{af=af+1|0;ah=s}}}}while(0);u=aa&255;L4667:do{if((aW|0)==($+((u&1|0)==0?u>>>1:c[y>>2]|0)|0)){aY=aW;aZ=an}else{ae=an;ah=aW;af=an;while(1){g=c[C>>2]|0;do{if((g|0)==0){a_=0}else{if((c[g+12>>2]|0)!=(c[g+16>>2]|0)){a_=g;break}if((f2[c[(c[g>>2]|0)+36>>2]&255](g)|0)==-1){c[C>>2]=0;a_=0;break}else{a_=c[C>>2]|0;break}}}while(0);g=(a_|0)==0;do{if((ae|0)==0){a$=af;am=4069}else{if((c[ae+12>>2]|0)!=(c[ae+16>>2]|0)){if(g){a0=ae;a1=af;break}else{aY=ah;aZ=af;break L4667}}if((f2[c[(c[ae>>2]|0)+36>>2]&255](ae)|0)==-1){a$=0;am=4069;break}if(g){a0=ae;a1=af}else{aY=ah;aZ=af;break L4667}}}while(0);if((am|0)==4069){am=0;if(g){aY=ah;aZ=a$;break L4667}else{a0=0;a1=a$}}s=c[C>>2]|0;ab=c[s+12>>2]|0;if((ab|0)==(c[s+16>>2]|0)){a2=(f2[c[(c[s>>2]|0)+36>>2]&255](s)|0)&255}else{a2=a[ab]|0}if(a2<<24>>24!=(a[ah]|0)){aY=ah;aZ=a1;break L4667}ab=c[C>>2]|0;s=ab+12|0;t=c[s>>2]|0;if((t|0)==(c[ab+16>>2]|0)){ag=c[(c[ab>>2]|0)+40>>2]|0;f2[ag&255](ab)|0}else{c[s>>2]=t+1}t=ah+1|0;s=a[P]|0;ab=s&255;if((t|0)==(((s&1)==0?j:c[E>>2]|0)+((ab&1|0)==0?ab>>>1:c[y>>2]|0)|0)){aY=t;aZ=a1;break}else{ae=a0;ah=t;af=a1}}}}while(0);if(!z){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=aZ;break L4555}u=a[P]|0;$=u&255;if((aY|0)==(((u&1)==0?j:c[E>>2]|0)+(($&1|0)==0?$>>>1:c[y>>2]|0)|0)){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=aZ}else{am=4082;break L4535}break};case 4:{$=0;u=O;aa=U;af=w;ah=p;ae=M;t=an;L4700:while(1){ab=c[C>>2]|0;do{if((ab|0)==0){a3=0}else{if((c[ab+12>>2]|0)!=(c[ab+16>>2]|0)){a3=ab;break}if((f2[c[(c[ab>>2]|0)+36>>2]&255](ab)|0)==-1){c[C>>2]=0;a3=0;break}else{a3=c[C>>2]|0;break}}}while(0);ab=(a3|0)==0;do{if((t|0)==0){am=4094}else{if((c[t+12>>2]|0)!=(c[t+16>>2]|0)){if(ab){a4=t;break}else{a5=t;break L4700}}if((f2[c[(c[t>>2]|0)+36>>2]&255](t)|0)==-1){am=4094;break}if(ab){a4=t}else{a5=t;break L4700}}}while(0);if((am|0)==4094){am=0;if(ab){a5=0;break}else{a4=0}}s=c[C>>2]|0;ag=c[s+12>>2]|0;if((ag|0)==(c[s+16>>2]|0)){a6=(f2[c[(c[s>>2]|0)+36>>2]&255](s)|0)&255}else{a6=a[ag]|0}do{if(a6<<24>>24>-1){if((b[(c[e>>2]|0)+(a6<<24>>24<<1)>>1]&2048)==0){am=4114;break}ag=c[o>>2]|0;if((ag|0)==(ae|0)){s=(c[x>>2]|0)!=264;ad=c[_>>2]|0;ac=ae-ad|0;a7=ac>>>0<2147483647?ac<<1:-1;a8=sT(s?ad:0,a7)|0;if((a8|0)==0){am=4104;break L4535}do{if(s){c[_>>2]=a8;a9=a8}else{ad=c[_>>2]|0;c[_>>2]=a8;if((ad|0)==0){a9=a8;break}f$[c[x>>2]&511](ad);a9=c[_>>2]|0}}while(0);c[x>>2]=138;a8=a9+ac|0;c[o>>2]=a8;ba=(c[_>>2]|0)+a7|0;bb=a8}else{ba=ae;bb=ag}c[o>>2]=bb+1;a[bb]=a6;bc=$+1|0;bd=u;be=aa;bf=af;bg=ah;bh=ba}else{am=4114}}while(0);if((am|0)==4114){am=0;ab=d[H]|0;if(!(($|0)!=0&(((ab&1|0)==0?ab>>>1:c[n>>2]|0)|0)!=0&a6<<24>>24==aj<<24>>24)){a5=a4;break}if((aa|0)==(u|0)){ab=aa-af|0;a8=ab>>>0<2147483647?ab<<1:-1;if((ah|0)==264){bi=0}else{bi=af}s=sT(bi,a8)|0;g=s;if((s|0)==0){am=4119;break L4535}bj=g+(a8>>>2<<2)|0;bk=g+(ab>>2<<2)|0;bl=g;bm=138}else{bj=u;bk=aa;bl=af;bm=ah}c[bk>>2]=$;bc=0;bd=bj;be=bk+4|0;bf=bl;bg=bm;bh=ae}g=c[C>>2]|0;ab=g+12|0;a8=c[ab>>2]|0;if((a8|0)==(c[g+16>>2]|0)){s=c[(c[g>>2]|0)+40>>2]|0;f2[s&255](g)|0;$=bc;u=bd;aa=be;af=bf;ah=bg;ae=bh;t=a4;continue}else{c[ab>>2]=a8+1;$=bc;u=bd;aa=be;af=bf;ah=bg;ae=bh;t=a4;continue}}if((af|0)==(aa|0)|($|0)==0){bn=u;bo=aa;bp=af;bq=ah}else{if((aa|0)==(u|0)){t=aa-af|0;a8=t>>>0<2147483647?t<<1:-1;if((ah|0)==264){br=0}else{br=af}ab=sT(br,a8)|0;g=ab;if((ab|0)==0){am=4131;break L4535}bs=g+(a8>>>2<<2)|0;bt=g+(t>>2<<2)|0;bu=g;bv=138}else{bs=u;bt=aa;bu=af;bv=ah}c[bt>>2]=$;bn=bs;bo=bt+4|0;bp=bu;bq=bv}if((T|0)>0){g=c[C>>2]|0;do{if((g|0)==0){bw=0}else{if((c[g+12>>2]|0)!=(c[g+16>>2]|0)){bw=g;break}if((f2[c[(c[g>>2]|0)+36>>2]&255](g)|0)==-1){c[C>>2]=0;bw=0;break}else{bw=c[C>>2]|0;break}}}while(0);g=(bw|0)==0;do{if((a5|0)==0){am=4147}else{if((c[a5+12>>2]|0)!=(c[a5+16>>2]|0)){if(g){bx=a5;break}else{am=4154;break L4535}}if((f2[c[(c[a5>>2]|0)+36>>2]&255](a5)|0)==-1){am=4147;break}if(g){bx=a5}else{am=4154;break L4535}}}while(0);if((am|0)==4147){am=0;if(g){am=4154;break L4535}else{bx=0}}$=c[C>>2]|0;ah=c[$+12>>2]|0;if((ah|0)==(c[$+16>>2]|0)){by=(f2[c[(c[$>>2]|0)+36>>2]&255]($)|0)&255}else{by=a[ah]|0}if(by<<24>>24!=ak<<24>>24){am=4154;break L4535}ah=c[C>>2]|0;$=ah+12|0;af=c[$>>2]|0;if((af|0)==(c[ah+16>>2]|0)){aa=c[(c[ah>>2]|0)+40>>2]|0;f2[aa&255](ah)|0;bz=ae;bA=bx;bB=T;bC=bx}else{c[$>>2]=af+1;bz=ae;bA=bx;bB=T;bC=bx}while(1){af=c[C>>2]|0;do{if((af|0)==0){bD=0}else{if((c[af+12>>2]|0)!=(c[af+16>>2]|0)){bD=af;break}if((f2[c[(c[af>>2]|0)+36>>2]&255](af)|0)==-1){c[C>>2]=0;bD=0;break}else{bD=c[C>>2]|0;break}}}while(0);af=(bD|0)==0;do{if((bA|0)==0){bE=bC;am=4169}else{if((c[bA+12>>2]|0)!=(c[bA+16>>2]|0)){if(af){bF=bA;bG=bC;break}else{am=4177;break L4535}}if((f2[c[(c[bA>>2]|0)+36>>2]&255](bA)|0)==-1){bE=0;am=4169;break}if(af){bF=bA;bG=bC}else{am=4177;break L4535}}}while(0);if((am|0)==4169){am=0;if(af){am=4177;break L4535}else{bF=0;bG=bE}}$=c[C>>2]|0;ah=c[$+12>>2]|0;if((ah|0)==(c[$+16>>2]|0)){bH=(f2[c[(c[$>>2]|0)+36>>2]&255]($)|0)&255}else{bH=a[ah]|0}if(bH<<24>>24<=-1){am=4177;break L4535}if((b[(c[e>>2]|0)+(bH<<24>>24<<1)>>1]&2048)==0){am=4177;break L4535}ah=c[o>>2]|0;if((ah|0)==(bz|0)){$=(c[x>>2]|0)!=264;aa=c[_>>2]|0;u=bz-aa|0;t=u>>>0<2147483647?u<<1:-1;a8=sT($?aa:0,t)|0;if((a8|0)==0){am=4180;break L4535}do{if($){c[_>>2]=a8;bI=a8}else{aa=c[_>>2]|0;c[_>>2]=a8;if((aa|0)==0){bI=a8;break}f$[c[x>>2]&511](aa);bI=c[_>>2]|0}}while(0);c[x>>2]=138;a8=bI+u|0;c[o>>2]=a8;bJ=(c[_>>2]|0)+t|0;bK=a8}else{bJ=bz;bK=ah}a8=c[C>>2]|0;$=c[a8+12>>2]|0;if(($|0)==(c[a8+16>>2]|0)){af=(f2[c[(c[a8>>2]|0)+36>>2]&255](a8)|0)&255;bL=af;bM=c[o>>2]|0}else{bL=a[$]|0;bM=bK}c[o>>2]=bM+1;a[bM]=bL;$=bB-1|0;af=c[C>>2]|0;a8=af+12|0;aa=c[a8>>2]|0;if((aa|0)==(c[af+16>>2]|0)){ab=c[(c[af>>2]|0)+40>>2]|0;f2[ab&255](af)|0}else{c[a8>>2]=aa+1}if(($|0)>0){bz=bJ;bA=bF;bB=$;bC=bG}else{bN=bJ;bO=$;bP=bG;break}}}else{bN=ae;bO=T;bP=a5}if((c[o>>2]|0)==(c[_>>2]|0)){am=4198;break L4535}else{at=D;au=bn;av=bo;aw=bp;ax=bq;ay=bN;az=bO;aA=bP}break};default:{at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=an}}}while(0);L4839:do{if((am|0)==3949){am=0;if((v|0)==3){ao=p;ap=w;aq=U;ar=D;as=an;am=4200;break L4535}else{bQ=an;bR=an}while(1){f=c[C>>2]|0;do{if((f|0)==0){bS=0}else{if((c[f+12>>2]|0)!=(c[f+16>>2]|0)){bS=f;break}if((f2[c[(c[f>>2]|0)+36>>2]&255](f)|0)==-1){c[C>>2]=0;bS=0;break}else{bS=c[C>>2]|0;break}}}while(0);f=(bS|0)==0;do{if((bQ|0)==0){bT=bR;am=3961}else{if((c[bQ+12>>2]|0)!=(c[bQ+16>>2]|0)){if(f){bU=bQ;bV=bR;break}else{at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=bR;break L4839}}if((f2[c[(c[bQ>>2]|0)+36>>2]&255](bQ)|0)==-1){bT=0;am=3961;break}if(f){bU=bQ;bV=bR}else{at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=bR;break L4839}}}while(0);if((am|0)==3961){am=0;if(f){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=bT;break L4839}else{bU=0;bV=bT}}ah=c[C>>2]|0;t=c[ah+12>>2]|0;if((t|0)==(c[ah+16>>2]|0)){bW=(f2[c[(c[ah>>2]|0)+36>>2]&255](ah)|0)&255}else{bW=a[t]|0}if(bW<<24>>24<=-1){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=bV;break L4839}if((b[(c[e>>2]|0)+(bW<<24>>24<<1)>>1]&8192)==0){at=D;au=O;av=U;aw=w;ax=p;ay=M;az=T;aA=bV;break L4839}t=c[C>>2]|0;ah=t+12|0;u=c[ah>>2]|0;if((u|0)==(c[t+16>>2]|0)){bX=(f2[c[(c[t>>2]|0)+40>>2]&255](t)|0)&255}else{c[ah>>2]=u+1;bX=a[u]|0}u=a[S]|0;if((u&1)==0){bY=(u&255)>>>1;bZ=10;b_=u}else{ah=c[V>>2]|0;bY=c[h>>2]|0;bZ=(ah&-2)-1|0;b_=ah&255}if((bY|0)==(bZ|0)){if((bZ|0)==-3){am=3978;break L4535}ah=(b_&1)==0?J:c[r>>2]|0;do{if(bZ>>>0<2147483631){t=bZ+1|0;g=bZ<<1;$=t>>>0<g>>>0?g:t;if($>>>0<11){b$=11;break}b$=$+16&-16}else{b$=-2}}while(0);f=(b$|0)==0?1:b$;while(1){b0=sR(f)|0;if((b0|0)!=0){break}$=(I=c[138018]|0,c[138018]=I+0,I);if(($|0)==0){am=3992;break L4535}gp[$&63]()}s1(b0|0,ah|0,bZ)|0;if(!((bZ|0)==10|(ah|0)==0)){sS(ah)}c[r>>2]=b0;f=b$|1;c[V>>2]=f;b1=f&255}else{b1=u}if((b1&1)==0){a[S]=(bY<<1)+2&255;b2=J;b3=bY+1|0}else{f=c[r>>2]|0;$=bY+1|0;c[h>>2]=$;b2=f;b3=$}a[b2+bY|0]=bX;a[b2+b3|0]=0;bQ=bU;bR=bV}}}while(0);ae=v+1|0;if(ae>>>0<4){M=ay;p=ax;w=aw;U=av;O=au;D=at;v=ae;T=az;ai=aA}else{ao=ax;ap=aw;aq=av;ar=at;as=aA;am=4200;break}}L4898:do{if((am|0)==3948){c[k>>2]=c[k>>2]|4;b4=0;b5=w;b6=p}else if((am|0)==3978){mV();return 0}else if((am|0)==3992){aA=fc(4)|0;c[aA>>2]=53880;dq(aA|0,60400,240);return 0}else if((am|0)==3925){mV();return 0}else if((am|0)==3939){aA=fc(4)|0;c[aA>>2]=53880;dq(aA|0,60400,240);return 0}else if((am|0)==4041){c[k>>2]=c[k>>2]|4;b4=0;b5=w;b6=p}else if((am|0)==4082){c[k>>2]=c[k>>2]|4;b4=0;b5=w;b6=p}else if((am|0)==4104){aA=fc(4)|0;c[aA>>2]=53880;dq(aA|0,60400,240);return 0}else if((am|0)==4119){aA=fc(4)|0;c[aA>>2]=53880;dq(aA|0,60400,240);return 0}else if((am|0)==4131){aA=fc(4)|0;c[aA>>2]=53880;dq(aA|0,60400,240);return 0}else if((am|0)==4154){c[k>>2]=c[k>>2]|4;b4=0;b5=bp;b6=bq}else if((am|0)==4177){c[k>>2]=c[k>>2]|4;b4=0;b5=bp;b6=bq}else if((am|0)==4180){aA=fc(4)|0;c[aA>>2]=53880;dq(aA|0,60400,240);return 0}else if((am|0)==4198){c[k>>2]=c[k>>2]|4;b4=0;b5=bp;b6=bq}else if((am|0)==4200){L4922:do{if((ar|0)!=0){aA=ar;at=ar+1|0;av=ar+8|0;aw=ar+4|0;ax=1;ai=as;L4924:while(1){az=d[aA]|0;if((az&1|0)==0){b7=az>>>1}else{b7=c[aw>>2]|0}if(ax>>>0>=b7>>>0){break L4922}az=c[C>>2]|0;do{if((az|0)==0){b8=0}else{if((c[az+12>>2]|0)!=(c[az+16>>2]|0)){b8=az;break}if((f2[c[(c[az>>2]|0)+36>>2]&255](az)|0)==-1){c[C>>2]=0;b8=0;break}else{b8=c[C>>2]|0;break}}}while(0);az=(b8|0)==0;do{if((ai|0)==0){am=4217}else{if((c[ai+12>>2]|0)!=(c[ai+16>>2]|0)){if(az){b9=ai;break}else{break L4924}}if((f2[c[(c[ai>>2]|0)+36>>2]&255](ai)|0)==-1){am=4217;break}if(az){b9=ai}else{break L4924}}}while(0);if((am|0)==4217){am=0;if(az){break}else{b9=0}}u=c[C>>2]|0;ah=c[u+12>>2]|0;if((ah|0)==(c[u+16>>2]|0)){ca=(f2[c[(c[u>>2]|0)+36>>2]&255](u)|0)&255}else{ca=a[ah]|0}if((a[aA]&1)==0){cb=at}else{cb=c[av>>2]|0}if(ca<<24>>24!=(a[cb+ax|0]|0)){break}ah=ax+1|0;u=c[C>>2]|0;T=u+12|0;v=c[T>>2]|0;if((v|0)==(c[u+16>>2]|0)){D=c[(c[u>>2]|0)+40>>2]|0;f2[D&255](u)|0;ax=ah;ai=b9;continue}else{c[T>>2]=v+1;ax=ah;ai=b9;continue}}c[k>>2]=c[k>>2]|4;b4=0;b5=ap;b6=ao;break L4898}}while(0);if((ap|0)==(aq|0)){b4=1;b5=aq;b6=ao;break}c[N>>2]=0;oe(G,ap,aq,N);if((c[N>>2]|0)==0){b4=1;b5=ap;b6=ao;break}c[k>>2]=c[k>>2]|4;b4=0;b5=ap;b6=ao}}while(0);do{if((a[S]&1)!=0){ao=c[r>>2]|0;if((ao|0)==0){break}sS(ao)}}while(0);do{if((a[R]&1)!=0){r=c[B>>2]|0;if((r|0)==0){break}sS(r)}}while(0);do{if((a[Q]&1)!=0){B=c[X>>2]|0;if((B|0)==0){break}sS(B)}}while(0);do{if((a[P]&1)!=0){X=c[E>>2]|0;if((X|0)==0){break}sS(X)}}while(0);do{if((a[H]&1)!=0){E=c[G+8>>2]|0;if((E|0)==0){break}sS(E)}}while(0);if((b5|0)==0){i=q;return b4|0}f$[b6&511](b5);i=q;return b4|0}function qu(a){a=a|0;return}function qv(a){a=a|0;if((a|0)==0){return}sS(a);return}function qw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=fc(8)|0;c[b>>2]=53944;d=b+4|0;e=d;if((d|0)==0){dq(b|0,60432,122)}d=sZ(a|0)|0;f=d+13|0;g=(f|0)==0?1:f;while(1){h=sR(g)|0;if((h|0)!=0){i=4277;break}f=(I=c[138018]|0,c[138018]=I+0,I);if((f|0)==0){i=4271;break}gp[f&63]()}if((i|0)==4277){g=d+1|0;c[h+4>>2]=d;c[h>>2]=d;d=h+12|0;c[e>>2]=d;c[h+8>>2]=0;s1(d|0,a|0,g)|0;dq(b|0,60432,122)}else if((i|0)==4271){i=fc(4)|0;c[i>>2]=53880;dq(i|0,60400,240)}}function qx(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;d=i;i=i+144|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+120|0;o=d+128|0;p=d+136|0;q=n|0;c[q>>2]=m;r=n+4|0;c[r>>2]=264;s=m+100|0;m=c[h+28>>2]|0;t=m;u=m+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;if((c[137882]|0)!=-1){c[l>>2]=551528;c[l+4>>2]=16;c[l+8>>2]=0;mU(551528,l)}l=(c[137883]|0)-1|0;u=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-u>>2>>>0>l>>>0){v=c[u+(l<<2)>>2]|0;if((v|0)==0){break}w=v;a[p]=0;x=f|0;y=c[x>>2]|0;do{if(qt(e,y,g,t,c[h+4>>2]|0,j,p,w,n,o,s)|0){z=k;if((a[z]&1)==0){a[k+1|0]=0;a[z]=0}else{a[c[k+8>>2]|0]=0;c[k+4>>2]=0}A=v;if((a[p]&1)!=0){B=gj[c[(c[A>>2]|0)+28>>2]&127](w,45)|0;C=a[z]|0;if((C&1)==0){D=(C&255)>>>1;E=10}else{D=c[k+4>>2]|0;E=(c[k>>2]&-2)-1|0}if((D|0)==(E|0)){m_(k,E,1,E,E,0);F=a[z]|0}else{F=C}if((F&1)==0){a[z]=(D<<1)+2&255;G=k+1|0;H=D+1|0}else{C=c[k+8>>2]|0;J=D+1|0;c[k+4>>2]=J;G=C;H=J}a[G+D|0]=B;a[G+H|0]=0}B=gj[c[(c[A>>2]|0)+28>>2]&127](w,48)|0;A=c[o>>2]|0;J=A-1|0;C=c[q>>2]|0;while(1){if(C>>>0>=J>>>0){break}if((a[C]|0)==B<<24>>24){C=C+1|0}else{break}}B=C;J=a[z]|0;K=J&255;if((K&1|0)==0){L=K>>>1}else{L=c[k+4>>2]|0}if((J&1)==0){M=10;N=J}else{J=c[k>>2]|0;M=(J&-2)-1|0;N=J&255}J=A-B|0;if((A|0)==(C|0)){break}if((M-L|0)>>>0<J>>>0){m_(k,M,L+J-M|0,L,L,0);O=a[z]|0}else{O=N}if((O&1)==0){P=k+1|0}else{P=c[k+8>>2]|0}K=A+(L-B)|0;B=C;Q=P+L|0;while(1){a[Q]=a[B]|0;R=B+1|0;if((R|0)==(A|0)){break}B=R;Q=Q+1|0}a[P+K|0]=0;Q=L+J|0;if((a[z]&1)==0){a[z]=Q<<1&255;break}else{c[k+4>>2]=Q;break}}}while(0);w=e|0;v=c[w>>2]|0;do{if((v|0)==0){S=0}else{if((c[v+12>>2]|0)!=(c[v+16>>2]|0)){S=v;break}if((f2[c[(c[v>>2]|0)+36>>2]&255](v)|0)!=-1){S=v;break}c[w>>2]=0;S=0}}while(0);w=(S|0)==0;do{if((y|0)==0){T=4339}else{if((c[y+12>>2]|0)!=(c[y+16>>2]|0)){if(w){break}else{T=4341;break}}if((f2[c[(c[y>>2]|0)+36>>2]&255](y)|0)==-1){c[x>>2]=0;T=4339;break}else{if(w){break}else{T=4341;break}}}}while(0);if((T|0)==4339){if(w){T=4341}}if((T|0)==4341){c[j>>2]=c[j>>2]|2}c[b>>2]=S;x=m+4|0;if(((I=c[x>>2]|0,c[x>>2]=I+ -1,I)|0)==0){f$[c[(c[m>>2]|0)+8>>2]&511](m)}x=c[q>>2]|0;c[q>>2]=0;if((x|0)==0){i=d;return}f$[c[r>>2]&511](x);i=d;return}}while(0);d=fc(4)|0;c[d>>2]=53912;dq(d|0,60416,316)}function qy(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=i;i=i+584|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+416|0;o=d+424|0;p=d+432|0;q=d+440|0;r=d+480|0;s=n|0;c[s>>2]=m;t=n+4|0;c[t>>2]=264;u=m+400|0;m=c[h+28>>2]|0;v=m;w=m+4|0;I=c[w>>2]|0,c[w>>2]=I+1,I;if((c[137880]|0)!=-1){c[l>>2]=551520;c[l+4>>2]=16;c[l+8>>2]=0;mU(551520,l)}l=(c[137881]|0)-1|0;w=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-w>>2>>>0>l>>>0){x=c[w+(l<<2)>>2]|0;if((x|0)==0){break}y=x;a[p]=0;z=f|0;do{if(qz(e,c[z>>2]|0,g,v,c[h+4>>2]|0,j,p,y,n,o,u)|0){A=q|0;B=c[(c[x>>2]|0)+48>>2]|0;gn[B&31](y,53056,53066,A)|0;B=r|0;C=c[o>>2]|0;D=c[s>>2]|0;E=C-D|0;do{if((E|0)>392){F=sR((E>>2)+2|0)|0;if((F|0)!=0){G=F;H=F;break}F=fc(4)|0;c[F>>2]=53880;dq(F|0,60400,240)}else{G=B;H=0}}while(0);if((a[p]&1)==0){J=G}else{a[G]=45;J=G+1|0}if(D>>>0<C>>>0){E=q+40|0;F=q;K=J;L=D;while(1){M=A;while(1){if((M|0)==(E|0)){N=E;break}if((c[M>>2]|0)==(c[L>>2]|0)){N=M;break}else{M=M+4|0}}a[K]=a[53056+(N-F>>2)|0]|0;M=L+4|0;O=K+1|0;if(M>>>0<(c[o>>2]|0)>>>0){K=O;L=M}else{P=O;break}}}else{P=J}a[P]=0;L=eF(B|0,45880,(K=i,i=i+8|0,c[K>>2]=k,K)|0)|0;i=K;if((L|0)==1){if((H|0)==0){break}sS(H);break}L=fc(8)|0;c[L>>2]=53944;K=L+4|0;F=K;do{if((K|0)!=0){while(1){Q=sR(28)|0;if((Q|0)!=0){R=4397;break}E=(I=c[138018]|0,c[138018]=I+0,I);if((E|0)==0){break}gp[E&63]()}if((R|0)==4397){c[Q+4>>2]=15;c[Q>>2]=15;E=Q+12|0;c[F>>2]=E;c[Q+8>>2]=0;s1(E|0,44808,16)|0;break}E=fc(4)|0;c[E>>2]=53880;dq(E|0,60400,240)}}while(0);dq(L|0,60432,122)}}while(0);y=e|0;x=c[y>>2]|0;do{if((x|0)==0){S=0}else{F=c[x+12>>2]|0;if((F|0)==(c[x+16>>2]|0)){T=f2[c[(c[x>>2]|0)+36>>2]&255](x)|0}else{T=c[F>>2]|0}if((T|0)!=-1){S=x;break}c[y>>2]=0;S=0}}while(0);y=(S|0)==0;x=c[z>>2]|0;do{if((x|0)==0){R=4416}else{F=c[x+12>>2]|0;if((F|0)==(c[x+16>>2]|0)){U=f2[c[(c[x>>2]|0)+36>>2]&255](x)|0}else{U=c[F>>2]|0}if((U|0)==-1){c[z>>2]=0;R=4416;break}else{if(y){break}else{R=4418;break}}}}while(0);if((R|0)==4416){if(y){R=4418}}if((R|0)==4418){c[j>>2]=c[j>>2]|2}c[b>>2]=S;z=m+4|0;if(((I=c[z>>2]|0,c[z>>2]=I+ -1,I)|0)==0){f$[c[(c[m>>2]|0)+8>>2]&511](m)}z=c[s>>2]|0;c[s>>2]=0;if((z|0)==0){i=d;return}f$[c[t>>2]&511](z);i=d;return}}while(0);d=fc(4)|0;c[d>>2]=53912;dq(d|0,60416,316)}function qz(b,e,f,g,h,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0;p=i;i=i+592|0;q=p|0;r=p+16|0;s=p+32|0;t=p+40|0;u=p+56|0;v=p+72|0;w=p+88|0;x=p+104|0;y=p+112|0;z=p+128|0;A=p+144|0;B=p+160|0;C=p+176|0;D=p+184|0;E=p+584|0;F=E;G=i;i=i+12|0;i=i+7>>3<<3;H=G;I=i;i=i+12|0;i=i+7>>3<<3;J=i;i=i+12|0;i=i+7>>3<<3;K=i;i=i+12|0;i=i+7>>3<<3;L=i;i=i+12|0;i=i+7>>3<<3;M=i;i=i+4|0;i=i+7>>3<<3;c[C>>2]=o;o=D|0;s_(H|0,0,12);N=I;O=J;P=K;Q=L;s_(N|0,0,12);s_(O|0,0,12);s_(P|0,0,12);s_(Q|0,0,12);R=t;S=u;T=v;U=w;V=y;W=z;X=A;Y=B;L5173:do{if(f){Z=s;if((c[137996]|0)!=-1){c[r>>2]=551984;c[r+4>>2]=16;c[r+8>>2]=0;mU(551984,r)}_=(c[137997]|0)-1|0;$=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-$>>2>>>0>_>>>0){aa=c[$+(_<<2)>>2]|0;if((aa|0)==0){break}ab=aa;f0[c[(c[aa>>2]|0)+44>>2]&255](Z,ab);c[E>>2]=c[s>>2];ac=aa;f0[c[(c[ac>>2]|0)+32>>2]&255](t,ab);if((a[P]&1)==0){c[K+4>>2]=0;a[P]=0}else{c[c[K+8>>2]>>2]=0;c[K+4>>2]=0}m0(K);c[P>>2]=c[R>>2];c[P+4>>2]=c[R+4>>2];c[P+8>>2]=c[R+8>>2];s_(R|0,0,12);f0[c[(c[ac>>2]|0)+28>>2]&255](u,ab);if((a[O]&1)==0){c[J+4>>2]=0;a[O]=0}else{c[c[J+8>>2]>>2]=0;c[J+4>>2]=0}m0(J);c[O>>2]=c[S>>2];c[O+4>>2]=c[S+4>>2];c[O+8>>2]=c[S+8>>2];s_(S|0,0,12);ad=aa;ae=f2[c[(c[ad>>2]|0)+12>>2]&255](ab)|0;af=f2[c[(c[ad>>2]|0)+16>>2]&255](ab)|0;f0[c[(c[aa>>2]|0)+20>>2]&255](v,ab);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}mW(G);c[H>>2]=c[T>>2];c[H+4>>2]=c[T+4>>2];c[H+8>>2]=c[T+8>>2];s_(T|0,0,12);f0[c[(c[ac>>2]|0)+24>>2]&255](w,ab);if((a[N]&1)==0){c[I+4>>2]=0;a[N]=0}else{c[c[I+8>>2]>>2]=0;c[I+4>>2]=0}m0(I);c[N>>2]=c[U>>2];c[N+4>>2]=c[U+4>>2];c[N+8>>2]=c[U+8>>2];s_(U|0,0,12);ag=f2[c[(c[ad>>2]|0)+36>>2]&255](ab)|0;ah=af;ai=ae;break L5173}}while(0);Z=fc(4)|0;c[Z>>2]=53912;dq(Z|0,60416,316);return 0}else{Z=x;if((c[137998]|0)!=-1){c[q>>2]=551992;c[q+4>>2]=16;c[q+8>>2]=0;mU(551992,q)}_=(c[137999]|0)-1|0;$=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-$>>2>>>0>_>>>0){ae=c[$+(_<<2)>>2]|0;if((ae|0)==0){break}af=ae;f0[c[(c[ae>>2]|0)+44>>2]&255](Z,af);c[E>>2]=c[x>>2];ab=ae;f0[c[(c[ab>>2]|0)+32>>2]&255](y,af);if((a[P]&1)==0){c[K+4>>2]=0;a[P]=0}else{c[c[K+8>>2]>>2]=0;c[K+4>>2]=0}m0(K);c[P>>2]=c[V>>2];c[P+4>>2]=c[V+4>>2];c[P+8>>2]=c[V+8>>2];s_(V|0,0,12);f0[c[(c[ab>>2]|0)+28>>2]&255](z,af);if((a[O]&1)==0){c[J+4>>2]=0;a[O]=0}else{c[c[J+8>>2]>>2]=0;c[J+4>>2]=0}m0(J);c[O>>2]=c[W>>2];c[O+4>>2]=c[W+4>>2];c[O+8>>2]=c[W+8>>2];s_(W|0,0,12);ad=ae;ac=f2[c[(c[ad>>2]|0)+12>>2]&255](af)|0;aa=f2[c[(c[ad>>2]|0)+16>>2]&255](af)|0;f0[c[(c[ae>>2]|0)+20>>2]&255](A,af);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}mW(G);c[H>>2]=c[X>>2];c[H+4>>2]=c[X+4>>2];c[H+8>>2]=c[X+8>>2];s_(X|0,0,12);f0[c[(c[ab>>2]|0)+24>>2]&255](B,af);if((a[N]&1)==0){c[I+4>>2]=0;a[N]=0}else{c[c[I+8>>2]>>2]=0;c[I+4>>2]=0}m0(I);c[N>>2]=c[Y>>2];c[N+4>>2]=c[Y+4>>2];c[N+8>>2]=c[Y+8>>2];s_(Y|0,0,12);ag=f2[c[(c[ad>>2]|0)+36>>2]&255](af)|0;ah=aa;ai=ac;break L5173}}while(0);Z=fc(4)|0;c[Z>>2]=53912;dq(Z|0,60416,316);return 0}}while(0);Y=m|0;c[n>>2]=c[Y>>2];B=b|0;b=l;X=K+4|0;A=K+8|0;W=J+4|0;z=J+8|0;V=(h&512|0)!=0;h=I+4|0;y=I+8|0;I=L+4|0;x=L+8|0;E=F+3|0;g=G+4|0;q=L|0;U=264;w=o;T=o;o=D+400|0;D=0;v=0;S=ag;ag=e;L5247:while(1){e=c[B>>2]|0;do{if((e|0)==0){aj=1}else{u=c[e+12>>2]|0;if((u|0)==(c[e+16>>2]|0)){ak=f2[c[(c[e>>2]|0)+36>>2]&255](e)|0}else{ak=c[u>>2]|0}if((ak|0)==-1){c[B>>2]=0;aj=1;break}else{aj=(c[B>>2]|0)==0;break}}}while(0);do{if((ag|0)==0){al=4515}else{e=c[ag+12>>2]|0;if((e|0)==(c[ag+16>>2]|0)){am=f2[c[(c[ag>>2]|0)+36>>2]&255](ag)|0}else{am=c[e>>2]|0}if((am|0)==-1){al=4515;break}if(aj){an=ag}else{ao=U;ap=w;aq=T;ar=D;as=ag;al=4780;break L5247}}}while(0);if((al|0)==4515){al=0;if(aj){ao=U;ap=w;aq=T;ar=D;as=0;al=4780;break}else{an=0}}L5269:do{switch(a[F+v|0]|0){case 4:{e=0;u=o;R=T;t=w;s=U;r=an;L5270:while(1){f=c[B>>2]|0;do{if((f|0)==0){at=1}else{Z=c[f+12>>2]|0;if((Z|0)==(c[f+16>>2]|0)){au=f2[c[(c[f>>2]|0)+36>>2]&255](f)|0}else{au=c[Z>>2]|0}if((au|0)==-1){c[B>>2]=0;at=1;break}else{at=(c[B>>2]|0)==0;break}}}while(0);do{if((r|0)==0){al=4693}else{f=c[r+12>>2]|0;if((f|0)==(c[r+16>>2]|0)){av=f2[c[(c[r>>2]|0)+36>>2]&255](r)|0}else{av=c[f>>2]|0}if((av|0)==-1){al=4693;break}if(at){aw=r}else{ax=r;break L5270}}}while(0);if((al|0)==4693){al=0;if(at){ax=0;break}else{aw=0}}f=c[B>>2]|0;Z=c[f+12>>2]|0;if((Z|0)==(c[f+16>>2]|0)){ay=f2[c[(c[f>>2]|0)+36>>2]&255](f)|0}else{ay=c[Z>>2]|0}if(f7[c[(c[b>>2]|0)+12>>2]&127](l,2048,ay)|0){Z=c[n>>2]|0;if((Z|0)==(c[C>>2]|0)){qD(m,n,C);az=c[n>>2]|0}else{az=Z}c[n>>2]=az+4;c[az>>2]=ay;aA=e+1|0;aB=u;aC=R;aD=t;aE=s}else{Z=d[H]|0;if(!((((((Z&1|0)==0?Z>>>1:c[g>>2]|0)|0)==0|(e|0)==0)^1)&(ay|0)==(ah|0))){ax=aw;break}if((R|0)==(u|0)){Z=R-t|0;f=Z>>>0<2147483647?Z<<1:-1;if((s|0)==264){aF=0}else{aF=t}_=sT(aF,f)|0;$=_;if((_|0)==0){al=4709;break L5247}aG=$+(f>>>2<<2)|0;aH=$+(Z>>2<<2)|0;aI=$;aJ=138}else{aG=u;aH=R;aI=t;aJ=s}c[aH>>2]=e;aA=0;aB=aG;aC=aH+4|0;aD=aI;aE=aJ}$=c[B>>2]|0;Z=$+12|0;f=c[Z>>2]|0;if((f|0)==(c[$+16>>2]|0)){_=c[(c[$>>2]|0)+40>>2]|0;f2[_&255]($)|0;e=aA;u=aB;R=aC;t=aD;s=aE;r=aw;continue}else{c[Z>>2]=f+4;e=aA;u=aB;R=aC;t=aD;s=aE;r=aw;continue}}if((t|0)==(R|0)|(e|0)==0){aK=u;aL=R;aM=t;aN=s}else{if((R|0)==(u|0)){r=R-t|0;f=r>>>0<2147483647?r<<1:-1;if((s|0)==264){aO=0}else{aO=t}Z=sT(aO,f)|0;$=Z;if((Z|0)==0){al=4721;break L5247}aP=$+(f>>>2<<2)|0;aQ=$+(r>>2<<2)|0;aR=$;aS=138}else{aP=u;aQ=R;aR=t;aS=s}c[aQ>>2]=e;aK=aP;aL=aQ+4|0;aM=aR;aN=aS}if((S|0)>0){$=c[B>>2]|0;do{if(($|0)==0){aT=1}else{r=c[$+12>>2]|0;if((r|0)==(c[$+16>>2]|0)){aU=f2[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{aU=c[r>>2]|0}if((aU|0)==-1){c[B>>2]=0;aT=1;break}else{aT=(c[B>>2]|0)==0;break}}}while(0);do{if((ax|0)==0){al=4738}else{$=c[ax+12>>2]|0;if(($|0)==(c[ax+16>>2]|0)){aV=f2[c[(c[ax>>2]|0)+36>>2]&255](ax)|0}else{aV=c[$>>2]|0}if((aV|0)==-1){al=4738;break}if(aT){aW=ax}else{al=4744;break L5247}}}while(0);if((al|0)==4738){al=0;if(aT){al=4744;break L5247}else{aW=0}}$=c[B>>2]|0;e=c[$+12>>2]|0;if((e|0)==(c[$+16>>2]|0)){aX=f2[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{aX=c[e>>2]|0}if((aX|0)!=(ai|0)){al=4744;break L5247}e=c[B>>2]|0;$=e+12|0;s=c[$>>2]|0;if((s|0)==(c[e+16>>2]|0)){t=c[(c[e>>2]|0)+40>>2]|0;f2[t&255](e)|0;aY=aW;aZ=S;a_=aW}else{c[$>>2]=s+4;aY=aW;aZ=S;a_=aW}while(1){s=c[B>>2]|0;do{if((s|0)==0){a$=1}else{$=c[s+12>>2]|0;if(($|0)==(c[s+16>>2]|0)){a0=f2[c[(c[s>>2]|0)+36>>2]&255](s)|0}else{a0=c[$>>2]|0}if((a0|0)==-1){c[B>>2]=0;a$=1;break}else{a$=(c[B>>2]|0)==0;break}}}while(0);do{if((aY|0)==0){a1=a_;al=4760}else{s=c[aY+12>>2]|0;if((s|0)==(c[aY+16>>2]|0)){a2=f2[c[(c[aY>>2]|0)+36>>2]&255](aY)|0}else{a2=c[s>>2]|0}if((a2|0)==-1){a1=0;al=4760;break}if(a$){a3=aY;a4=a_}else{al=4767;break L5247}}}while(0);if((al|0)==4760){al=0;if(a$){al=4767;break L5247}else{a3=0;a4=a1}}s=c[B>>2]|0;$=c[s+12>>2]|0;if(($|0)==(c[s+16>>2]|0)){a5=f2[c[(c[s>>2]|0)+36>>2]&255](s)|0}else{a5=c[$>>2]|0}if(!(f7[c[(c[b>>2]|0)+12>>2]&127](l,2048,a5)|0)){al=4767;break L5247}if((c[n>>2]|0)==(c[C>>2]|0)){qD(m,n,C)}$=c[B>>2]|0;s=c[$+12>>2]|0;if((s|0)==(c[$+16>>2]|0)){a6=f2[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{a6=c[s>>2]|0}s=c[n>>2]|0;c[n>>2]=s+4;c[s>>2]=a6;s=aZ-1|0;$=c[B>>2]|0;e=$+12|0;t=c[e>>2]|0;if((t|0)==(c[$+16>>2]|0)){R=c[(c[$>>2]|0)+40>>2]|0;f2[R&255]($)|0}else{c[e>>2]=t+4}if((s|0)>0){aY=a3;aZ=s;a_=a4}else{a7=s;a8=a4;break}}}else{a7=S;a8=ax}if((c[n>>2]|0)==(c[Y>>2]|0)){al=4778;break L5247}else{a9=D;ba=aK;bb=aL;bc=aM;bd=aN;be=a7;bf=a8}break};case 1:{if((v|0)==3){ao=U;ap=w;aq=T;ar=D;as=an;al=4780;break L5247}s=c[B>>2]|0;t=c[s+12>>2]|0;if((t|0)==(c[s+16>>2]|0)){bg=f2[c[(c[s>>2]|0)+36>>2]&255](s)|0}else{bg=c[t>>2]|0}if(!(f7[c[(c[b>>2]|0)+12>>2]&127](l,8192,bg)|0)){al=4565;break L5247}t=c[B>>2]|0;s=t+12|0;e=c[s>>2]|0;if((e|0)==(c[t+16>>2]|0)){bh=f2[c[(c[t>>2]|0)+40>>2]&255](t)|0}else{c[s>>2]=e+4;bh=c[e>>2]|0}e=a[Q]|0;if((e&1)==0){bi=(e&255)>>>1;bj=1}else{bi=c[I>>2]|0;bj=(c[q>>2]&-2)-1|0}if((bi|0)==(bj|0)){nr(L,bj,1,bj,bj,0,0);bk=a[Q]|0}else{bk=e}if((bk&1)==0){a[Q]=(bi<<1)+2&255;bl=I;bm=bi+1|0}else{e=c[x>>2]|0;s=bi+1|0;c[I>>2]=s;bl=e;bm=s}c[bl+(bi<<2)>>2]=bh;c[bl+(bm<<2)>>2]=0;al=4566;break};case 3:{s=a[O]|0;e=s&255;t=(e&1|0)==0?e>>>1:c[W>>2]|0;e=a[P]|0;$=e&255;R=($&1|0)==0?$>>>1:c[X>>2]|0;if((t|0)==(-R|0)){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L5269}$=(t|0)==0;t=c[B>>2]|0;u=c[t+12>>2]|0;r=c[t+16>>2]|0;f=(u|0)==(r|0);if(!($|(R|0)==0)){if(f){R=f2[c[(c[t>>2]|0)+36>>2]&255](t)|0;Z=c[B>>2]|0;bn=R;bo=a[O]|0;bp=Z;bq=c[Z+12>>2]|0;br=c[Z+16>>2]|0}else{bn=c[u>>2]|0;bo=s;bp=t;bq=u;br=r}r=bp+12|0;Z=(bq|0)==(br|0);if((bn|0)==(c[((bo&1)==0?W:c[z>>2]|0)>>2]|0)){if(Z){R=c[(c[bp>>2]|0)+40>>2]|0;f2[R&255](bp)|0}else{c[r>>2]=bq+4}r=d[O]|0;a9=((r&1|0)==0?r>>>1:c[W>>2]|0)>>>0>1?J:D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L5269}if(Z){bs=f2[c[(c[bp>>2]|0)+36>>2]&255](bp)|0}else{bs=c[bq>>2]|0}if((bs|0)!=(c[((a[P]&1)==0?X:c[A>>2]|0)>>2]|0)){al=4638;break L5247}Z=c[B>>2]|0;r=Z+12|0;R=c[r>>2]|0;if((R|0)==(c[Z+16>>2]|0)){_=c[(c[Z>>2]|0)+40>>2]|0;f2[_&255](Z)|0}else{c[r>>2]=R+4}a[k]=1;R=d[P]|0;a9=((R&1|0)==0?R>>>1:c[X>>2]|0)>>>0>1?K:D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L5269}if($){if(f){$=f2[c[(c[t>>2]|0)+36>>2]&255](t)|0;bt=$;bu=a[P]|0}else{bt=c[u>>2]|0;bu=e}if((bt|0)!=(c[((bu&1)==0?X:c[A>>2]|0)>>2]|0)){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L5269}e=c[B>>2]|0;$=e+12|0;R=c[$>>2]|0;if((R|0)==(c[e+16>>2]|0)){r=c[(c[e>>2]|0)+40>>2]|0;f2[r&255](e)|0}else{c[$>>2]=R+4}a[k]=1;R=d[P]|0;a9=((R&1|0)==0?R>>>1:c[X>>2]|0)>>>0>1?K:D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L5269}if(f){f=f2[c[(c[t>>2]|0)+36>>2]&255](t)|0;bv=f;bw=a[O]|0}else{bv=c[u>>2]|0;bw=s}if((bv|0)!=(c[((bw&1)==0?W:c[z>>2]|0)>>2]|0)){a[k]=1;a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L5269}s=c[B>>2]|0;u=s+12|0;f=c[u>>2]|0;if((f|0)==(c[s+16>>2]|0)){t=c[(c[s>>2]|0)+40>>2]|0;f2[t&255](s)|0}else{c[u>>2]=f+4}f=d[O]|0;a9=((f&1|0)==0?f>>>1:c[W>>2]|0)>>>0>1?J:D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break};case 0:{al=4566;break};case 2:{if(!((D|0)!=0|v>>>0<2)){if((v|0)==2){bx=(a[E]|0)!=0}else{bx=0}if(!(V|bx)){a9=0;ba=o;bb=T;bc=w;bd=U;be=S;bf=an;break L5269}}f=a[N]|0;u=c[y>>2]|0;s=(f&1)==0?h:u;L5479:do{if((v|0)==0){by=s;bz=f;bA=u}else{if((d[F+(v-1)|0]|0)>=2){by=s;bz=f;bA=u;break}t=f&255;L5482:do{if((((t&1|0)==0?t>>>1:c[h>>2]|0)|0)==0){bB=f;bC=s;bD=u}else{R=s;while(1){if(!(f7[c[(c[b>>2]|0)+12>>2]&127](l,8192,c[R>>2]|0)|0)){break}$=R+4|0;e=a[N]|0;r=c[y>>2]|0;Z=e&255;if(($|0)==(((e&1)==0?h:r)+(((Z&1|0)==0?Z>>>1:c[h>>2]|0)<<2)|0)){bB=e;bC=$;bD=r;break L5482}else{R=$}}bB=a[N]|0;bC=R;bD=c[y>>2]|0}}while(0);t=(bB&1)==0?h:bD;$=bC-t>>2;r=a[Q]|0;e=r&255;Z=(e&1|0)==0?e>>>1:c[I>>2]|0;if($>>>0>Z>>>0){by=t;bz=bB;bA=bD;break}e=(r&1)==0?I:c[x>>2]|0;r=e+(Z<<2)|0;if(($|0)==0){by=bC;bz=bB;bA=bD;break}_=e+(Z-$<<2)|0;$=t;while(1){if((c[_>>2]|0)!=(c[$>>2]|0)){by=t;bz=bB;bA=bD;break L5479}Z=_+4|0;if((Z|0)==(r|0)){by=bC;bz=bB;bA=bD;break}else{_=Z;$=$+4|0}}}}while(0);s=bz&255;L5495:do{if((by|0)==(((bz&1)==0?h:bA)+(((s&1|0)==0?s>>>1:c[h>>2]|0)<<2)|0)){bE=by;bF=an}else{u=an;f=by;$=an;while(1){_=c[B>>2]|0;do{if((_|0)==0){bG=1}else{r=c[_+12>>2]|0;if((r|0)==(c[_+16>>2]|0)){bH=f2[c[(c[_>>2]|0)+36>>2]&255](_)|0}else{bH=c[r>>2]|0}if((bH|0)==-1){c[B>>2]=0;bG=1;break}else{bG=(c[B>>2]|0)==0;break}}}while(0);do{if((u|0)==0){bI=$;al=4668}else{_=c[u+12>>2]|0;if((_|0)==(c[u+16>>2]|0)){bJ=f2[c[(c[u>>2]|0)+36>>2]&255](u)|0}else{bJ=c[_>>2]|0}if((bJ|0)==-1){bI=0;al=4668;break}if(bG){bK=u;bL=$}else{bE=f;bF=$;break L5495}}}while(0);if((al|0)==4668){al=0;if(bG){bE=f;bF=bI;break L5495}else{bK=0;bL=bI}}_=c[B>>2]|0;R=c[_+12>>2]|0;if((R|0)==(c[_+16>>2]|0)){bM=f2[c[(c[_>>2]|0)+36>>2]&255](_)|0}else{bM=c[R>>2]|0}if((bM|0)!=(c[f>>2]|0)){bE=f;bF=bL;break L5495}R=c[B>>2]|0;_=R+12|0;r=c[_>>2]|0;if((r|0)==(c[R+16>>2]|0)){t=c[(c[R>>2]|0)+40>>2]|0;f2[t&255](R)|0}else{c[_>>2]=r+4}r=f+4|0;_=a[N]|0;R=_&255;if((r|0)==(((_&1)==0?h:c[y>>2]|0)+(((R&1|0)==0?R>>>1:c[h>>2]|0)<<2)|0)){bE=r;bF=bL;break}else{u=bK;f=r;$=bL}}}}while(0);if(!V){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=bF;break L5269}s=a[N]|0;$=s&255;if((bE|0)==(((s&1)==0?h:c[y>>2]|0)+((($&1|0)==0?$>>>1:c[h>>2]|0)<<2)|0)){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=bF}else{al=4680;break L5247}break};default:{a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=an}}}while(0);L5529:do{if((al|0)==4566){al=0;if((v|0)==3){ao=U;ap=w;aq=T;ar=D;as=an;al=4780;break L5247}else{bN=an;bO=an}while(1){$=c[B>>2]|0;do{if(($|0)==0){bP=1}else{s=c[$+12>>2]|0;if((s|0)==(c[$+16>>2]|0)){bQ=f2[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{bQ=c[s>>2]|0}if((bQ|0)==-1){c[B>>2]=0;bP=1;break}else{bP=(c[B>>2]|0)==0;break}}}while(0);do{if((bN|0)==0){bR=bO;al=4579}else{$=c[bN+12>>2]|0;if(($|0)==(c[bN+16>>2]|0)){bS=f2[c[(c[bN>>2]|0)+36>>2]&255](bN)|0}else{bS=c[$>>2]|0}if((bS|0)==-1){bR=0;al=4579;break}if(bP){bT=bN;bU=bO}else{a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=bO;break L5529}}}while(0);if((al|0)==4579){al=0;if(bP){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=bR;break L5529}else{bT=0;bU=bR}}$=c[B>>2]|0;s=c[$+12>>2]|0;if((s|0)==(c[$+16>>2]|0)){bV=f2[c[(c[$>>2]|0)+36>>2]&255]($)|0}else{bV=c[s>>2]|0}if(!(f7[c[(c[b>>2]|0)+12>>2]&127](l,8192,bV)|0)){a9=D;ba=o;bb=T;bc=w;bd=U;be=S;bf=bU;break L5529}s=c[B>>2]|0;$=s+12|0;f=c[$>>2]|0;if((f|0)==(c[s+16>>2]|0)){bW=f2[c[(c[s>>2]|0)+40>>2]&255](s)|0}else{c[$>>2]=f+4;bW=c[f>>2]|0}f=a[Q]|0;if((f&1)==0){bX=(f&255)>>>1;bY=1}else{bX=c[I>>2]|0;bY=(c[q>>2]&-2)-1|0}if((bX|0)==(bY|0)){nr(L,bY,1,bY,bY,0,0);bZ=a[Q]|0}else{bZ=f}if((bZ&1)==0){a[Q]=(bX<<1)+2&255;b_=I;b$=bX+1|0}else{f=c[x>>2]|0;$=bX+1|0;c[I>>2]=$;b_=f;b$=$}c[b_+(bX<<2)>>2]=bW;c[b_+(b$<<2)>>2]=0;bN=bT;bO=bU}}}while(0);$=v+1|0;if($>>>0<4){U=bd;w=bc;T=bb;o=ba;D=a9;v=$;S=be;ag=bf}else{ao=bd;ap=bc;aq=bb;ar=a9;as=bf;al=4780;break}}L5576:do{if((al|0)==4680){c[j>>2]=c[j>>2]|4;b0=0;b1=w;b2=U}else if((al|0)==4565){c[j>>2]=c[j>>2]|4;b0=0;b1=w;b2=U}else if((al|0)==4638){c[j>>2]=c[j>>2]|4;b0=0;b1=w;b2=U}else if((al|0)==4709){bf=fc(4)|0;c[bf>>2]=53880;dq(bf|0,60400,240);return 0}else if((al|0)==4721){bf=fc(4)|0;c[bf>>2]=53880;dq(bf|0,60400,240);return 0}else if((al|0)==4744){c[j>>2]=c[j>>2]|4;b0=0;b1=aM;b2=aN}else if((al|0)==4767){c[j>>2]=c[j>>2]|4;b0=0;b1=aM;b2=aN}else if((al|0)==4778){c[j>>2]=c[j>>2]|4;b0=0;b1=aM;b2=aN}else if((al|0)==4780){L5588:do{if((ar|0)!=0){bf=ar;a9=ar+4|0;bb=ar+8|0;bc=1;bd=as;L5590:while(1){ag=d[bf]|0;if((ag&1|0)==0){b3=ag>>>1}else{b3=c[a9>>2]|0}if(bc>>>0>=b3>>>0){break L5588}ag=c[B>>2]|0;do{if((ag|0)==0){b4=1}else{be=c[ag+12>>2]|0;if((be|0)==(c[ag+16>>2]|0)){b5=f2[c[(c[ag>>2]|0)+36>>2]&255](ag)|0}else{b5=c[be>>2]|0}if((b5|0)==-1){c[B>>2]=0;b4=1;break}else{b4=(c[B>>2]|0)==0;break}}}while(0);do{if((bd|0)==0){al=4798}else{ag=c[bd+12>>2]|0;if((ag|0)==(c[bd+16>>2]|0)){b6=f2[c[(c[bd>>2]|0)+36>>2]&255](bd)|0}else{b6=c[ag>>2]|0}if((b6|0)==-1){al=4798;break}if(b4){b7=bd}else{break L5590}}}while(0);if((al|0)==4798){al=0;if(b4){break}else{b7=0}}ag=c[B>>2]|0;be=c[ag+12>>2]|0;if((be|0)==(c[ag+16>>2]|0)){b8=f2[c[(c[ag>>2]|0)+36>>2]&255](ag)|0}else{b8=c[be>>2]|0}if((a[bf]&1)==0){b9=a9}else{b9=c[bb>>2]|0}if((b8|0)!=(c[b9+(bc<<2)>>2]|0)){break}be=bc+1|0;ag=c[B>>2]|0;S=ag+12|0;v=c[S>>2]|0;if((v|0)==(c[ag+16>>2]|0)){D=c[(c[ag>>2]|0)+40>>2]|0;f2[D&255](ag)|0;bc=be;bd=b7;continue}else{c[S>>2]=v+4;bc=be;bd=b7;continue}}c[j>>2]=c[j>>2]|4;b0=0;b1=ap;b2=ao;break L5576}}while(0);if((ap|0)==(aq|0)){b0=1;b1=aq;b2=ao;break}c[M>>2]=0;oe(G,ap,aq,M);if((c[M>>2]|0)==0){b0=1;b1=ap;b2=ao;break}c[j>>2]=c[j>>2]|4;b0=0;b1=ap;b2=ao}}while(0);do{if((a[Q]&1)!=0){ao=c[x>>2]|0;if((ao|0)==0){break}sS(ao)}}while(0);do{if((a[P]&1)!=0){x=c[A>>2]|0;if((x|0)==0){break}sS(x)}}while(0);do{if((a[O]&1)!=0){A=c[z>>2]|0;if((A|0)==0){break}sS(A)}}while(0);do{if((a[N]&1)!=0){z=c[y>>2]|0;if((z|0)==0){break}sS(z)}}while(0);do{if((a[H]&1)!=0){y=c[G+8>>2]|0;if((y|0)==0){break}sS(y)}}while(0);if((b1|0)==0){i=p;return b0|0}f$[b2&511](b1);i=p;return b0|0}function qA(a){a=a|0;return}function qB(a){a=a|0;if((a|0)==0){return}sS(a);return}function qC(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;d=i;i=i+440|0;l=e;e=i;i=i+4|0;i=i+7>>3<<3;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+416|0;o=d+424|0;p=d+432|0;q=n|0;c[q>>2]=m;r=n+4|0;c[r>>2]=264;s=m+400|0;m=c[h+28>>2]|0;t=m;u=m+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;if((c[137880]|0)!=-1){c[l>>2]=551520;c[l+4>>2]=16;c[l+8>>2]=0;mU(551520,l)}l=(c[137881]|0)-1|0;u=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-u>>2>>>0>l>>>0){v=c[u+(l<<2)>>2]|0;if((v|0)==0){break}w=v;a[p]=0;x=f|0;y=c[x>>2]|0;do{if(qz(e,y,g,t,c[h+4>>2]|0,j,p,w,n,o,s)|0){z=k;if((a[z]&1)==0){c[k+4>>2]=0;a[z]=0}else{c[c[k+8>>2]>>2]=0;c[k+4>>2]=0}A=v;if((a[p]&1)!=0){B=gj[c[(c[A>>2]|0)+44>>2]&127](w,45)|0;C=a[z]|0;if((C&1)==0){D=(C&255)>>>1;E=1}else{D=c[k+4>>2]|0;E=(c[k>>2]&-2)-1|0}if((D|0)==(E|0)){nr(k,E,1,E,E,0,0);F=a[z]|0}else{F=C}if((F&1)==0){a[z]=(D<<1)+2&255;G=k+4|0;H=D+1|0}else{C=c[k+8>>2]|0;J=D+1|0;c[k+4>>2]=J;G=C;H=J}c[G+(D<<2)>>2]=B;c[G+(H<<2)>>2]=0}B=gj[c[(c[A>>2]|0)+44>>2]&127](w,48)|0;A=c[o>>2]|0;J=A-4|0;C=c[q>>2]|0;while(1){if(C>>>0>=J>>>0){break}if((c[C>>2]|0)==(B|0)){C=C+4|0}else{break}}B=C;K=a[z]|0;L=K&255;if((L&1|0)==0){M=L>>>1}else{M=c[k+4>>2]|0}if((K&1)==0){N=1;O=K}else{K=c[k>>2]|0;N=(K&-2)-1|0;O=K&255}K=A-B>>2;if((K|0)==0){break}if((N-M|0)>>>0<K>>>0){nr(k,N,M+K-N|0,M,M,0,0);P=a[z]|0}else{P=O}if((P&1)==0){Q=k+4|0}else{Q=c[k+8>>2]|0}L=Q+(M<<2)|0;if((C|0)==(A|0)){R=L}else{S=((J+(-B|0)|0)>>>2)+1|0;B=C;T=L;while(1){c[T>>2]=c[B>>2];L=B+4|0;if((L|0)==(A|0)){break}B=L;T=T+4|0}R=Q+(S+M<<2)|0}c[R>>2]=0;T=M+K|0;if((a[z]&1)==0){a[z]=T<<1&255;break}else{c[k+4>>2]=T;break}}}while(0);w=e|0;v=c[w>>2]|0;do{if((v|0)==0){U=0}else{T=c[v+12>>2]|0;if((T|0)==(c[v+16>>2]|0)){V=f2[c[(c[v>>2]|0)+36>>2]&255](v)|0}else{V=c[T>>2]|0}if((V|0)!=-1){U=v;break}c[w>>2]=0;U=0}}while(0);w=(U|0)==0;do{if((y|0)==0){W=4900}else{v=c[y+12>>2]|0;if((v|0)==(c[y+16>>2]|0)){X=f2[c[(c[y>>2]|0)+36>>2]&255](y)|0}else{X=c[v>>2]|0}if((X|0)==-1){c[x>>2]=0;W=4900;break}else{if(w){break}else{W=4902;break}}}}while(0);if((W|0)==4900){if(w){W=4902}}if((W|0)==4902){c[j>>2]=c[j>>2]|2}c[b>>2]=U;x=m+4|0;if(((I=c[x>>2]|0,c[x>>2]=I+ -1,I)|0)==0){f$[c[(c[m>>2]|0)+8>>2]&511](m)}x=c[q>>2]|0;c[q>>2]=0;if((x|0)==0){i=d;return}f$[c[r>>2]&511](x);i=d;return}}while(0);d=fc(4)|0;c[d>>2]=53912;dq(d|0,60416,316)}function qD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a+4|0;f=(c[e>>2]|0)!=264;g=a|0;a=c[g>>2]|0;h=a;i=(c[d>>2]|0)-h|0;j=i>>>0<2147483647?i<<1:-1;i=(c[b>>2]|0)-h>>2;if(f){k=a}else{k=0}a=sT(k,j)|0;k=a;if((a|0)==0){a=fc(4)|0;c[a>>2]=53880;dq(a|0,60400,240)}do{if(f){c[g>>2]=k;l=k}else{a=c[g>>2]|0;c[g>>2]=k;if((a|0)==0){l=k;break}f$[c[e>>2]&511](a);l=c[g>>2]|0}}while(0);c[e>>2]=138;c[b>>2]=l+(i<<2);c[d>>2]=(c[g>>2]|0)+(j>>>2<<2);return}function qE(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=+l;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+272|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=e|0;n=e+120|0;o=e+232|0;p=e+240|0;q=e+248|0;r=e+256|0;s=r;t=i;i=i+12|0;i=i+7>>3<<3;u=t;v=i;i=i+12|0;i=i+7>>3<<3;w=v;x=i;i=i+4|0;i=i+7>>3<<3;y=i;i=i+100|0;i=i+7>>3<<3;z=i;i=i+4|0;i=i+7>>3<<3;A=i;i=i+4|0;i=i+7>>3<<3;B=e+16|0;c[n>>2]=B;C=e+128|0;D=b5(B|0,100,43448,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;do{if(D>>>0>99){do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);E=o0(n,c[137522]|0,43448,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;F=c[n>>2]|0;if((F|0)==0){G=fc(4)|0;c[G>>2]=53880;dq(G|0,60400,240)}G=sR(E)|0;if((G|0)!=0){H=G;J=E;K=F;L=G;break}G=fc(4)|0;c[G>>2]=53880;dq(G|0,60400,240)}else{H=C;J=D;K=0;L=0}}while(0);D=c[j+28>>2]|0;C=D;B=D+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[137882]|0)!=-1){c[m>>2]=551528;c[m+4>>2]=16;c[m+8>>2]=0;mU(551528,m)}m=(c[137883]|0)-1|0;B=c[D+8>>2]|0;do{if((c[D+12>>2]|0)-B>>2>>>0>m>>>0){G=c[B+(m<<2)>>2]|0;if((G|0)==0){break}F=G;E=c[n>>2]|0;M=E+J|0;N=c[(c[G>>2]|0)+32>>2]|0;gn[N&31](F,E,M,H)|0;if((J|0)==0){O=0}else{O=(a[c[n>>2]|0]|0)==45}s_(s|0,0,12);s_(u|0,0,12);s_(w|0,0,12);qF(g,O,C,o,p,q,r,t,v,x);M=y|0;E=c[x>>2]|0;if((J|0)>(E|0)){N=d[w]|0;if((N&1|0)==0){P=N>>>1}else{P=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){Q=N>>>1}else{Q=c[t+4>>2]|0}R=P+(J-E<<1|1)+Q|0}else{N=d[w]|0;if((N&1|0)==0){S=N>>>1}else{S=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){T=N>>>1}else{T=c[t+4>>2]|0}R=S+2+T|0}N=R+E|0;do{if(N>>>0>100){G=sR(N)|0;if((G|0)!=0){U=G;V=G;break}G=fc(4)|0;c[G>>2]=53880;dq(G|0,60400,240)}else{U=M;V=0}}while(0);qG(U,z,A,c[j+4>>2]|0,H,H+J|0,F,O,o,a[p]|0,a[q]|0,r,t,v,E);oX(b,c[f>>2]|0,U,c[z>>2]|0,c[A>>2]|0,j,k);if((V|0)!=0){sS(V)}do{if((a[w]&1)!=0){M=c[v+8>>2]|0;if((M|0)==0){break}sS(M)}}while(0);do{if((a[u]&1)!=0){E=c[t+8>>2]|0;if((E|0)==0){break}sS(E)}}while(0);do{if((a[s]&1)!=0){E=c[r+8>>2]|0;if((E|0)==0){break}sS(E)}}while(0);E=D+4|0;if(((I=c[E>>2]|0,c[E>>2]=I+ -1,I)|0)==0){f$[c[(c[D>>2]|0)+8>>2]&511](D)}if((L|0)!=0){sS(L)}if((K|0)==0){i=e;return}sS(K);i=e;return}}while(0);e=fc(4)|0;c[e>>2]=53912;dq(e|0,60416,316)}function qF(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;n=i;i=i+40|0;o=n|0;p=n+16|0;q=n+32|0;r=q;s=i;i=i+12|0;i=i+7>>3<<3;t=s;u=i;i=i+4|0;i=i+7>>3<<3;v=u;w=i;i=i+12|0;i=i+7>>3<<3;x=w;y=i;i=i+12|0;i=i+7>>3<<3;z=y;A=i;i=i+12|0;i=i+7>>3<<3;B=A;D=i;i=i+4|0;i=i+7>>3<<3;E=D;F=i;i=i+12|0;i=i+7>>3<<3;G=F;H=i;i=i+4|0;i=i+7>>3<<3;I=H;J=i;i=i+12|0;i=i+7>>3<<3;K=J;L=i;i=i+12|0;i=i+7>>3<<3;M=L;N=i;i=i+12|0;i=i+7>>3<<3;O=N;if(b){if((c[138e3]|0)!=-1){c[p>>2]=552e3;c[p+4>>2]=16;c[p+8>>2]=0;mU(552e3,p)}p=(c[138001]|0)-1|0;b=c[e+8>>2]|0;if((c[e+12>>2]|0)-b>>2>>>0<=p>>>0){P=fc(4)|0;Q=P;c[Q>>2]=53912;dq(P|0,60416,316)}R=c[b+(p<<2)>>2]|0;if((R|0)==0){P=fc(4)|0;Q=P;c[Q>>2]=53912;dq(P|0,60416,316)}P=R;Q=c[R>>2]|0;if(d){f0[c[Q+44>>2]&255](r,P);r=f;C=c[q>>2]|0;a[r]=C&255;C=C>>8;a[r+1|0]=C&255;C=C>>8;a[r+2|0]=C&255;C=C>>8;a[r+3|0]=C&255;f0[c[(c[R>>2]|0)+32>>2]&255](s,P);s=l;if((a[s]&1)==0){a[l+1|0]=0;a[s]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}mW(l);c[s>>2]=c[t>>2];c[s+4>>2]=c[t+4>>2];c[s+8>>2]=c[t+8>>2];s_(t|0,0,12)}else{f0[c[Q+40>>2]&255](v,P);v=f;C=c[u>>2]|0;a[v]=C&255;C=C>>8;a[v+1|0]=C&255;C=C>>8;a[v+2|0]=C&255;C=C>>8;a[v+3|0]=C&255;f0[c[(c[R>>2]|0)+28>>2]&255](w,P);w=l;if((a[w]&1)==0){a[l+1|0]=0;a[w]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}mW(l);c[w>>2]=c[x>>2];c[w+4>>2]=c[x+4>>2];c[w+8>>2]=c[x+8>>2];s_(x|0,0,12)}x=R;a[g]=f2[c[(c[x>>2]|0)+12>>2]&255](P)|0;a[h]=f2[c[(c[x>>2]|0)+16>>2]&255](P)|0;x=R;f0[c[(c[x>>2]|0)+20>>2]&255](y,P);y=j;if((a[y]&1)==0){a[j+1|0]=0;a[y]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}mW(j);c[y>>2]=c[z>>2];c[y+4>>2]=c[z+4>>2];c[y+8>>2]=c[z+8>>2];s_(z|0,0,12);f0[c[(c[x>>2]|0)+24>>2]&255](A,P);A=k;if((a[A]&1)==0){a[k+1|0]=0;a[A]=0}else{a[c[k+8>>2]|0]=0;c[k+4>>2]=0}mW(k);c[A>>2]=c[B>>2];c[A+4>>2]=c[B+4>>2];c[A+8>>2]=c[B+8>>2];s_(B|0,0,12);S=f2[c[(c[R>>2]|0)+36>>2]&255](P)|0;c[m>>2]=S;i=n;return}else{if((c[138002]|0)!=-1){c[o>>2]=552008;c[o+4>>2]=16;c[o+8>>2]=0;mU(552008,o)}o=(c[138003]|0)-1|0;P=c[e+8>>2]|0;if((c[e+12>>2]|0)-P>>2>>>0<=o>>>0){T=fc(4)|0;U=T;c[U>>2]=53912;dq(T|0,60416,316)}e=c[P+(o<<2)>>2]|0;if((e|0)==0){T=fc(4)|0;U=T;c[U>>2]=53912;dq(T|0,60416,316)}T=e;U=c[e>>2]|0;if(d){f0[c[U+44>>2]&255](E,T);E=f;C=c[D>>2]|0;a[E]=C&255;C=C>>8;a[E+1|0]=C&255;C=C>>8;a[E+2|0]=C&255;C=C>>8;a[E+3|0]=C&255;f0[c[(c[e>>2]|0)+32>>2]&255](F,T);F=l;if((a[F]&1)==0){a[l+1|0]=0;a[F]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}mW(l);c[F>>2]=c[G>>2];c[F+4>>2]=c[G+4>>2];c[F+8>>2]=c[G+8>>2];s_(G|0,0,12)}else{f0[c[U+40>>2]&255](I,T);I=f;C=c[H>>2]|0;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;f0[c[(c[e>>2]|0)+28>>2]&255](J,T);J=l;if((a[J]&1)==0){a[l+1|0]=0;a[J]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}mW(l);c[J>>2]=c[K>>2];c[J+4>>2]=c[K+4>>2];c[J+8>>2]=c[K+8>>2];s_(K|0,0,12)}K=e;a[g]=f2[c[(c[K>>2]|0)+12>>2]&255](T)|0;a[h]=f2[c[(c[K>>2]|0)+16>>2]&255](T)|0;K=e;f0[c[(c[K>>2]|0)+20>>2]&255](L,T);L=j;if((a[L]&1)==0){a[j+1|0]=0;a[L]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}mW(j);c[L>>2]=c[M>>2];c[L+4>>2]=c[M+4>>2];c[L+8>>2]=c[M+8>>2];s_(M|0,0,12);f0[c[(c[K>>2]|0)+24>>2]&255](N,T);N=k;if((a[N]&1)==0){a[k+1|0]=0;a[N]=0}else{a[c[k+8>>2]|0]=0;c[k+4>>2]=0}mW(k);c[N>>2]=c[O>>2];c[N+4>>2]=c[O+4>>2];c[N+8>>2]=c[O+8>>2];s_(O|0,0,12);S=f2[c[(c[e>>2]|0)+36>>2]&255](T)|0;c[m>>2]=S;i=n;return}}function qG(d,e,f,g,h,i,j,k,l,m,n,o,p,q,r){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;c[f>>2]=d;s=j;t=q;u=q+1|0;v=q+8|0;w=q+4|0;q=p;x=(g&512|0)==0;y=p+1|0;z=p+4|0;A=p+8|0;p=j+8|0;B=(r|0)>0;C=o;D=o+1|0;E=o+8|0;F=o+4|0;o=-r|0;G=r-1|0;H=(G|0)>0;I=h;h=0;while(1){L5925:do{switch(a[l+h|0]|0){case 4:{J=c[f>>2]|0;K=k?I+1|0:I;L=K;while(1){if(L>>>0>=i>>>0){break}M=a[L]|0;if(M<<24>>24<=-1){break}if((b[(c[p>>2]|0)+(M<<24>>24<<1)>>1]&2048)==0){break}else{L=L+1|0}}M=L;if(B){if(L>>>0>K>>>0){N=K+(-M|0)|0;M=N>>>0<o>>>0?o:N;N=M+r|0;O=L-1|0;P=a[O]|0;c[f>>2]=J+1;a[J]=P;if(O>>>0>K>>>0&H){P=O;O=G;while(1){Q=c[f>>2]|0;R=P-1|0;S=a[R]|0;c[f>>2]=Q+1;a[Q]=S;S=O-1|0;Q=(S|0)>0;if(R>>>0>K>>>0&Q){P=R;O=S}else{T=Q;break}}}else{T=H}O=L+M|0;if(T){U=N;V=O;W=5114}else{X=0;Y=N;Z=O}}else{U=r;V=L;W=5114}if((W|0)==5114){W=0;X=gj[c[(c[s>>2]|0)+28>>2]&127](j,48)|0;Y=U;Z=V}O=c[f>>2]|0;c[f>>2]=O+1;if((Y|0)>0){P=Y;Q=O;while(1){a[Q]=X;S=P-1|0;R=c[f>>2]|0;c[f>>2]=R+1;if((S|0)>0){P=S;Q=R}else{_=R;break}}}else{_=O}a[_]=m;$=Z}else{$=L}if(($|0)==(K|0)){Q=gj[c[(c[s>>2]|0)+28>>2]&127](j,48)|0;P=c[f>>2]|0;c[f>>2]=P+1;a[P]=Q}else{Q=a[C]|0;P=Q&255;if((P&1|0)==0){aa=P>>>1}else{aa=c[F>>2]|0}if((aa|0)==0){ab=$;ac=0;ad=0;ae=-1}else{if((Q&1)==0){af=D}else{af=c[E>>2]|0}ab=$;ac=0;ad=0;ae=a[af]|0}while(1){do{if((ac|0)==(ae|0)){Q=c[f>>2]|0;c[f>>2]=Q+1;a[Q]=n;Q=ad+1|0;P=a[C]|0;N=P&255;if((N&1|0)==0){ag=N>>>1}else{ag=c[F>>2]|0}if(Q>>>0>=ag>>>0){ah=ae;ai=Q;aj=0;break}N=(P&1)==0;if(N){ak=D}else{ak=c[E>>2]|0}if((a[ak+Q|0]|0)==127){ah=-1;ai=Q;aj=0;break}if(N){al=D}else{al=c[E>>2]|0}ah=a[al+Q|0]|0;ai=Q;aj=0}else{ah=ae;ai=ad;aj=ac}}while(0);Q=ab-1|0;N=a[Q]|0;P=c[f>>2]|0;c[f>>2]=P+1;a[P]=N;if((Q|0)==(K|0)){break}else{ab=Q;ac=aj+1|0;ad=ai;ae=ah}}}L=c[f>>2]|0;if((J|0)==(L|0)){am=K;break L5925}O=L-1|0;if(J>>>0<O>>>0){an=J;ao=O}else{am=K;break L5925}while(1){O=a[an]|0;a[an]=a[ao]|0;a[ao]=O;O=an+1|0;L=ao-1|0;if(O>>>0<L>>>0){an=O;ao=L}else{am=K;break}}break};case 0:{c[e>>2]=c[f>>2];am=I;break};case 1:{c[e>>2]=c[f>>2];K=gj[c[(c[s>>2]|0)+28>>2]&127](j,32)|0;J=c[f>>2]|0;c[f>>2]=J+1;a[J]=K;am=I;break};case 3:{K=a[t]|0;J=K&255;if((J&1|0)==0){ap=J>>>1}else{ap=c[w>>2]|0}if((ap|0)==0){am=I;break L5925}if((K&1)==0){aq=u}else{aq=c[v>>2]|0}K=a[aq]|0;J=c[f>>2]|0;c[f>>2]=J+1;a[J]=K;am=I;break};case 2:{K=a[q]|0;J=K&255;L=(J&1|0)==0;if(L){ar=J>>>1}else{ar=c[z>>2]|0}if((ar|0)==0|x){am=I;break L5925}if((K&1)==0){as=y}else{as=c[A>>2]|0}if(L){at=J>>>1}else{at=c[z>>2]|0}J=as+at|0;L=c[f>>2]|0;if((at|0)==0){au=L}else{K=as;O=L;while(1){a[O]=a[K]|0;Q=K+1|0;if((Q|0)==(J|0)){break}else{K=Q;O=O+1|0}}au=L+at|0}c[f>>2]=au;am=I;break};default:{am=I}}}while(0);O=h+1|0;if(O>>>0<4){I=am;h=O}else{break}}h=a[t]|0;t=h&255;am=(t&1|0)==0;if(am){av=t>>>1}else{av=c[w>>2]|0}if(av>>>0>1){if((h&1)==0){aw=u}else{aw=c[v>>2]|0}if(am){ax=t>>>1}else{ax=c[w>>2]|0}w=aw+ax|0;t=c[f>>2]|0;if((ax|0)==1){ay=t}else{am=ax-1|0;ax=t;v=aw+1|0;while(1){a[ax]=a[v]|0;aw=v+1|0;if((aw|0)==(w|0)){break}else{ax=ax+1|0;v=aw}}ay=t+am|0}c[f>>2]=ay}ay=g&176;if((ay|0)==32){c[e>>2]=c[f>>2];return}else if((ay|0)==16){return}else{c[e>>2]=d;return}}function qH(a){a=a|0;return}function qI(a){a=a|0;if((a|0)==0){return}sS(a);return}function qJ(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+56|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=e|0;m=e+16|0;n=e+24|0;o=e+32|0;p=e+40|0;q=p;r=i;i=i+12|0;i=i+7>>3<<3;s=r;t=i;i=i+12|0;i=i+7>>3<<3;u=t;v=i;i=i+4|0;i=i+7>>3<<3;w=i;i=i+100|0;i=i+7>>3<<3;x=i;i=i+4|0;i=i+7>>3<<3;y=i;i=i+4|0;i=i+7>>3<<3;z=c[h+28>>2]|0;A=z;B=z+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[137882]|0)!=-1){c[l>>2]=551528;c[l+4>>2]=16;c[l+8>>2]=0;mU(551528,l)}l=(c[137883]|0)-1|0;B=c[z+8>>2]|0;do{if((c[z+12>>2]|0)-B>>2>>>0>l>>>0){C=c[B+(l<<2)>>2]|0;if((C|0)==0){break}D=C;E=k;F=k;G=a[F]|0;H=G&255;if((H&1|0)==0){J=H>>>1}else{J=c[k+4>>2]|0}if((J|0)==0){K=0}else{if((G&1)==0){L=E+1|0}else{L=c[k+8>>2]|0}G=a[L]|0;K=G<<24>>24==(gj[c[(c[C>>2]|0)+28>>2]&127](D,45)|0)<<24>>24}s_(q|0,0,12);s_(s|0,0,12);s_(u|0,0,12);qF(g,K,A,m,n,o,p,r,t,v);C=w|0;G=a[F]|0;F=G&255;H=(F&1|0)==0;if(H){M=F>>>1}else{M=c[k+4>>2]|0}N=c[v>>2]|0;if((M|0)>(N|0)){if(H){O=F>>>1}else{O=c[k+4>>2]|0}P=d[u]|0;if((P&1|0)==0){Q=P>>>1}else{Q=c[t+4>>2]|0}P=d[s]|0;if((P&1|0)==0){R=P>>>1}else{R=c[r+4>>2]|0}S=Q+(O-N<<1|1)+R|0}else{P=d[u]|0;if((P&1|0)==0){T=P>>>1}else{T=c[t+4>>2]|0}P=d[s]|0;if((P&1|0)==0){U=P>>>1}else{U=c[r+4>>2]|0}S=T+2+U|0}P=S+N|0;do{if(P>>>0>100){V=sR(P)|0;if((V|0)!=0){W=V;X=V;break}V=fc(4)|0;c[V>>2]=53880;dq(V|0,60400,240)}else{W=C;X=0}}while(0);if((G&1)==0){Y=E+1|0}else{Y=c[k+8>>2]|0}if(H){Z=F>>>1}else{Z=c[k+4>>2]|0}qG(W,x,y,c[h+4>>2]|0,Y,Y+Z|0,D,K,m,a[n]|0,a[o]|0,p,r,t,N);oX(b,c[f>>2]|0,W,c[x>>2]|0,c[y>>2]|0,h,j);if((X|0)!=0){sS(X)}do{if((a[u]&1)!=0){C=c[t+8>>2]|0;if((C|0)==0){break}sS(C)}}while(0);do{if((a[s]&1)!=0){N=c[r+8>>2]|0;if((N|0)==0){break}sS(N)}}while(0);do{if((a[q]&1)!=0){N=c[p+8>>2]|0;if((N|0)==0){break}sS(N)}}while(0);N=z+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)!=0){i=e;return}f$[c[(c[z>>2]|0)+8>>2]&511](z);i=e;return}}while(0);e=fc(4)|0;c[e>>2]=53912;dq(e|0,60416,316)}function qK(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=+l;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+568|0;m=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[m>>2];m=e|0;n=e+120|0;o=e+528|0;p=e+536|0;q=e+544|0;r=e+552|0;s=r;t=i;i=i+12|0;i=i+7>>3<<3;u=t;v=i;i=i+12|0;i=i+7>>3<<3;w=v;x=i;i=i+4|0;i=i+7>>3<<3;y=i;i=i+400|0;z=i;i=i+4|0;i=i+7>>3<<3;A=i;i=i+4|0;i=i+7>>3<<3;B=e+16|0;c[n>>2]=B;C=e+128|0;D=b5(B|0,100,43448,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;do{if(D>>>0>99){do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);E=o0(n,c[137522]|0,43448,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;F=c[n>>2]|0;if((F|0)==0){G=fc(4)|0;c[G>>2]=53880;dq(G|0,60400,240)}G=sR(E<<2)|0;H=G;if((G|0)!=0){J=H;K=E;L=F;M=H;break}H=fc(4)|0;c[H>>2]=53880;dq(H|0,60400,240)}else{J=C;K=D;L=0;M=0}}while(0);D=c[j+28>>2]|0;C=D;B=D+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[137880]|0)!=-1){c[m>>2]=551520;c[m+4>>2]=16;c[m+8>>2]=0;mU(551520,m)}m=(c[137881]|0)-1|0;B=c[D+8>>2]|0;do{if((c[D+12>>2]|0)-B>>2>>>0>m>>>0){H=c[B+(m<<2)>>2]|0;if((H|0)==0){break}F=H;E=c[n>>2]|0;G=E+K|0;N=c[(c[H>>2]|0)+48>>2]|0;gn[N&31](F,E,G,J)|0;if((K|0)==0){O=0}else{O=(a[c[n>>2]|0]|0)==45}s_(s|0,0,12);s_(u|0,0,12);s_(w|0,0,12);qL(g,O,C,o,p,q,r,t,v,x);G=y|0;E=c[x>>2]|0;if((K|0)>(E|0)){N=d[w]|0;if((N&1|0)==0){P=N>>>1}else{P=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){Q=N>>>1}else{Q=c[t+4>>2]|0}R=P+(K-E<<1|1)+Q|0}else{N=d[w]|0;if((N&1|0)==0){S=N>>>1}else{S=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){T=N>>>1}else{T=c[t+4>>2]|0}R=S+2+T|0}N=R+E|0;do{if(N>>>0>100){H=sR(N<<2)|0;U=H;if((H|0)!=0){V=U;W=U;break}U=fc(4)|0;c[U>>2]=53880;dq(U|0,60400,240)}else{V=G;W=0}}while(0);qM(V,z,A,c[j+4>>2]|0,J,J+(K<<2)|0,F,O,o,c[p>>2]|0,c[q>>2]|0,r,t,v,E);pa(b,c[f>>2]|0,V,c[z>>2]|0,c[A>>2]|0,j,k);if((W|0)!=0){sS(W)}do{if((a[w]&1)!=0){G=c[v+8>>2]|0;if((G|0)==0){break}sS(G)}}while(0);do{if((a[u]&1)!=0){E=c[t+8>>2]|0;if((E|0)==0){break}sS(E)}}while(0);do{if((a[s]&1)!=0){E=c[r+8>>2]|0;if((E|0)==0){break}sS(E)}}while(0);E=D+4|0;if(((I=c[E>>2]|0,c[E>>2]=I+ -1,I)|0)==0){f$[c[(c[D>>2]|0)+8>>2]&511](D)}if((M|0)!=0){sS(M)}if((L|0)==0){i=e;return}sS(L);i=e;return}}while(0);e=fc(4)|0;c[e>>2]=53912;dq(e|0,60416,316)}function qL(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;n=i;i=i+40|0;o=n|0;p=n+16|0;q=n+32|0;r=q;s=i;i=i+12|0;i=i+7>>3<<3;t=s;u=i;i=i+4|0;i=i+7>>3<<3;v=u;w=i;i=i+12|0;i=i+7>>3<<3;x=w;y=i;i=i+12|0;i=i+7>>3<<3;z=y;A=i;i=i+12|0;i=i+7>>3<<3;B=A;D=i;i=i+4|0;i=i+7>>3<<3;E=D;F=i;i=i+12|0;i=i+7>>3<<3;G=F;H=i;i=i+4|0;i=i+7>>3<<3;I=H;J=i;i=i+12|0;i=i+7>>3<<3;K=J;L=i;i=i+12|0;i=i+7>>3<<3;M=L;N=i;i=i+12|0;i=i+7>>3<<3;O=N;if(b){if((c[137996]|0)!=-1){c[p>>2]=551984;c[p+4>>2]=16;c[p+8>>2]=0;mU(551984,p)}p=(c[137997]|0)-1|0;b=c[e+8>>2]|0;if((c[e+12>>2]|0)-b>>2>>>0<=p>>>0){P=fc(4)|0;Q=P;c[Q>>2]=53912;dq(P|0,60416,316)}R=c[b+(p<<2)>>2]|0;if((R|0)==0){P=fc(4)|0;Q=P;c[Q>>2]=53912;dq(P|0,60416,316)}P=R;Q=c[R>>2]|0;if(d){f0[c[Q+44>>2]&255](r,P);r=f;C=c[q>>2]|0;a[r]=C&255;C=C>>8;a[r+1|0]=C&255;C=C>>8;a[r+2|0]=C&255;C=C>>8;a[r+3|0]=C&255;f0[c[(c[R>>2]|0)+32>>2]&255](s,P);s=l;if((a[s]&1)==0){c[l+4>>2]=0;a[s]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}m0(l);c[s>>2]=c[t>>2];c[s+4>>2]=c[t+4>>2];c[s+8>>2]=c[t+8>>2];s_(t|0,0,12)}else{f0[c[Q+40>>2]&255](v,P);v=f;C=c[u>>2]|0;a[v]=C&255;C=C>>8;a[v+1|0]=C&255;C=C>>8;a[v+2|0]=C&255;C=C>>8;a[v+3|0]=C&255;f0[c[(c[R>>2]|0)+28>>2]&255](w,P);w=l;if((a[w]&1)==0){c[l+4>>2]=0;a[w]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}m0(l);c[w>>2]=c[x>>2];c[w+4>>2]=c[x+4>>2];c[w+8>>2]=c[x+8>>2];s_(x|0,0,12)}x=R;c[g>>2]=f2[c[(c[x>>2]|0)+12>>2]&255](P)|0;c[h>>2]=f2[c[(c[x>>2]|0)+16>>2]&255](P)|0;f0[c[(c[R>>2]|0)+20>>2]&255](y,P);y=j;if((a[y]&1)==0){a[j+1|0]=0;a[y]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}mW(j);c[y>>2]=c[z>>2];c[y+4>>2]=c[z+4>>2];c[y+8>>2]=c[z+8>>2];s_(z|0,0,12);f0[c[(c[R>>2]|0)+24>>2]&255](A,P);A=k;if((a[A]&1)==0){c[k+4>>2]=0;a[A]=0}else{c[c[k+8>>2]>>2]=0;c[k+4>>2]=0}m0(k);c[A>>2]=c[B>>2];c[A+4>>2]=c[B+4>>2];c[A+8>>2]=c[B+8>>2];s_(B|0,0,12);S=f2[c[(c[x>>2]|0)+36>>2]&255](P)|0;c[m>>2]=S;i=n;return}else{if((c[137998]|0)!=-1){c[o>>2]=551992;c[o+4>>2]=16;c[o+8>>2]=0;mU(551992,o)}o=(c[137999]|0)-1|0;P=c[e+8>>2]|0;if((c[e+12>>2]|0)-P>>2>>>0<=o>>>0){T=fc(4)|0;U=T;c[U>>2]=53912;dq(T|0,60416,316)}e=c[P+(o<<2)>>2]|0;if((e|0)==0){T=fc(4)|0;U=T;c[U>>2]=53912;dq(T|0,60416,316)}T=e;U=c[e>>2]|0;if(d){f0[c[U+44>>2]&255](E,T);E=f;C=c[D>>2]|0;a[E]=C&255;C=C>>8;a[E+1|0]=C&255;C=C>>8;a[E+2|0]=C&255;C=C>>8;a[E+3|0]=C&255;f0[c[(c[e>>2]|0)+32>>2]&255](F,T);F=l;if((a[F]&1)==0){c[l+4>>2]=0;a[F]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}m0(l);c[F>>2]=c[G>>2];c[F+4>>2]=c[G+4>>2];c[F+8>>2]=c[G+8>>2];s_(G|0,0,12)}else{f0[c[U+40>>2]&255](I,T);I=f;C=c[H>>2]|0;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;f0[c[(c[e>>2]|0)+28>>2]&255](J,T);J=l;if((a[J]&1)==0){c[l+4>>2]=0;a[J]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}m0(l);c[J>>2]=c[K>>2];c[J+4>>2]=c[K+4>>2];c[J+8>>2]=c[K+8>>2];s_(K|0,0,12)}K=e;c[g>>2]=f2[c[(c[K>>2]|0)+12>>2]&255](T)|0;c[h>>2]=f2[c[(c[K>>2]|0)+16>>2]&255](T)|0;f0[c[(c[e>>2]|0)+20>>2]&255](L,T);L=j;if((a[L]&1)==0){a[j+1|0]=0;a[L]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}mW(j);c[L>>2]=c[M>>2];c[L+4>>2]=c[M+4>>2];c[L+8>>2]=c[M+8>>2];s_(M|0,0,12);f0[c[(c[e>>2]|0)+24>>2]&255](N,T);N=k;if((a[N]&1)==0){c[k+4>>2]=0;a[N]=0}else{c[c[k+8>>2]>>2]=0;c[k+4>>2]=0}m0(k);c[N>>2]=c[O>>2];c[N+4>>2]=c[O+4>>2];c[N+8>>2]=c[O+8>>2];s_(O|0,0,12);S=f2[c[(c[K>>2]|0)+36>>2]&255](T)|0;c[m>>2]=S;i=n;return}}function qM(b,d,e,f,g,h,i,j,k,l,m,n,o,p,q){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;c[e>>2]=b;r=i;s=p;t=p+4|0;u=p+8|0;p=o;v=(f&512|0)==0;w=o+4|0;x=o+8|0;o=i;y=(q|0)>0;z=n;A=n+1|0;B=n+8|0;C=n+4|0;n=g;g=0;while(1){L6284:do{switch(a[k+g|0]|0){case 4:{D=c[e>>2]|0;E=j?n+4|0:n;F=E;while(1){if(F>>>0>=h>>>0){break}if(f7[c[(c[o>>2]|0)+12>>2]&127](i,2048,c[F>>2]|0)|0){F=F+4|0}else{break}}if(y){do{if(F>>>0>E>>>0){G=F;H=q;do{G=G-4|0;I=c[G>>2]|0;J=c[e>>2]|0;c[e>>2]=J+4;c[J>>2]=I;H=H-1|0;K=(H|0)>0;}while(G>>>0>E>>>0&K);if(K){L=H;M=G;N=5438;break}I=c[e>>2]|0;c[e>>2]=I+4;O=I;P=G}else{L=q;M=F;N=5438}}while(0);do{if((N|0)==5438){N=0;I=gj[c[(c[r>>2]|0)+44>>2]&127](i,48)|0;J=c[e>>2]|0;c[e>>2]=J+4;if((L|0)>0){Q=L;R=J}else{O=J;P=M;break}while(1){c[R>>2]=I;J=Q-1|0;S=c[e>>2]|0;c[e>>2]=S+4;if((J|0)>0){Q=J;R=S}else{O=S;P=M;break}}}}while(0);c[O>>2]=l;T=P}else{T=F}if((T|0)==(E|0)){I=gj[c[(c[r>>2]|0)+44>>2]&127](i,48)|0;G=c[e>>2]|0;c[e>>2]=G+4;c[G>>2]=I}else{I=a[z]|0;G=I&255;if((G&1|0)==0){U=G>>>1}else{U=c[C>>2]|0}if((U|0)==0){V=T;W=0;X=0;Y=-1}else{if((I&1)==0){Z=A}else{Z=c[B>>2]|0}V=T;W=0;X=0;Y=a[Z]|0}while(1){do{if((W|0)==(Y|0)){I=c[e>>2]|0;c[e>>2]=I+4;c[I>>2]=m;I=X+1|0;G=a[z]|0;H=G&255;if((H&1|0)==0){_=H>>>1}else{_=c[C>>2]|0}if(I>>>0>=_>>>0){$=Y;aa=I;ab=0;break}H=(G&1)==0;if(H){ac=A}else{ac=c[B>>2]|0}if((a[ac+I|0]|0)==127){$=-1;aa=I;ab=0;break}if(H){ad=A}else{ad=c[B>>2]|0}$=a[ad+I|0]|0;aa=I;ab=0}else{$=Y;aa=X;ab=W}}while(0);I=V-4|0;H=c[I>>2]|0;G=c[e>>2]|0;c[e>>2]=G+4;c[G>>2]=H;if((I|0)==(E|0)){break}else{V=I;W=ab+1|0;X=aa;Y=$}}}F=c[e>>2]|0;if((D|0)==(F|0)){ae=E;break L6284}I=F-4|0;if(D>>>0<I>>>0){af=D;ag=I}else{ae=E;break L6284}while(1){I=c[af>>2]|0;c[af>>2]=c[ag>>2];c[ag>>2]=I;I=af+4|0;F=ag-4|0;if(I>>>0<F>>>0){af=I;ag=F}else{ae=E;break}}break};case 0:{c[d>>2]=c[e>>2];ae=n;break};case 3:{E=a[s]|0;D=E&255;if((D&1|0)==0){ah=D>>>1}else{ah=c[t>>2]|0}if((ah|0)==0){ae=n;break L6284}if((E&1)==0){ai=t}else{ai=c[u>>2]|0}E=c[ai>>2]|0;D=c[e>>2]|0;c[e>>2]=D+4;c[D>>2]=E;ae=n;break};case 1:{c[d>>2]=c[e>>2];E=gj[c[(c[r>>2]|0)+44>>2]&127](i,32)|0;D=c[e>>2]|0;c[e>>2]=D+4;c[D>>2]=E;ae=n;break};case 2:{E=a[p]|0;D=E&255;F=(D&1|0)==0;if(F){aj=D>>>1}else{aj=c[w>>2]|0}if((aj|0)==0|v){ae=n;break L6284}if((E&1)==0){ak=w}else{ak=c[x>>2]|0}if(F){al=D>>>1}else{al=c[w>>2]|0}D=ak+(al<<2)|0;F=c[e>>2]|0;if((al|0)==0){am=F}else{E=ak+(al-1<<2)+(-ak|0)|0;I=ak;H=F;while(1){c[H>>2]=c[I>>2];G=I+4|0;if((G|0)==(D|0)){break}I=G;H=H+4|0}am=F+((E>>>2)+1<<2)|0}c[e>>2]=am;ae=n;break};default:{ae=n}}}while(0);H=g+1|0;if(H>>>0<4){n=ae;g=H}else{break}}g=a[s]|0;s=g&255;ae=(s&1|0)==0;if(ae){an=s>>>1}else{an=c[t>>2]|0}if(an>>>0>1){if((g&1)==0){ao=t}else{ao=c[u>>2]|0}if(ae){ap=s>>>1}else{ap=c[t>>2]|0}t=ao+(ap<<2)|0;s=c[e>>2]|0;if((ap|0)==1){aq=s}else{ae=(ao+(ap-2<<2)+(-ao|0)|0)>>>2;ap=s;u=ao+4|0;while(1){c[ap>>2]=c[u>>2];ao=u+4|0;if((ao|0)==(t|0)){break}else{ap=ap+4|0;u=ao}}aq=s+(ae+1<<2)|0}c[e>>2]=aq}aq=f&176;if((aq|0)==32){c[d>>2]=c[e>>2];return}else if((aq|0)==16){return}else{c[d>>2]=b;return}}function qN(a){a=a|0;return}function qO(a){a=a|0;return}function qP(a){a=a|0;if((a|0)==0){return}sS(a);return}function qQ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((a[d]&1)==0){f=d+1|0}else{f=c[d+8>>2]|0}d=bI(f|0,200)|0;return d>>>(((d|0)!=-1|0)>>>0)|0}function qR(a,b){a=a|0;b=b|0;d7(((b|0)==-1?-1:b<<1)|0)|0;return}function qS(a){a=a|0;if((a|0)==0){return}sS(a);return}function qT(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((a[d]&1)==0){f=d+1|0}else{f=c[d+8>>2]|0}d=bI(f|0,200)|0;return d>>>(((d|0)!=-1|0)>>>0)|0}function qU(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+56|0;l=f;f=i;i=i+4|0;i=i+7>>3<<3;c[f>>2]=c[l>>2];l=e|0;m=e+16|0;n=e+24|0;o=e+32|0;p=e+40|0;q=p;r=i;i=i+12|0;i=i+7>>3<<3;s=r;t=i;i=i+12|0;i=i+7>>3<<3;u=t;v=i;i=i+4|0;i=i+7>>3<<3;w=i;i=i+400|0;x=i;i=i+4|0;i=i+7>>3<<3;y=i;i=i+4|0;i=i+7>>3<<3;z=c[h+28>>2]|0;A=z;B=z+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[137880]|0)!=-1){c[l>>2]=551520;c[l+4>>2]=16;c[l+8>>2]=0;mU(551520,l)}l=(c[137881]|0)-1|0;B=c[z+8>>2]|0;do{if((c[z+12>>2]|0)-B>>2>>>0>l>>>0){C=c[B+(l<<2)>>2]|0;if((C|0)==0){break}D=C;E=k;F=a[E]|0;G=F&255;if((G&1|0)==0){H=G>>>1}else{H=c[k+4>>2]|0}if((H|0)==0){J=0}else{if((F&1)==0){K=k+4|0}else{K=c[k+8>>2]|0}F=c[K>>2]|0;J=(F|0)==(gj[c[(c[C>>2]|0)+44>>2]&127](D,45)|0)}s_(q|0,0,12);s_(s|0,0,12);s_(u|0,0,12);qL(g,J,A,m,n,o,p,r,t,v);C=w|0;F=a[E]|0;E=F&255;G=(E&1|0)==0;if(G){L=E>>>1}else{L=c[k+4>>2]|0}M=c[v>>2]|0;if((L|0)>(M|0)){if(G){N=E>>>1}else{N=c[k+4>>2]|0}O=d[u]|0;if((O&1|0)==0){P=O>>>1}else{P=c[t+4>>2]|0}O=d[s]|0;if((O&1|0)==0){Q=O>>>1}else{Q=c[r+4>>2]|0}R=P+(N-M<<1|1)+Q|0}else{O=d[u]|0;if((O&1|0)==0){S=O>>>1}else{S=c[t+4>>2]|0}O=d[s]|0;if((O&1|0)==0){T=O>>>1}else{T=c[r+4>>2]|0}R=S+2+T|0}O=R+M|0;do{if(O>>>0>100){U=sR(O<<2)|0;V=U;if((U|0)!=0){W=V;X=V;break}V=fc(4)|0;c[V>>2]=53880;dq(V|0,60400,240)}else{W=C;X=0}}while(0);if((F&1)==0){Y=k+4|0}else{Y=c[k+8>>2]|0}if(G){Z=E>>>1}else{Z=c[k+4>>2]|0}qM(W,x,y,c[h+4>>2]|0,Y,Y+(Z<<2)|0,D,J,m,c[n>>2]|0,c[o>>2]|0,p,r,t,M);pa(b,c[f>>2]|0,W,c[x>>2]|0,c[y>>2]|0,h,j);if((X|0)!=0){sS(X)}do{if((a[u]&1)!=0){C=c[t+8>>2]|0;if((C|0)==0){break}sS(C)}}while(0);do{if((a[s]&1)!=0){M=c[r+8>>2]|0;if((M|0)==0){break}sS(M)}}while(0);do{if((a[q]&1)!=0){M=c[p+8>>2]|0;if((M|0)==0){break}sS(M)}}while(0);M=z+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)!=0){i=e;return}f$[c[(c[z>>2]|0)+8>>2]&511](z);i=e;return}}while(0);e=fc(4)|0;c[e>>2]=53912;dq(e|0,60416,316)}function qV(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=i;i=i+16|0;j=d|0;k=j;s_(k|0,0,12);l=b;m=a[h]|0;if((m&1)==0){n=h+1|0}else{n=c[h+8>>2]|0}o=m&255;if((o&1|0)==0){p=o>>>1}else{p=c[h+4>>2]|0}h=n+p|0;do{if((p|0)>0){o=j+1|0;m=j+8|0;q=j|0;r=j+4|0;s=n;t=0;L6513:while(1){u=a[s]|0;if((t&1)==0){v=(t&255)>>>1;w=10;x=t}else{y=c[q>>2]|0;v=c[r>>2]|0;w=(y&-2)-1|0;x=y&255}if((v|0)==(w|0)){if((w|0)==-3){z=5603;break}y=(x&1)==0?o:c[m>>2]|0;do{if(w>>>0<2147483631){A=w+1|0;B=w<<1;C=A>>>0<B>>>0?B:A;if(C>>>0<11){D=11;break}D=C+16&-16}else{D=-2}}while(0);C=(D|0)==0?1:D;while(1){E=sR(C)|0;if((E|0)!=0){break}A=(I=c[138018]|0,c[138018]=I+0,I);if((A|0)==0){z=5617;break L6513}gp[A&63]()}s1(E|0,y|0,w)|0;if(!((w|0)==10|(y|0)==0)){sS(y)}c[m>>2]=E;C=D|1;c[q>>2]=C;F=C&255}else{F=t}if((F&1)==0){a[k]=(v<<1)+2&255;G=o;H=v+1|0}else{C=c[m>>2]|0;A=v+1|0;c[r>>2]=A;G=C;H=A}a[G+v|0]=u;a[G+H|0]=0;A=s+1|0;J=a[k]|0;if(A>>>0<h>>>0){s=A;t=J}else{z=5626;break}}if((z|0)==5603){mV()}else if((z|0)==5617){t=fc(4)|0;c[t>>2]=53880;dq(t|0,60400,240)}else if((z|0)==5626){K=(J&1)==0?o:c[m>>2]|0;L=(e|0)==-1?-1:e<<1;break}}else{K=j+1|0;L=(e|0)==-1?-1:e<<1}}while(0);e=fW(L|0,f|0,g|0,K|0)|0;s_(l|0,0,12);K=sZ(e|0)|0;g=e+K|0;L6548:do{if((K|0)>0){f=b+1|0;L=b+8|0;J=b+4|0;z=b|0;h=e;H=0;while(1){G=a[h]|0;if((H&1)==0){M=(H&255)>>>1;N=10}else{M=c[J>>2]|0;N=(c[z>>2]&-2)-1|0}if((M|0)==(N|0)){m_(b,N,1,N,N,0);O=a[l]|0}else{O=H}if((O&1)==0){a[l]=(M<<1)+2&255;P=f;Q=M+1|0}else{v=c[L>>2]|0;F=M+1|0;c[J>>2]=F;P=v;Q=F}a[P+M|0]=G;a[P+Q|0]=0;G=h+1|0;if(G>>>0>=g>>>0){break L6548}h=G;H=a[l]|0}}}while(0);if((a[k]&1)==0){i=d;return}k=c[j+8>>2]|0;if((k|0)==0){i=d;return}sS(k);i=d;return}function qW(a,b){a=a|0;b=b|0;d7(((b|0)==-1?-1:b<<1)|0)|0;return}function qX(a){a=a|0;qY(a);if((a|0)==0){return}sS(a);return}function qY(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[b>>2]=55296;d=b+12|0;e=c[d>>2]|0;f=b+8|0;g=c[f>>2]|0;if((e|0)==(g|0)){h=e}else{i=0;j=g;g=e;while(1){e=c[j+(i<<2)>>2]|0;if((e|0)==0){k=g;l=j}else{m=e+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)==0){f$[c[(c[e>>2]|0)+8>>2]&511](e|0)}k=c[d>>2]|0;l=c[f>>2]|0}e=i+1|0;if(e>>>0<k-l>>2>>>0){i=e;j=l;g=k}else{h=l;break}}}do{if((a[b+144|0]&1)==0){n=h}else{l=c[b+152>>2]|0;if((l|0)==0){n=h;break}sS(l);n=c[f>>2]|0}}while(0);if((n|0)==0){return}f=c[d>>2]|0;if((n|0)!=(f|0)){c[d>>2]=f+(~((f-4+(-n|0)|0)>>>2)<<2)}if((n|0)==(b+24|0)){a[b+136|0]=0;return}else{sS(n);return}}function qZ(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;d=i;i=i+224|0;j=d|0;k=d+8|0;l=d+40|0;m=d+48|0;n=d+56|0;o=d+64|0;p=d+192|0;q=d+200|0;r=d+208|0;s=r;t=i;i=i+8|0;u=i;i=i+8|0;s_(s|0,0,12);v=b;w=t|0;c[t+4>>2]=0;c[t>>2]=55576;x=a[h]|0;if((x&1)==0){y=h+4|0}else{y=c[h+8>>2]|0}z=x&255;if((z&1|0)==0){A=z>>>1}else{A=c[h+4>>2]|0}h=y+(A<<2)|0;do{if((A|0)>0){z=t;x=k|0;B=k+32|0;C=r+1|0;D=r+8|0;E=r|0;F=r+4|0;G=y;H=55576;L6617:while(1){c[m>>2]=G;J=(gq[c[H+12>>2]&31](w,j,G,h,m,x,B,l)|0)==2;K=c[m>>2]|0;if(J|(K|0)==(G|0)){L=5696;break}if(x>>>0<(c[l>>2]|0)>>>0){J=x;do{M=a[J]|0;N=a[s]|0;if((N&1)==0){O=(N&255)>>>1;P=10;Q=N}else{R=c[E>>2]|0;O=c[F>>2]|0;P=(R&-2)-1|0;Q=R&255}if((O|0)==(P|0)){if((P|0)==-3){L=5721;break L6617}R=(Q&1)==0?C:c[D>>2]|0;do{if(P>>>0<2147483631){S=P+1|0;T=P<<1;U=S>>>0<T>>>0?T:S;if(U>>>0<11){V=11;break}V=U+16&-16}else{V=-2}}while(0);U=(V|0)==0?1:V;while(1){W=sR(U)|0;if((W|0)!=0){break}S=(I=c[138018]|0,c[138018]=I+0,I);if((S|0)==0){L=5735;break L6617}gp[S&63]()}s1(W|0,R|0,P)|0;if(!((P|0)==10|(R|0)==0)){sS(R)}c[D>>2]=W;U=V|1;c[E>>2]=U;X=U&255}else{X=N}if((X&1)==0){a[s]=(O<<1)+2&255;Y=C;Z=O+1|0}else{U=c[D>>2]|0;S=O+1|0;c[F>>2]=S;Y=U;Z=S}a[Y+O|0]=M;a[Y+Z|0]=0;J=J+1|0;}while(J>>>0<(c[l>>2]|0)>>>0);_=c[m>>2]|0}else{_=K}if(_>>>0>=h>>>0){L=5747;break}G=_;H=c[z>>2]|0}if((L|0)==5696){z=fc(8)|0;c[z>>2]=53944;H=z+4|0;G=H;do{if((H|0)!=0){while(1){$=sR(33)|0;if(($|0)!=0){L=5711;break}F=(I=c[138018]|0,c[138018]=I+0,I);if((F|0)==0){break}gp[F&63]()}if((L|0)==5711){c[$+4>>2]=20;c[$>>2]=20;K=$+12|0;c[G>>2]=K;c[$+8>>2]=0;s1(K|0,25648,21)|0;break}K=fc(4)|0;c[K>>2]=53880;dq(K|0,60400,240)}}while(0);dq(z|0,60432,122)}else if((L|0)==5747){aa=(a[s]&1)==0?C:c[D>>2]|0;ab=(e|0)==-1?-1:e<<1;break}else if((L|0)==5735){G=fc(4)|0;c[G>>2]=53880;dq(G|0,60400,240)}else if((L|0)==5721){mV()}}else{aa=r+1|0;ab=(e|0)==-1?-1:e<<1}}while(0);e=fW(ab|0,f|0,g|0,aa|0)|0;s_(v|0,0,12);aa=u|0;c[u+4>>2]=0;c[u>>2]=55520;g=sZ(e|0)|0;f=e+g|0;L6671:do{if((g|0)>=1){ab=u;$=f;_=o|0;h=o+128|0;m=b+4|0;l=b+8|0;Z=b|0;Y=e;O=55520;while(1){c[q>>2]=Y;X=(gq[c[O+16>>2]&31](aa,n,Y,($-Y|0)>32?Y+32|0:f,q,_,h,p)|0)==2;V=c[q>>2]|0;if(X|(V|0)==(Y|0)){break}if(_>>>0<(c[p>>2]|0)>>>0){X=_;do{W=c[X>>2]|0;P=a[v]|0;if((P&1)==0){ac=(P&255)>>>1;ad=1}else{ac=c[m>>2]|0;ad=(c[Z>>2]&-2)-1|0}if((ac|0)==(ad|0)){nr(b,ad,1,ad,ad,0,0);ae=a[v]|0}else{ae=P}if((ae&1)==0){a[v]=(ac<<1)+2&255;af=m;ag=ac+1|0}else{P=c[l>>2]|0;Q=ac+1|0;c[m>>2]=Q;af=P;ag=Q}c[af+(ac<<2)>>2]=W;c[af+(ag<<2)>>2]=0;X=X+4|0;}while(X>>>0<(c[p>>2]|0)>>>0);ah=c[q>>2]|0}else{ah=V}if(ah>>>0>=f>>>0){break L6671}Y=ah;O=c[ab>>2]|0}ab=fc(8)|0;c[ab>>2]=53944;O=ab+4|0;Y=O;do{if((O|0)!=0){while(1){ai=sR(33)|0;if((ai|0)!=0){L=5775;break}m=(I=c[138018]|0,c[138018]=I+0,I);if((m|0)==0){break}gp[m&63]()}if((L|0)==5775){c[ai+4>>2]=20;c[ai>>2]=20;V=ai+12|0;c[Y>>2]=V;c[ai+8>>2]=0;s1(V|0,25648,21)|0;break}V=fc(4)|0;c[V>>2]=53880;dq(V|0,60400,240)}}while(0);dq(ab|0,60432,122)}}while(0);if((a[s]&1)==0){i=d;return}s=c[r+8>>2]|0;if((s|0)==0){i=d;return}sS(s);i=d;return}function q_(b){b=b|0;var d=0;c[b>>2]=55040;d=b+8|0;b=c[d>>2]|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);if((b|0)==(c[137522]|0)){return}cE(c[d>>2]|0);return}
function q$(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0;b=i;i=i+448|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;l=b+112|0;m=b+128|0;n=b+144|0;o=b+160|0;p=b+176|0;q=b+192|0;r=b+208|0;s=b+224|0;t=b+240|0;u=b+256|0;v=b+272|0;w=b+288|0;x=b+304|0;y=b+320|0;z=b+336|0;A=b+352|0;B=b+368|0;C=b+384|0;D=b+400|0;E=b+416|0;F=b+432|0;if((a[682960]|0)!=0){G=c[137516]|0;i=b;return G|0}if((cQ(682960)|0)==0){G=c[137516]|0;i=b;return G|0}do{if((a[682968]|0)==0){if((cQ(682968)|0)==0){break}c[137563]=0;c[137562]=55296;a[550384]=1;c[137565]=550272;c[137564]=550272;c[137566]=550384;H=28;J=550272;do{if((J|0)==0){K=0}else{c[J>>2]=0;K=c[137565]|0}J=K+4|0;c[137565]=J;H=H-1|0;}while((H|0)!=0);a[550392]=2;a[550393]=67;a[550394]=0;H=c[137564]|0;if((H|0)!=(J|0)){c[137565]=K+(-((K+(-H|0)|0)>>>2)<<2)}c[137555]=0;c[137554]=55e3;if((c[137802]|0)!=-1){c[F>>2]=551208;c[F+4>>2]=16;c[F+8>>2]=0;mU(551208,F)}H=c[137803]|0;L=H-1|0;I=c[137555]|0,c[137555]=I+1,I;M=c[137565]|0;N=c[137564]|0;O=M-N>>2;do{if(O>>>0>L>>>0){P=N}else{if(O>>>0<H>>>0){sp(550256,H-O|0);P=c[137564]|0;break}if(O>>>0<=H>>>0){P=N;break}Q=N+(H<<2)|0;if((Q|0)==(M|0)){P=N;break}c[137565]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);P=N}}while(0);N=c[P+(L<<2)>>2]|0;if((N|0)==0){R=P}else{M=N+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){f$[c[(c[N>>2]|0)+8>>2]&511](N|0)}R=c[137564]|0}c[R+(L<<2)>>2]=550216;c[137553]=0;c[137552]=54960;if((c[137800]|0)!=-1){c[E>>2]=551200;c[E+4>>2]=16;c[E+8>>2]=0;mU(551200,E)}N=c[137801]|0;M=N-1|0;I=c[137553]|0,c[137553]=I+1,I;H=c[137565]|0;O=c[137564]|0;J=H-O>>2;do{if(J>>>0>M>>>0){S=O}else{if(J>>>0<N>>>0){sp(550256,N-J|0);S=c[137564]|0;break}if(J>>>0<=N>>>0){S=O;break}Q=O+(N<<2)|0;if((Q|0)==(H|0)){S=O;break}c[137565]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);S=O}}while(0);O=c[S+(M<<2)>>2]|0;if((O|0)==0){T=S}else{H=O+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){f$[c[(c[O>>2]|0)+8>>2]&511](O|0)}T=c[137564]|0}c[T+(M<<2)>>2]=550208;c[137605]=0;c[137604]=55408;c[137606]=0;a[550428]=0;c[137606]=c[(cC()|0)>>2];if((c[137882]|0)!=-1){c[D>>2]=551528;c[D+4>>2]=16;c[D+8>>2]=0;mU(551528,D)}O=c[137883]|0;H=O-1|0;I=c[137605]|0,c[137605]=I+1,I;N=c[137565]|0;J=c[137564]|0;L=N-J>>2;do{if(L>>>0>H>>>0){U=J}else{if(L>>>0<O>>>0){sp(550256,O-L|0);U=c[137564]|0;break}if(L>>>0<=O>>>0){U=J;break}Q=J+(O<<2)|0;if((Q|0)==(N|0)){U=J;break}c[137565]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);U=J}}while(0);J=c[U+(H<<2)>>2]|0;if((J|0)==0){V=U}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){f$[c[(c[J>>2]|0)+8>>2]&511](J|0)}V=c[137564]|0}c[V+(H<<2)>>2]=550416;c[137603]=0;c[137602]=55328;if((c[137880]|0)!=-1){c[C>>2]=551520;c[C+4>>2]=16;c[C+8>>2]=0;mU(551520,C)}J=c[137881]|0;N=J-1|0;I=c[137603]|0,c[137603]=I+1,I;O=c[137565]|0;L=c[137564]|0;M=O-L>>2;do{if(M>>>0>N>>>0){W=L}else{if(M>>>0<J>>>0){sp(550256,J-M|0);W=c[137564]|0;break}if(M>>>0<=J>>>0){W=L;break}Q=L+(J<<2)|0;if((Q|0)==(O|0)){W=L;break}c[137565]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);W=L}}while(0);L=c[W+(N<<2)>>2]|0;if((L|0)==0){X=W}else{O=L+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){f$[c[(c[L>>2]|0)+8>>2]&511](L|0)}X=c[137564]|0}c[X+(N<<2)>>2]=550408;c[137557]=0;c[137556]=55096;if((c[137806]|0)!=-1){c[B>>2]=551224;c[B+4>>2]=16;c[B+8>>2]=0;mU(551224,B)}L=c[137807]|0;O=L-1|0;I=c[137557]|0,c[137557]=I+1,I;J=c[137565]|0;M=c[137564]|0;H=J-M>>2;do{if(H>>>0>O>>>0){Y=M}else{if(H>>>0<L>>>0){sp(550256,L-H|0);Y=c[137564]|0;break}if(H>>>0<=L>>>0){Y=M;break}Q=M+(L<<2)|0;if((Q|0)==(J|0)){Y=M;break}c[137565]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);Y=M}}while(0);M=c[Y+(O<<2)>>2]|0;if((M|0)==0){Z=Y}else{J=M+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f$[c[(c[M>>2]|0)+8>>2]&511](M|0)}Z=c[137564]|0}c[Z+(O<<2)>>2]=550224;c[13261]=0;c[13260]=55040;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);c[13262]=c[137522];if((c[137804]|0)!=-1){c[A>>2]=551216;c[A+4>>2]=16;c[A+8>>2]=0;mU(551216,A)}O=c[137805]|0;M=O-1|0;I=c[13261]|0,c[13261]=I+1,I;J=c[137565]|0;L=c[137564]|0;H=J-L>>2;do{if(H>>>0>M>>>0){_=L}else{if(H>>>0<O>>>0){sp(550256,O-H|0);_=c[137564]|0;break}if(H>>>0<=O>>>0){_=L;break}N=L+(O<<2)|0;if((N|0)==(J|0)){_=L;break}c[137565]=J+(~((J-4+(-N|0)|0)>>>2)<<2);_=L}}while(0);L=c[_+(M<<2)>>2]|0;if((L|0)==0){$=_}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f$[c[(c[L>>2]|0)+8>>2]&511](L|0)}$=c[137564]|0}c[$+(M<<2)>>2]=53040;c[137559]=0;c[137558]=55152;if((c[137808]|0)!=-1){c[z>>2]=551232;c[z+4>>2]=16;c[z+8>>2]=0;mU(551232,z)}L=c[137809]|0;J=L-1|0;I=c[137559]|0,c[137559]=I+1,I;O=c[137565]|0;H=c[137564]|0;N=O-H>>2;do{if(N>>>0>J>>>0){aa=H}else{if(N>>>0<L>>>0){sp(550256,L-N|0);aa=c[137564]|0;break}if(N>>>0<=L>>>0){aa=H;break}Q=H+(L<<2)|0;if((Q|0)==(O|0)){aa=H;break}c[137565]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);aa=H}}while(0);H=c[aa+(J<<2)>>2]|0;if((H|0)==0){ab=aa}else{O=H+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){f$[c[(c[H>>2]|0)+8>>2]&511](H|0)}ab=c[137564]|0}c[ab+(J<<2)>>2]=550232;c[137561]=0;c[137560]=55208;if((c[137810]|0)!=-1){c[y>>2]=551240;c[y+4>>2]=16;c[y+8>>2]=0;mU(551240,y)}H=c[137811]|0;O=H-1|0;I=c[137561]|0,c[137561]=I+1,I;L=c[137565]|0;N=c[137564]|0;M=L-N>>2;do{if(M>>>0>O>>>0){ac=N}else{if(M>>>0<H>>>0){sp(550256,H-M|0);ac=c[137564]|0;break}if(M>>>0<=H>>>0){ac=N;break}Q=N+(H<<2)|0;if((Q|0)==(L|0)){ac=N;break}c[137565]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);ac=N}}while(0);N=c[ac+(O<<2)>>2]|0;if((N|0)==0){ad=ac}else{L=N+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f$[c[(c[N>>2]|0)+8>>2]&511](N|0)}ad=c[137564]|0}c[ad+(O<<2)>>2]=550240;c[137535]=0;c[137534]=54504;a[550144]=46;a[550145]=44;s_(550148,0,12);if((c[137786]|0)!=-1){c[x>>2]=551144;c[x+4>>2]=16;c[x+8>>2]=0;mU(551144,x)}N=c[137787]|0;L=N-1|0;I=c[137535]|0,c[137535]=I+1,I;H=c[137565]|0;M=c[137564]|0;J=H-M>>2;do{if(J>>>0>L>>>0){ae=M}else{if(J>>>0<N>>>0){sp(550256,N-J|0);ae=c[137564]|0;break}if(J>>>0<=N>>>0){ae=M;break}Q=M+(N<<2)|0;if((Q|0)==(H|0)){ae=M;break}c[137565]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);ae=M}}while(0);M=c[ae+(L<<2)>>2]|0;if((M|0)==0){af=ae}else{H=M+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){f$[c[(c[M>>2]|0)+8>>2]&511](M|0)}af=c[137564]|0}c[af+(L<<2)>>2]=550136;c[13253]=0;c[13252]=54456;c[13254]=46;c[13255]=44;s_(53024,0,12);if((c[137784]|0)!=-1){c[w>>2]=551136;c[w+4>>2]=16;c[w+8>>2]=0;mU(551136,w)}M=c[137785]|0;H=M-1|0;I=c[13253]|0,c[13253]=I+1,I;N=c[137565]|0;J=c[137564]|0;O=N-J>>2;do{if(O>>>0>H>>>0){ag=J}else{if(O>>>0<M>>>0){sp(550256,M-O|0);ag=c[137564]|0;break}if(O>>>0<=M>>>0){ag=J;break}Q=J+(M<<2)|0;if((Q|0)==(N|0)){ag=J;break}c[137565]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);ag=J}}while(0);J=c[ag+(H<<2)>>2]|0;if((J|0)==0){ah=ag}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){f$[c[(c[J>>2]|0)+8>>2]&511](J|0)}ah=c[137564]|0}c[ah+(H<<2)>>2]=53008;c[137551]=0;c[137550]=54888;if((c[137798]|0)!=-1){c[v>>2]=551192;c[v+4>>2]=16;c[v+8>>2]=0;mU(551192,v)}J=c[137799]|0;N=J-1|0;I=c[137551]|0,c[137551]=I+1,I;M=c[137565]|0;O=c[137564]|0;L=M-O>>2;do{if(L>>>0>N>>>0){ai=O}else{if(L>>>0<J>>>0){sp(550256,J-L|0);ai=c[137564]|0;break}if(L>>>0<=J>>>0){ai=O;break}Q=O+(J<<2)|0;if((Q|0)==(M|0)){ai=O;break}c[137565]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);ai=O}}while(0);O=c[ai+(N<<2)>>2]|0;if((O|0)==0){aj=ai}else{M=O+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){f$[c[(c[O>>2]|0)+8>>2]&511](O|0)}aj=c[137564]|0}c[aj+(N<<2)>>2]=550200;c[137549]=0;c[137548]=54816;if((c[137796]|0)!=-1){c[u>>2]=551184;c[u+4>>2]=16;c[u+8>>2]=0;mU(551184,u)}O=c[137797]|0;M=O-1|0;I=c[137549]|0,c[137549]=I+1,I;J=c[137565]|0;L=c[137564]|0;H=J-L>>2;do{if(H>>>0>M>>>0){ak=L}else{if(H>>>0<O>>>0){sp(550256,O-H|0);ak=c[137564]|0;break}if(H>>>0<=O>>>0){ak=L;break}Q=L+(O<<2)|0;if((Q|0)==(J|0)){ak=L;break}c[137565]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);ak=L}}while(0);L=c[ak+(M<<2)>>2]|0;if((L|0)==0){al=ak}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f$[c[(c[L>>2]|0)+8>>2]&511](L|0)}al=c[137564]|0}c[al+(M<<2)>>2]=550192;c[137547]=0;c[137546]=54752;if((c[137794]|0)!=-1){c[t>>2]=551176;c[t+4>>2]=16;c[t+8>>2]=0;mU(551176,t)}L=c[137795]|0;J=L-1|0;I=c[137547]|0,c[137547]=I+1,I;O=c[137565]|0;H=c[137564]|0;N=O-H>>2;do{if(N>>>0>J>>>0){am=H}else{if(N>>>0<L>>>0){sp(550256,L-N|0);am=c[137564]|0;break}if(N>>>0<=L>>>0){am=H;break}Q=H+(L<<2)|0;if((Q|0)==(O|0)){am=H;break}c[137565]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);am=H}}while(0);H=c[am+(J<<2)>>2]|0;if((H|0)==0){an=am}else{O=H+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){f$[c[(c[H>>2]|0)+8>>2]&511](H|0)}an=c[137564]|0}c[an+(J<<2)>>2]=550184;c[137545]=0;c[137544]=54688;if((c[137792]|0)!=-1){c[s>>2]=551168;c[s+4>>2]=16;c[s+8>>2]=0;mU(551168,s)}H=c[137793]|0;O=H-1|0;I=c[137545]|0,c[137545]=I+1,I;L=c[137565]|0;N=c[137564]|0;M=L-N>>2;do{if(M>>>0>O>>>0){ao=N}else{if(M>>>0<H>>>0){sp(550256,H-M|0);ao=c[137564]|0;break}if(M>>>0<=H>>>0){ao=N;break}Q=N+(H<<2)|0;if((Q|0)==(L|0)){ao=N;break}c[137565]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);ao=N}}while(0);N=c[ao+(O<<2)>>2]|0;if((N|0)==0){ap=ao}else{L=N+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f$[c[(c[N>>2]|0)+8>>2]&511](N|0)}ap=c[137564]|0}c[ap+(O<<2)>>2]=550176;c[137615]=0;c[137614]=56456;if((c[138002]|0)!=-1){c[r>>2]=552008;c[r+4>>2]=16;c[r+8>>2]=0;mU(552008,r)}N=c[138003]|0;L=N-1|0;I=c[137615]|0,c[137615]=I+1,I;H=c[137565]|0;M=c[137564]|0;J=H-M>>2;do{if(J>>>0>L>>>0){aq=M}else{if(J>>>0<N>>>0){sp(550256,N-J|0);aq=c[137564]|0;break}if(J>>>0<=N>>>0){aq=M;break}Q=M+(N<<2)|0;if((Q|0)==(H|0)){aq=M;break}c[137565]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);aq=M}}while(0);M=c[aq+(L<<2)>>2]|0;if((M|0)==0){ar=aq}else{H=M+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){f$[c[(c[M>>2]|0)+8>>2]&511](M|0)}ar=c[137564]|0}c[ar+(L<<2)>>2]=550456;c[137613]=0;c[137612]=56392;if((c[138e3]|0)!=-1){c[q>>2]=552e3;c[q+4>>2]=16;c[q+8>>2]=0;mU(552e3,q)}M=c[138001]|0;H=M-1|0;I=c[137613]|0,c[137613]=I+1,I;N=c[137565]|0;J=c[137564]|0;O=N-J>>2;do{if(O>>>0>H>>>0){as=J}else{if(O>>>0<M>>>0){sp(550256,M-O|0);as=c[137564]|0;break}if(O>>>0<=M>>>0){as=J;break}Q=J+(M<<2)|0;if((Q|0)==(N|0)){as=J;break}c[137565]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);as=J}}while(0);J=c[as+(H<<2)>>2]|0;if((J|0)==0){at=as}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){f$[c[(c[J>>2]|0)+8>>2]&511](J|0)}at=c[137564]|0}c[at+(H<<2)>>2]=550448;c[137611]=0;c[137610]=56328;if((c[137998]|0)!=-1){c[p>>2]=551992;c[p+4>>2]=16;c[p+8>>2]=0;mU(551992,p)}J=c[137999]|0;N=J-1|0;I=c[137611]|0,c[137611]=I+1,I;M=c[137565]|0;O=c[137564]|0;L=M-O>>2;do{if(L>>>0>N>>>0){au=O}else{if(L>>>0<J>>>0){sp(550256,J-L|0);au=c[137564]|0;break}if(L>>>0<=J>>>0){au=O;break}Q=O+(J<<2)|0;if((Q|0)==(M|0)){au=O;break}c[137565]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);au=O}}while(0);O=c[au+(N<<2)>>2]|0;if((O|0)==0){av=au}else{M=O+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){f$[c[(c[O>>2]|0)+8>>2]&511](O|0)}av=c[137564]|0}c[av+(N<<2)>>2]=550440;c[137609]=0;c[137608]=56264;if((c[137996]|0)!=-1){c[o>>2]=551984;c[o+4>>2]=16;c[o+8>>2]=0;mU(551984,o)}O=c[137997]|0;M=O-1|0;I=c[137609]|0,c[137609]=I+1,I;J=c[137565]|0;L=c[137564]|0;H=J-L>>2;do{if(H>>>0>M>>>0){aw=L}else{if(H>>>0<O>>>0){sp(550256,O-H|0);aw=c[137564]|0;break}if(H>>>0<=O>>>0){aw=L;break}Q=L+(O<<2)|0;if((Q|0)==(J|0)){aw=L;break}c[137565]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);aw=L}}while(0);L=c[aw+(M<<2)>>2]|0;if((L|0)==0){ax=aw}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f$[c[(c[L>>2]|0)+8>>2]&511](L|0)}ax=c[137564]|0}c[ax+(M<<2)>>2]=550432;c[137533]=0;c[137532]=54160;if((c[137774]|0)!=-1){c[n>>2]=551096;c[n+4>>2]=16;c[n+8>>2]=0;mU(551096,n)}L=c[137775]|0;J=L-1|0;I=c[137533]|0,c[137533]=I+1,I;O=c[137565]|0;H=c[137564]|0;N=O-H>>2;do{if(N>>>0>J>>>0){ay=H}else{if(N>>>0<L>>>0){sp(550256,L-N|0);ay=c[137564]|0;break}if(N>>>0<=L>>>0){ay=H;break}Q=H+(L<<2)|0;if((Q|0)==(O|0)){ay=H;break}c[137565]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);ay=H}}while(0);H=c[ay+(J<<2)>>2]|0;if((H|0)==0){az=ay}else{O=H+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){f$[c[(c[H>>2]|0)+8>>2]&511](H|0)}az=c[137564]|0}c[az+(J<<2)>>2]=550128;c[137531]=0;c[137530]=54120;if((c[137772]|0)!=-1){c[m>>2]=551088;c[m+4>>2]=16;c[m+8>>2]=0;mU(551088,m)}H=c[137773]|0;O=H-1|0;I=c[137531]|0,c[137531]=I+1,I;L=c[137565]|0;N=c[137564]|0;M=L-N>>2;do{if(M>>>0>O>>>0){aA=N}else{if(M>>>0<H>>>0){sp(550256,H-M|0);aA=c[137564]|0;break}if(M>>>0<=H>>>0){aA=N;break}Q=N+(H<<2)|0;if((Q|0)==(L|0)){aA=N;break}c[137565]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);aA=N}}while(0);N=c[aA+(O<<2)>>2]|0;if((N|0)==0){aB=aA}else{L=N+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f$[c[(c[N>>2]|0)+8>>2]&511](N|0)}aB=c[137564]|0}c[aB+(O<<2)>>2]=550120;c[137529]=0;c[137528]=54080;if((c[137770]|0)!=-1){c[l>>2]=551080;c[l+4>>2]=16;c[l+8>>2]=0;mU(551080,l)}N=c[137771]|0;L=N-1|0;I=c[137529]|0,c[137529]=I+1,I;H=c[137565]|0;M=c[137564]|0;J=H-M>>2;do{if(J>>>0>L>>>0){aC=M}else{if(J>>>0<N>>>0){sp(550256,N-J|0);aC=c[137564]|0;break}if(J>>>0<=N>>>0){aC=M;break}Q=M+(N<<2)|0;if((Q|0)==(H|0)){aC=M;break}c[137565]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);aC=M}}while(0);M=c[aC+(L<<2)>>2]|0;if((M|0)==0){aD=aC}else{H=M+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){f$[c[(c[M>>2]|0)+8>>2]&511](M|0)}aD=c[137564]|0}c[aD+(L<<2)>>2]=550112;c[137527]=0;c[137526]=54040;if((c[137768]|0)!=-1){c[k>>2]=551072;c[k+4>>2]=16;c[k+8>>2]=0;mU(551072,k)}M=c[137769]|0;H=M-1|0;I=c[137527]|0,c[137527]=I+1,I;N=c[137565]|0;J=c[137564]|0;O=N-J>>2;do{if(O>>>0>H>>>0){aE=J}else{if(O>>>0<M>>>0){sp(550256,M-O|0);aE=c[137564]|0;break}if(O>>>0<=M>>>0){aE=J;break}Q=J+(M<<2)|0;if((Q|0)==(N|0)){aE=J;break}c[137565]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);aE=J}}while(0);J=c[aE+(H<<2)>>2]|0;if((J|0)==0){aF=aE}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){f$[c[(c[J>>2]|0)+8>>2]&511](J|0)}aF=c[137564]|0}c[aF+(H<<2)>>2]=550104;c[13249]=0;c[13248]=54360;c[13250]=54408;if((c[137782]|0)!=-1){c[j>>2]=551128;c[j+4>>2]=16;c[j+8>>2]=0;mU(551128,j)}J=c[137783]|0;N=J-1|0;I=c[13249]|0,c[13249]=I+1,I;M=c[137565]|0;O=c[137564]|0;L=M-O>>2;do{if(L>>>0>N>>>0){aG=O}else{if(L>>>0<J>>>0){sp(550256,J-L|0);aG=c[137564]|0;break}if(L>>>0<=J>>>0){aG=O;break}Q=O+(J<<2)|0;if((Q|0)==(M|0)){aG=O;break}c[137565]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);aG=O}}while(0);O=c[aG+(N<<2)>>2]|0;if((O|0)==0){aH=aG}else{M=O+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){f$[c[(c[O>>2]|0)+8>>2]&511](O|0)}aH=c[137564]|0}c[aH+(N<<2)>>2]=52992;c[13245]=0;c[13244]=54264;c[13246]=54312;if((c[137780]|0)!=-1){c[h>>2]=551120;c[h+4>>2]=16;c[h+8>>2]=0;mU(551120,h)}O=c[137781]|0;M=O-1|0;I=c[13245]|0,c[13245]=I+1,I;J=c[137565]|0;L=c[137564]|0;H=J-L>>2;do{if(H>>>0>M>>>0){aI=L}else{if(H>>>0<O>>>0){sp(550256,O-H|0);aI=c[137564]|0;break}if(H>>>0<=O>>>0){aI=L;break}Q=L+(O<<2)|0;if((Q|0)==(J|0)){aI=L;break}c[137565]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);aI=L}}while(0);L=c[aI+(M<<2)>>2]|0;if((L|0)==0){aJ=aI}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f$[c[(c[L>>2]|0)+8>>2]&511](L|0)}aJ=c[137564]|0}c[aJ+(M<<2)>>2]=52976;c[13241]=0;c[13240]=55264;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);c[13242]=c[137522];c[13240]=54232;if((c[137778]|0)!=-1){c[g>>2]=551112;c[g+4>>2]=16;c[g+8>>2]=0;mU(551112,g)}M=c[137779]|0;L=M-1|0;I=c[13241]|0,c[13241]=I+1,I;J=c[137565]|0;O=c[137564]|0;H=J-O>>2;do{if(H>>>0>L>>>0){aK=O}else{if(H>>>0<M>>>0){sp(550256,M-H|0);aK=c[137564]|0;break}if(H>>>0<=M>>>0){aK=O;break}N=O+(M<<2)|0;if((N|0)==(J|0)){aK=O;break}c[137565]=J+(~((J-4+(-N|0)|0)>>>2)<<2);aK=O}}while(0);O=c[aK+(L<<2)>>2]|0;if((O|0)==0){aL=aK}else{J=O+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f$[c[(c[O>>2]|0)+8>>2]&511](O|0)}aL=c[137564]|0}c[aL+(L<<2)>>2]=52960;c[13237]=0;c[13236]=55264;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);c[13238]=c[137522];c[13236]=54200;if((c[137776]|0)!=-1){c[f>>2]=551104;c[f+4>>2]=16;c[f+8>>2]=0;mU(551104,f)}L=c[137777]|0;O=L-1|0;I=c[13237]|0,c[13237]=I+1,I;J=c[137565]|0;M=c[137564]|0;H=J-M>>2;do{if(H>>>0>O>>>0){aM=M}else{if(H>>>0<L>>>0){sp(550256,L-H|0);aM=c[137564]|0;break}if(H>>>0<=L>>>0){aM=M;break}N=M+(L<<2)|0;if((N|0)==(J|0)){aM=M;break}c[137565]=J+(~((J-4+(-N|0)|0)>>>2)<<2);aM=M}}while(0);M=c[aM+(O<<2)>>2]|0;if((M|0)==0){aN=aM}else{J=M+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){f$[c[(c[M>>2]|0)+8>>2]&511](M|0)}aN=c[137564]|0}c[aN+(O<<2)>>2]=52944;c[137543]=0;c[137542]=54592;if((c[137790]|0)!=-1){c[e>>2]=551160;c[e+4>>2]=16;c[e+8>>2]=0;mU(551160,e)}M=c[137791]|0;J=M-1|0;I=c[137543]|0,c[137543]=I+1,I;L=c[137565]|0;H=c[137564]|0;N=L-H>>2;do{if(N>>>0>J>>>0){aO=H}else{if(N>>>0<M>>>0){sp(550256,M-N|0);aO=c[137564]|0;break}if(N>>>0<=M>>>0){aO=H;break}Q=H+(M<<2)|0;if((Q|0)==(L|0)){aO=H;break}c[137565]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);aO=H}}while(0);H=c[aO+(J<<2)>>2]|0;if((H|0)==0){aP=aO}else{L=H+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){f$[c[(c[H>>2]|0)+8>>2]&511](H|0)}aP=c[137564]|0}c[aP+(J<<2)>>2]=550168;c[137541]=0;c[137540]=54552;if((c[137788]|0)!=-1){c[d>>2]=551152;c[d+4>>2]=16;c[d+8>>2]=0;mU(551152,d)}H=c[137789]|0;L=H-1|0;I=c[137541]|0,c[137541]=I+1,I;M=c[137565]|0;N=c[137564]|0;O=M-N>>2;do{if(O>>>0>L>>>0){aQ=N}else{if(O>>>0<H>>>0){sp(550256,H-O|0);aQ=c[137564]|0;break}if(O>>>0<=H>>>0){aQ=N;break}Q=N+(H<<2)|0;if((Q|0)==(M|0)){aQ=N;break}c[137565]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);aQ=N}}while(0);N=c[aQ+(L<<2)>>2]|0;if((N|0)==0){aR=aQ}else{M=N+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){f$[c[(c[N>>2]|0)+8>>2]&511](N|0)}aR=c[137564]|0}c[aR+(L<<2)>>2]=550160;c[137518]=550248}}while(0);aR=c[137518]|0;c[137520]=aR;aQ=aR+4|0;I=c[aQ>>2]|0,c[aQ>>2]=I+1,I;c[137516]=550080;G=c[137516]|0;i=b;return G|0}function q0(a,b){a=a|0;b=b|0;return b|0}function q1(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[f>>2]=d;c[i>>2]=g;return 3}function q2(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[f>>2]=d;c[i>>2]=g;return 3}function q3(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;return 3}function q4(a){a=a|0;return 1}function q5(a){a=a|0;return 1}function q6(a){a=a|0;return 1}function q7(a,b){a=a|0;b=b|0;return b<<24>>24|0}function q8(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b&255:c)|0}function q9(a,b,c){a=a|0;b=b|0;c=c|0;return(b<<24>>24>-1?b:c)|0}function ra(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b=d-c|0;return(b>>>0<e>>>0?b:e)|0}function rb(a){a=a|0;c[a+4>>2]=(I=c[137812]|0,c[137812]=I+1,I)+1;return}function rc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((d|0)==(e|0)){g=d;return g|0}else{h=d;i=f}while(1){c[i>>2]=a[h]|0;f=h+1|0;if((f|0)==(e|0)){g=e;break}else{h=f;i=i+4|0}}return g|0}function rd(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((d|0)==(e|0)){h=d;return h|0}b=(e-4+(-d|0)|0)>>>2;i=d;j=g;while(1){g=c[i>>2]|0;a[j]=g>>>0<128?g&255:f;g=i+4|0;if((g|0)==(e|0)){break}else{i=g;j=j+1|0}}h=d+(b+1<<2)|0;return h|0}function re(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((c|0)==(d|0)){f=c;return f|0}else{g=c;h=e}while(1){a[h]=a[g]|0;e=g+1|0;if((e|0)==(d|0)){f=d;break}else{g=e;h=h+1|0}}return f|0}function rf(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((c|0)==(d|0)){g=c;return g|0}else{h=c;i=f}while(1){f=a[h]|0;a[i]=f<<24>>24>-1?f:e;f=h+1|0;if((f|0)==(d|0)){g=d;break}else{h=f;i=i+1|0}}return g|0}function rg(a){a=a|0;if((a|0)==0){return}sS(a);return}function rh(a){a=a|0;if((a|0)==0){return}f$[c[(c[a>>2]|0)+4>>2]&511](a);return}function ri(a){a=a|0;if((a|0)==0){return}sS(a);return}function rj(b){b=b|0;var d=0;c[b>>2]=55408;d=c[b+8>>2]|0;do{if((d|0)!=0){if((a[b+12|0]&1)!=0){sS(d)}if((b|0)!=0){break}return}}while(0);sS(b);return}function rk(b){b=b|0;var d=0;c[b>>2]=55408;d=c[b+8>>2]|0;if((d|0)==0){return}if((a[b+12|0]&1)==0){return}sS(d);return}function rl(a){a=a|0;if((a|0)==0){return}sS(a);return}function rm(a,d,e){a=a|0;d=d|0;e=e|0;var f=0;if(e>>>0>=128){f=0;return f|0}f=(b[(c[(cC()|0)>>2]|0)+(e<<1)>>1]&d)<<16>>16!=0;return f|0}function rn(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((d|0)==(e|0)){g=d;return g|0}else{h=d;i=f}while(1){f=c[h>>2]|0;if(f>>>0<128){j=b[(c[(cC()|0)>>2]|0)+(f<<1)>>1]|0}else{j=0}b[i>>1]=j;f=h+4|0;if((f|0)==(e|0)){g=e;break}else{h=f;i=i+2|0}}return g|0}function ro(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((e|0)==(f|0)){g=e;return g|0}else{h=e}while(1){e=c[h>>2]|0;if(e>>>0<128){if((b[(c[(cC()|0)>>2]|0)+(e<<1)>>1]&d)<<16>>16!=0){g=h;i=6379;break}}e=h+4|0;if((e|0)==(f|0)){g=f;i=6380;break}else{h=e}}if((i|0)==6379){return g|0}else if((i|0)==6380){return g|0}return 0}function rp(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=e;while(1){if((a|0)==(f|0)){g=f;h=6390;break}e=c[a>>2]|0;if(e>>>0>=128){g=a;h=6388;break}if((b[(c[(cC()|0)>>2]|0)+(e<<1)>>1]&d)<<16>>16==0){g=a;h=6389;break}else{a=a+4|0}}if((h|0)==6388){return g|0}else if((h|0)==6390){return g|0}else if((h|0)==6389){return g|0}return 0}function rq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>=128){d=b;return d|0}d=c[(c[(fn()|0)>>2]|0)+(b<<2)>>2]|0;return d|0}function rr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==(d|0)){e=b;return e|0}else{f=b}while(1){b=c[f>>2]|0;if(b>>>0<128){g=c[(c[(fn()|0)>>2]|0)+(b<<2)>>2]|0}else{g=b}c[f>>2]=g;b=f+4|0;if((b|0)==(d|0)){e=d;break}else{f=b}}return e|0}function rs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>=128){d=b;return d|0}d=c[(c[(ft()|0)>>2]|0)+(b<<2)>>2]|0;return d|0}function rt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==(d|0)){e=b;return e|0}else{f=b}while(1){b=c[f>>2]|0;if(b>>>0<128){g=c[(c[(ft()|0)>>2]|0)+(b<<2)>>2]|0}else{g=b}c[f>>2]=g;b=f+4|0;if((b|0)==(d|0)){e=d;break}else{f=b}}return e|0}function ru(a,b){a=a|0;b=b|0;var d=0;if(b<<24>>24<=-1){d=b;return d|0}d=c[(c[(fn()|0)>>2]|0)+((b&255)<<2)>>2]&255;return d|0}function rv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==(e|0)){f=d;return f|0}else{g=d}while(1){d=a[g]|0;if(d<<24>>24>-1){h=c[(c[(fn()|0)>>2]|0)+(d<<24>>24<<2)>>2]&255}else{h=d}a[g]=h;d=g+1|0;if((d|0)==(e|0)){f=e;break}else{g=d}}return f|0}function rw(a,b){a=a|0;b=b|0;var d=0;if(b<<24>>24<=-1){d=b;return d|0}d=c[(c[(ft()|0)>>2]|0)+(b<<24>>24<<2)>>2]&255;return d|0}function rx(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==(e|0)){f=d;return f|0}else{g=d}while(1){d=a[g]|0;if(d<<24>>24>-1){h=c[(c[(ft()|0)>>2]|0)+(d<<24>>24<<2)>>2]&255}else{h=d}a[g]=h;d=g+1|0;if((d|0)==(e|0)){f=e;break}else{g=d}}return f|0}function ry(b){b=b|0;var d=0,e=0;c[b>>2]=55040;d=b+8|0;e=c[d>>2]|0;do{if((a[682976]|0)==0){if((cQ(682976)|0)==0){break}c[137522]=bN(1,41064,0)|0}}while(0);if((e|0)!=(c[137522]|0)){cE(c[d>>2]|0)}if((b|0)==0){return}sS(b);return}function rz(a){a=a|0;return 0}function rA(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;d=i;i=i+264|0;l=d|0;m=d+8|0;n=e;while(1){if((n|0)==(f|0)){o=f;break}if((c[n>>2]|0)==0){o=n;break}else{n=n+4|0}}c[k>>2]=h;c[g>>2]=e;L7462:do{if((e|0)==(f|0)|(h|0)==(j|0)){p=e}else{n=j;q=b+8|0;r=m|0;s=l|0;t=h;u=e;v=o;while(1){w=v-u>>2;x=eC(c[q>>2]|0)|0;y=c[g>>2]|0;z=(t|0)!=0;A=z?n-t|0:256;B=z?t:r;L7466:do{if((y|0)==0|(A|0)==0){C=0;D=w;E=A;F=B;G=y}else{H=A;I=w;J=0;K=B;L=y;while(1){M=I>>>0>=H>>>0;if(!(M|I>>>0>32)){C=J;D=I;E=H;F=K;G=L;break L7466}N=M?H:I;M=I-N|0;L7470:do{if((K|0)==0){O=c[L>>2]|0;if((O|0)==0){P=0;Q=L;break}else{R=0;S=L;T=O}while(1){if(T>>>0>127){O=sD(s,T)|0;if((O|0)==-1){C=-1;D=M;E=0;F=K;G=L;break L7466}else{U=O}}else{U=1}O=U+R|0;V=S+4|0;W=c[V>>2]|0;if((W|0)==0){X=O;Y=L;Z=6500;break}else{R=O;S=V;T=W}}}else{L7478:do{if(N>>>0>3){W=N;V=K;O=L;while(1){_=c[O>>2]|0;if((_|0)==0){$=W;aa=V;ab=O;Z=6490;break L7478}if(_>>>0>127){ac=sD(V,_)|0;if((ac|0)==-1){C=-1;D=M;E=0;F=K;G=O;break L7466}ad=V+ac|0;ae=W-ac|0;af=O}else{a[V]=_&255;ad=V+1|0;ae=W-1|0;af=O}_=af+4|0;if(ae>>>0>3){W=ae;V=ad;O=_}else{ag=ae;ah=ad;ai=_;Z=6484;break}}}else{ag=N;ah=K;ai=L;Z=6484}}while(0);if((Z|0)==6484){Z=0;if((ag|0)==0){aj=0}else{$=ag;aa=ah;ab=ai;Z=6490}}L7489:do{if((Z|0)==6490){while(1){Z=0;O=c[ab>>2]|0;if((O|0)==0){Z=6498;break}if(O>>>0>127){V=sD(s,O)|0;if((V|0)==-1){C=-1;D=M;E=0;F=K;G=ab;break L7466}if(V>>>0>$>>>0){Z=6494;break}W=c[ab>>2]|0;sD(aa,W)|0;ak=aa+V|0;al=$-V|0;am=ab}else{a[aa]=O&255;ak=aa+1|0;al=$-1|0;am=ab}if((al|0)==0){aj=0;break L7489}else{$=al;aa=ak;ab=am+4|0;Z=6490}}if((Z|0)==6498){Z=0;a[aa]=0;aj=$;break}else if((Z|0)==6494){Z=0;X=N-$|0;Y=ab;Z=6500;break L7470}}}while(0);X=N-aj|0;Y=0;Z=6500}}while(0);if((Z|0)==6500){Z=0;if((X|0)==-1){C=-1;D=M;E=0;F=K;G=Y;break L7466}else{P=X;Q=Y}}if((K|0)==(r|0)){an=r;ao=H}else{an=K+P|0;ao=H-P|0}N=P+J|0;if((Q|0)==0|(ao|0)==0){C=N;D=M;E=ao;F=an;G=Q;break}else{H=ao;I=M;J=N;K=an;L=Q}}}}while(0);L7510:do{if((G|0)==0){ap=C;aq=0}else{if((E|0)==0|(D|0)==0){ap=C;aq=G;break}else{ar=E;as=D;at=C;au=F;av=G}while(1){aw=sD(au,c[av>>2]|0)|0;if((aw+1|0)>>>0<2){break}y=av+4|0;B=as-1|0;w=at+1|0;if((ar|0)==(aw|0)|(B|0)==0){ap=w;aq=y;break L7510}else{ar=ar-aw|0;as=B;at=w;au=au+aw|0;av=y}}y=(aw|0)==0;ap=y?at:-1;aq=y?0:av}}while(0);if(z){c[g>>2]=aq}if((x|0)!=0){eC(x|0)|0}if((ap|0)==(-1|0)){Z=6515;break}else if((ap|0)==0){ax=1;Z=6537;break}y=(c[k>>2]|0)+ap|0;c[k>>2]=y;if((y|0)==(j|0)){Z=6534;break}if((v|0)==(f|0)){ay=f;az=y;aA=c[g>>2]|0}else{y=eC(c[q>>2]|0)|0;if((y|0)!=0){eC(y|0)|0}y=c[k>>2]|0;if((y|0)==(j|0)){ax=1;Z=6540;break}c[k>>2]=y+1;a[y]=0;y=(c[g>>2]|0)+4|0;c[g>>2]=y;w=y;while(1){if((w|0)==(f|0)){aB=f;break}if((c[w>>2]|0)==0){aB=w;break}else{w=w+4|0}}ay=aB;az=c[k>>2]|0;aA=y}if((aA|0)==(f|0)|(az|0)==(j|0)){p=aA;break L7462}else{t=az;u=aA;v=ay}}if((Z|0)==6515){c[k>>2]=t;L7539:do{if((u|0)==(c[g>>2]|0)){aC=u}else{v=u;r=t;while(1){s=c[v>>2]|0;n=eC(c[q>>2]|0)|0;w=sD(r,s)|0;if((n|0)!=0){eC(n|0)|0}if((w|0)==-1){aC=v;break L7539}n=(c[k>>2]|0)+w|0;c[k>>2]=n;w=v+4|0;if((w|0)==(c[g>>2]|0)){aC=w;break}else{v=w;r=n}}}}while(0);c[g>>2]=aC;ax=2;i=d;return ax|0}else if((Z|0)==6534){p=c[g>>2]|0;break}else if((Z|0)==6537){i=d;return ax|0}else if((Z|0)==6540){i=d;return ax|0}}}while(0);ax=(p|0)!=(f|0)|0;i=d;return ax|0}function rB(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;l=i;i=i+1040|0;m=l|0;n=l+1024|0;o=l+1032|0;p=o;q=e;while(1){if((q|0)==(f|0)){r=f;break}if((a[q]|0)==0){r=q;break}else{q=q+1|0}}c[k>>2]=h;c[g>>2]=e;L7558:do{if((e|0)==(f|0)|(h|0)==(j|0)){s=e}else{q=d;t=j;u=b+8|0;v=m|0;w=d|0;x=h;y=e;z=r;while(1){A=c[q+4>>2]|0;c[o>>2]=c[q>>2];c[o+4>>2]=A;B=z;A=B-y|0;C=eC(c[u>>2]|0)|0;D=c[g>>2]|0;c[n>>2]=D;E=(x|0)!=0;F=E?t-x>>2:256;G=E?x:v;L7562:do{if((D|0)==0|(F|0)==0){H=0;I=A;J=F;K=G;L=D}else{M=F;N=A;O=0;P=G;Q=D;while(1){R=N>>>2;S=R>>>0>=M>>>0;if(!(S|N>>>0>131)){H=O;I=N;J=M;K=P;L=Q;break L7562}T=S?M:R;U=N-T|0;R=sC(P,n,T,d)|0;if((R|0)==-1){break}if((P|0)==(v|0)){V=v;W=M}else{V=P+(R<<2)|0;W=M-R|0}T=R+O|0;R=c[n>>2]|0;if((R|0)==0|(W|0)==0){H=T;I=U;J=W;K=V;L=R;break L7562}else{M=W;N=U;O=T;P=V;Q=R}}H=-1;I=U;J=0;K=P;L=c[n>>2]|0}}while(0);L7572:do{if((L|0)==0){X=H;Y=0}else{if((J|0)==0|(I|0)==0){X=H;Y=L;break}else{Z=J;_=I;$=H;aa=K;ab=L}while(1){ac=sv(aa,ab,_,d)|0;if((ac+2|0)>>>0<3){break}D=ab+ac|0;c[n>>2]=D;G=Z-1|0;A=$+1|0;if((G|0)==0|(_|0)==(ac|0)){X=A;Y=D;break L7572}else{Z=G;_=_-ac|0;$=A;aa=aa+4|0;ab=D}}if((ac|0)==0){c[n>>2]=0;X=$;Y=0;break}else if((ac|0)==(-1|0)){X=-1;Y=ab;break}else{c[w>>2]=0;X=$;Y=ab;break}}}while(0);if(E){c[g>>2]=Y}if((C|0)!=0){eC(C|0)|0}if((X|0)==(-1|0)){ad=6566;break}else if((X|0)==0){ae=2;ad=6592;break}P=(c[k>>2]|0)+(X<<2)|0;c[k>>2]=P;if((P|0)==(j|0)){ad=6588;break}D=c[g>>2]|0;if((z|0)==(f|0)){af=f;ag=P;ah=D}else{A=eC(c[u>>2]|0)|0;G=sv(P,D,1,d)|0;if((A|0)!=0){eC(A|0)|0}if((G|0)!=0){ae=2;ad=6596;break}c[k>>2]=(c[k>>2]|0)+4;G=(c[g>>2]|0)+1|0;c[g>>2]=G;A=G;while(1){if((A|0)==(f|0)){ai=f;break}if((a[A]|0)==0){ai=A;break}else{A=A+1|0}}af=ai;ag=c[k>>2]|0;ah=G}if((ah|0)==(f|0)|(ag|0)==(j|0)){s=ah;break L7558}else{x=ag;y=ah;z=af}}if((ad|0)==6596){i=l;return ae|0}else if((ad|0)==6566){c[k>>2]=x;L7604:do{if((y|0)==(c[g>>2]|0)){aj=y}else{z=x;w=y;while(1){v=eC(c[u>>2]|0)|0;t=sv(z,w,B-w|0,p)|0;if((v|0)!=0){eC(v|0)|0}if((t|0)==0){ak=w+1|0}else if((t|0)==(-1|0)){ad=6572;break}else if((t|0)==(-2|0)){ad=6573;break}else{ak=w+t|0}t=(c[k>>2]|0)+4|0;c[k>>2]=t;if((ak|0)==(c[g>>2]|0)){aj=ak;break L7604}else{z=t;w=ak}}if((ad|0)==6572){c[g>>2]=w;ae=2;i=l;return ae|0}else if((ad|0)==6573){c[g>>2]=w;ae=1;i=l;return ae|0}}}while(0);c[g>>2]=aj;ae=(aj|0)!=(f|0)|0;i=l;return ae|0}else if((ad|0)==6592){i=l;return ae|0}else if((ad|0)==6588){s=c[g>>2]|0;break}}}while(0);ae=(s|0)!=(f|0)|0;i=l;return ae|0}function rC(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;d=eC(c[a+8>>2]|0)|0;if((d|0)==0){return 0}eC(d|0)|0;return 0}function rD(a){a=a|0;var b=0,d=0,e=0;b=a+8|0;a=eC(c[b>>2]|0)|0;if((a|0)!=0){eC(a|0)|0}a=c[b>>2]|0;if((a|0)==0){return 1}b=eC(a|0)|0;a=dy()|0;if((b|0)==0){d=(a|0)==1;e=d&1;return e|0}eC(b|0)|0;d=(a|0)==1;e=d&1;return e|0}function rE(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)==0|(d|0)==(e|0)){g=0;return g|0}h=e;i=a+8|0;a=(b|0)!=0?b:256368;b=d;d=0;j=0;while(1){k=eC(c[i>>2]|0)|0;l=sv(0,b,h-b|0,a)|0;if((k|0)!=0){eC(k|0)|0}if((l|0)==0){m=1;n=b+1|0}else if((l|0)==(-1|0)|(l|0)==(-2|0)){g=d;o=6633;break}else{m=l;n=b+l|0}l=m+d|0;k=j+1|0;if(k>>>0>=f>>>0|(n|0)==(e|0)){g=l;o=6634;break}else{b=n;d=l;j=k}}if((o|0)==6634){return g|0}else if((o|0)==6633){return g|0}return 0}function rF(a){a=a|0;var b=0,d=0,e=0;b=c[a+8>>2]|0;do{if((b|0)==0){d=1}else{a=eC(b|0)|0;e=dy()|0;if((a|0)==0){d=e;break}eC(a|0)|0;d=e}}while(0);return d|0}function rG(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;return 3}function rH(a){a=a|0;return 0}function rI(a){a=a|0;return 0}function rJ(a){a=a|0;return 4}function rK(d,f,g,h,i,j,k,l){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=h;L7672:do{if(g>>>0<h>>>0){d=k;m=j;n=g;while(1){o=b[n>>1]|0;p=o&65535;do{if((o&65535)<128){if((d-m|0)<1){q=1;r=m;s=n;break L7672}a[m]=o&255;t=m+1|0;u=n}else{if((o&65535)<2048){if((d-m|0)<2){q=1;r=m;s=n;break L7672}a[m]=(p>>>6|192)&255;a[m+1|0]=(p&63|128)&255;t=m+2|0;u=n;break}if((o&65535)<55296){if((d-m|0)<3){q=1;r=m;s=n;break L7672}a[m]=(p>>>12|224)&255;a[m+1|0]=(p>>>6&63|128)&255;a[m+2|0]=(p&63|128)&255;t=m+3|0;u=n;break}if((o&65535)>=56320){if((o&65535)<57344){q=2;r=m;s=n;break L7672}if((d-m|0)<3){q=1;r=m;s=n;break L7672}a[m]=(p>>>12|224)&255;a[m+1|0]=(p>>>6&63|128)&255;a[m+2|0]=(p&63|128)&255;t=m+3|0;u=n;break}if((f-n|0)<4){q=1;r=m;s=n;break L7672}v=n+2|0;w=e[v>>1]|0;if((w&64512|0)!=56320){q=2;r=m;s=n;break L7672}if((d-m|0)<4){q=1;r=m;s=n;break L7672}x=p&960;if(((x<<10)+65536|0)>>>0>1114111){q=2;r=m;s=n;break L7672}y=(x>>>6)+1|0;a[m]=(y>>>2|240)&255;a[m+1|0]=(p>>>2&15|y<<4&48|128)&255;a[m+2|0]=(p<<4&48|w>>>6&15|128)&255;a[m+3|0]=(w&63|128)&255;t=m+4|0;u=v}}while(0);p=u+2|0;if(p>>>0<h>>>0){m=t;n=p}else{q=0;r=t;s=p;break}}}else{q=0;r=j;s=g}}while(0);c[i>>2]=g+(s-g>>1<<1);c[l>>2]=j+(r-j);return q|0}function rL(e,f,g,h,i,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;L7700:do{if(g>>>0<h>>>0){f=h;e=k;m=j;n=g;while(1){if(m>>>0>=k>>>0){o=m;p=n;q=6703;break L7700}r=a[n]|0;s=r&255;do{if(r<<24>>24>-1){b[m>>1]=r&255;t=m;u=n+1|0}else{if((r&255)<194){v=2;w=m;x=n;break L7700}if((r&255)<224){if((f-n|0)<2){v=1;w=m;x=n;break L7700}y=d[n+1|0]|0;if((y&192|0)!=128){v=2;w=m;x=n;break L7700}b[m>>1]=(y&63|s<<6&1984)&65535;t=m;u=n+2|0;break}if((r&255)<240){if((f-n|0)<3){v=1;w=m;x=n;break L7700}y=a[n+1|0]|0;z=a[n+2|0]|0;if((s|0)==224){if((y&-32)<<24>>24!=-96){v=2;w=m;x=n;break L7700}}else if((s|0)==237){if((y&-32)<<24>>24!=-128){v=2;w=m;x=n;break L7700}}else{if((y&-64)<<24>>24!=-128){v=2;w=m;x=n;break L7700}}A=z&255;if((A&192|0)!=128){v=2;w=m;x=n;break L7700}b[m>>1]=((y&255)<<6&4032|s<<12|A&63)&65535;t=m;u=n+3|0;break}if((r&255)>=245){v=2;w=m;x=n;break L7700}if((f-n|0)<4){v=1;w=m;x=n;break L7700}A=a[n+1|0]|0;y=a[n+2|0]|0;z=a[n+3|0]|0;if((s|0)==240){if((A+112&255)>=48){v=2;w=m;x=n;break L7700}}else if((s|0)==244){if((A&-16)<<24>>24!=-128){v=2;w=m;x=n;break L7700}}else{if((A&-64)<<24>>24!=-128){v=2;w=m;x=n;break L7700}}B=y&255;if((B&192|0)!=128){v=2;w=m;x=n;break L7700}y=z&255;if((y&192|0)!=128){v=2;w=m;x=n;break L7700}if((e-m|0)<4){v=1;w=m;x=n;break L7700}z=s&7;C=A&255;if((C<<12&196608|z<<18)>>>0>1114111){v=2;w=m;x=n;break L7700}b[m>>1]=(C<<2&60|B>>>4&3|((C>>>4&3|z<<2)<<6)+16320|55296)&65535;z=m+2|0;b[z>>1]=(B<<6&960|y&63|56320)&65535;t=z;u=n+4|0}}while(0);s=t+2|0;if(u>>>0<h>>>0){m=s;n=u}else{o=s;p=u;q=6703;break}}}else{o=j;p=g;q=6703}}while(0);if((q|0)==6703){v=p>>>0<h>>>0|0;w=o;x=p}c[i>>2]=g+(x-g);c[l>>2]=j+(w-j>>1<<1);return v|0}function rM(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;L7740:do{if(d>>>0<e>>>0&(f|0)!=0){c=e;b=0;g=d;L7742:while(1){h=a[g]|0;i=h&255;do{if(h<<24>>24>-1){j=g+1|0;k=b}else{if((h&255)<194){l=g;break L7740}if((h&255)<224){if((c-g|0)<2){l=g;break L7740}if((a[g+1|0]&-64)<<24>>24!=-128){l=g;break L7740}j=g+2|0;k=b;break}if((h&255)<240){m=g;if((c-m|0)<3){l=g;break L7740}n=a[g+1|0]|0;o=a[g+2|0]|0;if((i|0)==237){if((n&-32)<<24>>24!=-128){p=6720;break L7742}}else if((i|0)==224){if((n&-32)<<24>>24!=-96){p=6718;break L7742}}else{if((n&-64)<<24>>24!=-128){p=6722;break L7742}}if((o&-64)<<24>>24!=-128){l=g;break L7740}j=g+3|0;k=b;break}if((h&255)>=245){l=g;break L7740}q=g;if((c-q|0)<4){l=g;break L7740}if((f-b|0)>>>0<2){l=g;break L7740}o=a[g+1|0]|0;n=a[g+2|0]|0;r=a[g+3|0]|0;if((i|0)==244){if((o&-16)<<24>>24!=-128){p=6732;break L7742}}else if((i|0)==240){if((o+112&255)>=48){p=6730;break L7742}}else{if((o&-64)<<24>>24!=-128){p=6734;break L7742}}if((n&-64)<<24>>24!=-128){l=g;break L7740}if((r&-64)<<24>>24!=-128){l=g;break L7740}if(((o&255)<<12&196608|i<<18&1835008)>>>0>1114111){l=g;break L7740}j=g+4|0;k=b+1|0}}while(0);i=k+1|0;if(j>>>0<e>>>0&i>>>0<f>>>0){b=i;g=j}else{l=j;break L7740}}if((p|0)==6734){s=q-d|0;return s|0}else if((p|0)==6718){s=m-d|0;return s|0}else if((p|0)==6720){s=m-d|0;return s|0}else if((p|0)==6722){s=m-d|0;return s|0}else if((p|0)==6732){s=q-d|0;return s|0}else if((p|0)==6730){s=q-d|0;return s|0}}else{l=d}}while(0);s=l-d|0;return s|0}function rN(b,d,e,f,g,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;L7791:do{if(e>>>0<f>>>0){d=i;b=h;k=e;while(1){l=c[k>>2]|0;if((l&-2048|0)==55296|l>>>0>1114111){m=2;n=b;o=k;break L7791}do{if(l>>>0<128){if((d-b|0)<1){m=1;n=b;o=k;break L7791}a[b]=l&255;p=b+1|0}else{if(l>>>0<2048){if((d-b|0)<2){m=1;n=b;o=k;break L7791}a[b]=(l>>>6|192)&255;a[b+1|0]=(l&63|128)&255;p=b+2|0;break}q=d-b|0;if(l>>>0<65536){if((q|0)<3){m=1;n=b;o=k;break L7791}a[b]=(l>>>12|224)&255;a[b+1|0]=(l>>>6&63|128)&255;a[b+2|0]=(l&63|128)&255;p=b+3|0;break}else{if((q|0)<4){m=1;n=b;o=k;break L7791}a[b]=(l>>>18|240)&255;a[b+1|0]=(l>>>12&63|128)&255;a[b+2|0]=(l>>>6&63|128)&255;a[b+3|0]=(l&63|128)&255;p=b+4|0;break}}}while(0);l=k+4|0;if(l>>>0<f>>>0){b=p;k=l}else{m=0;n=p;o=l;break}}}else{m=0;n=h;o=e}}while(0);c[g>>2]=e+(o-e>>2<<2);c[j>>2]=h+(n-h);return m|0}function rO(a){a=a|0;if((a|0)==0){return}sS(a);return}function rP(a){a=a|0;if((a|0)==0){return}sS(a);return}function rQ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;return 3}function rR(a){a=a|0;return 0}function rS(a){a=a|0;return 0}function rT(a){a=a|0;return 4}function rU(b,e,f,g,h,i,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;L7826:do{if(f>>>0<g>>>0){e=g;b=i;l=f;while(1){if(b>>>0>=j>>>0){m=b;n=l;o=6808;break L7826}p=a[l]|0;q=p&255;do{if(p<<24>>24>-1){c[b>>2]=q;r=l+1|0}else{if((p&255)<194){s=2;t=b;u=l;break L7826}if((p&255)<224){if((e-l|0)<2){s=1;t=b;u=l;break L7826}v=d[l+1|0]|0;if((v&192|0)!=128){s=2;t=b;u=l;break L7826}c[b>>2]=v&63|q<<6&1984;r=l+2|0;break}if((p&255)<240){if((e-l|0)<3){s=1;t=b;u=l;break L7826}v=a[l+1|0]|0;w=a[l+2|0]|0;if((q|0)==224){if((v&-32)<<24>>24!=-96){s=2;t=b;u=l;break L7826}}else if((q|0)==237){if((v&-32)<<24>>24!=-128){s=2;t=b;u=l;break L7826}}else{if((v&-64)<<24>>24!=-128){s=2;t=b;u=l;break L7826}}x=w&255;if((x&192|0)!=128){s=2;t=b;u=l;break L7826}c[b>>2]=(v&255)<<6&4032|q<<12&61440|x&63;r=l+3|0;break}if((p&255)>=245){s=2;t=b;u=l;break L7826}if((e-l|0)<4){s=1;t=b;u=l;break L7826}x=a[l+1|0]|0;v=a[l+2|0]|0;w=a[l+3|0]|0;if((q|0)==240){if((x+112&255)>=48){s=2;t=b;u=l;break L7826}}else if((q|0)==244){if((x&-16)<<24>>24!=-128){s=2;t=b;u=l;break L7826}}else{if((x&-64)<<24>>24!=-128){s=2;t=b;u=l;break L7826}}y=v&255;if((y&192|0)!=128){s=2;t=b;u=l;break L7826}v=w&255;if((v&192|0)!=128){s=2;t=b;u=l;break L7826}w=(x&255)<<12&258048|q<<18&1835008|y<<6&4032|v&63;if(w>>>0>1114111){s=2;t=b;u=l;break L7826}c[b>>2]=w;r=l+4|0}}while(0);q=b+4|0;if(r>>>0<g>>>0){b=q;l=r}else{m=q;n=r;o=6808;break}}}else{m=i;n=f;o=6808}}while(0);if((o|0)==6808){s=n>>>0<g>>>0|0;t=m;u=n}c[h>>2]=f+(u-f);c[k>>2]=i+(t-i>>2<<2);return s|0}function rV(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;L7865:do{if(d>>>0<e>>>0&(f|0)!=0){c=e;b=1;g=d;L7867:while(1){h=a[g]|0;i=h&255;do{if(h<<24>>24>-1){j=g+1|0}else{if((h&255)<194){k=g;break L7865}if((h&255)<224){if((c-g|0)<2){k=g;break L7865}if((a[g+1|0]&-64)<<24>>24!=-128){k=g;break L7865}j=g+2|0;break}if((h&255)<240){l=g;if((c-l|0)<3){k=g;break L7865}m=a[g+1|0]|0;n=a[g+2|0]|0;if((i|0)==237){if((m&-32)<<24>>24!=-128){o=6825;break L7867}}else if((i|0)==224){if((m&-32)<<24>>24!=-96){o=6823;break L7867}}else{if((m&-64)<<24>>24!=-128){o=6827;break L7867}}if((n&-64)<<24>>24!=-128){k=g;break L7865}j=g+3|0;break}if((h&255)>=245){k=g;break L7865}p=g;if((c-p|0)<4){k=g;break L7865}n=a[g+1|0]|0;m=a[g+2|0]|0;q=a[g+3|0]|0;if((i|0)==240){if((n+112&255)>=48){o=6834;break L7867}}else if((i|0)==244){if((n&-16)<<24>>24!=-128){o=6836;break L7867}}else{if((n&-64)<<24>>24!=-128){o=6838;break L7867}}if((m&-64)<<24>>24!=-128){k=g;break L7865}if((q&-64)<<24>>24!=-128){k=g;break L7865}if(((n&255)<<12&196608|i<<18&1835008)>>>0>1114111){k=g;break L7865}j=g+4|0}}while(0);if(!(j>>>0<e>>>0&b>>>0<f>>>0)){k=j;break L7865}b=b+1|0;g=j}if((o|0)==6838){r=p-d|0;return r|0}else if((o|0)==6823){r=l-d|0;return r|0}else if((o|0)==6825){r=l-d|0;return r|0}else if((o|0)==6836){r=p-d|0;return r|0}else if((o|0)==6834){r=p-d|0;return r|0}else if((o|0)==6827){r=l-d|0;return r|0}}else{k=d}}while(0);r=k-d|0;return r|0}function rW(b){b=b|0;return a[b+8|0]|0}function rX(a){a=a|0;return c[a+8>>2]|0}function rY(b){b=b|0;return a[b+9|0]|0}function rZ(a){a=a|0;return c[a+12>>2]|0}function r_(b,c){b=b|0;c=c|0;c=b;a[b]=8;b=c+1|0;C=1702195828;a[b]=C&255;C=C>>8;a[b+1|0]=C&255;C=C>>8;a[b+2|0]=C&255;C=C>>8;a[b+3|0]=C&255;a[c+5|0]=0;return}function r$(a){a=a|0;if((a|0)==0){return}sS(a);return}function r0(a){a=a|0;if((a|0)==0){return}sS(a);return}function r1(b){b=b|0;var d=0;c[b>>2]=54504;do{if((a[b+12|0]&1)!=0){d=c[b+20>>2]|0;if((d|0)!=0){sS(d)}if((b|0)!=0){break}return}}while(0);sS(b);return}function r2(b){b=b|0;var d=0;c[b>>2]=54504;if((a[b+12|0]&1)==0){return}d=c[b+20>>2]|0;if((d|0)==0){return}sS(d);return}function r3(b){b=b|0;var d=0;c[b>>2]=54456;do{if((a[b+16|0]&1)!=0){d=c[b+24>>2]|0;if((d|0)!=0){sS(d)}if((b|0)!=0){break}return}}while(0);sS(b);return}function r4(b){b=b|0;var d=0;c[b>>2]=54456;if((a[b+16|0]&1)==0){return}d=c[b+24>>2]|0;if((d|0)==0){return}sS(d);return}function r5(b,c){b=b|0;c=c|0;c=b;a[b]=10;b=c+1|0;a[b]=a[30680]|0;a[b+1|0]=a[30681|0]|0;a[b+2|0]=a[30682|0]|0;a[b+3|0]=a[30683|0]|0;a[b+4|0]=a[30684|0]|0;a[c+6|0]=0;return}function r6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d+12|0;if((a[e]&1)==0){f=b;c[f>>2]=c[e>>2];c[f+4>>2]=c[e+4>>2];c[f+8>>2]=c[e+8>>2];return}e=c[d+20>>2]|0;f=c[d+16>>2]|0;if((f|0)==-1){mV()}do{if(f>>>0<11){a[b]=f<<1&255;g=b+1|0}else{d=f+16&-16;h=(d|0)==0?1:d;while(1){i=sR(h)|0;if((i|0)!=0){j=6917;break}k=(I=c[138018]|0,c[138018]=I+0,I);if((k|0)==0){break}gp[k&63]()}if((j|0)==6917){c[b+8>>2]=i;c[b>>2]=d|1;c[b+4>>2]=f;g=i;break}h=fc(4)|0;c[h>>2]=53880;dq(h|0,60400,240)}}while(0);s1(g|0,e|0,f)|0;a[g+f|0]=0;return}function r7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d+16|0;if((a[e]&1)==0){f=b;c[f>>2]=c[e>>2];c[f+4>>2]=c[e+4>>2];c[f+8>>2]=c[e+8>>2];return}e=c[d+24>>2]|0;f=c[d+20>>2]|0;if((f|0)==-1){mV()}do{if(f>>>0<11){a[b]=f<<1&255;g=b+1|0}else{d=f+16&-16;h=(d|0)==0?1:d;while(1){i=sR(h)|0;if((i|0)!=0){j=6939;break}k=(I=c[138018]|0,c[138018]=I+0,I);if((k|0)==0){break}gp[k&63]()}if((j|0)==6939){c[b+8>>2]=i;c[b>>2]=d|1;c[b+4>>2]=f;g=i;break}h=fc(4)|0;c[h>>2]=53880;dq(h|0,60400,240)}}while(0);s1(g|0,e|0,f)|0;a[g+f|0]=0;return}function r8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;while(1){d=sR(32)|0;if((d|0)!=0){break}b=(I=c[138018]|0,c[138018]=I+0,I);if((b|0)==0){e=6952;break}gp[b&63]()}if((e|0)==6952){e=fc(4)|0;c[e>>2]=53880;dq(e|0,60400,240)}e=d;c[a+8>>2]=e;c[a>>2]=9;c[a+4>>2]=4;a=31304;b=4;f=e;while(1){e=b-1|0;c[f>>2]=c[a>>2];if((e|0)==0){break}else{a=a+4|0;b=e;f=f+4|0}}c[d+16>>2]=0;return}function r9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;while(1){d=sR(32)|0;if((d|0)!=0){break}b=(I=c[138018]|0,c[138018]=I+0,I);if((b|0)==0){e=6966;break}gp[b&63]()}if((e|0)==6966){e=fc(4)|0;c[e>>2]=53880;dq(e|0,60400,240)}e=d;c[a+8>>2]=e;c[a>>2]=9;c[a+4>>2]=5;a=30280;b=5;f=e;while(1){e=b-1|0;c[f>>2]=c[a>>2];if((e|0)==0){break}else{a=a+4|0;b=e;f=f+4|0}}c[d+20>>2]=0;return}function sa(b){b=b|0;var d=0;if((a[683056]|0)!=0){d=c[137640]|0;return d|0}if((cQ(683056)|0)==0){d=c[137640]|0;return d|0}do{if((a[682944]|0)==0){if((cQ(682944)|0)==0){break}s_(549608,0,168);en(406,0,r|0)|0}}while(0);mS(549608,47536);mS(549620,47256);mS(549632,46960);mS(549644,46768);mS(549656,46688);mS(549668,46608);mS(549680,46472);mS(549692,46336);mS(549704,46280);mS(549716,46224);mS(549728,46088);mS(549740,45848);mS(549752,45768);mS(549764,45696);c[137640]=549608;d=c[137640]|0;return d|0}function sb(b){b=b|0;var d=0;if((a[683e3]|0)!=0){d=c[137618]|0;return d|0}if((cQ(683e3)|0)==0){d=c[137618]|0;return d|0}do{if((a[682920]|0)==0){if((cQ(682920)|0)==0){break}s_(548864,0,168);en(242,0,r|0)|0}}while(0);m$(548864,51352,6);m$(548876,51168,6);m$(548888,51008,7);m$(548900,50576,9);m$(548912,50360,8);m$(548924,50032,6);m$(548936,49472,8);m$(548948,49208,3);m$(548960,48904,3);m$(548972,48672,3);m$(548984,48560,3);m$(548996,48264,3);m$(549008,48056,3);m$(549020,47872,3);c[137618]=548864;d=c[137618]|0;return d|0}function sc(b){b=b|0;var d=0;if((a[683048]|0)!=0){d=c[137638]|0;return d|0}if((cQ(683048)|0)==0){d=c[137638]|0;return d|0}do{if((a[682936]|0)==0){if((cQ(682936)|0)==0){break}s_(549320,0,288);en(306,0,r|0)|0}}while(0);mS(549320,14128);mS(549332,13904);mS(549344,13568);mS(549356,13408);mS(549368,13304);mS(549380,13160);mS(549392,13e3);mS(549404,12728);mS(549416,12560);mS(549428,12368);mS(549440,11888);mS(549452,11704);mS(549464,11528);mS(549476,11360);mS(549488,11280);mS(549500,11152);mS(549512,13304);mS(549524,11016);mS(549536,10888);mS(549548,52704);mS(549560,52480);mS(549572,52008);mS(549584,51864);mS(549596,51712);c[137638]=549320;d=c[137638]|0;return d|0}function sd(b){b=b|0;var d=0;if((a[682992]|0)!=0){d=c[137616]|0;return d|0}if((cQ(682992)|0)==0){d=c[137616]|0;return d|0}do{if((a[682912]|0)==0){if((cQ(682912)|0)==0){break}s_(548576,0,288);en(208,0,r|0)|0}}while(0);m$(548576,19640,7);m$(548588,19504,8);m$(548600,19328,5);m$(548612,19208,5);m$(548624,16072,3);m$(548636,18576,4);m$(548648,18376,4);m$(548660,18192,6);m$(548672,17968,9);m$(548684,17840,7);m$(548696,17616,8);m$(548708,17432,8);m$(548720,17176,3);m$(548732,16944,3);m$(548744,16768,3);m$(548756,16312,3);m$(548768,16072,3);m$(548780,15808,3);m$(548792,15624,3);m$(548804,15496,3);m$(548816,15336,3);m$(548828,15216,3);m$(548840,15032,3);m$(548852,14832,3);c[137616]=548576;d=c[137616]|0;return d|0}function se(b){b=b|0;var d=0;if((a[683064]|0)!=0){d=c[137642]|0;return d|0}if((cQ(683064)|0)==0){d=c[137642]|0;return d|0}do{if((a[682952]|0)==0){if((cQ(682952)|0)==0){break}s_(549776,0,288);en(206,0,r|0)|0}}while(0);mS(549776,19968);mS(549788,19824);c[137642]=549776;d=c[137642]|0;return d|0}function sf(b){b=b|0;var d=0;if((a[683008]|0)!=0){d=c[137620]|0;return d|0}if((cQ(683008)|0)==0){d=c[137620]|0;return d|0}do{if((a[682928]|0)==0){if((cQ(682928)|0)==0){break}s_(549032,0,288);en(382,0,r|0)|0}}while(0);m$(549032,21216,2);m$(549044,20560,2);c[137620]=549032;d=c[137620]|0;return d|0}function sg(b){b=b|0;var c=0;if((a[683072]|0)!=0){return 550576}if((cQ(683072)|0)==0){return 550576}a[550576]=16;b=550577;c=b|0;C=623865125;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;c=b+4|0;C=2032480100;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;a[550585]=0;en(408,550576,r|0)|0;return 550576}function sh(b){b=b|0;var c=0;if((a[683096]|0)!=0){return 550624}if((cQ(683096)|0)==0){return 550624}a[550624]=16;b=550625;c=b|0;C=624576549;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;c=b+4|0;C=1394948685;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;a[550633]=0;en(408,550624,r|0)|0;return 550624}function si(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[683016]|0)!=0){return 550488}if((cQ(683016)|0)==0){return 550488}while(1){d=sR(48)|0;if((d|0)!=0){break}b=(I=c[138018]|0,c[138018]=I+0,I);if((b|0)==0){e=7142;break}gp[b&63]()}if((e|0)==7142){e=fc(4)|0;c[e>>2]=53880;dq(e|0,60400,240);return 0}e=d;c[137624]=e;c[137622]=13;c[137623]=8;b=29040;f=8;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+32>>2]=0;en(308,550488,r|0)|0;return 550488}function sj(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[683040]|0)!=0){return 550536}if((cQ(683040)|0)==0){return 550536}while(1){d=sR(48)|0;if((d|0)!=0){break}b=(I=c[138018]|0,c[138018]=I+0,I);if((b|0)==0){e=7163;break}gp[b&63]()}if((e|0)==7163){e=fc(4)|0;c[e>>2]=53880;dq(e|0,60400,240);return 0}e=d;c[137636]=e;c[137634]=13;c[137635]=8;b=27872;f=8;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+32>>2]=0;en(308,550536,r|0)|0;return 550536}function sk(b){b=b|0;var d=0,e=0;if((a[683088]|0)!=0){return 550608}if((cQ(683088)|0)==0){return 550608}while(1){d=sR(32)|0;if((d|0)!=0){e=7186;break}b=(I=c[138018]|0,c[138018]=I+0,I);if((b|0)==0){e=7184;break}gp[b&63]()}if((e|0)==7184){b=fc(4)|0;c[b>>2]=53880;dq(b|0,60400,240);return 0}else if((e|0)==7186){c[137654]=d;c[137652]=33;c[137653]=20;s1(d|0,27536,20)|0;a[d+20|0]=0;en(408,550608,r|0)|0;return 550608}return 0}function sl(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[683032]|0)!=0){return 550520}if((cQ(683032)|0)==0){return 550520}while(1){d=sR(96)|0;if((d|0)!=0){break}b=(I=c[138018]|0,c[138018]=I+0,I);if((b|0)==0){e=7203;break}gp[b&63]()}if((e|0)==7203){e=fc(4)|0;c[e>>2]=53880;dq(e|0,60400,240);return 0}e=d;c[137632]=e;c[137630]=25;c[137631]=20;b=27128;f=20;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+80>>2]=0;en(308,550520,r|0)|0;return 550520}function sm(b){b=b|0;do{if((a[549308]&1)!=0){b=c[137329]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549296]&1)!=0){b=c[137326]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549284]&1)!=0){b=c[137323]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549272]&1)!=0){b=c[137320]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549260]&1)!=0){b=c[137317]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549248]&1)!=0){b=c[137314]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549236]&1)!=0){b=c[137311]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549224]&1)!=0){b=c[137308]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549212]&1)!=0){b=c[137305]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549200]&1)!=0){b=c[137302]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549188]&1)!=0){b=c[137299]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549176]&1)!=0){b=c[137296]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549164]&1)!=0){b=c[137293]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549152]&1)!=0){b=c[137290]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549140]&1)!=0){b=c[137287]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549128]&1)!=0){b=c[137284]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549116]&1)!=0){b=c[137281]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549104]&1)!=0){b=c[137278]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549092]&1)!=0){b=c[137275]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549080]&1)!=0){b=c[137272]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549068]&1)!=0){b=c[137269]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549056]&1)!=0){b=c[137266]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549044]&1)!=0){b=c[137263]|0;if((b|0)==0){break}sS(b)}}while(0);if((a[549032]&1)==0){return}b=c[137260]|0;if((b|0)==0){return}sS(b);return}function sn(b){b=b|0;var d=0,e=0;if((a[683080]|0)!=0){return 550592}if((cQ(683080)|0)==0){return 550592}while(1){d=sR(16)|0;if((d|0)!=0){e=7302;break}b=(I=c[138018]|0,c[138018]=I+0,I);if((b|0)==0){e=7300;break}gp[b&63]()}if((e|0)==7300){b=fc(4)|0;c[b>>2]=53880;dq(b|0,60400,240);return 0}else if((e|0)==7302){c[137650]=d;c[137648]=17;c[137649]=11;s1(d|0,26760,11)|0;a[d+11|0]=0;en(408,550592,r|0)|0;return 550592}return 0}function so(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[683024]|0)!=0){return 550504}if((cQ(683024)|0)==0){return 550504}while(1){d=sR(48)|0;if((d|0)!=0){break}b=(I=c[138018]|0,c[138018]=I+0,I);if((b|0)==0){e=7319;break}gp[b&63]()}if((e|0)==7319){e=fc(4)|0;c[e>>2]=53880;dq(e|0,60400,240);return 0}e=d;c[137628]=e;c[137626]=13;c[137627]=11;b=26336;f=11;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+44>>2]=0;en(308,550504,r|0)|0;return 550504}function sp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=b+8|0;f=b+4|0;g=c[f>>2]|0;h=c[e>>2]|0;i=g;if(h-i>>2>>>0>=d>>>0){j=d;k=g;do{if((k|0)==0){l=0}else{c[k>>2]=0;l=c[f>>2]|0}k=l+4|0;c[f>>2]=k;j=j-1|0;}while((j|0)!=0);return}j=b+16|0;k=b|0;l=c[k>>2]|0;g=i-l>>2;i=g+d|0;if(i>>>0>1073741823){m=fc(8)|0;c[m>>2]=54008;n=m+4|0;o=n;if((n|0)==0){p=m;c[p>>2]=53976;dq(m|0,60448,162)}while(1){q=sR(19)|0;if((q|0)!=0){r=7346;break}n=(I=c[138018]|0,c[138018]=I+0,I);if((n|0)==0){r=7344;break}gp[n&63]()}if((r|0)==7346){c[q+4>>2]=6;c[q>>2]=6;n=q+12|0;c[o>>2]=n;c[q+8>>2]=0;a[n]=a[42088]|0;a[n+1|0]=a[42089|0]|0;a[n+2|0]=a[42090|0]|0;a[n+3|0]=a[42091|0]|0;a[n+4|0]=a[42092|0]|0;a[n+5|0]=a[42093|0]|0;a[n+6|0]=a[42094|0]|0;p=m;c[p>>2]=53976;dq(m|0,60448,162)}else if((r|0)==7344){m=fc(4)|0;c[m>>2]=53880;dq(m|0,60400,240)}}m=h-l|0;do{if(m>>2>>>0>536870910){s=1073741823;r=7358}else{l=m>>1;h=l>>>0<i>>>0?i:l;if((h|0)==0){t=0;u=0;break}l=b+128|0;if(!((a[l]&1)==0&h>>>0<29)){s=h;r=7358;break}a[l]=1;t=j;u=h}}while(0);do{if((r|0)==7358){i=s<<2;m=(i|0)==0?1:i;while(1){v=sR(m)|0;if((v|0)!=0){r=7369;break}i=(I=c[138018]|0,c[138018]=I+0,I);if((i|0)==0){break}gp[i&63]()}if((r|0)==7369){t=v;u=s;break}m=fc(4)|0;c[m>>2]=53880;dq(m|0,60400,240)}}while(0);s=d;d=t+(g<<2)|0;do{if((d|0)==0){w=0}else{c[d>>2]=0;w=d}d=w+4|0;s=s-1|0;}while((s|0)!=0);s=t+(u<<2)|0;u=c[k>>2]|0;w=(c[f>>2]|0)-u|0;v=t+(g-(w>>2)<<2)|0;g=v;t=u;s1(g|0,t|0,w)|0;c[k>>2]=v;c[f>>2]=d;c[e>>2]=s;if((u|0)==0){return}if((u|0)==(j|0)){a[b+128|0]=0;return}else{sS(t);return}}function sq(b){b=b|0;do{if((a[550052]&1)!=0){b=c[137515]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[550040]&1)!=0){b=c[137512]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[550028]&1)!=0){b=c[137509]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[550016]&1)!=0){b=c[137506]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[550004]&1)!=0){b=c[137503]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549992]&1)!=0){b=c[137500]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549980]&1)!=0){b=c[137497]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549968]&1)!=0){b=c[137494]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549956]&1)!=0){b=c[137491]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549944]&1)!=0){b=c[137488]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549932]&1)!=0){b=c[137485]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549920]&1)!=0){b=c[137482]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549908]&1)!=0){b=c[137479]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549896]&1)!=0){b=c[137476]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549884]&1)!=0){b=c[137473]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549872]&1)!=0){b=c[137470]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549860]&1)!=0){b=c[137467]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549848]&1)!=0){b=c[137464]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549836]&1)!=0){b=c[137461]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549824]&1)!=0){b=c[137458]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549812]&1)!=0){b=c[137455]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549800]&1)!=0){b=c[137452]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549788]&1)!=0){b=c[137449]|0;if((b|0)==0){break}sS(b)}}while(0);if((a[549776]&1)==0){return}b=c[137446]|0;if((b|0)==0){return}sS(b);return}function sr(b){b=b|0;do{if((a[548852]&1)!=0){b=c[137215]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548840]&1)!=0){b=c[137212]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548828]&1)!=0){b=c[137209]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548816]&1)!=0){b=c[137206]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548804]&1)!=0){b=c[137203]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548792]&1)!=0){b=c[137200]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548780]&1)!=0){b=c[137197]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548768]&1)!=0){b=c[137194]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548756]&1)!=0){b=c[137191]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548744]&1)!=0){b=c[137188]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548732]&1)!=0){b=c[137185]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548720]&1)!=0){b=c[137182]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548708]&1)!=0){b=c[137179]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548696]&1)!=0){b=c[137176]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548684]&1)!=0){b=c[137173]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548672]&1)!=0){b=c[137170]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548660]&1)!=0){b=c[137167]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548648]&1)!=0){b=c[137164]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548636]&1)!=0){b=c[137161]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548624]&1)!=0){b=c[137158]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548612]&1)!=0){b=c[137155]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548600]&1)!=0){b=c[137152]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548588]&1)!=0){b=c[137149]|0;if((b|0)==0){break}sS(b)}}while(0);if((a[548576]&1)==0){return}b=c[137146]|0;if((b|0)==0){return}sS(b);return}function ss(b){b=b|0;do{if((a[549596]&1)!=0){b=c[137401]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549584]&1)!=0){b=c[137398]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549572]&1)!=0){b=c[137395]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549560]&1)!=0){b=c[137392]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549548]&1)!=0){b=c[137389]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549536]&1)!=0){b=c[137386]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549524]&1)!=0){b=c[137383]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549512]&1)!=0){b=c[137380]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549500]&1)!=0){b=c[137377]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549488]&1)!=0){b=c[137374]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549476]&1)!=0){b=c[137371]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549464]&1)!=0){b=c[137368]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549452]&1)!=0){b=c[137365]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549440]&1)!=0){b=c[137362]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549428]&1)!=0){b=c[137359]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549416]&1)!=0){b=c[137356]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549404]&1)!=0){b=c[137353]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549392]&1)!=0){b=c[137350]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549380]&1)!=0){b=c[137347]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549368]&1)!=0){b=c[137344]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549356]&1)!=0){b=c[137341]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549344]&1)!=0){b=c[137338]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549332]&1)!=0){b=c[137335]|0;if((b|0)==0){break}sS(b)}}while(0);if((a[549320]&1)==0){return}b=c[137332]|0;if((b|0)==0){return}sS(b);return}function st(b){b=b|0;do{if((a[549020]&1)!=0){b=c[137257]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549008]&1)!=0){b=c[137254]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548996]&1)!=0){b=c[137251]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548984]&1)!=0){b=c[137248]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548972]&1)!=0){b=c[137245]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548960]&1)!=0){b=c[137242]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548948]&1)!=0){b=c[137239]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548936]&1)!=0){b=c[137236]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548924]&1)!=0){b=c[137233]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548912]&1)!=0){b=c[137230]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548900]&1)!=0){b=c[137227]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548888]&1)!=0){b=c[137224]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[548876]&1)!=0){b=c[137221]|0;if((b|0)==0){break}sS(b)}}while(0);if((a[548864]&1)==0){return}b=c[137218]|0;if((b|0)==0){return}sS(b);return}function su(b){b=b|0;do{if((a[549764]&1)!=0){b=c[137443]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549752]&1)!=0){b=c[137440]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549740]&1)!=0){b=c[137437]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549728]&1)!=0){b=c[137434]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549716]&1)!=0){b=c[137431]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549704]&1)!=0){b=c[137428]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549692]&1)!=0){b=c[137425]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549680]&1)!=0){b=c[137422]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549668]&1)!=0){b=c[137419]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549656]&1)!=0){b=c[137416]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549644]&1)!=0){b=c[137413]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549632]&1)!=0){b=c[137410]|0;if((b|0)==0){break}sS(b)}}while(0);do{if((a[549620]&1)!=0){b=c[137407]|0;if((b|0)==0){break}sS(b)}}while(0);if((a[549608]&1)==0){return}b=c[137404]|0;if((b|0)==0){return}sS(b);return}function sv(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+8|0;h=g|0;c[h>>2]=b;j=((f|0)==0?256360:f)|0;f=c[j>>2]|0;L421:do{if((d|0)==0){if((f|0)==0){k=0}else{break}i=g;return k|0}else{if((b|0)==0){l=h;c[h>>2]=l;m=l}else{m=b}if((e|0)==0){k=-2;i=g;return k|0}do{if((f|0)==0){l=a[d]|0;n=l&255;if(l<<24>>24>-1){c[m>>2]=n;k=l<<24>>24!=0|0;i=g;return k|0}else{l=n-194|0;if(l>>>0>50){break L421}o=d+1|0;q=c[p+(l<<2)>>2]|0;r=e-1|0;break}}else{o=d;q=f;r=e}}while(0);L439:do{if((r|0)==0){s=q}else{l=a[o]|0;n=(l&255)>>>3;if((n-16|n+(q>>26))>>>0>7){break L421}else{t=o;u=q;v=r;w=l}while(1){t=t+1|0;u=u<<6|(w&255)-128;v=v-1|0;if((u|0)>=0){break}if((v|0)==0){s=u;break L439}w=a[t]|0;if(((w&255)-128|0)>>>0>63){break L421}}c[j>>2]=0;c[m>>2]=u;k=e-v|0;i=g;return k|0}}while(0);c[j>>2]=s;k=-2;i=g;return k|0}}while(0);c[j>>2]=0;c[(ep()|0)>>2]=138;k=-1;i=g;return k|0}function sw(a){a=a|0;return}function sx(a){a=a|0;return 35736|0}function sy(a){a=a|0;return}function sz(a){a=a|0;return}function sA(a){a=a|0;return}function sB(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0;if((c[d+8>>2]|0)!=(b|0)){return}b=d+16|0;g=c[b>>2]|0;if((g|0)==0){c[b>>2]=e;c[d+24>>2]=f;c[d+36>>2]=1;return}if((g|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;c[d+24>>2]=2;a[d+54|0]=1;return}e=d+24|0;if((c[e>>2]|0)!=2){return}c[e>>2]=f;return}function sC(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0;h=c[e>>2]|0;do{if((g|0)==0){i=368}else{j=g|0;k=c[j>>2]|0;if((k|0)==0){i=368;break}if((b|0)==0){l=k;m=h;n=f;i=379;break}c[j>>2]=0;o=k;q=h;r=b;s=f;i=399}}while(0);if((i|0)==368){if((b|0)==0){t=h;u=f;i=370}else{v=h;w=b;x=f;i=369}}L479:while(1){if((i|0)==369){i=0;if((x|0)==0){y=f;i=418;break}else{z=x;A=w;B=v}while(1){h=a[B]|0;do{if(((h&255)-1|0)>>>0<127){if((B&3|0)==0&z>>>0>3){C=z;D=A;E=B}else{F=B;G=A;H=z;I=h;break}while(1){J=c[E>>2]|0;if(((J-16843009|J)&-2139062144|0)!=0){i=394;break}c[D>>2]=J&255;c[D+4>>2]=d[E+1|0]|0;c[D+8>>2]=d[E+2|0]|0;K=E+4|0;L=D+16|0;c[D+12>>2]=d[E+3|0]|0;M=C-4|0;if(M>>>0>3){C=M;D=L;E=K}else{i=393;break}}if((i|0)==393){i=0;F=K;G=L;H=M;I=a[K]|0;break}else if((i|0)==394){i=0;F=E;G=D;H=C;I=J&255;break}}else{F=B;G=A;H=z;I=h}}while(0);N=I&255;if((N-1|0)>>>0>=127){break}c[G>>2]=N;h=H-1|0;if((h|0)==0){y=f;i=422;break L479}else{z=h;A=G+4|0;B=F+1|0}}h=N-194|0;if(h>>>0>50){O=H;P=G;Q=F;R=I;i=411;break}o=c[p+(h<<2)>>2]|0;q=F+1|0;r=G;s=H;i=399;continue}else if((i|0)==370){i=0;h=a[t]|0;do{if(((h&255)-1|0)>>>0<127){if((t&3|0)!=0){S=t;T=u;U=h;break}g=c[t>>2]|0;if(((g-16843009|g)&-2139062144|0)==0){V=u;W=t}else{S=t;T=u;U=g&255;break}do{W=W+4|0;V=V-4|0;X=c[W>>2]|0;}while(((X-16843009|X)&-2139062144|0)==0);S=W;T=V;U=X&255}else{S=t;T=u;U=h}}while(0);h=U&255;if((h-1|0)>>>0<127){t=S+1|0;u=T-1|0;i=370;continue}g=h-194|0;if(g>>>0>50){O=T;P=b;Q=S;R=U;i=411;break}l=c[p+(g<<2)>>2]|0;m=S+1|0;n=T;i=379;continue}else if((i|0)==379){i=0;g=(d[m]|0)>>>3;if((g-16|g+(l>>26))>>>0>7){i=380;break}g=m+1|0;do{if((l&33554432|0)==0){Y=g}else{if(((d[g]|0)-128|0)>>>0>63){i=383;break L479}h=m+2|0;if((l&524288|0)==0){Y=h;break}if(((d[h]|0)-128|0)>>>0>63){i=386;break L479}Y=m+3|0}}while(0);t=Y;u=n-1|0;i=370;continue}else if((i|0)==399){i=0;g=d[q]|0;h=g>>>3;if((h-16|h+(o>>26))>>>0>7){i=400;break}h=q+1|0;Z=g-128|o<<6;do{if((Z|0)<0){g=(d[h]|0)-128|0;if(g>>>0>63){i=403;break L479}k=q+2|0;_=g|Z<<6;if((_|0)>=0){$=_;aa=k;break}g=(d[k]|0)-128|0;if(g>>>0>63){i=406;break L479}$=g|_<<6;aa=q+3|0}else{$=Z;aa=h}}while(0);c[r>>2]=$;v=aa;w=r+4|0;x=s-1|0;i=369;continue}}if((i|0)==406){ab=_;ac=q-1|0;ad=r;ae=s;i=409}else if((i|0)==386){ab=l;ac=m-1|0;ad=b;ae=n;i=409}else if((i|0)==380){ab=l;ac=m-1|0;ad=b;ae=n;i=409}else if((i|0)==400){ab=o;ac=q-1|0;ad=r;ae=s;i=409}else if((i|0)==403){ab=Z;ac=q-1|0;ad=r;ae=s;i=409}else if((i|0)==383){ab=l;ac=m-1|0;ad=b;ae=n;i=409}else if((i|0)==418){return y|0}else if((i|0)==422){return y|0}do{if((i|0)==409){if((ab|0)!=0){af=ad;ag=ac;break}O=ae;P=ad;Q=ac;R=a[ac]|0;i=411}}while(0);do{if((i|0)==411){if(R<<24>>24!=0){af=P;ag=Q;break}if((P|0)!=0){c[P>>2]=0;c[e>>2]=0}y=f-O|0;return y|0}}while(0);c[(ep()|0)>>2]=138;if((af|0)==0){y=-1;return y|0}c[e>>2]=ag;y=-1;return y|0}function sD(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0){e=1;return e|0}if(d>>>0<128){a[b]=d&255;e=1;return e|0}if(d>>>0<2048){a[b]=(d>>>6|192)&255;a[b+1|0]=(d&63|128)&255;e=2;return e|0}if(d>>>0<55296|(d-57344|0)>>>0<8192){a[b]=(d>>>12|224)&255;a[b+1|0]=(d>>>6&63|128)&255;a[b+2|0]=(d&63|128)&255;e=3;return e|0}if((d-65536|0)>>>0<1048576){a[b]=(d>>>18|240)&255;a[b+1|0]=(d>>>12&63|128)&255;a[b+2|0]=(d>>>6&63|128)&255;a[b+3|0]=(d&63|128)&255;e=4;return e|0}else{c[(ep()|0)>>2]=138;e=-1;return e|0}return 0}function sE(a){a=a|0;if((a|0)==0){return}sS(a);return}function sF(a){a=a|0;if((a|0)==0){return}sS(a);return}function sG(a){a=a|0;if((a|0)==0){return}sS(a);return}function sH(a){a=a|0;if((a|0)==0){return}sS(a);return}function sI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+112|0;f=e|0;g=e+56|0;if((a|0)==(b|0)){h=1;i=e;return h|0}if((b|0)==0){h=0;i=e;return h|0}j=b;k=c[b>>2]|0;b=j+(c[k-8>>2]|0)|0;l=c[k-4>>2]|0;k=l;c[f>>2]=61960;c[f+4>>2]=j;c[f+8>>2]=61976;c[f+12>>2]=-1;j=f+16|0;m=f+20|0;n=f+24|0;o=f+28|0;p=f+32|0;q=f+40|0;s_(j|0,0,39);do{if((l|0)==61960){c[f+48>>2]=1;gk[c[(c[15490]|0)+20>>2]&63](k,f,b,b,1,0);r=(c[n>>2]|0)==1?b:0}else{f_[c[(c[l>>2]|0)+24>>2]&15](k,f,b,1,0);s=c[f+36>>2]|0;if((s|0)==0){if((c[q>>2]|0)!=1){r=0;break}if((c[o>>2]|0)!=1){r=0;break}r=(c[p>>2]|0)==1?c[m>>2]|0:0;break}else if((s|0)!=1){r=0;break}if((c[n>>2]|0)!=1){if((c[q>>2]|0)!=0){r=0;break}if((c[o>>2]|0)!=1){r=0;break}if((c[p>>2]|0)!=1){r=0;break}}r=c[j>>2]|0}}while(0);j=r;if((r|0)==0){h=0;i=e;return h|0}s_(g|0,0,56);c[g>>2]=j;c[g+8>>2]=a;c[g+12>>2]=-1;c[g+48>>2]=1;gr[c[(c[r>>2]|0)+28>>2]&127](j,g,c[d>>2]|0,1);if((c[g+24>>2]|0)!=1){h=0;i=e;return h|0}c[d>>2]=c[g+16>>2];h=1;i=e;return h|0}function sJ(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0;if((b|0)!=(c[d+8>>2]|0)){g=c[b+8>>2]|0;gr[c[(c[g>>2]|0)+28>>2]&127](g,d,e,f);return}g=d+16|0;b=c[g>>2]|0;if((b|0)==0){c[g>>2]=e;c[d+24>>2]=f;c[d+36>>2]=1;return}if((b|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;c[d+24>>2]=2;a[d+54|0]=1;return}e=d+24|0;if((c[e>>2]|0)!=2){return}c[e>>2]=f;return}function sK(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((b|0)==(c[d+8>>2]|0)){g=d+16|0;h=c[g>>2]|0;if((h|0)==0){c[g>>2]=e;c[d+24>>2]=f;c[d+36>>2]=1;return}if((h|0)!=(e|0)){h=d+36|0;c[h>>2]=(c[h>>2]|0)+1;c[d+24>>2]=2;a[d+54|0]=1;return}h=d+24|0;if((c[h>>2]|0)!=2){return}c[h>>2]=f;return}h=c[b+12>>2]|0;g=b+16+(h<<3)|0;i=c[b+20>>2]|0;j=i>>8;if((i&1|0)==0){k=j}else{k=c[(c[e>>2]|0)+j>>2]|0}j=c[b+16>>2]|0;gr[c[(c[j>>2]|0)+28>>2]&127](j,d,e+k|0,(i&2|0)!=0?f:2);if((h|0)<=1){return}h=d+54|0;i=e;k=b+24|0;while(1){b=c[k+4>>2]|0;j=b>>8;if((b&1|0)==0){l=j}else{l=c[(c[i>>2]|0)+j>>2]|0}j=c[k>>2]|0;gr[c[(c[j>>2]|0)+28>>2]&127](j,d,e+l|0,(b&2|0)!=0?f:2);if((a[h]&1)!=0){m=513;break}b=k+8|0;if(b>>>0<g>>>0){k=b}else{m=514;break}}if((m|0)==513){return}else if((m|0)==514){return}}function sL(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;if((c[d+8>>2]|0)==(b|0)){if((c[d+4>>2]|0)!=(e|0)){return}g=d+28|0;if((c[g>>2]|0)==1){return}c[g>>2]=f;return}if((c[d>>2]|0)!=(b|0)){return}do{if((c[d+16>>2]|0)!=(e|0)){b=d+20|0;if((c[b>>2]|0)==(e|0)){break}c[d+32>>2]=f;c[b>>2]=e;b=d+40|0;c[b>>2]=(c[b>>2]|0)+1;do{if((c[d+36>>2]|0)==1){if((c[d+24>>2]|0)!=2){break}a[d+54|0]=1}}while(0);c[d+44>>2]=4;return}}while(0);if((f|0)!=1){return}c[d+32>>2]=1;return}function sM(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((c[d+8>>2]|0)!=(b|0)){return}a[d+53|0]=1;if((c[d+4>>2]|0)!=(f|0)){return}a[d+52|0]=1;f=d+16|0;b=c[f>>2]|0;if((b|0)==0){c[f>>2]=e;c[d+24>>2]=g;c[d+36>>2]=1;if(!((c[d+48>>2]|0)==1&(g|0)==1)){return}a[d+54|0]=1;return}if((b|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;a[d+54|0]=1;return}e=d+24|0;b=c[e>>2]|0;if((b|0)==2){c[e>>2]=g;i=g}else{i=b}if(!((c[d+48>>2]|0)==1&(i|0)==1)){return}a[d+54|0]=1;return}function sN(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=b|0;if((h|0)==(c[d+8>>2]|0)){if((c[d+4>>2]|0)!=(e|0)){return}i=d+28|0;if((c[i>>2]|0)==1){return}c[i>>2]=f;return}if((h|0)==(c[d>>2]|0)){do{if((c[d+16>>2]|0)!=(e|0)){h=d+20|0;if((c[h>>2]|0)==(e|0)){break}c[d+32>>2]=f;i=d+44|0;if((c[i>>2]|0)==4){return}j=c[b+12>>2]|0;k=b+16+(j<<3)|0;L736:do{if((j|0)>0){l=d+52|0;m=d+53|0;n=d+54|0;o=b+8|0;p=d+24|0;q=e;r=0;s=b+16|0;t=0;L738:while(1){a[l]=0;a[m]=0;u=c[s+4>>2]|0;v=u>>8;if((u&1|0)==0){w=v}else{w=c[(c[q>>2]|0)+v>>2]|0}v=c[s>>2]|0;gk[c[(c[v>>2]|0)+20>>2]&63](v,d,e,e+w|0,2-(u>>>1&1)|0,g);if((a[n]&1)!=0){x=t;y=r;break}do{if((a[m]&1)==0){z=t;A=r}else{if((a[l]&1)==0){if((c[o>>2]&1|0)==0){x=1;y=r;break L738}else{z=1;A=r;break}}if((c[p>>2]|0)==1){B=585;break L736}if((c[o>>2]&2|0)==0){B=585;break L736}else{z=1;A=1}}}while(0);u=s+8|0;if(u>>>0<k>>>0){r=A;s=u;t=z}else{x=z;y=A;break}}if(y){C=x;B=584}else{D=x;B=581}}else{D=0;B=581}}while(0);do{if((B|0)==581){c[h>>2]=e;k=d+40|0;c[k>>2]=(c[k>>2]|0)+1;if((c[d+36>>2]|0)!=1){C=D;B=584;break}if((c[d+24>>2]|0)!=2){C=D;B=584;break}a[d+54|0]=1;if(D){B=585}else{B=586}}}while(0);if((B|0)==584){if(C){B=585}else{B=586}}if((B|0)==585){c[i>>2]=3;return}else if((B|0)==586){c[i>>2]=4;return}}}while(0);if((f|0)!=1){return}c[d+32>>2]=1;return}C=c[b+12>>2]|0;D=b+16+(C<<3)|0;x=c[b+20>>2]|0;y=x>>8;if((x&1|0)==0){E=y}else{E=c[(c[e>>2]|0)+y>>2]|0}y=c[b+16>>2]|0;f_[c[(c[y>>2]|0)+24>>2]&15](y,d,e+E|0,(x&2|0)!=0?f:2,g);x=b+24|0;if((C|0)<=1){return}C=c[b+8>>2]|0;do{if((C&2|0)==0){b=d+36|0;if((c[b>>2]|0)==1){break}if((C&1|0)==0){E=d+54|0;y=e;A=x;while(1){if((a[E]&1)!=0){B=615;break}if((c[b>>2]|0)==1){B=623;break}z=c[A+4>>2]|0;w=z>>8;if((z&1|0)==0){F=w}else{F=c[(c[y>>2]|0)+w>>2]|0}w=c[A>>2]|0;f_[c[(c[w>>2]|0)+24>>2]&15](w,d,e+F|0,(z&2|0)!=0?f:2,g);z=A+8|0;if(z>>>0<D>>>0){A=z}else{B=624;break}}if((B|0)==615){return}else if((B|0)==623){return}else if((B|0)==624){return}}A=d+24|0;y=d+54|0;E=e;i=x;while(1){if((a[y]&1)!=0){B=612;break}if((c[b>>2]|0)==1){if((c[A>>2]|0)==1){B=613;break}}z=c[i+4>>2]|0;w=z>>8;if((z&1|0)==0){G=w}else{G=c[(c[E>>2]|0)+w>>2]|0}w=c[i>>2]|0;f_[c[(c[w>>2]|0)+24>>2]&15](w,d,e+G|0,(z&2|0)!=0?f:2,g);z=i+8|0;if(z>>>0<D>>>0){i=z}else{B=614;break}}if((B|0)==612){return}else if((B|0)==613){return}else if((B|0)==614){return}}}while(0);G=d+54|0;F=e;C=x;while(1){if((a[G]&1)!=0){B=622;break}x=c[C+4>>2]|0;i=x>>8;if((x&1|0)==0){H=i}else{H=c[(c[F>>2]|0)+i>>2]|0}i=c[C>>2]|0;f_[c[(c[i>>2]|0)+24>>2]&15](i,d,e+H|0,(x&2|0)!=0?f:2,g);x=C+8|0;if(x>>>0<D>>>0){C=x}else{B=626;break}}if((B|0)==622){return}else if((B|0)==626){return}}function sO(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=b|0;if((h|0)==(c[d+8>>2]|0)){if((c[d+4>>2]|0)!=(e|0)){return}i=d+28|0;if((c[i>>2]|0)==1){return}c[i>>2]=f;return}if((h|0)!=(c[d>>2]|0)){h=c[b+8>>2]|0;f_[c[(c[h>>2]|0)+24>>2]&15](h,d,e,f,g);return}do{if((c[d+16>>2]|0)!=(e|0)){h=d+20|0;if((c[h>>2]|0)==(e|0)){break}c[d+32>>2]=f;i=d+44|0;if((c[i>>2]|0)==4){return}j=d+52|0;a[j]=0;k=d+53|0;a[k]=0;l=c[b+8>>2]|0;gk[c[(c[l>>2]|0)+20>>2]&63](l,d,e,e,1,g);if((a[k]&1)==0){m=0;n=641}else{if((a[j]&1)==0){m=1;n=641}}L838:do{if((n|0)==641){c[h>>2]=e;j=d+40|0;c[j>>2]=(c[j>>2]|0)+1;do{if((c[d+36>>2]|0)==1){if((c[d+24>>2]|0)!=2){n=644;break}a[d+54|0]=1;if(m){break L838}}else{n=644}}while(0);if((n|0)==644){if(m){break}}c[i>>2]=4;return}}while(0);c[i>>2]=3;return}}while(0);if((f|0)!=1){return}c[d+32>>2]=1;return}function sP(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((b|0)!=(c[d+8>>2]|0)){i=d+52|0;j=a[i]&1;k=d+53|0;l=a[k]&1;m=c[b+12>>2]|0;n=b+16+(m<<3)|0;a[i]=0;a[k]=0;o=c[b+20>>2]|0;p=o>>8;if((o&1|0)==0){q=p}else{q=c[(c[f>>2]|0)+p>>2]|0}p=c[b+16>>2]|0;gk[c[(c[p>>2]|0)+20>>2]&63](p,d,e,f+q|0,(o&2|0)!=0?g:2,h);L860:do{if((m|0)>1){o=d+24|0;q=b+8|0;p=d+54|0;r=f;s=b+24|0;do{if((a[p]&1)!=0){break L860}do{if((a[i]&1)==0){if((a[k]&1)==0){break}if((c[q>>2]&1|0)==0){break L860}}else{if((c[o>>2]|0)==1){break L860}if((c[q>>2]&2|0)==0){break L860}}}while(0);a[i]=0;a[k]=0;t=c[s+4>>2]|0;u=t>>8;if((t&1|0)==0){v=u}else{v=c[(c[r>>2]|0)+u>>2]|0}u=c[s>>2]|0;gk[c[(c[u>>2]|0)+20>>2]&63](u,d,e,f+v|0,(t&2|0)!=0?g:2,h);s=s+8|0;}while(s>>>0<n>>>0)}}while(0);a[i]=j;a[k]=l;return}a[d+53|0]=1;if((c[d+4>>2]|0)!=(f|0)){return}a[d+52|0]=1;f=d+16|0;l=c[f>>2]|0;if((l|0)==0){c[f>>2]=e;c[d+24>>2]=g;c[d+36>>2]=1;if(!((c[d+48>>2]|0)==1&(g|0)==1)){return}a[d+54|0]=1;return}if((l|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;a[d+54|0]=1;return}e=d+24|0;l=c[e>>2]|0;if((l|0)==2){c[e>>2]=g;w=g}else{w=l}if(!((c[d+48>>2]|0)==1&(w|0)==1)){return}a[d+54|0]=1;return}function sQ(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;if((b|0)!=(c[d+8>>2]|0)){i=c[b+8>>2]|0;gk[c[(c[i>>2]|0)+20>>2]&63](i,d,e,f,g,h);return}a[d+53|0]=1;if((c[d+4>>2]|0)!=(f|0)){return}a[d+52|0]=1;f=d+16|0;h=c[f>>2]|0;if((h|0)==0){c[f>>2]=e;c[d+24>>2]=g;c[d+36>>2]=1;if(!((c[d+48>>2]|0)==1&(g|0)==1)){return}a[d+54|0]=1;return}if((h|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;a[d+54|0]=1;return}e=d+24|0;h=c[e>>2]|0;if((h|0)==2){c[e>>2]=g;j=g}else{j=h}if(!((c[d+48>>2]|0)==1&(j|0)==1)){return}a[d+54|0]=1;return}function sR(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;do{if(a>>>0<245){if(a>>>0<11){b=16}else{b=a+11&-8}d=b>>>3;e=c[136970]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=547920+(h<<2)|0;j=547920+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[136970]=e&~(1<<g)}else{if(l>>>0<(c[136974]|0)>>>0){cp();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{cp();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(b>>>0<=(c[136972]|0)>>>0){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=547920+(p<<2)|0;m=547920+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[136970]=e&~(1<<r)}else{if(l>>>0<(c[136974]|0)>>>0){cp();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{cp();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[136972]|0;if((l|0)!=0){q=c[136975]|0;d=l>>>3;l=d<<1;f=547920+(l<<2)|0;k=c[136970]|0;h=1<<d;do{if((k&h|0)==0){c[136970]=k|h;s=f;t=547920+(l+2<<2)|0}else{d=547920+(l+2<<2)|0;g=c[d>>2]|0;if(g>>>0>=(c[136974]|0)>>>0){s=g;t=d;break}cp();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[136972]=m;c[136975]=e;n=i;return n|0}l=c[136971]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[548184+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[136974]|0;if(r>>>0<i>>>0){cp();return 0}e=r+b|0;m=e;if(r>>>0>=e>>>0){cp();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){cp();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){cp();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){cp();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{cp();return 0}}}while(0);L1002:do{if((e|0)!=0){f=d+28|0;i=548184+(c[f>>2]<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[136971]=c[136971]&~(1<<c[f>>2]);break L1002}else{if(e>>>0<(c[136974]|0)>>>0){cp();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break L1002}}}while(0);if(v>>>0<(c[136974]|0)>>>0){cp();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[136972]|0;if((f|0)!=0){e=c[136975]|0;i=f>>>3;f=i<<1;q=547920+(f<<2)|0;k=c[136970]|0;g=1<<i;do{if((k&g|0)==0){c[136970]=k|g;y=q;z=547920+(f+2<<2)|0}else{i=547920+(f+2<<2)|0;l=c[i>>2]|0;if(l>>>0>=(c[136974]|0)>>>0){y=l;z=i;break}cp();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[136972]=p;c[136975]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231){o=-1;break}f=a+11|0;g=f&-8;k=c[136971]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[548184+(A<<2)>>2]|0;L1050:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break L1050}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=(i|-i)&k;if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[548184+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(J>>>0>=((c[136972]|0)-g|0)>>>0){o=g;break}q=K;m=c[136974]|0;if(q>>>0<m>>>0){cp();return 0}p=q+g|0;k=p;if(q>>>0>=p>>>0){cp();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){cp();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){cp();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){cp();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{cp();return 0}}}while(0);L1100:do{if((e|0)!=0){i=K+28|0;m=548184+(c[i>>2]<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[136971]=c[136971]&~(1<<c[i>>2]);break L1100}else{if(e>>>0<(c[136974]|0)>>>0){cp();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break L1100}}}while(0);if(L>>>0<(c[136974]|0)>>>0){cp();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256){e=i<<1;m=547920+(e<<2)|0;r=c[136970]|0;j=1<<i;do{if((r&j|0)==0){c[136970]=r|j;O=m;P=547920+(e+2<<2)|0}else{i=547920+(e+2<<2)|0;d=c[i>>2]|0;if(d>>>0>=(c[136974]|0)>>>0){O=d;P=i;break}cp();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=548184+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[136971]|0;l=1<<Q;if((m&l|0)==0){c[136971]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=861;break}else{l=l<<1;m=j}}if((T|0)==861){if(S>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[136974]|0;if(m>>>0<i>>>0){cp();return 0}if(j>>>0<i>>>0){cp();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[136972]|0;if(o>>>0<=K>>>0){S=K-o|0;J=c[136975]|0;if(S>>>0>15){R=J;c[136975]=R+o;c[136972]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[136972]=0;c[136975]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[136973]|0;if(o>>>0<J>>>0){S=J-o|0;c[136973]=S;J=c[136976]|0;K=J;c[136976]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[16084]|0)==0){J=aX(8)|0;if((J-1&J|0)==0){c[16086]=J;c[16085]=J;c[16087]=-1;c[16088]=-1;c[16089]=0;c[137081]=0;c[16084]=(fm(0)|0)&-16^1431655768;break}else{cp();return 0}}}while(0);J=o+48|0;S=c[16086]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(S>>>0<=o>>>0){n=0;return n|0}O=c[137080]|0;do{if((O|0)!=0){P=c[137078]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);L1192:do{if((c[137081]&4|0)==0){O=c[136976]|0;L1194:do{if((O|0)==0){T=891}else{L=O;P=548328;while(1){U=P|0;M=c[U>>2]|0;if(M>>>0<=L>>>0){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=891;break L1194}else{P=M}}if((P|0)==0){T=891;break}L=R-(c[136973]|0)&Q;if(L>>>0>=2147483647){W=0;break}m=bu(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=900}}while(0);do{if((T|0)==891){O=bu(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[16085]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[137078]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647)){W=0;break}m=c[137080]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=bu($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=900}}while(0);L1214:do{if((T|0)==900){m=-_|0;if((X|0)!=-1){aa=Y;ab=X;T=911;break L1192}do{if((Z|0)!=-1&_>>>0<2147483647&_>>>0<J>>>0){g=c[16086]|0;O=K-_+g&-g;if(O>>>0>=2147483647){ac=_;break}if((bu(O|0)|0)==-1){bu(m|0)|0;W=Y;break L1214}else{ac=O+_|0;break}}else{ac=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ac;ab=Z;T=911;break L1192}}}while(0);c[137081]=c[137081]|4;ad=W;T=908}else{ad=0;T=908}}while(0);do{if((T|0)==908){if(S>>>0>=2147483647){break}W=bu(S|0)|0;Z=bu(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ac=Z-W|0;Z=ac>>>0>(o+40|0)>>>0;Y=Z?W:-1;if((Y|0)!=-1){aa=Z?ac:ad;ab=Y;T=911}}}while(0);do{if((T|0)==911){ad=(c[137078]|0)+aa|0;c[137078]=ad;if(ad>>>0>(c[137079]|0)>>>0){c[137079]=ad}ad=c[136976]|0;L1234:do{if((ad|0)==0){S=c[136974]|0;if((S|0)==0|ab>>>0<S>>>0){c[136974]=ab}c[137082]=ab;c[137083]=aa;c[137085]=0;c[136979]=c[16084];c[136978]=-1;S=0;do{Y=S<<1;ac=547920+(Y<<2)|0;c[547920+(Y+3<<2)>>2]=ac;c[547920+(Y+2<<2)>>2]=ac;S=S+1|0;}while(S>>>0<32);S=ab+8|0;if((S&7|0)==0){ae=0}else{ae=-S&7}S=aa-40-ae|0;c[136976]=ab+ae;c[136973]=S;c[ab+(ae+4)>>2]=S|1;c[ab+(aa-36)>>2]=40;c[136977]=c[16088]}else{S=548328;while(1){af=c[S>>2]|0;ag=S+4|0;ah=c[ag>>2]|0;if((ab|0)==(af+ah|0)){T=923;break}ac=c[S+8>>2]|0;if((ac|0)==0){break}else{S=ac}}do{if((T|0)==923){if((c[S+12>>2]&8|0)!=0){break}ac=ad;if(!(ac>>>0>=af>>>0&ac>>>0<ab>>>0)){break}c[ag>>2]=ah+aa;ac=c[136976]|0;Y=(c[136973]|0)+aa|0;Z=ac;W=ac+8|0;if((W&7|0)==0){ai=0}else{ai=-W&7}W=Y-ai|0;c[136976]=Z+ai;c[136973]=W;c[Z+(ai+4)>>2]=W|1;c[Z+(Y+4)>>2]=40;c[136977]=c[16088];break L1234}}while(0);if(ab>>>0<(c[136974]|0)>>>0){c[136974]=ab}S=ab+aa|0;Y=548328;while(1){aj=Y|0;if((c[aj>>2]|0)==(S|0)){T=933;break}Z=c[Y+8>>2]|0;if((Z|0)==0){break}else{Y=Z}}do{if((T|0)==933){if((c[Y+12>>2]&8|0)!=0){break}c[aj>>2]=ab;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ab+8|0;if((S&7|0)==0){ak=0}else{ak=-S&7}S=ab+(aa+8)|0;if((S&7|0)==0){al=0}else{al=-S&7}S=ab+(al+aa)|0;Z=S;W=ak+o|0;ac=ab+W|0;_=ac;K=S-(ab+ak)-o|0;c[ab+(ak+4)>>2]=o|3;do{if((Z|0)==(c[136976]|0)){J=(c[136973]|0)+K|0;c[136973]=J;c[136976]=_;c[ab+(W+4)>>2]=J|1}else{if((Z|0)==(c[136975]|0)){J=(c[136972]|0)+K|0;c[136972]=J;c[136975]=_;c[ab+(W+4)>>2]=J|1;c[ab+(J+W)>>2]=J;break}J=aa+4|0;X=c[ab+(al+J)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;L1279:do{if(X>>>0<256){U=c[ab+((al|8)+aa)>>2]|0;Q=c[ab+(aa+12+al)>>2]|0;R=547920+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[136974]|0)>>>0){cp();return 0}if((c[U+12>>2]|0)==(Z|0)){break}cp();return 0}}while(0);if((Q|0)==(U|0)){c[136970]=c[136970]&~(1<<V);break}do{if((Q|0)==(R|0)){am=Q+8|0}else{if(Q>>>0<(c[136974]|0)>>>0){cp();return 0}m=Q+8|0;if((c[m>>2]|0)==(Z|0)){am=m;break}cp();return 0}}while(0);c[U+12>>2]=Q;c[am>>2]=U}else{R=S;m=c[ab+((al|24)+aa)>>2]|0;P=c[ab+(aa+12+al)>>2]|0;do{if((P|0)==(R|0)){O=al|16;g=ab+(O+J)|0;L=c[g>>2]|0;if((L|0)==0){e=ab+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){an=0;break}else{ao=O;ap=e}}else{ao=L;ap=g}while(1){g=ao+20|0;L=c[g>>2]|0;if((L|0)!=0){ao=L;ap=g;continue}g=ao+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{ao=L;ap=g}}if(ap>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[ap>>2]=0;an=ao;break}}else{g=c[ab+((al|8)+aa)>>2]|0;if(g>>>0<(c[136974]|0)>>>0){cp();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){cp();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;an=P;break}else{cp();return 0}}}while(0);if((m|0)==0){break}P=ab+(aa+28+al)|0;U=548184+(c[P>>2]<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=an;if((an|0)!=0){break}c[136971]=c[136971]&~(1<<c[P>>2]);break L1279}else{if(m>>>0<(c[136974]|0)>>>0){cp();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=an}else{c[m+20>>2]=an}if((an|0)==0){break L1279}}}while(0);if(an>>>0<(c[136974]|0)>>>0){cp();return 0}c[an+24>>2]=m;R=al|16;P=c[ab+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[an+16>>2]=P;c[P+24>>2]=an;break}}}while(0);P=c[ab+(R+J)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[an+20>>2]=P;c[P+24>>2]=an;break}}}while(0);aq=ab+(($|al)+aa)|0;ar=$+K|0}else{aq=Z;ar=K}J=aq+4|0;c[J>>2]=c[J>>2]&-2;c[ab+(W+4)>>2]=ar|1;c[ab+(ar+W)>>2]=ar;J=ar>>>3;if(ar>>>0<256){V=J<<1;X=547920+(V<<2)|0;P=c[136970]|0;m=1<<J;do{if((P&m|0)==0){c[136970]=P|m;as=X;at=547920+(V+2<<2)|0}else{J=547920+(V+2<<2)|0;U=c[J>>2]|0;if(U>>>0>=(c[136974]|0)>>>0){as=U;at=J;break}cp();return 0}}while(0);c[at>>2]=_;c[as+12>>2]=_;c[ab+(W+8)>>2]=as;c[ab+(W+12)>>2]=X;break}V=ac;m=ar>>>8;do{if((m|0)==0){au=0}else{if(ar>>>0>16777215){au=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;au=ar>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=548184+(au<<2)|0;c[ab+(W+28)>>2]=au;c[ab+(W+20)>>2]=0;c[ab+(W+16)>>2]=0;X=c[136971]|0;Q=1<<au;if((X&Q|0)==0){c[136971]=X|Q;c[m>>2]=V;c[ab+(W+24)>>2]=m;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}if((au|0)==31){av=0}else{av=25-(au>>>1)|0}Q=ar<<av;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ar|0)){break}aw=X+16+(Q>>>31<<2)|0;m=c[aw>>2]|0;if((m|0)==0){T=1006;break}else{Q=Q<<1;X=m}}if((T|0)==1006){if(aw>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[aw>>2]=V;c[ab+(W+24)>>2]=X;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[136974]|0;if(X>>>0<$>>>0){cp();return 0}if(m>>>0<$>>>0){cp();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ab+(W+8)>>2]=m;c[ab+(W+12)>>2]=X;c[ab+(W+24)>>2]=0;break}}}while(0);n=ab+(ak|8)|0;return n|0}}while(0);Y=ad;W=548328;while(1){ax=c[W>>2]|0;if(ax>>>0<=Y>>>0){ay=c[W+4>>2]|0;az=ax+ay|0;if(az>>>0>Y>>>0){break}}W=c[W+8>>2]|0}W=ax+(ay-39)|0;if((W&7|0)==0){aA=0}else{aA=-W&7}W=ax+(ay-47+aA)|0;ac=W>>>0<(ad+16|0)>>>0?Y:W;W=ac+8|0;_=ab+8|0;if((_&7|0)==0){aB=0}else{aB=-_&7}_=aa-40-aB|0;c[136976]=ab+aB;c[136973]=_;c[ab+(aB+4)>>2]=_|1;c[ab+(aa-36)>>2]=40;c[136977]=c[16088];c[ac+4>>2]=27;c[W>>2]=c[137082];c[W+4>>2]=c[548332>>2];c[W+8>>2]=c[548336>>2];c[W+12>>2]=c[548340>>2];c[137082]=ab;c[137083]=aa;c[137085]=0;c[137084]=W;W=ac+28|0;c[W>>2]=7;if((ac+32|0)>>>0<az>>>0){_=W;while(1){W=_+4|0;c[W>>2]=7;if((_+8|0)>>>0<az>>>0){_=W}else{break}}}if((ac|0)==(Y|0)){break}_=ac-ad|0;W=Y+(_+4)|0;c[W>>2]=c[W>>2]&-2;c[ad+4>>2]=_|1;c[Y+_>>2]=_;W=_>>>3;if(_>>>0<256){K=W<<1;Z=547920+(K<<2)|0;S=c[136970]|0;m=1<<W;do{if((S&m|0)==0){c[136970]=S|m;aC=Z;aD=547920+(K+2<<2)|0}else{W=547920+(K+2<<2)|0;Q=c[W>>2]|0;if(Q>>>0>=(c[136974]|0)>>>0){aC=Q;aD=W;break}cp();return 0}}while(0);c[aD>>2]=ad;c[aC+12>>2]=ad;c[ad+8>>2]=aC;c[ad+12>>2]=Z;break}K=ad;m=_>>>8;do{if((m|0)==0){aE=0}else{if(_>>>0>16777215){aE=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;ac=(Y+520192|0)>>>16&4;W=Y<<ac;Y=(W+245760|0)>>>16&2;Q=14-(ac|S|Y)+(W<<Y>>>15)|0;aE=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=548184+(aE<<2)|0;c[ad+28>>2]=aE;c[ad+20>>2]=0;c[ad+16>>2]=0;Z=c[136971]|0;Q=1<<aE;if((Z&Q|0)==0){c[136971]=Z|Q;c[m>>2]=K;c[ad+24>>2]=m;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}if((aE|0)==31){aF=0}else{aF=25-(aE>>>1)|0}Q=_<<aF;Z=c[m>>2]|0;while(1){if((c[Z+4>>2]&-8|0)==(_|0)){break}aG=Z+16+(Q>>>31<<2)|0;m=c[aG>>2]|0;if((m|0)==0){T=1041;break}else{Q=Q<<1;Z=m}}if((T|0)==1041){if(aG>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[aG>>2]=K;c[ad+24>>2]=Z;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}}Q=Z+8|0;_=c[Q>>2]|0;m=c[136974]|0;if(Z>>>0<m>>>0){cp();return 0}if(_>>>0<m>>>0){cp();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[ad+8>>2]=_;c[ad+12>>2]=Z;c[ad+24>>2]=0;break}}}while(0);ad=c[136973]|0;if(ad>>>0<=o>>>0){break}_=ad-o|0;c[136973]=_;ad=c[136976]|0;Q=ad;c[136976]=Q+o;c[Q+(o+4)>>2]=_|1;c[ad+4>>2]=o|3;n=ad+8|0;return n|0}}while(0);c[(ep()|0)>>2]=12;n=0;return n|0}function sS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[136974]|0;if(b>>>0<e>>>0){cp()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){cp()}h=f&-8;i=a+(h-8)|0;j=i;L1451:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){cp()}if((n|0)==(c[136975]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[136972]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=547920+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){cp()}if((c[k+12>>2]|0)==(n|0)){break}cp()}}while(0);if((s|0)==(k|0)){c[136970]=c[136970]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){cp()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}cp()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){cp()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){cp()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){cp()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{cp()}}}while(0);if((p|0)==0){q=n;r=o;break}v=a+(l+28)|0;m=548184+(c[v>>2]<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[136971]=c[136971]&~(1<<c[v>>2]);q=n;r=o;break L1451}else{if(p>>>0<(c[136974]|0)>>>0){cp()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break L1451}}}while(0);if(A>>>0<(c[136974]|0)>>>0){cp()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[136974]|0)>>>0){cp()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[136974]|0)>>>0){cp()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(d>>>0>=i>>>0){cp()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){cp()}do{if((e&2|0)==0){if((j|0)==(c[136976]|0)){B=(c[136973]|0)+r|0;c[136973]=B;c[136976]=q;c[q+4>>2]=B|1;if((q|0)!=(c[136975]|0)){return}c[136975]=0;c[136972]=0;return}if((j|0)==(c[136975]|0)){B=(c[136972]|0)+r|0;c[136972]=B;c[136975]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;L1554:do{if(e>>>0<256){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=547920+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[136974]|0)>>>0){cp()}if((c[u+12>>2]|0)==(j|0)){break}cp()}}while(0);if((g|0)==(u|0)){c[136970]=c[136970]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[136974]|0)>>>0){cp()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}cp()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[136974]|0)>>>0){cp()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[136974]|0)>>>0){cp()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){cp()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{cp()}}}while(0);if((f|0)==0){break}t=a+(h+20)|0;u=548184+(c[t>>2]<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[136971]=c[136971]&~(1<<c[t>>2]);break L1554}else{if(f>>>0<(c[136974]|0)>>>0){cp()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break L1554}}}while(0);if(E>>>0<(c[136974]|0)>>>0){cp()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[136974]|0)>>>0){cp()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[136974]|0)>>>0){cp()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[136975]|0)){H=B;break}c[136972]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256){d=r<<1;e=547920+(d<<2)|0;A=c[136970]|0;E=1<<r;do{if((A&E|0)==0){c[136970]=A|E;I=e;J=547920+(d+2<<2)|0}else{r=547920+(d+2<<2)|0;h=c[r>>2]|0;if(h>>>0>=(c[136974]|0)>>>0){I=h;J=r;break}cp()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=548184+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[136971]|0;d=1<<K;do{if((r&d|0)==0){c[136971]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=1218;break}else{A=A<<1;J=E}}if((N|0)==1218){if(M>>>0<(c[136974]|0)>>>0){cp()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[136974]|0;if(J>>>0<E>>>0){cp()}if(B>>>0<E>>>0){cp()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[136978]|0)-1|0;c[136978]=q;if((q|0)==0){O=548336}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[136978]=-1;return}function sT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((a|0)==0){d=sR(b)|0;return d|0}if(b>>>0>4294967231){c[(ep()|0)>>2]=12;d=0;return d|0}if(b>>>0<11){e=16}else{e=b+11&-8}f=a-8|0;g=a-4|0;h=c[g>>2]|0;i=h&-8;j=i-8|0;k=a+j|0;l=k;m=c[136974]|0;if(f>>>0<m>>>0){cp();return 0}n=h&3;if(!((n|0)!=1&(j|0)>-8)){cp();return 0}j=i|4;o=a+(j-8)|0;p=c[o>>2]|0;if((p&1|0)==0){cp();return 0}L1689:do{if((n|0)==0){if(e>>>0<256|i>>>0<(e|4)>>>0){break}if((i-e|0)>>>0>c[16086]<<1>>>0|(f|0)==0){break}else{d=a}return d|0}else{do{if(i>>>0<e>>>0){if((l|0)==(c[136976]|0)){q=(c[136973]|0)+i|0;if(q>>>0<=e>>>0){break L1689}r=q-e|0;c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=r|1;c[136976]=a+(e-8);c[136973]=r;break}if((l|0)==(c[136975]|0)){r=(c[136972]|0)+i|0;if(r>>>0<e>>>0){break L1689}q=r-e|0;if(q>>>0>15){c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=q|1;c[a+(r-8)>>2]=q;s=a+(r-4)|0;c[s>>2]=c[s>>2]&-2;t=a+(e-8)|0;u=q}else{c[g>>2]=h&1|r|2;q=a+(r-4)|0;c[q>>2]=c[q>>2]|1;t=0;u=0}c[136972]=u;c[136975]=t;break}if((p&2|0)!=0){break L1689}q=(p&-8)+i|0;if(q>>>0<e>>>0){break L1689}r=q-e|0;s=p>>>3;L1713:do{if(p>>>0<256){v=c[a+i>>2]|0;w=c[a+j>>2]|0;x=547920+(s<<1<<2)|0;do{if((v|0)!=(x|0)){if(v>>>0<m>>>0){cp();return 0}if((c[v+12>>2]|0)==(l|0)){break}cp();return 0}}while(0);if((w|0)==(v|0)){c[136970]=c[136970]&~(1<<s);break}do{if((w|0)==(x|0)){y=w+8|0}else{if(w>>>0<m>>>0){cp();return 0}z=w+8|0;if((c[z>>2]|0)==(l|0)){y=z;break}cp();return 0}}while(0);c[v+12>>2]=w;c[y>>2]=v}else{x=k;z=c[a+(i+16)>>2]|0;A=c[a+j>>2]|0;do{if((A|0)==(x|0)){B=a+(i+12)|0;C=c[B>>2]|0;if((C|0)==0){D=a+(i+8)|0;E=c[D>>2]|0;if((E|0)==0){F=0;break}else{G=E;H=D}}else{G=C;H=B}while(1){B=G+20|0;C=c[B>>2]|0;if((C|0)!=0){G=C;H=B;continue}B=G+16|0;C=c[B>>2]|0;if((C|0)==0){break}else{G=C;H=B}}if(H>>>0<m>>>0){cp();return 0}else{c[H>>2]=0;F=G;break}}else{B=c[a+i>>2]|0;if(B>>>0<m>>>0){cp();return 0}C=B+12|0;if((c[C>>2]|0)!=(x|0)){cp();return 0}D=A+8|0;if((c[D>>2]|0)==(x|0)){c[C>>2]=A;c[D>>2]=B;F=A;break}else{cp();return 0}}}while(0);if((z|0)==0){break}A=a+(i+20)|0;v=548184+(c[A>>2]<<2)|0;do{if((x|0)==(c[v>>2]|0)){c[v>>2]=F;if((F|0)!=0){break}c[136971]=c[136971]&~(1<<c[A>>2]);break L1713}else{if(z>>>0<(c[136974]|0)>>>0){cp();return 0}w=z+16|0;if((c[w>>2]|0)==(x|0)){c[w>>2]=F}else{c[z+20>>2]=F}if((F|0)==0){break L1713}}}while(0);if(F>>>0<(c[136974]|0)>>>0){cp();return 0}c[F+24>>2]=z;x=c[a+(i+8)>>2]|0;do{if((x|0)!=0){if(x>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[F+16>>2]=x;c[x+24>>2]=F;break}}}while(0);x=c[a+(i+12)>>2]|0;if((x|0)==0){break}if(x>>>0<(c[136974]|0)>>>0){cp();return 0}else{c[F+20>>2]=x;c[x+24>>2]=F;break}}}while(0);if(r>>>0>=16){c[g>>2]=c[g>>2]&1|e|2;c[a+((e|4)-8)>>2]=r|3;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;sX(a+(e-8)|0,r);break}c[g>>2]=q|c[g>>2]&1|2;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;d=a;return d|0}else{s=i-e|0;if(s>>>0<=15){break}c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=s|3;c[o>>2]=c[o>>2]|1;sX(a+(e-8)|0,s);d=a;return d|0}}while(0);if((f|0)==0){break}else{d=a}return d|0}}while(0);f=sR(b)|0;if((f|0)==0){d=0;return d|0}e=c[g>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;e=g>>>0<b>>>0?g:b;s1(f|0,a|0,e)|0;sS(a);d=f;return d|0}function sU(a){a=a|0;return}function sV(a){a=a|0;return 28344|0}function sW(a){a=a|0;if((a|0)==0){return}sS(a);return}function sX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;L1802:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[136974]|0;if(i>>>0<l>>>0){cp()}if((j|0)==(c[136975]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[136972]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=547920+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){cp()}if((c[p+12>>2]|0)==(j|0)){break}cp()}}while(0);if((q|0)==(p|0)){c[136970]=c[136970]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){cp()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}cp()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){cp()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){cp()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){cp()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{cp()}}}while(0);if((m|0)==0){n=j;o=k;break}t=d+(28-h)|0;l=548184+(c[t>>2]<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[136971]=c[136971]&~(1<<c[t>>2]);n=j;o=k;break L1802}else{if(m>>>0<(c[136974]|0)>>>0){cp()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break L1802}}}while(0);if(y>>>0<(c[136974]|0)>>>0){cp()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[136974]|0)>>>0){cp()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[136974]|0)>>>0){cp()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[136974]|0;if(e>>>0<a>>>0){cp()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[136976]|0)){A=(c[136973]|0)+o|0;c[136973]=A;c[136976]=n;c[n+4>>2]=A|1;if((n|0)!=(c[136975]|0)){return}c[136975]=0;c[136972]=0;return}if((f|0)==(c[136975]|0)){A=(c[136972]|0)+o|0;c[136972]=A;c[136975]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;L1901:do{if(z>>>0<256){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=547920+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){cp()}if((c[g+12>>2]|0)==(f|0)){break}cp()}}while(0);if((t|0)==(g|0)){c[136970]=c[136970]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){cp()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}cp()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){cp()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){cp()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){cp()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{cp()}}}while(0);if((m|0)==0){break}l=d+(b+28)|0;g=548184+(c[l>>2]<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[136971]=c[136971]&~(1<<c[l>>2]);break L1901}else{if(m>>>0<(c[136974]|0)>>>0){cp()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break L1901}}}while(0);if(C>>>0<(c[136974]|0)>>>0){cp()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[136974]|0)>>>0){cp()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[136974]|0)>>>0){cp()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[136975]|0)){F=A;break}c[136972]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256){z=o<<1;y=547920+(z<<2)|0;C=c[136970]|0;b=1<<o;do{if((C&b|0)==0){c[136970]=C|b;G=y;H=547920+(z+2<<2)|0}else{o=547920+(z+2<<2)|0;d=c[o>>2]|0;if(d>>>0>=(c[136974]|0)>>>0){G=d;H=o;break}cp()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=548184+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[136971]|0;z=1<<I;if((o&z|0)==0){c[136971]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=1491;break}else{I=I<<1;J=G}}if((L|0)==1491){if(K>>>0<(c[136974]|0)>>>0){cp()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[136974]|0;if(J>>>0<I>>>0){cp()}if(L>>>0<I>>>0){cp()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function sY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0,P=0,Q=0.0,R=0.0,S=0.0;e=b;while(1){f=e+1|0;if((bp(a[e]|0)|0)==0){break}else{e=f}}g=a[e]|0;if((g<<24>>24|0)==43){i=f;j=0}else if((g<<24>>24|0)==45){i=f;j=1}else{i=e;j=0}e=-1;f=0;g=i;while(1){k=a[g]|0;if(((k<<24>>24)-48|0)>>>0<10){l=e}else{if(k<<24>>24!=46|(e|0)>-1){break}else{l=f}}e=l;f=f+1|0;g=g+1|0}l=g+(-f|0)|0;i=(e|0)<0;m=((i^1)<<31>>31)+f|0;n=(m|0)>18;o=(n?-18:-m|0)+(i?f:e)|0;e=n?18:m;do{if((e|0)==0){p=b;q=0.0}else{if((e|0)>9){m=l;n=e;f=0;while(1){i=a[m]|0;r=m+1|0;if(i<<24>>24==46){s=a[r]|0;t=m+2|0}else{s=i;t=r}u=(f*10|0)-48+(s<<24>>24)|0;r=n-1|0;if((r|0)>9){m=t;n=r;f=u}else{break}}v=+(u|0)*1.0e9;w=9;x=t;y=1539}else{if((e|0)>0){v=0.0;w=e;x=l;y=1539}else{z=0.0;A=0.0}}if((y|0)==1539){f=x;n=w;m=0;while(1){r=a[f]|0;i=f+1|0;if(r<<24>>24==46){B=a[i]|0;C=f+2|0}else{B=r;C=i}D=(m*10|0)-48+(B<<24>>24)|0;i=n-1|0;if((i|0)>0){f=C;n=i;m=D}else{break}}z=+(D|0);A=v}E=A+z;do{if((k<<24>>24|0)==69|(k<<24>>24|0)==101){m=g+1|0;n=a[m]|0;if((n<<24>>24|0)==45){F=g+2|0;G=1}else if((n<<24>>24|0)==43){F=g+2|0;G=0}else{F=m;G=0}m=a[F]|0;if(((m<<24>>24)-48|0)>>>0<10){H=F;I=0;J=m}else{K=0;L=F;M=G;break}while(1){m=(J<<24>>24)-48+(I*10|0)|0;n=H+1|0;f=a[n]|0;if(((f<<24>>24)-48|0)>>>0<10){H=n;I=m;J=f}else{K=m;L=n;M=G;break}}}else{K=0;L=g;M=0}}while(0);n=o+((M|0)==0?K:-K|0)|0;m=(n|0)<0?-n|0:n;if((m|0)>511){c[(ep()|0)>>2]=34;N=1.0;O=5832;P=511;y=1556}else{if((m|0)==0){Q=1.0}else{N=1.0;O=5832;P=m;y=1556}}if((y|0)==1556){while(1){y=0;if((P&1|0)==0){R=N}else{R=N*+h[O>>3]}m=P>>1;if((m|0)==0){Q=R;break}else{N=R;O=O+8|0;P=m;y=1556}}}if((n|0)>-1){p=L;q=E*Q;break}else{p=L;q=E/Q;break}}}while(0);if((d|0)!=0){c[d>>2]=p}if((j|0)==0){S=q;return+S}S=-0.0-q;return+S}function sZ(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function s_(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+e|0;if((e|0)>=20){d=d&255;e=b&3;g=d|d<<8|d<<16|d<<24;h=f&~3;if(e){e=b+4-e|0;while((b|0)<(e|0)){a[b]=d;b=b+1|0}}while((b|0)<(h|0)){c[b>>2]=g;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}}function s$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;z=z+1|0;c[a>>2]=z;while((e|0)<40){if((c[d+(e<<2)>>2]|0)==0){c[d+(e<<2)>>2]=z;c[d+((e<<2)+4)>>2]=b;c[d+((e<<2)+8)>>2]=0;return 0}e=e+2|0}c4(116);c4(111);c4(111);c4(32);c4(109);c4(97);c4(110);c4(121);c4(32);c4(115);c4(101);c4(116);c4(106);c4(109);c4(112);c4(115);c4(32);c4(105);c4(110);c4(32);c4(97);c4(32);c4(102);c4(117);c4(110);c4(99);c4(116);c4(105);c4(111);c4(110);c4(32);c4(99);c4(97);c4(108);c4(108);c4(44);c4(32);c4(98);c4(117);c4(105);c4(108);c4(100);c4(32);c4(119);c4(105);c4(116);c4(104);c4(32);c4(97);c4(32);c4(104);c4(105);c4(103);c4(104);c4(101);c4(114);c4(32);c4(118);c4(97);c4(108);c4(117);c4(101);c4(32);c4(102);c4(111);c4(114);c4(32);c4(77);c4(65);c4(88);c4(95);c4(83);c4(69);c4(84);c4(74);c4(77);c4(80);c4(83);c4(10);ah(0);return 0}function s0(a,b){a=a|0;b=b|0;var d=0,e=0;while((d|0)<20){e=c[b+(d<<2)>>2]|0;if((e|0)==0)break;if((e|0)==(a|0)){return c[b+((d<<2)+4)>>2]|0}d=d+2|0}return 0}function s1(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function s2(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function s3(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;while(e>>>0<d>>>0){f=s2(a[b+e|0]|0)|0;g=s2(a[c+e|0]|0)|0;if((f|0)==(g|0)&(f|0)==0)return 0;if((f|0)==0)return-1;if((g|0)==0)return 1;if((f|0)==(g|0)){e=e+1|0;continue}else{return(f>>>0>g>>>0?1:-1)|0}}return 0}function s4(a,b){a=a|0;b=b|0;return s3(a,b,-1)|0}function s5(b,c,d){b=b|0;c=c|0;d=d|0;if((c|0)<(b|0)&(b|0)<(c+d|0)){c=c+d|0;b=b+d|0;while((d|0)>0){b=b-1|0;c=c-1|0;d=d-1|0;a[b]=a[c]|0}}else{s1(b,c,d)|0}}function s6(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;while((e|0)<(c|0)){f=d[a+e|0]|0;g=d[b+e|0]|0;if((f|0)!=(g|0))return((f|0)>(g|0)?1:-1)|0;e=e+1|0}return 0}function s7(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;while((e|0)<(d|0)){a[b+e|0]=f?0:a[c+e|0]|0;f=f?1:(a[c+e|0]|0)==0;e=e+1|0}return b|0}function s8(b,c){b=b|0;c=c|0;var d=0;do{a[b+d|0]=a[c+d|0];d=d+1|0}while(a[c+(d-1)|0]|0);return b|0}function s9(b,c){b=b|0;c=c|0;var d=0,e=0;d=b+(sZ(b)|0)|0;do{a[d+e|0]=a[c+e|0];e=e+1|0}while(a[c+(e-1)|0]|0);return b|0}function ta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(K=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function tb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(K=e,a-c>>>0|0)|0}function tc(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){K=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}K=a<<c-32;return 0}function td(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){K=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}K=0;return b>>>c-32|0}function te(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){K=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}K=(b|0)<0?-1:0;return b>>c-32|0}function tf(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function tg(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function th(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ag(d,c)|0;f=a>>>16;a=(e>>>16)+(ag(d,f)|0)|0;d=b>>>16;b=ag(d,c)|0;return(K=(a>>>16)+(ag(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function ti(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=tb(e^a,f^b,e,f)|0;b=K;a=g^e;e=h^f;f=tb((tn(i,b,tb(g^c,h^d,g,h)|0,K,0)|0)^a,K^e,a,e)|0;return(K=K,f)|0}function tj(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=tb(h^a,j^b,h,j)|0;b=K;a=tb(k^d,l^e,k,l)|0;tn(m,b,a,K,g)|0;a=tb(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=K;i=f;return(K=j,a)|0}function tk(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=th(e,a)|0;f=K;return(K=(ag(b,a)|0)+(ag(d,e)|0)+f|f&0,c|0|0)|0}function tl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=tn(a,b,c,d,0)|0;return(K=K,e)|0}function tm(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;tn(a,b,d,e,g)|0;i=f;return(K=c[g+4>>2]|0,c[g>>2]|0)|0}function tn(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(K=n,o)|0}else{if(!m){n=0;o=0;return(K=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(K=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(K=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(K=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((tg(l|0)|0)>>>0);return(K=n,o)|0}p=(tf(l|0)|0)-(tf(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(K=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(K=n,o)|0}else{if(!m){r=(tf(l|0)|0)-(tf(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(K=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(K=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(tf(j|0)|0)+33-(tf(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(K=n,o)|0}else{p=tg(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(K=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;F=0;G=0}else{g=d|0|0;d=k|e&0;e=ta(g,d,-1,-1)|0;k=K;i=w;w=v;v=u;u=t;t=s;s=0;while(1){H=w>>>31|i<<1;I=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;tb(e,k,j,a)|0;b=K;h=b>>31|((b|0)<0?-1:0)<<1;J=h&1;L=tb(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=K;b=t-1|0;if((b|0)==0){break}else{i=H;w=I;v=M;u=L;t=b;s=J}}B=H;C=I;D=M;E=L;F=0;G=J}J=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(J|0)>>>31|(B|C)<<1|(C<<1|J>>>31)&0|F;o=(J<<1|0>>>31)&-2|G;return(K=n,o)|0}function to(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;fa(a|0,b|0,c|0,d|0,e|0)}function tp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dX(a|0,b|0,c|0,d|0,e|0)}function tq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dI(a|0,b|0,c|0,d|0,e|0)}function tr(a,b){a=a|0;b=+b;bS(a|0,+b)}function ts(a){a=a|0;bD(a|0)}function tt(a){a=a|0;ds(a|0)}function tu(a){a=a|0;dr(a|0)}function tv(a){a=a|0;cy(a|0)}function tw(a){a=a|0;fK(a|0)}function tx(a){a=a|0;c7(a|0)}function ty(a){a=a|0;dP(a|0)}function tz(a){a=a|0;b4(a|0)}function tA(a){a=a|0;dK(a|0)}function tB(a){a=a|0;fz(a|0)}function tC(a){a=a|0;eE(a|0)}function tD(a){a=a|0;cz(a|0)}function tE(a){a=a|0;dd(a|0)}function tF(a){a=a|0;fJ(a|0)}function tG(a){a=a|0;dG(a|0)}function tH(a){a=a|0;c9(a|0)}function tI(a){a=a|0;fU(a|0)}function tJ(a){a=a|0;e$(a|0)}function tK(a){a=a|0;bA(a|0)}function tL(a){a=a|0;bK(a|0)}function tM(a){a=a|0;bi(a|0)}function tN(a){a=a|0;bO(a|0)}function tO(a){a=a|0;bo(a|0)}function tP(a){a=a|0;by(a|0)}function tQ(a){a=a|0;eJ(a|0)}function tR(a,b){a=a|0;b=b|0;bX(a|0,b|0)}function tS(a,b){a=a|0;b=b|0;cF(a|0,b|0)}function tT(a,b){a=a|0;b=b|0;dp(a|0,b|0)}function tU(a,b){a=a|0;b=b|0;fM(a|0,b|0)}function tV(a,b){a=a|0;b=b|0;cT(a|0,b|0)}function tW(a,b){a=a|0;b=b|0;db(a|0,b|0)}function tX(a,b){a=a|0;b=b|0;ce(a|0,b|0)}function tY(a,b){a=a|0;b=b|0;fV(a|0,b|0)}function tZ(a,b){a=a|0;b=b|0;cd(a|0,b|0)}function t_(a,b){a=a|0;b=b|0;bM(a|0,b|0)}function t$(a,b){a=a|0;b=b|0;er(a|0,b|0)}function t0(a,b){a=a|0;b=b|0;ck(a|0,b|0)}function t1(a,b){a=a|0;b=b|0;ek(a|0,b|0)}function t2(a,b){a=a|0;b=b|0;cr(a|0,b|0)}function t3(a,b){a=a|0;b=b|0;a6(a|0,b|0)}function t4(a,b){a=a|0;b=b|0;eg(a|0,b|0)}function t5(a,b){a=a|0;b=b|0;fL(a|0,b|0)}function t6(a,b){a=a|0;b=b|0;fe(a|0,b|0)}function t7(a,b){a=a|0;b=b|0;e9(a|0,b|0)}function t8(a,b){a=a|0;b=b|0;c1(a|0,b|0)}function t9(a,b){a=a|0;b=b|0;e7(a|0,b|0)}function ua(a,b){a=a|0;b=b|0;fQ(a|0,b|0)}function ub(a,b){a=a|0;b=b|0;eB(a|0,b|0)}function uc(a,b){a=a|0;b=b|0;dw(a|0,b|0)}function ud(a,b){a=a|0;b=b|0;br(a|0,b|0)}function ue(a,b){a=a|0;b=b|0;fi(a|0,b|0)}function uf(a,b){a=a|0;b=b|0;df(a|0,b|0)}function ug(a,b){a=a|0;b=b|0;b3(a|0,b|0)}function uh(a,b){a=a|0;b=b|0;dU(a|0,b|0)}function ui(a,b){a=a|0;b=b|0;b_(a|0,b|0)}function uj(a,b){a=a|0;b=b|0;ef(a|0,b|0)}function uk(a,b){a=a|0;b=b|0;dk(a|0,b|0)}function ul(a,b){a=a|0;b=b|0;fS(a|0,b|0)}function um(a){a=a|0;return c4(a|0)|0}function un(a){a=a|0;return cJ(a|0)|0}function uo(a){a=a|0;return a7(a|0)|0}function up(a){a=a|0;return dT(a|0)|0}function uq(a){a=a|0;return cl(a|0)|0}function ur(a){a=a|0;return bY(a|0)|0}function us(a){a=a|0;return cu(a|0)|0}function ut(a){a=a|0;return bH(a|0)|0}function uu(a){a=a|0;return bd(a|0)|0}function uv(a){a=a|0;return d4(a|0)|0}function uw(a){a=a|0;return a_(a|0)|0}function ux(a){a=a|0;return eO(a|0)|0}function uy(a){a=a|0;return cI(a|0)|0}function uz(a){a=a|0;return eu(a|0)|0}function uA(a){a=a|0;return dH(a|0)|0}function uB(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;dW(a|0,+b,+c,+d,+e)}function uC(a,b,c){a=a|0;b=b|0;c=c|0;return de(a|0,b|0,c|0)|0}function uD(a,b,c){a=a|0;b=b|0;c=c|0;return a4(a|0,b|0,c|0)|0}function uE(a,b,c){a=a|0;b=b|0;c=c|0;return b0(a|0,b|0,c|0)|0}function uF(a,b,c){a=a|0;b=b|0;c=c|0;return eQ(a|0,b|0,c|0)|0}function uG(a,b,c){a=a|0;b=b|0;c=c|0;return bb(a|0,b|0,c|0)|0}function uH(a,b,c){a=a|0;b=b|0;c=c|0;return eM(a|0,b|0,c|0)|0}function uI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;cc(a|0,b|0,c|0,d|0,e|0,f|0)}function uJ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ej(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function uK(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;e2(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function uL(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;fA(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function uM(a){a=+a;return+bZ(+a)}function uN(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;bQ(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function uO(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;eI(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function uP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;eG(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function uQ(a,b){a=a|0;b=b|0;return fh(a|0,b|0)|0}function uR(a,b){a=a|0;b=b|0;return dz(a|0,b|0)|0}function uS(a,b){a=a|0;b=b|0;return d3(a|0,b|0)|0}function uT(a,b){a=a|0;b=b|0;return dv(a|0,b|0)|0}function uU(a,b){a=a|0;b=b|0;return da(a|0,b|0)|0}function uV(){return+bk()}function uW(){return ea()|0}function uX(){return ff()|0}function uY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return be(a|0,b|0,c|0,d|0)|0}function uZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return b5(a|0,b|0,c|0,d|0)|0}function u_(a,b,c){a=a|0;b=b|0;c=c|0;ec(a|0,b|0,c|0)}function u$(a,b,c){a=a|0;b=b|0;c=c|0;b6(a|0,b|0,c|0)}function u0(a,b,c){a=a|0;b=b|0;c=c|0;bC(a|0,b|0,c|0)}function u1(a,b,c){a=a|0;b=b|0;c=c|0;dB(a|0,b|0,c|0)}function u2(a,b,c){a=a|0;b=b|0;c=c|0;a0(a|0,b|0,c|0)}function u3(a,b,c){a=a|0;b=b|0;c=c|0;c5(a|0,b|0,c|0)}function u4(a,b,c){a=a|0;b=b|0;c=c|0;ei(a|0,b|0,c|0)}function u5(a,b,c){a=a|0;b=b|0;c=c|0;bF(a|0,b|0,c|0)}function u6(a,b,c){a=a|0;b=b|0;c=c|0;c2(a|0,b|0,c|0)}function u7(a,b,c){a=a|0;b=b|0;c=c|0;a9(a|0,b|0,c|0)}function u8(a,b,c){a=a|0;b=b|0;c=c|0;ed(a|0,b|0,c|0)}function u9(a,b,c){a=a|0;b=b|0;c=c|0;dg(a|0,b|0,c|0)}function va(a,b,c){a=a|0;b=b|0;c=c|0;co(a|0,b|0,c|0)}function vb(a,b,c){a=a|0;b=b|0;c=c|0;bn(a|0,b|0,c|0)}function vc(a,b,c){a=a|0;b=b|0;c=c|0;bB(a|0,b|0,c|0)}function vd(a,b,c){a=a|0;b=b|0;c=c|0;fF(a|0,b|0,c|0)}function ve(a,b,c){a=a|0;b=b|0;c=c|0;b8(a|0,b|0,c|0)}function vf(a,b,c){a=a|0;b=b|0;c=c|0;bj(a|0,b|0,c|0)}function vg(a,b,c){a=a|0;b=b|0;c=c|0;ct(a|0,b|0,c|0)}function vh(a,b,c){a=a|0;b=b|0;c=c|0;eb(a|0,b|0,c|0)}function vi(a,b,c){a=a|0;b=b|0;c=c|0;e5(a|0,b|0,c|0)}function vj(a,b,c){a=a|0;b=b|0;c=c|0;fu(a|0,b|0,c|0)}function vk(a,b,c){a=a|0;b=b|0;c=c|0;a2(a|0,b|0,c|0)}function vl(a,b,c){a=a|0;b=b|0;c=c|0;fI(a|0,b|0,c|0)}function vm(a,b,c){a=a|0;b=b|0;c=c|0;dS(a|0,b|0,c|0)}function vn(a,b,c){a=a|0;b=b|0;c=c|0;fp(a|0,b|0,c|0)}function vo(a,b,c){a=a|0;b=b|0;c=c|0;bV(a|0,b|0,c|0)}function vp(a,b,c){a=a|0;b=b|0;c=c|0;cR(a|0,b|0,c|0)}function vq(a,b,c){a=a|0;b=b|0;c=c|0;dR(a|0,b|0,c|0)}function vr(){e8()}function vs(){cS()}function vt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dY(a|0,b|0,c|0,d|0)}function vu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fy(a|0,b|0,c|0,d|0)}function vv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;el(a|0,b|0,c|0,d|0)}function vw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fk(a|0,b|0,c|0,d|0)}function vx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;aW(a|0,b|0,c|0,d|0)}function vy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d$(a|0,b|0,c|0,d|0)}function vz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cW(a|0,b|0,c|0,d|0)}function vA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eh(a|0,b|0,c|0,d|0)}function vB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eL(a|0,b|0,c|0,d|0)}function vC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cH(a|0,b|0,c|0,d|0)}function vD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;e0(a|0,b|0,c|0,d|0)}function vE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cB(a|0,b|0,c|0,d|0)}function vF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d2(a|0,b|0,c|0,d|0)}function vG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bv(a|0,b|0,c|0,d|0)}function vH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eR(a|0,b|0,c|0,d|0)}function vI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ca(a|0,b|0,c|0,d|0)}function vJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eD(a|0,b|0,c|0,d|0)}function vK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;e_(a|0,b|0,c|0,d|0)}function vL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d1(a|0,b|0,c|0,d|0)}function vM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cj(a|0,b|0,c|0,d|0)}function vN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cX(a|0,b|0,c|0,d|0)}function vO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eN(a|0,b|0,c|0,d|0)}function vP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dj(a|0,b|0,c|0,d|0)}function vQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eH(a|0,b|0,c|0,d|0)}function vR(a,b,c){a=a|0;b=+b;c=+c;dM(a|0,+b,+c)}function vS(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;bt(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function vT(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;dF(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function vU(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;cV(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function vV(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;cP(a|0,+b,+c,+d)}function vW(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return fY[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0)|0}function vX(a,b,c){a=a|0;b=b|0;c=+c;fZ[a&7](b|0,+c)}function vY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;f_[a&15](b|0,c|0,d|0,e|0,f|0)}function vZ(a,b){a=a|0;b=b|0;f$[a&511](b|0)}function v_(a,b,c){a=a|0;b=b|0;c=c|0;f0[a&255](b|0,c|0)}function v$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return f1[a&15](b|0,c|0,d|0,e|0,f|0,g|0)|0}function v0(a,b){a=a|0;b=b|0;return f2[a&255](b|0)|0}function v1(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;f3[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)}function v2(a,b,c,d,e,f){a=a|0;b=b|0;c=+c;d=+d;e=+e;f=+f;f4[a&7](b|0,+c,+d,+e,+f)}function v3(a,b){a=a|0;b=+b;return f5[a&3](+b)|0}function v4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return f6[a&31](b|0,c|0,d|0,e|0,f|0)|0}function v5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return f7[a&127](b|0,c|0,d|0)|0}function v6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;f8[a&15](b|0,c|0,d|0,e|0,f|0,+g)}function v7(a,b,c,d){a=a|0;b=b|0;c=+c;d=+d;f9[a&3](b|0,+c,+d)}function v8(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=+d;e=+e;ga[a&3](b|0,+c,+d,+e)}function v9(a,b,c){a=a|0;b=b|0;c=c|0;return+gb[a&3](b|0,c|0)}function wa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;return gc[a&3](b|0,c|0,+d)|0}function wb(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;gd[a&31](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function wc(a,b,c){a=a|0;b=b|0;c=+c;return ge[a&3](b|0,+c)|0}function wd(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;gf[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function we(a,b){a=a|0;b=+b;return+gg[a&3](+b)}function wf(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;gh[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)}function wg(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;gi[a&7](b|0,c|0,d|0,e|0,f|0,g|0,+h)}function wh(a,b,c){a=a|0;b=b|0;c=c|0;return gj[a&127](b|0,c|0)|0}function wi(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;gk[a&63](b|0,c|0,d|0,e|0,f|0,g|0)}function wj(a){a=a|0;return+gl[a&3]()}function wk(a){a=a|0;return gm[a&31]()|0}function wl(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return gn[a&31](b|0,c|0,d|0,e|0)|0}function wm(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;go[a&127](b|0,c|0,d|0)}function wn(a){a=a|0;gp[a&63]()}function wo(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;return gq[a&31](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)|0}function wp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;gr[a&127](b|0,c|0,d|0,e|0)}function wq(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ah(0);return 0}function wr(a,b){a=a|0;b=+b;ah(1)}function ws(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ah(2)}function wt(a){a=a|0;ah(3)}function wu(a,b){a=a|0;b=b|0;ah(4)}function wv(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ah(5);return 0}function ww(a){a=a|0;ah(6);return 0}function wx(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;ah(7)}function wy(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;ah(8)}function wz(a){a=+a;ah(9);return 0}function wA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ah(10);return 0}function wB(a,b,c){a=a|0;b=b|0;c=c|0;ah(11);return 0}function wC(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;ah(12)}function wD(a,b,c){a=a|0;b=+b;c=+c;ah(13)}function wE(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;ah(14)}function wF(a,b){a=a|0;b=b|0;ah(15);return 0.0}function wG(a,b,c){a=a|0;b=b|0;c=+c;ah(16);return 0}function wH(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ah(17)}function wI(a,b){a=a|0;b=+b;ah(18);return 0}function wJ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ah(19)}function wK(a){a=+a;ah(20);return 0.0}function wL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ah(21)}function wM(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;ah(22)}function wN(a,b){a=a|0;b=b|0;ah(23);return 0}function wO(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ah(24)}function wP(){ah(25);return 0.0}function wQ(){ah(26);return 0}function wR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ah(27);return 0}function wS(a,b,c){a=a|0;b=b|0;c=c|0;ah(28)}function wT(){ah(29)}function wU(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ah(30);return 0}function wV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ah(31)}
// EMSCRIPTEN_END_FUNCS
var fY=[wq,wq,j8,wq];var fZ=[wr,wr,jK,wr,tr,wr,wr,wr];var f_=[ws,ws,to,ws,sL,ws,j6,ws,sO,ws,tp,ws,tq,ws,sN,ws];var f$=[wt,wt,ts,wt,qS,wt,n5,wt,qP,wt,mN,wt,tt,wt,kU,wt,rb,wt,mt,wt,kT,wt,mk,wt,oR,wt,mJ,wt,ie,wt,oy,wt,lg,wt,kh,wt,tu,wt,nW,wt,nP,wt,l2,wt,tv,wt,h_,wt,rg,wt,hL,wt,rj,wt,h2,wt,g$,wt,pr,wt,ox,wt,tw,wt,kI,wt,nL,wt,hy,wt,qN,wt,nB,wt,rh,wt,iy,wt,tx,wt,o3,wt,nA,wt,ty,wt,kV,wt,p8,wt,jc,wt,qY,wt,hK,wt,tz,wt,tA,wt,ni,wt,lb,wt,le,wt,rl,wt,tB,wt,sz,wt,l4,wt,hx,wt,r1,wt,tC,wt,jX,wt,mM,wt,kv,wt,k2,wt,nY,wt,pC,wt,tD,wt,r4,wt,ri,wt,sS,wt,pi,wt,qI,wt,r0,wt,tE,wt,nD,wt,ls,wt,i8,wt,n4,wt,qg,wt,ir,wt,lu,wt,mK,wt,ig,wt,l1,wt,oQ,wt,im,wt,r2,wt,hJ,wt,kw,wt,kR,wt,pK,wt,nz,wt,jU,wt,tF,wt,nJ,wt,qe,wt,pu,wt,nQ,wt,p4,wt,lv,wt,sW,wt,g9,wt,lN,wt,sq,wt,sr,wt,nw,wt,qX,wt,nM,wt,no,wt,tG,wt,ry,wt,rO,wt,tH,wt,jF,wt,nO,wt,qr,wt,mv,wt,qc,wt,nN,wt,hN,wt,sU,wt,st,wt,sA,wt,tI,wt,ia,wt,rP,wt,mp,wt,l_,wt,tJ,wt,qf,wt,qu,wt,sE,wt,ql,wt,qH,wt,lw,wt,p0,wt,o4,wt,jy,wt,n3,wt,l0,wt,lt,wt,mP,wt,tK,wt,mg,wt,sG,wt,qB,wt,qv,wt,tL,wt,r3,wt,k8,wt,pg,wt,nZ,wt,la,wt,ss,wt,mY,wt,k1,wt,kx,wt,mj,wt,sw,wt,nj,wt,sH,wt,lL,wt,nI,wt,lo,wt,tM,wt,mQ,wt,ny,wt,mq,wt,k9,wt,nK,wt,h1,wt,tN,wt,l$,wt,i1,wt,nX,wt,nF,wt,nt,wt,nH,wt,mu,wt,n2,wt,pO,wt,kM,wt,pG,wt,q_,wt,qA,wt,nE,wt,nn,wt,nG,wt,tO,wt,r$,wt,tP,wt,sm,wt,hM,wt,lM,wt,sF,wt,lf,wt,qO,wt,mf,wt,ln,wt,sy,wt,qh,wt,lp,wt,qk,wt,su,wt,mR,wt,rk,wt,mL,wt,nC,wt,tQ,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt,wt];var f0=[wu,wu,jY,wu,hI,wu,jJ,wu,jB,wu,r5,wu,ib,wu,qq,wu,lx,wu,tR,wu,tS,wu,r7,wu,r6,wu,j9,wu,pW,wu,tT,wu,tU,wu,p7,wu,pU,wu,tV,wu,tW,wu,mw,wu,qR,wu,tX,wu,pX,wu,tY,wu,j$,wu,ix,wu,ju,wu,qm,wu,kG,wu,tZ,wu,pZ,wu,m8,wu,p3,wu,t_,wu,t$,wu,t0,wu,t1,wu,p1,wu,qo,wu,t2,wu,jP,wu,jO,wu,t3,wu,t4,wu,my,wu,t5,wu,qn,wu,g5,wu,r8,wu,t6,wu,t7,wu,kj,wu,t8,wu,t9,wu,ua,wu,l6,wu,ub,wu,p6,wu,uc,wu,ud,wu,js,wu,qd,wu,ue,wu,p5,wu,kD,wu,i0,wu,uf,wu,r9,wu,pV,wu,pY,wu,r_,wu,pT,wu,mx,wu,jC,wu,ug,wu,jL,wu,m1,wu,qW,wu,mD,wu,p9,wu,pS,wu,hs,wu,pR,wu,p2,wu,uh,wu,i7,wu,qa,wu,qb,wu,ui,wu,uj,wu,g3,wu,jr,wu,uk,wu,qp,wu,ul,wu,ja,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu,wu];var f1=[wv,wv,ic,wv,ii,wv,ih,wv,ij,wv,jq,wv,wv,wv,wv,wv];var f2=[ww,ww,l5,ww,kH,ww,so,ww,ip,ww,iz,ww,m5,ww,jv,ww,sd,ww,nl,ww,sl,ww,pH,ww,rD,ww,mz,ww,iA,ww,rJ,ww,ph,ww,sb,ww,hW,ww,k3,ww,sZ,ww,nq,ww,sR,ww,nc,ww,si,ww,sf,ww,lZ,ww,rR,ww,sx,ww,kN,ww,mG,ww,lS,ww,rZ,ww,rW,ww,lY,ww,sg,ww,um,ww,hP,ww,mb,ww,rX,ww,hp,ww,m3,ww,qj,ww,sh,ww,jt,ww,un,ww,iv,ww,mh,ww,hX,ww,kl,ww,i6,ww,k$,ww,j7,ww,pI,ww,jw,ww,sj,ww,rz,ww,uo,ww,kb,ww,up,ww,ly,ww,uq,ww,rT,ww,i9,ww,pP,ww,sa,ww,ur,ww,us,ww,ut,ww,ml,ww,rS,ww,nv,ww,pF,ww,uu,ww,hb,ww,uv,ww,mm,ww,uw,ww,rY,ww,ik,ww,m4,ww,iw,ww,na,ww,mr,ww,hE,ww,mc,ww,pJ,ww,q6,ww,kk,ww,q5,ww,sV,ww,nb,ww,pD,ww,sc,ww,q4,ww,pE,ww,ll,ww,mF,ww,pL,ww,rI,ww,pN,ww,sn,ww,hd,ww,pM,ww,se,ww,ux,ww,pQ,ww,ps,ww,kf,ww,uy,ww,k0,ww,uz,ww,sk,ww,uA,ww,ka,ww,rF,ww,rH,ww,mA,ww,i5,ww,ww,ww,ww,ww,ww,ww,ww,ww,ww,ww,ww,ww,ww,ww,ww,ww,ww,ww];var f3=[wx,wx,kg,wx];var f4=[wy,wy,jH,wy,jI,wy,uB,wy];var f5=[wz,wz,jb,wz];var f6=[wA,wA,rG,wA,rE,wA,rV,wA,rd,wA,rM,wA,ra,wA,q3,wA,n0,wA,rf,wA,rQ,wA,n_,wA,rC,wA,wA,wA,wA,wA,wA,wA];var f7=[wB,wB,uC,wB,j4,wB,rv,wB,rt,wB,i4,wB,l7,wB,uD,wB,it,wB,sI,wB,n$,wB,q8,wB,n1,wB,jx,wB,uE,wB,j_,wB,nm,wB,nk,wB,hS,wB,rm,wB,m9,wB,qT,wB,hi,wB,iu,wB,q9,wB,i3,wB,uF,wB,jp,wB,rr,wB,lT,wB,np,wB,mO,wB,mI,wB,uG,wB,rx,wB,qQ,wB,m2,wB,uH,wB,nx,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB,wB];var f8=[wC,wC,pf,wC,pd,wC,jM,wC,o2,wC,o$,wC,wC,wC,wC,wC];var f9=[wD,wD,vR,wD];var ga=[wE,wE,vV,wE];var gb=[wF,wF,j1,wF];var gc=[wG,wG,jV,wG];var gd=[wH,wH,vS,wH,qi,wH,p$,wH,vT,wH,qs,wH,qy,wH,qx,wH,qC,wH,vU,wH,wH,wH,wH,wH,wH,wH,wH,wH,wH,wH,wH,wH];var ge=[wI,wI,i_,wI];var gf=[wJ,wJ,pp,wJ,pv,wJ,pj,wJ,py,wJ,qU,wJ,pc,wJ,o8,wJ,qJ,wJ,po,wJ,pz,wJ,uJ,wJ,uK,wJ,uL,wJ,oS,wJ,pn,wJ,oq,wJ,oI,wJ,pw,wJ,o_,wJ,oY,wJ,oK,wJ,oG,wJ,oH,wJ,oz,wJ,oJ,wJ,oE,wJ,oB,wJ,oP,wJ,oO,wJ,oM,wJ,pA,wJ,oj,wJ,pk,wJ,on,wJ,of,wJ,oh,wJ,ol,wJ,ob,wJ,ov,wJ,ot,wJ,n8,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ,wJ];var gg=[wK,wK,uM,wK];var gh=[wL,wL,iS,wL,uN,wL,uO,wL,pB,wL,pq,wL,uP,wL,wL,wL];var gi=[wM,wM,qK,wM,qE,wM,wM,wM];var gj=[wN,wN,s4,wN,id,wN,ru,wN,mB,wN,lH,wN,g8,wN,uQ,wN,q7,wN,hz,wN,nd,wN,lQ,wN,uR,wN,q0,wN,jE,wN,jD,wN,mn,wN,kF,wN,ms,wN,rq,wN,lc,wN,hV,wN,ke,wN,lF,wN,kC,wN,hU,wN,lD,wN,l8,wN,kZ,wN,rw,wN,lm,wN,gP,wN,k7,wN,lR,wN,nu,wN,rs,wN,uS,wN,kW,wN,h5,wN,hD,wN,k5,wN,hG,wN,kA,wN,gL,wN,sT,wN,lB,wN,uT,wN,hf,wN,m7,wN,md,wN,lh,wN,ld,wN,uU,wN,m6,wN,mi,wN,ky,wN,kQ,wN,kJ,wN,hg,wN,wN,wN,wN,wN,wN,wN,wN,wN,wN,wN];var gk=[wO,wO,iK,wO,iG,wO,iN,wO,qZ,wO,pb,wO,o5,wO,sQ,wO,pl,wO,ma,wO,qV,wO,iI,wO,ng,wO,iF,wO,iJ,wO,sP,wO,uI,wO,iQ,wO,o6,wO,iM,wO,oT,wO,oZ,wO,oU,wO,o7,wO,sM,wO,iE,wO,ne,wO,iL,wO,iH,wO,wO,wO,wO,wO,wO,wO];var gl=[wP,wP,uV,wP];var gm=[wQ,wQ,iV,wQ,uW,wQ,hT,wQ,lP,wQ,lX,wQ,lr,wQ,h9,wQ,kd,wQ,uX,wQ,ho,wQ,hH,wQ,ki,wQ,j0,wQ,j2,wQ,hR,wQ];var gn=[wR,wR,g6,wR,rn,wR,uY,wR,uZ,wR,ro,wR,re,wR,jQ,wR,rc,wR,rp,wR,wR,wR,wR,wR,wR,wR,wR,wR,wR,wR,wR,wR];var go=[wS,wS,u_,wS,kB,wS,jW,wS,jG,wS,u$,wS,u0,wS,u1,wS,s5,wS,u2,wS,io,wS,kE,wS,u3,wS,u4,wS,u5,wS,u6,wS,u7,wS,u8,wS,u9,wS,va,wS,vb,wS,vc,wS,vd,wS,ve,wS,vf,wS,kP,wS,lk,wS,vg,wS,vh,wS,vi,wS,lE,wS,vj,wS,hZ,wS,vk,wS,jN,wS,k4,wS,lG,wS,lA,wS,hr,wS,iO,wS,vl,wS,mH,wS,hl,wS,lW,wS,vm,wS,vn,wS,nV,wS,hC,wS,iR,wS,vo,wS,vp,wS,vq,wS,lC,wS,i$,wS,k6,wS,kY,wS,wS,wS,wS,wS,wS,wS,wS,wS,wS,wS,wS,wS,wS,wS,wS,wS];var gp=[wT,wT,jA,wT,hO,wT,hv,wT,g7,wT,g0,wT,vr,wT,h0,wT,kc,wT,lK,wT,h$,wT,lV,wT,lU,wT,gY,wT,j5,wT,hQ,wT,hY,wT,lO,wT,gR,wT,hu,wT,lJ,wT,jZ,wT,hw,wT,lI,wT,gS,wT,gU,wT,jz,wT,j3,wT,h3,wT,vs,wT,gK,wT,wT,wT];var gq=[wU,wU,q1,wU,rB,wU,rL,wU,q2,wU,rN,wU,rU,wU,rA,wU,rK,wU,wU,wU,wU,wU,wU,wU,wU,wU,wU,wU,wU,wU,wU,wU];var gr=[wV,wV,vt,wV,vu,wV,vv,wV,gO,wV,vw,wV,vx,wV,vy,wV,vz,wV,vA,wV,vB,wV,vC,wV,sJ,wV,sK,wV,vD,wV,nf,wV,vE,wV,vF,wV,vG,wV,vH,wV,vI,wV,sB,wV,vJ,wV,nh,wV,vK,wV,vL,wV,vM,wV,l9,wV,n7,wV,vN,wV,vO,wV,vP,wV,vQ,wV,n6,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV,wV];return{_memcmp:s6,_saveSetjmp:s$,_strcat:s9,_free:sS,_main:gJ,_testSetjmp:s0,_strncpy:s7,_memmove:s5,__GLOBAL__I_a:mE,_strncasecmp:s3,_memset:s_,_malloc:sR,_memcpy:s1,_tolower:s2,_strlen:sZ,_strcasecmp:s4,_realloc:sT,_strcpy:s8,runPostSets:gI,stackAlloc:gs,stackSave:gt,stackRestore:gu,setThrew:gv,setTempRet0:gy,setTempRet1:gz,setTempRet2:gA,setTempRet3:gB,setTempRet4:gC,setTempRet5:gD,setTempRet6:gE,setTempRet7:gF,setTempRet8:gG,setTempRet9:gH,dynCall_iiiiiiii:vW,dynCall_vif:vX,dynCall_viiiii:vY,dynCall_vi:vZ,dynCall_vii:v_,dynCall_iiiiiii:v$,dynCall_ii:v0,dynCall_viiiiiiiiiii:v1,dynCall_viffff:v2,dynCall_if:v3,dynCall_iiiiii:v4,dynCall_iiii:v5,dynCall_viiiiif:v6,dynCall_viff:v7,dynCall_vifff:v8,dynCall_fii:v9,dynCall_iiif:wa,dynCall_viiiiiiii:wb,dynCall_iif:wc,dynCall_viiiiiii:wd,dynCall_ff:we,dynCall_viiiiiiiii:wf,dynCall_viiiiiif:wg,dynCall_iii:wh,dynCall_viiiiii:wi,dynCall_f:wj,dynCall_i:wk,dynCall_iiiii:wl,dynCall_viii:wm,dynCall_v:wn,dynCall_iiiiiiiii:wo,dynCall_viiii:wp}})
// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_vif": invoke_vif, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_ii": invoke_ii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_viffff": invoke_viffff, "invoke_if": invoke_if, "invoke_iiiiii": invoke_iiiiii, "invoke_iiii": invoke_iiii, "invoke_viiiiif": invoke_viiiiif, "invoke_viff": invoke_viff, "invoke_vifff": invoke_vifff, "invoke_fii": invoke_fii, "invoke_iiif": invoke_iiif, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_iif": invoke_iif, "invoke_viiiiiii": invoke_viiiiiii, "invoke_ff": invoke_ff, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_viiiiiif": invoke_viiiiiif, "invoke_iii": invoke_iii, "invoke_viiiiii": invoke_viiiiii, "invoke_f": invoke_f, "invoke_i": invoke_i, "invoke_iiiii": invoke_iiiii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_iiiiiiiii": invoke_iiiiiiiii, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_RWebInputDestroy": _RWebInputDestroy, "_RWebAudioStop": _RWebAudioStop, "_glClearColor": _glClearColor, "_sysconf": _sysconf, "__scanString": __scanString, "_pthread_mutex_unlock": _pthread_mutex_unlock, "_fclose": _fclose, "_RWebAudioInit": _RWebAudioInit, "_glGetVertexAttribPointerv": _glGetVertexAttribPointerv, "_pthread_mutex_lock": _pthread_mutex_lock, "_glGetRenderbufferParameteriv": _glGetRenderbufferParameteriv, "_eglDestroySurface": _eglDestroySurface, "_strtoul": _strtoul, "_strtoull": _strtoull, "_glBindTexture": _glBindTexture, "_fflush": _fflush, "_isxdigit": _isxdigit, "_glGetUniformiv": _glGetUniformiv, "_fabsf": _fabsf, "_strtol": _strtol, "_fputc": _fputc, "_glGetString": _glGetString, "_fwrite": _fwrite, "_gluUnProject": _gluUnProject, "_send": _send, "_fputs": _fputs, "_glLineWidth": _glLineWidth, "_glUniform2fv": _glUniform2fv, "_emscripten_get_now": _emscripten_get_now, "_asprintf": _asprintf, "_eglCreateContext": _eglCreateContext, "_glBindAttribLocation": _glBindAttribLocation, "_glCompileShader": _glCompileShader, "_isspace": _isspace, "_localtime": _localtime, "_glDeleteTextures": _glDeleteTextures, "_eglBindAPI": _eglBindAPI, "_glCompressedTexImage2D": _glCompressedTexImage2D, "_sbrk": _sbrk, "_glStencilFuncSeparate": _glStencilFuncSeparate, "_read": _read, "_RWebAudioBufferSize": _RWebAudioBufferSize, "_glDeleteShader": _glDeleteShader, "_RWebInputInit": _RWebInputInit, "_glClearDepthf": _glClearDepthf, "_glUniform4iv": _glUniform4iv, "_glGetTexParameteriv": _glGetTexParameteriv, "_glClearStencil": _glClearStencil, "_glLoadIdentity": _glLoadIdentity, "_glUniform1fv": _glUniform1fv, "___cxa_guard_abort": ___cxa_guard_abort, "_glIsShader": _glIsShader, "__Z7catopenPKci": __Z7catopenPKci, "_strstr": _strstr, "_glSampleCoverage": _glSampleCoverage, "_fsync": _fsync, "_glGenTextures": _glGenTextures, "_newlocale": _newlocale, "_glDepthFunc": _glDepthFunc, "_remove": _remove, "_glCompressedTexSubImage2D": _glCompressedTexSubImage2D, "_pthread_cond_wait": _pthread_cond_wait, "_glUniform1f": _glUniform1f, "_opendir": _opendir, "___resumeException": ___resumeException, "_glGetTexParameterfv": _glGetTexParameterfv, "_RWebAudioWrite": _RWebAudioWrite, "_glStencilMaskSeparate": _glStencilMaskSeparate, "_glCreateShader": _glCreateShader, "_round": _round, "_glUniform1i": _glUniform1i, "___cxa_end_catch": ___cxa_end_catch, "_strncmp": _strncmp, "_cosf": _cosf, "_vsscanf": _vsscanf, "_glDeleteRenderbuffers": _glDeleteRenderbuffers, "_glLinkProgram": _glLinkProgram, "_snprintf": _snprintf, "_glUniform2i": _glUniform2i, "_fgetc": _fgetc, "_glStencilFunc": _glStencilFunc, "_strerror_r": _strerror_r, "_glShaderSource": _glShaderSource, "_readdir": _readdir, "_glVertexAttribPointer": _glVertexAttribPointer, "_glHint": _glHint, "_glBindBuffer": _glBindBuffer, "_glVertexPointer": _glVertexPointer, "_fgets": _fgets, "_close": _close, "_getgid": _getgid, "_glGetAttachedShaders": _glGetAttachedShaders, "_glBindFramebuffer": _glBindFramebuffer, "_glIsFramebuffer": _glIsFramebuffer, "_strchr": _strchr, "_llvm_bswap_i16": _llvm_bswap_i16, "_glUniform4fv": _glUniform4fv, "_abort": _abort, "___setErrNo": ___setErrNo, "_glDeleteFramebuffers": _glDeleteFramebuffers, "_eglTerminate": _eglTerminate, "_glGetVertexAttribfv": _glGetVertexAttribfv, "_glIsBuffer": _glIsBuffer, "_emscripten_GetProcAddress": _emscripten_GetProcAddress, "_eglGetProcAddress": _eglGetProcAddress, "_ftell": _ftell, "_glDeleteProgram": _glDeleteProgram, "_exit": _exit, "_sprintf": _sprintf, "_glRenderbufferStorage": _glRenderbufferStorage, "___ctype_b_loc": ___ctype_b_loc, "_strrchr": _strrchr, "_freelocale": _freelocale, "_glAttachShader": _glAttachShader, "_RWebInputPoll": _RWebInputPoll, "_glUniform3i": _glUniform3i, "_glIsProgram": _glIsProgram, "_glCheckFramebufferStatus": _glCheckFramebufferStatus, "__isLeapYear": __isLeapYear, "_gluProject": _gluProject, "___cxa_find_matching_catch": ___cxa_find_matching_catch, "_llvm_uadd_with_overflow_i32": _llvm_uadd_with_overflow_i32, "_localtime_r": _localtime_r, "_glUniform3f": _glUniform3f, "___cxa_guard_acquire": ___cxa_guard_acquire, "_glGetBufferParameteriv": _glGetBufferParameteriv, "_glFlush": _glFlush, "_glBlendEquationSeparate": _glBlendEquationSeparate, "_emscripten_get_canvas_size": _emscripten_get_canvas_size, "_glCopyTexImage2D": _glCopyTexImage2D, "_glDrawElements": _glDrawElements, "_glColorMask": _glColorMask, "_sinf": _sinf, "_gluLookAt": _gluLookAt, "_eglInitialize": _eglInitialize, "_recv": _recv, "__parseInt64": __parseInt64, "_glVertexAttrib1fv": _glVertexAttrib1fv, "_glUniform2iv": _glUniform2iv, "__ZSt18uncaught_exceptionv": __ZSt18uncaught_exceptionv, "_putchar": _putchar, "_glUniform1iv": _glUniform1iv, "___cxa_call_unexpected": ___cxa_call_unexpected, "_glActiveTexture": _glActiveTexture, "_glMatrixMode": _glMatrixMode, "_glBlendEquation": _glBlendEquation, "_strcmp": _strcmp, "_glVertexAttrib1f": _glVertexAttrib1f, "_RWebAudioWriteAvail": _RWebAudioWriteAvail, "_glGenerateMipmap": _glGenerateMipmap, "_memchr": _memchr, "_glDetachShader": _glDetachShader, "_glGetShaderiv": _glGetShaderiv, "__exit": __exit, "_strftime": _strftime, "_glVertexAttrib3f": _glVertexAttrib3f, "_glGenRenderbuffers": _glGenRenderbuffers, "_tzset": _tzset, "_RWebAudioSampleRate": _RWebAudioSampleRate, "_glGetShaderPrecisionFormat": _glGetShaderPrecisionFormat, "_glVertexAttrib4fv": _glVertexAttrib4fv, "___cxa_throw": ___cxa_throw, "_glDepthMask": _glDepthMask, "_glDisableVertexAttribArray": _glDisableVertexAttribArray, "_glBegin": _glBegin, "_llvm_eh_exception": _llvm_eh_exception, "_printf": _printf, "_glBindRenderbuffer": _glBindRenderbuffer, "_pread": _pread, "___locale_mb_cur_max": ___locale_mb_cur_max, "_fopen": _fopen, "_open": _open, "_glDrawArrays": _glDrawArrays, "_usleep": _usleep, "_llvm_pow_f32": _llvm_pow_f32, "__arraySum": __arraySum, "_glCopyTexSubImage2D": _glCopyTexSubImage2D, "_glDisable": _glDisable, "_puts": _puts, "_glUniform4i": _glUniform4i, "_nanosleep": _nanosleep, "_glClear": _glClear, "_qsort": _qsort, "_glUniform2f": _glUniform2f, "_eglDestroyContext": _eglDestroyContext, "_isalpha": _isalpha, "_glEnableVertexAttribArray": _glEnableVertexAttribArray, "_rmdir": _rmdir, "_glUniform3fv": _glUniform3fv, "_glStencilOp": _glStencilOp, "_strdup": _strdup, "_glDepthRange": _glDepthRange, "___cxa_free_exception": ___cxa_free_exception, "_glUniform4f": _glUniform4f, "_glFramebufferTexture2D": _glFramebufferTexture2D, "_glUniformMatrix2fv": _glUniformMatrix2fv, "_glGenVertexArrays": _glGenVertexArrays, "_eglMakeCurrent": _eglMakeCurrent, "_glUniformMatrix3fv": _glUniformMatrix3fv, "_glutCreateWindow": _glutCreateWindow, "_glBufferData": _glBufferData, "_glBlendColor": _glBlendColor, "_glGetUniformLocation": _glGetUniformLocation, "_glIsEnabled": _glIsEnabled, "__formatString": __formatString, "_pthread_cond_broadcast": _pthread_cond_broadcast, "__Z8catcloseP8_nl_catd": __Z8catcloseP8_nl_catd, "_getenv": _getenv, "___cxa_does_inherit": ___cxa_does_inherit, "_glGetError": _glGetError, "_glGetVertexAttribiv": _glGetVertexAttribiv, "_glTexParameteriv": _glTexParameteriv, "_glGetProgramiv": _glGetProgramiv, "_llvm_trap": _llvm_trap, "_glVertexAttrib3fv": _glVertexAttrib3fv, "_glGetFloatv": _glGetFloatv, "_glBufferSubData": _glBufferSubData, "_glUniform3iv": _glUniform3iv, "_glReadPixels": _glReadPixels, "_glGenFramebuffers": _glGenFramebuffers, "_glFramebufferRenderbuffer": _glFramebufferRenderbuffer, "_emscripten_procAddressTable": _emscripten_procAddressTable, "_atexit": _atexit, "_ceil": _ceil, "___errno_location": ___errno_location, "_strerror": _strerror, "_glGetIntegerv": _glGetIntegerv, "_RWebAudioFree": _RWebAudioFree, "_llvm_lifetime_start": _llvm_lifetime_start, "_glIsRenderbuffer": _glIsRenderbuffer, "_llvm_bswap_i32": _llvm_bswap_i32, "_vsnprintf": _vsnprintf, "__parseInt": __parseInt, "___cxa_guard_release": ___cxa_guard_release, "_ungetc": _ungetc, "_RWebAudioSetNonblockState": _RWebAudioSetNonblockState, "_glVertexAttrib2fv": _glVertexAttrib2fv, "_uselocale": _uselocale, "_glGetFramebufferAttachmentParameteriv": _glGetFramebufferAttachmentParameteriv, "_glUseProgram": _glUseProgram, "_sscanf": _sscanf, "_glTexImage2D": _glTexImage2D, "_glGetProgramInfoLog": _glGetProgramInfoLog, "_glTexSubImage2D": _glTexSubImage2D, "_glStencilMask": _glStencilMask, "_fread": _fread, "_glStencilOpSeparate": _glStencilOpSeparate, "_strtok_r": _strtok_r, "_glGetShaderInfoLog": _glGetShaderInfoLog, "_glIsTexture": _glIsTexture, "_eglCreateWindowSurface": _eglCreateWindowSurface, "_fprintf": _fprintf, "_glGetShaderSource": _glGetShaderSource, "_gluPerspective": _gluPerspective, "_strtoll": _strtoll, "_isdigit": _isdigit, "_eglChooseConfig": _eglChooseConfig, "___buildEnvironment": ___buildEnvironment, "_feof": _feof, "__addDays": __addDays, "___cxa_rethrow": ___cxa_rethrow, "_glScissor": _glScissor, "_glEnable": _glEnable, "_glBlendFuncSeparate": _glBlendFuncSeparate, "__reallyNegative": __reallyNegative, "_glGetActiveAttrib": _glGetActiveAttrib, "_fseek": _fseek, "_sqrt": _sqrt, "_glTexParameterfv": _glTexParameterfv, "_write": _write, "_glGenBuffers": _glGenBuffers, "_glFinish": _glFinish, "_glGetAttribLocation": _glGetAttribLocation, "_glVertexAttrib4f": _glVertexAttrib4f, "_rewind": _rewind, "___cxa_allocate_exception": ___cxa_allocate_exception, "_sin": _sin, "_glBlendFunc": _glBlendFunc, "_glCreateProgram": _glCreateProgram, "_realpath": _realpath, "_stat": _stat, "_longjmp": _longjmp, "_vasprintf": _vasprintf, "_glViewport": _glViewport, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_time": _time, "___ctype_toupper_loc": ___ctype_toupper_loc, "___cxa_begin_catch": ___cxa_begin_catch, "_glVertexAttrib2f": _glVertexAttrib2f, "_closedir": _closedir, "_isgraph": _isgraph, "_readlink": _readlink, "___ctype_tolower_loc": ___ctype_tolower_loc, "_glGetUniformfv": _glGetUniformfv, "_llvm_va_end": _llvm_va_end, "_unlink": _unlink, "_gluOrtho2D": _gluOrtho2D, "_glUniformMatrix4fv": _glUniformMatrix4fv, "_glClearDepth": _glClearDepth, "_glGetActiveUniform": _glGetActiveUniform, "_glutDestroyWindow": _glutDestroyWindow, "_pwrite": _pwrite, "__isFloat": __isFloat, "_fabs": _fabs, "_glTexParameterf": _glTexParameterf, "__ZSt9terminatev": __ZSt9terminatev, "_RWebAudioStart": _RWebAudioStart, "_glTexParameteri": _glTexParameteri, "_glFrontFace": _glFrontFace, "_glCullFace": _glCullFace, "_glDepthRangef": _glDepthRangef, "_glDeleteBuffers": _glDeleteBuffers, "_eglGetDisplay": _eglGetDisplay, "_emscripten_set_canvas_size": _emscripten_set_canvas_size, "___cxa_is_number_type": ___cxa_is_number_type, "_glGetBooleanv": _glGetBooleanv, "_eglQuerySurface": _eglQuerySurface, "_glPixelStorei": _glPixelStorei, "_readdir_r": _readdir_r, "_glValidateProgram": _glValidateProgram, "_glPolygonOffset": _glPolygonOffset, "__Z7catgetsP8_nl_catdiiPKc": __Z7catgetsP8_nl_catdiiPKc, "___gxx_personality_v0": ___gxx_personality_v0, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "__ZTVN10__cxxabiv117__class_type_infoE": __ZTVN10__cxxabiv117__class_type_infoE, "___fsmu8": ___fsmu8, "_stdout": _stdout, "___dso_handle": ___dso_handle, "_stdin": _stdin, "_stderr": _stderr, "__ZTVN10__cxxabiv120__si_class_type_infoE": __ZTVN10__cxxabiv120__si_class_type_infoE }, buffer);
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _strcat = Module["_strcat"] = asm["_strcat"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _strncpy = Module["_strncpy"] = asm["_strncpy"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var __GLOBAL__I_a = Module["__GLOBAL__I_a"] = asm["__GLOBAL__I_a"];
var _strncasecmp = Module["_strncasecmp"] = asm["_strncasecmp"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _strcasecmp = Module["_strcasecmp"] = asm["_strcasecmp"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_vif = Module["dynCall_vif"] = asm["dynCall_vif"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_viffff = Module["dynCall_viffff"] = asm["dynCall_viffff"];
var dynCall_if = Module["dynCall_if"] = asm["dynCall_if"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiiif = Module["dynCall_viiiiif"] = asm["dynCall_viiiiif"];
var dynCall_viff = Module["dynCall_viff"] = asm["dynCall_viff"];
var dynCall_vifff = Module["dynCall_vifff"] = asm["dynCall_vifff"];
var dynCall_fii = Module["dynCall_fii"] = asm["dynCall_fii"];
var dynCall_iiif = Module["dynCall_iiif"] = asm["dynCall_iiif"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_iif = Module["dynCall_iif"] = asm["dynCall_iif"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_ff = Module["dynCall_ff"] = asm["dynCall_ff"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_viiiiiif = Module["dynCall_viiiiiif"] = asm["dynCall_viiiiiif"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_f = Module["dynCall_f"] = asm["dynCall_f"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiiiiiii = Module["dynCall_iiiiiiiii"] = asm["dynCall_iiiiiiiii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };
// TODO: strip out parts of this we do not need
//======= begin closure i64 code =======
// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */
var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };
  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.
    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };
  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.
  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};
  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };
  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };
  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };
  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };
  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.
  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;
  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);
  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);
  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };
  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };
  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (this.isZero()) {
      return '0';
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }
    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };
  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };
  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };
  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };
  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };
  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };
  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };
  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };
  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };
  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };
  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };
  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);
      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };
  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };
  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };
  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };
  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };
  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };
  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };
  //======= begin jsbn =======
  var navigator = { appName: 'Modern Browser' }; // polyfill a little
  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/
  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */
  // Basic JavaScript BN library - subset useful for RSA encryption.
  // Bits per digit
  var dbits;
  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);
  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }
  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }
  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.
  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;
  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }
  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }
  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }
  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }
  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }
  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }
  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }
  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }
  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }
  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }
  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }
  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }
  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }
  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }
  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }
  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }
  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }
  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }
  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }
  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }
  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }
  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }
  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }
  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }
  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }
  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  // jsbn2 stuff
  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }
  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }
  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }
  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }
  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }
  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  //======= end jsbn =======
  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();
//======= end closure i64 code =======
// === Auto-generated postamble setup entry stuff ===
function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;
var initialStackTop;
var preloadStartTime = null;
Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
    Module.printErr('preload time: ' + (Date.now() - preloadStartTime) + ' ms');
  }
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);
  initialStackTop = STACKTOP;
  try {
    var ret = Module['_main'](argc, argv, 0);
    // if we're not running an evented main loop, it's time to exit
    if (!Module['noExitRuntime']) {
      exit(ret);
    }
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      throw e;
    }
  }
}
function run(args) {
  args = args || Module['arguments'];
  if (preloadStartTime === null) preloadStartTime = Date.now();
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }
  preRun();
  if (runDependencies > 0) {
    // a preRun added a dependency, run will be called later
    return;
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    calledRun = true;
    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }
    postRun();
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;
function exit(status) {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;
  // exit the runtime
  exitRuntime();
  // throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;
function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }
  ABORT = true;
  EXITSTATUS = 1;
  throw 'abort() at ' + (new Error().stack);
}
Module['abort'] = Module.abort = abort;
// {{PRE_RUN_ADDITIONS}}
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run();
// {{POST_RUN_ADDITIONS}}
// {{MODULE_ADDITIONS}}
